%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%        File: lctenc.def
%      Author: Oliver Corff
%        Date: July 1st, 2002
%     Version: 0.6
%   Copyright: Ulaanbaatar, Beijing, Berlin
%
% Description: Local Tibetan Encoding Definition
%
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% -------------------     identification     -------------------
%
\ProvidesFile{lctenc.def}
	[2002/07/01 v0.6 Mongolian Language Support Tibetan Encoding]
%
%
\DeclareFontEncoding{LCT}{}{}{}
\DeclareFontSubstitution{LCT}{ctib}{m}{n}
%
\DeclareTextSymbol{\tibom			}{LCT}{0 }
\DeclareTextSymbol{\om				}{LCT}{0 }
\DeclareTextSymbol{\tibswasti			}{LCT}{"40 }
\DeclareTextSymbol{\tibvarfive			}{LCT}{5 }
\DeclareTextSymbol{\tibvarsix			}{LCT}{6 }
\DeclareTextSymbol{\tibvarseven			}{LCT}{7 }
\DeclareTextSymbol{\tibvareight			}{LCT}{8 }
\DeclareTextSymbol{\tibvarnine			}{LCT}{9 }
\DeclareTextSymbol{\tibempty			}{LCT}{32 }
\DeclareTextSymbol{\tibShad			}{LCT}{46 }
\DeclareTextSymbol{\tibTsheg			}{LCT}{44 }
\DeclareTextSymbol{\tibSwasti			}{LCT}{64 }
\DeclareTextSymbol{\tibVisarga			}{LCT}{58 }
\DeclareTextSymbol{\tibTshegshad		}{LCT}{33 }
\DeclareTextSymbol{\tibAlttshegshad		}{LCT}{31 }
\DeclareTextSymbol{\tibNyistshegshad		}{LCT}{34 }
\DeclareTextSymbol{\tibChemgoshad		}{LCT}{35 }
\DeclareTextSymbol{\tibSbrulshad		}{LCT}{36 }
\DeclareTextSymbol{\tibRgyagramshad		}{LCT}{37 }
\DeclareTextSymbol{\tibVarchemgoshad		}{LCT}{38 }
\DeclareTextSymbol{\tibRjessungaro		}{LCT}{24 }
\DeclareTextSymbol{\tibSnaldan			}{LCT}{25 }
\DeclareTextSymbol{\tibRnambcad			}{LCT}{26 }
\DeclareTextSymbol{\tibGtertsheg		}{LCT}{27 }
\DeclareTextSymbol{\tibRinchenspungsshad	}{LCT}{47 }
\DeclareTextSymbol{\tibTopiniyigmgomdunma	}{LCT}{40 }
\DeclareTextSymbol{\tibFinalyigmgomdunma	}{LCT}{41 }
\DeclareTextSymbol{\tibIniyigmgomdunma		}{LCT}{42 }
\DeclareTextSymbol{\tibAngkhyanggyon		}{LCT}{60 }
\DeclareTextSymbol{\tibAngkhyanggyas		}{LCT}{62 }
\DeclareTextSymbol{\tibHalanta			}{LCT}{10 }
\DeclareTextSymbol{\tibLcirtags			}{LCT}{11 }
\DeclareTextSymbol{\tibNyizlanaada		}{LCT}{12 }
\DeclareTextSymbol{\tibHalf			}{LCT}{13 }
\DeclareTextSymbol{\tibGteryigmgotr		}{LCT}{14 }
\DeclareTextSymbol{\tibPaluta			}{LCT}{15 }
%
\DeclareTextSymbolDefault{\tibom		}{LCT}
\DeclareTextSymbolDefault{\om			}{LCT}
\DeclareTextSymbolDefault{\tibswasti		}{LCT}
%%  \DeclareTextSymbolDefault{\tibvarfive	}{LCT}
%%  \DeclareTextSymbolDefault{\tibvarsix	}{LCT}
%%  \DeclareTextSymbolDefault{\tibvarseven	}{LCT}
%%  \DeclareTextSymbolDefault{\tibvareight	}{LCT}
%%  \DeclareTextSymbolDefault{\tibvarnine	}{LCT}
\DeclareTextSymbolDefault{\tibempty		}{LCT}
\DeclareTextSymbolDefault{\tibShad		}{LCT}
\DeclareTextSymbolDefault{\tibTsheg		}{LCT}
\DeclareTextSymbolDefault{\tibSwasti		}{LCT}
\DeclareTextSymbolDefault{\tibVisarga		}{LCT}
\DeclareTextSymbolDefault{\tibTshegshad		}{LCT}
\DeclareTextSymbolDefault{\tibAlttshegshad	}{LCT}
\DeclareTextSymbolDefault{\tibNyistshegshad	}{LCT}
\DeclareTextSymbolDefault{\tibChemgoshad	}{LCT}
\DeclareTextSymbolDefault{\tibSbrulshad		}{LCT}
\DeclareTextSymbolDefault{\tibRgyagramshad	}{LCT}
\DeclareTextSymbolDefault{\tibVarchemgoshad	}{LCT}
\DeclareTextSymbolDefault{\tibRjessungaro	}{LCT}
\DeclareTextSymbolDefault{\tibSnaldan		}{LCT}
\DeclareTextSymbolDefault{\tibRnambcad		}{LCT}
\DeclareTextSymbolDefault{\tibGtertsheg		}{LCT}
\DeclareTextSymbolDefault{\tibRinchenspungsshad	}{LCT}
\DeclareTextSymbolDefault{\tibTopiniyigmgomdunma}{LCT}
\DeclareTextSymbolDefault{\tibFinalyigmgomdunma	}{LCT}
\DeclareTextSymbolDefault{\tibIniyigmgomdunma	}{LCT}
\DeclareTextSymbolDefault{\tibAngkhyanggyon	}{LCT}
\DeclareTextSymbolDefault{\tibAngkhyanggyas	}{LCT}
\DeclareTextSymbolDefault{\tibHalanta		}{LCT}
\DeclareTextSymbolDefault{\tibLcirtags		}{LCT}
\DeclareTextSymbolDefault{\tibNyizlanaada	}{LCT}
\DeclareTextSymbolDefault{\tibHalf		}{LCT}
\DeclareTextSymbolDefault{\tibGteryigmgotr	}{LCT}
\DeclareTextSymbolDefault{\tibPaluta		}{LCT}
%
\endinput
