% Copyright 2000-2005 Werner Lemberg <wl@gnu.org>.
% This file is part of vntex.  License: LPPL, version 1.3 or newer,
% according to http://www.latex-project.org/lppl.txt
%
%
% This is the file viscii.def which provides VISCII input encoding for
% Vietnamese.
%
% written by Werner Lemberg <wl@gnu.org>
%
% History
%
%   1.0  2000/01/28
%
%     Initial release.
%
%   post 1.0  ?
%
%     Don't rely on dblaccnt.sty.
%
%   1.1  2005/04/21
%
%     Add copyright message and history.

\ProvidesFile{viscii.def}[2005/04/21 v1.1 VISCII Vietnamese input encoding]

\makeatletter

\DeclareInputText{2}{\h\ABREVE}
\DeclareInputText{5}{\~\ABREVE}
\DeclareInputText{6}{\~\ACIRCUMFLEX}
\DeclareInputText{20}{\h Y}
\DeclareInputText{25}{\~Y}
\DeclareInputText{30}{\d Y}

\DeclareInputText{128}{\d A}
\DeclareInputText{129}{\@tabacckludge'\ABREVE}
\DeclareInputText{130}{\@tabacckludge`\ABREVE}
\DeclareInputText{131}{\d\ABREVE}
\DeclareInputText{132}{\@tabacckludge'\ACIRCUMFLEX}
\DeclareInputText{133}{\@tabacckludge`\ACIRCUMFLEX}
\DeclareInputText{134}{\h\ACIRCUMFLEX}
\DeclareInputText{135}{\d\ACIRCUMFLEX}
\DeclareInputText{136}{\~E}
\DeclareInputText{137}{\d E}
\DeclareInputText{138}{\@tabacckludge'\ECIRCUMFLEX}
\DeclareInputText{139}{\@tabacckludge`\ECIRCUMFLEX}
\DeclareInputText{140}{\h\ECIRCUMFLEX}
\DeclareInputText{141}{\~\ECIRCUMFLEX}
\DeclareInputText{142}{\d\ECIRCUMFLEX}
\DeclareInputText{143}{\@tabacckludge'\OCIRCUMFLEX}

\DeclareInputText{144}{\@tabacckludge`\OCIRCUMFLEX}
\DeclareInputText{145}{\h\OCIRCUMFLEX}
\DeclareInputText{146}{\~\OCIRCUMFLEX}
\DeclareInputText{147}{\d\OCIRCUMFLEX}
\DeclareInputText{148}{\d\OHORN}
\DeclareInputText{149}{\@tabacckludge'\OHORN}
\DeclareInputText{150}{\@tabacckludge`\OHORN}
\DeclareInputText{151}{\h\OHORN}
\DeclareInputText{152}{\d I}
\DeclareInputText{153}{\h O}
\DeclareInputText{154}{\d O}
\DeclareInputText{155}{\h I}
\DeclareInputText{156}{\h U}
\DeclareInputText{157}{\~U}
\DeclareInputText{158}{\d U}
\DeclareInputText{159}{\@tabacckludge`Y}

\DeclareInputText{160}{\~O}
\DeclareInputText{161}{\@tabacckludge'\abreve}
\DeclareInputText{162}{\@tabacckludge`\abreve}
\DeclareInputText{163}{\d\abreve}
\DeclareInputText{164}{\@tabacckludge'\acircumflex}
\DeclareInputText{165}{\@tabacckludge`\acircumflex}
\DeclareInputText{166}{\h\acircumflex}
\DeclareInputText{167}{\d\acircumflex}
\DeclareInputText{168}{\~e}
\DeclareInputText{169}{\d e}
\DeclareInputText{170}{\@tabacckludge'\ecircumflex}
\DeclareInputText{171}{\@tabacckludge`\ecircumflex}
\DeclareInputText{172}{\h\ecircumflex}
\DeclareInputText{173}{\~\ecircumflex}
\DeclareInputText{174}{\d\ecircumflex}
\DeclareInputText{175}{\@tabacckludge'\ocircumflex}

\DeclareInputText{176}{\@tabacckludge`\ocircumflex}
\DeclareInputText{177}{\h\ocircumflex}
\DeclareInputText{178}{\~\ocircumflex}
\DeclareInputText{179}{\~\OHORN}
\DeclareInputText{180}{\OHORN}
\DeclareInputText{181}{\d\ocircumflex}
\DeclareInputText{182}{\@tabacckludge`\ohorn}
\DeclareInputText{183}{\h\ohorn}
\DeclareInputText{184}{\d i}
\DeclareInputText{185}{\d\UHORN}
\DeclareInputText{186}{\@tabacckludge'\UHORN}
\DeclareInputText{187}{\@tabacckludge`\UHORN}
\DeclareInputText{188}{\h\UHORN}
\DeclareInputText{189}{\ohorn}
\DeclareInputText{190}{\@tabacckludge'\ohorn}
\DeclareInputText{191}{\UHORN}

\DeclareInputText{192}{\@tabacckludge`A}
\DeclareInputText{193}{\@tabacckludge'A}
\DeclareInputText{194}{\ACIRCUMFLEX}
\DeclareInputText{195}{\~A}
\DeclareInputText{196}{\h A}
\DeclareInputText{197}{\ABREVE}
\DeclareInputText{198}{\h\abreve}
\DeclareInputText{199}{\~\abreve}
\DeclareInputText{200}{\@tabacckludge`E}
\DeclareInputText{201}{\@tabacckludge'E}
\DeclareInputText{202}{\ECIRCUMFLEX}
\DeclareInputText{203}{\h E}
\DeclareInputText{204}{\@tabacckludge`I}
\DeclareInputText{205}{\@tabacckludge'I}
\DeclareInputText{206}{\~I}
\DeclareInputText{207}{\@tabacckludge`y}

\DeclareInputText{208}{\DJ}
\DeclareInputText{209}{\@tabacckludge'\uhorn}
\DeclareInputText{210}{\@tabacckludge`O}
\DeclareInputText{211}{\@tabacckludge'O}
\DeclareInputText{212}{\OCIRCUMFLEX}
\DeclareInputText{213}{\d a}
\DeclareInputText{214}{\h y}
\DeclareInputText{215}{\@tabacckludge`\uhorn}
\DeclareInputText{216}{\h\uhorn}
\DeclareInputText{217}{\@tabacckludge`U}
\DeclareInputText{218}{\@tabacckludge'U}
\DeclareInputText{219}{\~y}
\DeclareInputText{220}{\d y}
\DeclareInputText{221}{\@tabacckludge'Y}
\DeclareInputText{222}{\~\ohorn}
\DeclareInputText{223}{\uhorn}

\DeclareInputText{224}{\@tabacckludge`a}
\DeclareInputText{225}{\@tabacckludge'a}
\DeclareInputText{226}{\acircumflex}
\DeclareInputText{227}{\~a}
\DeclareInputText{228}{\h a}
\DeclareInputText{229}{\abreve}
\DeclareInputText{230}{\~\uhorn}
\DeclareInputText{231}{\~\acircumflex}
\DeclareInputText{232}{\@tabacckludge`e}
\DeclareInputText{233}{\@tabacckludge'e}
\DeclareInputText{234}{\ecircumflex}
\DeclareInputText{235}{\h e}
\DeclareInputText{236}{\@tabacckludge`i}
\DeclareInputText{237}{\@tabacckludge'i}
\DeclareInputText{238}{\~i}
\DeclareInputText{239}{\h i}

\DeclareInputText{240}{\dj}
\DeclareInputText{241}{\d\uhorn}
\DeclareInputText{242}{\@tabacckludge`o}
\DeclareInputText{243}{\@tabacckludge'o}
\DeclareInputText{244}{\ocircumflex}
\DeclareInputText{245}{\~o}
\DeclareInputText{246}{\h o}
\DeclareInputText{247}{\d o}
\DeclareInputText{248}{\d u}
\DeclareInputText{249}{\@tabacckludge`u}
\DeclareInputText{250}{\@tabacckludge'u}
\DeclareInputText{251}{\~u}
\DeclareInputText{252}{\h u}
\DeclareInputText{253}{\@tabacckludge'y}
\DeclareInputText{254}{\d\ohorn}
\DeclareInputText{255}{\~\UHORN}

\makeatother

\endinput

% end of viscii.def
