\qt@newcmd\qurantrans@ur@i{شروع الله کا نام لے کر جو بڑا مہربان نہایت رحم والا ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@ii{سب تعریفیں الله کے لیے ہیں جو سب جہانوں کا پالنے والا ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@iii{بڑا مہربان نہایت رحم والا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@iv{جزا کے دن کا مالک\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@v{ہم تیری ہی عبادت کرتے ہیں اور تجھ ہی سے مدد مانگتے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@vi{ہمیں سیدھا راستہ دکھا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@vii{ان لوگوں کا راستہ جن پر تو نے انعام کیا نہ جن پر تیرا غضب نازل ہوا اور نہ وہ گمراہ ہوئے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@viii{\basmalahur المۤ\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@ix{یہ وہ کتاب ہے جس میں کوئی بھی شک نہیں پرہیز گارو ں کے لیے ہدایت ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@x{جو بن دیکھے ایمان لاتے ہیں اور نماز قائم کرتے ہیں ا ور جو کچھ ہم نے انہیں دیا ہے اس میں خرچ کرتے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@xi{اور جو ایمان لاتے ہیں اس پر جو اتارا گیا آپ پراور جو آپ سے پہلے اتارا گیا اور آخرت پر بھی وہ یقین رکھتے ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@xii{وہی لوگ اپنے رب کے راستہ پر ہیں اور وہی نجات پانے والے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@xiii{بے شک جو لوگ انکار کر چکے ہیں برابر ہے انہیں تو ڈرائے یا نہ ڈرائے وہ ایمان نہیں لائیں گے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@xiv{الله نے ان کے دلوں اورکانوں پرمہر لگا دی ہے اور ان کی آنکھوں پر پردہ ہے اوران کے لیے بڑا عذا ب ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@xv{اور کچھ ایسے بھی لوگ ہیں جو کہتے ہیں کہ ہم الله اور قیامت کے دن پر ایمان لائے حالانکہ وہ ایمان دار نہیں ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@xvi{الله اور ایمان داروں کو دھوکا دیتے ہیں حالانکہ وہ اپنے آپ ہی کو دھوکہ دے رہے ہیں اور نہیں سمجھتے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@xvii{انکے دلوں میں بیماری ہے پھر الله نے ان کی بیماری بڑھا دی اور ان کے لیے دردناک عذاب ہے اس لیے کہ وہ جھوٹ بولتے تھے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@xviii{اور جب انہیں کہا جاتا ہے کہ ملک میں فساد نہ ڈالو تو کہتے ہیں کہ ہم ہی تو اصلاح کرنے والے ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@xix{خبردار بے شک وہی لوگ فسادی ہیں لیکن نہیں سمجھتے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@xx{اور جب انہیں کہا جاتا ہے ایمان لاؤ جس طرح اور لوگ ایمان لائے ہیں تو کہتے ہیں کیا ہم ایمان لائیں جس طرح بے وقوف ایمان لائے ہیں خبردار وہی بے وقوف ہیں لیکن نہیں جانتے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@xxi{اور جب ایمانداروں سے ملتے ہیں تو کہتے ہیں کہ ہم ایمان لائے اور جب اپنے شیطانوں کے پاس اکیلے ہوتے ہیں تو کہتے ہیں ہم توتمہارے ساتھ ہیں ہم تو صرف ہنسی کرنے والے ہیں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@xxii{الله ان سے ہنسی کرتا ہے اور انہیں مہلت دیتا ہے کہ وہ اپنی گمراہی میں حیران رہیں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@xxiii{یہ وہ لوگ ہیں جنہوں نے ہدایت کے بدلے گمراہی خریدی سو ان کی تجارت نے نفع نہ دیا اور ہدایت پانے والے نہ ہوئے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@xxiv{ان کی مثال اس شخص کی سی ہے جس نے آگ جلائی پھر جب آگ نے اس کے آس پاس کو روشن کر دیا تو الله نے ان کی روشنی بجھا دی اور انہیں اندھیروں میں چھوڑا کہ کچھ نہیں دیکھتے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@xxv{بہرے گونگے اندھے ہیں سو وہ نہیں لوٹیں گے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@xxvi{یا جیسا کہ آسمان سے بارش ہو جس میں اندھیرے اور گرج اور بجلی ہو اپنی انگلیاں اپنے کانوں میں کڑک کے سبب سے موت کے ڈر سے دیتے ہوں اور الله کافروں کو گھیرے ہوئے ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@xxvii{قریب ہے کہ بجلی ان کے آنکھیں اچک لے جب ان پر چمکتی ہے تو اس کی روشنی میں چلتے ہیں اور جب ان پر اندھیرا ہوتا ہے تو ٹھر جاتے ہیں اور اگر الله چاہے تو ان کے کان اور آنکھیں لے جائے بے شک الله ہر چیز پر قادر ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@xxviii{اے لوگو اپنے رب کی عبادت کرو جس نے تمہیں پیدا کیا اور انہیں جو تم سے پہلے تھے تاکہ تم پرہیزگار ہو جاؤ\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@xxix{جس نے تمہارے لیے زمین کو بچھونا اور آسمان کو چھت بنایا اور آسمان سے پانی اتارا پھر اس سے تمہارے کھانے کے لیے پھل نکالے سو کسی کو الله کا شریک نہ بناؤ حالانکہ تم جانتے بھی ہو\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@xxx{اور اگر تمہیں اس چیز میں شک ہے جو ہم نے اپنے بندے پر نازل کی ہے تو ایک سورت اس جیسی لے آؤ اور الله کے سوا جس قدر تمہارے حمایتی ہوں بلا لو اگر تم سچے ہو\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@xxxi{بھلا اگر ایسا نہ کر سکو اور ہرگز نہ کر سکو گے تو اس آگ سے بچو جس کا ایندھن آدمی اور پتھر ہیں جو کافرو ں کے لیے تیار کی گئی ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@xxxii{اوران لوگو ں کو خوشخبری دے جو ایمان لائے اور اچھے کام کیے کہ ان کے لیے باغ ہیں ان کے نیچے نہریں بہتی ہیں جب انہیں وہاں کا کوئي پھل کھانے کو ملے گا تو کہیں گے یہ تو وہی ہے جو ہمیں اس سے پہلے ملا تھا اور انہیں ہم شکل پھل دیئے جائیں گے اور ان کے لیے وہاں پاکیزہ عورتیں ہوں گی اوروہ وہیں ہمیشہ رہیں گے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@xxxiii{بے شک الله نہیں شرماتا اس بات سے کہ کوئی مثال بیان کرے مچھر کی یا اس چیز کی جو اس سے بڑھ کر ہے سو جو لوگ مومن ہیں وہ اسے اپنے رب کی طرف سے صحیح جانتے ہیں اور جو کافر ہیں سو کہتے ہیں الله کا اس مثال سے کیا مطلب ہے الله اس مثال سے بہتوں کو گمراہ کرتا ہے اور بہتوں کو اس سے ہدایت کرتا ہے اوراس سے گمراہ تو بدکاروں ہی کو کیا کرتا ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@xxxiv{جو الله کے عہد کو پختہ کرنے کے بعد توڑتے ہیں اور جس کے جوڑنے کا الله نے حکم دیا ہے اسے توڑتے ہیں اور ملک میں فساد کرتے ہیں وہی لوگ نقصان اٹھانے والے ہیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@xxxv{تم الله کا کیونکر انکار کرسکتے ہو حالانکہ تم بے جان تھے پھر تمہیں زندہ کیا پھر تمہیں مارے گا پھر تمہیں زندہ کرے گا پھر تم اسی کے پاس لوٹ کر جاؤ گے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@xxxvi{الله وہ ہے جس نے جو کچھ زمین میں ہے سب تمہارے لیے پیدا کیا ہےپھر آسمان کی طرف متوجہ ہوا تو انہیں سات آسمان بنایا اور وہ ہر چیز جانتا ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@xxxvii{اور جب تیرے رب نے فرشتوں سے کہا میں زمین میں ایک نائب بنانے والا ہوں فرشتوں نے کہا کیا تو زمین میں ایسے شخص کو نائب بنانا چاہتا ہے جو فساد پھیلائے اور خون بہائے حالانکہ ہم تیری حمد کے ساتھ تسبیح بیان کرتے اور تیری پاکی بیان کرتے ہیں فرمایا میں جو کچھ جانتا ہوں وہ تم نہیں جانتے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@xxxviii{اور الله نے آدم کو سب چیزوں کے نام سکھائے پھر ان سب چیزوں کو فرشتوں کے سامنے پیش کیا پھر فرمایا مجھے ان کے نام بتاؤ اگر تم سچے ہو\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@xxxix{انہوں نے کہا تو پاک ہے ہم تو اتنا ہی جانتے ہیں جتنا تو نے ہمیں بتایاہے بے شک تو بڑے علم والا حکمت والا ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@xl{فرمایا اے آدم ان چیزو ں کے نام بتا دو پھر جب آدم نے انہیں ان کے نام بتا دیئے فرمایا کیا میں نے تمہیں نہیں کہا تھا کہ میں آسمانوں اور زمین کی چھپی ہوئی چیزیں جانتا ہوں اور جو تم ظاہر کرتے ہو اور جو چھپاتے ہو اسے بھی جانتا ہوں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@xli{اورجب ہم نے فرشتوں سے کہا کہ آدم کو سجدہ کرو تو انہوں نے سجدہ کیا مگر ابلیس کہ اس نے انکار کیا اورتکبر کیا اورکافروں میں سے ہو گیا\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@xlii{اور ہم نے کہا اے آدم تم اور تمہاری بیوی جنت میں جا کر رہو اور اس میں جو چاہو اور جہاں سےچاہو کھاؤ اور اس درخت کے نزدیک نہ جاؤ پھر ظالموں میں سے ہو جاؤ گے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@xliii{پھر شیطان نے ان کو وہاں سے ڈگمگایا پھر انہیں اس عزت و راحت سے نکالا کہ جس میں تھے اور ہم نے کہا تم سب اترو کہ تم ایک دوسرے کے دشمن ہو اور تمہارے لیے زمین میں ٹھکانا ہے اور سامان ایک وقت معین تک\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@xliv{پھر آدم نے اپنے رب سے چند کلمات حاصل کیے پھر اس کی توبہ قبول فرمائی بے شک وہ توبہ قبول کرنے والا مہربان ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@xlv{ہم نے کہا کہ تم سب یہاں سے نیچے اتر جاؤ پھر اگرتمہارے پاس میری طرف سے کوئی ہدایت آئے پس جو میری ہدایت پر چلیں گے ان پرنہ کچھ خوف ہوگا اور نہ وہ غمگین ہوں گے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@xlvi{اور جو انکار کریں گے اور ہماری آیتوں کو جھٹلائیں گے وہی دوزخی ہو ں گے جو اس میں ہمیشہ رہی گے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@xlvii{اے بنی اسرائل میرے احسان یاد کرو جو میں نے تم پر کئے اور تم میرا عہد پورا کرو میں تمہارا عہد پورا کروں گا اور مجھ ہی سے ڈرا کرو\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@xlviii{اور اس کتاب پر ایمان لاؤ جو میں نے نازل کی تصدیق کرتی ہے اس کی جو تمہارے پاس ہے اور تم ہی سب سے پہلے اس کےمنکر نہ بنو اور میری آیتو ں کو تھوڑی قیمت پر نہ بیچو اور مجھ ہی سے ڈرو\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@xlix{اور سچ میں جھوٹ نہ ملاؤ اور جان بوجھ کر حق کو نہ چھپاؤ\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@l{اورنماز قائم کرو اوزکوةٰ دو اور رکوع کرنے والوں کے ساتھ رکوع کرو\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@li{کیا لوگوں کو تم نیکی کا حکم کرتے ہو اور اپنے آپ کو بھول جاتے ہو حالانکہ تم کتاب پڑھتے ہو پھر کیوں نہیں سمجھتے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@lii{اور صبر کرنے اور نماز پڑھنے سےمدد لیا کرو اوربے شک نماز مشکل ہے مگر ان پر جو عاجزی کرنے والے ہیں\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@liii{جو یہ سمجھتے ہیں کہ ہمیں ضرور اپنے رب سے ملنا ہے اور ہمیں اس کے پاس لوٹ کر جانا ہے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@liv{اے بنی اسرائیل میری ان نعمتوں کو یاد کرو جو میں نے تمہیں دی تھیں اور میں نے تمہیں جہان پر فضیلت دی تھی\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@lv{اوراس دن سے ڈرو جس دن کوئی شخص کسی کے کچھ بھی کام نہ آئے گا اور نہ ان کے لیے کوئی سفارش قبول ہو گی اورنہ اس کی طرف سے بدلہ لیا جائے گا اور نہ ان کی مدد کی جائے گی\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@lvi{اور جب ہم نے تمہیں فرعونیوں سے نجات دی و ہ تمہیں بری طرح عذاب دیا کرتے تھے تمہارے بیٹوں کو ذبح کرتے تھے اور تمہاری بیٹیوں کو زندہ رکھتے تھے اور اس میں تمہارے رب کی طرف سے تمہاری بڑی آزمائش تھی\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@lvii{اور جب ہم نے تمہارے لیے سمندر کو پھاڑ دیا پھر تمہیں تو بچا لیا اور تمہارے دیکھتے دیکھتے فرعوینوں کو ڈبو دیا\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@lviii{اورجب ہم نے موسیٰ سے چالیس رات کا وعدہ کیا پھر اس کے بعد تم نے بچھڑا بنا لیا حالانکہ تم ظالم تھے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@lix{پھر اس کے بعدبھی ہم نے تمہیں معاف کر دیا تاکہ تم شکر کرو\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@lx{اورجب ہم نے موسیٰ کو کتاب اورقانون فیصل دیا تاکہ تم ہدایت پاؤ\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@lxi{اور جب موسیٰ نے اپنی قوم سے کہا اے میری قوم بے شک تم نے بچھڑا بنا کر اپنی جانوں پر ظلم کیا سو اپنے پیدا کرنے والے کے آگے توبہ کرو پھر اپنے آپ کو قتل کرو تمہارے لیے تمہارے خالق کے نزدیک یہی بہتر ہے پھر اس نے تمہاری توبہ قبول کر لی بے شک وہی بڑا توبہ قبول کرنے والا نہایت رحم والا ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@lxii{اور جب تم نے کہا اے موسیٰ ہم ہرگز تیرا یقین نہیں کریں گے جب تک کہ روبرو الله کو دیکھ نہ لیں تب تمہیں بجلی نے دیکھتے ہی دیکھتے آ لیا\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@lxiii{پھر ہم نے تمہیں تمہاری موت کے بعد زندہ کر اٹھایا تاکہ تم شکر کرو\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@lxiv{اور ہم نے تم پر ابر کا سایہ کیا اور تم پر من اور سلویٰ اتارا جو کچھ ہم نے تمہیں پاکیزہ چیزیں عطا کی ہیں ان میں سے کھاؤ اور انہوں نے ہمارا کچھ نقصان نہ کیا بلکہ اپنا ہی نقصان کرتے رہے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@lxv{اور جب ہم نے کہا اس شہر میں داخل ہو جاؤ پھر اس میں جہاں سے چاہو بے تکلفی سے کھاؤ اور دروازہ میں سجدہ کرتے ہوئے داخل ہو اور کہتے جاؤ بخش دے تو ہم تمہارے قصور معاف کر دیں گے اور نیکی کرنے والوں کو زیادہ بھی دیں گے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@lxvi{پھر ظالموں نے بدل ڈالا کلمہ سوائے اس کے جو انہیں کہا گیا تھا سو ہم نے ان ظالموں پر ان کی نافرمانی کی وجہ سے آسمان سے عذاب نازل کیا\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@lxvii{پھر جب موسیٰ نے اپنی قوم کے لیے پانی مانگا تو ہم نے کہا اپنے عصا کو پتھر پر مار سو اس سے بارہ چشمے بہہ نکلے ہر قوم نے اپنا گھاٹ پہچان لیا الله کے دیئے ہوئے رزق میں سے کھاؤ پیو اور زمین میں فساد مچاتےنہ پھرو\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@lxviii{اور جب تم نے کہا اے موسیٰ ہم ایک ہی طرح کے کھانے پر ہرگز صبر نہ کریں گے سو ہمارے لیے اپنے رب سے دعا مانگ کہ وہ ہمارے لیے زمین کی پیداوار میں سے ساگ اور ککڑی اور گیہوں اور مسور اور پیاز پیدا کر دے کہا کیا تم اس چیز کو لینا چاہتے ہو جو ادنیٰ ہے بدلہ اس کے جو بہتر ہے کسی شہر میں اُترو بے شک جو تم مانگتے ہو تمہیں ملے گا اور ان پر ذلت اور محتاجی ڈال دی گئی اور انہوں نے غضب الہیٰ کمایا یہ اس لیے کہ وہ الله کی نشانیوں کا انکار کرتے تھے اور نبیوں کو ناحق قتل کرتے تھے یہ اس لیے کہ نافرمان تھے اور حد سے بڑھ جاتے تھے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@lxix{جو کوئی مسلمان اور یہودی اور نصرانی اورصابئی الله اور قیامت کے دن پر ایمان لائے اور اچھے کام بھی کرے تو ان کا اجر ان کے رب کے ہاں موجود ہے اور ان پر نہ کچھ خوف ہو گا اور نہ وہ غمگین ہوں گے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@lxx{اور جب ہم نے تم سے عہد لیا اور تم پر کوہِ طور بلند کیا جو کچھ ہم نے تمہیں دیا ہے اسے مضبوط پکڑو اور جو کچھ اس میں ہے اسے یاد رکھو تاکہ تم پرہیزگار ہو جاؤ\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@lxxi{پھر تم اس کے بعد پھر گئے سو اگر تم پر الله کا فضل اور اس کی رحمت نہ ہوتی تو تم تباہ ہوجاتے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@lxxii{اور بے شک تمہیں وہ لوگ بھی معلوم ہیں جنہوں نے تم میں سے ہفتہ کے دن زیادتی کی تھی پھر ہم نے ان سے کہا تم ذلیل بندر ہو جاؤ\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@lxxiii{پھر ہم نے اس واقعہ کو اس زمانہ کے لوگوں کے لیے اور ان سے پچھلوں کے لیے عبرت اور پرہیز گاروں کے لیے نصیحت بنا دیا\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@lxxiv{اور جب موسیٰ نے اپنی قوم سے کہا کہ الله تمہیں حکم دیتا ہے کہ ایک گائے ذبح کرو انہوں نے کہا کیا تم ہم سے ہنسی کرتا ہے کہا میں الله کی پناہ مانگتا ہوں اس سے کہ جاہلوں میں سے ہوں\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@lxxv{انہوں نے کہا ہمارے لیے اپنے رب سے دعا کر ہمیں بتائے کہ وہ گائے کیسی ہے کہا وہ فرماتا ہے کہ وہ ایک ایسی گائے ہے نہ بوڑھی اور نہ بچہ اس کے درمیان ہے پس کر ڈالو جو تمہیں حکم دیا جاتا ہے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@lxxvi{انہوں نے کہا ہمارے لیے اپنے رب سے دعا کر کہ ہمیں بتائے اس کا رنگ کیسا ہےکہاوہ فرماتا ہے کہ وہ ایک زرد گائے ہے اس کا رنگ خوب گہراہے دیکھنے والوں کو بھلی معلوم ہوتی ہے\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@lxxvii{انہوں نے کہا ہمارے لیے اپنے رب سے دعا کر ہمیں بتائے کہ وہ کس قسم کی ہے کیوں کہ وہ گائے ہم پر مشتبہ ہو گئی ہے اور ہم اگر الله نے چاہا تو ضرور پتہ لگا لیں گے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@lxxviii{کہا و ہ فرماتا ہے کہ وہ ایک ایسی گائے ہے محنت کرنے والی نہیں جو زمین کو جوتتی ہو یا کھیتی کو پانی دیتی ہو بے عیب ہے اس میں کوئي داغ نہیں انہوں نے کہا اب تو نے ٹھیک بات بتائی پھر انہوں نے اسے ذبح کر دیا اور وہ کرنے والے تو نہیں تھے\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@lxxix{اور جب تم ایک شخص قتل کر کے اس میں جھگڑنے لگے اور الله ظاہر کرنے والا تھا اس چیز کو جسے تم چھپاتے تھے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@lxxx{پھر ہم نے کہا اس مردہ پر اس گائے کا ایک ٹکڑا مارو اسی طرح الله مردوں کو زندہ کرے گا اور تمہیں اپنی قدرت کی نشانیاں دکھاتا ہے تاکہ تم سمجھو\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@lxxxi{پھر ا سکے بعد تمہارے دل سخت ہو گئے گویا کہ وہ پتھر ہیں یا ان سے بھی زیادہ سخت اور بعض پتھر تو ایسے بھی ہیں جن سے نہریں پھوٹ کر نکلتی ہیں اور بعض ایسے بھی ہیں جو پھٹتے ہیں پھر ان سے پانی نکلتا ہے اور بعض ایسے بھی ہیں جو الله کے ڈر سے گر پڑتے ہیں اور الله تمہارے کاموں سے بے خبر نہیں\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@lxxxii{کیا تمہیں امید ہے کہ یہود تمہارے کہنے پر ایمان لے آئیں گے حالانکہ ان میں ایک ایسا گروہ بھی گزرا ہے جو الله کا کلام سنتا تھا پھر اسے سمجھنے کے بعد جان بوجھ کر بدل ڈالتا تھا\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@lxxxiii{اور جب وہ ان لوگوں سے ملتے ہیں جو ایمان لاچکے ہیں تو کہتے ہیں ہم بھی ایمان لے آئےہیں اور جب وہ ایک دوسرے کے پاس علیحدٰہ ہوتے ہیں تو کہتے ہیں کیا تم انہیں وہ راز بتا دیتےہو جو الله نے تم پر کھولے ہیں تاکہ وہ اس سے تمہیں تمہارے رب کے روبرو الزام دیں کیا تم نہیں سمجھتے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@lxxxiv{کیا وہ نہیں جانتے کہ الله جانتا ہے جو وہ چھپاتے ہیں اور جو وہ ظاہر کرتے ہیں\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@lxxxv{اور بعض ان میں سے ان پڑھ ہیں جو کتاب نہیں جانتے سوائے جھوٹی آرزوؤں کے اور وہ محض اٹکل پچو باتیں بناتے ہیں\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@lxxxvi{سو افسوس ہے ان لوگوں پر جو اپنے ہاتھوں سے لکھتے ہیں پھر کہتے ہیں کہ یہ الله کی طرف سے ہے تاکہ اس سے کچھ روپیہ کمائیں پھر افسوس ہے ان کے ہاتھوں کے لکھنے پر اور افسوس ہے ان کی کمائی ہر\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@lxxxvii{اور کہتے ہیں ہمیں سوائے چند گنتی کے دنوں کے آگ نہیں چھوٹے گی کہہ دو کیا تم نے الله سے کوئی عہدلےلیا ہے کہ ہر گز الله اپنے عہد کا خلاف نہیں کرے گا یا تم الله پر وہ باتیں کہتے ہو جو تم نہیں جانتے\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@lxxxviii{ہاں جس نے کوئی گناہ کیا اور اسے اس کے گناہ نے گھیر لیا سو وہی دوزخی ہیں وہ اس میں ہمیشہ رہیں گے\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@lxxxix{اور جو لوگ ایمان لائے اور نیک کام کئے وہی بہشتی ہیں وہ اس میں ہمیشہ رہیں گے\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@xc{اور جب ہم نے بنی اسرائیل سے عہد لیا کہ الله کے سوا کسی کی عبادت نہ کرنا اور ماں باپ اور رشتہ داروں اور یتیموں اور محتاجوں سے اچھا سلوک کرنا اور لوگوں سے اچھی بات کہنا اور نماز قائم کرنا اور زکوةٰ دینا پھر سوائے چند آدمیوں کے تم میں سے سب منہ موڑ کر پھر گئے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@xci{اور جب ہم نے تم سے عہد لیا کہ آپس میں خونریزی نہ کرنا اور نہ اپنے لوگوں کو جلا وطن کرنا پھر تم نے اقرار کیا اور تم خود گواہ ہو\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@xcii{پھر تم ہی وہ ہو کہ اپنے لوگوں کو قتل کرتے ہو اور ایک جماعت کو اپنے میں سے ان کے گھروں میں سے نکالتے ہو ان پر گناہ اور ظلم سے چڑھائی کرتے ہو اور اگر وہ تمہارے پاس قیدی ہو کر آئیں تو ان کا تاوان دیتے ہو حالانکہ تم پر ان کا نکالنا بھی حرام تھا کیا تم کتاب کے ایک حصہ پرایمان رکھتے ہو اور دوسرے حصہ کا انکار کرتے ہو پھرجو تم میں سے ایسا کرے اس کی یہی سزا ہے کہ دنیا میں ذلیل ہو اور قیامت کے دن بھی سخت عذاب میں دھکیلے جائیں اور الله اس سے بے خبر نہیں جو تم کرتے ہو\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@xciii{یہی وہ لوگ ہیں جنہوں نے دنیا کی زندگی کو آخرت کے بدلہ خریدا سو ان سے عذاب ہلکانہ کیا جائے گا اور نہ انہیں کوئی مدد مل سکے گی\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@xciv{اور بے شک ہم نے موسیٰ کو کتاب دی اور اس کے بعد بھی پے در پے رسول بھیجتے رہے اور ہم نے عیسیٰ مریم کے بیٹے کو نشانیاں دیں اور روح لقدس سے اس کی تائید کی کیا جب تمہارے پاس کوئی وہ حکم لایا جسے تمہارے دل نہیں چاہتے تھے تو تم اکڑ بیٹھے پھر ایک جماعت کو تم نے جھٹلایا اور ایک جماعت کو قتل کیا\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@xcv{اور کہتے ہیں ہمارے دلوں پر غلاف ہیں بلکہ الله نے ان کے کفر کے سبب سے لعنت کی ہے سو بہت ہی کم ایمان لاتے ہیں\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@xcvi{اور جب ان کے پاس اللہ کی طرف سے کتاب آئی جو تصدیق کرتی ہے اس کی جو ان کے پاس ہے اور اس سے پہلے وہ کفار پر فتح مانگا کرتے تھے پھر جب ان کے پاس وہ چیز آئی جسے انہوں نے پہچان لیا تو اس کا انکارکیاسوکافروں پر الله کی لعنت ہے\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@xcvii{انہوں نے اپنی جانوں کو بہت ہی بری چیز کے لیے بیچ ڈالا یہ کہ الله کی نازل کی ہوئی چیزوں کا اس ضد میں آ کر انکار کرنے لگے کہ وہ پنے فضل کو اپنے بندوں میں سے جس پر چاہتا ہے کیوں نازل کر دیتا ہے سوغضب پر غضب میں آ گئے اور کافروں کے لیے ذلت کا عذاب ہے\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@xcviii{اورجب ان سے کہا جاتا ہے کہ اس پر ایمان لاؤ جو الله نے نازل کیا ہے تو کہتے ہیں ہم تو اسی کو مانتے ہیں جو ہم پر اترا ہے اور اسے نہیں مانتے ہیں جو اس کے سوا ہے حالانکہ وہ حق ہے اور تصدیق کرنے والی ہے جو ان کے پاس ہے کہہ دو پھر تم کیوں اس سے پہلے الله کے نبیوں کو قتل کرتے رہے اگر تم مومن تھے\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@xcix{اور تمہارے پاس موسیٰ صریح معجزے لے کر آیا پھر تم نے اس کے بعد بچھڑے کو بنالیا اور تم ظالم تھے\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@c{اور جب ہم نے تم سے عہد لیا اور تم پر کوہِ طورکو اٹھایا کہ جو ہم نے تمہیں دیا ہے اسے مضبوطی سے پکڑو اور سنو انہوں نے کہا ہم نے سن لیا اور مانیں گے نہیں اور ان کے دلوں میں کفر کی وجہ سے بچھڑے کی محبت رچ گئی تھی کہہ دو اگر تم ایمان دار ہو تو تمہارا ایمان تمہیں بہت ہی برا حکم دے رہا ہے\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@ci{کہہ دو اگر الله کے نزدیک آخرت کا گھر خصوصیت کے ساتھ سوائے اور لوگوں کے تمہارے ہی لئے ہے تو تم موت کی آرزو کرو اگر تم سچے ہو\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@cii{وہ کبھی بھی اس کی ہر گز آرزو نہیں کریں گے ان گناہوں کی وجہ سے جو ان کے ہاتھ آگے بھیج چکے ہیں اور الله ظالموں کو خوب جانتا ہے\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@ciii{اور آپ انہیں زندگی پر سب لوگوں سے زيادہ حریص پائیں گے اور ان سے بھی جو مشرک ہیں ہرایک ان میں سے چاہتا ہے کہ کاش اسے ہزار برس عمرملے اور اسے عمر کا ملنا عذاب سے بچانے والا نہیں اور الله دیکھتا ہے جو وہ کرتے ہیں\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@civ{کہہ دوجو کوئی جبرائیل کا دشمن ہو سواسی نے اتاراہے وہ قرآن اللہ کے حکم سے آپ کے دل پر ان کی تصدیق کرتا ہے جو اس سے پہلے ہیں اور ایمان والوں کے لئے ہدایت اور خوشخبری ہے\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@cv{جو شخص اللہ اور اس کے فرشتوں اور اس کے رسولوں اور جبرائیل اور میکائیل کا دشمن ہو تو بیشک اللہ بھی ان کافروں کا دشمن ہے\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@cvi{اور ہم نے آپ کی طرف روشن آیتیں اتاری ہیں اور ان سے انکاری نہیں مگر فاسق\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@cvii{کیا جب کبھی انہوں نے کوئی عہد باندھا تو اسے ان میں سے ایک جماعت نے پھینک دیا بلکہ ان میں سے اکثرایمان ہی نہیں رکھتے\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@cviii{اور جب ان کے پاس الله کی طرف سے وہ رسول آیا جو اس کی تصدیق کرتا ہے جو ان کے پا س ہے تو اہلِ کتاب کی ایک جماعت نے الله کی کتاب کو اپنی پیٹھ کے پیچھے ایسا پھینکا کہ گویا اسے جانتے ہی نہیں\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@cix{اور انہوں نے اس چیز کی پیروی کی جو شیطان سلیمان کی بادشاہت کے وقت پڑھتے تھے اور سلیمان نے کفر نہیں کیا تھا لیکن شیطانوں نے ہی کفر کیا لوگوں کو جادو سکھاتے تھے اور اس کی بھی جو شہر بابل میں ہاروت و ماروت دوفرشتوں پر اتارا گیا تھا اور وہ کسی کو نہ سکھاتے تھے جب تک یہ نہ کہہ دیتے ہم تو صرف آزمائش کے لیے ہیں تو کافر نہ بن پس ان سے وہ بات سیکھتے تھے جس سے خاوند اور بیوی میں جدائی ڈالیں حالانکہ وہ اس سے کسی کو الله کے حکم کے سوا کچھ بھی نقصان نہیں پہنچا سکتے تھے اور سیکھتے تھے وہ و ان کو نقصان دیتی تھی اورنہ نفع اور وہ یہ بھی جانتے تھے کہ جس نے جادو کو خریدا اس کے لیے آخرت میں کچھ حصہ نہیں اور وہ چیز بہت بری ہے جس کے بدلہ میں انہوں نے اپنے آپ کو بیچا کاش وہ جانتے\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@cx{اور اگر وہ ایمان لاتے اور پرہیز گاری کرتے تو البتہ الله کے ہاں کا اجر ان کے لیے بہتر تھا کاش وہ جانتے\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@cxi{اے ایمان والو راعنا نہ کہو اور انظرنا کہو اور سنا کرو اور کافروں کے لیے دردناک عذاب ہے\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@cxii{اہل کتاب کے کافر اور مشرک نہیں چاہتے کہ تمہارے رب کی طرف سے تم پر کوئی بھی اچھی بات نازل ہو اور الله اپنی رحمت کے ساتھ خاص کر لیتا ہے جسے چاہے اور الله بڑے فضل والا ہے\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@cxiii{ہم جو کسی آیت کو منسوخ کرتے ہیں یا بھلا دیتے ہیں تو اس سے بہتر یا اس کے برابر لاتے ہیں کیا تم نہیں جانتے کہ الله ہر چیز پر قاد رہے\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@cxiv{کیا تم نہیں جانتے الله ہی کے لیے آسمانوں اور زمین کی بادشاہت ہے اور تمہارے لیے الله کے سوا نہ کوئی دوست ہے نہ مددگار\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@cxv{کیا تم چاہتے ہو کہ اپنے رسول سے سوال کرو جیسے اس سے پہلے موسیٰ سے سوال کیے گئے تھے اور جو کوئی ایمان کے عوض کفر کوبدل لے سو وہ سیدھے راستہ سے گمراہ ہوا\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@cxvi{اکثر اہلِ کتاب تو اپنے حسد سے حق ظاہر ہونے کے بعد بھی یہ چاہتے ہیں کہ کسی طرح سے تمہیں ایمان لانے کے بعد پھر کفر کی طرف لوٹا کر لے جائیں سو معاف کرو اور درگزر کرو جب تک کہ الله اپنا حکم بھیجے بے شک الله ہر چیز پر قادر ہے\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@cxvii{اور نماز قائم کرو اور زکوةٰ دو اور جو کچھ نیکی سے اپنےواسطے آگے بھیجو گے اسے الله کے ہاں پاؤ گے بے شک الله جو کچھ تم کرتے ہو سب دیکھتا ہے\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@cxviii{اور کہتے ہیں کہ سوائے یہود یا نصاریٰ کے اور کوئی جنت میں ہرگز داخل نہ ہوگا یہ ان کے ڈھکوسلے ہیں کہہ دو اپنی دلیل لاؤ اگر تم سچے ہو\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@cxix{ہاں جس نے اپنا منہ الله کے سامنے جھکا دیا اور وہ نیکو کار بھی ہو تو اس کے لیے اس کا بدلہ اس کے رب کے ہاں ہے اور ان پر نہ کوئی خوف ہوگا اور نہ وہ غمگین ہوں گے\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@cxx{اور یہود کہتے ہیں کہ نصاریٰ ٹھیک راہ پر نہیں اور نصاریٰ کہتے ہیں کہ یہودی راہے حق پر نہیں ہیں حالانکہ وہ سب کتاب پڑھتے ہیں ایسی ہی باتیں وہ لوگ بھی کہتے ہیں جو بے علم ہیں پھر الله قیامت کے دن ان باتوں کا کہ جس میں وہ جھگڑ رہے ہیں خودفیصلہ کرے گا\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@cxxi{اوراس سے بڑھ کر کون ظالم ہوگا جس نے الله کی مسجدوں میں اس کا نام لینے کی ممانعت کردی اور ان کے ویران کرنے کی کوشش کی ایسے لوگوں کا حق نہیں ہے کہ ان میں داخل ہوں مگر ڈرتے ہوئے ان کے لیے دنیا میں بھی ذلت ہے اوران کے لیے آخرت میں بہت بڑا عذاب ہے\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@cxxii{اورمشرق اور مغرب الله ہی کا ہے سو تم جدھر بھی رخ کرو ادھر ہی الله کا رخ ہے بے شک الله وسعت ولا جاننے والا ہے\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@cxxiii{اور کہتے ہیں الله نے بیٹا بنایاہے حالانکہ وہ پاک ہے بلکہ جو کچھ آسمانوں اور زمین میں ہے سب اسی کا ہے سب اسی کے فرمانبردار ہیں\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@cxxiv{آسمانوں اور زمین کا پیدا کرنے والا ہے اور جب کوئی چیز کرنا چاہتا ہے تو صرف یہی کہہ دیتا ہے کہ ہو جا سو وہ ہو جاتی ہے\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@cxxv{اوربے علم کہتے ہیں کہ الله ہم سے کیوں کلام نہیں کرتا یا ہمارے اس کوئی نشانی کیوں نہیں آتی ان سے پہلے لوگ بھی ایسی ہی باتیں کہہ چکے ہیں ان کے دل ایک جیسے ہیں یقین کرنے والوں کے لیے تو ہم نشانیاں بیان کر چکے ہیں\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@cxxvi{بے شک ہم نے تمہیں سچائ کے ساتھ بھیجا ہے خوشخبری سنانے کے لیے اور ڈرانے کے لیے اور تم سے دوزخیوں کے متعلق باز پرس نہ ہو گی\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@cxxvii{اورتم سے یہود اور نصاریٰ ہرگز راضی نہ ہوں گے جب تک کہ تم ان کے دین کی پیروی نہیں کرو گے کہہ دو بے شک ہدایت الله ہی کی ہدایت ہے اور اگر تم نے ان کی خواہشوں کی پیروی کی اس کے بعد جو تمہارے پاس علم آ چکا تو تمہارے لیے الله کے ہاں کوئی دوست اور مددگار نہیں ہوگا\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@cxxviii{وہ لوگ جنہیں ہم نے کتاب دی ہے وہ اسے پڑھتے ہیں جیسا اس کے پڑھنے کا حق ہے وہی لوگ اس پر ایمان لاتے ہیں جور اس سے انکار کرتے ہیں وہی نقصان اٹھانے والے ہیں\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@cxxix{اے بنی اسرائل میرے احسان کو یاد کرو جو میں نے تم پر کیے اور بے شک میں نے تمہیں سارے جہاں پر بزرگی دی تھی\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@cxxx{اوراس دن سے ڈرو جس دن کوئی بھی کسی کے کام نہ آئے گا اور نہ اس سے بدلہ قبول کیا جائے گا اور نہ اسے کوئی سفارش نفع دے گی اور نہ وہ مدد دیے جائیں گے\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@cxxxi{اور جب ابراھیم کو اس کے رب نے کئی باتوں میں آزمایا تو اس نےانہیں پورا کر دیا فرمایا بے شک میں تمہیں سب لوگوں کا پیشوا بنادوں گا کہا اور میری اولاد میں سے بھی فرمایا میرا عہد ظالموں کو نہیں پہنچے گا\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@cxxxii{اور جب ہم نے کعبہ لوگوں کے لیے عبادت گاہ اور امن کی جگہ بنایا (اور فرمایا) مقام ابراہیم کو نماز کی جگہ بناؤ اور ہم نے ابراھیم اور اسماعیل سے عہد لیا کہ میرے گھر کو طواف کرنے والوں اور اعتکاف کرنے والوں اور رکوع کرنے والوں اور سجدہ کرنے والوں کے لیے پاک رکھو\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@cxxxiii{اورجب ابراھیم نے کہا اے میرے رب اسے امن کا شہر بنا دے اور اس کے رہنےو الوں کو پھلوں سے رزق دے جوکوئی ان میں سے الله اور قیامت کے دن پر ایمان لائے فرمایا اور جو کافر ہوگا سو اسے بھی تھوڑاسا فائدہ پہنچاؤں گا پھر اسے دوزخ کے عذاب میں دھکیل دوں گا اوروہ برا ٹھکانہ ہے\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@cxxxiv{اور جب ابراھیم اور اسماعیل کعبہ کی بنیادیں اٹھا رہے تھے اے ہمارے رب ہم سے قبول کر بے شک تو ہی سننے والا جاننے والا ہے\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@cxxxv{اے ہمارے رب ہمیں اپنا فرمانبردار بنا دے اور ہماری اولاد میں سے بھی ایک جماعت کو اپنافرمانبردار بنا اور ہمیں ہمارے حج کے طریقے بتا دے اور ہماری توبہ قبول فرما بے شک تو بڑا توبہ قبول کرنے والا نہایت رحم والا ہے\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@cxxxvi{اے ہمارے رب اور ان میں ایک رسول انہیں میں سے بھیج جو ان پر تیری آیتیں پڑھیں اور انہیں کتاب اور دانائی سکھائے اور انہیں پاک کرے بے شک تو ہی غالب حکمت والا ہے\qt@no{(129)}}%
\qt@newcmd\qurantrans@ur@cxxxvii{اور کون ہے جو ملت ابراھیمی سے روگردانی کرے سوائے اس کے جو خود ہی احمق ہو اور ہم نے تو اسے دنیا میں بھی بزرگی دی تھی اور بے شک وہ آخرت میں بھی اچھے لوگوں میں سے ہوگا\qt@no{(130)}}%
\qt@newcmd\qurantrans@ur@cxxxviii{جب اسے اس کے رب نے کہا فرمانبردار ہو جا تو کہا میں جہانوں کا پروردگار کا فرمانبردار ہوں\qt@no{(131)}}%
\qt@newcmd\qurantrans@ur@cxxxix{اور اسی بات کی ابراھیم اور یعقوب نے بھی اپنے بیٹوں کو وصیت کی کہ اے میرے بیٹو بے شک الله نےتمہارے لیے یہ دین چن لیا سو تم ہر گز نہ مرنا مگر درآنحالیکہ تم مسلمان ہو\qt@no{(132)}}%
\qt@newcmd\qurantrans@ur@cxl{کیا تم حاضر تھے جب یعقوب کو موت آئی تب اس نے اپنے بیٹوں سے کہا تم میرے بعد کس کی عبادت کرو گے انہوں نے کہا ہم آپ کے اور آپ کے باپ دادا ابراھیم اور اسماعیل اور اسحاق کے معبود کی عبادت کریں گے جو ایک معبود ہے اور ہم اسی کے فرمانبردار ہیں\qt@no{(133)}}%
\qt@newcmd\qurantrans@ur@cxli{یہ ایک جماعت تھی جو گزرچکی ان کے لیے ان کے اعمال میں اور تمہارے لیے اور تمہارے اعمال ہیں اور تم سے نہیں پوچھا جائے گا کہ وہ کیا کرتے تھے\qt@no{(134)}}%
\qt@newcmd\qurantrans@ur@cxlii{اور کہتے ہیں کہ یہودی یا نصرانی ہو جاؤ تاکہ ہدایت پاؤ کہہ دو بلکہ ہم تو ملت ابراھیمی پر رہیں گے جو موحد تھا اور مشرکوں میں سے نہیں تھا\qt@no{(135)}}%
\qt@newcmd\qurantrans@ur@cxliii{کہہ دو ہم الله پر ایمان لائے اور اس پر جو ہم پر اتارا گیا اور جو ابراھیم اور اسماعیل اور اسحاق اور یعقوب اور اس کی اولاد پر اتارا گیا اور جو موسیٰ اور عیسیٰ کو دیا گیا اور جو دوسرے نبیوں کو ان کے رب کی طرف سے دیا گیا ہم کسی ایک میں ان میں سے فرق نہیں کرتے اور ہم اسی کے فرمانبردار ہیں\qt@no{(136)}}%
\qt@newcmd\qurantrans@ur@cxliv{پس اگر وہ بھی ایمان لے آئيں جس طرح تم ایمان لائے ہو تو وہ بھی ہدایت پا گئے اور اگر وہ نہ مانیں تو وہی ضد میں پڑے ہوئے ہیں سو تمہیں ان سے الله کافی ہے اور وہی سننے والا جاننے والا ہے\qt@no{(137)}}%
\qt@newcmd\qurantrans@ur@cxlv{الله کا رنگ اللہ کے رنگ سے اور کس کا رنگ بہتر ہے اور ہم تو اسی کی عبادت کرتے ہیں\qt@no{(138)}}%
\qt@newcmd\qurantrans@ur@cxlvi{کہہ دو کیا تم ہم سے الله کی نسبت جھگڑا کرتے ہو حالانکہ وہی ہمارا اور تمہارا رب ہے اور ہمارے لیے ہمارے عمل ہیں اور تمہاری لئے تمہارے عمل او رہم تو خا لص اسی کی عبادت کرتے ہیں\qt@no{(139)}}%
\qt@newcmd\qurantrans@ur@cxlvii{یا تم کہتے ہو کہ ابراھیم اور اسماعیل اور اسحاق اور یعقوب اور اس کی اولاد یہودی یا نصرانی تھے کہہ دو کیا تم زیادہ جانتے ہو یا الله اور اس سے بڑھ کر کون ظالم ہے جو گواہی چھپائے جو اس کے پاس الله کی طرف سے ہےاور الله بے خبر نہیں اس سے جو تم کرتے ہو\qt@no{(140)}}%
\qt@newcmd\qurantrans@ur@cxlviii{وہ ایک جماعت تھی جو گزر چکی ان کے لیے ان کے عمل ہیں اور تمہارے لیے تمہارے عمل ہیں اور تم سے ان کے اعمال کی نسبت نہیں پوچھا جائے گا\qt@no{(141)}}%
\qt@newcmd\qurantrans@ur@cxlix{بے وقوف لوگ کہیں گے کہ کس چیز نے مسلمانوں کو ان کے قبلہ سے پھیر دیا جس پر وہ تھے کہہ دو مشرق اور مغرب الله ہی کا ہے وہ جسے چاہتا ہے سیدھا راستہ دکھاتا ہے\qt@no{(142)}}%
\qt@newcmd\qurantrans@ur@cl{اور اسی طرح ہم نے تمہیں برگزیدہ امت بنایا تاکہ تم اور لوگوں پر گواہ ہو اور رسول تم پر گواہ ہو اور ہم نے وہ قبلہ نہیں بنایا تھا جس پر آپ پہلے تھے مگر اس لیے کہ ہم معلوم کریں اس کو جو رسول کی پیروی کرتا ہے اس سے جو الٹے پاؤں پھر جاتا ہےاور بے شک یہ بات بھاری ہے سوائے ان کے جنہیں الله نے ہدایت دی اور الله تمہارے ایمان کو ضائع نہیں کرے گا بے شک الله لوگوں پر بڑا مہربان نہایت رحم والا ہے\qt@no{(143)}}%
\qt@newcmd\qurantrans@ur@cli{بے شک ہم آپ کے منہ کا آسمان کی طرف پھرنا دیکھ رہے ہیں سو ہم آپ کو اس قبلہ کی طرف پھیر دیں گے جسے آپ پسند کرتے ہیں پس اب اپنا منہ مسجد حرام کی طرف پھیر لیجیئے اور جہاں کہیں تم ہوا کرو اپنے مونہوں کو اسی کی طرف پھیر لیا کرو اور بے شک وہ لوگ جنہیں کتاب دی گئی ہے یقیناً جانتے ہیں کہ وہی حق ہے ان کے رب کی طرف سے اور الله اس سے بے خبر نہیں جو وہ کر رہے ہیں\qt@no{(144)}}%
\qt@newcmd\qurantrans@ur@clii{اور اگر آپ ان کے سامنے تمام دلیلیں لے آئيں جنہیں کتاب دی گئی تو بھی وہ آپ کے قبلے کو نہیں مانیں گے اور نہ آپ ہی ان کے قبلہ کو ماننے والے ہیں اور نہ ان میں کوئی دوسرے قبلہ کو ماننے والا ہے اور اگر آپ ان کی خواہشوں کی پیروی کریں گے بعد اس کے کہ آپ کے پاس علم آ چکا تو بے شک آپ بھی تب ظالموں میں سے ہوں گے\qt@no{(145)}}%
\qt@newcmd\qurantrans@ur@cliii{وہ لوگ جنہیں ہم نے کتاب دی تھی وہ اسے پہچانتے ہیں جیسے اپنے بیٹوں کو پہچانتے ہیں اور بےشک کچھ لوگ ان میں سے حق کوچھپاتے ہیں اور وہ جانتے ہیں\qt@no{(146)}}%
\qt@newcmd\qurantrans@ur@cliv{آپ کے رب کی طرف سے حق وہی ہے پس شک کرنے والوں میں سے نہ ہو\qt@no{(147)}}%
\qt@newcmd\qurantrans@ur@clv{اور ہر ایک کے لیے ایک طرف ہے جس طرف وہ منہ کرتا ہے پس تم نیکیوں کی طرف دوڑو تم جہاں کہیں بھی ہو گے تم سب کو الله سمیٹ کر لے آئے گا بے شک الله ہر چیز پر قادر ہے\qt@no{(148)}}%
\qt@newcmd\qurantrans@ur@clvi{اور جہاں سے آپ نکلیں تو اپنا منہ مسجد حرام کی طرف کیا کریں اور آپ کے رب کی طرف سےیہی حق بھی ہے اور الله تمہارے کام سے غافل نہیں\qt@no{(149)}}%
\qt@newcmd\qurantrans@ur@clvii{اور آپ جہاں کہیں سے نکلیں تو اپنا منہ مسجد حرام کی طرف کیا کریں اور تم بھی جہاں کہیں ہو تو اپنا منہ ا س کی طرف کیاکر و تاکہ لوگوں کو تم پر کوئی الزام نہ رہے مگر ان میں سے جو ہٹ دھرم ہیں تم بھی ان سے نہ ڈرو اور ہم سے ڈرتے رہا کرو اور تاکہ میں اپنی نعمت تم پر پوری کروں اورتاکہ تم راہ پاؤ\qt@no{(150)}}%
\qt@newcmd\qurantrans@ur@clviii{جیسا کہ ہم نے تم میں ایک رسول تم ہی میں سے بھیجا جو تم پر ہماری آیتیں پڑھتا ہے اور تمہیں پاک کرتا ہے اور تمہیں کتاب اور دانائی سکھاتا ہے اور تمہیں سکھاتا ہے جو تم نہیں جانتے تھے\qt@no{(151)}}%
\qt@newcmd\qurantrans@ur@clix{پس مجھے یاد کرو میں تمہیں یاد کروں گا اور میرا شکر کرو اور ناشکری نہ کرو\qt@no{(152)}}%
\qt@newcmd\qurantrans@ur@clx{اے ایمان والو صبر اور نماز سے مدد لیا کرو بے شک اللہ صبر کرنے والوں کے ساتھ ہے\qt@no{(153)}}%
\qt@newcmd\qurantrans@ur@clxi{اور جو الله کی راہ میں مارے جائیں انہیں مرا ہوا نہ کہا کرو بلکہ وہ تو زندہ ہیں لیکن تم نہیں سمجھتے\qt@no{(154)}}%
\qt@newcmd\qurantrans@ur@clxii{اور ہم تمہیں کچھ خوف اور بھوک اور مالوں اور جانوں اور پھلوں کے نقصان سے ضرور آز مائيں گے اور صبر کرنے والوں کو خوشخبری دے دو\qt@no{(155)}}%
\qt@newcmd\qurantrans@ur@clxiii{وہ لوگ کہ جب انہیں کوئی مصیبت پہنچتی ہے تو کہتے ہیں ہم تو الله کے ہیں اور ہم اسی کی طرف لوٹ کر جانے والے ہیں\qt@no{(156)}}%
\qt@newcmd\qurantrans@ur@clxiv{یہ لوگ ہیں جن پر ان کے رب کی طرف سے مہربانیاں ہیں اور رحمت اور یہی ہدایت پانے والے ہیں\qt@no{(157)}}%
\qt@newcmd\qurantrans@ur@clxv{بے شک صفا اور مروہ الله کی نشانیوں میں سے ہیں پس جو کعبہ کا حج یا عمرہ کرے تو اس پر کوئی گناہ نہیں کہ ان کے درمیان طواف کرے اورجو کوئی اپنی خوشی سے نیکی کرے تو بے شک الله قدردان جاننے والا ہے\qt@no{(158)}}%
\qt@newcmd\qurantrans@ur@clxvi{بے شک جو لوگ ان کھلی کھلی باتوں اور ہدایت کو جسے ہم نے نازل کر دیا ہے اس کے بعد بھی چھپاتے ہیں کہ ہم نے ان کو لوگوں کے لیے کتاب میں بیان کر دیا یہی لوگ ہیں کہ ان پر الله لعنت کرتا ہے اور لعنت کرنے والے لعنت کرتے ہیں\qt@no{(159)}}%
\qt@newcmd\qurantrans@ur@clxvii{مگر وہ لوگ جنہوں نے توبہ کی اور اصلاح کر لی اور ظاہر کر دیا پس یہی لوگ ہیں کہ میں ان کی توبہ قبول کرتا ہوں اور میں بڑاتوبہ قبول کرنے والا نہایت رحم والا ہوں\qt@no{(160)}}%
\qt@newcmd\qurantrans@ur@clxviii{بے شک جنہوں نے انکار کیا اور انکار ہی کی حالت میں مر بھی گئے تو ان پر الله کی لعنت ہے اور فرشتوں اور سب لوگوں کی بھی\qt@no{(161)}}%
\qt@newcmd\qurantrans@ur@clxix{وہ ہمیشہ اسی میں رہیں گے ان سے عذاب ہلکا نہ کیا جائے گا اور نہ وہ مہلت دیئے جائیں گے\qt@no{(162)}}%
\qt@newcmd\qurantrans@ur@clxx{اور تمہارا معبود ایک ہی معبود ہے جس کے سوا کوئی معبود نہیں بڑا مہربان نہایت رحم والا ہے\qt@no{(163)}}%
\qt@newcmd\qurantrans@ur@clxxi{بے شک آسمانوں اور زمین کے پیدا کرنے میں اور رات اور دن کے بدلنے میں اور جہازوں میں جو دریا میں لوگوں کی نفع دینے والی چیزیں لے کر چلتے ہیں اور اس پانی میں جسسے الله نے آسمان سے نازل کیا ہے پھر اس سے مردہ زمین کو زندہ کرتا ہے اور اس میں ہر قسم کے چلنے والے جانور پھیلاتا ہے اور ہواؤں کے بدلنے میں اور بادل میں جو آسمان اور زمین کے درمیان حکم کا تابع ہے البتہ عقلمندوں کے لیے نشانیاں ہیں\qt@no{(164)}}%
\qt@newcmd\qurantrans@ur@clxxii{اورایسے لوگ بھی ہیں جنہوں نے الله کے سوا اور شریک بنا رکھے ہیں جن سے ایسی محبت رکھتے ہیں جیسی کہ الله سے رکھنی چاہیئے اور ایمان والوں کو تو الله ہی سے زیادہ محبت ہوتی ہے اور کاش دیکھتے وہ لوگ جو ظالم ہیں جب عذاب دیکھیں گے کہ سب قوت الله ہی کے لیے ہے اور الله سخت عذاب دینے والا ہے\qt@no{(165)}}%
\qt@newcmd\qurantrans@ur@clxxiii{جب وہ لوگ بیزار ہو جائیں گے جن کی پیروی کی گئی تھی ان لوگوں سے جنہوں نے پیروی کی تھی اور وہ عذاب دیکھ لیں گے اور ان کے تعلقات ٹوٹ جائیں گے\qt@no{(166)}}%
\qt@newcmd\qurantrans@ur@clxxiv{اور کہیں گے وہ لوگ جنہوں نے پیروی کی تھی کاش ہمیں دوبارہ جانا ہوتا تو ہم بھی ان سے بیزار ہوجاتے جیسے یہ ہم سے بیزار ہو جاتے جیسے یہ ہم سے بیزار ہوئے ہیں اسی طرح الله انہیں ان کے اعمال حسرت دلانے کے لیے دکھائے گا اور وہ دوزخ سے نکلنے والے نہیں\qt@no{(167)}}%
\qt@newcmd\qurantrans@ur@clxxv{اے لوگو ان چیزوں میں سے کھاؤ جو زمین میں حلال پاکیزہ ہیں اور شیطان کے قدموں کی پیروی نہ کرو بے شک وہ تمہارا صریح دشمن ہے\qt@no{(168)}}%
\qt@newcmd\qurantrans@ur@clxxvi{وہ تو تمہیں برائی اور بے حیائی ہی کا حکم دے گا اور یہ کہ الله کے ذمے تم وہ باتیں لگاؤ جنہیں تم نہیں جانتے\qt@no{(169)}}%
\qt@newcmd\qurantrans@ur@clxxvii{اور جب انہیں کہا جاتا ہے کہ اس کی پیروی کرو جو الله نے نازل کیا ہے تو کہتے ہیں بلکہ ہم تو اس کی پیروی کریں گے جس پر ہم نے اپنے باپ دادا کو پایا کیا اگرچہ ان کے باپ دادا کچھ بھی نہ سمجھتے ہوں اور نہ سیدھی راہ پائی ہو\qt@no{(170)}}%
\qt@newcmd\qurantrans@ur@clxxviii{اوران کی مثال جو کافر ہیں اس شخص کی سی ہے جو اس چیز کو پکارتا ہے جو سوائے پکار اور آواز کے نہیں سنتی وہ بہرے ہیں گونگے ہیں اندھے ہیں پس وہ نہیں سمجھتے\qt@no{(171)}}%
\qt@newcmd\qurantrans@ur@clxxix{اے ایمان والو پاکیزہ چیزوں میں سے کھاؤ جو ہم نے تمہیں عطا کی اور الله کا شکر کرو اگر تم اس کی عبادت کرتے ہو\qt@no{(172)}}%
\qt@newcmd\qurantrans@ur@clxxx{سوائے اس کے نہیں کہ تم پر مردار اور خون اورسؤر کا گوشت اور اور اس چیز کو کہ الله کے سوا اور کے نام سے پکاری گئی ہو حرام کیا ہے پس جو لاچار ہو جائے نہ سرکشی کرنے والا ہو اور نے حد سے بڑھنے والا تو اس پر کوئی گناہ نہیں بے شک الله بخشنے والا نہایت رحم والا ہے\qt@no{(173)}}%
\qt@newcmd\qurantrans@ur@clxxxi{بے شک جو لوگ الله کی نازل کی ہوئی کتاب کو چھپاتے اور اس کے بدلے میں تھوڑا سا مول لیتے ہیں یہ لوگ اپنے پیٹوں میں نہیں کھاتے مگر آگ اور الله ان سے قیامت کے دن کلام نہیں کرے گا اور نہ انہیں پاک کرے گا اور ان کے لیے دردناک عذاب ہے\qt@no{(174)}}%
\qt@newcmd\qurantrans@ur@clxxxii{یہی وہ لوگ ہیں جنہوں نے گمراہی کو بدلے ہدایت کے خریدا اور عذاب کو بدلے بخشش کے پس دوزخ کی آگ پر ان کا کتنا بڑا صبر ہے\qt@no{(175)}}%
\qt@newcmd\qurantrans@ur@clxxxiii{یہ اس لیے کہ الله نے کتاب سچائی کے ساتھ اتاری اور بے شک جنہوں نے کتاب میں اختلاف کیا البتہ ضد میں بہت دور جا پڑے\qt@no{(176)}}%
\qt@newcmd\qurantrans@ur@clxxxiv{یہی نیکی نہیں کہ تم اپنے منہ مشرق اور مغرب کی طرف پھیرو بلکہ نیکی تو یہ ہے جو الله اور قیامت کے دن پر ایمان لائے اورفرشتوں اور کتابوں او رنبیوں پر اور ا سکی محبت میں رشتہ دارو ں اور یتیموں اور مسکینوں اور مسافروں اور سوال کرنے والوں کو اور گردنوں کے چھڑانے میں مال دے اور نماز پڑھے اور زکوةٰ دے اور جو اپنے عہدوں کو پورا کرنے والے ہیں جب وہ عہد کر لیں اورتنگدستی میں اور بیماری میں اور لڑائی کےوقت صبر کرنے والے ہیں یہی سچے لوگ ہیں اوریہی پرہیزگار ہیں\qt@no{(177)}}%
\qt@newcmd\qurantrans@ur@clxxxv{اے ایمان والو مقتولوں میں برابری کرنا تم پر فرض کیا گیا ہے آزاد بدلے آزاد کے اور غلام بدلے غلام کے اور عورت بدلے عورت کے پس جسے اس کے بھائی کی طرف سے کچھ بھی معاف کیا جائے تو دستور کے موافق مطالبہ کرنا چاہیئے اور اسے نیکی کے ساتھ ادا کرنا چاہیئے یہ تمہارے رب کی طرف سے آسانی اور مہربانی ہے پس جو اس کے بعد زیادتی کرے تو اس کے لیے دردناک عذاب ہے\qt@no{(178)}}%
\qt@newcmd\qurantrans@ur@clxxxvi{اور اے عقلمندو تمہارے لیے قصاص میں زندگی ہے تاکہ تم (خونریزی سے) بچو\qt@no{(179)}}%
\qt@newcmd\qurantrans@ur@clxxxvii{تم پر فرض کیا گیا ہے کہ جب تم میں سے کسی کو موت آ پہنچے اگر وہ مال چھوڑے تو ماں باپ اور رشتہ داروں کے لیے مناسب طور پر وصیت کرے یہ پرہیزگاروں پرحق ہے\qt@no{(180)}}%
\qt@newcmd\qurantrans@ur@clxxxviii{پس جواسے اس کے سننے کےبعد بدل دے اس کا گناہ ان ہی پر ہے جو اسے بدلتے ہیں بے شک اللہ سننے والا جاننے والا ہے\qt@no{(181)}}%
\qt@newcmd\qurantrans@ur@clxxxix{پس جو وصیت کرنے والے سے طرف داری یا گناہ کا خوف کرے پھر ان کے درمیان اصلاح کر دے تو اس پر کوئی گناہ نہیں بے شک الله بڑا بخشنے والا نہایت رحم والا ہے\qt@no{(182)}}%
\qt@newcmd\qurantrans@ur@cxc{اے ایمان والو تم پر روزے فرض کیے گئے ہیں جو تم سے پہلے تھے تاکہ تم پرہیز گار ہو جاؤ\qt@no{(183)}}%
\qt@newcmd\qurantrans@ur@cxci{گنتی کے چند روز پھر جو کوئی تم میں سے بیمار یا سفر پر ہو تو دوسرے دنو ں سے گنتی پوری کر لےاور ان پر جو اس کی طاقت رکھتے ہیں فدیہ ہے ایک مسکین کا کھانا پھر جو کوئی خوشی سے نیکی کرے تو وہ اس کے لیےبہتر ہے اورروزہ رکھنا تمہارے لیے بہتر ہے اگرتم جانتے ہو\qt@no{(184)}}%
\qt@newcmd\qurantrans@ur@cxcii{رمضان کا وہ مہینہ ہے جس میں قرآن اتارا گیا جو لوگوں کے واسطے ہدایت ہے اور ہدایت کی روشن دلیلیں اور حق و باطل میں فرق کرنے والا ہے سو جو کوئی تم میں سے اس مہینے کو پالے تو اس کے روزے رکھے اور جو کوئی بیمار یا سفر پر ہو تو دوسرے دنو ں سے گنتی پوری کر ے اللہ تم پر آسانی چاہتا ہے اور تم پر تنگی نہیں چاہتا اور تاکہ تم گنتی پوری کر لو اور تاکہ تم الله کی بڑائی بیان کرو اس پر کہ اس نے تمہیں ہدایت دی اور تاکہ تم شکر کرو\qt@no{(185)}}%
\qt@newcmd\qurantrans@ur@cxciii{اور جب آپ سےمیرے بندے میرے متعلق سوال کریں تو میں نزدیک ہوں دعاا کرنے والے کی دعا قبول کرتا ہوں جب وہ مجھے پکارتا ہے پھر چاہیئے کہ میرا حکم مانیں اور مجھ پر ایمان لائیں تاکہ وہ ہدایت پائیں\qt@no{(186)}}%
\qt@newcmd\qurantrans@ur@cxciv{تمہارے لیے روزوں کی راتو ں میں اپنی عورتوں سے مباثرت کرنا حلال کیا گیا ہے وہ تمہارے لیے پردہ ہیں اورتم ان کے لیے پردہ ہو الله کو معلوم ہے تم اپنے نفسوں سے خیانت کرتے تھے پس تمہاری توبہ قبول کر لی اور تمہیں معاف کر دیا سو اب ان سے مباثرت کرو اور طلب کرو وہ چیز جو الله نے تمہارے لیے لکھدی ہے اور کھاؤ اور پیو جب تک کہ تمہارے لیے سفید دھاری سیادہ دھاری سے فجر کے وقت صاف ظاہر ہو جاوے پھر روزوں کو رات پورا کرو اور ان سے مباثرت نہ کرو جب کہ تم مسجدوں میں معتکف ہو یہ الله کی حدیں ہیں سو ان کے قریب نہ جاؤ اسی طرح الله اپنی آیتیں لوگوں کے لیے بیان کرتا ہے تاکہ وہ پرہیز گار ہو جائیں\qt@no{(187)}}%
\qt@newcmd\qurantrans@ur@cxcv{اور ایک دوسرے کے مال آپس میں ناجائز طور پر نہ کھاؤ اور انہیں حاکموں تک نہ پہنچاؤ تاکہ لوگوں کے مال کا کچھ حصہ گناہ سے کھا جاؤ حالانکہ تم جانتے ہو\qt@no{(188)}}%
\qt@newcmd\qurantrans@ur@cxcvi{آپ سے چاندوں کے متعلق پوچھتے ہیں کہہ دو یہ لوگوں کے لیے اور حج کے لیے وقت کے اندازے ہیں اور نیکی یہ نہیں ہے کہ تم گھروں میں ان کی پشت کی طرف سے آؤ اور لیکن نیکی یہ ہے کہ جو کوئی الله سے ڈرے اور تم گھروں میں ان کے دروازوں سے آؤ اور الله سے ڈرتے رہو تاکہ تم کامیاب ہو جاؤ\qt@no{(189)}}%
\qt@newcmd\qurantrans@ur@cxcvii{اور الله کی راہ میں ان سے لڑو جوتم سے لڑیں اور زیادتی نہ کرو بے شک الله زیادتی کرنے والوں کو پسند نہیں کرتا\qt@no{(190)}}%
\qt@newcmd\qurantrans@ur@cxcviii{اور انہیں قتل کرو جہاں پاؤ اور انہیں نکال دو جہاں سے انہوں نےتمہیں نکالا ہے اور غلبہ شرک قتل سے زیادہ سخت ہے اور مسجد حرام کے پاس ان سے نہ لڑو جب تک کہ وہ تم سے یہاں نہ لڑیں پھراگروہ تم سےلڑیں تم بھی انہیں قتل کرو کافروں کی یہی سزا ہے\qt@no{(191)}}%
\qt@newcmd\qurantrans@ur@cxcix{پھر اگر وہ باز آجائیں تو الله بڑا بخشنے والا نہایت رحم والا ہے\qt@no{(192)}}%
\qt@newcmd\qurantrans@ur@cc{اور ان سے لڑو یہاں تک کہ فساد باقی نہ رہے اور الله کا دین قائم ہو جائے پھر اگر وہ باز آجائیں تو سوائے ظالموں کے کسی پر سختی جائز نہیں\qt@no{(193)}}%
\qt@newcmd\qurantrans@ur@cci{حرمت واے مہینے کا بدلہ حرمت والا مہینہ ہے اور سب قابلِ تعظیم باتوں کا بدلہ ہے پھر جو تم پر زیادتی کرےتم بھی اس پر زیادتی کرو جیسی کہ اس نے تم پر زیادتی کی اور الله سے ڈرو اور جان لو کہ الله پرہیزگاروں کے ساتھ ہے\qt@no{(194)}}%
\qt@newcmd\qurantrans@ur@ccii{اورالله کی راہ میں خرچ کرو اور اپنے آپ کوپنے ہاتھوں ہلاکت میں نہ ڈالو او رنیکی کرو بے شک الله نیکی کرنے والوں کو دوست رکھتا ہے\qt@no{(195)}}%
\qt@newcmd\qurantrans@ur@cciii{اور الله کے لیے حج اور عمرہ پورا کرو پس اگر روکے جاؤ تو جو قربانی سے میسر ہو اور اپنے سر نہ منڈواؤ جب تک کہ قربانی اپنی جگہ پر نہ پہنچ جائے پھر جو کوئی تم میں سے بیمار ہو یا اسے سر میں تکلیف ہو تو روزوں سے یا صدقہ سے یا قربانی سے فدیہ دے پھر جب تم امن میں ہو تو عمرہ سے حج تک فائدہ اٹھائے تو قربانی سے جو میسر ہو (دے) پھر جو نہ پائے تو تین روزے حج کے دنوں میں رکھےاور سات جب تم لوٹو یہ دس پورے ہو گئے یہ ا س کے لیے ہے جس کا گھر بار مکہ میں نہ ہو اور الله سے ڈرتے رہو اور جان لو کہ الله سخت عذاب دینے والا ہے\qt@no{(196)}}%
\qt@newcmd\qurantrans@ur@cciv{حج کے چند مہینے معلوم ہیں سو جو کوئي ان میں حج کا قصد کرے تو مباثرت جائز نہیں اور نہ گناہ کرنا اور نہ حج میں لڑائي جھگڑا کرنا اور تم جو نیکی کرتے ہو الله اس کو جانتا ہے اور زادِ راہ لے لیا کرو اور بہترین زادِ راہ پرہیزگاری ہے اور اے عقلمندوں مجھ سے ڈرو\qt@no{(197)}}%
\qt@newcmd\qurantrans@ur@ccv{تم پر کوئی گناہ نہیں ہے کہ اپنے رب کا فضل تلاش کرو پھر جب تم عرفات سے پھرو تو مشعر الحرام کے پاس الله کو یاد کرو اور اس کی یاد اس طرح کرو کہ جس طرح اس نے تمیں بتائی ہے اور اس سے پہلے تو تم گمراہوں میں سے تھے\qt@no{(198)}}%
\qt@newcmd\qurantrans@ur@ccvi{پھر تم لوٹ کر آؤ جہاں سے لوٹ کر آتے ہیں اور الله سے بخشش مانگو بے شک الله بڑا بخشنے والا نہایت رحم والا ہے\qt@no{(199)}}%
\qt@newcmd\qurantrans@ur@ccvii{پھر جب حج کے ارکان ادا کر چکو تو الله کو یاد کرو جیسے تم اپنے باپ دادا کو یاد کیا کرتے تھے یا اس سے بھی بڑھ کر یاد کرنا پھر بعض تو یہ کہتے ہیں اےہمارے رب ہمیں دنیا میں دے اور اس کے لیے آخرت میں کوئی حصہ نہیں ہے\qt@no{(200)}}%
\qt@newcmd\qurantrans@ur@ccviii{اوربعض یہ کہتے ہیں کہ اے ہمارے رب ہمیں دنیا میں نیکی اور آخرت میں بھی نیکی دے اور ہمیں دوزخ کے عذاب سے بچا\qt@no{(201)}}%
\qt@newcmd\qurantrans@ur@ccix{یہی وہ لوگ ہیں جنہیں ان کی کمائی کا حصہ ملتا ہے اور الله جلد حساب لینے والا ہے\qt@no{(202)}}%
\qt@newcmd\qurantrans@ur@ccx{اور الله کو چند گنتی کے دنوں میں یاد کرو پھر جس نے دو دن کے اندر کوچ کرنے میں جلدی کی تو اس پر کوئی گناہ نہیں اور جو تاخیر کرے تو اس پر بھی کوئی گناہ نہیں جو (الله سے) ڈرتا ہے اور الله سے ڈرو اور جان لو کہ تم اسی کی طرف جمع کیے جاؤ گے\qt@no{(203)}}%
\qt@newcmd\qurantrans@ur@ccxi{اور بعض ایسے بھی ہیں جن کی بات دنیا کی زندگی میں آپ کو بھلی معلوم ہوتی ہے اور وہ اپنی دل کی باتوں پر الله کو گواہ کرتا ہے حالانکہ وہ سخت جھگڑالو ہے\qt@no{(204)}}%
\qt@newcmd\qurantrans@ur@ccxii{اور جب پیٹھ پھیر کر جاتا ہے تو ملک میں فساد ڈالتا اور کھیتی اور مویشی کو برباد کرنے کی کوشش کرتا ہے اور الله فساد کو پسندنہیں کرتا\qt@no{(205)}}%
\qt@newcmd\qurantrans@ur@ccxiii{اور جب اسسے کہا جاتا ہے کہ الله سے ڈر تو شیخی میں آ کر اور بھی گناہ کرتا ہے سو اس کے لیے دوزخ کافی ہے اور البتہ وہ برا ٹھکانہ ہے\qt@no{(206)}}%
\qt@newcmd\qurantrans@ur@ccxiv{اوربعض ایسے بھی ہیں جو الله کی رضا جوئی کے لیے اپنی جان بھی بیچ دیتے ہیں اور الله کے بندوں پر بڑا مہربان ہے\qt@no{(207)}}%
\qt@newcmd\qurantrans@ur@ccxv{اے ایمان والو اسلام میں سارے کے سارے داخل ہو جاؤ اور شیطان کے قدموں کی پیروی نہ کرو کیوں کہ وہ تمہارا صریح دشمن ہے\qt@no{(208)}}%
\qt@newcmd\qurantrans@ur@ccxvi{پھر اگر تم کھلی کھلی نشانیاں آجانے کے بعد بھی پھسل گئے تو جان لو کہ الله غالب حکمت والا ہے\qt@no{(209)}}%
\qt@newcmd\qurantrans@ur@ccxvii{کیا وہ انتظار کرتے ہیں کہ الله ان کے سامنے بادلوں کے سایہ میں آ موجود ہو اور فرشتے بھی آجائیں اور کام پورا ہو جائے اور سب باتیں الله ہی کے اختیار میں ہیں\qt@no{(210)}}%
\qt@newcmd\qurantrans@ur@ccxviii{بنی اسرائیل سے پوچھیئے کہ ہم نے انہیں کتنی روشن دلیلیں دیں اور جو الله کی نعمت کو بدل دیتا ہے بعد اس کے کہ وہ اس کے پاس آ چکی ہو تو بے شک الله سخت عذاب دینے والا ہے\qt@no{(211)}}%
\qt@newcmd\qurantrans@ur@ccxix{کافروں کو دنیا کی زندگی بھلی لگتی ہے اور وہ ان لوگوں کا مذاق اڑاتے ہیں جو ایمان لائے حالانکہ جولوگ پرہیزگار ہیں وہ قیامت کے دن ان سے بالاتر ہوں گے اور الله جسے چاہے بے حساب رزق دیتا ہے\qt@no{(212)}}%
\qt@newcmd\qurantrans@ur@ccxx{سب لوگ ایک دین پر تھے پھر الله نے انبیاء خوشخبری دینے والے اور ڈرانے والے بھیجے اور ان کے ساتھ سچی کتابیں نازل کیں تاکہ لوگوں میں اس بات میں فیصلہ کرے جس میں اختلاف کرتے تھےاور اس میں اختلاف نہیں کیا مگر انہیں لوگوں نے جنھیں وہ (کتاب) دی گئی تھی اس کے بعد کہ ا ن کے پاس روشن دلیلیں آ چکی تھیں آپس کی ضد کی وجہ سے پھر الله نے اپنے حکم سے ہدایت کی ان کو جو ایمان والے ہیں اس حق بات کی جس میں وہ اختلاف کر رہے تھے اور الله جسے چاہے سیدھے راستے کی ہدایت کرتا ہے\qt@no{(213)}}%
\qt@newcmd\qurantrans@ur@ccxxi{کیا تم خیال کرتے ہو کہ جنت میں داخل ہو جاؤ گے حالانکہ تمہیں وہ (حالات) پیش نہیں آئے جو ان لوگو ں کو پیش آئے جو تم سے پہلے ہو گزرے ہیں انہیں سختی اور تکلیف پہنچی اور ہلا دیئے گئے یہاں تک کہ رسول اور جو اس کے ساتھ ایمان لائے تھے بول اٹھے کہ الله کی مدد کب ہوگی سنو بے شک الله کی مدد قریب ہے\qt@no{(214)}}%
\qt@newcmd\qurantrans@ur@ccxxii{آپ سے پوچھتے ہیں کیا خرچ کریں کہہ دو جو مال بھی تم خرچ کرو وہ ماں باپ اور رشتہ داروں اور یتیموں اور محتاجوں اور مسافروں کا حق ہے اور جو نیکی تم کرتے ہو سو بے شک الله خوب جانتا ہے\qt@no{(215)}}%
\qt@newcmd\qurantrans@ur@ccxxiii{تم پر جہاد فرض کیا گیا ہے اور وہ تمہیں ناگوار ہے اور ممکن ہے تم کسی چیز کو ناگوار سمجھو اور وہ تمہارے لیے بہتر ہو اور ممکن ہے کہ تم کسی چیز کو پسند کرو اور وہ تمہارے لیے مضر ہو اور الله ہی جانتا ہے اور تم نہیں جانتے\qt@no{(216)}}%
\qt@newcmd\qurantrans@ur@ccxxiv{آپ سے حرمت والے مہینے میں لڑائی کے متعلق پوچھتے ہیں کہہ دو اس میں لڑنا بڑا (گناہ) ہے اور الله کے راستہ سے روکنا اور اس کا انکار کرنا اور مسجد حرام سے روکنا اور اس کے رہنے والوں کو اس میں سے نکالنا الله کے نزدیک اس سے بڑا گناہ ہے اور فتنہ انگیزی تو قتل سے بھی بڑا جرم ہے اور وہ تم سے ہمیشہ لڑتے رہیں گے یہاں تک کہ تمہیں تمہارے دین سے پھیر دیں اگر ان کا بس چلےاور جو تم میں سے اپنے دین سے پھر جائے پھر کافر ہی مرجائے پس یہی وہ لوگ ہیں کہ ان کے عمل دنیا اور آخرت میں ضائع ہو گئے اور وہی دوزخی ہیں جو اسی میں ہمیشہ رہیں گے\qt@no{(217)}}%
\qt@newcmd\qurantrans@ur@ccxxv{بے شک جو لوگ ایمان لائے اور جنہوں نے ہجرت کی اور الله کی راہ میں جہاد کیا وہی الله کی رحمت کے امیدوار ہیں اور الله بڑا بخشنے والا نہایت رحم والا ہے\qt@no{(218)}}%
\qt@newcmd\qurantrans@ur@ccxxvi{آپ سے شراب اور جوئے کے متعلق پوچھتے ہیں کہہ دو ان میں بڑا گنا ہے اور لوگوں کے لیے کچھ فائدے بھی ہیں اور ان کا گناہ ان کے نفع سے بہت بڑا ہے اور آپ سے پوچھتے ہیں کہ کیا خرچ کریں کہہ دو جو زاید ہو ایسے ہی الله تمہارے لیے آیتیں کھول کر بیان کرتا ہے تاکہ تم غور کرو\qt@no{(219)}}%
\qt@newcmd\qurantrans@ur@ccxxvii{دنیا اور آخرت کے بارے میں اور یتیموں کے متعلق آپ سے پوچھتے ہیں کہہ دو ان کی اصلاح کرنا بہتر ہے اور اگر تم انہیں ملا لو تو وہ تمہارے بھائی ہیں اور الله بگاڑنے والے کو اصلاح کرنےوالے سے جانتا ہے اور اگر الله چاہتا تو تمہیں تکلیف میں ڈالتا بے شک الله غالب حکمت والا ہے\qt@no{(220)}}%
\qt@newcmd\qurantrans@ur@ccxxviii{اور مشرک عورتیں جب تک ایمان نہ لائیں ان سے نکاح نہ کرو اورمشرک عورتوں سے ایمان دار لونڈی بہتر ہے گو وہ تمہیں بھلی معلوم ہو اور مشرک مردوں سے نکاح نہ کرو یہاں تک کہ وہ ایمان لائیں اور البتہ مومن غلام مشرک سے بہتر ہے اگرچہ وہ تمہیں اچھا ہی لگے یہ لوگ دوزخ کی طرف بلاتے ہیں اور الله جنت اور بخشش کی طرف اپنے حکم سے بلاتا ہے اور لوگوں کے لیے اپنی آیتیں کھول کر بیان کرتا ہے تاکہ وہ نصیحت حاصل کریں\qt@no{(221)}}%
\qt@newcmd\qurantrans@ur@ccxxix{اور آپ سے حیض کے بارے میں پوچھتے ہیں کہہ دو وہ نجاست ہے پس حیض میں عورتوں سے علیحدٰہ رہو اور ان کے پاس نہ جاؤ یہاں تک کہ وہ پاک ہو لیں پھر جب وہ پاک ہو جائیں تو ان کے پاس جاؤ جہاں سے اللہ نےتمہیں حکم دیا ہے بے شک الله توبہ کرنے والوں کو دوست رکھتا ہے اوربہت پاک رہنے والوں کو دوست رکھتا ہے\qt@no{(222)}}%
\qt@newcmd\qurantrans@ur@ccxxx{تمہاری بیویاں تمہاری کھیتیاں ہیں پس تم اپنی کھیتیوں میں جیسے چاہو آؤ اور اپنے لیے آئندہ کی بھی تیاری کرو اور الله سے ڈرتے رہو اور جان لو کہ تم ضرور اسے ملو گے اور ایمان والوں کو خوشخبری سنا دو\qt@no{(223)}}%
\qt@newcmd\qurantrans@ur@ccxxxi{اور الله کو اپنی قسموں کا نشانہ نہ بناؤ نیکی اور پرہیز گاری اور لوگو ں کے درمیان اصلاح کرنے سے اور الله سننے والا جاننے والا ہے\qt@no{(224)}}%
\qt@newcmd\qurantrans@ur@ccxxxii{الله تمہیں تمہاری قسموں میں بے ہودہ گوئی پر نہیں پکڑتا لیکن تم سے ان قسموں پر مواخذہ کرتا ہے جن کا تمہارے دلوں نے ارادہ کیا ہو اور الله بڑا بحشنے والا بردبار ہے\qt@no{(225)}}%
\qt@newcmd\qurantrans@ur@ccxxxiii{جو لوگ اپنی بیویوں کے پاس جانے سے قسم کھا لیتے ہیں ان کے لیے چار مہینے کی مہلت ہے پھر اگر وہ رجوع کر لیں تو الله بڑا بخشنے والا نہایت رحم والا ہے\qt@no{(226)}}%
\qt@newcmd\qurantrans@ur@ccxxxiv{اور اگر انہوں نے طلاق کا پختہ ارداہ کر لیا تو بے شک الله سننے والا جاننے والا ہے\qt@no{(227)}}%
\qt@newcmd\qurantrans@ur@ccxxxv{اور طلاق دی ہوئی عورتیں تین حیض تک اپنے آپ کو روکے رکھیں اور ان کے لیے جائز نہیں کہ چھپائیں جو الله نے ان کے پیٹوں میں پیدا کیاہے اگر وہ الله اور قیامت کے دن پر ایمان رکھتی ہیں اوران کے خاوند اس مدت میں ان کو لوٹالینے کے زیادہ حق دار ہیں اگر وہ اصلاح کا اردہ رکھتے ہیں اور دستور کے مطابق ان کا ویسا ہی حق ہےجیسا ان پر ہے اور مردوں کو ان پر فضیلت دی ہے اور الله غالب حکمت والا ہے\qt@no{(228)}}%
\qt@newcmd\qurantrans@ur@ccxxxvi{طلاق دو مرتبہ ہے پھر بھلائی کے ساتھ روک لینا ہے یا نیکی کے ساتھ چھوڑ دنیا ہے اور تمہارے یے اس میں سے کچھ بھی لینا جائز نہیں جو تم نے انہیں دیا ہے مگر یہ کہ دونوں ڈریں کہ الله کی حدیں قائم نہیں رکھ سکیں گے پھر اگرتمہیں خوف ہو کہ دونوں الله کی حدیں قائم نہیں رکھ سکیں گے تو ان دونوں پر اس میں کوئی گناہ نہیں کہ عورت معاوضہ دے کر پیچھا چھڑالے یہ الله کی حدیں ہیں سو ان سے تجاوز نہ کرو اورجو الله کی حدوں سے تجاوز کرے گا سو وہی ظالم ہیں\qt@no{(229)}}%
\qt@newcmd\qurantrans@ur@ccxxxvii{پھر اگر اسے طلاق دے دی تو اس کے بعد اس کے لیے وہ حلال نہ ہوگی یہاں تک کہ وہ کسی اور خاوند سے نکاح کرے پھر اگر وہ اسے طلاق دے دے تو ان دونوں پر کوئی گناہ نہیں کہ آپس میں رجوع کر لیں اگر ان کا گمان غالب ہو کہ وہ الله کی حدیں قائم سکیں گے اور یہ الله کی حدیں ہیں وہ انہیں کھول کر بیان کرتا ہے ان لوگوں کے لیے جو علم رکھتے ہیں\qt@no{(230)}}%
\qt@newcmd\qurantrans@ur@ccxxxviii{اور جب عورتوں کو طلاق دے دوپھر وہ اپنی عدت کو پہنچ جائیں تو انہیں حسن سلوک سے روک لو یا انہیں دستور کے مطابق چھوڑ دو اور انہیں تکلیف دینے کے یے نہ روکو تاکہ تم سختی کرو اور جو ایسا کرے گا تو وہ اپنے اوپر ظلم کرے گا اور الله کی آیتوں کا تمسخر نہ اڑاؤ اورالله کے احسان کو یاد کرو جو اس نے تم پر کیا ہے اور جو اس نے تم پر کتاب اور حکمت اتاری ہے کہ تمہیں اس سے نصیحت کرے اور الله سے ڈرو اور جان لو کہ الله ہر چیز کو خوب جاننے والا ہے\qt@no{(231)}}%
\qt@newcmd\qurantrans@ur@ccxxxix{اورجب تم عورتوں کو طلاق دے دو پس وہ اپنی عدت تمام کر چکیں تو اب انہیں اپنے خاوندوں سے نکاح کرنے سے نہ روکو جب کہ وہ آپس میں دستور کے مطابق راضی ہو جائیں تم میں سے یہ نصیحت اسے کی جاتی ہے جو الله اور قیامت کے دن پر ایمان رکھتا ہے یہ تمہارے لیے بڑی پاکیزی اوربڑی صفائی کی بات ہے اور الله ہی جانتا ہے اور تم نہیں جانتے\qt@no{(232)}}%
\qt@newcmd\qurantrans@ur@ccxl{اور مائیں اپنے بچوں کو پورے دو برس دودھ پلائیں یہ اس کے لیے ہے جو دودھ کی مدت کو پورا کرنا چاہے اور باپ پر دودھ پلانے والیوں کا کھانا اور کپڑا دستور کے مطابق ہے کسی کو تکلیف نے دی جائے مگر اسی قدر کہ اس کی طاقت ہو نہ ماں کو اس کے بچہ کی وجہ سے تکلیف دی جائے اور نہ باپ ہی کو اس کی اولاد کی وجہ سے اور وارث پر بھی ویسا ہی نان نفقہ ہے پھر اگر دونوں اپنی رضا مندی اور مشورہ سے دودھ چھڑانا چاہیں تو ان پر کوئی گناہ نہیں ہے اور اگر کسی اور سے اپنی اولاد کو دودھ پلوانا چاہو تو اس میں بھی تم پر کوئی گناہ نہیں بشرطیکہ تم دے دو جو دستور کے مطابق تم نے دینا ٹھرایا ہے اور الله سے ڈرو اور جان لو کہ الله اسے جو تم کرتے ہو خوب دیکھتا ہے\qt@no{(233)}}%
\qt@newcmd\qurantrans@ur@ccxli{اور جو تم میں سے مر جائیں اور بیویاں چھوڑ جائيں تو ان بیویوں کو چار مہینے دس دن تک اپنے نفس کو روکنا چاہیئے پھر جب وہ اپنی مدت پوری کر لیں تو تم پر اس میں کوئی گناہ نہیں جو وہ دستور کے مطابق اپنے حق میں کریں اور الله اس سے جو تم کرتے ہو خبردار ہے\qt@no{(234)}}%
\qt@newcmd\qurantrans@ur@ccxlii{اورتم پر اس میں گناہ نہیں ہے کہ ان عورتوں کو اشارہ سے پیغام نکاح دو اور یا تم اسے اپنے دل میں چھپاؤ الله جانتاہے کہ تمہیں ان عورتوں کا خیال پیدا ہو گا لیکن مخفی طور پر ان سے نکاح کا وعدہ نہ کرو مگر یہ کہ قاعدہ کے مطابق کوئی بات کہو اورجب تک معیاد نوشتہ پوری نہ ہو اس وقت تک نکاح کا قصد بھی نہ کرو اور جان لو کہ الله جانتا ہے جو کچھ تمہارے دلو ں میں ہے پس اس سے ڈرتے رہو اور جان لو الله بڑا بخشنے والا بردبار ہے\qt@no{(235)}}%
\qt@newcmd\qurantrans@ur@ccxliii{تم پر کوئی گناہ نہیں اگر تم عورتوں کو طلاق دے دو جب کہ انہیں ہاتھ بھی نہ لگایا ہو اور ان کے لیے کچھ مہر بھی مقرر نہ کیا ہو اور انہیں کچھ سامان دے دو وسعت والے پر اپنے قدر کے مطابق اور مفلس پر اپنے قدر کے مطابق سامان حسب دستور ہے نیکو کاروں پر یہ حق ہے\qt@no{(236)}}%
\qt@newcmd\qurantrans@ur@ccxliv{اور اگر تمہیں انہیں طلاق دو اس سے پہلےکہ انہیں ہاتھ لگاؤ حالانکہ تم ان کے لیے مہر مقرر کر چکے ہو تو نصف اس کا جو تم نے مقرر کیا تھا مگر یہ کہ وہ معاف کر دیں یا وہ شخص معاف کر دے جس کے ہاتھ میں نکاح کی گرہ ہے اور تمہارا معاف کر دینا پرہیزگاری کے زیادہ قریب ہے اور آپس میں احسان کرنا نہ بھولو کیوں کہ جو کچھ بھی تم کر رہے ہو الله اسے دیکھ رہا ہے\qt@no{(237)}}%
\qt@newcmd\qurantrans@ur@ccxlv{سب نمازوں کی حفاظت کیا کرو اور (خاص کر) درمیانی نماز کی اور الله کے لیے ادب سے کھڑے رہا کرو\qt@no{(238)}}%
\qt@newcmd\qurantrans@ur@ccxlvi{پھر اگر تمہیں خوف ہو تو پیادہ یا سوار ہی (پڑھ لیا کرو) پھر جب امن پاؤ تو الله کو یادکیا کرو جیسا اس نے تمہیں سکھایا ہے جو تم نہ جانتے تھے\qt@no{(239)}}%
\qt@newcmd\qurantrans@ur@ccxlvii{اور جو لوگ تم میں سے مر جائیں اوربیویاں چھوڑ جائیں تو انہیں اپنی بیویوں کے لیے سال بھر کے لیے گزارہ کے واسطے وصیت کرنی چاہیئے گھر سے باہر گئے بغیر پھر اگر وہ خود نکل جائیں توتم پر اس میں کوئي گناہ نہیں جو وہ عورتیں اپنے حق میں دستور کے موافق کریں اور الله زبردست حکمت والا ہے\qt@no{(240)}}%
\qt@newcmd\qurantrans@ur@ccxlviii{اور طلاق دی ہوئی عورتوں کے واسطے دستور کے موافق خرچ دینا پرہیزگارو ں پر یہ لازم ہے\qt@no{(241)}}%
\qt@newcmd\qurantrans@ur@ccxlix{اسی طرح الله تمہارے واسطے اپنے احکام بیان فرماتا ہے تاکہ تم سمجھ لو\qt@no{(242)}}%
\qt@newcmd\qurantrans@ur@ccl{کیا تم نے ان لوگو ں کو نہیں دیکھا جو موت کے ڈر سے اپنے گھروں سے نکلے حالانکہ وہ ہزاروں تھے پھر الله نےان کو فرمایا کہ مرجاؤ پھر انہیں زندہ کر دیا بے شک الله لوگوں پر فضل کرنے والا ہے لیکن اکثر لوگ شکر نہیں کرتے\qt@no{(243)}}%
\qt@newcmd\qurantrans@ur@ccli{اور الله کی راہ میں لڑو اور سمجھ لو کہ بے شک الله خوب سننے والا جاننے والا ہے\qt@no{(244)}}%
\qt@newcmd\qurantrans@ur@cclii{ایسا کون شخص ہے جو الله کو اچھا قرض دے پھر الله اس کو کئی گناہ بڑھا کردے اور الله ہی تنگی کرتا ہے اور کشائش کرتا ہے اورتم سب اسی کی طرف لوٹائے جاؤ گے\qt@no{(245)}}%
\qt@newcmd\qurantrans@ur@ccliii{کیاتم نے بنی اسرائیل کی ایک جماعت کو موسیٰ کے بعد نہیں دیکھا جب انہوں نے اپنے نبی سے کہا کہ ہمارے لیے ایک بادشاہ مقرر کر دو تاکہ ہم الله کی راہ میں لڑیں پیغمبر نے کہاکیا یہ بھی ممکن ہے اگر تمہیں لڑائی کا حکم ہو تو تم اس وقت نہ لڑو انہوں نے کہا ہم الله کی راہ میں کیوں نہیں لڑیں گے حالانکہ ہمیں اپنے گھروں اور اپنےبیٹوں سے نکال دیا گیا ہے پھر جب انہیں لڑائی کا حکم ہوا تو سوائے چند آدمیوں کے سب پھر گئے اور الله ظالموں کو خوب جانتا ہے\qt@no{(246)}}%
\qt@newcmd\qurantrans@ur@ccliv{ان کے نبی نے ان سے کہا بے شک الله نے طالوت کو تمہارا بادشاہ مقرر فرمایا ہے انہوں نے کہا اس کی حکومت ہم پر کیوں کر ہو سکتی ہے اس سے تو ہم ہی سلطنت کے زیادہ مستحق ہیں اور اسے مال میں بھی کشائش نہیں دی گئی پیغمبر نے کہا بے شک الله نے اسے تم پر پسند فرمایا ہے اور اسے علم اور جسم میں زیادہ فراخ دی ہے اور الله اپنا ملک جسے چاہے دیتا ہے اور الله کشائش والا جاننے والا ہے\qt@no{(247)}}%
\qt@newcmd\qurantrans@ur@cclv{اوربنی اسرائیل سے ان کے نبی نے کہاکہ طالوت کی بادشاہی کی یہ نشانی ہے کہ تمہارے پاس وہ صندوق واپس آئے گا جس میں تمہارے رب کی طرف سے اطمینان ہے اور کچھ بچی ہوئی چیزیں ہیں ان میں سے جو موسیٰ اور ہارون کی اولاد چھوڑ گئی تھی اس صندوق کو فرشتے اٹھا لائیں گے بے شک اس میں تمہارے لیے پوری نشانی ہے اگرتم ایمان والے ہو\qt@no{(248)}}%
\qt@newcmd\qurantrans@ur@cclvi{پھر جب طالوت فوجیں لے کر نکلا کہا بے شک الله ایک نہر سے تمہاری آزمائش کرنے والا ہے جس نے اس نہر کا پانی پیا تو وہ میرا نہیں ہے اور جس نے اسے نہ چکھا تو وہ بےشک میرا ہے مگر جو کوئی اپنے ہاتھ سے ایک چلو بھر لے (تو اسے معاف ہے) پھر ان میں سے سوائے چند آدمیوں کے سب نے اس کا پانی پی لیا پھر جب طالوت اور ایمان والے ا س کے ساتھ پار ہوئے تو کہنے لگے آج ہمیں جالوت اور اس کے لشکروں سے لڑنے کی طاقت نہیں جن لوگو ں کو خیال تھا کہ انہیں الله سے ملنا ہے وہ کہنے لگے بار ہا بڑی جماعت پر چھوٹی جماعت الله کے حکم سے غالب ہوئی ہے اور الله صبر کرنے والو ں کے ساتھ ہے\qt@no{(249)}}%
\qt@newcmd\qurantrans@ur@cclvii{اورجب جالوت اور اس کی فوجوں کے سامنے ہوئے تو کہا اے رب ہمارے دلوں میں صبر ڈال دے اور ہمارے پاؤں جمائے رکھ اور اس کافر قوم پر ہماری مدد کر\qt@no{(250)}}%
\qt@newcmd\qurantrans@ur@cclviii{پھر الله کے حکم سے مومنو ں نے جالوت کے لشکروں کو شکست دی اور داؤد نے جالوت کو مار ڈالا اور الله نے سلطنت اور حکمت داؤد کو دی اور جو چاہا اسے سکھایا اور اگر الله کابعض کو بعض کے ذریعے سے دفع کرا دینا نہ ہوتا تو زمین فساد سے پُر ہو جاتی لیکن الله جہان والوں پر بہت مہربان ہے\qt@no{(251)}}%
\qt@newcmd\qurantrans@ur@cclix{یہ الله کی آیتیں ہیں ہم تمہیں ٹھیک طور پر پڑھ کر سناتے ہیں اوربے شک تو ہمارے رسولوں میں سے ہے\qt@no{(252)}}%
\qt@newcmd\qurantrans@ur@cclx{یہ سب رسول ہیں ہم نے ان میں سے بعض کو بعض پر فضیلت دی ہے بعض وہ ہیں جن سے الله نے کلام فرمائی اور بعضوں کے درجے بلند کیے اور ہم نے عیسیٰ مریم کے بیٹے کو صریح معجزے دیے تھے اور اسے روح القدس کے ساتھ قوت دی تھی اور اگر الله چاہتا تو وہ لوگ جو ان پیغمبروں کے بعد آئے وہ آپس میں نہ لڑتے بعد اس کے کہ ان کے پاس صاف حکم پہنچ چکے تھے لیکن ان میں اختلاف پیدا ہو گیا پھر کوئی ان میں سے ایمان لایا اور کوئی کافر ہوا اور اگر الله چاہتا تو وہ آپس میں نہ لڑتے لیکن الله جو چاہتا ہے کرتا ہے\qt@no{(253)}}%
\qt@newcmd\qurantrans@ur@cclxi{اے ایمان والو! جو ہم نے تمہیں رزق دیا ہے اس میں سے خرچ کرو اس دن کے آنے سے پہلے جس میں نہ کوئی خرید و فروخت ہو گی اور نہ کوئی دوستی اور نہ کوئی سفارش اور کافر وہی ظالم ہیں\qt@no{(254)}}%
\qt@newcmd\qurantrans@ur@cclxii{الله کے سوا کوئی معبود نہیں زندہ ہےسب کا تھامنے والا نہ اس کی اونگھ دبا سکتی ہے نہ نیند آسمانوں اور زمین میں جو کچھ بھی ہے سب اسی کا ہے ایسا کون ہے جو اس کی اجازت کے سوا اس کے ہاں سفارش کر سکے مخلوقات کے تمام حاضر اور غائب حالات کو جانتا ہے اور وہ سب اس کی معلومات میں سےکسی چیز کا احاطہ نہیں کر سکتے مگر جتنا کہ وہ چاہے اس کی کرسی نے سب آسمانوں اور زمین کو اپنے اندر لے رکھا ہے اور الله کو ان دونوں کی حفاظت کچھ گراں نہیں گزرتی اور وہی سب سےبرتر عظمت والا ہے\qt@no{(255)}}%
\qt@newcmd\qurantrans@ur@cclxiii{دین کے معاملے میں زبردستی نہیں ہے بے شک ہدایت یقیناً گمراہی سے ممتاز ہو چکی ہے پھر جو شخص شیطان کو نہ مانے اور الله پر ایمان لائے تو اس نے مضبوط حلقہ پکڑ لیاجو ٹوٹنے والا نہیں اور الله سننے والا جاننے والا ہے\qt@no{(256)}}%
\qt@newcmd\qurantrans@ur@cclxiv{الله ایمان والوں کا مددگار ہے اور انہیں اندھیروں سے روشنی کی طرف نکالتا ہے اور جو لوگ کافر ہیں ان کے دوست شیطان ہیں انہیں روشنی سے اندھیروں کی طرف نکالتے ہیں یہی لوگ دوزخ میں رہنے والے ہیں وہ اس میں ہمیشہ رہیں گے\qt@no{(257)}}%
\qt@newcmd\qurantrans@ur@cclxv{کیا تو نے اس شخص کو نہیں دیکھا جس نے ابراھیم سے اس کے رب کی بابت جھگڑا کیا اس لیے کہ الله نے اسے سلطنت دی تھی جب ابراھیم نے کہا کہ میرا رب وہ ہے جو زندہ کرتا ہے اور مارتا ہے اس نے کہا میں بھی زندہ کرتا ہوں اور مارتا ہوں کہا ابراھیم نے بے شک الله سورج مشرق سے لاتا ہے تو اسے مغرب سے لے آ تب وہ کافر حیران رہ گیا اور الله بے انصافوں کی سیدھی راہ نہیں دکھاتا\qt@no{(258)}}%
\qt@newcmd\qurantrans@ur@cclxvi{یا تو نے اس شخص کو نہیں دیکھا جو ایک شہر پر گزرا اور وہ اپنی چھتوں پر گرا ہوا تھاکہا اسے الله مرنے کے بعد کیوں کر زندہ کرے گا پھر الله نے اسے سو برس تک مار ڈالا پھر اسے اٹھایا کہا تو یہاں کتنی دیر رہا کہا ایک دن یا اس سے کچھ کم رہا فرمایا بلکہ تو سو برس رہا ہے اب تو اپنا کھانا اور پینا دیکھ وہ تو سڑا نہیں اور اپنے گدھے کو دیکھ اور ہم نے تجھے لوگوں کے واسطے نمونہ چاہا ہے اور ہڈیوں کیطرف دیکھ کہ ہم انہیں کس طرح ابھار کر جوڑدیتے ہیں پھر ان پر گوشت پہناتے ہیں پھر اس پر یہ حال ظاہر ہوا تو کہا میں یقین کرتا ہو ں کہ بے شک الله ہر چیز پر قادر ہے\qt@no{(259)}}%
\qt@newcmd\qurantrans@ur@cclxvii{اور یاد کر جب ابراھیم نے کہا اے میرے پروردگار! مجھ کو دکھا کہ تو مردے کو کس طرح زندہ کرے گا فرمایا کہ کیا تم یقین نہیں لاتے کہا کیوں نہیں لیکن اس واسطے چاہتاہوں کہ میرے دل کو تسکین ہو جائے فرمایا تو چار جانور اڑنے والے پکڑے پھر انہیں اپنے ساتھ ہلا لے پھر ہر پہاڑ پر ان کے بدن کا ایک ایک ٹکڑا رکھ دے پھر ان کو بلا تیرے پاس دوڑتے ہوئے آئیں گے اور جان لے کہ بے شک الله زبردست حکمت والا ہے\qt@no{(260)}}%
\qt@newcmd\qurantrans@ur@cclxviii{ان لوگوں کی مثال جو الله کی راہ میں مال خرچ کرتے ہیں ایسی ہے کہ جیسے ایک دانہ کہ اگائے سات بالیں ہر بال میں سو سو دانے اور الله جس کے واسطے چاہے بڑھاتا ہے اور الله بڑی وسعت جاننے والا ہے\qt@no{(261)}}%
\qt@newcmd\qurantrans@ur@cclxix{جو لوگ اپنے مال الله کی راہ میں خرچ کرتے ہیں پھر خرچ کرنے کے بعد نہ احسان رکھتے ہیں اور نہ ستاتے ہیں انہیں کے لیے اپنے رب کے ہاں ثواب ہے اوران پر نہ کوئی ڈر ہے اور نہ وہ غمگین ہوں گے\qt@no{(262)}}%
\qt@newcmd\qurantrans@ur@cclxx{مناسب بات کہہ دینا اور درگزر کرنا اس خیرات سے بہتر ہے جس کے بعد ستانا ہو اور الله بے پرواا نہایت تحمل والا ہے\qt@no{(263)}}%
\qt@newcmd\qurantrans@ur@cclxxi{اے ایمان والو! احسان رکھ کر اور ایذا دے کے اپنی خیرات کو ضائع نہ کرو اس شخص کی طرح جو اپنا مال لوگوں کے دکھانے کو خرچ کرتا ہے اور الله پر اور قیامت کے دن پر یقین نہیں رکھتا سو اس کی مثال ایسی ہے جیسے صاف پتھر کہ اس پر کچھ مٹی پڑی ہو پھر اس پر زور کا مینہ برساپھر اسی کو بالکل صاف کر دیا ایسے لوگوں کو اپنی کمائی ذرا ہاتھ بھی نہ لگے گی اور الله کافروں کو سیدھی راہ نہیں دکھاتا\qt@no{(264)}}%
\qt@newcmd\qurantrans@ur@cclxxii{اور ان لوگوں کی مثال جو اپنے مال الله کی رضا حاصل کرنے کے لیے اور اپنے دلوں کو مضبوط کر کے خرچ کرتے ہیں ایسی ہے جس طرح بلند زمین پر ایک باغ ہو اس پر زور کا مینہ برسا تو وہ باغ اپنا پھل دوگنا لایا اور اگر اس پر مینہ نہ برسایا تو شبنم ہی کافی ہے اور الله تمہارے کاموں کو خوب دیکھنے والا ہے\qt@no{(265)}}%
\qt@newcmd\qurantrans@ur@cclxxiii{کیا تم میں کسی کو یہ بات پسند آتی ہے کہ اس کا ایک باغ کھجور اور انگور کا ہو جس کے نیچے نہریں بہتی ہوں اسے اس باغ میں اوربھی ہر طرح کا میوہ حاصل ہو اور اس پر بڑھاپا آ گیا ہو اور اس کی اولاد ضعیف ہو تب اس باغ پرایک بگولہ آ پڑا جس میں آگ تھی جس سے وہ باغ جل گیا الله تمہیں اس طرح نشانیاں سمجھاتا ہے تاکہ تم سوچا کرو\qt@no{(266)}}%
\qt@newcmd\qurantrans@ur@cclxxiv{اے ایمان والو! اپنی کمائی میں سے ستھری چیزیں خرچ کرو اور اس چیز میں سے بھی جو ہم نے تمہارے لیے زمین سے پیدا کی ہے اور اس میں سے ردی چیز کا ارادہ نہ کرو کہ اس کو خرچ کرو حالانکہ تم اسے کبھی نہ لو مگر یہ کہ چشم پوشی کر جاؤ اور سمجھ لو کہ بے شک الله بے پرواہ تعریف کیا ہوا ہے\qt@no{(267)}}%
\qt@newcmd\qurantrans@ur@cclxxv{شیطان تمہیں تنگدستی کا وعدہ دیتا ہے اور بے حیائی کا حکم کرتا ہے اور الله تمہیں اپنی بخشش اور فضل کا وعدہ دیتا ہے اور الله بہت کشائش کرنے والا سب کچھ جاننے والا ہے\qt@no{(268)}}%
\qt@newcmd\qurantrans@ur@cclxxvi{جس کو چاہتا ہے سمجھ دے دیتا ہے اور جسے سمجھ دی گئی تو اسے بڑی خوبی ملی اور نصیحت وہی قبول کرتے ہیں جو عقل والے ہیں\qt@no{(269)}}%
\qt@newcmd\qurantrans@ur@cclxxvii{اورجو تم خیرات کے طور پر خرچ کرو گے یا تم کوئی منت مانگوگے تو بے شک الله کو سب معلوم ہے اور ظالموں کا کوئی مددگار نہیں ہے\qt@no{(270)}}%
\qt@newcmd\qurantrans@ur@cclxxviii{اگر تم خیرات ظاہر کرکے دو تو بھی اچھی بات ہے اور اگر اسے چھپا کردو اور فقیروں کو پہنچادو تو تمہارے حق میں وہ بہتر ہے اور الله تمہارے کچھ گناہ دور کر دے گا اور الله تمہارے کاموں سے خوب خبر رکھنے والا ہے\qt@no{(271)}}%
\qt@newcmd\qurantrans@ur@cclxxix{انہیں راہ پر لانا تیرے ذمہ نہیں اور لیکن الله جسے چاہے راہ پر لاتا ہے اور جو مال تم خرچ کرو گے اس کا نفع تمہاری جان کے لیے ہےاور الله ہی کی رضا مندی کے لیے خرچ کرو اور جو اچھی چیز تم خرچ کرو گے اس کا پورا اجر تمہیں دیا جائے گا ااور تم پر ظلم نہیں کیا جائے گا\qt@no{(272)}}%
\qt@newcmd\qurantrans@ur@cclxxx{خیرات ان حاجت مندوں کے لیے ہے جو الله کی راہ میں رکےہوئے ہیں ملک میں چل پھر نہیں سکتے ناواقف ان کے سوال نہ کرنے سے انہیں مال دار سمجھتا ہے تو ان کے چہرے سے پہچان سکتا ہے لوگوں سے لپٹ کر سوال نہیں کرتے اور جو کام کی چیز تم خرچ کرو گے بے شک وہ الله کو معلوم ہے\qt@no{(273)}}%
\qt@newcmd\qurantrans@ur@cclxxxi{جو لوگ اپنے مال الله کی راہ میں رات اوردن چھپا کر اور ظاہر خرچ کرتے ہیں تو ان کے لیےاپنے رب کے ہاں ثواب ہے ان پر نہ کوئي ڈر ہے اور نہ وہ غمگین ہوں گے\qt@no{(274)}}%
\qt@newcmd\qurantrans@ur@cclxxxii{جو لوگ سود کھاتے ہیں قیامت کے دن وہ نہیں اٹھیں گے مگر جس طرح کہ وہ شخص اٹھتا ہے جس کے حواس جن نے لپٹ کر کھو دیئے ہیں یہ حالت ان کی اس لیے ہوگی کہ انہوں نے کہا تھا کہ سوداگری بھی تو ایسی ہی ہے جیسےسود لینا حالانکہ الله نے سوداگری کو حلال کیا ہے اور سود کو حرام کیا ہے پھر جسے اپنے رب کی طرف سے نصیحت پہنچی اوروہ باز آ گیا تو جو پہلے لے چکا ہے وہ اسی کا رہا اور اس کا معاملہ الله کے حوالہ ہے اور جو کوئی پھر سود لے وہی لوگ دوزخ والے ہیں وہ اس میں ہمیشہ رہیں گے\qt@no{(275)}}%
\qt@newcmd\qurantrans@ur@cclxxxiii{الله سود کو مٹاتا ہے اور صدقات کو بڑھاتا ہے اور الله کسی ناشکرے گناہگار کو پسندنہیں کرتا\qt@no{(276)}}%
\qt@newcmd\qurantrans@ur@cclxxxiv{جو لوگ ایمان لائے اور نیک کام کیے اور نماز کو قائم رکھا اور زکواةٰ دیتے رہے تو ان کے رب کے ہاں ان کااجر ہے اور ان پر کوئی خوف نہ ہوگا اور نہ وہ غمگین ہوں گے\qt@no{(277)}}%
\qt@newcmd\qurantrans@ur@cclxxxv{اے ایمان والو! الله سے ڈرو اور جو کچھ باقی سود رہ گیا ہے اسے چھوڑ دو اگر تم ایمان والے ہو\qt@no{(278)}}%
\qt@newcmd\qurantrans@ur@cclxxxvi{اگر تم نے نہ چھوڑا تو الله اور اس کے رسول کی طرف سے تمہارےخلاف اعلان جنگ ہے اور اگرتوبہ کرلوتو اصل مال تمھارا تمہارے واسطے ہے نہ تم کسی پر ظلم کرو اور نہ تم پر ظلم کیا جائے گا\qt@no{(279)}}%
\qt@newcmd\qurantrans@ur@cclxxxvii{اور اگر وہ تنگ دست ہے تو آسودہ حالی تک مہلت دینی چاہیئے اور بخش دو تو تمہارے لیے بہت ہی بہتر ہے اگر تم جانتے ہو\qt@no{(280)}}%
\qt@newcmd\qurantrans@ur@cclxxxviii{اور اس دن سے ڈرو جس دن الله کی طرف لوٹائے جاؤ گے پھر پھر ہر شخص کو اس کی کمائی کا پورا پورا بدلہ دے دیا جائے گا اور ان پر ظلم نہ ہوگا\qt@no{(281)}}%
\qt@newcmd\qurantrans@ur@cclxxxix{اے ایمان والو! جب تم کسی وقت مقرر تک آپس میں ادھار کا معاملہ کرو تو اسے لکھ لیا کرو اور چاہیئے کہ تمہارے درمیان لکھنے والے انصاف سے لکھے اور لکھنے والا لکھنے سے انکار نہ کرے جیسا کہ اس کو الله نے سکھایا ہے سو اسے چاہیئے کہ لکھ دے اور وہ شخص بتلاتا جائے کہ جس پر قرض ہے اور الله سے ڈرے جو اس کا رب ہے اور اس میں کچھ کم کر کے نہ لکھائے پھر اگر وہ شخص کہ جس پر قرض ہے بے وقوف ہے یا کمزور ہے یا وہ بتلا نہیں سکتا تو اس کا کارکن ٹھیک طور پر لکھوا دے اور اپنے مردوں میں سے دو گواہ کر لیا کرو پھر اگر دو مرد نہ ہوں تو ایک مرد اور دوعورتیں ان لوگوں میں سے جنہیں تم گواہو ں میں سے پسند کرتے ہوتاکہ اگر ایک ان میں سے بھول جائے تو دوسری اسے یاد دلا دے اور جب گواہوں کو بلایا جائے تو انکار نہ کریں اور معاملہ چھوٹا ہو یا بڑا اس کی معیاد تک لکھنے میں سستی نہ کرو یہ لکھ لینا الله کے نزدیک انصاف کو زیادہ قائم رکھنے والا ہے اور شہادت کا زیادہ درست رکھنے والا ہے اور زیادہ قریب ہے اس بات کے کہ تم کسی شبہ میں نہ پڑو مگر یہ کہ سوداگری ہاتھوں ہاتھ ہو جسے آپس میں لیتے دیتے ہو پھر تم پر کوئی گناہ نہیں کہ اسے نہ لکھو اور جب آپس میں سودا کرو تو گواہ بنا لو اور لکھنے والے اور گواہ بنانے والے کو تکلیف نہ دی جائے اور اگر تم نے تکلیف دی تو تمہیں گناہ ہوگا اور الله سے ڈرو اور الله تمہیں سکھاتا ہے اور الله ہر چیز کا جاننے والا ہے\qt@no{(282)}}%
\qt@newcmd\qurantrans@ur@ccxc{اور اگر تم سفر میں ہو اور کوئی لکھنے والا نہ پاؤ تو گروی پر قبضہ کیا جائے اور اگر ایک تم میں سے دوسرے پر اعتبار کرے تو چاہیئے کہ کہ وہ شخص امانت ادا کردے جس پر اعتبار کیا گیا اور اپنے الله سے ڈرے جو اس کا رب ہے اور گواہی کو نہ چھپاؤ اور جو شخص اسے چھپائے گا تو بے شک اس کا دل گناہگار ہے اور جو کچھ تم کرتے ہو الله خوب جانتا ہے\qt@no{(283)}}%
\qt@newcmd\qurantrans@ur@ccxci{جو کچھ آسمانوں اور زمین میں ہے اللہ ہی کا ہے اور اگر تم اپنے دل کی بات ظاہر کرو گے یا چھپاؤ گے الله تم سے اس کا حساب لے گا پھر جس کو چاہے بخشے گا اور جسے چاہے عذاب کرے گا اور الله ہر چیز پر قادر ہے\qt@no{(284)}}%
\qt@newcmd\qurantrans@ur@ccxcii{رسول نے مان لیا جو کچھ اس پر اس کے رب کی طرف سے اترا ہے اور مسلمانوں نے بھی مان لیا سب نے الله کو اور اس کے فرشتوں کو اور اس کی کتابوں کو اور اس کے رسولوں کو مان لیا ہے کہتے ہیں کہ ہم الله کے رسولوں کو ایک دوسرے سے الگ نہیں کرتے اور کہتے ہیں ہم نے سنا اور مان لیا اے ہمارے رب تیری بخشش چاہتے ہیں اور تیری ہی طرف لوٹ کر جانا ہے\qt@no{(285)}}%
\qt@newcmd\qurantrans@ur@ccxciii{الله کسی کو اس کی طاقت کے سوا تکلیف نہیں دیتا نیکی کا فائدہ بھی اسی کو ہو گا اور برائی کی زد بھی اسی پر پڑے گی اے رب ہمارے! اگر ہم بھول جائیں یا غلطی کریں تو ہمیں نہ پکڑ اے رب ہمارے! اور ہم پر بھاری بوجھ نہ رکھ جیسا تو نے ہم سے پہلے لوگوں پر رکھا تھا اے رب ہمارے! اور ہم سے وہ بوجھ نہ اٹھوا جس کی ہمیں طاقت نہیں اور ہمیں معاف کر دے اور ہمیں بخش دے اور ہم پر رحم کر تو ہی ہمارا کارساز ہے کافروں کے مقابلہ میں تو ہماری مدد کر\qt@no{(286)}}%
\qt@newcmd\qurantrans@ur@ccxciv{\basmalahur المۤ\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@ccxcv{الله اس کے سوا کوئی معبود نہیں زندہ ہے نظام کائنات کا سنبھالنے والا ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@ccxcvi{اس نے تجھ پر یہ سچی کتاب نازل فرمائی جو پہلی کتابوں کی تصدیق کرتی ہے اور اسی نے اس کتاب سے پہلے تورات اور انجیل نازل فرمائی\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@ccxcvii{وہ کتابیں لوگوں کے لیے راہ نما ہیں اور اسی نے فیصلہ کن چیزیں نازل فرمائیں بے شک جو لوگ الله کی آیتوں سے منکر ہوئے ان کے لیے سخت عذاب ہے اور الله تعالیٰ زبردست بدلہ دینے والا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@ccxcviii{الله پر زمین اور آسمان میں کوئی چیز چھپی ہوئی نہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@ccxcix{وہی جس طرح چاہے ماں کے پیٹ میں تمہارا نقشہ بناتا ہے اس کے سوا اور کوئی معبود نہیں زبردست حکمت والا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@ccc{وہی ہے جس نے تجھ پر کتاب اتاری اس میں بعض آیتیں محکم ہیں (جن کے معنیٰ واضح ہیں) وہ کتاب کی اصل ہیں اور دوسری مشابہ ہیں (جن کے معنیٰ معلوم یا معین نہیں) سو جن لوگو ں کے دل ٹیڑھے ہیں وہ گمراہی پھیلانے کی غرض سے اور مطلب معلوم کرنے کی غرض سے متشابہات کے پیچھے لگتے ہیں اور حالانکہ ان کا مطلب سوائے الله کے اور کوئی نہیں جانتا اور مضبوط علم والے کہتے ہیں ہمارا ان چیزوں پر ایمان ہے یہ سب ہمارے رب کی طرف سے ہیں اور نصیحت وہی لوگ مانتے ہیں جو عقلمند ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@ccci{اے رب ہمارے! جب تو ہم کو ہدایت کر چکا تو ہمارے دلوں کا نہ پھیر اور اپنے ہاں سے ہمیں رحمت عطافرما بے شک تو بہت زیادہ دینے والا ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@cccii{اے ہمارے رب! توایک دن سب لوگوں کو جمع کرنے والا ہے جس میں کوئی شک نہیں بے شک الله اپنے وعدہ کا خلاف نہیں کرتا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@ccciii{بے شک جو لوگ کافر ہیں ان کے مال او ران کی اولاد الله کے مقابلے میں ہر گز کام نہیں آئیں گے اوروہ لوگ دوزخ کا ایندھن ہیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@ccciv{جس طرح فرعون والوں اور ان سے پہلے لوگوں کا معاملہ تھا انہوں نے ہماری نشانیوں کو جھٹلایا پھر الله نے ان کے گناہوں کے سبب سے انہیں پکڑا اور الله سخت عذاب دینے والا ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@cccv{کافروں کو کہہ دے کہ اب تم مغلوب ہو گئے اور دوزخ کی طرف اکھٹے کیے جاؤ گے اوروہ برا ٹھکانہ ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@cccvi{تمہارے سامنے ایک نمونہ دو فوجوں کا گزر چکا ہے جو آپس میں ملیں ایک فوج الله کی راہ میں لڑتی ہے اور دوسری فوج کافروں کی ہے وہ کافر مسلمانوں کو اپنے سے دوگنا دیکھ رہے تھے آنکھوں کے دیکھنے سے اور االله جسے چاہے اپنی مدد سے قوت دیتا ہے اس واقعہ میں دیکھنے والوں کے لیے عبرت ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@cccvii{لوگوں کو مرغوب چیزوں کی محبت نے فریفتہ کیا ہوا ہے جیسے عورتیں اور بیٹے اور سونے اور چاندی کے جمع کیے ہوئے خزانے اور نشان کیے ہوئے گھوڑے اور مویشی اور کھیتی یہ دنیا کی زندگی کا فائدہ ہے اور الله ہی کے پاس اچھا ٹھکانہ ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@cccviii{کہہ دے کیا میں تم کو اس سے بہتر بناؤں پرہیزگاروں کے لیے اپنے رب کے ہاں باغ ہیں جن کے نیچے نہریں بہتی ہیں ان میں ہمیشہ رہیں گے اور پاک عورتیں ہیں اور الله کی رضا مندی ہے اور الله بندوں کو خوب دیکھنے والا ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@cccix{وہ جو کہتے ہیں اے رب ہمارے! ہم ایمان لائے ہیں سو ہمیں ہمارے گناہ بخش دے اور ہمیں دوزخ کے عذاب سے بچا لے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@cccx{وہ صبر کرنے والے ہیں اور سچے ہیں اور فرمانبرداری کرنے والے ہیں اور خرچ کرنے والے ہیں اور پچھلی راتوں میں گناہ بخشوا نے والے ہیں\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@cccxi{الله نے اور فرشتوں نے اور علم والوں نے گواہی دی کہ اس کے سوا اورکوئی معبود نہیں وہی انصاف کا حاکم ہے اس کے سوا اورکوئی معبود نہیں زبردست حکمت والا ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@cccxii{بےشک دین الله کے ہاں فرمابرداری ہی ہے اور جنہیں کتاب دی گئی تھی انہوں نے صحیح علم ہونے کے بعد آپس کی ضد کے باعث اختلاف کیا اور جو شخص الله کے حکموں کا انکار کرے تو الله جلد ہی حساب لینے والا ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@cccxiii{پھربھی اگر تجھ سے جھگڑیں تو ان سے کہہ دے کہ میں نے اپنا منہ الله کے تابع کیا ہے ان لوگوں نے بھی جو میرے ساتھ ہیں اور ان لوگوں سے کہہ دے جنہیں کتاب دی گئی ہے اور ان پڑھوں سے آیا تم بھی تابع ہوتے ہو پھر اگر وہ تابع ہو گئے تو انہوں نے بھی سیدھی راہ پالی اور اگر وہ منہ پھیریں تو تیرے ذمہ فقط پہنچا دینا ہے اور الله بندوں کو خوب دیکھنے والا ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@cccxiv{بے شک جولوگ الله کے حکموں کا انکار کرتے ہیں اور پیغمبروں کو ناحق قتل کرتے ہیں اور لوگوں میں سے انصاف کا حکم کرنے والوں کو قتل کرتے ہیں سو انہیں دردناک عذاب کی خوشخبری سنا دیے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@cccxv{یہی وہ لوگ ہیں جنکی دنیا اور آخرت میں محنت ضائع ہو گئی اور ان کا کوئی مددگار نہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@cccxvi{کیا تو نے ان لوگوں کو نہیں دیکھا جنہیں ایک حصہ کتاب کا ملا وہ الله کی کتاب کی طرف بلائے جاتے ہیں تاکہ وہ کتاب ان میں فیصلہ کرے پھر ایک فرقہ ان میں سے پھر جاتا ہے ایسے حال میں کہ وہ منہ پھیرنے والے ہوتے ہیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@cccxvii{یہ ا سلیے ہےکہ وہ کہتے ہیں کہ ہمیں ہرگز آگ نہیں لگے گی مگر چند دن گنتی کے اور ان کی بنائی ہوئی باتوں نے انہیں دین میں دھوکہ دیا ہوا ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@cccxviii{پھر ان کا کیا ہوگا جب ہم انہیں ایک دن جمع کریں گے جس کے آنے میں کوئی شبہ نہیں اور ہر کسی کواپنی کمائی کا اجر پورا دیا جائے گا اور ان پر کوئی ظلم نہیں کیا جائے گا\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@cccxix{تو کہہ اے الله! بادشاہی کے مالک! جسے تو چاہتا ہے سلطنت دیتاہے اور جس سے چاہتا ہے سلطنت چھین لیتا ہے جسے تو چاہتا ہے عزت دیتا ہے اور جسے توچاہے ذلیل کرتا ہے سب خوبی تیرے ہاتھ میں ہے بے شک تو ہر چیز قادر ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@cccxx{تو رات کو دن میں داخل کرتا ہے اور دن کو رات میں داخل کرتا ہے اور زندہ کو مردہ سے نکالتا ہے اور مردہ کو زندہ سےنکالتا ہے اور جسے تو چاہتا ہے بے حساب رزق دیتا ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@cccxxi{مسلمان مسلمانوں کو چھوڑ کر کافروں کو دوست نہ بنائيں اور جوکوئی یہ کام کریں اسے الله سے کوئی تعلق نہیں مگر اس صورت میں کہ تم ان سے بچاؤ کرنا چاہو اور الله تمہیں اپنے سے ڈراتا ہے اور الله ہی کی طرف لوٹ کر جانا ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@cccxxii{تو کہہ دے اگر تم اپنے دل کی بات چھپاؤ یا ظاہر کرو اسے الله جانتا ہے اور جو کچھ آسمانوں اور جو کچھ زمین میں ہے اسے جانتا ہے اور الله ہر چیز ہر قادر ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@cccxxiii{جس دن ہرشخص موجود پائے گا اپنے سامنے اس نیکی کو جو اس نے کی تھی اور جو کچھ کہ اس نے برائی کی تھی اس دن چاہے گا کہ کاش درمیان اس کے اور درمیان اس کی برائی کے مسافت دور کی ہو اور الله تمہیں اپنی ذات سے ڈراتا ہے اور الله بندوں پر شفقت کرنے والا ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@cccxxiv{کہہ دو اگر تم الله کی محبت رکھتے ہو تو میری تابعداری کرو تاکہ تم سے الله محبت کرے اور تمہارے گناہ بخشے اور الله بخشنے والا مہربان ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@cccxxv{کہہ دو الله اور اس کے رسول کی فرمانبرداری کرو پھر اگر وہ منہ موڑیں تو الله کافروں کو دوست نہیں رکھتا\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@cccxxvi{بے شک اللهنے آدم کو اور نوح کو اور ابراھیم کی اولاد کو اور عمران کی اولاد کو سارے جہان سے پسند کیاہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@cccxxvii{جو ایک دوسرے کی اولاد تھے اور الله سننے والا جاننے والا ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@cccxxviii{جب عمران کی عورت نے کہا اے میرے رب جو کچھ میرے پیٹ میں ہے سب سے آزاد کر کے میں نےتیری نذر کیا سو تو مجھ سے قبول فرما بے شک تو ہی سننے والا جاننے والا ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@cccxxix{پھر جب اسے جنا کہا اے میرے رب! میں نے تو وہ لڑکی جنی ہے اور جو کچھ اس نے جنا ہے الله اسے خوب جانتا ہے اور بیٹا بیٹی کی طرح نہیں ہوتا اور میں نے اس کا نام مریم رکھا اور میں اسے اور اس کی اولاد کو شیطان مردود سے بچا کر تیری پناہ میں دیتی ہوں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@cccxxx{پھر اسے اس کے رب نے اچھی طرح سے قبول کیا اور اسے اچھی طرح بڑھایا اور وہ زکریا کو سونپ دی جب زکریا اس کے پاس حجرہ میں آتے تو اس کے پاس کچھ کھانے کی چیز پاتے کہتے اے مریم! تیرے پاس یہ چیز کہاں سے آئی ہے وہ کہتی یہ الله کے ہاں سے آئی ہے الله جسے چاہے بے قیاس رزق دیتا ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@cccxxxi{زکریا نے وہیں اپنے رب سے دعا کی کہا اے میرے رب! مجھے اپنے پاس سے پاکیزہ اولاد عطا فرما بے شک تو دعا کا سننے والا ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@cccxxxii{پھر فرشتوں نے اس کو آواز دی جب وہ حجرے کے اندر نماز میں کھڑے تھے کہ بے شک الله تجھ کو یحییٰ کو خوشخبری دیتا ہے جو الله کے ایک حکم کی گواہی دے گا اور سردار ہوگا اور عورت کے پاس نہ جائے گا اور صالحین میں سے نبی ہوگا\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@cccxxxiii{کہا اے میرے رب! میرا لڑکا کہاں سے ہوگا حالانکہ میں بڑھاپے کو پہنچ چکا ہوں اور میری بیوی بانجھ ہے فرمایا الله اسی طرح جو چاہتا ہے کرتا ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@cccxxxiv{کہا اے میرے رب! میرے لیے کوئی نشانی مقرر کر فرمایا تیرے لیے یہ نشانی ہے کہ تو لوگوں سے تین دن سوائے اشارہ کے بات نہ کر سکے گا اور اپنے رب کو بہت یاد کر اور شام اور صبح تسبیح کر\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@cccxxxv{اور جب فرشتوں نے کہا اے مریم! بے شک الله نے تجھے پسند کیا ہے تجھے پاک کیا ہے اور تجھے سب جہان کی عورتوں پر پسند کیا ہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@cccxxxvi{اے مریم! اپنے رب کی بندگی کر اور سجدہ اور رکوع کرنے والوں کے ساتھ رکوع کر\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@cccxxxvii{یہ غیب کی خبریں ہیں ہم بذریعہ وحی تمہیں اطلاع دیتے ہیں اورتو ان کے پاس نہیں تھا جب اپنا قلم ڈالنے لگے تھے کہ مریم کی کون پرورش کرے اور تو ان کے پاس نہیں تھا جب کہ وہ جھگڑتے تھے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@cccxxxviii{جب فرشتوں نے کہا اے مریم! الله تجھ کو ایک بات کی اپنی طرف سے بشارت دیتا ہے اس کا نام مسیح عیسیٰ بیٹا مریم کا ہوگا دنیا اور آخرت میں مرتبے والا اور الله کے مقربوں میں سے ہو گا\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@cccxxxix{اور جب کہ وہ ماں کی گود میں ہوگا تو لوگوں سے باتیں کرے گا اور جبکہ وہ ادھیڑ عمر کا ہوگا اور نیکوں میں سے ہوگا\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@cccxl{مریم نے کہا اے میرے رب! مجھے بیٹا کیسے ہو گا حالانکہ مجھے کسی آدمی نے ہاتھ نہیں لگایا فرمایا اسی طرح الله جو چاہے پیدا کرتا ہےجب کسی کام کا ارادہ کرتا ہے تو اس کو یہی کہتا ہے کہ ہوجا تو وہ ہو جاتا ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@cccxli{اور اس کو کتاب سکھائے گا اور دانش عطا فرمائے گا اور توریت اور انجیل\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@cccxlii{اور اس کو بنی اسرائیل کی طرف پیغمبر بنا کر بھیجے گا بے شک میں تمہارے رب کی طرف سے تمہارے پاس نشانیاں لے کر آیا ہوں کہ میں تمہیں مٹی سے ایک پرندہ کی شکل بنادیتا ہوں پھر اس میں پھونک مارتا ہوں اور وہ الله کے حکم سے اڑتا جانور ہو جاتا ہے اور مادر زاد اندھے اور کوڑھی کو اچھا کردیتا ہوں اور الله کے حکم سے مردے زندہ کرتا ہوں اور تمہیں بتا دیتا ہوں جو کھا کر آؤ اور جواپنے گھروں میں رکھ کر آؤ اس میں تمہار لیے نشانیاں ہیں اگر تم ایماندار ہو\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@cccxliii{اور مجھ سے پہلی کتاب جو تورات ہے اس کی تصدیق کرنے والاہوں اور تا کہ تم کو بعض چیزیں حلال کر دوں جو تم پر حرام تھیں اور تمہارے پاس تمہارے رب کی طرف سے نشانی لے کر آیا ہوں سو الله سے ڈرو اور میرا کہنا مانو\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@cccxliv{بے شک الله ہی میرا اور تمہارا رب ہے سو اسی کی بندگی کرو یہی سیدھا راستہ ہے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@cccxlv{جب عیسیٰ نے بنی اسرائیل کاکفر معلوم کیا تو کہاکہ الله کی راہ میں کون میرا مددگار ہے حواریو ں نے کہا ہم الله کے دین کی مدد کرنے والے ہیں ہم الله پر یقین لائے اور تو گواہ رہ کہ ہم فرمانبرادر ہونے والے ہیں\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@cccxlvi{اے رب ہمارے! ہم اس چیز پر ایمان لائے جو تو نے نازل کی اور ہم رسول کے تابعدار ہوئے سو تو ہمیں گواہی دینے والوں میں لکھ لے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@cccxlvii{اور انہوں نے خفیہ تدبیر کی اور الله نے بھی خفیہ تدبیر فرمائی اور الله بہترین خفیہ تدبیر کرنے والو ں میں سے ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@cccxlviii{جس وقت الله نے فرمایا اے عیسیٰ! بے شک میں تمہیں وفات دینے والا ہوں اور تمہیں اپنی طرف اٹھانے والا ہوں اور تمہیں کافروں سے پاک کرنے والا ہوں اور جو لوگ تیرے تابعدار ہوں گے انہیں ان لوگوں پر قیامت کے دن تک غالب رکھنے والا ہوں جو تیرے منکر ہیں پھر تم سب کو میری طرف لوٹ کر آنا ہوگا پھر میں تم میں فیصلہ کروں گا جس بات میں تم جھگڑتے تھے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@cccxlix{سو جو لوگ کافر ہوئے انہیں دنیا اور آخرت میں سخت عذاب دوں گا اور ان کا کوئی مددگار نہیں ہوگا\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@cccl{اورجو لوگ ایمان لائے اور نیک کام کیے انہیں ان کا حق پورا پورا دے گا اور الله ظالموں کو پسند نہیں کرتا\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@cccli{یہ آیتیں ہم تمہیں پڑھ کر سناتے ہیں اور نصیحت حکمت والی\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@ccclii{بے شک عیسیٰ کی مثال الله کے نزدیک آدم کی سی ہے اسے مٹی سے بنایا پھر اسے کہا کہ ہو جا پھر ہو گیا\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@cccliii{حق وہی ہے جو تیرا رب کہے پھر تو شک کرنے والو ں میں سے نہ ہو\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@cccliv{پھر جو کوئی تجھ سے اس واقعہ میں جھگڑے بعد اس کے کہ تیرے پاس صحیح علم آ چکا ہے تو کہہ دے آؤ ہم اپنے بیٹے اور تمہارے بیٹے اور اپنی عورتیں اور تمہاری عورتیں اور اپنی جانیں اور تمہاری جانیں بلائیں پھر سب التجا کریں اور الله کی لعنت ڈالیں ان پر جو جھوٹے ہوں\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@ccclv{بے شک یہی سچا بیان ہے اور الله کے سوا اور کوئی معبود نہیں اور بے شک الله ہی زبردست حکمت والا ہے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@ccclvi{پھر اگر پھر جائیں تو بے شک الله فساد کرنے والوں کو جانتا ہے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@ccclvii{کہہ اے اہلِ کتاب! ایک بات کی طرف آؤ جو ہمارے اور تمہارے درمیان برابر ہے کہ سوائے الله کے اور کسی کی بندگی نہ کریں اور اس کا کسی کو شریک نہ ٹھیرائیں اور سوائے الله کے کوئی کسی کو رب نہ بنائے پس اگر وہ پھر جائیں تو کہہ دو گواہ رہو کہ ہم تو فرمانبردار ہونے والے ہیں\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@ccclviii{اے اہلِ کتاب! ابراھیم کے معاملہ میں کیوں جھگڑتے ہو حالانکہ تورات اور انجیل تو اس کے بعد اتری ہیں کیا تم یہ نہیں سجحھتے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@ccclix{ہاں! تم وہ لوگ ہو جس چیز کا تمہیں علم تھا اس میں تو جھگڑے پس اس چیز میں کیوں جھگڑتے ہو جس چیز کا تمہیں علم ہی نہیں اور الله جانتا ہے اور تم نہیں جانتے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@ccclx{ابراھیم نہ یہوودی تھے اور نہ نصرانی لیکن سیدھے راستے والے مسلمان تھے اور مشرکوں میں سے نہ تھے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@ccclxi{لوگوں میں سب سے زیادہ قریب ابراھیم کے وہ لوگ تھے جنہوں نے اس کی تابعداری کی اور یہ نبی اور جو اس نبی پر ایمان لائے اور الله ایمان والوں کا دوست ہے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@ccclxii{بعض اہلِ کتاب دل سے چاہتے ہیں کہ کسی طرح تم کو گمراہ کردیں اور گمراہ نہیں کرتے مگر اپنے نفسوں کو اور نہیں سمجتے\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@ccclxiii{اے اہلِ کتاب! الله کی آیتو ں کا کیوں انکار کرتے ہو حالانکہ تم گواہ ہو\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@ccclxiv{اے اہلِ کتاب! سچ میں جھوٹ کیوں ملاتے ہو اور سچی بات کو چھپاتے ہو حالانکہ تم جانتے ہو\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@ccclxv{اور اہل کتاب میں سے ایک جماعت نے کہا جو کچھ مسلمانوں پر اترا ہے اس پر صبح ایمان لاؤ اور شام کو اس سے انکار کر دو شاید کہ وہ پھر جائیں\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@ccclxvi{اوراپنے مذہب والے کے سوا کسی کی بات نہ مانو ان سے کہہ دو کہ بے شک ہدایت وہی ہے جو الله ہدایت کرے اور یہ بات نہ مانو کہ کوئی شخص دیا جا سکتا ہے مثل اس کے کہ تم دیے گئے ہو یا کوئی گروہ خدا کے ہاں تم پر الزام قائم کرسکتا ہے ان سے کہہ دو کہ فضل الله کے اختیار میں ہے جسے چاہے وہ دیتا ہے اور الله کشائش والا جاننے والا ہے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@ccclxvii{جسے چاہے اپنی مہربانی سے خاص کرتا ہے اور الله بڑے فضل والا ہے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@ccclxviii{اور اہل کتاب میں بعض ایسے ہیں کہ اگر تو ان کے پاس ایک ڈھیر مال کا امانت رکھے وہ تجھ کو ادا کریں اور بعضے ان میں سے وہ ہیں اگر تو ان کے پاس ایک اشرفی امانت رکھے تو بھی تجھے واپس نہیں کریں گے ہاں جب تک کہ تو اس کے سر پر کھڑا رہے یا اس واسطے ہے کہ وہ کہتے ہیں ہم پر ان پڑھ لوگوں کا حق لینے میں کوئی گناہ نہیں اور الله پر وہ جھوٹ بولتے ہیں حالانکہ وہ جانتے ہیں\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@ccclxix{گناہ کیوں نہ ہوگا جس شخص نے اپنا عہد پورا کیا اور الله سے ڈرا تو بے شک پرہیزگاروں کو دوست رکھتا ہے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@ccclxx{بے شک جو لوگ الله کے عہد اور اپنی قسمو ں کے بدلے حقیر معاوضہ لیتے ہیں آخرت میں ان کا کوئی حصہ نہیں اور ان سے الله کلام نہیں کرے گا اور قیامت کے دن ان کی طرف نہ دیکھے گا اور انہیں پاک بھی نہ کرے گا اور ان کے لیے دردناک عذاب ہے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@ccclxxi{اوربے شک ان میں سے ایک جماعت ہے کہ کتاب کو زبان مروڑ کر پڑھتے ہیں تاکہ تم یہ خیال کرو کہ وہ کتاب میں سے ہے حالانکہ وہ کتاب میں سے نہیں ہے اوروہ کہتے ہیں کہ الله کے ہاں سے ہے حالانکہ وہ الله کے ہاں سے نہیں ہے اور الله پر جان بوجھ کر جھوٹ بولتے ہیں\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@ccclxxii{کسی انسان کے لیے یہ جائز نہیں ہے کہ الله اسے کتاب اور حکمت اور نبوت عطا فرمائے پھر وہ لوگوں سے یہ کہے کہ الله کو چھوڑ کر میرے بندے ہو جاؤ لیکن کہے گا کہ تم لوگ الله والے بن جاؤ اس لیے کہ تم الله کی کتاب سکھاتے ہو اوراس واسطے کہ تم پڑھتے ہو\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@ccclxxiii{اورنہ یہ جائز ہے کہ تمہیں حکم کرے کہ تم فرشتوں اور نبیوں کو رب بنا لو کیا وہ تمہیں کفر سکھائے گا بعد اس کے کہ تم مسلمان ہو چکے ہو\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@ccclxxiv{اورجب الله نے نبیوں سے عہد لیا اور البتہ جو کچھ میں تمہیں کتاب ابور علم سے دوں پھر تمہارے پاس پیغنبر آئے جو اس چیز کی تصدیق کرنے والا ہو جو تمہارے پاس ہے البتہ اس پر ایمان لے آنا اور البتہ اس کی مدد کرنا فرمایا کیاتم نے اقرار کیا اور اس شرط پر میرا عہد قبول کیا انہوں نے کہا ہم نے اقرار کیا الله نے فرمایا تو اب تم گواہ رہو میں بھی تمہارے ساتھ گواہ ہوں\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@ccclxxv{پھر جو کوئی اس کے بعد پھر جائے تو وہی لوگ نافرمان ہیں\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@ccclxxvi{کیا الله کے دین کے سوا کوئی اور دین تلاش کرتے ہیں حالانکہ جو کوئی آسمان اور زمین میں ہے خوشی سے یا لاچاری سے سب اسی کے تابع ہے اور اسی کی طرف لوٹائے جائیں گے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@ccclxxvii{کہہ دو ہم الله پر ایمان لائے اور جو کچھ ہم پر نازل کیاگیا اور جو کچھ ابراھیم اور اسماعیل اور اسحاق اور یعقوب اور اس کی اولاد پر نازل کیا گیا اور جو کچھ موسیٰ اور عیسیٰ اور سب نبیوں کو ان کے رب کی طرف سے ملا ہم ان میں سے کسی کو جدا نہیں کرتے اور ہم اسی کے فرمانبردار ہیں\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@ccclxxviii{اور جو کوئی اسلام کے سوا اور کوئی دین چاہے تو وہ اس سے ہر گز قبول نہیں کیا جائے گا اور وہ آخرت میں نقصان اٹھانے والوں میں سے ہوگا\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@ccclxxix{الله ایسے لوگوں کو کیونکر راہ دکھائے جو ایمان لانے کے بعد کافر ہوگئے اور گواہی دے چکے ہیں کہ بے شک یہ رسول سچا ہے اور ان کے پاس روشن نشانیاں آئی ہیں اور الله ظالموں کو راہ نہیں دکھاتا\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@ccclxxx{ایسے لوگوں کی یہ سزا ہے کہ ان پر الله اور فرشتوں اور سب لوگو ں کی لعنت ہو\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@ccclxxxi{اس میں ہمیشہ رہنے والے ہوں گے ان سے عذاب ہلکا نہ کیا جائے گا اور نہ وہ مہلت دیے جائیں گے\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@ccclxxxii{مگر جنہوں نے اس کے بعد توبہ کی اور نیک کام کیے تو بے شک الله بخشنے والا مہربان ہے\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@ccclxxxiii{بے شک جو لوگ ایمان لانے کے بعد منکر ہو گئے پھر انکار میں بڑھتے گئے ان کی توبہ ہر گز قبول نہیں کی جائے گی اور وہی گمراہ ہیں\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@ccclxxxiv{بے شک جو لوگ کافر ہوئے اور کفر کی حالت میں مر گئے تو کسی ایسے سے زمین بھر کر سونا بھی قبول نہیں کیا جائے گا اگرچہ وہ اس قدر سونا بدلے میں دے ان لوگوں کے لیے دردناک عذاب ہے اور ان کا کوئی مددگار نہیں ہوگا\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@ccclxxxv{ہر گز نیکی میں کمال حاصل نہ کر سکو گے یہاں تک کہ اپنی پیاری چیز سے کچھ خرچ کرو اور جو چیز تم خرچ کرو گے بے شک الله اسے جاننے والا ہے\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@ccclxxxvi{بنی اسرائیل کے لیے سب کھانے کی چیزیں حلال تھیں مگر وہ چیز جو اسرائیل نے تورات نازل ہونے سے پہلےاپنے اوپر حرام کی تھی کہہ دو تورات لاؤ اور اسے پڑھو اگر تم سچے ہو\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@ccclxxxvii{پھر جس شخص نے اس کے بعد الله پر جھوٹ بنایا وہی بڑے بے انصاف ہیں\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@ccclxxxviii{کہہ دو الله نے سچ فرمایا ہے اب ابراھیم کے دین کے تابع ہو جاؤ جوایک ہی کےہو گئے تھے اور مشرکوں میں سے نہ تھے\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@ccclxxxix{بے شک لوگوں کے واسطے جو سب سے پہلا گھر مقرر ہوا یہی ہے جو مکہ میں برکت والا ہے اور جہان کے لوگوں کے لیے راہ نما ہے\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@cccxc{اس میں ظاہر نشانیاں ہیں مقام ابراھیم ہے اور جو اس میں داخل ہو جائے وہ امن والا ہو جاتا ہے اور لوگوں پر اس گھر کا حج کرنا الله کا حق ہے جو شخص اس تک پہنچنے کی طاقت رکھتا ہو اور جو انکار کرے تو پھر الله جہان والوں سے بے پرواہ ہے\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@cccxci{کہہ دواے اہلِ کتاب الله کیا آیتوں کا کیوں انکار کرتے ہو اور جو کچھ تم کرتے ہو الله اس پر گواہ ہے\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@cccxcii{کہہ دواے اہلِ کتاب الله کی راہ سے کیوں روکتے ہو اس شخص کو جو ایمان لائے اس میں عیب ڈھونڈتے ہو اورتم خود جانتے ہو اور تمہارے کام سے الله بے خبر نہیں ہے\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@cccxciii{اے ایمان والو اگرتم اہلِ کتاب کی کسی جماعت کابھی کہا مانو گےتو وہ تمہیں ایمان لانے کے بعد کافر کر دیں گے\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@cccxciv{اور تم کس طرح کافر ہو گے حالانکہ تم پر الله کی آیتیں پڑھی جاتی ہیں اور اس کا رسول تم میں موجود ہے اور جو شخص الله کو مضبوط پکڑے گا تو اسے ہی سیدھے راستے کی ہدایت کی جائے گی\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@cccxcv{اے ایمان والو الله سے ڈرتے رہو جیسا اس سے ڈرنا چاہیئے اور نہ مرد مگر ایسے حال میں کہ تم مسملمان ہو\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@cccxcvi{اور سب مل کر الله کی رسی مضبوط پکڑو اور پھوٹ نہ ڈالو اور الله کا احسان اپنے اوپر یاد کرو جب کہ تم آپس میں دشمن تھے پھر تمہارے دلوں میں الفت ڈال دی پھر تم اس کے فضل سے بھائی بھائی ہو گئے اور تم آگ کے گڑھے کے کنارے پر تھے پھر تم کو اس سے نجات دی اس طرح تم پر الله اپنی نشانیاں بیان کرتا ہے تاکہ تم ہدایت پاؤ\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@cccxcvii{اور چاہیئے کہ تم میں سے ایک جماعت ایسی ہو جو نیک کام کی طرف بلاتی رہے اوراچھے کاموں کا حکم کرتی رہے اور برے کاموں سے روکتی رہے اور وہی لوگ نجات پانے والے ہیں\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@cccxcviii{ان لوگو ں کی طرح مت ہو جو متفرق ہو گئے بعد اس کے کہ ان کے پاس واضح احکام آئے انہوں نے اختلاف کیا اور ان کے لیے بڑا عذاب ہے\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@cccxcix{جس دن بعضے منہ سفید اور بعضے منہ سیاہ ہوں گے سو وہ جن کے منہ سیاہ ہوں گے ان سے کہا جائے گا کیا تم ایمان لا کر کافر ہو گئے تھے اب اس کفر کرنےکے بدلے میں عذاب چکھو\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@cd{اور وہ لوگ جن کے منہ سفید ہوں گے تو وہ الله کی رحمت میں ہوں گے وہ اس میں ہمیشہ رہیں گے\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@cdi{یہ الله کے احکام ہیں ہم تمہیں ٹھیک ٹھیک سناتے ہیں اور الله مخلوقات پر ظلم نہیں کرنا چاہتا\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@cdii{اور جو کچھ آسمانوں اور جو کچھ زمین میں ہے سب الله ہی کا ہے اور سب کام الله ہی کے طرف پھیرے جاتے ہیں\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@cdiii{تم سب امتوں میں سے بہتر ہو جو لوگوں کے لیے بھیجی گئی ہیں اچھے کاموں کا حکم کرتے رہو اور برے کاموں سے روکتے رہو اور الله پر ایمان لاتے ہو اور اگر اہل کتاب ایمان لے آتے تو ان کے لیے بہتر تھا کچھ ان میں سے ایماندار ہیں اور اکثر ان میں سے نافرمان ہیں\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@cdiv{وہ زبان سے ستانے کے سوا تمہارا اور کچھ بگاڑ نہ سکیں گے اور اگر تم سے لڑیں گے تو پیٹھ پھیر دیں گے پھر مدد نہیں دیے جائیں گے\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@cdv{ان پر ذلت لازم کی گئی ہے جہاں وہ پائے جائیں گے مگر ساتھ الله کی پناہ کے اور لوگو ں کی پناہ کے اور وہ الله کے غضب کے مستحق ہوئے اور ان پر پستی لازم کی گئی یہ اس واسطے ہے کہ الله کی نشانیوں کے ساتھ کفر کرتے تھے اور پیغمبروں کو ناحق قتل کرتے تھے یہ اس سبب سے ہے کہ انہوں نے نافرمانی کی اور حد سے نکل جاتے تھے\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@cdvi{وہ سب برابر نہیں اہل کتاب میں سے ایک فرقہ سیدھی راہ پر ہے وہ رات کے وقت الله کی آیتیں پڑھتے ہیں اور وہ سجدے کرتے ہیں\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@cdvii{الله اور قیامت کے دن پر ایمان لاتے ہیں اور اچھی بات کا حکم کرتے ہیں اور برے کاموں سے روکتے ہیں اور نیک کاموں میں دوڑتے ہیں اور وہی لوگ نیک بخت ہیں\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@cdviii{وہ لوگ جو نیک کام کریں گے اس سے محروم نہ کیے جائیں گے اور الله پرہیزگارو ں کا جاننے والا ہے\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@cdix{بے شک جو لوگ کافر ہیں ان کے مال اور اولاد الله کے مقابلے میں کچھ کام نہ آئیں گے اوروہی لوگ دوزخی ہیں وہ اس آگ میں ہمیشہ رہنے والے ہیں\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@cdx{اس دنیا کی زندگی میں جو کچھ خرچ کرتے ہیں اس کی مثال ایسی ہے جس طرح ایک ہوا ہو جس میں تیز سردی ہو وہ ایسے لوگو ں کی کھیتی کو لگ جائے جنہوں نے اپنے نفسوں پر ظلم کیا تھا پھر ا سکو برباد کر گئی اور الله نے ان پر ظلم نہیں کیا لیکن وہ اپنے او پر ظلم کرتے ہیں\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@cdxi{اے ایمان والو اپنوں کے سوا کسی کو بھیدی نہ بناؤ وہ تمہاری خرابی میں قصور نہیں کرتے جو چیز تمہیں تکلیف دے وہ انہیں پسند آتی ہے ان کے مونہوں سے دشمنی نکل پڑتی ہے اور جو ان کے سینے میں چپھی ہوئي ہے وہ بہت زیادہ ہے ہم نے تمہارے لیے نشانیاں بیان کر دی ہیں اگر تم عقل رکھتے ہو\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@cdxii{سن لو تم ان کے دوست ہو اور وہ تمہارے دوست نہیں اور تم تو سب کتابوں کو مانتے ہو اور جب وہ تم سے ملتے ہیں تو کہتے ہیں کہ ہم مسلمان ہیں اور جب الگ ہوتے ہیں تو تم پر غصہ سے انگلیاں کاٹ کاٹ کھاتے ہیں کہہ دو تم اپنے غصہ میں مرو الله کو دلوں کی باتیں خوب معلوم ہیں\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@cdxiii{اگر تمہیں کوئی بھلائی پہنچے توانہیں بری لگتی ہے اور اگر تمہیں کوئی تکلیف پہنچے تو اس سے خوش ہوتے ہیں اور اگر تم صبر کرو اور پرہیزگاری کرو تو ان کے فریب سے تمہارا کچھ نہ بگڑے گا بے شک الله ان کے اعمال پر احاطہ کرنے والا ہے\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@cdxiv{اور جب تو صبح کو اپنے گھر سے نکلا مسلمانوں کو لڑائی کا ٹھکانے پر بٹھا رہا تھا اور الله سننے والا جاننے والا ہے\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@cdxv{جب تم میں سے دو جماعتوں نے قصد کیا کہ نامردی کریں اور الله ا ن کا مددگار تھا اور چاہیئے کہ الله ہی پر مسلمان بھروسہ کریں\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@cdxvi{اور الله بدر کی لڑائی میں تمہاری مدد کر چکا ہے حالانکہ تم کمزور تھے پس الله سے ڈرو تاکہ تم شکر کرو\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@cdxvii{جب تو مسلمانوں کو کہتا تھا کیا تمہیں یہ کافی نہیں کہ تمہارا رب تمہاری مدد کے لیے تین ہزار فرشتے آسمان سے اترنے والے بھیجے\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@cdxviii{بلکہ اگر تم صبر کرو اور پرہیزگاری کرو اور وہ تم پر ایک دم سے آ پہنچیں تو تمہارا رب پانچ ہزار فرشتے نشان دار گھوڑوں پر مدد کے لیے بھیجے گا\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@cdxix{اوراس چیز کواللہ نے تمہارے دل کی خوشی کے لیے کیا ہے اور تاکہ تمہارے دلوں کو اس سے اطمینان ہو اورمدد تو صرف الله ہی کی طرف سے ہے جو زبردست حکمت والا ہے\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@cdxx{تاکہ بعض کافروں کو ہلاک کرے یا انہیں ذلیل کرے پھر وہ ناکام ہو کر لوٹ جائیں\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@cdxxi{تیرا کوئی اختیار نہیں ہے یا الله انہیں توبہ کی توفیق دے یاانہیں عذاب کرے کیوں کہ وہ ظالم ہیں\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@cdxxii{اور جو کچھ آسمانو ں میں اور جو کچھ زمین میں ہے سب الله ہی کا ہے جسے چاہے بخش دے اور جسے چاہے عذاب کرے اور الله بخشنے والا مہربان ہے\qt@no{(129)}}%
\qt@newcmd\qurantrans@ur@cdxxiii{اے ایمان والو سود دونے پر دونا نہ کھاؤ اور الله سے ڈرو تاکہ تمہارا چھٹکارا ہو\qt@no{(130)}}%
\qt@newcmd\qurantrans@ur@cdxxiv{اوراس آگ سے بچو جو کافروں کے لیے تیار کی گئی ہے\qt@no{(131)}}%
\qt@newcmd\qurantrans@ur@cdxxv{اور الله اور رسول کی تابعداری کرو تاکہ تم پر رحم کیے جاؤ\qt@no{(132)}}%
\qt@newcmd\qurantrans@ur@cdxxvi{اور اپنے رب کی بخشش کی طرف دوڑو اوربہشت کی طرف جس کا عرض آسمان اور زمین ہے جوپرہیزگاروں کے لیے تیار کی گئی ہے\qt@no{(133)}}%
\qt@newcmd\qurantrans@ur@cdxxvii{جو خوشی اور تکلیف میں خرچ کرتے ہیں اور غصہ ضبط کرنے والے ہیں اور لوگوں کو معاف کرنے والے ہیں اور الله نیکی کرنے والوں کو دوست رکھتا ہے\qt@no{(134)}}%
\qt@newcmd\qurantrans@ur@cdxxviii{اور وہ لوگ جب کوئی کھلا گناہ کر بیٹھیں یا اپنے حق میں ظلم کریں تو الله کو یاد کرتے ہیں اور اپنے گناہوں سے بخشش مانگتے ہیں اور سوائے الله کے اور کون گناہ بخشنے والا ہے اور اپنے کیے پر وہ اڑتے نہیں اور وہ جانتے ہیں\qt@no{(135)}}%
\qt@newcmd\qurantrans@ur@cdxxix{یہ لوگ ان کا بدلہ ان کے رب کے ہاں سے بخشش ہے اور باغ ہیں جن کے نیچے نہریں بہتی ہوں گی ان باغوں میں ہمیشہ رہنے والے ہوں گے اور کام کرنے والوں کی کیسی اچھی مزدوری ہے\qt@no{(136)}}%
\qt@newcmd\qurantrans@ur@cdxxx{تم سے پہلے کئی واقعات ہو چکے ہیں سو زمین میں سیر کرو اور دیکھو کہ جھٹلانے والوں کا کیا انجام ہوا\qt@no{(137)}}%
\qt@newcmd\qurantrans@ur@cdxxxi{یہ لوگوں کے واسطے بیان ہے اور ڈرنے والوں کے لیے ہدایت اور نصیحت ہے\qt@no{(138)}}%
\qt@newcmd\qurantrans@ur@cdxxxii{اورسست نہ ہو اور غم نہ کھاؤ اور تم ہی غالب رہو گے\qt@no{(139)}}%
\qt@newcmd\qurantrans@ur@cdxxxiii{اگر تمہیں زخم پہنچا ہےتو انہیں بھی ایسا ہی زخم پہنچ چکا ہے اور ہم یہ دن لوگوں میں باری باری بدلتے رہتے ہیں اور تاکہ الله ایمان والوں کو جان لے اور تم میں سے بعضوں کو شہید کرے اور الله ظالموں کو پسند نہیں کرتا\qt@no{(140)}}%
\qt@newcmd\qurantrans@ur@cdxxxiv{اور تاکہ الله ایمان والوں کو پاک کردے اور کافروں کو مٹا دے\qt@no{(141)}}%
\qt@newcmd\qurantrans@ur@cdxxxv{کیا تم یہ خیال کرتے ہو کہ جنت میں داخل ہو جاؤ گے اور ابھی تک الله نے نہیں ظاہرکیا ان لوگوں کو جو تم میں سے جہاد کرنے والے ہیں اور ابھی صبر کرنے والوں کو بھی ظاہر نہیں کیا\qt@no{(142)}}%
\qt@newcmd\qurantrans@ur@cdxxxvi{اور تم موت سے پہلے اس کی ملاقات کی آرزو کرتے تھے سو اب تم نے اسے آنکھوں کے سامنہ دیکھ لیا\qt@no{(143)}}%
\qt@newcmd\qurantrans@ur@cdxxxvii{اور محمد تو ایک رسول ہے اس سے پہلے بہت رسول گزرے پھرکیا اگر وہ مرجائے یا مارا جائے تو تم الٹے پاؤں پھر جاؤ گے اور جو کوئی الٹے پاؤں پھر جائے گا تو الله کا کچھ بھی نہیں بگاڑے گا اور الله شکر گزاروں کو ثواب دے گا\qt@no{(144)}}%
\qt@newcmd\qurantrans@ur@cdxxxviii{اور الله کے حکم کے سوا کوئی مر نہیں سکتا ایک وقت مقرر لکھا ہوا ہے اور جو شخص دنیا کا بدلہ چاہے گا ہم اسے دنیا ہی میں دے دیں گے اور جو آخرت کا بدلہ چاہے گا ہم اسے دنیاہی میں دے دینگے اور ہم شکر گزاروں کو جزا دیں گے\qt@no{(145)}}%
\qt@newcmd\qurantrans@ur@cdxxxix{اور کئی نبی ہیں جن کے ساتھ ہو کر بہت الله والے لڑے ہیں پھر الله کی راہ میں تکلیف پہنچنے پر نہ ہارے ہیں اور نہ سست ہوئے اور نہ وہ دبے ہیں اور الله ثابت قدم رہنے والوں کو پسند کرتا ہے\qt@no{(146)}}%
\qt@newcmd\qurantrans@ur@cdxl{اور انہوں نے سوائے اس کے کچھ نہیں کہا کہ اے ہمارے رب ہمارے گناہ بخش دے اور جو ہمارے کام میں ہم سے زیادتی ہوئی ہے او رہمارے قدم ثابت رکھ اور کافروں کی قوم پر ہمیں مدد دے\qt@no{(147)}}%
\qt@newcmd\qurantrans@ur@cdxli{پھر الله نے ان کو دنیا کا ثواب اور آخرت کا عمدہ بدلہ دیا اور الله نیک کاموں کو پسند کرتا ہے\qt@no{(148)}}%
\qt@newcmd\qurantrans@ur@cdxlii{اے ایمان والو اگر تم کافروں کا کہا مانو گے تو وہ تمہیں الٹے پاؤں پھیر دیں گے پھر تم نقصان میں جا پڑو گے\qt@no{(149)}}%
\qt@newcmd\qurantrans@ur@cdxliii{بلکہ الله تمہارا مددگار ہے اور وہ بہترین مدد کرنے والا ہے\qt@no{(150)}}%
\qt@newcmd\qurantrans@ur@cdxliv{اب ہم کافروں کے دلوں میں ہیبت ڈال دیں گے اس لیے کہ انہوں نے الله کا شریک ٹھیرایا جس کی اس نے کوئی دلیل نہیں اتاری اور ان کا ٹھکانا دوزخ ہے اور ظالموں کا وہ بہت بڑاٹھکانا ہے\qt@no{(151)}}%
\qt@newcmd\qurantrans@ur@cdxlv{اور الله تو اپنا وعدہ تم سے سچا کر چکا جب تم اس کے حکم سے انہیں قتل کرنے لگے یہاں تک کہ جب تم نے نامردی کی اور کام میں جھگڑا ڈالا اور نافرمانی کی بعد اس کے کہ تم کو دکھا دی وہ چیز جسے تم پسند کرتے تھے بعض تم میں سے دنیا چاہتے تھے اور بعض تم میں سے آخرت کے طالب تھےپھر تمہیں ان سے پھیر دیا تاکہ تمہیں آزمائے اورالبتہ تحقیق تمہیں اس نے معاف کردیا ہے اور اللہ ایمانداروں پر فضل والا ہے\qt@no{(152)}}%
\qt@newcmd\qurantrans@ur@cdxlvi{جس وقت تم چڑھے جاتے تھے اور کسی کو مڑ کر نہ دیکھتے تھے اور رسول تمہیں تمہارےپیچھے سے پکار رہا تھا سو الله نے تمہیں اس کی پاداش میں غم دیا بسبب غم دینے کے تاکہ تم مغموم نہ ہو اس پر جو ہاتھ سے نکل گئی اور نہ اس پر جو تمہیں پیش آئی اور الله خبردار ہے اس چیز سے جو تم کرتے ہو\qt@no{(153)}}%
\qt@newcmd\qurantrans@ur@cdxlvii{پھر الله نے اس غم کے بعد تم پر چین یعنی اونگھ بھیجی اس نے بعضوں کو تم میں سے ڈھانک لیا اور بعضوں کو اپنی جان کا فکر لڑ رہا تھا الله پر جھوٹے خیال جاہلوں جیسے کر رہے تھے کہتے تھے ہمارے ہاتھ میں کچھ کام ہے کہہ دو کہ سب کام الله کے ہاتھ میں ہے وہ اپنے دل میں چھپاتے ہیں جو تیرے سامنے ظاہر نہیں کرتے کہتے ہیں اگر ہمارے ہاتھ میں کچھ کام ہوتا تو ہم اس جگہ مارے نہ جاتے کہہ دو اگر تم اپنے گھروں میں ہوتے البتہ اپنے گرنے کی جگہ پرباہر نکل آتے وہ لوگ جن پر قتل ہونا لکھا جا چکا تھا اور تاکہ الله آزمائے جو تمہارے سینوں میں ہے اور تاکہ اس چیز کو صاف کردے جو تمہارے دلوں میں ہے اور الله دلوں کے بھید جاننے والا ہے\qt@no{(154)}}%
\qt@newcmd\qurantrans@ur@cdxlviii{بے شک وہ لوگ جو تم میں پیٹھ پھیر گئے جس دن دونوں فوجیں ملیں سو شیطان نے ان کے گناہ کے سبب سے انہیں بہکا دیا تھا اور الله نے ان کو معاف کر دیا ہے بے شک الله بخشنے والا تحمل کرنے والا ہے\qt@no{(155)}}%
\qt@newcmd\qurantrans@ur@cdxlix{اے ایمان والو تم ان لوگو ں کی طرح نہ ہو جو کافر ہوئے اور وہ اپنے بھائیوں سے کہتے ہیں جب وہ ملک میں سفر پر نکلیں یا جہاد پر جائیں اگر ہمارے پاس رہتے تو نہ مرتے اور نہ مارے جاتے تاکہ الله اس خیال سے ان کے دلوں میں افسوس ڈالے اور الله ہی جلاتا اور مارتا ہے اور الله تمہارے سب کاموں کو دیکھنے والا ہے\qt@no{(156)}}%
\qt@newcmd\qurantrans@ur@cdl{اور اگر تم الله کی راہ میں مارے گئے یا مر گئے تو الله کی بخشش اور اس کی مہربانی اس چیز سے بہتر ہے جو وہ جمع کرتے ہیں\qt@no{(157)}}%
\qt@newcmd\qurantrans@ur@cdli{اوراگرتم مرگئے یا مارے گئے تو البتہ تم سب الله ہی کے ہاں جمع کیے جاؤ گے\qt@no{(158)}}%
\qt@newcmd\qurantrans@ur@cdlii{پھر الله کی رحمت کے سبب سے تو ان کے لیے نرم ہو گیا اور اگرتو تند خو اور سخت دل ہوتا تو البتہ تیرے گرد سے بھاگ جاتے پس انہیں معاف کردے اور ان کے واسطے بخشش مانگ او رکام میں ان سے مشورہ لیا کر پھر جب تو اس کام کا ارادہ کر چکا تو الله پر بھروسہ کر بے شک الله توکل کرنے والے لوگوں کو پسند کرتا ہے\qt@no{(159)}}%
\qt@newcmd\qurantrans@ur@cdliii{ااگر الله تمہاری مدد کرے گا تو تم پر کوئی غالب نہ ہوسکے گا اور اگر اس نے مدد چھوڑ دی تو پھر ایسا کون ہے جو اس کے بعد تمہاری مدد کر سکے اور مسلمانوں کو الله ہی پر بھروسہ کرنا چاہیے\qt@no{(160)}}%
\qt@newcmd\qurantrans@ur@cdliv{اور کسی نبی کو یہ لائق نہیں کہ خیانت کرے گااور جو کوئی خیانت کرے گا اس چیز کو قیامت کے دن لائے گا جو خیانت کی تھی پھر ہر کوئی پورا پالے گا جو اس نے کمایا تھا اور وہ ظلم نہیں کیے جائیں گے\qt@no{(161)}}%
\qt@newcmd\qurantrans@ur@cdlv{آیا وہ شخص جو الله کی رضا کا تابع ہے اس کے برابر ہو سکتا ہے جو غضب الہیٰ کا مستحق ہوا اور اس کا ٹھکانہ دوزخ ہے اور کیسی وہ بری جگہ ہے\qt@no{(162)}}%
\qt@newcmd\qurantrans@ur@cdlvi{الله کے ہاں لوگوں کے مختلف درجے ہیں اور الله دیکھتا ہے جو کچھ وہ کرتے ہیں\qt@no{(163)}}%
\qt@newcmd\qurantrans@ur@cdlvii{الله نے ایمان والوں پر احسان کیا ہے جو ان میں انہیں میں سے رسول بھیجا ان پر اس کی آیتیں پڑھتا ہے اور انہیں پاک کرتا ہے اور انہیں کتاب اور دانش سکھاتا ہے اگرچہ وہ اس سے پہلے صریح گمراہی میں تھے\qt@no{(164)}}%
\qt@newcmd\qurantrans@ur@cdlviii{کیا جب تمہیں ایک تکلیف پہنچی حالانکہ تم تو اس سے دو چند تکلیف پہنچا چکے ہو تو کہتے ہو یہ کہاں سے آئی کہہ دو یہ تکلیف تمہیں تمہاری طرف سے پہنچی ہے بے شک الله ہر چیز پر قادر ہے\qt@no{(165)}}%
\qt@newcmd\qurantrans@ur@cdlix{اور جو کچھ تمہیں اس دن پیش آیا جس دن دونوں جماعتیں ملیں سو الله کے حکم سے ہوا او رتاکہ الله ایمان دارو ں کو ظاہر کر دے\qt@no{(166)}}%
\qt@newcmd\qurantrans@ur@cdlx{اور تاکہ منافقوں کو ظاہر کر دے اور انہیں کہا گیا تھا کہ آؤ الله کی راہ میں لڑو یا دشمنوں کو دفع کرو تو انہوں نے کہا اگر ہمیں علم ہوتا کہ آج جنگ ہو گی تو ہم ضرور تمہارے ساتھ چلتے وہ اس وقت بہ نسبت ایمان کے کفر سے زیادہ قریب تھے وہ اپنے مونہوں سے وہ باتیں کہتے ہیں جو ان کے دلو ں میں نہیں ہیں اور جو کچھ وہ چھپاتے ہیں الله اس کو خوب جانتا ہے\qt@no{(167)}}%
\qt@newcmd\qurantrans@ur@cdlxi{یہ وہ لوگ ہیں جو اپنے بھائیوں سے کہتے ہیں حالانکہ خود بیٹھ رہے تھے اگر وہ ہماری بات مانتے تو قتل نہ کیے جاتے کہہ دو اگر تم سچے ہو تو اپنی جانوں سے موت کو ہٹا دو\qt@no{(168)}}%
\qt@newcmd\qurantrans@ur@cdlxii{اور جو لوگ الله کی راہ میں مارے گئے ہیں انہیں مردہ نہ سمجھو بلکہ وہ زندہ ہیں اپنے رب کے ہاں سے رزق دیے جاتے ہیں\qt@no{(169)}}%
\qt@newcmd\qurantrans@ur@cdlxiii{الله نے اپنے فضل سے جو انہیں دیا ہے اس پر خوش ہونے والے ہیں اور ان کی طرف سے بھی خوش ہوتے ہیں جو ابھی تک ان کے پیچھے سے ان کے پاس نہیں پہنچے اس لئے کہ نہ ان پر خوف ہے او رنہ وہ غم کھائیں گے\qt@no{(170)}}%
\qt@newcmd\qurantrans@ur@cdlxiv{الله کی نعمت اور فضل سے خوش ہوتے ہیں اوراس بات سے کہ الله ایمانداروں کی مزدوری کو ضائع نہیں کرتا\qt@no{(171)}}%
\qt@newcmd\qurantrans@ur@cdlxv{جن لوگو ں نے الله اور اس کے رسول کا حکم مانا بعد اس کے کہ انہیں زخم پہنچ چکے تھے جو ان میں سے نیک ہیں اور پرہیزگارہوئے ان کے لیے بڑا اجر ہے\qt@no{(172)}}%
\qt@newcmd\qurantrans@ur@cdlxvi{جنہیں لوگوں نے کہا کہ مکہ والوں نے تمہارے مقابلے کے لیے سامان جمع کیا ہے سوتم ان سے ڈرو تو ان کا ایمان اور زیادہ ہوا اور کہا کہ ہمیں الله کافی ہے اور وہ بہترین کارساز ہے\qt@no{(173)}}%
\qt@newcmd\qurantrans@ur@cdlxvii{پھر مسلمان الله کی نعمت اور فضل کے ساتھ لوٹ آئے انہیں کوئی تکلیف نہ پہنچی اور الله کی مرضی کے تابع ہوئے اور الله بڑے فضل والا ہے\qt@no{(174)}}%
\qt@newcmd\qurantrans@ur@cdlxviii{سویہ شیطان ہے کہ اپنے دوستوں سے ڈراتا ہے پس تم ان سے مت ڈرو اورمجھ سے ڈرو اگر تم ایمان دار ہو\qt@no{(175)}}%
\qt@newcmd\qurantrans@ur@cdlxix{اور وہ لوگ آپ ے غم میں نہ ڈال دیں جو کفر کی طرف دوڑتے ہیں وہ الله کا کچھ نہیں بگاڑیں گے الله ارادہ کرتا ہے کہ آخرت میں انہیں کوئی حصہ نہ دے اوران کے لیے بڑا عذاب ہے\qt@no{(176)}}%
\qt@newcmd\qurantrans@ur@cdlxx{جنہوں نے ایمان کے بدلے کفر خرید لیا وہ الله کا کچھ نہیں بگاڑیں گے اور ان کے لیے دردناک عذاب ہے\qt@no{(177)}}%
\qt@newcmd\qurantrans@ur@cdlxxi{اور کافر یہ نہ سمجھیں کہ ہم جو انہیں مہلت دیتے ہیں یہ ان کے حق میں بھلائی ہے ہم انہیں مہلت اس لیے دیتے ہیں کہ وہ گناہ میں زیادتی کریں اور ان کے لیے خوار کرنے والا عذاب ہے\qt@no{(178)}}%
\qt@newcmd\qurantrans@ur@cdlxxii{الله مسلمانوں کو اس حالت پر رکھنا نہیں چاہتا جس پر اب تم ہو جب تک کہ ناپاک کو پاک سے جدا نہ کر دے اورالله کا یہ طریقہ نہیں ہے کہ تمہیں غیب پر مطلع کر دے لیکن الله اپنے رسولوں میں جسے چاہے چن لیتا ہے سو تم الله اور اس کے رسول پر ایمان لاؤ اور پرہیزگاری کرو تو تمہارے لیے بہت بڑا اجر ہے\qt@no{(179)}}%
\qt@newcmd\qurantrans@ur@cdlxxiii{اور جو لوگ اس چیز پر بخل کرتے ہیں جو الله نے ان کو اپنے فضل سے دی ہے وہ یہ خیال نہ کریں کہ بخل ان کے حق میں بہتر ہے بلکہ یہ ان کے حق میں براہے قیامت کے دن وہ مال طوق بناا کر ان کے گلوں میں ڈالا جائے گا جس میں وہ بخل کرتے تھے اور الله ہی آسمانوں اور زمین کا وارث ہے اور جو کچھ تم کرتے ہو الله اسے جانتا ہے\qt@no{(180)}}%
\qt@newcmd\qurantrans@ur@cdlxxiv{بے شک الله نے ان کی بات سنی ہے جنہوں نے کہا کہ بے شک الله فقیر ہے اور ہم دولت مند ہیں اب ہم ان کی بات لکھ رکھیں گے اور جو انہوں نے انبیاء کے ناحق خون کیے ہیں اور کہیں گے کہ جلتی آگ کا عذاب چکھو\qt@no{(181)}}%
\qt@newcmd\qurantrans@ur@cdlxxv{یہ اس چیز کے بدلےہے جو تمہارے ہاتھوں نے آگے بھیجا اور الله بندوں پر ظلم نہیں کرتا\qt@no{(182)}}%
\qt@newcmd\qurantrans@ur@cdlxxvi{وہ لوگ جو کہتے ہیں کہ الله نے ہمیں حکم فرمایا تھا کہ ہم کسی پیغمبر پر ایمان نہ لائیں یہاں تک کہ وہ ہمارے پاس قربانی لائے کہ اسے آگ کھا جائے کہہ دو مجھ سے پہلے کتنے رسول نشانیاں لے کر تمہارے پاس آئے اور یہ نشانی بھی جو تم کہتے ہو پھر انہیں تم نے کیوں قتل کیا اگر تم سچے ہو\qt@no{(183)}}%
\qt@newcmd\qurantrans@ur@cdlxxvii{پھر اگر یہ تجھے جھٹلائیں تو تجھ سے پہلے بہت سے رسول جھٹلائے گئے جو نشانیاں اور صحیفے اور روشن کتاب لائے\qt@no{(184)}}%
\qt@newcmd\qurantrans@ur@cdlxxviii{ہر جان موت کا مزہ چکھنے والی ہے اور تمہیں قیامت کے دن پورے پورے بدلے ملیں گے پھر جو کوئی دوزخ سے دور رکھا گیا اور بہشت میں داخل کیا گیا سو وہ پورا کامیاب ہوا اور دنیا کی زندگی سوائے دھوکے کی پونجی کے اور کچھ نہیں\qt@no{(185)}}%
\qt@newcmd\qurantrans@ur@cdlxxix{البتہ تم اپنے مالوں اور جانوں میں آزمائے جاؤ گے اور البتہ پہلی کتاب والوں اور مشرکوں سے تم بہت بدگوئی سنو گے اور اگر تم نے صبر کیا اور پرہیزگاری کی تو یہ ہمت کے کاموں میں سے ہے\qt@no{(186)}}%
\qt@newcmd\qurantrans@ur@cdlxxx{اور جب الله نے اہلِ کتاب سے یہ عہد لیا کہ اسے لوگوں سے ضرور بیان کرو گے اورنہ چھپاؤ گے انہوں نے وہ عہد اپنی پیٹھ کے پیچھے پھینک دیا اور اس کے بدلے میں تھوڑا سا مول خرید کیا سو کیا ہی برا ہے جو وہ خریدتے ہیں\qt@no{(187)}}%
\qt@newcmd\qurantrans@ur@cdlxxxi{مت گمان کر ان لوگوں کو جو خوش ہوتے ہیں جو کرتے ہیں اور چاہتے ہیں کہ اس چیز کے ساتھ تعریف کیے جائیں جو انہوں نے کی پس ہر گز تو انہیں عذاب سے خلاصی پانے والا خیال نہ کر اور ان کے لیے دردناک عذاب ہے\qt@no{(188)}}%
\qt@newcmd\qurantrans@ur@cdlxxxii{اور آسمانوں اور زمین کی بادشاہی الله ہی کے واسطے ہے اور الله ہر چیز پر قادر ہے\qt@no{(189)}}%
\qt@newcmd\qurantrans@ur@cdlxxxiii{بے شک آسمان اور زمین کے بنانے اور رات اور دن کے آنے جانے میں البتہ عقلمندوں کے لیے نشانیاں ہیں\qt@no{(190)}}%
\qt@newcmd\qurantrans@ur@cdlxxxiv{وہ جو الله کو کھڑے اور بیٹھے اور کروٹ پر لیٹے یاد کرتے ہیں اور آسمان اور زمین کی پیدائش میں فکر کرتے ہیں (کہتے ہیں) اے ہمارے رب تو نے یہ بےفائدہ نہیں بنایا توسب عیبوں سے پاک ہے سو ہمیں دوزح کے عذاب سے بچا\qt@no{(191)}}%
\qt@newcmd\qurantrans@ur@cdlxxxv{اے رب ہمارے جسے تو نے دوزخ میں داخل کیا سو تو نے اے رسوا کیا اور ظالموں کا کوئی مددگار نہیں ہوگا\qt@no{(192)}}%
\qt@newcmd\qurantrans@ur@cdlxxxvi{ہم نے ایک پکارنے والے سے سنا جو ایمان لانے کو پکارتا تھا کہ اپنے رب پر ایمان لاؤ سو ہم ایمان لائے اے رب ہمارے اب ہمارے گناہ بخش دے اور ہم سے ہمارا برائیاں دو رکردے اور ہمیں نیک لوگو ں کے ساتھ موت دے\qt@no{(193)}}%
\qt@newcmd\qurantrans@ur@cdlxxxvii{اے رب ہمارے او رہمیں دے جو تو نےہم سے اپنے رسولوں کے ذریعے سے وعدہ کیا ہے اور ہمیں قیامت کے دن رسوا نہ کر بے شک تو وعدہ کے خلاف نہیں کرتا\qt@no{(194)}}%
\qt@newcmd\qurantrans@ur@cdlxxxviii{پھر ان کے رب نے ان کی دعا قبول کی کہ میں تم میں سے کسی کام کرنے والے کا کام ضائع نہیں کرتا خواہ مرد ہو یا عورت تم آپس میں ایک دوسرے کے جز ہو پھر جن لوگوں نے وطن چھوڑا اور اپنے گھروں سے نکالے گئے اور میری راہ میں ستائے گئے او رلڑے اور مارے گئے البتہ میں ان سے ان کی برائیاں دور کروں گا اور انہیں باغوں میں داخل کروں گا جن کے نیچے نہریں بہتی ہوں گی یہ الله کے ہاں سے بدلہ ہے\qt@no{(195)}}%
\qt@newcmd\qurantrans@ur@cdlxxxix{تجھ کو کافروں کا شہرو ں میں چلنا پھرنا دھوکہ نہ دے\qt@no{(196)}}%
\qt@newcmd\qurantrans@ur@cdxc{یہ تھوڑا سا فائدہ ہے پھر ان کا ٹھکانا دوزخ ہے اوروہ بہت برا ٹھکاناہے\qt@no{(197)}}%
\qt@newcmd\qurantrans@ur@cdxci{ے لیکن جو لوگ اپنے رب سے ڈرتے رہے ان کے لیے باغ ہیں جن کے نیچے نہریں بہتی ہیں ان میں وہ ہمیشہ رہیں گے یہ الله کے ہاں مہمانی ہے اور جو الله کے ہاں ہے وہ نیک بندوں کے لیے بدرجہا بہتر ہے\qt@no{(198)}}%
\qt@newcmd\qurantrans@ur@cdxcii{اور اہل کتاب میں بعض ایسے بھی ہیں جو الله پر ایمان لاتے ہیں اور جو چیز تمہاری طرف نازل کی گئی اور جو ان کی طرف نازل کی گئی الله کے سامنے عاجزی کرنے والے ہیں الله کی آیتوں پر تھوڑا مول نہیں لیتے یہی ہیں جن کے لیے ان کے رب کے ہاں مزدوری ہے بے شک الله جلد حساب لینے والا ہے\qt@no{(199)}}%
\qt@newcmd\qurantrans@ur@cdxciii{اے ایمان والو صبر کرو اور مقابلہ کے وقت مضبوط رہو اور لگے رہو اور الله سے ڈرتے رہو تاکہ تم نجات پاؤ\qt@no{(200)}}%
\qt@newcmd\qurantrans@ur@cdxciv{\basmalahur اے لوگو اپنے رب سے ڈرو جس نے تمہیں ایک جان سے پیدا کیا اور اسی جان سے اس کا جوڑا بنایا اور ان دونوں سے بہت سے مرد اور عورتیں پھیلائیں اس اللہ سے ڈرو جس کا واسطہ دے کر تم ایک دوسرے اپنا حق مانگتے ہو اور رشتہ داری کے تعلقات کو بگاڑنے سے بچو بے شک الله تم پر نگرانی کر رہا ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@cdxcv{اوریتیموں کوان کے مال دے دو اور ناپاک کو پاک سے نہ بدلو اور ان کے مال اپنے مال کے ساتھ ملا کر نہ کھا جاؤ یہ بڑا گناہ ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@cdxcvi{اور اگر تم یتیم لڑکیوں سے بے انصافی کرنے سے ڈرتے ہوتوجوعورتیں تمہیں پسند آئیں ان میں سے دو دو تین تین چار چار سے نکاح کر لو اگر تمہیں خطرہ ہو کہ انصاف نہ کر سکو گے تو پھر ایک ہی سے نکاح کرو جو لونڈی تمہارے ملک میں ہو وہی سہی یہ طریقہ بے انصافی سے بچنے کے لیے زیادہ قریب ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@cdxcvii{اور عورتوں کو ان کے مہر خوشی سے دے دو پھر اگر وہ اس میں سے اپنی خوشی سے تمہیں کچھ معاف کر دیں تو تم اسے مزہ دار خوشگوار سمجھ کر کھاؤ\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@cdxcviii{اور اپنے وہ مال جنہیں الله نے تمہاری زندگی کے قیام کا ذریعہ بنایا ہے بے سمجھو کے حوالے نہ کرو البتہ انہیں ان مالوں سے کھلاتے او رپہناتے رہو اور انہیں نصیحت کی بات کہتے رہو\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@cdxcix{اور یتیموں کی آزمائش کرتے رہو یہاں تک کہ وہ نکاح کی عمر کو پہنچ جائیں پھر اگر ان میں ہوشیاری دیکھو تو ان کے مال ان کے حوالے کر دو اور انصاف کی حد سے تجاوز کر کے یتیموں کا مال نہ کھا جاؤ اور ان کے بڑے ہونے کے ڈر سے ان کا مال جلدی نہ کھاؤ اور جسے ضرورت نہ ہو تو وہ یتیم کے مال سے بچے او رجو حاجت مند ہو تو مناسب مقدار کھالے پھر جب ان کے مال ان کے حوالے کر و تو اس پر گواہ بنا لو اور حساب لینے کے لیے الله کافی ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@d{مردوں کا اس مال میں حصہ ہے جو ماں باپ اور رشتہ داروں نے چھوڑا ہو اور عورتوں کا بھی اس مال میں حصہ ہے جو ماں باپ اور رشتہ دارو ں نے چھوڑا ہو تھوڑا ہو یہ بہت یہ حصہ مقرر ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@di{اور جب تقسیم کے وقت رشتہ دار اور یتیم اور مسکین آئيں تو اس مال میں سے کچھ انہیں بھی دے دو اور ان کو معقول بات کہہ دو\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@dii{اور ایسے لوگو ں کو ڈرنا چاہيے اگر اپنے بعد چھوٹے چھوٹے بچے چھوڑ جائیں جن کی انہیں فکر ہو ان لوگو ں کو چاہیئے کہ خدا سے ڈریں اور سیدھی بات کہیں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@diii{بے شک جو لوگ یتیموں کا مال ناحق کھاتے ہیں وہ اپنے پیٹ آگ سے بھرتے ہیں اور عنقریب آگ میں داخل ہوں گے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@div{الله تعالیٰ تمہاری اولاد کے حق میں تمہیں حکم دیتا ہے کہ ایک مرد کا حصہ دوعورتوں کے برابر ہے پھر اگر دو سے زاید لڑکیاں ہوں تو ا ن کے لیے دو تہائی اس مال میں سے ہے جو میت نے چھوڑا اور اگر ایک ہی لڑکی ہو تو اس کے لیے آدھا ہے اور اگر میت کی اولاد ہے تو اس کے والدین میں سے ہر ایک کو کل مال کا چھٹا حصہ ملنا چاہیئے اور اگر اس کی کوئی اولاد نہیں اور ماں باپ ہی اس کے وارث ہیں تو اس کی ماں کا ایک تہائی حصہ ہے پھر اگر میت کے بھائی بہن بھی ہوں تو اس کی ماں کا چھٹا حصہ ہے (یہ حصہ اس) وصیت کے بعد ہوگا جو وہ کر گیا تھا اور بعد ادا کرنے قرض کے تم نہیں جانتے تمہارے باپوں اور تمہارے بیٹوں میں سے کون تمہیں زیادہ نفع پہنچانے والا ہے الله کی طرف سے یہ حصہ مقرر کیا ہوا ہے بے شک الله خبردار حکمت والا ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@dv{جو مال تمہارحی عورتیں چھوڑ مریں اس میں تمہارا آدھا حصہ ہے بشرطیکہ ان کی اولاد نہ ہو او راگر ان کی اولاد ہو تو اس میں سےجو چھوڑ جائیں ایک چوتھائي تمہاری ہے اس وصیت کے بعد جو وہ کر جائیں یا قرض کے بعد اور عورتوں کے لیے چوتھائی مال ہے جو تم چھوڑ کر مرو بشرطیکہ تمہاری اولاد نہ ہوپس اگر تمہاری اولاد ہو تو جو تم نے چھوڑا اس میں ان کا آٹھواں حصہ ہے اس وصیت کے بعد جو تم کر جاؤ یا قرض کے بعد اوراگر وہ مرد یا عورت جس کی یہ میراث ہے باپ بیٹا کچھ نہیں رکھتا اور اس میت کا ایک بھائي یا بہن ہے تو دونوں میں سے ہر ایک کا چھٹا حصہ ہے پس اگر اس سے زیادہ ہوں تو ایک تہائی میں سب شریک ہیں وصیت کی بات جوہو چکی ہو یا قرض کے بعد بشرطیکہ اورروں کا نقصان نہ ہو یہ الله کا حکم ہے اور الله جاننے والا تحمل کرنے والا ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@dvi{یہ الله کی باندھی ہوئی حدیں ہیں اور جو شخص الله اور اس کے رسول کے حکم پر چلے اسے بہشتوں میں داخل کرے گا جن کے نیچے نہریں بہتی ہوں گی ان میں ہمیشہ رہیں گے اور یہی ہے بڑی کامیابی\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@dvii{اور جو شخص الله اور اس کے رسول کی نافرمانی کرے اوراس کی حدوں سے نکل جائے اسے آگ میں ڈالے گا اس میں ہمیشہ رہے گا اور اس کے لیے ذلت کا عذاب ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@dviii{اور تمہاری عورتوں میں سے جوکوئی بدکاری کرے ان پر اپنوں میں سے چار مرد گواہ لاؤ پھر اگر وہ گواہی دے دیں تو ان عورتوں کو ان گھروں میں بند رکھو یہاں تک کہ انہیں موت آ جائے یا الله ان کے لیے کوئی راستہ نکال دے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@dix{اور تم میں سے جو دو مرد وہی بدکاری کریں تو ان کو تکلیف دو پھر اگر وہ توبہ کریں اور اپنی اصلاح کرلیں تو انہیں چھوڑ دو بےشک الله توبہ قبول کرنے والا مہربان ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@dx{الله پر توبہ قبول کرنے کا حق انہیں لوگو ں کے لیے ہے جو جہالت کی وجہ سے برا کام کرتے ہیں اس کے بعد جلد ہی توبہ کر لیتے ہیں ان لوگو ں کو الله معاف کر دیتا ہے اور الله سب کچھ جاننے والا دانا ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@dxi{اور ان لوگوں کی توبہ قبول نہیں ہے جو برے کام کرتےرہتے ہیں یہاں تک کہ جب ان میں سے کسی کی موت کا وقت آ جاتا ہے اس وقت کہتا ہے کہ اب میں توبہ کرتا ہوں اوراسی طرح ان لوگو ں کی توبہ قبول نہیں ہے جو کفر کی حالت میں مرتے ہیں ان کے لیے ہم نے دردناک عذاب تیار کیا ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@dxii{اے ایمان والو! تمہیں یہ حلال نہیں کہ زبردستی عورتوں کو میراث میں لے لو اور ان کو اس واسطے نہ روکے رکھو کہ ان سے کچھ اپنا دیا ہوا مال واپس لے لو ہاں اگر وہ کسی صریح بدچلنی کا ارتکاب کریں اور عورتوں کے ساتھ اچھی طرح سے زندگی بسر کرو اگر وہ تمہیں نا پسند ہوں تو ممکن ہے کہ تمہیں ایک چیز پسند نہ آئے مگر الله نے اس میں بہت کچھ بھلائی رکھی ہو\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@dxiii{اور اگر تم ایک عورت کی جگہ دوسری عورت کو بدلنا چاہو اور ایک کو بہت سا مال دے چکے ہو تو اس میں سے کچھ بھی واپس نہ لو کیا تم اسے بہتان لگا کر اور صریح ظلم کر کے واپس لو گے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@dxiv{تم اسے کیوں کر لے سکتے ہو جب کہ تم میں سے ہر ایک دوسرے سے لطف اندوز ہو چکا ہے اور وہ عورتیں تم سے پختہ عہد لے چکی ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@dxv{ان عورتوں سے نکاح نہ کرو جن سے تمہارے ماں باپ نکاح کر چکے ہیں مگر جو پہلے ہو چکا بے حیائی ہے اور غضب کا کام ہے اور برا چلن ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@dxvi{تم پر تمہاری مائیں اور بیٹیاں اور بہنیں اور پھوپھیاں اور خالائیں اور بھتیجیاں اور بھانجیاں اور جن ماؤں نے تمہیں دودھ پلایا اور تمہاری دودھ شریک بہنیں اور تمہاری عورتوں کی مائیں اور ان کی بیٹیاں جنہوں نے تمہاری گود میں پرورش پائی ہے ان بیویو ں کی لڑکیاں جن سے تمہار تعلق زن و شو ہو چکاہے اور اگر تعلق زن و شو نہ ہوا ہو تو تم پر اس نکاح میں کچھ گناہ نہیں اور تمہارے بیٹو ں کی عورتیں جو تمہاری پشت سے ہیں یہ سب عورتیں تم پر حرام ہیں اور دو بہنوں کو (ایک نکاح میں) اکھٹا کرنا حرام ہے مگر جو پہلے ہو چکا بے شک الله بخشنے والا مہربان ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@dxvii{اور خاوند والی عورتیں مگر تمہارے ہاتھ جن کے مالک ہو جائیں یہ الله کا قانون تم پر لازم ہے اور ان کے سوا تم پرسب عورتیں حلال ہیں بشرطیکہ انہیں اپنے مال کے بدلے میں طلب کرو ایسے حال میں کہ نکاح کرنے والے ہو نہ یہ کہ آزاد شہوت رانی کرنے لگو پھر ان عورتوں میں سے جسے تم کام میں لائے ہو تو ان کے حق جو مقرر ہوئے ہیں وہ انہیں دے دو البتہ مہر کے مقرر ہو جانے کے بعد آپس کی رضا مندی سے باہمی کوئی سمجھوتہ ہو جائے تو اس میں کوئی گناہ نہیں بے شک الله خبردار حکمت والا ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@dxviii{اور جو کوئی تم میں سے اس بات کی طاقت نہ رکھے کہ خاندانی مسلمان عورتیں نکاح میں لائے تو تمہاری ان لونڈیو ں میں سے کسی سے نکاح کر لے جو تمہارے قبضے میں ہوں اور ایماندار بھی ہوں اور الله تمہارے ایمانو ں کا حال خوب جانتا ہے تم آپس میں ایک ہو لہذا ان کے مالکوں کی اجازت سے ان سے نکاح کر لو اور دستور کے موافق ان کے مہر دے دو در آنحالیکہ نکاح میں آنے والیاں ہو ں آزاد شہوت رانیاں کرنے والیاں نہ ہوں اور نہ چھپی یاری کرنے والیاں پھر جب وہ قید نکاح میں آجائیں پھر اگر بے حیائی کا کام کریں تو ان پرآدھی سزاہے جو خاندانی عورتوں پر مقرر کی گئی ہے یہ سہولت اس کیلئے ہے جوکوئی تم سے تکلیف میں پڑنے سے دڑےاور صبر کروتو تمہارےحق میں بہتر ہے اور اللہ بخشنے والا مہربان ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@dxix{الله چاہتا ہے کہ تمہارے واسطے بیان کرے اور تمہیں پہلوں کی راہ پر چلائے اور تمہاری توبہ قبول کرے اور الله جاننے والا حکمت والا ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@dxx{اور الله چاہتا ہے کہ تم پر اپنی رحمت سے متوجہ ہو اور جو لوگ اپنے مزوں کے پیچھے لگے ہوئے ہیں وہ چاہتے ہیں کہ تم راہ راست سے بہت دور ہٹ جاؤ\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@dxxi{اللہ چاہتا ہے کہ تم سے بوجھ ہلکا کر دے کیوں کہ انسان کمزور پیدا کیا گیا ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@dxxii{اے ایمان والو! آپس میں ایک دوسرے کے مال نا حق نہ کھاؤ مگر یہ کہ آپس کی خوشی سے تجارت ہو اور آپس میں کسی کو قتل نہ کرو بے شک اللہ تم پر مہربان ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@dxxiii{اور جو شخص تعدّی اور ظلم سے یہ کام کرے گا تو ہم اسے آگ میں ڈالیں گے اور یہ اللہ پر آسان ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@dxxiv{اگر تم ان بڑے گناہوں سے بچو گے جن سے تمہیں منع کیا گیا تو ہم تم سے تمہارے چھوٹے گناہ معاف کردیں گے اور تمہیں عزت کے مقام میں داخل کریں گے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@dxxv{اور مت ہوس کرو اس فضیلت میں جو الله نے بعض کو بعض پر دی ہے مردوں کو اپنی کمائی سے حصہ ہے اور عورتوں کو اپنی کمائی سے حصہ ہے اور اللہ سے اس کا فضل مانگو بے شک اللہ کو ہر چیز کا علم ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@dxxvi{اور ہر شخص کے ہم نے وارث مقرر کر دیئے ہیں اس مال کے جو ماں باپ یا رشتہ دار چھوڑ کر مریں اور وہ لوگ جن سے تمہارے عہد و پیمان ہوں تو انہیں ان کا حصہ دے دو بے شک الله ہر چیز پر گواہ ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@dxxvii{مرد عورتوں پر حاکم ہیں اس واسطے کہ الله نے ایک کو ایک پر فضیلت دی ہے اور اس واسطے کہ انہوں نے اپنے مال خرچ کیے ہیں پھر جو عورتیں نیک ہیں وہ تابعدار ہیں مردوں کے پیٹھ پیچھے الله کی نگرانی میں (ان کے حقوق کی) حفاظت کرتی ہیں اور جن عورتو ں سےتمہیں سرکشی کا خطرہ ہو تو انہیں سمجھاؤ اور سونے میں جدا کر دو اور مارو پھر اگر تمہارا کہا مان جائیں تو ان پر الزام لگانے کے لیے بہانے مت تلاش کرو بے شک الله سب سے اوپر بڑا ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@dxxviii{اور اگر تمہیں کہیں میاں بیوی کے تعلقات بگڑ جانے کا خطرہ ہو تو ایک منصف مرد کے خاندان میں سے اور ایک منصف عورت کے خاندان میں سے مقرر کرو اگر یہ دونوں صلح کرنا چاہیں گے تو الله ان دونو ں میں موافقت کر دے گا بے شک الله سب کچھ جاننے والا خبردار ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@dxxix{اور الله کی بندگی کرو اورکسی کو اس کا شریک نہ کرو اور ماں باپ کے ساتھ نیکی کرو اور رشتہ داروں اور یتیموں اور مسکینوں اور قریبی ہمسایہ اور اجنبی ہمسایہ اورپاس بیٹھنے والے او رمسافر او راپنے غلاموں کے ساتھ بھی نیکی کرو بے شک الله اترانے والے بڑائی کرنے والے کو پسند نہیں کرتا\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@dxxx{جو لوگ بخل کرتے ہیں اور لوگو ں کو بخل سکھاتے ہیں اور الله نے انہیں اپنے فضل سے جو دیا ہے اسے چھپاتے ہیں اور ہم نے کافروں کے لیے ذلت کا عذاب تیار کر رکھا ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@dxxxi{اور جو لوگ اپنے مالوں کو لوگوں کے دکھانے میں خرچ کرتے ہیں اور اللہ پر اور قیامت کے دن پر ایمان نہیں لاتے اور جس کا شیطان ساتھی ہوا تو وہ بہت برا ساتھی ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@dxxxii{اور اگر یہ الله اور قیامت کے دن پر ایمان لے آتے اور الله کے دیے ہوئے مال میں سے خرچ کرتے تو ان کا کیا نقصان تھا اور الله انہیں خوب جانتا ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@dxxxiii{بے شک الله کسی کا ایک ذرہ برابر بھی حق نہیں رکھتا اور اگر نیکی ہو تو اس کو دگنا کر دیتا ہے اور اپنے ہاں سے بڑا ثواب دیتا ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@dxxxiv{پھر کیا حال ہوگا جب ہم ہر امت میں سے گواہ بلائینگے اور تمیں ان پر گواہ کر کے لائیں گے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@dxxxv{جن لوگو ں نے کفر کیا تھا اور رسول کی نافرمانی کی تھی وہ اس دن کی آرزو کریں گے کہ زمین کے برابر ہو جائیں اور الله سے کوئی بات نہ چھپا سکیں گے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@dxxxvi{اے ایمان والو! جس وقت کہ تم نشہ میں ہو نماز کے نزدیک نہ جاؤ یہاں تک کہ تم سمجھو سکوکہ تم کیا کہہ رہے ہو اور جنبی ہونے کی حالت میں مگر راستہ گزرتے ہوئے یہاں تک کہ غسل کر لو اور اگر تم بیمار ہو یا سفر میں ہو یا کوئی شخص تم میں سے رفع حاجت کر کے آئے یا عورتوں کے پاس گئے ہو پھر تمہیں پانی نہ ملے تو پاک مٹی سے کام لو اور اسے اپنے مونہوں پر اور ہاتھوں پر ملو بے شک الله معاف کرنے والا بخشنے والا ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@dxxxvii{کیا تم نے ان لوگوں کو نہیں دیکھا جنہیں کچھ حصہ کتاب سے ملا ہے وہ گمراہی خریدتے ہیں اور چاہتے ہیں کہ تم بھی راستہ گم کر دو\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@dxxxviii{اور الله تمہارے دشمنوں کو خوب جانتا ہے اور تمہاری حمایت اور مدد کے لیے الله ہی کافی ہے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@dxxxix{یہودیوں میں بعض ایسے ہیں جو الفاظ کو ان کے محل سے پھیر دیتے ہیں او ر کہتے ہیں ہم نے سنا اور نہ مانا او رکہتے ہیں کہ سن نہ سنایا جائے تو اور کہتے ہیں راعِنا اپنی زبان کو مروڑ کر اور دین میں طعن کرنے کے خیال سےاور اگر وہ کہتے ہیں کہ ہم نے سنا اور ہمنے مانا اور سن تو اور ہم پر نظر کو تو ان کے حق میں بہتر اور درست ہوتا لیکن ان کے کفر کے سبب سے الله نے ا ن پر لعنت کی سو ان میں سے بہت کم لوگ ایمان لائیں گے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@dxl{اے کتاب والو اس پر ایمان لے آؤ جو ہم نے نازل کیا ہے اس کتاب کی تصدیق کرتا ہے جو تمہارے پاس ہے اس سے پہلے کہ ہم بہت سے چہرو ں کو مٹا ڈالیں پھر انہیں پیٹھ کیطرف الٹ دیں یا ان پر لعنت کریں جسطرح ہم نے ہفتے کے دن والوں پر لعنت کی تھی اور الله کا حکم تو نافذ ہو کر ہی رہتا ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@dxli{بے شک الله اسے نہیں بخشتا جو اس کا شریک کرے اور شرک کے ماسوا دوسرےگناہ جسے چاہے بخشتا ہے اور جس نے الله کا شریک ٹھیرایا اس نے بڑا ہی گناہ کیا\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@dxlii{کیا تم نے ان لوگو ں کو نہیں دیکھا جو اپنی پاکیزگی کا دم بھرتے ہیں بلکہ الله جسے چاہے پاک کرتا ہے اور ان پر تاگے کے برابر بھی ظلم نہ ہوگا\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@dxliii{دیکھو یہ لوگ الله پر کیسا جھوٹ باندھتے ہیں یہی ایک صریح گنا ہ کافی ہے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@dxliv{کیا تم نے ان لوگوں کو نہیں دیکھا جنہیں کتاب کا کچھ حصہ دیا گیا وہ بتوں اور شیطانوں کو مانتے ہیں اور کافروں سے یہ کہتے ہیں کہ یہ لوگ مسلمانوں سے زیادہ راہِ راست پر ہیں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@dxlv{یہی وہ لوگ ہیں جن پر الله کی لعنت ہے اور جس پر الله لعنت کرے تو اس کا کوئي مددگار نہیں پائے گا\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@dxlvi{کیا سلطنت میں ان کا بھی کچھ حصہ ہے پھر تو یہ لوگوں کو ایک تِل بھر بھی نہیں دیں گے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@dxlvii{یا لوگو ں پر حسد کرتے ہیں جو الله نے ان کو اپنے فضل سے دیا ہے ہم نے تو ابراھیم کی اولاد کو کتاب اور حکمت ادا کی ہے اور ان کوہم نے بڑی بادشاہی دی ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@dxlviii{پھران میں سے کوئی اس پر ایمان لایا اورکوئی اس سے ہٹ گیا اور دوزخ کی بھڑکتی ہوئی آگ کافی ہے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@dxlix{بے شک جن لوگو ں نے ہماری آیتوں کا انکار کیا انہیں ہم آگ میں ڈال دیں گے جس وقت ان کی کھالیں جل جائیں گی تو ہم انکو اور کھالیں بدل دیں گے تاکہ عذاب چکھتے رہیں بے شک الله زبردست حکمت والا ہے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@dl{او رجو لوگ ایمان لائے اور نیک کام کیے انہیں ہم ایسے باغوں میں داخل کریں گے جن کے نیچے نہریں بہتی ہوں گی ان میں ہمیشہ ہمیشہ رہنے والے ہوں گے ان کے لیے وہاں ستھری عورتیں ہوں گی اور ہم انہیں گھنی چھاؤں میں رکھیں گے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@dli{بے شک الله تمہیں حکم دیتا ہے کہ امانتیں امانت والوں کو پہنچا دو اور جب لوگوں کے درمیان فیصلہ کرو تو انصاف سے فیصلہ کرو بے شک تمہیں نہایت اچھی نصیحت کرتا ہے بے شک الله سننے والا دیکھنے والا ہے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@dlii{اے ایمان والو الله کی فرمانبرداری کرو اور رسول کی فرمانبرداری کرو اور ان لوگوں کی جو تم میں سے حاکم ہوں پھر اگر آپس میں کوئی چیز میں جھگڑا کرو تو اسے الله اور اس کے رسول کی طرف پھیرو اگر تم الله اور قیامت کے دن پر یقین رکھتے ہو یہی بات اچھی ہے اور انجام کے لحاظ سے بہت بہتر ہے\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@dliii{کیا تم لوگوں نے ان لوگوں کو نہیں دیکھا جواس چیز پر ایمان لانے کا دعویٰ کرتے ہیں جو تجھ پر نازل کی گئی ہے اور جو چیز تم سےپہلے نازل کی گئی ہے وہ چاہتے ہیں کہ اپنا فیصلہ شیطان سے کرائیں حالانکہ انہیں حکم دیا گیا ہے کہ اسے نہ مانیں اور شیطان تو چاہتا ہے کہ انہیں بہکا کر دو رجا ڈالے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@dliv{اور جب انہیں کہا جاتا ہے جو چیز الله نے نازل کی ہے اس کی طرف آؤ اور رسول کی طرف آؤ توتو منافقوں کو دیکھے گا کہ تجھ سے پہلو تہی کرتے ہیں\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@dlv{پھر کیاہوتا ہے جب ان کے اپنے ہاتھوں سے لائی ہوئی مصیبت ان پر آتی ہے پھر تیرے پاس آ کر خدا کی قسمیں کھاتے ہیں کہ ہم کو تو سوائے بھلائیا ور باہمی موافقت کے اور کوئی غرض نہ تھی\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@dlvi{یہ وہ لوگ ہیں کہ الله جانتا ہے جو ان کے دلوں میں ہے تو ان سے منہ پھیر لے اور انہیں نصیحت کرو ان سے ایسی بات کہو جو ان کے دلوں میں اتر جائے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@dlvii{اورہم نے کبھی کوئی رسول نہیں بھیجا مگر اسی واسطے کہ الله کے حکم سے اس کی تابعداری کی جائے اور جب انہوں نے اپنے نفسوں پر ظلم کیا تھا تیرے پاس آتے پھر الله سے معافی مانگتے اور رسول بھی ان کی معافی کی درخواست کرتا تو یقیناًیہ الله کو بخشنے والا رحم کرنے والا پاتے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@dlviii{سو تیرے رب کی قسم ہے یہ کبھی مومن نہیں ہوں گے جب تک کہ اپنے اختلافات میں تجھے منصف نہ مان لیں پھر تیرے فیصلہ پر اپنے دلوں میں کوئی تنگی نہ پائیں اور خوشی سے قبول کریں\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@dlix{اور اگر ہم ان پر حکم کرتے کہ اپنی جانوں کو ہلاک کر دو یا اپنے گھروں سے نکل جاؤ تو ان میں سے بہت ہی کم آدمی اس پر عمل کرتے اور اگر یہ لوگ کریں جو ان کو نصیحت کی جاتی ہے تو یہ ان کے لیے زیادہ بہتر ہوتا اور دین میں زیادہ ثابت رکھنے والا ہوتا\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@dlx{اور اس وقت البتہ ہم ان کو اپنے ہاں سے بڑا ثواب دیتے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@dlxi{اور البتہ انھیں سیدھا راستہ دکھاتے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@dlxii{اورجو شخص الله اور اس کے رسول کا فرمانبردار ہو تو وہ ان کے ساتھ ہوں گے جن پر الله نے انعام کیا وہ نبی اور صدیق اور شہید اور صالح ہیں اور یہ رفیق کیسے اچھے ہیں\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@dlxiii{یہ الله کی طرف سے احسان ہے اور الله کافی ہے جاننے والا\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@dlxiv{اے ایمان والو! اپنے ہتھیار لے لو پھر جدا جدا فوج ہو کر نکلویا سب اکھٹے ہوکر نکلو\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@dlxv{اور بے شک تم میں بعض ایسا بھی ہے جو لڑائی سے جی چراتا ہے پھر اگر تم پر کوئی مصیبت آجائے تو کہتا ہے الله نے مجھ پر فضل کیا کہ میں ان لوگوں کے ساتھ نہ تھا\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@dlxvi{اور اگر الله کی طرف سے تم پر فضل ہو تو اس طرح کہنے لگتا ہے کہ گویا تمہارے اور اس کے درمیان دوستی کا کوئی تعلق ہی نہیں کہ کاش میں بھی ان کے ساتھ ہوتا تو بڑی مراد پاتا\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@dlxvii{سو چاہیئے کہ الله کی راہ میں وہ لوگ لڑیں جو دنیا کی زندگی کو آخرت کے بدلے بیچتے ہیں اور جو کوئی الله کی راہ میں لڑے پھر مارا جائے یا غالب رہے تو اسے ہم بڑا ثواب دیں گے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@dlxviii{اور کیا وجہ ہے کہ تم الله کی راہ میں ان بے بس مردوں اور عورتوں اور بچوں کی خاطر نہ لڑو جو کہتے ہیں اے ہمارے رب ہمیں اس بستی سے نکال جس کے باشندے ظالم ہیں اور ہمارے واسطے اپنے ہاں سے کوئی حمایتی کر دے اور ہمارے واسطےاپنے ہاں سے کوئی مددگار بنا دے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@dlxix{جو ایمان والے ہیں وہ الله کی راہ میں لڑتے ہیں اور جو کافر ہیں وہ شیطان کی راہ میں لڑتے ہیں سو تم شیطان کے ساتھیوں سے لڑو بے شک شیطان کا فریب کمزور ہے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@dlxx{کیا تم نے ان لوگوں کو نہیں دیکھا جنہیں کہا گیا تھا کہ اپنے ہاتھ روکے رکھو اور نماز قائم کرو اور زکواة دو پھر جب انہیں لڑنے کا حکم دیا گیا اس وقت ان میں سے ایک جماعت لوگوں سے ایسا ڈرنے لگی جیسا الله کا ڈر ہو یا اس سے بھی زیادہ ڈر اور کہنے لگے اے رب ہمارے تو نے ہم پر لڑنا یوں فرض کیا کیوں نہ ہمیں تھوڑی مدت اور مہلت دی ان سے کہ دو دنیا کا فائدہ تھوڑا ہے اور آخرت پرہیزگاروں کے لیے بہتر ہے اور ایک تاگے کے برابر بھی تم سے بے انصافی نہیں کی جائے گی\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@dlxxi{تم جہاں کہیں ہو گے موت تمہیں آ ہی پکڑے گی اگرچہ تم مضبوط قلعوں میں ہی ہو اور اگر انہیں کوئی فائدہ پہنچتا ہے تو لوگ کہتے ہیں کہ یہ الله کی طرف سے ہے اور اگر کوئی نقصان پہنچتا ہے تو کہتے ہیں کہ یہ تیری طرف سے ہے ان لوگوں کو کیا ہو گیا ہے کہ کوئی بات ان کی سمجھ میں نہیں آتی\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@dlxxii{تجھے جو بھی بھلائی پہنچے وہ الله کی طرف سے ہے اور جو تجھے برائی پہنچے وہ تیرے نفس کی طرف سے ہے ہم نے تجھے لوگوں کو پیغام پہنچانے واا بنا کر بھیجا ہے اور الله کی گواہی کافی ہے\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@dlxxiii{جس نے رسول کا حکم مانا اس نے الله کا حکم مانا اور جس نے منہ موڑا تو ہم نے تجھے ان پر نگہبان بنا کر نہیں بھیجا\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@dlxxiv{اور کہتے ہیں قبول کیا پھر جب تیرے ہاں سے باہر گئے تو ان میں سے ایک گروہ رات کو جمع ہو کر تمہاری باتو ں کے خلاف مشورہ کرتا ہے اور الله لکھتا ہے جو وہ مشورہ کرتے ہیں تو ان کی پرواہ نہ کر اور الله پر بھروسہ کر اور الله کارساز کافی ہے\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@dlxxv{کیا یہ لوگ قرآن میں غور نہیں کرتے اور اگر یہ قرآن سوائے الله کے کسی اور کی طرف سے ہوتا تو وہ اس میں بہت اختلاف پاتے\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@dlxxvi{اور جب ان کے پاس کوئی خبر امن یا ڈر کی پہنچتی ہے تو اسے مشہور کر دیتے ہیں اور اگر اسے رسول او راپنی جماعت کے ذمہ دار اصحاب تک پہنچاتے تو اس کی تحقیق کرتے جو ان میں تحقیق کرنے والے ہیں اوراگر تم پر الله کا فضل اوراس کی مہربانی نہ ہوتی تو البتہ تم شیطان کے پیچھے ہو لیتے سوائے چند لوگوں کے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@dlxxvii{سو تو الله کی راہ میں لڑ تو سوائے اپنی جان کے کسی کا ذمہ دار نہیں اور مسلمانوں کو تاکید کر قریب ہے کہ الله کافرو ں کی لڑائی بند کر دے اور الله لڑائی میں بہت ہی سخت ہےاور سزا دینے میں بھی بہت سخت ہے\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@dlxxviii{جو کوئی اچھی بات میں سفارش کرے اسے بھی اس میں سے ایک حصہ ملے گا اور جو کوئی بری بات میں سفارش کرے اس میں سے ایک بوجھ اس پر بھی ہے اور الله ہر چیز پر قدرت رکھنے والا ہے\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@dlxxix{اور جب تمہیں کوئی دعا دے تو تم اس سے بہتر دعا دو یا الٹ کر ویسی ہی کہو بے شک الله ہر چیز کا حساب لینے والا ہے\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@dlxxx{الله وہ ہے جس کے سوا کوئی بندگی نہیں بے شک قیامت کے دن تم سب کو جمع کرے گا اس میں کوئی شک نہیں اور الله سے بڑھ کر کس کی بات سچی ہو سکتی ہے\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@dlxxxi{پھر تمہیں کیا ہو گیا ہے کہ منافقوں کے معاملہ میں دو گروہ ہو رہے ہیں اور الله نے ان کے اعمال کے سبب سےانہیں الٹ دیا ہے کیا تم چاہتے ہو جسے الله نے گمراہ کیا ہو اسے راہ پر لاؤ اور جسے الله گمراہ کرے تو اس کے لیے ہرگز کوئی راہ نہیں پائے گا\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@dlxxxii{وہ تو چاہتے ہیں کہ جیسے وہ کافر ہوئے ہیں تم بھی کافر ہو جاؤ پھر تم سب برابر ہو جاؤ لہذا ان میں سے کسی کو اپنا دوست نہ بناؤ جب تک وہ الله کی راہ میں ہجرت کر کے نہ آ جائیں پھر اگر وہ اس بات کو قبول نہ کریں تو جہاں پاؤ انہیں پکڑو اور قتل کرو اور ان میں سے کسی کو اپنے دوست اور مددگار نہ بناؤ\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@dlxxxiii{البتہ وہ منافق اس حکم سے مستثنیٰ ہیں جو کسی ایسی قوم سے جا ملیں جس کے ساتھ تمہارا معاہدہ ہو یا وہ جو تمہارے پاس آتے ہیں اور لڑائی سے دل برداشتہ ہیں نہ تم سے لڑتے ہیں اور نہ اپنی قوم سے اور اگر الله چاہتا تو انہیں تم پر مسلط کر دیتا ہے پھر وہ تم سے لڑتے ہیں سو اگر وہ تم سے یک سو رہیں اور تم سے نہ لڑیں او رتمہاری طرف صلح کا ہاتھ بڑھائیں تو الله نے تمہیں ان پر کوئی راہ نہیں دی\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@dlxxxiv{ایک اور قسم کے تم منافق دیکھو گے جو چاہتے ہیں تم سے بھی امن میں رہیں اور اپنی قوم سے بھی جب کبھی وہ فساد کی طرف لوٹائے جاتے ہیں تو اس میں کود پڑتے ہیں پھر اگر وہ تم سے یک سو نہ رہیں اور تہارے آگے صلح پیش نہ کریں اور اپنے ہاتھ نہ روکیں تو انہیں جہاں پا پکڑو او رمار ڈالو اور ان پر ہاتھ اٹھانے کے لیے ہم نے تمہیں کھلی حجت دے دی ہے\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@dlxxxv{اور مسلمانوں کا یہ کام نہیں کہ کسی مسلمان کو قتل کرے مگر غلطی سے اور جو مسلمان کو غلطی سے قتل کرے تو ایک مسلمان کی گردن آزاد کرے اور مقتول کے وارثوں کو خون بہا دے مگر یہ کہ وہ خون بہا معاف کر دیں پھر اگر وہ مسلمان مقتول کسی ایسی قوم میں تھا جس سے تمہاری دشمنی ہے تو ایک مومن غلام آزاد کرنا ہے اور اگر وہ مقتول مسلمان کسی ایسی قوم میں سے تھا جس سے تمہارا معاہدہ ہے تو اس کے وارثوں کو خون بہا دیا جائے گا اور ایک مومن غلام کو آزاد کرنا ہوگا پھر جو غلام نہ پائے وہ پے درپے دو مہینے کے روزے رکھے الله سےگناہ بخشوانے کے لیے اور الله جاننے والا حکمت والا ہے\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@dlxxxvi{اور جو کوئی کسی مسلمان کو جان کر قتل کرے اس کی سزا دوزخ ہے جس میں وہ ہمیشہ رہے گا اس پر الله کا غضب اور اس کی لعنت ہے اور الله نے اس کےلیے بڑا عذاب تیا رکیا ہے\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@dlxxxvii{اے ایمان والو! جب الله کی راہ میں سفر کرو تو تحقیق کر لیا کرو او جو تم پر سلام کہے اس کو مت کہو کہ مسلمان نہیں ہے تم دنیا کی زندگی کا سامان چاہتے ہو سو الله کے ہاں بہت غنیمتیں ہیں تم بھی تو اس سے پہلے ایسے ہی تھے پھر الله نے تم پر احسان کیا لہذا تحقیق سے کام لیا کرو بے شک الله تمہارے کاموں سے باخبر ہے\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@dlxxxviii{مسلمانوں میں سے جو لوگ کسی عذر کے بغیر گھر بیٹھے رہتے ہیں اور وہ جو الله کی راہ میں جان و مال سے جہاد کرتے ہیں دونوں برابر نہیں ہیں الله نے بیٹھنے والوں پر جان و مال سے جہاد کرنے والوں کا درجہ بڑھایا دیا ہے اگرچہ ہر ایک سے الله نے بھلائي کا وعدہ کیا ہے اور الله نے لڑنے والوں کو بیٹھنے والوں سے اجر عظیم میں زیادہ کیا ہے\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@dlxxxix{ان کے لیے الله کی طرف سے بڑے درجے اور مغفرت اور رحمت ہے اور الله معاف کرنے والا رحم کرنے والا ہے\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@dxc{بے شک جو لوگ اپنے نفسوں پر ظلم کر رہے تھے ان کی روحیں جب فرشتوں نے قبض کیں توان سے پوچھا کہ تم کس حال میں تھے انہوں نے جواب دیا ہم اس ملک میں بے بس تھے فرتشوں نے کہا کیا الله کی زمین وسیع نہ تھی کہ تم اس میں ہجرت کر جاتےسو ایسوں کا ٹھکانہ دوزخ ہے اور بہت ہی برا ٹھکانہ ہے\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@dxci{ہاں جو مرد اور عورتیں اور بچے کافی کمزور ہیں جو نکلنے کا کوئی ذریعہ اور راستہ نہیں پاتے\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@dxcii{پس امید ہے کہ ایسوں کو الله معاف کر دے اور الله معاف کرنے والا بخشنے والا ہے\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@dxciii{اور جو کوئی الله کی راہ میں وطن چھوڑے اس کے عوض جگہ بہت اور کشائش پائے گا اور جو کوئی اپنے گھر سے الله اور رسول کی طرف ہجرت کر کے نکلے پھر اس کو موت پالے تو الله کے ہاں اس کا ثواب ہو چکا اور الله بخشنے والا مہربان ہے\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@dxciv{اور جب تم سفر کے لیے نکلو تو تم پر کوئی گناہ نہیں نماز میں سے کچھ کم کر دو اگر تمہیں یہ ڈر ہو کہ کافر تمہیں ستائیں گے بےشک کافر تمہارے صریح دشمن ہیں\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@dxcv{اے نبی جب تم مسلمانو ں میں موجود ہو اور انہیں نماز پڑھانے کے لیے کھڑا ہو تو چاہیئے ان میں سے ایک جماعت تیرے ساتھ کھڑی ہو اور اپنے ہتھیار ساتھ لے لیں پھر جب یہ سجدہ کریں تو تیرے پیچھے سے ہٹ جائیں اور دوسری جماعت آئے جس نے نماز نہیں پڑھی وہ تیرے ساتھ نماز پڑھتے اور وہ بھی اپنے بچاؤ اور اپنے ہتھیار ساتھ رکھیں کافر چاہتے ہیں کہ کسی طرح تم اپنے ہتھیاروں اور اسباب سے بے خبر ہو جاؤ تاکہ تم پر یک بارگی ٹوٹ پڑیں اور اگر تم بارش کی وجہ سے تکلیف محسوس کرو یا بیمار ہو تو ہتھیار رکھ دینے میں کوئي مضائقہ نہیں اور (تب بھی) اپنا بچاؤ ساتھ رکھو بے شک الله نے کافروں کے لیے ذلت کا عذاب تیار کر رکھا ہے\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@dxcvi{پھر جب نماز سے فارغ ہو جاؤ تو الله کو کھڑے او ربیٹھے اور لیٹے ہونے کی حالت میں یاد کرو پھر جب تمہیں اطمینان ہو جائے تو پوری نماز پڑھو بے شک نماز اپنے مقرر وقتوں میں مسلمانوں پر فرض ہے\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@dxcvii{اور ان لوگوں کا پیچھا کرنے سے ہمت نہ ہارو اگر تم تکلیف اٹھاتے ہو تو وہ بھی تمہاری طرح تکلیف اٹھاتے ہیں حالانکہ تم الله سے جس چیز کے امیدوار ہو وہ نہیں ہیں اور الله سب کچھ جاننے والا حکمت ولا ہے\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@dxcviii{بے شک ہم نے تیری طرف سچی کتاب اتاری ہے تاکہ تو لوگوں میں انصاف کرے جو کچھ تمہیں الله سجھا دے اور تو بد دیانت لوگوں کی طرف سے جھگڑنے والا نہ ہو\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@dxcix{اور الله سے بخشش مانگ بے شک الله بخشنے والا مہربان ہے\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@dc{اور ان لوگوں کی طرف سے مت جھگڑو جو اپنے دل میں دغا رکھتے ہیں جو شخص دغا باز گناہگار ہو بے شک الله اسے پسند نہیں کرتا\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@dci{یہ لوگوں سے تو چھپتے ہیں اور خدا سے نہیں چھپتے حالانکہ جب وہ راتوں کو ایسی باتوں کے مشورے کیا کرتے ہیں جن کو وہ پسند نہیں کرتا ان کے ساتھ ہوا کرتا ہے اور خدا ان کے (تمام) کاموں پر احاطہ کئے ہوئے ہے\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@dcii{ہاں تم لوگوں نے ان مجرمو ں کی طرف سے دنیا کی زندگی میں تو جھگڑا کر لیا پھر قیامت کے دن ان کی طرف سے الله سے کون جھگڑے گا یا ان کا وکیل کون ہوگا\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@dciii{اور جو کوئی برا فعل کرے یا اپنے نفس پر ظلم کرے پھراس کے بعد اللهسےبخشوائے تو الله کو بخشنے والا مہربان پائے\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@dciv{اور جو کوئی گناہ کرے سو اپنےہی حق میں کرتا ہے اور الله سب باتوں کا جاننے والا حکمت والا ہے\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@dcv{اور جو کوئی خطا یا گناہ کرے پھر کسی بے گنا پر تہمت لگادے تو اس نے بڑے بہتان اور صریح گناہ کا بار سمیٹ لیا\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@dcvi{اور اگر تجھ پر الله کا فضل اور اس کی رحمت نہ ہوتی تو ان میں سے ایک گروہ نے تمہیں غلط فہمی میں مبتلا کرنے کا فیصلہ کرہی لیا تھا حالا نکہ وہ اپنے سوا کسی کو غلط فہمی میں مبتلانہیں کر سکتے تھے اور وہ تمہارا کچھ نہیں بگاڑ سکتے تھے اور الله نے تجھ پر کتاب اور حکمت نازل کی ہے اور تجھے وہ باتیں سکھائی ہیں جو تو نہ جانتا تھا اور الله کا تجھ پر بہت بڑا فضل ہے\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@dcvii{ان لوگو ں کی خفیہ سرگوشیوں میں اکثر کوئی بھلائی نہیں ہوتی ہاں مگر کوئی پوشیدہ طور پر صدقہ کرنے یا کسی نیک کام کرنے یا لوگو ں میں صلح کرانے میں کی جائے تو یہ بھلی بات ہے اور جو شخص یہ کام الله کی رضا جوئی کے لیے کرے تو ہم اسے بڑا ثواب دیں گے\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@dcviii{اور جو کوئی رسول کی مخالفت کرے بعد اس کے کہ اس پر سیدھی راہ کھل چکی ہو اور سب مسلمانوں کے راستہ کے خلاف چلے تو ہم اسے اسی طرف چلائیں گے جدھر وہ خود پھر گیا ہے اور اسے دوزح میں ڈال دینگے اور وہ بہت برا ٹھکانا ہے\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@dcix{بے شک الله اس کو نہیں بخشتا جو کسی کو اس کا شریک بنائے اس کے سوا جسے چاہے بخش دے اور جس نے الله کا شریک ٹھیرایا وہ بڑی دور کی گمراہی میں جا پڑا\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@dcx{یہ لوگ الله کے سوا عورتو ں کی عبادت کرتے ہیں اور صرف شیطان سرکش کی عبادت کرتے ہیں\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@dcxi{جس پر الله کی لعنت ہے اور شیطان نے کہا کہ اے الله میں تیرے بندوں میں سے حصہ مقرر لوں گا\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@dcxii{اور البتہ انہیں ضرور گمراہ کروں گا اور البتہ ضرور انہیں امیدیں دلاؤں گا اور البتہ ضرور انہیں حکم کروں گا کہ جانوروں کے کان چریں اور البتہ ضرور انہیں حکم دوں گا کہ جانورں کے کان چیریں اور البتہ ضرور انہیں حکم دوں گاکہ الله کی بنائی ہوئی صورتیں بدلیں اور جو شخص الله کو چھوڑ کر شیطان کو دوست بنائے گا وہ صریح نقصان میں جا پڑا\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@dcxiii{شیطان ان سے وعدے کرتا ہےاور انہیں امیدیں دلاتا ہے اور شیطان ان سے صرف جھوٹے وعدے کرتا ہے\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@dcxiv{ایسے لوگو ں کا ٹھکانہ دورخ ہے ااور اس ے کہیں بچنے کے لیے جگہ نہ پائیں گے\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@dcxv{اور جو لوگ ایمان لائے اور اچھے کام کیے انہیں ہم باغوں میں داخل کر ینگے جن کے نیچے نہریں بہتی ہیں ان میں ہمیشہ رہیں گے الله کا وعدہ سچا ہے اور الله سے زیادہ سچا کون ہے\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@dcxvi{نہ تمہاری امیدوں پر مدار ہے اور نہ اہل کتاب کی امیدوں پر جو کوئی برائی کا کام کرے گا اس کی سزا دیا جائے گا اور الله کے سوا اپنا کوئی حمایتی اور مددگار نہیں پائے گا\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@dcxvii{اور جو کوئی اچھے کام کرے گا مرد ہے یا عورت درآنحالینکہ وہ ایما ندار ہو تو وہ لوگ جنت میں داخل ہوں گے اور کھجور کے شگاف برابر بھی ظلم نہیں کیے جائیں گے\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@dcxviii{اس شخص سے بہتر دین میں کون ہے جس نے الله کے حکم پر پیشانی رکھی اور وہ نیکی کرنے والا ہو اور ابراھیم حنیف کے دین کی پیروی کرے اور الله نے ابراھیم کوخاص دوست بنا لیا ہے\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@dcxix{اور الله ہی کا ہے جو کچھ آسمانوں اور زمین میں ہے اور الله سب چیزو ں کا احاطہ کیے ہوئے ہے\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@dcxx{اور تجھ سے عورتو ں کے نکاح کی رخصت مانگتے ہیں کہہ دے الله تمہیں ان کی اجازت دیتا ہے اور وہ جو تمہیں قرآن سنایا جاتا ہے سو ان یتیم عورتوں کا حکم ہے جنہیں تم نہیں دیتے جو ان کے لیے مقرر کیا گیا ہے او رچاہتے ہو کہ ان سے نکاح کرو اور کمزور لڑکوں کے بارے میں ہے اور یہ کہ یتیموں کے حق میں انصاف پر قائم رہو اور جو تم نیکی کرو گے پس تحقیق الله اسے جاننے والا ہے\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@dcxxi{اور اگر کوئی عورت اپنے خاوند کے لڑنے یا منہ پھیرنے سے ڈرے تو دونوں پر کوئی گناہ نہیں کہ آپس میں کسی طرح صلح کر لیں اور یہ صلح بہتر ہے اور دلوں میں حرص موجود ہے اور اگر تم نیکی کرو او رپرہیزگاری کرو تو الله کو تمہارے اعمال کی پوری خبر ہے\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@dcxxii{اور تم عورتوں کو ہرگز برابر نہیں رکھ سکو گے اگرچہ اس کی حرص کرو سوتم بالکل ہی ایک طرف نہ جھک جاؤ کہ دوسری عورت کو لٹکی ہوئی چھوڑ دو اور اگر اصلاح کرتے رہو اور پرہیزگاری کرتے رہو تو الله بحشنے والا مہربان ہے\qt@no{(129)}}%
\qt@newcmd\qurantrans@ur@dcxxiii{اور اگر دونوں میاں بیوی جدا ہو جائیں تو الله اپنی و سعت سے ہر ایک کو بے پروا کردے گا اور الله وسعت کرنے والا حکمت والا ہے\qt@no{(130)}}%
\qt@newcmd\qurantrans@ur@dcxxiv{اور جو کچھ اسمانوں اور جو کچھ زمین میں ہے وہ الله ہی کا ہے اور ہم نے پہلی کتاب والوں کو اور تمہیں حکم دیا ہے کہ الله سے ڈرو اور اگر ناشکری کرو گے تو جو کچھ آسمانو ں میں ہے اور جو کچھ زمین میں ہے سب الله ہی کا ہے اور الله بے پرواہ تعریف کیا ہواہے\qt@no{(131)}}%
\qt@newcmd\qurantrans@ur@dcxxv{اور جو کچھ آسمانو ں اور زمین میں سب الله ہی کا ہے اور الله کارسازکافی ہے\qt@no{(132)}}%
\qt@newcmd\qurantrans@ur@dcxxvi{اگر چاہے تو اے لوگو تمہیں لے جائے اوراوروں کو لے آئے اور الله اس پر قادر ہے\qt@no{(133)}}%
\qt@newcmd\qurantrans@ur@dcxxvii{جو شخص دنیا کا ثواب چاہتا ہے تو الله کے ہاں دنیا اور آخرت کا ثواب ہے اور الله سننے والا دیکھنے والا ہے\qt@no{(134)}}%
\qt@newcmd\qurantrans@ur@dcxxviii{اے ایمان والو! انصاف پر قائم رہو الله کی طرف گواہی دو اگرچہ اپنی جانوں پر ہو یا اپنے ماں باپ اور رشہ داروں پر اگر کوئی مالدار ہے یا فقیر ہے تو الله ان کا تم سے زیادہ خیر خوا ہ ہے سو تم انصاف کرنے میں دل کی خواہش کی پیروی نہ کرو اور اگر تم کج بیانی کرو گے یا پہلو تہی کرو گے تو بلاشبہ الله تمہارے سب اعمال سے با خبر ہے\qt@no{(135)}}%
\qt@newcmd\qurantrans@ur@dcxxix{اے ایمان والو! الله اور اس کے رسول پر یقین لاؤ اور اس کتاب پر جو اس نے اپنے رسول پر نازل کی ہےاور اس کتاب پر جو پہلے نازل کی تھی اور جو کوئی الله کا انکار کرے اور اس کے فرشتوں کا اور اس کے رسولوں کا اور قیامت کے دن کا تو وہ شخص بڑی دور کی گمراہی میں جا پڑا\qt@no{(136)}}%
\qt@newcmd\qurantrans@ur@dcxxx{بے شک وہ لوگ جو ایمان لائے پھر کفر کیا پھر ایمان لائے پھر کفر کیا پھر کفر میں بڑھتے رہے تو الله ان کو ہرگز نہیں بخشے گا اور نہ انہیں راہ دکھائے گا\qt@no{(137)}}%
\qt@newcmd\qurantrans@ur@dcxxxi{منافقوں کو خوشخبری سنا دے کہ ان کے واسطے دردناک عذاب ہے\qt@no{(138)}}%
\qt@newcmd\qurantrans@ur@dcxxxii{وہ جو مسلمانوں کو چھوڑ کر کافروں کو اپنا دوست بناتے ہیں کیا ان کے ہاں سے عزت چاہتے ہیں سو ساری عزت الله ہی کے قبضہ میں ہے\qt@no{(139)}}%
\qt@newcmd\qurantrans@ur@dcxxxiii{اور الله نے تم پر قرآن میں حکم اتارا ہے کہ جب تم الله کی آیتوں پر انکار اور مذاق ہوتا سنو تو ان کے ساتھ نہ بیٹھو یہاں تک کہ کسی بات میں مشغول ہوں ورنہ تم بھی ان جیسے ہو جاؤ گے اور الله منافقوں اور کافروں کو دوزخ میں ایک ہی جگہ اکھٹا کرنے والا ہے\qt@no{(140)}}%
\qt@newcmd\qurantrans@ur@dcxxxiv{وہ منافق جو تمہارے متعلق انتظار کرتے ہیں پھر اگر تمہیں الله کی طرف سے فتح ہو تو کہتے ہیں کیا ہم تمہارے ساتھ نہ تھےاور اگر کافرو ں کو کچھ حصہ مل جائے تو کہتے ہیں کیا ہم تم پر غالب نہ آنے لگے تھے اور کیا ہم نے تمہیں مسلمانوں سے بچا نہیں لیا سو الله تمہارا اور ان کا قیامت میں فیصلہ کرے گا اور (وہاں) الله کافروں کو مسلمانوں کے مقابلہ میں ہرگز غالب نہیں کرے گا\qt@no{(141)}}%
\qt@newcmd\qurantrans@ur@dcxxxv{منافق الله کو فریب دیتے ہیں اور وہی ان کو فریب دے گا اور جب وہ نماز میں کھڑے ہوتے ہیں تو سست بن کر کھڑے ہوتے ہیں لوگو ں کو دکھا تے ہیں اور الله کو بہت کم یاد کرتے ہیں\qt@no{(142)}}%
\qt@newcmd\qurantrans@ur@dcxxxvi{کفر اور ایمان کے درمیان ڈانوں ڈول ہیں نہ پورے اس طرف ہیں اور نہ پورے اس طرف اور جسے الله گمراہ کر دے تو اس کے واسطے ہرگزکہیں راہ نہ پائے گا\qt@no{(143)}}%
\qt@newcmd\qurantrans@ur@dcxxxvii{اے ایمان والو مسلمانوں کو چھوڑ کر کافروں کو اپنا دوست نہ بناؤ کیا تم اپنے اوپر الله کا صریح الزام لینا چاہتے ہو\qt@no{(144)}}%
\qt@newcmd\qurantrans@ur@dcxxxviii{بے شک منافق دوزخ کے سب سےنیچے درجہ میں ہوں گے تو ان کے واسطے کوئی مددگار ہرگز نہ پائے گا\qt@no{(145)}}%
\qt@newcmd\qurantrans@ur@dcxxxix{مگر جنہوں نے توبہ کی اور اپنی اصلاح کی اور الله کو مضبوط پکڑا اور اپنے دین کو خالص الله ہی کے لیے کیاتو وہ لوگ ایمان والوں کے ساتھ ہیں اور الله جلدی ایمان والوں کو بہت بڑا ثواب دے گا\qt@no{(146)}}%
\qt@newcmd\qurantrans@ur@dcxl{) اے منافقو) الله تمہیں سزادے کر کیا کرے گا اگر تم شکر گزار بنو اور ایمان لے آؤ اور الله قدردان جاننے والا ہے\qt@no{(147)}}%
\qt@newcmd\qurantrans@ur@dcxli{الله کو کسی کی بڑی بات کا ظاہر کرنا پسند نہیں مگر جس پر ظلم ہواہو اور الله سننے والا جاننے والا ہے\qt@no{(148)}}%
\qt@newcmd\qurantrans@ur@dcxlii{اور اگرتم نیک کام اعلانیہ کر ویا اسے خفیہ کرو یا کسی برائی کو معاف کردو تو الله بڑا معاف کرنے والا قدرت والا ہے\qt@no{(149)}}%
\qt@newcmd\qurantrans@ur@dcxliii{بے شک جو لوگ الله اور اس کے رسولوں کے ساتھ کفر کرتے ہیں اور چاہتے ہیں کہ الله اوراس کے رسولوں کے درمیان فرق رکھیں اور کہتے ہیں کہ ہم بعضوں پر ایمان لائے ہیں اور بعضوں کے منکر ہیں اور چاہتے ہیں کہ کفر اور ایمان کے درمیان ایک راہ نکالیں\qt@no{(150)}}%
\qt@newcmd\qurantrans@ur@dcxliv{ایسے لوگ یقیناً کافر ہیں اور ہم نے کافرو ں کے واسطے ذلت کا عذاب تیار کر رکھا ہے\qt@no{(151)}}%
\qt@newcmd\qurantrans@ur@dcxlv{اور جو لوگ الله پر ایمان لائے اور رسولوں پر ان میں سے کسی کو جدا نہ کیاان لوگوں کو الله جلدان کے ثواب دے گا اور الله بخشنے والا مہربان ہے\qt@no{(152)}}%
\qt@newcmd\qurantrans@ur@dcxlvi{اہلِ کتاب تجھ سےدرخواست کرتے ہیں کہ تو ان پر آسمان سے لکھی ہوئی کتب اتار لائے سو موسیٰ سے اس سے بڑی چیز مانگ چکے ہیں اور کہا ہمیں الله کو بالکل سامنے لا کر دکھا دے ان کے اس ظلم کے باعث ان پر بجلی ٹوٹ پڑی پھر بہت سی نشانیاں پہنچ چکنے کے بعد بچھڑے کو بنا لیا پھر ہم نے وہ بھی معاف کر دیا اور ہم نے موسیٰ کو بڑا رعب دیاتھا\qt@no{(153)}}%
\qt@newcmd\qurantrans@ur@dcxlvii{اور لوگوں پر طور اٹھا کر ان سے عہد لیا اور ہم نے کہا کہ دروازہ میں سجدہ کرتے ہوئےداخل ہو اور ہم نے کہا کہ ہفتے کے بارے میں زیادتی نہ کرو اور ہم نے ان سے پختہ عہد لیا\qt@no{(154)}}%
\qt@newcmd\qurantrans@ur@dcxlviii{پھر ان کی عہد شکنی پر اور الله کی آیتوں سے منکر ہونے پر اور پیغمبروں کا ناحق خون کرنے پر اور اس کہنے پرکہ ہمارے دلوں پرپر دے رہے ہیں انہیں سزا ملی پردے نہیں بلکہ الله نے ان کے دلوں پر کفر کے سبب سے مہر کر دی ہے سو ایمان نہیں لاتے مگر تھوڑے\qt@no{(155)}}%
\qt@newcmd\qurantrans@ur@dcxlix{اور ان کے کفر او رمریم پر بڑا بہتان باندھنے کے سبب سے\qt@no{(156)}}%
\qt@newcmd\qurantrans@ur@dcl{اور ان کے اس کہنے پر کہ ہم نے مسیح عیسیٰ مریم کے بیٹے کو قتل کیا جو الله کا رسول تھا حالانکہ انہوں نے نہ اسے قتل کیا اور نہ سولی پر چڑھایا لیکن ان کو اشتباہ ہو گیا اورجن لوگوں نے اس کے بارے میں اختلاف کیا ہے وہ بھی دراصل شک میں مبتلا ہیں ان کے پا س بھی اس معاملہ میں کوئی یقین نہیں ہے محض گمان ہی کی پیروی ہے انہوں نے یقیناً مسیح کو قتل نہیں کیا\qt@no{(157)}}%
\qt@newcmd\qurantrans@ur@dcli{بلکہ اسے الله نے اپنی طرف اٹھا لیا اور الله زبردست حکمت والا ہے\qt@no{(158)}}%
\qt@newcmd\qurantrans@ur@dclii{اور اہلِ کتاب میں کوئی ایسانہ ہوگا جواسکی موت سے پہلے اس پر ایمان نہ لائے گا اور قیامت کے دن وہ ان پر گواہ ہو گا\qt@no{(159)}}%
\qt@newcmd\qurantrans@ur@dcliii{سویہود کے گناہوں کے سبب سے ہم نے ان پر بہت سی پاک چیزیں حرام کر دیں جو ان پر حلا ل تھیں اور اس سبب سے الله کی راہ سے بہت روکتے تھے\qt@no{(160)}}%
\qt@newcmd\qurantrans@ur@dcliv{اور ان کو سود لینے کے سبب سے حالانکہ اس سے منع کیے گئے تھے اور اس سبب سے کہ لوگو ں کا مال ناحق کھاتے تھے اور ان میں سے جو کافر ہیں ہم نے ان کے لیے دردناک عذاب تیار کر رکھا ہے\qt@no{(161)}}%
\qt@newcmd\qurantrans@ur@dclv{لیکن ان میں سے جو علم میں پختہ ہیں اور مسلمان ہیں سومانتے ہیں اس کو جو تجھ پر نازل ہوا اور جو تجھ سے پہلے نازل ہو چکا ہے اور نماز قائم کرنے والے اور زکواة دینے والے اور اللهاور قیامت پر ایمان لانے والے ہیں یہ وہ لوگ ہیں جنہیں ہم بڑا ثواب عطا فرمائیں گے\qt@no{(162)}}%
\qt@newcmd\qurantrans@ur@dclvi{ہم نے تیری طرف وحی بھیجی جیسی نوح پر وحی بھیجی اور ان نبیوں پر جو اس کے بعد آئے اور ابراھیمؑ اور اسماعیلؑ اور اسحاقؑ اور یعقوبؑ اور اس کی اولاد اور عیسیٰؑ اور ایوبؑ اوریونسؑ اور ھارونؑ اور سلیمانؑ پر وحی بھیجی اور ہم نے داؤدؑ کو زبور دی\qt@no{(163)}}%
\qt@newcmd\qurantrans@ur@dclvii{اور ایسے رسول بھیجے جن کا حال اس سے پہلےہم تمہیں سنا چکیں ہیں اور ایسے رسول جن کا ہم نے تم سے بیان نہیں کیا اور الله نے موسیٰ سے خاص طور پر کلام فرمایا\qt@no{(164)}}%
\qt@newcmd\qurantrans@ur@dclviii{ہم نے پیغمبر بھیجے خوشخبری دینے والے اور ڈرانے والے تاکہ ان لوگوں کا الله پر پیغمبرو ں کے بعد الزا م نہ رہے اور الله غالب حکمت والا ہے\qt@no{(165)}}%
\qt@newcmd\qurantrans@ur@dclix{لیکن الله اس پر شاہد ہے جو تم پر نازل کیا کہ اسے اپنے علم سے نازل کیا اور فرشتے بھی گواہ ہیں اورالله گواہی دینے والا کافی ہے\qt@no{(166)}}%
\qt@newcmd\qurantrans@ur@dclx{بے شک جو لوگ کافر ہوئے اور الله کی راہ سے روکا وہ بڑی دور کی گمراہی میں جا پڑے\qt@no{(167)}}%
\qt@newcmd\qurantrans@ur@dclxi{بے شک جو لوگ کافر ہوئے اور ظلم کیا الله انہیں کبھی نہیں بخشے گا اور نہ ان کو سیدھی راہ دکھائے گا\qt@no{(168)}}%
\qt@newcmd\qurantrans@ur@dclxii{مگر دوزخ کی راہ جس میں وہ ہمیشہ رہیں گے اور الله پر یہ آسان ہے\qt@no{(169)}}%
\qt@newcmd\qurantrans@ur@dclxiii{اے لوگو! تمہارے پاس تمہارے رب کی طرف سے ٹھیک بات لے کر رسول آ چکا سو مان لو تاکہ تمہارا بھلا ہو اور اگر انکار کرو گے تو الله ہی کا ہے جو کچھ آسمانوں اور زمین میں ہے اور الله سب کچھ جاننے والا حکمت والا ہے\qt@no{(170)}}%
\qt@newcmd\qurantrans@ur@dclxiv{اے اہِل کتاب تم اپنے دین میں حد سے نہ نکلو اور الله کی شان میں سوائے پکی بات کے نہ کہو بے شک مسیح عیسیٰ مریم کا بیٹا الله کا رسول ہے اور الله کا ایک کلمہ ہےجسے الله نے مریم تک پہنچایا اور الله کی طرف سے ایک جان ہے سو الله پر اور اس کے سب رسولوں پر ایمان لاؤ اور نہ کہو کہ خدا تین ہیں اس بات کو چھوڑ دو تمہارے لیے بہتر ہو گا بے شک الله اکیلا معبود ہے وہ اس سے پاک ہے اس کی اولاد ہو اسی کا ہے جو کچھ آسمانوں میں ہے اور جو کچھ زمین میں ہے اور الله کارساز کافی ہے\qt@no{(171)}}%
\qt@newcmd\qurantrans@ur@dclxv{مسیح خدا کا بندہ بننے سے ہرگز عار نہیں کرے گا اور نہ مقرب فرشتے اور جو کوئی اس کی بندگی سے انکار کرے گا اور تکبر کرے گا پھران سب کو اپنی طرف اکھٹاکرے گا\qt@no{(172)}}%
\qt@newcmd\qurantrans@ur@dclxvi{پھر جو لوگ ایمان لائے ہوں گے اور اچھے کام کیے ہوں گے انہیں تو ان کا پورا ثواب دے گا اور انہیں اپنے فضل سے زیادہ دے گا اور جن لوگوں نے انکار کیا اورتکبر کیا انہیں درد دینے والا عذاب دے گا اور وہ الله کے سوا اپنے واسطے کوئی دوست اور مددگار نہیں پائیں گے\qt@no{(173)}}%
\qt@newcmd\qurantrans@ur@dclxvii{اے لوگو! تمہارے پاس تمہارے پروردگار کی طرف سے ایک دلیل آ چکی ہے اور ہم نےتمہاری طرف ایک ظاہر روشنی اتاری ہے\qt@no{(174)}}%
\qt@newcmd\qurantrans@ur@dclxviii{سو جو لوگ الله پر ایمان لائے اور انھوں نے الله کومظبوط پکڑا انہیں الله اپنی رحمت اور اپنے فضل میں داخل کرے گا اور اپنے تک ان کو سیدھا راستہ دکھائے گا\qt@no{(175)}}%
\qt@newcmd\qurantrans@ur@dclxix{تجھ سے حکم دریافت کرتے ہیں کہہ دو الله تمہیں کلالہ کے بارے میں حکم دیتا ہے اگر کوئی شخص مر جائے جس کی اولاد نہ ہو اور اس کی ایک بہن ہو تو اسے اس کے تمام ترکہ کانصف ملے گا اور وہ شخص اس بہن کا وارث ہو گا اگر اس کی کوئی اولاد نہ ہو اور اگر دو بہنیں ہوں تو انہیں کل ترکہ میں سے دو تہائی ملے گا اور اگر چند وارث بھائی بہن ہوں مرد اور عورت تو ایک مرد کو دو عورتوں کے حصہ کے برابر ملے گا الله تم سے اس لیے بیان کرتا ہے کہ تم گمراہ نہ ہو جاؤ اور الله ہر چیز کو جاننے والا ہے\qt@no{(176)}}%
\qt@newcmd\qurantrans@ur@dclxx{\basmalahur اے ایمان والو! عہدوں کوپورا کرو تمہارے لیے چوپائے مویشی حلال ہیں سوائے ان کے جو تمہیں آگے سنائے جائیں گے مگر شکار کو احرام کی حالت میں حلال نہ جانو الله جو چاہے حکم دیتا ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@dclxxi{اے ایمان والو! الله کی نشانیوں کو حلال نہ سمجھو اور نہ حرمت والے مہینے کو اور نہ حرم میں قربانی ہونے والے جانور کو اور نہ ان جانوروں کو جن کے گلے میں پٹے پڑے ہوئے ہوں اور نہ حرمت والے گھر کی طرف آنے والوں کو جو اپنے رب کا فضل اور اس کی خوشی ڈھونڈتے ہیں اور جب تم احرام کھول دو پھر شکار کرو اور تمہیں اس قوم کی دشمنی جو کہ تمہیں حرمت والی مسجد سے روکتی تھی اس بات کا باعث نہ بنے کہ زیادتی کرنے لگو اور آپس میں نیک کام اور پرہیز گاری پر مدد کرو اورگناہ اور ظلم پر مدد نہ کرو اور الله سے ڈرو بے شک الله سخت عذاب دینے والا ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@dclxxii{تم پر مردار اور لہو اور سور کا گوشت حرام کیا گیا ہے اور وہ جانور جس پر الله کے سوا کسی اور کا نام پکارا جائے جو گلا گھوٹ کر یا چوٹ سے یا بلندی سے گر کر یا سینگ مارنے سے مر گیا ہو اور وہ جسے کسی درندے نے پھاڑ ڈالا ہو مگر جسے تم نے ذبح کر لیا ہو اور وہ جو کسی تھان پر ذبح کیا جائے اور یہ کہ جوئے کے تیروں سے تقسیم کرو یہ سب گناہ ہیں آج تمہارے دین سے کافر نا امید ہو گئے سو ان سے نہ ڈرو اور مجھ سے ڈرو آج میں تمہارے لیے تمہارا دین پورا کر چکا اور میں نے تم پر اپنا احسان پورا کر دیا اور میں نے تمہارے واسطے اسلام ہی کو دین پسند کیا ہے پھر جو کوئی بھوک سے بیتاب ہو جائے لیکن گناہ پر مائل نہ ہو تو الله معاف کرنے والا مہربان ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@dclxxiii{تجھ سے پوچھتے ہیں کہ ان کے لیے کیا چیز حلال ہے کہہ دو تمہارے واسطے سب پاکیزہ چیزیں حلا ل کی گئی ہیں اور جو شکاری جانور جسے شکار پر دوڑنے کی تعلیم دو کہ انہیں سکھاتے ہو اس میں سے جو الله نے تمہیں سکھایا ہے سو اس میں سے کھاؤ جو وہ تمہارے لیے پکڑ رکھیں اور اس پر الله کا نا م لو اور الله سے ڈرتے رہو بیشک الله جلد حساب لینے والا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@dclxxiv{آج تمہارے واسطے سب پاکیزہ چیزیں حلا کی گئی ہیں اور اہلِ کتاب کا کھانا تمہیں حلال ہے اور تمہارا کھانا انہیں حلال ہے اور تمہارے لیے پاک دامن مسلمان عورتیں حلال ہیں اوران میں سے پاک دامن عورتیں جنہیں تم سے پہلے کتاب دی گئی ہےجب ان کے مہر انہیں دے دو ایسے حال میں کہ نکاح میں لانے والے ہو نہ بدکاری کرنے والے اورنہ خفیہ آشنائی کرنے والے اورجوایمان سے منکر ہوا تو اس کی محنت ضائع ہوئی اور وہ آخرت میں نقصان اٹھانے والوں میں سے ہو گا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@dclxxv{اے ایمان والو! جب تم نماز کے لیے اٹھو تو اپنے منہ دھو لو اور ہاتھ کہنیوں تک اور اپنے سروں پر مسح کرو اور اپنے پاؤں ٹخنوں تک دھو لو اور اگر تم ناپاک ہو تو نہا لو اور اگرتم بیمار ہو یا سفر پر ہو یا کوئی تم میں سے جائے ضرور سے آیا ہو یا عورتوں کے پاس گئے ہو پھر تم پانی نہ پاؤ تو پاک مٹی سے تیمم کر لو اور اسے اپنے مونہوں او رہاتھوں پر مل لو الله تم پر تنگی کرنا نہیں چاہتا لیکن تمہیں پاک کرنا چاہتا ہے اور تاکہ اپنا احسان تم پر پورا کرے تاکہ تم شکر کرو\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@dclxxvi{اور الله کا انعام جو تم پر ہوا ہے اسے یاد کرو اور اس کا عہد جس کا تم سے معاہدہ کیا ہے جب تم نے کہا تھا کہ ہم نے سنا اور مان لیا اور الله سے ڈرتے رہو الله دلو ں کی بات خوب جانتا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@dclxxvii{اے ایمان والو! الله کے واسطے انصاف کی گواہی دینے کے لیے کھڑے ہو جاؤ اور کسی قوم کی دشمنی کا باعث انصاف کو ہر گز نہ چھوڑو انصاف کرو یہی بات تقویٰ کے زیادہ نزدیک ہے اور الله سے ڈرتے رہو جو کچھ تم کرتے ہو بے شک الله اس سے خبردارہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@dclxxviii{الله نے ایمان والوں سے اور جو نیک کام کرتے ہیں بخشش اور بڑے اجر کا وعدہ کیا ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@dclxxix{اور جن لوگو ں نے کفر کیا اور ہماری آیتیں جھٹلائیں وہ دوزخی ہیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@dclxxx{اے ایمان والو! الله کا احسان اپنے اوپر یاد کرو جب لوگو ں نے ارادہ کیا کہ تم پر دست درازی کریں پھر الله نے ان کے ہاتھ تم پر اٹھنے سےروک دیئے اور الله سے ڈرتے رہو اور ایمان والوں کو الله ہی پر بھروسہ کرنا چاہیے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@dclxxxi{اور الله نے بنی اسرائیل سے عہد لیا تھا اور ہم نے ان میں سے بارہ سردار مقرر کیے اور الله نےکہا میں تمہارے ساتھ ہوں اگر تم نماز کی پابندی کرو گے اور زکواة دیتے رہو گے اور میرے سب رسولوں پر ایمان لاؤ گے اور ان کی مدد کرو گے اور الله کواچھے طور پر قرض دیتے رہو گے تو میں ضرور تمہارے گناہ تم سےدور کردوں گا اور تمہیں باغوں میں داخل کروں گا جن کے نیچے نہریں بہتی ہیں پھر جوکوئی تم میں سے اس کے بعد کافر ہوا وہ بے شک سیدھے راستے سے گمراہ ہوا\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@dclxxxii{پھر ان کی عہد شکنی کے باعث ہم نے ان پر لعنت کی اوران کے دلوں کوسخت کر دیا وہ لوگ کلام کو ا سکے ٹھکانے سے بدلتے ہیں اور اس نصیحت سے نفع اٹھانا بھول گئے جو انہوں کی گئی تھی اور تو ہمشیہ ان کی کسی نہ کسی خیانت پر اطلاع پاتا رہے گا مگر تھوڑے ان میں سے سو انہیں معاف کر اور درگزر کر بے شک الله نیکی کرنے والوں کو پسند کرتا ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@dclxxxiii{اورجو لوگ اپنے آپ کو نصاریٰ کہتے ہیں ان سے بھی ہم نے عہد لیا تھا پھر وہ اس نصیحت سے نفع اٹھانا بھول گئے جو انہیں کی گئی تھی پھر ہم نے ان کے درمیان ایک دوسرے دشمنی اور بغض قیامت تک کے لیے ڈال دیا اور الله ان کا کیا ہوا انہیں جتلا دے گا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@dclxxxiv{اے اہلِ کتاب تحقیق تمہارے پاس ہمارا رسول آیا ہے جو بہت سی چیزیں تم پر ظاہر کرتا ہے جنہیں تم کتاب سے چھاپتے تھے اوربہت سی چیزوں سے درگزرکرتا ہے بے شک تمہارے پاس الله کی طرف سے روشنی اور واضح کتاب آئی ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@dclxxxv{الله سلامتی کی راہیں دکھاتا ہے اسے جو اس کی رضا کا تابع ہو اور انہیں اپنے حکم سے اندھیروں سے روشنی کی طرف نکالتا ہے اور انہیں سیدھی راہ پر چلاتا ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@dclxxxvi{بے شک وہ کافر ہوئے جنہوں نے کہا الله تو وہی مسیح مریم کا بیٹا ہے کہہ دے پھر الله کے سامنے کس کا بس چل سکتا ہے اگر وہ چاہے کہ مسیح مریم کے بیٹے اور اس کی ماں اور جتنے لوگ زمین میں ہیں سب کو ہلاک کر دے اور آسمانوں اور زمین اور ان دونوں کے درمیان کی سلطنت الله ہی کے واسطے ہے جو چاہے پیدا کرتا ہے اور الله ہر چیز پر قادر ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@dclxxxvii{اوریہود اور نصاریٰ کہتے ہیں کہ ہم الله کے بیٹے اور اس کے پیارے ہیں کہہ دو پھر تمہارے گناہوں کے باعث وہ تمہیں کیوں عذاب دیتا ہے بلکہ تم بھی اور مخلوقات کی طرح ایک آدمی ہو جسے چاہے بخش دے اور جسے چاہے سزا دے اور آسمانوں اور زمین اوران دونوں کے درمیان کی سلطنت الله ہی کے لیے ہے اور اسی کی طرف لوٹ کر جانا ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@dclxxxviii{اے اہل کتاب تحقیق تمہارے پاس ہمارا پیغمبر آ یا جو تمہیں صاف صاف بتلاتا ہے ایسے وقت میں رسولوں کا سلسلہ موقوف تھا تاکہ تم یوں نہ کہنے لگو کہ ہمارے پاس کوئی خوشبخبری دینے والا اور ڈرانے والانہیں آیاسوتمہارےپاس خوشخبری دینے والااورڈرانےوالاآ گیا ہے اور الله ہر چیز پر قادر ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@dclxxxix{اور جب موسیٰ نے اپنی قوم سے کہاکہ اے میری قوم الله کا احسان اپنے اوپر یاد کرو جب کہ تم میں نبی پیدا کیے اور تمہیں بادشاہ بنایا اور تمہیں وہ دیا جو جہان میں کسی کو نہ دیا تھا\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@dcxc{اے میری قوم اس پاک زمین میں داخل ہو جاؤ جو الله نے تمہارے لیے مقرر کر دی اور پیچھے نہ ہٹو ورنہ نقصان میں جا پڑو گے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@dcxci{انہوں نے کہا اے موسیٰ بے شک وہاں ایک زبردست قوم ہے اور ہم وہاں ہرگز نہ جائیں گے یہاں تک کہ وہ وہاں سے نکل جائیں پھراگروہ وہاں سےنکل جائیں تو ہم ضرور داخل ہو ں گے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@dcxcii{الله سے ڈرنے والوں میں سے دو مردوں نے کہا جن پر الله کا فضل تھا کہ ان پر حملہ کر کے دروازہ میں گھس جاؤ پھر جب تم اس میں گھس جاؤ گے تو تم ہی غالب ہو گے اور الله پر بھروسہ رکھو اگر تم ایمان دار ہو\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@dcxciii{کہا اے موسیٰ ہم کبھی وہاں داخل نہیں ہو ں گے جب تک کہ وہ اس میں ہیں سو تو اور تیرا رب جائے اور تم دونوں لڑو ہم تو یہیں بیٹھیں ہیں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@dcxciv{موسیٰ نے کہا اے میرے رب میرے اختیار میں تو سوائے میری جان اور میرے بھائی کے اور کوئی نہیں سو ہمارے درمیان اور اس نافرمان قوم کے درمیان جدائی ڈال دے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@dcxcv{فرمایا تحقیق وہ زمین ان پر چالیس بر س حرام کی گئی ہے اس ملک میں سرگرداں پھریں گے سو تو نافرمان قوم پر افسوس نہ کر\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@dcxcvi{تو اہلِ کتاب کو آدم کے دو بیٹوں کا قصہ صحیح طور پر پڑھکر سنا دے جب ان دونوں نے قربانی کی ان میں سے ایک کی قربانی قبول ہو گئی اور دوسرے کی نہ ہوئی اس نے کہا میں تجھے مار ڈالوں گا اس نے جواب دیا الله پرہیز گاروں ہی سے قبول کرتا ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@dcxcvii{اگرتو مجھے قتل کرنے کے لیے ہاتھ اٹھائے گا تو میں تجھے قتل کرنے کے لیے ہاتھ نہ اٹھاؤں گا میں الله رب العالمین سے ڈرتا ہوں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@dcxcviii{میں چاہتا ہوں کہ میرا اور اپنا گناہ تو ہی سمیٹ لے اور دوزخی بن جائے اور ظالموں کی یہی سزا ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@dcxcix{پھر اسے اس کے نفس نے اپنے بھائی کے خون پر راضی کر لیا پھر اسے مار ڈالا پس وہ نقصان اٹھانے والوں میں سے ہو گیا\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@dcc{پھر الله نے ایک کوا بھیجا جو زمین کریدتا تھا تاکہ اسے دکھلائے کہ اپنے بھائی کی لاش کو کس طرح چھپاتا ہے اس نے کہا افسوس مجھ پر اس کوے جیسا بھی نہ ہو سکا کہ اپنے بھائی کی لاش چھپانے کی تدبیر کرتا پھر پچھتانے لگا\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@dcci{اس سبب سے ہم نے بنی اسرائیل پر لکھا کہ جس نے کسی انسان کو خون کے بدلے یا زمین میں فساد پھیلانے کے سوا کسی اور وجہ سے قتل کیا گویا اس نے تمام انسانوں کو قتل کر دیا اورجس نے کسی کو زندگی بخشی اس نے گویا تمام انسانوں کی زندگی بخشی اورہمارے رسولوں ان کے پاس کھلے حکم لا چکے ہیں پھر بھی ان میں سے بہت لوگ زمین میں زیادتیاں کرنے والے ہیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@dccii{ان کی بھی یہی سزا ہے جو الله اوراس کے رسول سے لڑتے ہیں اورملک میں فساد کرنے کو دوڑتے ہیں یہ کہ ان کو قتل کیا جائے یا وہ سولی چڑھائے جائیں یا ان کے ہاتھ اور پاؤں مخالف جانب سے کاٹے جائیں یا وہ جلا وطن کر دیے جائیں یہ ذلت ان کے لیے دنیا میں ہے اور آخرت میں ان کے لیے بڑا عذاب ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@dcciii{مگر جنہوں نے تمہارے قابو پانے سے پہلے توبہ کر لی تو جان لو کہ الله بخشنے والا مہربان ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@dcciv{اے ایمان والو الله سے ڈرو اور الله کا قرب تلاش کرو اور الله کی راہ میں جہاد کرو تاکہ تم کامیاب ہو جاؤ\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@dccv{بے شک جو لوگ کافر ہیں اگر ان کے پاس دنیا بھر کی چیزیں ہوں اور اس کے ساتھ اتنا ہی اور ہو تاکہ قیامت کے عذاب سے بچنے کے لیے بدلہ میں دیں تو بھی ان سے قبول نہ ہوگا اوران کے لیے دردناک عذاب ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@dccvi{وہ چاہیں گے ُکہ آگ سے نکل جائیں حالانکہ وہ اس سے نکلنے والے نہیں اور ان کے لیے دائمی عذاب ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@dccvii{اور چور خواہ مرد ہو یا عورت دونوں کے ہاتھ کاٹ دو یہ ان کی کمائی کا بدلہ اور الله کی طرف سے عبرت ناک سزا ہے اور الله غالب حکمت والا ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@dccviii{پھر جس نے اپنے ظلم کے بعد توبہ کی اور اصلاح کر لی تو الله اس کی توبہ قبول کر لے گا بے شک الله بخشنے والا مہربان ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@dccix{کیا تجھے معلوم نہیں کہ آسمانوں اور زمین کی سلطنت الله ہی کے واسطے ہے وہ جسے چاہے عذاب دے اور جسے چاہے بخش دے اور الله سب چیزوں پر قادر ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@dccx{اے رسول انکا غم نہ کر جو دوڑ کر کفر میں گرتے ہیں وہ لوگ جو اپنے منہ سے کہتے ہیں کہ ہم مومن ہیں حالانکہ ان کے دل مومن نہیں ہیں اور وہ جو یہودی ہیں جھوٹ بولنے کے لیے جاسوسی کرتے ہیں وہ دوسری جماعت کے جاسوس ہیں جو تجھ تک نہیں آئی بات کو اس کےٹھکانے سے بدل دیتے ہیں کہتے ہیں کہ تمہیں یہ حکم ملے تو قبول کر لینا اور اگر یہ نہ ملے تو بچتے رہنا اور جسے الله گمراہ کرنا چاہے سو تو الله کے ہاں ا سکے لیے کچھ نہیں کر سکتا یہ وہی لوگ ہیں جن کے دل پاک کرنے کا الله نے ارادہ نہیں کیا ان کے لیے دنیا میں ذلت ہے اور آخرت میں بڑا عذا ب ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@dccxi{جھوٹ بولنے کے لیے جاسوسی کرنے والے ہیں اور بہت حرام کھانے والے ہیں سو اگر وہ تیرے پاس آئیں تو ان میں فیصلہ کر دے یا ان سے منہ پھیر لے اور اگر تو ان سے منہ پھیر لے گا تو وہ تیرا کچھ نہ بگاڑ سکیں گے اور اگر تو فیصلہ کرے تو ان میں انصاف سے فیصلہ کر بے شک الله انصاف کرنے والوں کو دوست رکھتا ہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@dccxii{اور وہ تجھے کس طرح منصف بنائیں گے حالانکہ ان کے پاس تو تورات ہے جس میں الله کا حکم ہے پھر اس کے بعد ہٹ جاتے ہیں اور یہ مومن نہیں ہیں\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@dccxiii{ہم نے تورات نازل کی کہ اس میں ہدایت اور روشنی ہے اس پر پیغمبر جو الله کے فرمانبردار تھے یہود کو حکم کرتے تھے اور اس کی خبر گیری پر مقرر تھے سوتم لوگو ں سے نہ ڈرو اور مجھ سے ڈرو اور میری آیتوں کے بدلے میں تھوڑا مول مت لو اور جو کوئی اس کے موافق فیصلہ نہ کر لے جو الله نے اتارا تو وہی لوگ کافر ہیں\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@dccxiv{اور ہم نے ان پراس کتاب میں لکھا تھا کہ جان بدلے جان کے اور آنکھ بدلے آنکھ کے اور ناک بدلے ناک کے اور کان بدلے کان کے اور دانت بدلے دانت کے اور زخموں کا بدلہ ان کے برابر ہے پھر جس نے معاف کر دیا تو وہ گناہ سے پاک ہو گیا اور جو کوئی اس کے موافق حکم نہ کرے جو الله نے اتارا سو وہی لوگ ظالم ہیں\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@dccxv{اور ہم نے ان کے پیچھے ان ہی کے قدموں پر عیسیٰ مریم کے بیٹے کو بھیجا جو اپنے سے پہلی کتاب تورات کی تصدیق کرنے والا تھا اور ہم نے اسے انجیل دی جس میں ہدایت اور روشنی تھی اپنے سے پہلی کتاب تورات کی تصدیق کرنے والا تھا اور راہ بتانے والی اور ڈرنے والوں کیلئے نصیحت تھی\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@dccxvi{اور چاہیئے کہ ابخیل والے اس کے موافق حکم کریں جو الله نےاس میں اتارا ہے اور جو چیز الله نے اتاری ہے جو شخص اس کے موافق حکم نہ کرے سو وہی لوگ نافرمان ہیں\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@dccxvii{ہم نے تجھ پر سچی کتاب اتاری جو اپنے سے پہلی کتابوں کی تصدیق کرنے والی ہے اور ان کے مضامین پر نگہبانی کرنے والی ہے سو تو ان میں اس کے موافق حکم کر جو الله نے اتارا ہے اور جو حق تیرے پاس آیا ہے اس سے منہ موڑ کر ان کی خواہشات کی پیروی نہ کر ہم نے تم میں سے ہر ایک کے لیے ایک شریعت اور واضح راہ مقرر کر دی ہے اور اگر الله چاہتا تو سب کو ایک ہی امت کر دیتا لیکن وہ تمہیں اپنے دیے ہوئے حکموں میں آزمانا چاہتا ہے لہذا نیکیوں میں ایک دوسرے سے بڑھنے کی کوشش کرو تو سب کو الله کے پاس پہنچنا ہے پھر تمہیں جتائے گا جس میں تم اختلاف کرتے تھے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@dccxviii{اور فرمایا کہ تو ان میں اس کے موافق حکم کر جو الله نے تارا ہے اوران کی خواہشوں کی پیروی نہ کر اوران سے بچتا رہ کہ تجھے کسی ایسے حکم سے بہکا نہ دیں جو الله نے تجھ پر اتارا ہے پھر اگر یہ منہ موڑیں تو جان لو کہ الله کا اردہ انہیں ان کے بعض گناہوں کی پاداش میں مصیبت میں مبتلا کرنے کا ہے اور لوگوں میں بہت سے نافرمان ہیں\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@dccxix{تو کیا پھر جاہلیت کا فیصلہ چاہتے ہیں حالانکہ جو لوگ یقین رکھنے والے ہیں ان کے ہاں الله سے بہتر اور کوئی فیصلہ کرنے والا نہیں\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@dccxx{اے ایمان والو یہود اور نصاریٰ کو دوست نہ بناؤ وہ آپس میں ایک دوسرے کے دوست ہیں اور جو کوئی تم میں سے ان کے ساتھ دوستی کرے تو وہ ان میں سے ہے الله ظالموں کو ہدایت نہیں کرتا\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@dccxxi{پھر تو ان لوگوں کو دیکھے گا جن کے دلوں میں بیماری ہے ان میں دوڑ کر جا ملتے ہیں کہتے ہیں کہ ہمیں ڈر ہے کہ ہم پر زمانے کی گردش نہ آ جائے سو قریب ہے کہ الله جلدی فتح ظاہر فرماد ے یا کوئی اور حکم اپنے ہاں سے ظاہر کرے پھر یہ اپنے دل کی چھپی ہوئی بات پر شرمندہ ہوں گے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@dccxxii{اور مسلمان کہتے ہیں کیا یہ وہی لوگ ہیں جو الله کے نام کی پکی قسمیں کھاتے تھے کہ ہم تمہارے ساتھ ہیں ان کے اعمال برباد ہو گئے پھر وہ نقصان اٹھانے والے ہو گئے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@dccxxiii{اے ایمان والو جو کوئی تم میں سے اپنے دین سے پھر جائے گا تو عنقریب الله ایسی قوم کو لائے گا کہ الله ان کو چاہتا ہے اور وہ اس کو چاہتے ہیں مسلمانوں پر نرم دل ہوں گے اور کافروں پر زبردست الله کی راہ میں لڑیں گے اور کسی کی ملامت سے نہیں ڈریں گے یہ الله کا فضل ہے جسے چاہے دیتا ہے اور الله کشائش والا جاننے والا ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@dccxxiv{تمہارا دوست تو الله اور اس کا رسول اور ایمان دار لوگ ہیں جو نماز قائم کرتے ہیں اور زکواة دیتے ہیں اور وہ عاجزی کرنے والے ہیں\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@dccxxv{اور جو شخص الله اور اس کے رسول اور ایمان داروں کو دوست رکھے تو الله کی جماعت وہی غالب ہونے والی ہے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@dccxxvi{اے ایمان والو! ان لوگوں کو اپنا دوست نہ بناؤ جنہوں نے تمہارے دین کو ہنسی اور کھیل بنا رکھا ہے ان لوگو ں میں سے جنہیں تم سے پہلے کتاب دی گئی اور کافروں کو اور الله سے ڈرو اگر تم ایمان دار ہو\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@dccxxvii{اور جب تم نماز کے لیے پکارتے ہو تو وہ لوگ اس کے ساتھ ہنسی اور کھیل کرتے ہیں یہ ا س واسطے کہ وہ لوگ بے عقل ہیں\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@dccxxviii{کہہ دو اے اہلِ کتاب تم ہم میں کون سا عیب پاتے ہو بجز اس کے کہ ہم الله پر ایمان لائے ہیں اوراس پر جو ہمارے پاس بھیجی گئی ہے اور اس پر جو پہلے بھیجی جا چکی ہے باوجود اس کے تم میں اکثر لوگ نافرمان ہیں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@dccxxix{کہہ دو میں تم کو بتلاؤں الله کے ہاں ان میں سے کس کی بری جزا ہے وہی جس پر الله نے لعنت کی اور اس پر غضب نازل کیا اور بعضوں کو ان میں سے بندربنا دیا اور بعضوں کو سور اورجنہوں نے شیطان کی بندگی کی وہی لوگ درجہ میں بدتر ہیں اور راہِ راست سے بھی بہت دور ہیں\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@dccxxx{اور جب تمہارے پاس آتے ہیں تو کہتے ہیں کہ ہم ایمان لائے حالانکہ وہ کافر ہی آئے تھے اور کافر ہی گئے اور الله خوب جانتا ہے جو کچھ وہ چھپاتے تھے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@dccxxxi{اور تو ان میں سے اکثر کو دیکھے گا کہ گناہ اور ظلم پر اور حرام کھانے پر دوڑتے ہیں بہت برا ہے جو کچھ وہ کر رہے ہیں\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@dccxxxii{ان کے فقراء اور علماء گناہ کی بات کہنے اور حرام مال کھانے سے انہیں کیوں نہیں منع کرتے البتہ بری ہے وہ چیز جو وہ کرتے ہیں\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@dccxxxiii{اور یہود کہتے ہیں الله کا ہاتھ بند ہوگیا ہے انہیں کے ہاتھ بند ہوں اور انہیں اس کہنے پر لعنت ہے بلکہ اس کے دونوں ہاتھ کھلے ہوئے ہیں جس طرح چاہے خرچ کرتا ہے جو کلام تیرے رب کی طرف سے تم پر نازل ہوا ہے وہ ان میں سے اکثر لوگوں کی سرکشی اور کفر میں زیادتی کا باعث بن گیا اور ہم نے ان کے درمیان قیامت تک عداوت اور دشمنی ڈال دی ہے جب کبھی لڑائی کے لیے آگ سلگاتے ہیں تو الله اس کو بجھا دیتا ہے یہ زمین میں فساد پھیلانے کی کوشش کرتے ہیں اور الله فساد کرنے والوں کو پسند نہیں کرتا\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@dccxxxiv{اور اگر اہل کتاب ایمان لاتے اور ڈرتے تو ہم ان میں سے ان کی برائياں دور کر دیتے اور ضرور انہیں نعمت کے باغوں میں داخل کر تے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@dccxxxv{اور اگر وہ تورات اور انجیل کوقائم رکھتے اور اس کو جو ان پر ان کے رب کی طرف سے نازل ہوا ہے تو اپنے اوپر سے اور اپنے پاؤں کے نیچے سے کھاتے کچھ لوگ ان میں سیدھی راہ پر ہیں اور اکثر ان میں سے برے کام کر رہے ہیں\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@dccxxxvi{اے رسول جو تجھ پر تیرے رب کی طرف سے اترا ہے اسے پہنچا دے اور اگر تو نے ایسا نہ کیا تو اس کی پیغمبری کا حق ادا نہیں کیا اور الله تجھے لوگوں سے بچائے گا بے شک الله کافروں کی قوم کو راستہ نہیں دکھاتا\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@dccxxxvii{کہہ دو اے اہل کتاب تم کسی راہ پر نہیں ہو جب تک کہ تم تورات اور انجیل اور جو چیز تمہارے رب کی طرف سے نازل کی گئی ہے قائم نہ کرو اور ضرور ہے کہ یہ فرمان جو تم پرنازل ہوا ہے ان میں سے اکثر کی سرکشی اور انکار کو اور زيادہ بڑھائے گا مگر انکار کرنے والاوں کے حال پر کچھ افسوس نہ کرو\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@dccxxxviii{بے شک جو مسلمان ہیں اور جو یہودی ہیں اور صائبی اور نصاریٰ جو کوئی الله اور قیامت پر ایمان لایا اور نیک کام کیے تو ان پر کوئی خوف نہیں ہوگا اور نہ وہ غمگین ہوں گے\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@dccxxxix{ہم نے بنی اسرائیل سے پختہ وعدہ لیا تھا اور ان کی طرف کئی رسول بھیجے تھے جب کبھی کوئی رسول ان کے پاس وہ حکم لایا جو ان کے نفس نہیں چاہتے تھے تو ایک جماعت کو جھٹلایا اور ایک جماعت کو قتل کر ڈالا\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@dccxl{اور یہی گمان کیا کہ کوئی فتنہ نہیں ہوگا پھر اندھے اور بہرے ہوئے پھر الله نے ان کی توبہ قبول کی پھر ان میں سے اکثر اندھے اور بہرے ہو گئے اور جو کچھ وہ کرتے ہیں الله دیکھتا ہے\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@dccxli{البتہ تحقیق وہ لوگ کافر ہوئے جنہوں نے کہا بے شک الله وہی مسیح مرین کا بیٹا ہی ہے حالانکہ مسیح نے کہا اے بنی اسرائیل اس الله کی بندگی کرو جو میرا اور تمہارا رب ہے بے شک جس نے الله کا شریک ٹھیرایا سو الله نے اس پر جنت حرام کی اور اس کا ٹھکانا دوزخ ہے اور ظالموں کا کوئی مددگار نہیں ہو گا\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@dccxlii{جنہوں نے کہا الله تین میں سے ایک ہے بے شک وہ کافر ہوئے حالانکہ سوائے ایک معبود کے اورکوئی معبود نہیں اور اگر وہ اس بات سے باز نہ آئيں گے جو وہ کہتے ہیں تو ان میں سے کفر پر قائم رہنے والوں کو دردناک عذاب پہنچے گا\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@dccxliii{الله کے آگے کیوں توبہ نہیں کرتے اور اس سے گناہ نہیں بخشواتے اور الله بخشنے والا مہربان ہے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@dccxliv{مسیح مریم کا بیٹا تو صرف ایک پیغمبر ہی ہے جس سے پہلے اور بھی پیغمبر گزر چکے ہیں اور اس کی ماں ولی ہے وہ دونوں کھانا کھاتے تھے دیکھ ہم انہیں کیسی دلیلیں بتلاتے ہیں پھر دیکھووہ کہاں الٹے جا تے ہیں\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@dccxlv{کہہ دو تم الله کر چوڑ کر ایسی چیز کی بندگی کرتے ہو جو تمہارے نقصان اور نفع کے مالک نہیں اور الله وہی ہے سننے والا جاننے والا\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@dccxlvi{کہہ اے اہلِ کتاب تم اپنے دین میں ناحق زیادتی مت کرو اور ان لوگو ں کی خواہشات کی پیروی نہ کرو جو اس سے پہلے گمراہ ہو چکے اور انہوں نے بہتوں کو گمراہ کیا اور سیدھی راہ سے دور ہو گئے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@dccxlvii{بنی اسرائیل میں سے جو کافر ہوئے ان پر داؤد اور عیسیٰ بیٹے مریم کی زبان پر لعنت کی گئی یہ اس لیے کہ وہ نافرمان تھے اور حد سے گزر گئے تھے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@dccxlviii{آپس می ں برے کام سے منع نہ کرتے تھے جو وہ کر رہے تھے کیسا ہی برا کام ہےجووہ کرتے تھے\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@dccxlix{تو دیکھے گا تو ان میں سے بہت سے لوگ کافروں سے دوستی رکھتے ہیں انہوں نے کیسا ہی برا سامان اپنے نفسوں کے لیے آگے بھیجا اور وہ یہ کہ ان پر الله کا غضب ہوا اور وہ ہمیشہ عذاب میں رہنے والے ہیں\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@dccl{اور اگر وہ الله اور نبی پر اور اس چیز پر جواس کی طرف سے نازل کی گئی ہے ایمان لاتے تو کافروں کو دوست نہ بناتے لیکن ان میں سے اکثر لوگ نافرمان ہیں\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@dccli{تو سب لوگو ں سے زیادہ مسلمانوں کا دشمن یہودیوں اور مشرکوں کو پائے گا اور تو سب سے نزدیک محبت میں مسلمانوں سے ان لوگوں کو پائے گا جو کہتے ہیں کہ ہم نصاریٰ ہیں یہ اس لیے اکہ ان میں علماء اور فقراء ہیں اور اس لیے کہ وہ تکبر نہیں کرتے\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@dcclii{اور جب اس چیز کو سنتے ہیں جو رسول پر اتری تو ان کی آنکھوں کو دیکھے گا کہ آنسوؤں سے بہتی ہیں اس لیے کہ انہوں نے حق کو پہچان لیا کہتے ہیں اے رب ہمارے کہ ہم ایمان لائے تو ہمیں ماننے والوں کے ساتھ لکھ لے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@dccliii{اور ہمیں کیا ہے ہم الله پر ایمان نہ لائيں اور اس چیز پر جو ہمیں حق سے پہنچی ہے اور اس کی طمع رکھتے ہیں کہ ہمیں ہمارا رب نیکو ں میں داخل کر ے گا\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@dccliv{پھر الله نے انہیں اس کہنے کے بدلے ایسے باغ دئیے کہ جن کے نیچے نہریں بہتی ہیں ان میں ہمیشہ رہیں گے اور نیکی کرنے والوں کا یہی بدلہ ہے\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@dcclv{اور وہ لوگ جو کافر ہوئے اور ہماری آیتوں کو جھٹلایا وہ دوزخ کے رہنے والے ہیں\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@dcclvi{اے ایمان والو ان ستھری چیزوں کو حرام نہ کرو جو الله نے تمہارے لیے حلال کی ہیں اور حد سے نہ بڑھو بے شک الله حد سے بڑھنے والوں کو پسند نہیں کرتا\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@dcclvii{اور الله کے رزق میں سے جو چیز حلال ستھری ہو کھاؤ اور الله سے ڈرو جس پر تم ایمان رکھتے ہو\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@dcclviii{الله تمہیں تمہاری بی ہودہ قسموں پر نہیں پکڑتا لیکن ان قسموں پرپکڑتا ہے جنہیں تم مستحکم کر دو سو اس کا کفارہ دس مسکینوں کو اوسط درجہ کا کھانا دینا ہے جو تم اپنے گھر والوں کو دیتے ہو یا دس مسکینوں کو کپڑا پہنانا یا گردن آزاد کرنی پھر جو شخص یہ نہ پائے تو تین دن کے روزے رکھنے ہیں اسی طرح تمہای قسموں کا کفارہ ہے جب تم قسم کھاؤ اور اپنی قسموں کی حفاظت کرو اسی طرح تمہارے لیے اپنے حکم بیان کرتا ہے تاکہ تم شکر کرو\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@dcclix{اے ایمان والو شراب اور جوا اور بت اور فال کے تیر سب شیطان کے گندے کام ہیں سو ان سے بچتے رہو تاکہ تم نجات پاؤ\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@dcclx{شیطان تو یہی چاہتا ہے کہ شراب اور جوئے کے ذریعے سےتم میں دشمنی اور بغض ڈال دے اور تمہیں الله کی یاد سے اور نماز سے روکے سو اب بھی باز آجاؤ\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@dcclxi{اور الله اور رسول کا حکم مانو اور بچتے رہو پھر اگر تم پھر جاوگےتوجان لو کہ ہمارے رسول کے ذمہ صرف کھول کر پہنچا دینا ہی ہے\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@dcclxii{جو لو گ ایمان لائے اور نیک کام کیے ان پر اس میں کوئی گناہ نہیں جو پہلے کھا چکے جب کہ آئندہ کو پرہیزگار ہوئے اور ایمان لائے اور عمل نیک کیے پھر پرہیزگار ہوئے اور نیکی کی اور الله نیکی کرنے والوں کو دوست رکھتا ہے\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@dcclxiii{اے ایمان والو! البتہ ایک بات سے تمہیں آزمائے گا اس شکار سے جس پر تمہارے ہاتھ اور تمہارے نیزے پہنچیں گے تاکہ الله معلوم کرے کہ بن دیکھے اس سے کون ڈرتا ہے پھر جس نے اس کے بعد زیادتی کی تو اس کے لیے دردناک عذاب ہے\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@dcclxiv{اے ایمان والو! جس وقت تم احرام میں ہو تو شکار کونہ قتل کرو اور جو کوئی تم میں سے اسےجان بوجھ کر مارے تو اس مارے ہوئے کے برابر مویشی میں سے اس پر بدلہ لازم ہے جو تم میں سے دو معتبر آدمی تجویز کریں بشرطیکہ قربانی کعبہ تک پہنچنے والی ہو یا کفارہ مسکینوں کا کھانا کھلانا ہو یا اس کے برابر روزے تاکہ اپنے کام کا وبال چکھے الله نے اس چیز کو معاف کیا جو گزر چکی اور جو کوئی پھر کرے گا الله اس سے بدلہ لے گا اور الله غالب بدلہ لینے والا ہے\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@dcclxv{تمہارے لیے دریا کا شکار کرنا اوراس کا کھانا حلال کیا گیا ہے تمہارے واسطے اور مسافروں کے لیے فائدہ ہے اور تم پر جنگل کا شکار کرناحرام کیا گیا ہے جب تک کہ تم احرام میں ہو اور اس الله سے ڈرو جس کی طرف جمع کیے جاؤ گے\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@dcclxvi{الله نے کعبہ کو جو بزرگی والا گھر ہے لوگوں کے لیے قیام کا باعث کر دیا ہے اور عزت والے مہینے کو اور حرم میں قربانی والے جانور کو بھی اور جن کے گلے میں پٹہ ڈال کر کر کعبہ کو لے جائیں یہ اس لیے ہے کہ تم جان لو کہ بے شک الله کو معلوم ہے کہ جو کچھ آسمانوں اور زمین میں ہے اور بے شک الله ہر چیز کو جاننے والا ہے\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@dcclxvii{جان لو بے شک الله سخت عذاب والا ہے اور بے شک الله بخشنے والا مہربان ہے\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@dcclxviii{رسول کے ذمہ سوائے پہنچانے کے اورکچھ نہیں اور الله کو معلوم ہے جو تم ظاہر کرتے ہو اور جو چھپ کر کرتے ہو\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@dcclxix{کہہ دو کہ ناپاک اور پاک برابر نہیں اگرچہ تمہیں ناپاک کی کثرت بھی معلوم ہو سو اے عقل مندو الله سے ڈرتے رہو تاکہ تمہاری نجات ہو\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@dcclxx{اے ایمان والو! ایسی بات مت پوچھو کہ اگر تم پر ظاہر کی جائیں تو تمہیں بری لگیں اور اگر یہ باتیں یسے وقت میں پوچھو گے جب کہ قرآن نازل ہو رہا ہے تو تم پر ظاہر کر دی جائیں گی گذشتہ سوالات الله نے معاف کر دیے ہیں اور الله بخشنے والا بردبار ہے\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@dcclxxi{ایسی باتیں تم سے پہلے ایک جماعت پوچھ چکی ہے پھر وہ ان باتوں کے وہ مخالف ہوگئے\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@dcclxxii{الله نے بحیرہ اور سائبہ اور وصیلہ اور حام مقرر نہیں کیے لیکن کافر الله پر بہتان باندھتے ہیں اور ان میں سے اکثر بیوقوف ہیں\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@dcclxxiii{اور جب انہیں کہا جاتا ہے اس کی طرف آؤ جو الله نے نازل کیا ہ اور رسول کی طرف تو کہتے ہیں ہمیں وہ کافی ہے جس پر ہم نے باپ دادا کو پایا بھلا اگر چہ ان کے باپ دادانہ کچھ علم رکھتے ہوں نہ انہوں نے ہدایت پائی ہو تو بھی ایسا ہی کریں گے\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@dcclxxiv{اے ایمان والو! تم پر اپنی جان کی فکر لازم ہے تمہارا کچھ نہیں بگاڑتا جو کوئی گمراہ ہو جب کہ تم ہدایت یافتہ ہو تم سب کو الله کی طرف لوٹ کر جانا ہے پھر وہ تمہیں بتلا دے گا جو کچھ تم کرتے تھے\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@dcclxxv{اے ایمان والو! جب کہ تم میں سے کسی کو موت آ پہنچے تو وصیت کے وقت تمہارے درمیان تم میں سے معتبر آدمی گواہ ہو نے چاہیئیں یا تمہارے سوا دو گواہ اور ہوں اگر تم نے زمین پر سفر کیاہو پھر تمہیں موت کی مصیبت آ پہچنے ان دونوں کو نماز کے بعد کھڑا کرو وہ دونوں الله کی قسمیں کھائیں اگر تمہیں کہیں شبہ ہو کہ ہم قسم کے بدلے مال نہیں لیتے اگرچہ رشتہ داری ہی کیوں نہ ہو اور ہم الله کی گواہی نہیں چھپاتے ورنہ ہم بے شک گناہگار ہوں گے\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@dcclxxvi{پھر اگر اس بات کی اطلاع ہو جائے کہ وہ دونوں گناہ کے مستحق ہوئے تو ان کی جگہ اور دو گواہ کھڑےہوں ان میں سے جن کا حق دبایا گیا ہے جو سب سے زیادہ میت کے قریب ہوں پھر الله کی قسم کھائیں کہ ہماری گواہی ان کی گواہی سے زیادہ سچی ہے اور ہم نے زیادتی نہیں کی ورنہ ہم بے شک ظالموں میں سے ہوں گے\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@dcclxxvii{یہ اس امر کا قریب ذریعہ ہے کہ وہ لوگ واقع کو ٹھیک طور پر ظاہر کر دیں یہ اس بات سے ڈر جائیں کہ قسمیں ان کی قسموں کے بعد رد کی جائیں گی ارو الله سے ڈرتے رہو اور سنو اور الله نافرمانوں کو سیدھی راہ پر نہیں چلاتا\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@dcclxxviii{جن دن الله سب پیغمبروں کو جمع کرے گا پھر کہے گا تمہیں کیا جواب دیا گیا تھا وہ کہیں گے ہمیں کچھ خبر نہیں تو ہی چھپی باتو ں کا جاننے والا ہے\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@dcclxxix{جب الله کہے گا اے عیسیٰ مریم کے بیٹے میرا احسان یاد کر جو تجھ پر اور تیری ماں پر ہوا ہےجب میں نے روح پاک سے تیری مدد کی تو لوگوں سے گود میں اور ادھیڑ عمر میں بات کرتا تھا اور جب میں نے تجھے کتاب اورحکمت اور تورات اور انجیل سکھائی اور جب تو مٹی سے جانور کی صورت میرے حکم سے بناتا تھا پھرتو اس میں پھونک مارتا تھا تب وہ میرے حکم سے اڑنے والا ہو جاتا تھا اور مادر زاد اندھے کو اور کوڑھی کومیرے حکم سے اچھا کرتا تھا اور جب مردوں کو میرے حکم سے نکال کھڑا کرتا تھا اور جب میں نے بنی اسرائیل کو تجھ سے روکا جب تو ان کے پاس نشانیاں لے کر آیا تو جو ان میں کافر تھے وہ کہنے لگے اور کچھ نہیں یہ تو صریح جادو ہے\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@dcclxxx{اورجب میں نے حواریوں کے دل میں ڈال دیا کہ مجھ پر اور میرے رسول پر ایمان لاؤ تو کہنے لگے ہم یمان لائے اور تو گواہ رہے کہ ہم الله کے فرمانبردار ہیں\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@dcclxxxi{جب حواریوں نے کہا اے عیسیٰ مریم کے بیٹے کیا تیرا رب کر سکتا ہے کہ ہم پر خوان بھرا ہوا آسمان سے اتارے کہا الله سے ڈرو اگر تم ایمان دار ہو\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@dcclxxxii{انہوں نے کہا ہم چاہتے ہیں کہ اس میں سے کھائیں اور ہمارے دل مطمئن ہو جائیں اور ہم جان لیں کہ تو نے ہم سے سچ کہا ہے اور ہم اس پر گواہ ر ہیں\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@dcclxxxiii{عیسیٰ مریم کے بیٹے نے کہا اے اللهرب ہمارے ہم پر بھرا ہوا خوان آسمان سے اتار جو ہمارے پہلوں اور پچھلوں کیلئے عید ہو اور تیری طرف سےایک نشانی ہو اور ہمیں رزق دے اور تو ہی سب سے بہتر رزق دینے والا ہے\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@dcclxxxiv{الله نے فرمایا بے شک میں وہ خوان تم پر اتارو ں گا پھر اس کے بعد جو کوئی تم میں سے ناشکری کرے گا تو میں اسے ایسی سزا دوں گا جو دنیا میں کسی کو نہ دی ہو گی\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@dcclxxxv{اور جب الله فرمائے گا اے عیسیٰ مریم کے بیٹے کیا تو نے لوگو ں سے کہا تھا کہ خدا کے سوا مجھے اور میری ماں کو بھی خدا بنا لو وہ عرض کرے گا تو پاک ہے مجھے لائق نہیں ایسی بات کہوں کہ جس کا مجھے حق نہیں اگر میں نے یہ کہا ہوگا تو تجھے ضرور معلوم ہو گا جو میرے دل میں ہے تو جانتا ہے اور جو تیرے دل میں ہے وہ میں نہیں جانتا بے شک تو ہی چھپی ہوئی باتو ں کا جاننے والا ہے\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@dcclxxxvi{میں نے ان سے اس کے سوا کچھ نہیں کہا جس کا تو نے مجھے حکم دیا تھا کہ الله کی بندگی کرو جو میرا اور تمہارا رب ہے اور میں اس وقت تک ان کا نگران تھا جب تک ان میں رہا پھر جب تو نے مجھے اٹھا لیا تو تو ہی ان کا نگران تھا اور تو ہر چیز سے خبردار ہے\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@dcclxxxvii{اگر تو انہیں عذاب دے تو وہ تیرے ہی بندے ہیں اور اگر تو انہیں معاف کر دے تو تو ہی زبردست حکمت والا ہے\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@dcclxxxviii{الله فرمائے گا یہ وہ دن ہے جس میں سچوں کو ان کا سچ کام آئے گا ان کے لیے باغ ہیں جن کے نیچے نہریں بہتی ہیں ان میں سے ہمیشہ رہنے والے ہوں گے ان سے الله راضی ہوا اور وہ اس سے راضی ہوئے یہی بڑی کامیابی ہے\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@dcclxxxix{آسمانوں اور زمین اور جو کچھ ان کے درمیان ہے سب الله ہی کی سلطنت ہے اور وہ ہرچیز پر قادر ہے\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@dccxc{\basmalahur سب تعریف الله ہی کے لیے ہے جس نے آسمان اور زمین بنائے اور اندھیرا اوراجالا بنایا پھر بھی یہ کافر اوروں کو اپنے رب کے ساتھ برابر ٹھیراتے ہیں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@dccxci{الله وہی ہے جس نے تمہیں مٹی سے پیدا کیا پھر ایک وقت مقرر کر دیا اور اس کےہاں ایک مدت مقرر ہے تم پھر بھی شک کرتے ہو\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@dccxcii{اور وہی ایک الله آسمانوں میں بھی ہے اور زمین میں بھی تمہارے ظاہر اور چھپے سب حال جانتا ہے او رجانتا ہے جو کچھ تم کرتے ہو\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@dccxciii{ان کے رب کی نشانیوں میں سے کوئی نشانی ایسی نہیں جو ان کے سامنے آئی ہو اور انہوں نے منہ نہ موڑا ہو\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@dccxciv{اب جو حق ان کے پاس آیا تو اسے بھی انہوں نے جھٹلا دیا جس چیز کا اب تک وہ مذاق اڑاتے رہے ہیں عنقریب اس کے متعلق کچھ خبریں ان کو پہنچیں گی\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@dccxcv{کیا وہ دیکھتے نہیں کہ ہم ان سے پہلے بھی کتنی امتیں ہلاک کر دیں ہم نے انہیں زمین میں وہ اقتدار بخشا تھا جو تمہیں نہیں بخشا اور ہم نے ان پر آسمان سے خوب بارشیں برسائیں اوران کے نیچے نہریں بہا دیں پھر ہم نے انہیں ان کے گناہوں کی پاداش میں ہلاک کر دیا اور ہم نے ان کے بعد اور امتوں کو پیدا کیا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@dccxcvi{اور اگر ہم تم پر کوئی کاغذ پر لکھی ہوئی کتاب اتار دیتے اور لوگوں سے اپنے ہاتھوں سے چھو کر بھی دیکھ لیتے تب بھی کافر یہی کہتے ہیں کہ یہ تو صریح جادو ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@dccxcvii{اور کہتے ہیں اس پر کوئی فرشتہ کیوں نہیں اتارا گیا اور اگر ہم فرشتہ اتارے تو اب تک فیصلہ ہو چکا ہوتا پھر انہیں مہلت نہ دی جاتی\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@dccxcviii{اور اگر ہم کسی کو فرشتہ کو رسول بنا کر بھیجتے تو وہ بھی آدمی ہی کی صورت میں ہوتا اور انہیں اسی میں شبہ میں ڈالے جس میں اب مبتلا ہیں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@dccxcix{اور تم سے پہلے بھی بہت سے رسولوں کا مذاق اڑایا جا چکا ہے پھر جن لوگوں نے ان سے مذاق کیا تھا انہیں اسی عذاب نے آ گھیرا جس کا مذاق اڑاتے تھے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@dccc{کہہ دو کہ ملک میں سیر کرو پھر دیکھو جھٹلانے والوں کا کیا انجام ہوا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@dccci{ان سے پوچھو آسمان اور زمین میں جو کچھ ہے وہ کس کا ہے کہہ دو سب کچھ الله ہی کا ہے اس نے اپنے اوپر رحم لازم کر لیا ہے وہ قیامت کے دن تم سب کو ضرور اکھٹا کرے گا جس میں کچھ شک نہیں جو لوگ اپنی جانوں کا نقصان میں ڈال چکے وہ ایمان نہیں لاتے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@dcccii{اور الله ہی کا ہے جو کچھ رات اور دن میں پایا جاتا ہے اور وہی سننے والا جاننے والا ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@dccciii{کہہ دو جو الله آُسمانوں اور زمین کا بنانے والا ہے کیا اس کے سوا کسی اور کو اپنا مددگار بناؤں اور وہ سب کو کھلاتا ہے اور اسے کوئی نہیں کھلاتا کہہ دو مجھے تو حکم دیا گیا ہے کہ سب سے پہلے اس کا فرمانبردار ہو جاؤں اور تو ہرگز مشرکوں میں شامل نہ ہو\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@dccciv{کہہ دو اگر میں اپنے رب کی نافرمانی کروں تو ایک بڑے دن کےعذاب سے ڈرتا ہوں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@dcccv{جس سے اس دن عذاب ٹل گیا تو اس پر الله نے رحم کر دیا اور یہی بڑی کامیابی ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@dcccvi{اور اگر الله تجھے کوئی تکلیف پہنچائے تواس کے سوا اور کوئی دور کرنے والا نہیں اور اگر تجھے کوئی بھلائی پہنچائے تو وہ ہر چیز پر قادر ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@dcccvii{اوراپنے بندوں پر اسی کا زور ہے اور وہی حکمت والا خبردار ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@dcccviii{تو پوچھ سب سے بڑا گواہ کون ہے کہہ دو الله میرے اور تمہارے درمیان گواہ ہے اور مجھ پر یہ قرآن اتارا گیا ہے تاکہ تمہیں اس کے ذریعہ سے ڈراؤں اور جس جس کو یہ قرآن پہنچے کیا تم گواہی دیتے ہو کہ الله کے ساتھ اور بھی کوئی معبود ہیں کہہ دو میں تو گواہی نہیں دیتا کہہ دو وہی ایک معبود ہے اور میں تمہارے شرک سے بیزار ہوں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@dcccix{جنہیں ہم نے کتاب دی ہے وہ اسے پہچانتے ہیں جیسے اپنے بیٹوں کو پہچانتے ہیں اور جو لوگ اپنی جانوں کو نقصان میں ڈال چکے ہیں وہی ایمان نہیں لاتے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@dcccx{جو شخص الله پر بہتان باندھے یا اس کی آیتوں کو جھٹلائے اس سے زیادہ ظالم کون ہے بے شک ظالم نجات نہیں پائیں گے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@dcccxi{اور جس دن ہم ان سب کو جمع کریں گے پھر ان لوگوں سے کہیں گے جنہوں نے شرک کیا تھا تمہارے شریک کہاں ہیں جن کاتمہیں دعویٰ تھا\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@dcccxii{پھر سوائے اس کے ان کا اورکوئی بہانہ نہ ہوگا کہیں گے ہمیں الله اپنے پرودگار کی قسم ہے کہ ہم تو مشرک نہیں تھے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@dcccxiii{دیکھو اپنے اوپر انہوں نے کیسا جھوٹ بولا اور جو باتیں وہ بنایا کرتا تھے وہ سب غائب ہو گئیں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@dcccxiv{اور بعض ان میں سے تیری طرف کان لگائے رہتے ہیں اور ہم نے ان کے دلوں پر پردے ڈال رکھے ہیں جس کی وجہ سے وہ کچھ نہیں سمجھتے اور ان کے کانو ں میں گرانی ہے اور اگر یہ تمام نشانیاں بھی دیکھ لیں تو بھی ان پر ایمان نہ لادیں گے جب وہ تمہارے پاس آ کر تم سے جھگڑتے ہیں تو کافر کہتے ہیں کہ یہ تو پہلے لوگو ں کی کہانیاں ہی ہیں\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@dcccxv{اور یہ لوگ اس سے روکتے ہیں اور خود بھی اس سے دور بھاگتے ہیں اور انہیں ہلاک کر تے مگر اپنے آپ کو اور سمجھتے نہیں\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@dcccxvi{کاش تم اس وقت کی حالت دیکھ سکتے جب وہ دوزخ کے کنارے کھڑے کیے جائیں گے اس وقت کہیں گے کاش کوئی صورت ایسی ہو کہ ہم واپس بھیج دیے جائیں اور اپنے رب کی نشانیوں کو نہ جھٹلائیں اور ایمان والوں میں ہوجائیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@dcccxvii{بلکہ جس چیز کو اس سے پہلے چھپاتے تھے وہ ظاہر ہو گئی اور اگر یہ واپس بھیج دیے جائیں تب بھی وہی کام کریں گے جن سے انہیں منع کیا گیا تھا اور یقیناً یہ جھوٹے ہیں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@dcccxviii{اور کہتےہیں اس دنیا کی زندگی کے سوا ہمارے لیے اور کوئی زندگی نہیں اور ہم اٹھائے نہیں جائیں گے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@dcccxix{اور کاش کہ تو دیکھے جس وقت وہ اپنے رب کے سامنے کھڑے کیے جائیں گے وہ فرمائے گا کیا یہ سچ نہیں کہیں گے ہاں ہمیں رب کی قسم ہے فرمائے گا تو اپنے کفر کے بدلے عذاب چکھو\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@dcccxx{وہ لوگ تباہ ہوئے جنہوں نے اپنے رب کی ملاقات کو جھٹلایا یہاں تک کہ جب ان پر قیامت اچانک آ پہنچے گی تو کہیں گے اے افسوس ہم نے اس میں کیسی کوتاہی کی اور وہ اپنے بوجھ اپنے پیٹوں پر اٹھائیں گےخبرداروہ برا بوجھ ہے جسے وہ اٹھائیں گے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@dcccxxi{اور دنیا کی زندگی تو ایک کھیل اور تماشہ ہے اور البتہ آخرت کا گھر ان لوگوں کے لیے بہتر ہے جو پرہیزگار ہوئے کیا تم نہیں سمجھتے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@dcccxxii{ہمیں معلوم ہے کہ ان کی باتیں تمہیں غم میں ڈالتی ہیں سو وہ تجھے نہیں جھٹلاتے بلکہ یہ ظالم الله کی آیتوں کا انکار کرتے ہیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@dcccxxiii{اور بہت سے رسول تم سے پہلے جھٹلائے گئے پھر انہوں نےجھٹلائے جانے پر صبر کیا اور ایذا دیے گئے یہاں تک کہ ان کو ہماری مدد پہنچی اور الله کے فیصلے کوئی بدل نہیں سکتا اور تمہیں پیغمبروں کے حالات کچھ پہنچ چکے ہیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@dcccxxiv{اور اگر ان کا منہ پھیرنا تم پر گراں ہو رہا ہے پھر اگر تم سے ہو سکے تو کوئی سرنگ زمین میں تلاش کر یا آسمان سے سیڑھی لگا پھر ان کے پاس کوئی معجزہ لا اور اگر الله چاہتا تو سب کو سیدھی راہ پر جمع کر دیتا سو تو نادانوں میں سے نہ ہو\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@dcccxxv{وہی مانتے ہیں جو سنتے ہیں اور الله مردوں کو زندہ کرے گا پھر اس کی طرف لوٹائے جائیں گے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@dcccxxvi{اور کہتے ہیں اس کے رب کی طرف سے اس پر کوئی نشانی کیوں نہیں اتری کہہ دو الله اس پر قادر ہے کہ نشانی اتارے اور لیکن ان میں سے اکثر نہیں جانتے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@dcccxxvii{اور کوئی چلنے والا زمین میں نہیں اور نہ کوئی پرندہ کہ اپنے دوبازؤں سے اڑ تا ہے مگر یہ تمہاری ہی طرح کی جماعتیں ہیں ہم نے ان کی تقدیر کےلکھنے میں کوئی کسرنہیں چھوڑی پھر سب اپنے رب کے سامنے جمع کیے جائیں گے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@dcccxxviii{اور جو لوگ ہماری آیتوں کو جھٹلاتے ہیں وہ بہرےاور گونگے ہیں اندھیروں میں ہیں الله جسے چاہے گمراہ کر دے اور جسے چاہے سیدھی راہ پر ڈال دے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@dcccxxix{کہہ دو دیکھو تو سہی اگر تم پرخدا کا عذاب آئے یا تم پر قیامت ہی آ جائے تو کیا خدا کے سوا کسی اور کو پکارو گے اگر تم سچے ہو\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@dcccxxx{بلکہ اسی کو پکارتے ہو پھر اگر وہ چاہتا ہے تو اس مصیبت کو دور کر دیتا ہے جس کے لیے اسے پکارتے ہو اور جنہیں تم الله کا شریک بناتے ہو انہیں بھول جاتے ہو\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@dcccxxxi{اور ہم نے تجھ سے پہلے بہت سی امتوں کے ہاں رسول بھیجےتھے پھر ہم نے انہیں سختی اور تکلیف میں پکڑا تاکہ وہ عاجزی کریں\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@dcccxxxii{پھر کیوں نہ ہوا کہ جب ان پر ہمارا عذاب آیا تو عاجزی کرتے لیکن ان کے دل سخت ہو گئے اور شیطان نے انہیں وہ کام آراستہ کر دکھائے جو وہ کرتے تھے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@dcccxxxiii{پھر جب وہ اس نصیحت کو بھول گئے جو ان کو کی گئی تھی تو ہم نے ان پر ہر چیز کے دروازے کھول دیئے یہاں تک کہ جب وہ ان چیزوں پر خوش ہو گئےجو انہیں دی گئیں تھیں ہم نے انہیں اچانک پکڑ لیا وہ اس وقت نا امید ہوکر کر رہ گئے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@dcccxxxiv{پھر ان ظالموں کی جڑ کاٹ دی گئی اور الله ہی کے لیے سب تعریف ہے جو سارے جہان کا پالنے والا ہے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@dcccxxxv{ان سے کہہ دو دیکھو تو سہی اگر الله ہی کے لیے سب تعریف ہے جو سارے جہان کا پالنے والا ہےاگر الله تمہارے کان اور آنکھیں چھین لے اور تمہارے دلوں پر مہر لگا دے تو الله کے سوا کوئی ایسا رب ہے جو تمہیں یہ چیزیں لادے دیکھ ہم کیوں کر طرح طرح کی نشانیاں بیان کرتے ہیں پھر بھی یہ منہ موڑتے ہیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@dcccxxxvi{کہہ دو اگرتم پر الله کا عذاب اچانک یا ظاہر آ جائے تو ظالموں کے سوا اور کون ہلاک ہو گا\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@dcccxxxvii{اور ہم پیغبروں کو صرف اس لیے بھیجا کرتے ہیں کہ وہ بشارت دیں اور ڈرائیں پھر جو شخص ایمان لے آوے اور اپنی اصلاح کر لے سو ان پر کوئی ڈر نہ ہوگا اور نہ وہ غم کھائيں گے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@dcccxxxviii{اور جنہوں نے ہماری آیتوں کو جھٹلایا انہیں عذاب پہنچے گا اس لیے کہ وہ نافرمانی کرتے تھے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@dcccxxxix{کہہ دو میں تم سے یہ نہیں کہتا کہ میرے پاس الله کے خزانے ہیں اور نہ میں غیب کا علم رکھتا ہوں اور نہ یہ کہتا ہوں کہ میں فرشتہ ہوں میں تو صرف اس وحی کی پیروی کرتا ہوں جو مجھ پر نازل کی جاتی ہے کہہ دو کیا اندھا اور آنکھوں والا دونوں برابر ہو سکتے ہیں کیا تم غور نہیں کرتے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@dcccxl{اور اس قرآن کے ذریعے سے ان لوگو ں کو ڈرا جنہیں اس کا ڈر ہے کہ وہ اپنے رب کے سامنے جمع کیے جائیں گے اس طرح پر کہ الله کے سوا ان کوئی مددگار اور سفارش کرنے والا نہ ہو گا تاکہ وہ پرہیزگار ہوجائیں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@dcccxli{اور جو لوگ اپنے رب کو صبح و شام پکارتے ہیں انہیں اپنے سے دور نہ کر جو الله کی رضا چاہتے ہیں تیرے ذمہ ان کا کوئی حساب نہیں ہے اور نہ تیرا کوئی حساب ان کے ذمہ اگر تو نے انہیں دو ہٹا یا پس تو بے انصافوں میں سے ہوگا\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@dcccxlii{اور اسی طرح ہم نے بعض کو بعض کے ذریعہ سے آزمایا ہے تاکہ یہ لوگ کہیں کیا یہی ہیں ہم میں سے جن پر الله نے فضل کیا ہے کیا الله شکر گزارو ں کو جاننے والا نہیں ہے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@dcccxliii{اور ہماری آیتوں کو ماننے والے جب تیرے پاس آئیں تو کہہ دو کہ تم پر سلام ہے تمہارے رب نے اپنے ذمہ رحمت لازم کی ہےجو تم میں سے ناواقفیت سے برائی کرے پھر اس کے بعد توبہ کرے اور نیک ہو جائے تو بےشک وہ بخشنے والا مہربان ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@dcccxliv{اور اسی طرح ہم آیتوں کو تفصیل سے بیان کرتے ہیں اور تاکہ گنہگاروں کا راستہ واضح ہو جائے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@dcccxlv{کہہ دو مجھے منع کیا گیا ہے اس سے کہ میں بندگی کروں ان کی جنہیں تم الله کے سوا پکارتے ہو کہہ دو میں تمہاری خواہشات کے پیچھے نہیں چلتا کیوں کہ میں اس وقت گمراہ ہو جاؤں گا اور ہدایت پانے والوں میں سے نہ رہوں گا\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@dcccxlvi{کہہ دو میرے پاس تو میرے رب کی طرف سے ایک دلیل ہے اور تم اس کو جھٹلاتے ہو جس چیز کو تم جلدی چاہتے ہو وہ میرے پاس نہیں ہے الله کے سوا اور کسی کا حکم نہیں ہے وہ حق بیان کرتا ہے اور وہ بہترین فیصلہ کرنے والا ہے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@dcccxlvii{کہہ دو اگر میرے پاس وہ چیز ہوتی جس کی تم جلدی کر رہے ہو تو اس معاملہ میں فیصلہ ہوگیا ہو تا جو میرے اور تمہارے درمیان ہے اور الله ظالموں کو خوب جانتا ہے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@dcccxlviii{اور اسی کے پاس غیب کی کنجیاں ہیں جنہیں اس کےسوا کوئی نہیں جانتا جو کچھ جنگل اور دریا میں ہے وہ سب جانتا ہے اور کوئی پتہ نہیں گرتا مگر وہ اسے بھی جانتاہے اور کوئی دانہ زمین کے تاریک حصوں میں نہیں پڑتا اور نہ کوئی تر اور خشک چیز ہے مگر یہ سب کچھ کتاب روشن میں ہیں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@dcccxlix{اور وہ وہی ہے جو تمہیں رات کو اپنے قبضے میں لے لیتا ہے اور جو کچھ تم دن میں کر چکے ہو وہ جانتا ہے پھر تمہیں دن میں اٹھا دیتا ہے تاکہ وہ وعدہ پورا ہو جو مقرر ہو چکا ہے پھر اسی کی طرف تم لوٹائے جاؤ گے پھر تمہیں خبر دے گا اس کی جو کچھ تم کرتے تھے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@dcccl{اور وہی اپنے بندوں پر غالب ہے اور تم پر نگہبان بھیجتا ہے یہاں تک کہ جب تم میں سے کسی کو موت آ پہنچتی ہے تو ہمارے بھیجے ہوئے فرشتے اسے قبضہ میں لے لیتے اور وہ ذرا کوتاہی نہیں کرتے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@dcccli{پھر الله کی طرف پہنچائیں جائیں گے جو ا نکا سچا مالک ہے خوب سن لو کہ فیصلہ الله ہی کا ہوگا اور بہت جلدی حساب لینے والا ہے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@dccclii{کہہ دو تمہیں جنگل اور دریا کے اندھیروں سے کون بچا تا ہے جب اسے عاجزی سے اور چھپا کر پکارتے ہوکہ اگر ہمیں اس آفت سے بچا لے تو البتہ ہم ضرور شکر گزار کرنے والوں میں سے ہوں گے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@dcccliii{کہہ دو الله تمہیں اس سے اور ہر سختی سے بچا تا ہے تم پھر بھی شرک کرتے ہو\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@dcccliv{کہہ دو وہ اس پر قادر ہے کہ تم پر عذاب اوپر سے بھیجے یا تمہارے پاؤں کے نیچے سے یا تمہیں مختلف فرقے کر کے ٹکرا دے اور ایک کودوسرے کی لڑائی کا مزہ چکھا دے دیکھو ہم کس طرح مختلف طریقوں سے دلائل بیان کرتے ہیں تاکہ وہ سمجھ جائیں\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@dccclv{اور تیری قوم نے اسے جھٹلایا ہے حالانکہ وہ حق ہے کہہ دو میں تمہارا ذمہ دار نہیں بنایا گیا\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@dccclvi{ہر خبر کے ظاہر ہونے کا ایک وقت مقرر ہے اور عنقریب جان لو گے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@dccclvii{اور جب تو ان لوگو ں کو دیکھے جو ہماری آیتو ں میں جھگڑتے ہیں تو ان سے الگ ہو جا یہاں تک کہ کسی اور بات میں بحث کرنے لگیں اور اگر تجھے شیطان بھلا دے تو یاد آجانے کے بعد ظالموں کے پاس نہ بیٹھ\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@dccclviii{اور جھگڑنے والوں کے حساب میں سے پرہیزگاروں کے ذمہ کوئی چیز نہیں لیکن نصیحت کرنی ہے شاید کہ وہ ڈر جائیں\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@dccclix{اور انہیں چھوڑ دو جنہوں نے اپنے دین کو کھیل اور تماشا بنا رکھا ہے اور دنیاکی زندگی نے انہیں دھوکہ دیا ہے اور انہیں قرآن سے نصیحت کرتا تاکہ کوئی اپنے کیے میں گرفتار نہ ہو جائے کہ اس کے لیے الله کے سوا کوئی دوست اور سفارش کرنے والا نہ ہوگا اور اگر دنیا بھر کا معاوضہ بھی دے گا تب بھی اس سے نہ لیا جائے گا یہی وہ لوگ ہیں جو اپنے کیے میں گرفتار ہوئے ان کے پینے کے لیے گرم پانی ہوگا اور ان کے کفر کے بدلہ میں دردناک عذاب ہو گا\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@dccclx{انہیں کہہ دوکہ کیا ہم الله کے سوا انہیں پکاریں جو ہمیں نہ نفع پہنچا سکیں اور نہ نقصان دے سکیں اور کیا ہم الٹے پاؤں پھر جائیں اس کے بعد کہ الله نے ہمیں سیدھی راہ دکھائی ہے اس شخص کی طرح جسےجنگل میں جنوں نے راستہ بھلا دیا ہو جب کہ وہ حیران ہو اس کے ساتھی اسے راستے کی طرف بلاتے ہوں کہ ہمارے پاس چلا آ کہہ دو الله نے جو راہ بتلائی وہی سیدھی ہے اور ہمیں حکم دیا گیا ہے کہ ہم پروردگار عالم کے تابع رہیں\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@dccclxi{اور یہ کہ نماز قائم رکھو اور الله سے ڈرتے رہو وہی ہے جس کے سامنے اکھٹے کیے جاؤ گے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@dccclxii{اور وہی ہے جس نے آسمانوں اورزمین کو ٹھیک طور پر بنایا ہے اور جس دن کہے گا کہ ہو جا تو وہ ہو جائے گا اس کی بات سچی ہے جس دن صورمیں پھونکا جائے گاتو اسی کی بادشاہی ہو گی چھپی اور ظاہر باتوں کا جاننے والا ہے اور وہی حکمت والا خبردار ہے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@dccclxiii{اور یاد کر جب ابراہیم نے اپنے باپ آزر سے کہا کیا بتوں کو خدا جانتاہے میں تجھے اور تیرے قوم کو صریح گمراہی میں دیکھتا ہوں\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@dccclxiv{اور ہم نے اسی طرح ابراھیم کو آسمانوں اور زمین کے عجائبات دکھائے ابور تاکہ وہ یقین کرنے والوں میں سے ہو جائے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@dccclxv{پھر جب رات نے اس ہر اندھیرا کیا اس نے ایک ستارہ دیکھا کہا یہ میرا رب ہے پھر جب وہ غائب ہو گیا تو کہا میں غائب ہونے والوں کو پسند نہیں کرتا\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@dccclxvi{پھر جب چاند کو چمکتا ہوا دیکھا کہا یہ میرا رب ہے پھر جب وہ غائب ہو گیا تو کہا اگر مجھے میرا رب ہدایت نہ کرے گا تو میں ضرور گمراہوں میں سے ہوجاؤں گا\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@dccclxvii{پھر جب آفتاب کو چمکتاہوا دیکھا کہا یہی میرا رب ہے یہ سب سے بڑا ہے پھر جب وہ غائب ہو گیا کہا اے میری قوم میں ان سے بیزار ہوں جنہیں تم الله کا شریک بناتے ہو\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@dccclxviii{سب سے یک سو ہو کر میں نے اپنے منہ کو اسی کی طرف متوجہ کیا جس نے آسمان اور زمین بنائی اور میں شرک کرنے والوں میں سے نہیں ہوں\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@dccclxix{اور اس کی قوم نے اس سے جھگڑا کیا اس نے کہا کیا تم مجھ سے الله کے ایک ہونے میں جھگڑتے ہو اور اس نے میری رہنمائی کی ہے اور جنہیں تم شریک کرتے ہو میں ان سے نہیں ڈرتا مگر یہ کہ میرا رب مجھے کوئی تکلیف پہنچانا چاہے میرے رب نے علم کے لحاظ سے سب چیزوں پر احاطہ کیا ہوا ہے کیا تم سوچتے نہیں\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@dccclxx{اور تمہارے شریکوں سے کیوں ڈروں حالانکہ تم اس بات سے نہیں ڑرتے کہ الله کا شریک ٹھیراتے ہو اس چیز کو جس کی الله نے تم پر کوئی دلیل نہیں اتاری اگر تم کو کچھ سمجھ ہے تو (بتاؤ) دونوں جماعتوں میں سے امن کا زیادہ مستحق کون ہے\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@dccclxxi{جو لوگ ایمان لائے اور انہوں نے اپنے ایمان میں شرک نہیں ملایا امن انہیں کے لیے ہے اور وہی راہ راست پر ہیں\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@dccclxxii{اور یہ ہماری دلیل ہے کہ ہم نے ابراہیم کو اس کی قوم کے مقابلہ میں دی تھی ہم جس کے چاہیں درجے بلند کرتے ہیں بے شک تیرا رب حکمت والا جاننے والا ہے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@dccclxxiii{اور ہم نے ابراھیم کو اسحاق اور یعقوب بخشا ہم نے سب کو ہدایت دی اور اس سے پہلے ہم نے نوح کو ہدایت دی اور اس کی اولاد میں سے داؤد اور سلیمان اور ایوب اور یوسف اور موسیٰ اور ہارون ہیں اور اسی طرح ہم نیکو کاروں کو بدلہ دیتے ہیں\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@dccclxxiv{اور زکریا اور یحییٰ اور عیسیٰ اور الیاس سب نیکو کاروں سے ہیں\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@dccclxxv{اور اسماعیل اورالیسع اوریونس اور لوط او رہم نے سب کو سارے جہان والوں پر بزرگی دی\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@dccclxxvi{اور ان کے باپ دادوں اور ان کی اولاد اور ان کے بھائیوں میں سے بعضوں کو ہم نے ہدایت دی اور ہم نے انہیں پسند کیا اور سیدھی راہ پر چلایا\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@dccclxxvii{یہ الله کی ہدایت ہے اپنے بندوں کو جسے چاہے اس پر چلاتا ہے اور اگر یہ لوگ شرک کرتے تو البتہ جو کچھ انہوں نے کیا تھا سب کچھ ضائع ہو جاتا\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@dccclxxviii{یہی لوگ تھے جنہیں ہم نے کتاب اور شریعت اور نبوت دی تھی پھر اگر مکہ والے ان باتو ں کو نہ مانیں تو ہم نے ان باتو ں کے ماننے کے لیے ایسے لوگ مقرر کر دیے جوان کے منکر نہیں ہیں\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@dccclxxix{یہ وہ لوگ تھے جنہیں الله نے ہدایت دی سو تو ان کے طریقہ پر چل کہہ دو میں تم سے اس پر کوئی مزدوری نہیں مانگتا یہ تو جہان والوں کے لیے محض نصیحت ہے\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@dccclxxx{اور انہوں نے الله کو صحیح طور پر نہیں پہچانا جب انہوں نے کہا الله نے کسی انسان پر کوئی چیز نہیں اتاری تھی جو لوگو ں کے واسطے روشنی اور ہدایت تھی جسے تم نے ورق ورق کر کےد کھلا یا اوربہت سی باتو ں کو چھپا رکھا اور تمہیں وہ چیزیں سکھائیں جنہیں تم اور تمہارے باپ دااد نہیں جانتے تھے تو کہہ دو الله ہی نے اتاری تھی پھرانہیں چھوڑ دو کہ اپنی بحث میں کھیلتے رہیں\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@dccclxxxi{اور یہ کتاب جسے ہم نے اتارا ہےبرکت والی ہے ان کی تصدیق کرنے والی ہے جو اس سے پہلے تھیں اور تاکہ تو مکہ والوں کو اور اس کے آس پاس والوں کو ڈرائے اور جو لوگ آخرت پر یقین رکھتے ہیں وہی اس پر ایمان لاتے ہیں اور وہی اپنی نماز کی حفاظت کرتے ہیں\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@dccclxxxii{اور اس سے زیادہ ظالم کون ہو گا جو الله پربہتان باندھے یا یہ کہے کہ مجھ پر وحی نازل ہوئی ہے حالانکہ اس پر وحی نہ اتری ہو اور جو کہے میں بھی ایسی چیز اتار سکتا ہوں جیسی کہ الله نے اتاری ہے اور اگر تو دیکھے جس وقت ظالم موت کی سختیوں میں ہوں گے اور فرشتے اپنے ہاتھ بڑھانے والےہوں گے کہ اپنی جانوں کو نکالو آج تمہیں ذلت کا عذاب ملے گا اس سبب سے کہ تم الله پر جھوٹی باتیں کہتے تھے اور اس کی آیتوں کے ماننے سے تکبر کرتے تھے\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@dccclxxxiii{اور البتہ تم ہمارے پاس ایک ایک ہو کر آ گئے ہو جس طرح ہم نے تمہیں پہلی دفعہ پیدا کیا تھا اور جو کچھ ہم نے تمہیں دیا تھا وہ اپنے پیچھے ہی چھوڑ آئے ہو اور تمہارے ساتھ ان کی سفارش کرنے والوں کو نہیں دیکھتے جنہیں تم خیال کرتے تھے کہ وہ تمہارے معاملےمیں شریک ہیں تمہارا آپس میں قطع تعلق ہو گیا ہے اور جو تم خیال کرتے تھے وہ سب جاتا رہا\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@dccclxxxiv{بے شک الله دانے اور گٹھلی کا پھاڑنے والا ہے مردہ سے زندہ کو نکالتا ہے اور زندہ سے مردہ نکالنے والا ہے الله یہی ہے پھر کدھر الٹے پھرے جا رہے ہو\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@dccclxxxv{وہ صبح کا نکالنے والا ہے اور اس نے آرام کے لیے رات بنائی اسی نے چاند اور سورج کا حساب مقرر کیا ہے یہ غالب جاننے والے کا اندازہ ہے\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@dccclxxxvi{اور اسی نے تمہارے لیے ستارے بنائے ہیں تاکہ ان کے ذریعے سے جنگل اوردریا کےاندھیروں میں راستہ معلوم کر سکو تحقیق ہم نے کھول کر نشانیاں بیان کر دی ہیں ان لوگو ں کے لیے جو جانتے ہیں\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@dccclxxxvii{اور الله وہی ہے جس نے ایک شخص سے تم سب کو پیدا کیا پھر ایک تو تمہارا ٹھکانا ہے اور ایک امانت رکھے جانےکی جگہ تحقحق ہم نے کھول کر نشانیاں بیان کر دی ہیں ان کے لیے جو سوچتے ہیں\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@dccclxxxviii{اور اسی نے آسمان سے پانی اتارا پھر ہم نے اس سے ہر چیز اگنے والی نکالی پھر ہم نے اس سے سبز کھیتی نکالی جس سے ہم ایک دوسرے پرچڑھے ہوئے دانے نکالتے ہیں اور کھجور کے شگوفوں میں سے پھل کے جھکے ہوئے گچھے اور انگور اور زیتون اور انار کے باغ آپس میں ملتے جلتے اور جدا جدا بھی ہر ایک درخت کے پھل کو دیکھو جب وہ پھل لاتا ہے اور اس کے پکنے کو دیکھو ان چیزوں میں ایمان والوں کے لیے نشانیاں ہیں\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@dccclxxxix{اور اللہ کے شریک جنوں کو ٹھیراتے ہیں حالانکہ اس نے انہیں پیدا کیا ہے اور جہالت سے اس کے لیے بیٹے اور بیٹیاں تجویز کرتے ہیں وہ پاک ہے اور ان باتوں سے بھی بلند ہے جو وہ بیان کرتے ہیں\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@dcccxc{آسمانوں اور زمین کو از سر نو پیدا کرنے والا ہے اس کا بیٹا کیوں کر ہو سکتا ہے حالانکہ اس کی کوئی بیوی نہیں اور اس نے ہر چیز کو بنایاہے اور وہ ہر چیز کو جاننے والا ہے\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@dcccxci{یہی اللہ تمہارا رب ہے اس کے سوائے اورکوئی معبود نہیں ہر چیز کا پیدا کرنے والا ہے پس اسی کی عبادت کرو اور وہ ہر چیز کا کا رساز ہے\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@dcccxcii{اسے آنکھیں نہیں دیکھ سکتیں اور وہ آنکھوں کو دیکھ سکتا ہے اوثر وہ نہایت باریک بین خبردار ہے\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@dcccxciii{تحقیق تمہارے ہاں تمہارے رب کی طرف سے نشانیاں آ چکی ہیں پھر جس نے دیکھ لیا تو خود ہی نفع اٹھایا اور جو اندھا رہا سو اپنا نقصان کیا اور میں تمہارا نگہبان نہیں ہوں\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@dcccxciv{اور اسی طرح ہم مختلف طریقوں سے دلائل بیان کرتے ہیں تاکہ وہ کہیں کہ تو نے کسی سے پڑھا ہے اور تاکہ ہم سمجھداروں کے لیے واضح کر دیں\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@dcccxcv{تو اس کی تابعداری کر جو تیرےرب کی طرف سے وحی کی گئی ہے اس کے سوا اور کوئی معبود نہیں اور مشرکوں سے منہ پھیرے\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@dcccxcvi{اور اگر الله چاہتا تو وہ شرک نہ کرتے اور ہم نے تجھے ا ن پر نگہبان نہیں بنایا اور تو ان کا ذمہ دار نہیں ہے\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@dcccxcvii{اور جن کی یہ الله کے سوا پرستش کر تےہیں انہیں برا نہ کہوورنہ وہ بے سمجھی سے زیادتی کرکے الله کو برا کہیں گے اس طرح ہر ایک جماعت کی نظر میں ان کے اعمال کوہم نے آراستہ کر دیا ہے پھر ان سب کو اپنے رب کی طرف لوٹ کر آنا ہے تب وہ انہیں بتلائے گا جو کچھ کیا کرتے تھے\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@dcccxcviii{اور وہ الله کے نام کی پکی قسمیں کھاتے ہیں کہ اگر ان کے پاس کوئی نشانی آئے تو اس پر ضرور ایمان لاویں گے ان سے کہہ دو کہ نشانیاں تو اللہ کے ہاں ہیں اور تمہیں اے مسلمانو کیا خبر ہے کہ جب نشانیاں آہیں گی تو یہ لوگ ایمان لے ہی آئیں گے\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@dcccxcix{اور ہم بھی ان کے دلوں کو اور ان کی نگاہوں کو پھیر دیں گے جس طرح یہ اس پر پہلی دفعہ ایمان نہیں لاتے اور ہم انہیں ان کی سرکشی میں حیران رہنے دیں گے\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@cm{اور اگر ہم ان پر فرشتے بھی اتار دیں اور ان سے مردے باتیں بھی کریں اور ان کے سامنے ہم ہر چیز کو زندہ بھی کر دیں تو بھی یہ لوگ ایمان لانے والے نہیں مگر یہ کہ الله چاہے لیکن اکثر ان میں سے جاہل ہیں\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@cmi{اور اسی طرح ہم نے ہر نبی کے لیے شریر آدمیوں اور جنوں کو دشمن بنایا جو کہ ایک دوسرے کو طمع کرہوئی باتیں فریب دینے کے لیے سکھاتے ہیں اور اگر تیرا رب چاہتا تو یہ کام نہ کرتے سو تو انہیں اور جوجھوٹ بناتے ہیں اسے چھوڑ دے\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@cmii{اور تاکہ ان طمع کی ہوئی باتوں کی طرف ان لوگوں کے دل مائل ہوں جنہیں آخرت پر یقین نہیں اور تاکہ وہ لوگ ان باتو ں کو پسند کریں اور تاکہ وہ کریں جو برے کام وہ کر رہے ہیں\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@cmiii{کیا میں الله کےسوا اور کسی کو منصف بناؤں حالانکہ اس نے تمہاری طرف ایک واضح کتاب اتاری ہے اور جنہیں ہم نے کتاب دی ہے وہ جانتے ہیں کہ یہ ٹھیک تیرے رب کی طرف سے نازل ہوئی ہے پس تو شک کرنے والوں میں سے نہ ہو\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@cmiv{اور تیرے رب کی باتیں سچائی اور انصاف کی انتہائی حد تک پہنچی ہوئی ہیں اس کی باتو ں کو کوئی بدل نہیں سکتا اور وہ سننے والا جاننے والا ہے\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@cmv{اور اگر تو کہا مانے گا اکثر ان لوگو ں کا جو دنیا میں ہیں تو تجھے الله کی راہ سے ہٹا دیں گے وہ تو اپنے خیال پر چلتے اور قیاس آرائیاں کرتے ہیں\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@cmvi{تیرا رب خوب جانتا ہے اسے جو اس کے راہ سے ہٹ جاتا ہے اور سیدھے راستہ پر چلنے والوں کو بھی خوب جانتا ہے\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@cmvii{سو تم اس جانوروں میں سے کھاؤ جس پر الله کا نام لیا گیا ہے اگر تم اس کے حکموں پر ایمان لانے والے ہو\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@cmviii{کیا وجہ ہے کہ تم وہ چیز نہ کھاؤ جس پر الله کا نام لیا گیا ہو حالانکہ وہ واضح کر چکا ہے جو کچھ اس نے تم پر حرام کیا ہے ہاں مگر وہ چیز جس کی طرف تم مجبور ہو جاؤ اوربہت سے لوگ بےعلمی کے باعث اپنے خیالات کے باعث اپنے خیالات کی بناء پر لوگو ں کو بہکاتے ہیں تیرا رب حد سے بڑھنے والوں کو خوب جانتا ہے\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@cmix{تم ظاہری اورباطنی سب گناہ چھوڑ دو بے شک جو لوگ گناہ کرتے ہیں عنقریب اپنے کیے کی سزا پائیں گے\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@cmx{اور جس چیز پر الله کا نام نہیں لیا گیا اس میں سے نہ کھاؤ اور بے شک یہ کھانا گناہ ہے اور بے شک شیطان اپنے دوستوں کے دلو ں میں ڈالتے ہیں تاکہ وہ تم سے جھگڑیں اور اگر تم نے ان کا کہا مانا تو تم بھی مشرک ہو جاؤ گے\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@cmxi{بھلا وہ شخص جو مردہ تھا پھر ہم نے اسے زندہ کر دیا اور ہم نے اسے روشنی دی کہ اسے لوگوں میں لیے پھرتا ہےوہ اس کے برابر ہو سکتا ہے جو اندھیروں میں پڑا ہو وہاں سے نکل نہیں سکتا اسی طرح کافروں کی نظر میں ان کے کام آراستہ کر دیئے گئے ہیں\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@cmxii{اور اسی طرح ہر بستی میں ہم نے گناہگاروں کے سردار بنا دیےہیں تاکہ وہاں اپنے مکرو فریب کا جال پھیلائیں حالانکہ وہ اپنے فریب کے جال میں آپ پھنستے ہیں مگر وہ سمجھتے نہیں\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@cmxiii{جب ان کے پاس کوئی نشانی آتی ہے تو کہتے ہیں ہم نہیں مانیں گے جب تک کہ وہ چیز خود ہمیں نہ دی جائے جو الله کے رسولوں کو دی گئی ہے اور الله بہتر جانتا ہے کہ پیغمبری کا کام کس سے لے وہ وقت قریب ہے جب یہ مجرم اپنی مکاریو ں کی پاداش میں الله کے ہاں ذلت اور سخت عذاب میں مبتلا ہوں گے\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@cmxiv{سو جسے الله چاہتا ہے کہ ہدایت دے تو اس کے سینہ کو اسلام کے قبول کرنے کے لیے کھول دیتا ہے اور جس کے متعلق چاہتا ہے کہ گمراہ کرے اس کے سینہ کو بے حد تنگ کر دیتا ہے گو کہ وہ آسمان پر چڑھتا ہے اسی طرح الله تعالیٰ ایمان نہ لانے والوں پر پھٹکار ڈالتا ہے\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@cmxv{اور یہ تیرے رب کا سیدھا راستہ ہے ہم نے نصیحت حاصل کرنے والوں کے لیے آیتوں کو صاف صاف کر کے بیان کر دیا ہے\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@cmxvi{ان کے لیے اپنے رب کے ہاں سلامتی کا گھر ہے اور وہ ان کے اعمال کے سبب سے ان کا مددگار ہے\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@cmxvii{اور جس دن ان سب کو جمع کرے گا جنوں کی جماعت سے فرمائے گا تم نے آدمیوں سے بہت سے اپنے تابع کر لئے تھے اور آدمیوں میں سے جو جنوں کے دوست تھے کہیں گے اے رب ہمارے ہم میں سے ہر ایک نے دوسرے سے کام نکالا اور ہم اپنی اس معیاد کو آ پہنچے جو تو نے ہمارے واسطے مقرر کی تھی فرمائے گا تم سب کا ٹھکانا آگ ہے اس میں ہمیشہ رہو گے اس سے صرف وہی بچیں گے جنہیں الله بچائے گا بے شک تیرا رب حکمت والا جاننے والا ہے\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@cmxviii{اور اسی طرح ہم گنہگاروں کو ایک دوسرے کے ساتھ ان کے اعمال کے سبب سے ملا دیں گے\qt@no{(129)}}%
\qt@newcmd\qurantrans@ur@cmxix{اے جنو اور انسانو! کی جماعت کیا تمہارے پاس تم ہی میں سے رسول نہیں آئے تھے جو تمہیں میرے احکام سناتے تھے وہ اس دن کی ملاقات سے تمہیں ڈراتے تھے کہیں گے ہم اپنے گناہ کا راقرار کرتے ہیں اور انہیں دنیا کی زندگی نے دھوکہ دیا ہے او راپنے اوپر ہی گواہی دیں گے کہ وہ کافر تھے\qt@no{(130)}}%
\qt@newcmd\qurantrans@ur@cmxx{یہ اس لیے ہوا کہ تیار رب بستیوں کو ظلم کرنے کے باوجود ہلاک نہیں کیاکرتا اس حال میں کہ وہ بے خبر ہوں\qt@no{(131)}}%
\qt@newcmd\qurantrans@ur@cmxxi{اور ہر ایک کے لیے ان کے عمل کے لحاظ سے درجے ہیں اور تیرا رب ان کے کاموں سے بے خبر نہیں\qt@no{(132)}}%
\qt@newcmd\qurantrans@ur@cmxxii{اور تیرا رب بے پرواہ رحمت والا ہے اگر وہ چاہے تم سب کو اٹھالے اور تمہارے بعد جسے چاہے تمہاری جگہ آباد کردے جس طرح تمہیں ایک دوسری قوم کی نسل سے پیدا کیا ہے\qt@no{(133)}}%
\qt@newcmd\qurantrans@ur@cmxxiii{جس چیز کا تمہیں وعدہ دیا جاتا ہے وہ ضرور آنے والی ہے اور تم عاجز نہیں کر سکتے\qt@no{(134)}}%
\qt@newcmd\qurantrans@ur@cmxxiv{کہہ دو اے لوگو تم اپنی جگہ پر کام کرتے رہو اور میں بھی کرتا ہوں عنقریب معلوم کر لو گے آخرت کا گھر کس کے لیے ہوتا ہے بے شک ظالم نجات نہیں پاتے\qt@no{(135)}}%
\qt@newcmd\qurantrans@ur@cmxxv{اور الله کی پیدا کی ہوئی کھیتی اور مویشیوں میں سے ایک حصہ اس کے لیے مقرر کرتے ہیں اور اپنے خیال کے مطابق کہتے ہیں کہ یہ الله کا حصہ ہے اور یہ ہمارے شریکوں کا ہے سو جو حصہ ان کے شریکوں کا ہے وہ الله کی طرف نہیں جا سکتا اور جو الله کا ہے وہ ان کے شریکوں کی طرف جا سکتا ہے کیسا برا فیصلہ کرتے ہیں\qt@no{(136)}}%
\qt@newcmd\qurantrans@ur@cmxxvi{اور اسی طرح بہت سے مشرکوں کے خیال میں ان کے شریکوں نے اپنی اولاد کے قتل کرنے کو خوشنما بنا دیا ہے تاکہ انہیں ہلاکت میں مبتلا کر دیں اور ان پر ان کے دین کو مشتبہ بنا دیں اگر الله تعالیٰ چاہتا تو ایسا نہ کرتے سو انہیں چھوڑ دو اور جو وہ افتراء کر تے ہیں\qt@no{(137)}}%
\qt@newcmd\qurantrans@ur@cmxxvii{اور کہتے ہیں یہ جانور اور کھیت محفوظ ہیں انہیں صرف وہی لوگ کھا سکتے ہیں جنہیں ہم چاہیں اورکچھ جانور ہیں جن پر سواری حرام کر دی گئی ہے اور کچھ جانور ہیں جن پر الله کا نام نہیں لیتے یہ سب الله پر افتراء ہے عنقریب الله انہیں اس افترا کی سزا دے گا\qt@no{(138)}}%
\qt@newcmd\qurantrans@ur@cmxxviii{اور کہتے ہیں جو کچھ ان جانوروں کے پیٹ میں ہے یہ ہمارے مردوں کے لیے خاص ہے اور ہماری عورتو ں پر حرام ہے اور جو بچہ مردہ ہو تو دونوں اس کے کھانے میں برابر ہیں الله انہیں ان باتو ں کی سزا دے گا بے شک وہ حکمت والا جاننے والا ہے\qt@no{(139)}}%
\qt@newcmd\qurantrans@ur@cmxxix{تحقیق خسارے میں پڑے وہ لوگ جنہوں نے اپنی اولاد کو جہالت اور نادانی کی بنا پر قتل کیا اور الله پر بہتان باندھ کر اس رزق کو حرام کر لیا جو الله نے انہیں دیا تھا بے شک وہ گمراہ ہوئے اور سیدھی راہ پر نہ آئے\qt@no{(140)}}%
\qt@newcmd\qurantrans@ur@cmxxx{اور اسی نے وہ باغ پیدا کیے جو چھتو ں پر چڑھائے جاتے ہیں او رجو نہیں چڑھائے جاتے اور کھجور کے درخت او رکھیتی جن کے پھل مختلف ہیں اور زیتون اور انار پیدا کیے جو ایک دوسرے سے مشابہاور جدا جدا بھی ہیں ان کے پھل کھاؤ جب وہ پھل لائیں اور جس دن اسے کاٹو اس کا حق ادا کرو اور بے جا خرچ نہ کرو بے شک وہ بے جا خرچ کرنے والوں کو پسند نہیں کرتا\qt@no{(141)}}%
\qt@newcmd\qurantrans@ur@cmxxxi{اور بوجھ اٹھانے والے مویشی پیدا کیے اور زمین سے لگے ہوئے اور الله کے رزق میں سے کھاؤ اور شیطان کے قدموں پر نہ چلو وہ تمہارا صریح دشمن ہے\qt@no{(142)}}%
\qt@newcmd\qurantrans@ur@cmxxxii{آٹھ قسمیں پیدا کیں بھیڑ میں سے دو اور بکری میں سے دو تو پوچھ کہ دونوں نر الله نے حرام کیے ہیں یا دونوں مادہ یا وہ بچہ جو دونوں مادہ کے رحم میں ہے مجھے اس کی سند بتلاؤ اگر سچے ہو\qt@no{(143)}}%
\qt@newcmd\qurantrans@ur@cmxxxiii{اور اونٹ اور گائے سے دو دو قسمیں پیدا کیں تو پوچھ دونوں نر حرا م کیے ہیں یا دونوں مادہ یا وہ بچہ جو دونوں مادہ کے رحم میں ہے کیا تم موجود تھے جس وقت الله نے تمہیں حکم دیا تھا پھر اس سے زیادہ ظالم کون ہے جو الله پر جھوٹا بہتان باندھے تاکہ لوگو ں کو بلا تحقیق گمراہ کرے بے شک الله ظالموں کو ہدایت نہیں کرتا\qt@no{(144)}}%
\qt@newcmd\qurantrans@ur@cmxxxiv{کہہ دو کہ میں اس وحی میں جو مجھے پہنچی ہے کسی چیز کو کھانے والے پر حرام نہیں پاتا جو اسے کھائے مگر یہ کہ وہ مردار ہو یا بہتا ہوا خون یا سور کا گوشت کہ وہ ناپاک ہے یا وہ ناجائز ذبیحہ جس پر الله کے سوا کسی اور کا نام پکارا جائے پھر جو تمہیں بھوک سے بے اختیار ہوجائے ایسی حال میں کہ نہ بغاوت کرنے والا اور نہ حد سے گزرنے والا ہو تیرا رب بخشنے والا مہربان ہے\qt@no{(145)}}%
\qt@newcmd\qurantrans@ur@cmxxxv{یہود پرہم نے ایک ناخن والا جانور حرام کیا تھا اور گائے اوربکری میں سے ان دونوں کی چربی حرا م کی تھی مگر جو پشت پر یا انتڑیوں پر لگی ہوئی ہو یا جو ہڈی سے ملی ہوئی ہو ہم نے ان کی شرارت کے باعث انہیں یہ سزا دی تھی اور بے شک ہم سچے ہیں\qt@no{(146)}}%
\qt@newcmd\qurantrans@ur@cmxxxvi{پھر اگر تجھے جھٹلائیں تو کہہ دو تمہارا رب بہت وسیع رحمت والا ہے اورگناہگار لوگوں سے اس کا عذاب نہیں ٹلے گا\qt@no{(147)}}%
\qt@newcmd\qurantrans@ur@cmxxxvii{اب مشرک کہیں گے اگر الله چاہتا تو نہ ہم اور نہ ہمارے باپ دادا شرک کرتے اور نہ ہم کسی چیز کو حرام کرتے اورنہ ہم کسی چیز کو حرام کرتے اسی طرح ان لوگوں نے جھٹلایا جو ان سے پہلے تھے یہاں تک کہ انہو ں نے ہمارا عذاب چکھا کہہ دو تمہارے ہاں کوئی ثبوت ہے تو اسے ہمارے سامنے لاؤ تم فقط خیالی باتوں پر چلتے ہو اور صرف تخمینہ ہی کرتے ہو\qt@no{(148)}}%
\qt@newcmd\qurantrans@ur@cmxxxviii{کہہ دو پس الله کا الزام پورا ہو چکا پس اگر وہ چاہتا تو تم سب کو ہدایت کردیتا\qt@no{(149)}}%
\qt@newcmd\qurantrans@ur@cmxxxix{ان سے کہہ دو اپنے گواہ لاؤ جو اس بات کی گواہی دیں کہ الله نے ان چیزوں کو حرام کیا ہے پھر اگر وہ ایسی گواہی دیں توتو ان کا اعتبار نہ کر اور جنہوں نے ہماری آیتوں کو جھٹلایا ہے اور جو آخرت پریقین نہیں رکھتے اور وہ اوروں کو اپنے رب کے برابر کرتے ہیں\qt@no{(150)}}%
\qt@newcmd\qurantrans@ur@cmxl{کہہ دو آؤ میں تمہیں سنا دوں جو تمہارے رب نے تم پر حرام کیا ہے یہ کہ اس کے ساتھ کسی کو شریک نہ بناؤ اور ماں باپ کے ساتھ نیکی کرو اور تنگدستی کے سبب اپنی اولاد کو قتل نہ کرو ہم تمہیں اور انہیں رزق دیں گے اور بے حیائی کے ظاہر اور پوشیدہ کاموں کے قریب نہ جاؤ اور نا حق کسی جان کو قتل نہ کرو جس کا قتل الله نے حرام کیا ہے تمہیں یہ حکم دیتا ہے تاکہ تم سمجھ جاؤ\qt@no{(151)}}%
\qt@newcmd\qurantrans@ur@cmxli{اور سوائے کسی بہتر طریقہ کے یتیم کے مال کے پاس نہ جاؤ یہاں تک کہ وہ اپنی جوانی کو پہنچے اور ناپ اور تول کو انصاف سے پورا کرو ہم کسی کو اس کی طاقت سے زیادہ تکلیف نہیں دیتے اور جب بات کہو انصاف سے کہو اگرچہ رشتہ داری ہو اور الله کا عہد پورا کرو تمہیں یہ حکم دیا ہے تاکہ تم نصیحت حاصل کرو\qt@no{(152)}}%
\qt@newcmd\qurantrans@ur@cmxlii{اور بے شک یہی میرا سیدھا راستہ ہے سو اسی کا اتباع کرواور دوسرے راستوں پر مت چلو وہ تمہیں الله کی راہ سے ہٹا دیں گے تمہیں اسی کا حکم دیا ہے تاکہ تم پرہیزگار ہو جاؤ\qt@no{(153)}}%
\qt@newcmd\qurantrans@ur@cmxliii{پھر ہم نےنیکوں پر نعمت پوری کرنے کے لیے موسیٰ کو کتاب دی جس میں ہر چیز کی تفصیل اور ہدایت اور رحمت تھی تاکہ وہ لوگ اپنے رب کی ملاقات پر ایمان لائیں\qt@no{(154)}}%
\qt@newcmd\qurantrans@ur@cmxliv{یہ برکت والی کتاب ہم نے اتاری ہے سو اس کا اتباع کرو اور ڈرو تاکہ تم پر رحم کیا جائے\qt@no{(155)}}%
\qt@newcmd\qurantrans@ur@cmxlv{تاکہ تم یہ نہ کہو کہ ہم سے پہلے دو فرقوں پر کتاب نازل ہوئی تھی اورہم تو ان کے پڑھنے پڑھانے سے بے خبر تھے\qt@no{(156)}}%
\qt@newcmd\qurantrans@ur@cmxlvi{یا یہ کہو کہ اگر ہم پر کتاب نازل کی جاتی تو ہم ان سے بہتر راہ پر چلتے سو تمہارے پاس تمہارے رب کی ھرف سے ایک واضح کتاب اور ہدایت اور رحمت آ چکی ہے اب اس سے زیادہ کون ظالم ہے جو الله کی آیتوں کوجھٹلائے اور ان سے منہ موڑے جو لوگ ہماری آیتوں سے منہ موڑتے ہیں ہم انہیں ان کے منہ موڑنے کے باعث برے عذاب کی سزا دیں گے\qt@no{(157)}}%
\qt@newcmd\qurantrans@ur@cmxlvii{یہ لوگ اس کے منتظر ہیں کہ ان کے پا س فرشتے آویں یا تیرا رب آئے یا تیرے رب کی کوئی نشانی آئے گی تو کسی ایسے شخص کا ایمان کام نہ آئے گا جو پہلے ایمان نہ لایا ہو یا اس نے ایمان لانے کے بعد کوئی نیک کام نہ کیا ہو کہہ دو انتظار کرو ہم بھی انتظار کرنے والے ہیں\qt@no{(158)}}%
\qt@newcmd\qurantrans@ur@cmxlviii{جنہوں نے اپنے دین کو ٹکڑے ٹکڑے کر دیا اور کئی جماعتیں بن گئے تیرا ان سے کوئی تعلق نہیں اس کا کام الله ہی کے حوالے ہے پھر وہی انہیں بتلائے گا جو کچھ وہ کرتے تھے\qt@no{(159)}}%
\qt@newcmd\qurantrans@ur@cmxlix{جو کوئی ایک نیکی کرے گا اس کے لیے دس گنا اجر ہے اور جو بدی کرے گا سو اسے اسی کے برابر سزا دی جائے گی اور ان پر ظلم نہ کیا جائے گا\qt@no{(160)}}%
\qt@newcmd\qurantrans@ur@cml{کہہ دو میرے رب نے مجھےایک سیدھا راستہ بتلا دیا ہے ایک صحیح دین ابراھیم کی ملت جو ایک ہی طرف کاتھا اور مشرکوں میں سے نہیں تھا\qt@no{(161)}}%
\qt@newcmd\qurantrans@ur@cmli{کہہ دو بے شک میری نماز اور میری قربانی اور میرا جینا اور میرا مرنا الله ہی کے لیے ہے جو سارے جہان کا پالنے والا ہے\qt@no{(162)}}%
\qt@newcmd\qurantrans@ur@cmlii{اس کا کوئی شریک نہیں اور مجھے اسی کا حکم دیا گیا تھا اور میں سب سے پہلے فرمانبردار ہوں\qt@no{(163)}}%
\qt@newcmd\qurantrans@ur@cmliii{کہہ دو کیا اب میں الله کے سوا اور کوئی رب تلاش کروں حالانکہ وہی ہر چیز کا رب ہے اور جو شخص کوئی گناہ کرے گاتو وہ اسی کے ذمہ ہے اور ایک شخص دوسرے کا بوجھ نہیں اٹھائے گا پھر تمہارے رب کے ہاں ہی سب کو لوٹ کر جانا ہے سو جن باتو ں میں تم جھگڑتے تھے وہ تمہیں بتلاد ے گا\qt@no{(164)}}%
\qt@newcmd\qurantrans@ur@cmliv{اس نے تمہیں زمین میں نائب بنا یا ہے اور بعض کے بعض پر درجے بلند کر دیے ہیں تاکہ تمہیں اپنے دیے ہوئے حکموں میں آزمائے بے شک تیرا رب جلدی عذاب دینے والا ہے اور بے شک وہ بخشنے والا مہربان ہے\qt@no{(165)}}%
\qt@newcmd\qurantrans@ur@cmlv{\basmalahur المصۤ\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@cmlvi{یہ کتاب تیری طرف بھیجی گئی ہے تاکہ تو اس کے ذریعہ سے ڈرائے اور اس سے تیرے دل میں تنگی نہ ہونی چاہیئے اور یہ ایمان والوں کے لیے نصیحت ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@cmlvii{جو چیز تمہارے رب کی طرف سے تم پر اتری ہے اس کا اتباع کرو اور الله کو چھوڑ کر دوسرے دوستوں کی تابعداری نہ کرو تم لوگ بہت ہی کم نصیحت مانتے ہو\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@cmlviii{اور کتنی بستیاں ہم نے ہلاک کر دی ہیں جن پر ہمارا عذاب رات کو آیا ایسی حالت میں کہ دوپہر کوسونے والے تھے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@cmlix{جس وقت ان پر ہمارا عذاب آیا پھر ان کی یہی پکار تھی کہتے تھے بے شک ہم ہی ظالم تھے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@cmlx{پھر ہم ان لوگوں سے ضرور سوال کریں گے جن کے پاس پیغمبر بھیجے گئے تھے اور ان پیغمبروں سے ضرور پوچھیں گے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@cmlxi{پھر اپنے علم کی بناء پر ان کے سامنے بیان کر دیں گے اور ہم کہیں حاضر نہ تھے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@cmlxii{اورواقعی اس دن وزن بھی ہوگا جس شخص کا پلہ بھاری ہو گا سو ایسے لوگ کامیاب ہوں گے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@cmlxiii{اور جس کا پلہ ہلکا ہو گا سو یہ لوگ ہوں گے جنہوں نے اپنا نقصان کیا اس لیے کہ ہماری آیتوں کا انکار کرتے تھے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@cmlxiv{اور ہم نے تمہیں زمین میں جگہ دی اور اس میں تمہاری زندگی کا سامان بنا دیا تم بہت کم شکر کرتے ہو\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@cmlxv{او رہم نے تمہیں پیدا کیا پھر تمہاری صورتیں بنائیں پھر فرشتوں کو حکم دیا کہ آدم کو سجدہ کرو پھر سوائے ابلیس کے سب نے سجدہ کیا وہ سجدہ کرنے والوں میں سے نہ تھا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@cmlxvi{فرمایاتجھے سجدہ کرنے سے کس چیز نے منع کیا ہے جب کہ میں نے تجھے حکم دیا کہا میں اس سے بہتر ہوں تو نے مجھے آگ سے بنایا اور اسے مٹی سے بنایا ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@cmlxvii{کہاتو یہاں سے اتر جا تجھے یہ لائق نہیں کہ یہاں تکبر کرے پس نکل جا بے شک تو ذلیلوں میں سے ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@cmlxviii{کہا مجھے اس دن تک مہلت دے جس دن لوگ قبرو ں سے اٹھائے جائیں گے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@cmlxix{فرمایا تجھے مہلت دی گئی ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@cmlxx{کہا جیسا تو نے مجھے گمراہ کیا ہے میں بھی ضرور ان کی تاک میں تیری سیدھی راہ پر بیٹھوں گا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@cmlxxi{پھر ان کے پاس ان کے آگے ان کے پیچھے ان کے دائیں اور ان کے بائیں سےآؤں گا اور تو اکثر کو ان میں سے شکر گزار نہیں پائے گا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@cmlxxii{فرمایا یہاں سے ذلیل و خوار ہو کر نکل جا جو شخص ان سے تیرا کہا مانے گا میں تم سب کو جہنم میں بھر دوں گا\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@cmlxxiii{اور اے آدم تو اور تیری عورت جنت میں رہو پھر جہاں سے چاہو کھاؤ اور اس درخت کے پاس نہ جاؤ ورنہ بے انصافوں میں سے ہو جاؤ گے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@cmlxxiv{پھرانہیں شیطان نے بہکایا تاکہان کی شرم گاہیں جو ایک دوسرے سے چھپائی گئی تھیں ان کے سامنے کھول دے اور کہا تمہیں تمہارے رب نے اس درخت سے نہیں روکا مگر اس لیے کہ کہیں تم فرشتے ہو جاؤ یا ہمیشہ رہنے والے ہو جاؤ\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@cmlxxv{اور ان کے روبرو قسم کھائی کہ البتہ میں تمہارا خیرا خواہ ہوں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@cmlxxvi{پھر انہیں دھوکہ سے مائل کر لیا پھرجب ان دونوں نے درخت کو چکھا تو ان پر ان کی شرم گاہیں کھل گئیں اور اپنے اوپر بہشت کے پتے جوڑنے لگے اورانہیں ان کے رب نے پکارا کیا میں نے تمہیں اس درخت سے منع نہیں کیا تھا اور تمہیں کہ نہ دیا تھا کہ شیطان تمہارا کھلا دشمن ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@cmlxxvii{ان دونوں نے کہا اے رب ہمارے ہم نے اپنی جانوں پر ظلم کیا اور اگر تو ہمیں نہ بخشے گا اور ہم پر رحم نہ کرے گا تو ہم ضرور تباہ ہوجائیں گے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@cmlxxviii{فرمایا یہاں سے اترو تم ایک دوسرے کے دشمن ہو گے اور تمہارے لیے زمین میں ٹھکانا ہے اور ایک وقت تک نفع اٹھانا ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@cmlxxix{فرمایا تم اسی میں زندہ رہو گے اور اسی میں مرو گے اور اسی سے نکالے جاؤ گے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@cmlxxx{اے آدم کی اولاد ہم نے تم پر پوشاک اتاری جو تمہاری شرم گاہیں ڈھانکتی ہیں اور آرائش کے کپڑے بھی اتارے اور پرہیزگاری کا لباس وہ سب سے بہتر ہے یہ الله کی قدرت کی نشانیاں ہیں تاکہ وہ نصیحت حاصل کریں\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@cmlxxxi{اے آدم کی اولاد تمہیں شیطان نہ بہکائے جیسا کہ اس نے تمہارے ماں باپ کو بہشت سے نکال دیا ان سے ان کے کپڑے اتروائے تاکہ تمہیں ان کی شرمگاہیں دکھائے وہ اور اس کی قوم تمہیں دیکھتی ہے جہاں سے تم انہیں نہیں دیکھتے ہم نے شیطانوں کو ان لوگوں کا دوست بنادیا ہے جوایمان نہیں لاتے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@cmlxxxii{اور جب کوئی برا کام کرتے ہیں تو کہتے ہیں کہ ہم نے اسی طرح اپنے باپ دادا کو کرتے دیکھا ہے اور الله نے بھی ہمیں یہ حکم دیا ہے کہہ دو بے شک الله بے حیائی کا حکم نہیں کرتا الله کے ذمہ وہ باتیں کیوں لگاتے ہو جو تمہیں معلوم نہیں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@cmlxxxiii{کہہ دو میرے رب نے انصاف کا حکم دیا ہے اور ہر نماز کےوقت اپنے منہ سیدھے کرو اور اس کے خالص فرمانبردار ہو کر اسے پکارو جس طرح تمہیں پہلے پیدا کیا ہے اسی طرح دوبارہ پیدا ہو گے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@cmlxxxiv{ایک جماعت کو ہدایت دی اور ایک جماعت پر گمراہی ثابت ہو چکی انہوں نے الله کو چھوڑ کر شیطان کو اپنا دوست بنایا ہے اور خیال کرتے ہیں کہ وہ ہدایت پر ہیں\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@cmlxxxv{اے آدم کی اولاد تم مسجد کی حاضری کے وقت اپنا لباس پہن لیا کرو اور کھاؤ اور پیئو اور حد سے نہ نکلو بے شک الله حد سے نکلنے والوں کو پسند نہیں کرتا\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@cmlxxxvi{کہہ دو الله کی زینت کو کس نے حرام کیا ہے جو اس نے اپنے بندو ں کے واسطے پیدا کی ہے اورکس نے کھانے کی ستھری چیزیں (حرام کیں) کہہ دو دنیا کی زندگی میں یہ نعمتیں اصل میں ایمان والوں کے لیے ہیں قیامت کے دن خالص انہیں کے لیے ہوجائیں گی اسی طرح ہم آیتیں مفصل بیان کرتے ہیں ان کے لیے جو سمجھتے ہیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@cmlxxxvii{کہہ دو میرے رب نے صرف بے حیائی کی باتو ں کو حرام کیا ہے خواہ وہ علانیہ ہوں یا پوشیدہ اور ہر گناہ کواور ناحق کسی پر ظلم کرنے کو بھی اور یہ کہ الله پر وہ باتیں کہو جو تم نہیں جانتے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@cmlxxxviii{اور ہر ایک گروہ کے لیے ایک معیاد معین ہے پھر جب وہ معیاد ختم ہو گی اور وقت نہ ایک گھڑی پیچھے ہٹیں گے اور نہ آگے بڑھیں گے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@cmlxxxix{اے ادم کی اولاد اگر تم میں سے تمہارے پاس رسول آئیں جو تمہیں میری آیتیں سنائیں پھر جو شخص ڈرے گا اور اصلاح کرے گا ایسوں پر کوئی خوف نہ ہوگا اور نہ وہ غم کھائیں گے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@cmxc{اور جنہوں نے ہماری آیتو ں کو جھٹلایا اوران سے تکبر کیا وہی دوزخی ہیں وہ اس میں ہمیشہ رہنے والے ہوں گے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@cmxci{پھر اس سے زیادہ ظالم کون ہوگا الله پر بہتان باندھے یا اس کے حکموں کو جھٹلائے ان لوگوں کا جو کچھ نصیب ہے وہ ان کو مل جائے گا یہاں تک کہ جب ان کے ہاں ہمارے بھیجے ہوئے فرشتے ان کی روح قبض کرنے کے لیے آئيں گے تو کہیں گے کہ وہ کہاں گئے الله کو چھوڑ کر جن کی تم عبادت کرتے تھے کہیں گے ہم سے سب غائب ہو گئے اور اپنے کافر ہونے کااقرار کرنے لگیں گے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@cmxcii{فرمائے گا جنوں اور آدمیوں میں سے جو امتیں تم سے پہلے ہو چکی ہیں ان کے ساتھ دوزخ میں داخل ہو جاؤ جب ایک امت داخل ہو گی تو دوسری پر لعنت کرے گی یہاں تک کہ جب اس میں سب گر جائیں گے تو ن کے پچھلے پہلوں سے کہیں گے اے رب ہمارے ہمیں انہوں نے گمراہ کیا سو تو انہیں آگ کا دگنا عذاب دے فرمائے گا کہ دونوں کو دگنا ہے لیکن تم نہیں جانتے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@cmxciii{اور پہلے پچھلوں سے کہیں گے پس تمہیں ہم پر کوئی فضیلت نہیں پس بسب اپنی کمائی کے عذاب چکھو\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@cmxciv{بے شک جنہوں نے ہماری آیتو ں کو جھٹلایا اوران کے مقابلہ میں تکبر کیا ان کے لیے آسمان کے دروازے نہیں کھولے جائیں گے اورنہ وہ جنت میں داخل ہوں گے یہاں تک کہ اونٹ سوئی کے ناکے میں گھس جائے اور ہم گناہگاروں کو اسی طرح سزا دیتے ہیں\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@cmxcv{ان کے لیے دوزخ کا بچھونا اور اوپر سے اوڑھنا ہے اور ہم ظالموں کو ایسی ہی سزا دیا کرتے ہیں\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@cmxcvi{اور جو ایمان لانے اور نیکیاں کیں ہم کسی پر بوجھ نہیں رکھتے مگر اس کی طاقت کےموافق وہی بہشتی ہیں وہ اس میں ہمیشہ رہنے والے ہیں\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@cmxcvii{اور جوکچھ ان کے دلو ں میں خفگی ہو گی ہم اسے دور کردیں گے ان کے نیچے نہریں بہتی ہوں گی اور وہ کہیں گےکہ الله کاشکر ہے جس نے ہمیں یہاں تک پہنچایا اور ہم راہ نہ پاتے اگر الله ہماری رہنمائی نہ فرماتا بے شک ہمارے رب کے رسول سچی بات لائے تھے جور آواز آئے گی کہ یہ جنت ہے تم اپنے اعمال کے بدلے اس کے وارث ہو گئے ہو\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@cmxcviii{اور بہشت والے دوزخیوں کو پکاریں گے کہ ہم نے وعدہ سچا پایا جو ہمارے رب نے ہم سے کیا تھا آیاتم بھی اپنے رب کے وعدہ کو سچا پایا وہ کہیں گے ہاں پھر ایک پکارنے والا ان کے درمیان پکارے گا کہ ان ظالمو ں پر الله کی لعنت ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@cmxcix{جو الله کی راہ سے روکتے تھے اور اسے ٹیڑھا کرنا چاہتے تھے اور وہ آخرت کے منکر تھے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@m{اور ان دونوں کے درمیان ایک دیوار ہو گی اور اعراف کے اوپر ایسے مرد ہوں گے کہ ہر ایک کو اس کی نشانی سے پہچان لیں گے اور جنت والوں کو پکار کر کہیں گے کہ تم پر سلام ہو وہ ابھی جنت میں داخل نہیں ہوئے اور امیدوار ہیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mi{اورجب ان کی نگاہ دوزخ والوں کی طرف پھرے گی تو کہیں گے اے رب ہمارے ہمیں ظالموں کے ساتھ نہ ملا\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mii{اور اعراف والے پکاریں گے جنہیں وہ ان کی نشانی سے پہچانتے ہوں گے کہیں گے تمہاری جماعت تمہارے کسی کام نہ آئی اور نہ وہ جو تم تکبر کیا کرتے تھے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@miii{یہ وہی ہیں جن کے متعلق تم قسم کھاتے تھے کہ انہیں الله کی رحمت نہیں پہنچے گی (انہیں کہا گیا ہے) جنت میں چلے جاؤ تم پر نہ ڈر ہے اور نہ تم غمگین ہو گے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@miv{اور دوزخ والے بہشت والوں کو پکاریں گے کہ ہم پر تھوڑا سا پانی بہا دو یا کچھ اس چیز میں سے دو جو تمہیں الله نے رزق دیا ہے کہیں گے بے شک الله نے انہیں دونوں چیزوں کو کافروں پر حرام کیا ہے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mv{جنہوں نے اپنا دین تماشا اور کھیل بنایا اور انہیں دنیا کی زندگی نے دھوکے میں ڈال دیا ہے سو آج ہم انہیں بھلا دیں گے جس طرح انہوں نے اس دن کی ملاقات کو بھلا دیا تھا اور جیسا وہ ہماری آیتوں سے انکار کرتے تھے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mvi{اور ہم نے ان کے پاس ایک ایسی کتاب پہنچا دی ہے جسے ہم نے اپنے علم کامل سے بہت ہی واضح کر کے بیان کر دیا ہے وہ ہدایت ہے اوررحمت ہے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mvii{ان لوگو ں کے لیے ےجو ایمان لے آئے ہیں انہیں اور کسی بات کا انتظار نہیں صرف آخری نتیجہ کا انتظار ہے جس دن اس کا آخری نتیجہ سامنے آئے گا اس دن جو اسے پہلے بھولے ہوئے تھے کہیں گے کہ واقعی ہمارے رب کے رسول کی سچی باتیں لائے تھے سو اب کیا کوئی ہمارا سفارشی ہے جو ہماری سفارش کر ےیاکیا ہم پھر واپس بھیجے جا سکتے ہیں تاکہ ہم ان کے اعمال کے خلاف جنہیں کیا کرتے تھے دوسرے اعمال کریں بے شک انہوں نے اپنے آپ کو خسارے میں ڈا ل دیا اور جو باتیں بناتے تھے وہ سب گم ہو گئیں\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mviii{بے شک تمہارا رب الله ہے جس نے آسمانوں اور زمین کو چھ دن میں پیدا کیا پھرعرش پر قرار پکڑا رات سے دن کو ڈھانک دیتا ہے وہ اس کے پیچھے دوڑتا ہوا آتا ہے اور سورج اورچاند اور ستارے اپنے حکم کے تابعدار بنا کر پیدا کیے اسی کا کام ہے پیدا کرنا اور حکم فرمانا الله بڑی برکت والا ہے جو سارے جہان کا رب ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mix{اپنے رب کو عاجزی اور چپکے سے پکارو اسے حد سے بڑھنے والے پسند نہیں آتے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mx{اور زمین میں اس کی اصلاح کے بعد فساد مت کرو اور اسے ڈر اور طمع سے پکارو بے شک اللهکی رحمت نیکو کاروں سے قریب ہے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mxi{اور وہی ہے جو مینہ سے پہلے خوشخبری دینے والی ہوائیں چلاتا ہے یہاں تک کہ جب ہوائیں بھاری بادلو ں کو اٹھا لاتی ہیں تو ہم ا س بادل کو مردہ شہر کی طرف ہانک دیتے ہیں پھر ہم ا س بادل سے پانی اتارتے ہیں پھر اس سے سب طرح کے پھل نکالتے ہیں اسی طرح ہم مردوں کو نکالیں گے تاکہ تم نصیحت حاصل کرو\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mxii{اور جو شہر پاکیزہ ہے اس کا سبزہ اس کے رب کے حکم سے نکلتا ہے اور جو اس میں خراب ہے جو کچھ اس میں سے نکلتا ہے ناقص ہی ہوتا ہے اسی طرح ہم شکر گزاروں کے لیے مختلف طریقوں سے آیتیں بیان کرتے ہیں\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mxiii{بے شک ہم نے نوح کو اس کی قوم کی طرف بھیجا پس اس نے کہا اے میری قوم الله کی بندگی کرو اس کے سوا تمہارا کوئی معبود نہیں میں تم پر ایک بڑے دن کے عذاب سے ڈرتا ہوں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mxiv{اس کی قو م کے سرداروں نے کہا ہم تجھے صریح گمراہی میں دیکھتے ہیں\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mxv{فرمایا اے میری قوم میں ہرگز گمراہ نہیں ہوں لیکن میں جہان کے پروردگار کی طرف سے بھیجا ہوا ہوں\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mxvi{تمہیں اپنے رب کے پیغام پہنچاتا ہوں اور تمہیں نصیحت کرتا ہوں اور الله کی طرف سے وہ باتیں جانتا ہوں جو تم نہیں جانتے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mxvii{کیا تمہیں اس بات سے تعجب ہوا کہ تمہارے رب کی طرف سے تم ہی میں سے ایک مرد کی زبانی تمہارے پاس نصیحت آئی ہے تاکہ وہ تمہیں ڈرائے اورتاکہ تم پرہیزگار ہو جاؤ اور تاکہ تم پرحم کیے جاؤ\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mxviii{پھر انہو ں نے اسے جھٹلایا پھر ہم نے اسے اور ا سکے ساتھیوں کو کشتی میں بچا لیا اور جو ہماری آیتوں کو جھٹلاتے تھے انہیں غرق کر دیا بے شک وہ لوگ اندھے تھے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mxix{اور قوم عاد کی طرف ان کے بھائی ہود کو بھیجا فرمایا اے میری قوم الله کی بندگی کرو اس کے سوا تمہارا کوئی معبود نہیں سو کیا تم ڈرتے نہیں\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mxx{اس کی قوم کےکافر سردار بولےہم تو تمہیں بے وقوف سمجھتے ہیں اور ہم تجھے جھوٹا خیال کرتے ہیں\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mxxi{فرمایا اے میری قوم میں بے وقوف نہیں ہوں لیکن میں پروردگار عالم کی طرف سے بھیجا ہوا ہوں\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mxxii{تمہیں اپنے رب کے پیغام پہنچاتا ہوں اور تمہارا امانت دار خیر خواہ ہوں\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mxxiii{کیا تمہیں تعجب ہوا کہ تمہارے رب کی طرف سے تمہیں میں سے ایک مرد کی زبانی تمہارے پاس نصیحت آئی ہے تاکہ تمہیں ڈرائے اور یاد کرو جب کہ تمہیں قوم نوح کے بعد جانشین بنا یا اورڈیل ڈول میں تمہیں پھیلاؤ زیادہ دیا سو الله کی نعمتوں کو یاد کرو تاکہ تم نجات پاؤ\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mxxiv{انہوں نے کہا کیا تو ہمارے پاس اس لیے آیا ہے کہ ہم ایک الله کی بندگی کریں اور ہمارے باپ دادا جنہیں پوجتے رہے انہیں چھوڑ دیں پس جس چیز سے تو ہمیں ڈراتا ہے وہ لے آ اگرتو سچا ہے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mxxv{فرمایا تمہارے رب کی طرف سے تم پر عذاب اور غصہ واقع ہو چکا مجھ سے ان ناموں پر کیوں جھگڑتے ہو جوتم نے اور تمہارے باپ دادؤں نے مقرر کیے ہیں الله نے ان کے لیے کوئی دلیل نہیں اتاری سو انتظار کرو میں بھی تمہارے ساتھ انتظار کرنے والا ہوں\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mxxvi{پھر ہم نے اسے اور اس کے ساتھیوں کو اپنی رحمت سے بچا لیا اور جو ہماری آیتوں کو جھٹلاتے تھے ان کی جڑ کاٹ دی اور وہ مومن نہیں تھے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mxxvii{اور ثمود کی طرف ان کے بھائی صالح کو بھیجا فرمایا اے میری قوم الله کی بندگی کرو اس کے سوا تمہارا کوئی معبود نہیں تمہیں تمہراے رب کی طرف سے دلیل پہنچ چکی ہے یہ الله کی اونٹنی تمہارے لیے نشانی ہے سو اسے چھوڑ دو کہ الله کی زمین میں کھائے اور اسے بری طرح سے ہاتھ نہ لگاؤ ورنہ تمہیں دردناک عذاب پکڑے گا\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mxxviii{اور یاد کرو جب کہ تمہیں عاد کے بعد جانشین بنایا اور تمہیں زمین میں جگہ دی کہ نرم زمین میں محل بناتے ہو اور پہاڑو ں میں گھر تراشتے ہو سو الله کے احسان کو یاد کرو اور زمین میں فساد مت مچاتے پھرو\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mxxix{اس قوم کے متکبر سرداروں نے غریبوں سے کہا جو ایمان لاچکے تھے کیا تمہیں یقن ہے کہ صالح کو اس کے رب نے بھیجا ہے انہوں نے کہا جو وہ لے کر آیا ہے ہم اس پرایمان لانے والے ہیں\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mxxx{متکبروں نے کہا جس پر تمہیں یقین ہے ہم اسے نہیں مانتے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mxxxi{پھر اونٹنی کے پاؤں کاٹ ڈالے اور اپنے رب کے حکم سے سرکشی کی اور کہا اے صالح لے آ ہم پر جس سے تو ہمیں ڈراتا تھا اگر تو رسول ہے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mxxxii{پس انہیں زلزلہ نے آ پکڑا پھر صبح کو اپنے گھروں میں اوندھے پڑے ہوئے رہ گئے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mxxxiii{پھر صالح ان سے منہ موڑ کر چلے اور فرمایا اے میری قوم میں تمہیں اپنے رب کا پیغام پہنچا چکا اور تمہاری خیر خواہی کی لیکن تم خیر خواہوں کو پسند نہیں کرتے تھے\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mxxxiv{اور لوط کو بھیجا جب اس نے اپنی قوم کو کہا کیا تم ایسی بے حیائی کرتے ہو کہ تم سے پہلے اسے جہان میں کسی نے نہیں کیا\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mxxxv{بے شک تم عورتوں کو چھوڑ کر مردوں سے شہوت رانی کرتے ہو بلکہ تم حد سے بڑھنے والے ہو\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mxxxvi{اور اس کی قوم نے کوئی جواب نہیں دیا مگر یہی کہا کہ انہیں اپنےشہر سے نکال دو یہ لوگ بہت ہی پاک بننا چاہتے ہیں\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mxxxvii{پھر ہم نے اسےاور اس کے گھر والوں کو سوائے اس کی بیوی کے بچا لیا کہ وہ وہاں رہنے والو ں میں رہ گئی\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mxxxviii{اور ہم نے ان پر مینہ برسایا پھر دیکھیئے گناہگاروں کا کیا انجام ہوا\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mxxxix{اورمدین کی طرف اس کے بھائی شعیب کو بھیجا فرمایااے میری قوم الله کی بندگی کرو اس کے سوا تمہار کوئی معبود نہیں تمہارے رب کی طرف سے تمہارے پاس دلیل پہنچ چکی ہے سو ناپ او رتول کو پورا کرو اور لوگوں کو ان کی چیزیں گھٹا کر نہ دو اور زمین میں اس کی اصلاح کے بعد فساد مت کرو یہ تمہارے لیے بہتر ہے اگر تم ایمان دار ہو\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mxl{اور سڑکوں پر اس غرض سے مت بیٹھا کرو کہ الله پر ایمان لانے والوں کو دھمکیاں دو اور الله کی راہ سے روکو اوراس میں ٹیڑھا پن تلاش کرو اور اس حلات کو یاد کرو جب کہ تم تھوڑے تھے پھر الله نے تمہیں زیادہ کر دیا اور دیکھو فساد کرنے والوں کا انجام کیا ہوا ہے\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mxli{اور اگر تم میں سے ایک جماعت اس پر ایمان لے آئی ہے جو میرے ذریعے سے بھیجا گیا ہے اور ایک جماعت ایمان نہیں لائی پس صبر کرو جب تک الله ہمارے درمیان فیصلہ کرے اور وہ سب سے بہتر فیصلہ کرنے والا ہے\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mxlii{اس کی قوم کے متکبر سرداروں نے کہا اے شعیب ہم تجھے اور انہیں جو تجھ پر ایمان لائے ہیں اپنے شہر سے ضرور نکال دیں گے یا یہ کہ تم ہمارے دین میں واپس آ جاؤ فرمایا کیا اگرچہ ہم اس دین کو ناپسند کرنے والے ہوں\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mxliii{ہم تو الله پر بہتان باندھنے والے ہو جائیں اگر تمہارے مذہب میں واپس آئيں بعد اس کے کہ الله نے ہمیں اس سے نجات دی ہے اور ہمیں یہ حق نہیں کہ تمہارے دین میں لوٹ کر آئيں مگر یہ کہ الله چاہے جو ہمارا رب ہے ہمارے رب کا علم ہر چیز پر احاطہ کیے ہوئے ہے ہم الله ہی پر بھروسہ کرتے ہیں اے رب ہمارے اور ہماری قوم کے درمیان حق کے موافق فیصلہ کر دے اور تو بہتر فیصلہ کرنے والا ہے\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mxliv{اس کی قوم میں جو کافر سردار تھے انہوں نے کہا اگر تم شعیب کی تابعداری کرو گے تو بے شک نقصان اٹھاؤ گے\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mxlv{پھر انہیں زلزلہ نے آ پکڑا پھر وہ صبح تک اپنے گھرو ں میں اوندھے پڑے ہوئے رہ گئے\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mxlvi{جنہوں نے شعیب کو جھٹلایا گو وہ وہاں کبھی بسے ہی نہیں تھے جنہوں نے شعیب کو جھٹلایا وہی نقصان اٹھانے والے ہوئے\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mxlvii{پھر ان سے منہ پھیرا اور کہا اے میری قوم تحقیق میں نے تمہیں اپنے رب کے احکام پہنچا دیے اور میں نے تمہارے لیے خیر خواہی کی پھر کافروں کی قوم پر میں کیوں کر غم کھاؤں\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mxlviii{او رہم نے کسی بستی میں کوئی پیغمبرنہیں بھیجا مگر وہاں کے لوگوں کو سختی اور تکلیف میں پکڑا تاکہ وہ عاجزی کریں\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mxlix{پھر ہم نے برائی کی جگہ بھلائی بدل دی یہاں تک کہ وہ زیادہ ہو گئے اور کہنے لگے کہ ہمارے باپ داداؤں کو بھی تکلیف اور خوشی کا وقت آیا تھا پھر ہم نے انہیں اچانک پکڑا اور ان کو خبر نہ ہوئی\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@ml{اور اگر بستیوں والے ایمان لے آتے اور ڈرتے تو ہم ان پر آسمان اور زمین سے نعمتوں کے دروازے کھول دیتے لیکن انہوں نے جھٹلایا پھر ہم نے ان کے اعمال کے سبب سے گرفت کی\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mli{کیا بستی والے نڈر ہو چکے ہیں کہ ہماری طرف سے ان پر رات کو عذاب آئے جب وہ سو رہے ہوں\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mlii{یا بستیوں والے اس بات سے نڈر ہو چکے ہیں کہ ان پر ہمارا عذاب دن چڑھے آئے جب وہ کھیل رہے ہوں\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mliii{کیا وہ الله کی اچانک پکڑ سے بے فکر ہوئے ہیں بس الله کی اچانک پکڑ سے بے فکر ہو گئے ہیں پس الله کی اچانک پکڑ سے بے فکر نہیں ہوتے مگر نقصان اٹھانے والے\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mliv{کیا ان لوگو ں پر جو زمین کے وارث ہوئے ہیں وہاں کے لوگوں کے ہلاک ہونے کے بعد یہ ظاہر نہیں ہوا کہ اگر ہم چاہیں تو انہیں ان کے گناہوں کے سبب سے پکڑ لیں اور ہم نے ان کے دلوں پر مہر لگا دی ہے پس وہ نہیں سنتے\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mlv{یہ بستیاں ہیں جن کے حالات ہم تمہیں سناتے ہیں بے شک ان کے پاس ان کے رسولروشن نشانیاں لے کر آئے تھے پھر اس بات پر ہرگز ایمان نہ لائے جسے پہلے جھٹلا چلے تھے کافروں کے دلوں پر الله اسی طرح مہر لگا دیتا ہے\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mlvi{اور ہم نے ان کے اکثر لوگو ں میں عہد کا نباہ نہیں پایا اور ان میں سے اکثر نافرمان پایا\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mlvii{اس کے بعد ہم نے موسیٰ کو اپنی نشانیاں دے کر فرعون اور اس کے سرداروں کی طرف بھیجا پھر انہوں نے نشانیوں سے بے انصافی کی پھر دیکھ مفسدوں کا انجام کیا ہوا\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mlviii{اور موسیٰ نے کہا اے فرعون بے شک میں رب العالمین کی طرف سے رسول ہو کر آیا ہوں\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mlix{میرے لیے یہی مناسب ہے کہ سوائے سچ کے کوئی بات خدا کی طرف منسوب نہ کروں میں تمہارے رب کی طرف سے تمہارے پاس ایک بڑی دلیل لایا ہوں پس بنی اسرائیل کو میرے ساتھ بھیج دے\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mlx{کہا اگرتو کوئی نشانی لے کر آیا ہے تو وہ لا اگر تو سچا ہے\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mlxi{پھر اس نے اپنا عصا ڈال دیا وہ اس وقت صریح اژدھا ہو گیا\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mlxii{او راپنا ہاتھ نکالا تو اسی وقت دیکھنے والوں کے لیے سفید نظر آنے لگا\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mlxiii{فرعون کی قوم کے سرداروں نے کہا بے شک یہ بڑا ماہر جادو گر ہے\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mlxiv{تمہیں تمہارے ملک سے نکالنا چاہتا ہے پس تم کیا مشورہ دیتے ہو\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mlxv{انہوں نے کہا کہ اسے اور اس کے بھائی کو مہلت دے اور شہروں میں جمع کرنے والے بھیج دے\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mlxvi{تاکہ تیرے پاس ماہر جادوگر کو لے آئيں\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@mlxvii{اور جادوگر فرعون کے پاس آئے کہا اگر ہم غالب آئے تو ہمیں کچھ صلہ بھی ملے گا\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@mlxviii{کہا ہاں اور بے شک تم مقرب ہو جاؤ گے\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@mlxix{کہا اے موسیٰ یا تو تو ڈال یا ہم ڈالتے ہیں\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@mlxx{کہا تم ڈالوپس جب انہوں نے ڈالا تو لوگو ں کی نظر بندی کر دی اور انہیں ڈرایا اور اک طرح کا بڑا جادو دکھایا\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@mlxxi{اور ہم نے موسیٰ کو وحی کے ذریعے سے حکم دیا اپنا عصا ڈال دے سو وہ اسی وقت نگلنے لگا جو کھیل انہو ں نے بنا رکھا تھا\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@mlxxii{پھر حق ظاہر ہو گیا اور جو انہوں نے بنایا تھا وہ غلط ہو گیا\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@mlxxiii{پھر اس جگہ ہار گئے اور ذلیل ہو کر لوٹے\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@mlxxiv{اور جادوگر سجدہ میں گر پڑے\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@mlxxv{کہاہم رب العالمین پر ایمان لائے\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@mlxxvi{جو موسیٰ اور ہارون کا رب ہے\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@mlxxvii{فرعون نے کہا تم اس پر میری اجازت سے پہلے ہی ایمان لے آئے یہ تو مکر ہے جو تم سب نے اس شہر میں بنایا ہے تاکہ اس شہر کے رہنے والوں کو نکال دو سو اب تمہیں معلوم ہو جائے گا\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@mlxxviii{میں ضرور تمہارے ہاتھ اور دوسری طرف سے پاؤں کاٹوں گا پھر تم سب کو سولی چڑھا دوں گا\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@mlxxix{انہوں نے کہا ہمیں تو اپنے رب کی طرف لوٹ کر جانا ہی ہے\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@mlxxx{اور تمہیں ہم سے یہی دشمنی ہے کہ ہم نے اپنے رب کی نشانیوں کو مان لیا جب وہ ہمارے پاس آئیں اے ہمارے رب ہمارے اوپر صبر ڈال اورہمیں مسلمان کر کے موت دے\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@mlxxxi{اور فرعون کی قوم کے سرداروں نے کہا کیا تو موسیٰ اور اس کی قوم کو چھوڑتا ہے تاکہ وہ ملک میں فساد کریں اور تجھے اورتیرے معبودوں کو چھوڑ دے کہا ہم ان کے بیٹوں کو قتل کریں گے اور ان کی عورتو ں کو زندہ رکھیں گے اور بے شک ہم ان پر غالب ہیں\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@mlxxxii{موسیٰ نے اپنی قوم سے کہا الله سے مدد مانگو اور صبر کرو بے شک زمین الله کی ہے اپنے بندوں میں سے جسےچاہے اس کا وارث بنا دے اور انجام بخیر پرہیزگاروں کا ہی ہوتا ہے\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@mlxxxiii{انہوں نے کہا تیرے آنے سےپہلے بھی ہمیں تکلیفیں دی گئیں اور تیرے آنے کے بعد بھی فرمایا تمہارا رب بہت جلد تمہارے دشمن کو ہلاک کر دے گا اور اس کی بجائے تمہیں اس سرزمین کا مالک بنا دے گا پھر دیکھے گاتم کیا کرتے ہو\qt@no{(129)}}%
\qt@newcmd\qurantrans@ur@mlxxxiv{اور ہم نے فرعون والوں کو قحطوں میں اور میوں کی کمی میں پکڑ لیا تاکہ وہ نصیحت مانیں\qt@no{(130)}}%
\qt@newcmd\qurantrans@ur@mlxxxv{جب ان پر خوشحالی آتی تو کہتے کہ یہ تو ہمارے لیے ہونا ہی چاہیئے اور اگر انہیں کوئی بدحالی پیش آتی تو موسیٰ اور ان کے ساتھیوں کی نحوست بتلاتے یاد رکھو ان کی نحوست الله کے علم میں ہے لیکن اکثر لوگ نہیں جانتے\qt@no{(131)}}%
\qt@newcmd\qurantrans@ur@mlxxxvi{اور کہا جوکوئی نشانی تو ہمارے پاس لائے گا ہم پر اس کے ذریعہ سے جادو کرے سو ہم تجھ پر ہر گز ایمان نہ لائیں گے\qt@no{(132)}}%
\qt@newcmd\qurantrans@ur@mlxxxvii{پھر ہم نے ان پر طوفان اور ٹدی اور جوئیں اورمینڈک اور خون یہ سب کھلے کھلےمعجزے بھیجے پھر بھی انہوں نے تکبر ہی کیا اور لوگ گناہگار تھے\qt@no{(133)}}%
\qt@newcmd\qurantrans@ur@mlxxxviii{اور جب ان پر کوئی عذاب آتا تو کہتے اے موسیٰ ہمارے لیے اپنے رب سے دعا کر جس کا اس نے تجھ سے عہد کر رکھا ہے اگر تو نے ہم سے یہ عذاب دور کر دیا تو بے شک ہم تجھ پر ایمان لے آئيں گے اور بنی اسرائیل کو تیرے ساتھ بھیج دیں گے\qt@no{(134)}}%
\qt@newcmd\qurantrans@ur@mlxxxix{پھر جب ہم نےان سے ایک مدت تک عذاب اٹھا لیا کہ انہیں اس مدت تک پہنچنا تھا اس وقت وہ عہد توڑ ڈالتے\qt@no{(135)}}%
\qt@newcmd\qurantrans@ur@mxc{پھر ہم نے ان سے بدلہ لیا پھر ہم نے انہیں دریا میں ڈبو دیا اس لیے کہ انہوں نے ہماری آیتوں کو جھٹلایا اور وہ ان سے غافل تھے\qt@no{(136)}}%
\qt@newcmd\qurantrans@ur@mxci{اور ہم نے ان لوگوں کو وارث کر دیا جو اس زمین کے مشرق و مغرب میں کمزور سمجھے جاتے تھے کہ جس میں ہم نے برکت رکھی ہے او رتیرے رب کا نیک وعدہ بنی اسرائیلک کے حق میں ان کے صبر کے باعث پورا ہو گیا اور فرعون اور اس کی قوم نے جو کچھ بنایا تھا ہم نے اسے تباہ کر دیا اور جو وہ اونچی عمارتیں بناتے تھے\qt@no{(137)}}%
\qt@newcmd\qurantrans@ur@mxcii{اور ہم نے بنی اسرائیل کو دریا سے پار اتارا تو ایک ایسی قوم پر پہنچے جو اپنے بتوں کے پوجنے میں لگے ہوئے تھے کہا اے موسیٰ ہمیں بھی ایک ایسا معبود بنا دے جیسے ان کے معبود ہیں فرمایا بے شک تم لوگ جاہل ہو\qt@no{(138)}}%
\qt@newcmd\qurantrans@ur@mxciii{یہ لوگ جس چیز میں لگے ہوئے ہیں وہ تباہ ہونے والی ہے اور جو وہ کر رہے ہیں وہ غلط ہے\qt@no{(139)}}%
\qt@newcmd\qurantrans@ur@mxciv{کہا کیا الله کے سوا تمہارے لیے اور معبود بنا دوں حالانکہ اس نے تمہیں سارے جہاں پر فضیلت دی ہے\qt@no{(140)}}%
\qt@newcmd\qurantrans@ur@mxcv{اور یا د کرو جب ہم نے تمہیں فرعون والوں سے نجات دی جو تمہیں برا عذاب دیتے تھے تمہارے بیٹوں کو مار ڈال دیتے تھے اور تمہاری عورتوں کو زندہ رکھتے تھے اور اس میں تمہارے رب کا بڑا احسان تھا\qt@no{(141)}}%
\qt@newcmd\qurantrans@ur@mxcvi{اور موسیٰ سے ہم نے تیس رات کا وعدہ کیا اور انہیں اور دس سے پورا کیا پھر تیرے رب کی مدت چالیس راتیں پوری ہو گئی اور موسیٰ نے اپنے بھائی ہارون سے کہا کہ میری قوم میں میرا جانشین رہ اور اصلاح کرتے رہو اور مفسدوں کی راہ پر مت چل\qt@no{(142)}}%
\qt@newcmd\qurantrans@ur@mxcvii{اور جب موسیٰ ہمارے مقرر کردہ وقت پر آئے اور ان کے رب نے ان سے باتیں کیں تو عرض کیا کہ اے میرے رب مجھے دکھا کہ میں تجھے دیکھوں فرمایا کہ تو مجھے ہر گز نہیں دیکھ سکتا لیکن تو پہاڑ کی طرف دیکھتا رہ اگر وہ اپنی جگہ پر ٹھہرا رہا تو تو مجھے دیکھ سکے گا پھر جب اس کے رب نے پہاڑ کی طرف تجلی کی تو اس کو ریزہ ریزہ کر دیا اور موسیٰ بے ہوش ہو کر گر پڑے پھر جب ہوش میں آئے تو عرض کی کہ تیری ذات پاک ہے میں تیری جانب میں توبہ کرتا ہوں اور میں سب سے پہلا یقین لانے والا ہوں\qt@no{(143)}}%
\qt@newcmd\qurantrans@ur@mxcviii{فرمایا اے موسیٰ میں نے پیغمبری اور ہم کلامی سے دوسرے لوگوں پر تجھے امتیاز دیا ہے جو کچھ میں نے تجھے عطا کیا ہے اسے لے لو اور شکر کرنے والوں میں سے ہو جاؤ\qt@no{(144)}}%
\qt@newcmd\qurantrans@ur@mxcix{اور ہم نے اسے تختیوں پر ہر قسم کی نصیحت اور ہر چیز کی تفصیل لکھ دی سو انہیں مضبوطی سے پکڑ لے او راپنی قوم کو حکم کر کہ اس کی بہتر باتوں پر عمل کریں عنقریب میں تمہیں نافرمانوں کا ٹھکانہ دکھاؤں گا\qt@no{(145)}}%
\qt@newcmd\qurantrans@ur@mc{پھر میں اپنی آیتوں سے انہیں پھیر دوں گا جو زمین میں نا حق تکبر کرتے ہیں اور اگر وہ ساری نشانیاں بھی دیکھ لیں تو بھی ایمان نہیں لائیں گے اور اگر ہدایت کا راستہ دیکھیں تو اسے اپنا راہ نہیں بنائیں گے یہ اس لیے ہے کہ انہوں نے ہماری آیتو ں کو جھٹلایا اور ان سے بے خبر رہے\qt@no{(146)}}%
\qt@newcmd\qurantrans@ur@mci{اور جنھوں نے ہماری آیتوں کو اور آخرت کی ملاقات کو جھٹلایا ان کے اعمال ضائع ہو گئے انہیں وہی سزا دی جائے گی جو کچھ وہ کیا کرتے تھے\qt@no{(147)}}%
\qt@newcmd\qurantrans@ur@mcii{اور موسیٰ کی قوم نے اس کے بعد اپنے زیوروں سے بچھڑا بنا لیا ایک جسم تھا جس میں گائے کی آواز تھی کیا انہوں نے یہ نہ دیکھا کہ وہ ان سے بات بھی نہیں کرتا اور نہ ہی انہیں راہ بتاتا ہے اسے معبود بنا لیا اور وہ ظالم تھے\qt@no{(148)}}%
\qt@newcmd\qurantrans@ur@mciii{اور جب نادم ہوئے اور معلوم کیا کہ بیشک وہ گمراہ ہوگئے تھےتو کہنے لگے اگر ہمارے رب نے ہم پر رحم نہ کیا اور ہمیں نہ بخشا تو بے شک ہم نقصان پانے والوں میں سے ہوں گے\qt@no{(149)}}%
\qt@newcmd\qurantrans@ur@mciv{اور جب موسیٰ اپنی قو م کےی طرف غصہ اور رنج میں بھرے ہوئے واپس آئے تو فرمایا تم نے میرے بعد یہ بڑی نامعقول حرکت کی کیا تم نے اپنے رب کے حکم سے پہلے ہی جلد بازی کر لی اور تختیاں پھینک دیں اور اپنے بھائی کا سر پکڑ ا اسے پنی طرف کھینچنے لگا اس نے کہا کہ اے میری ماں کے بیٹے لوگوں نے مجھے کمزور سمجھا اور قریب تھے کہ مجھے مار ڈالیں سو مجھ پر دشمنوں کو نہ ہنسا اور مجھے گناہگار لوگو ں میں نہ ملا\qt@no{(150)}}%
\qt@newcmd\qurantrans@ur@mcv{کہا اے میرے رب مجھے اور میرے بھائی کو معاف فرما اور ہمیں اپنی رحمت میں داخل کر اور تو سب سے زيادہ رحم کرنے والا ہے\qt@no{(151)}}%
\qt@newcmd\qurantrans@ur@mcvi{بے شک جنہوں نے بچھڑے کو معبود بنایا انہیں ان کے رب کی طرف سے غضب اور دنیا کی زندگی میں ذلت پہنچے گی او رہم بہتان باندھنے والوں کو یہی سزا دیتے ہیں\qt@no{(152)}}%
\qt@newcmd\qurantrans@ur@mcvii{اور جنہوں نے برے کام کیے پھراس کے بعد توبہ کی اور ایمان لے آئے تو بے شک تیرا رب توبہ کے بعد البتہ بخشنے والا مہربان ہے\qt@no{(153)}}%
\qt@newcmd\qurantrans@ur@mcviii{اور جب موسیٰ کا غصہ ٹھنڈا ہوا تو اس نے تختیوں کو اٹھایا اور جو ان میں لکھا ہو ا تھا اس میں ان کے واسطے ہدایت اور رحمت تھی جو اپنے رب سے ڈرتے ہیں\qt@no{(154)}}%
\qt@newcmd\qurantrans@ur@mcix{اور موسیٰ نے اپنی قوم میں سے ستر مرد ہمارے وعدہ گا ہ پر لانے کے لیے چن لیے پھر جب انہیں زلزلہ نے پکڑ ا تو کہا اے میرے رب اگر تو چاہتا تو پہلے ہی انہیں ہلاک کر دیتا کیا تو ہمیں اس کام پر ہلاک کرتا ہے جو ہماری قوموں کے بیوقوفوں نے کیا یہ سب تیری آزمائش ہے جسے تو چاہے اس سے گمراہ کر دے اور جسے چاہے سیدھا رکھے تو ہی ہمارا کارساز ہے سو ہمیں بخش دے اور ہم پر رحم کر اور تو سب سے بہتر بخشنے والا ہے\qt@no{(155)}}%
\qt@newcmd\qurantrans@ur@mcx{او رہمارے لیے اس دنیا میں اور آخرت میں بھلائی لکھ ہم نے تیری طرف رجوع کیا فرمایا میں اپنا عذاب جسے چاہتا ہوں کرتا ہوں اور میری رحمت سب چیزوں سے وسیع ہے پس وہ رحمت ان کے لیے لکھوں گا جو ڈرتے ہیں اجور جو زکواة دیتے ہیں اور جو ہماری آیتوں پر ایمان لاتے ہیں\qt@no{(156)}}%
\qt@newcmd\qurantrans@ur@mcxi{وہ لوگ جو اس رسول کی پیروی کرتے ہیں اور جو نبی امی ہے جسے اپنے ہاں تورات اور انجیل میں لکھا ہوا پاتے ہیں وہ ان کو نیکی کا حکم کرتا ہے اور برے کام سے روکتا ہے اوران کے لیے سب پاک چیزیں حلا ل کرتا ہے اور ان پر ناپاک چیزیں حرام کرتا ہے اور ان پر سے ان کے بوجھ اور وہ قیدیں اتارتا ہے جو ان پر تھیں سو جو لوگ اس پر ایمان لائے اور اس کی حمایت کی اور اسے مدد دی اور اس کے نور کے تابع ہو ئے جو اس کے ساتھ بھیجا گیا ہے یہی لوگ نجات پانے والے ہیں\qt@no{(157)}}%
\qt@newcmd\qurantrans@ur@mcxii{کہہ دو اے لوگو تم سب کی طرف الله کا رسول ہوں جس کی حکومت آسمانوں اور زمین میں ہے اس کے سوا اور کوئی معبود نہیں وہی زندہ کرتا اور مارتا ہے پس الله پر ایمان لاؤ اوراس کے رسول نبی امی پر جو کہ الله پر اور اس کے سب کلاموں پر یقین رکھتا ہے اور اس کی پیروی کرو تاکہ تم راہ پاؤ\qt@no{(158)}}%
\qt@newcmd\qurantrans@ur@mcxiii{اور موسیٰ کی قوم میں سے ایک جماعت ہے جو حق کی راہ بتاتے ہیں اور اسی کے موافق انصاف کرتے ہیں\qt@no{(159)}}%
\qt@newcmd\qurantrans@ur@mcxiv{اور ہم نے انہیں جدا جدا کر دیا بارہ دادوں کی اولاد جو بڑی بڑی جماعتیں تھیں اور موسیٰ کو ہم نے حکم بھیجا جب اس کی قوم نے اس سے پانی مانگا کہ اپنی لاٹھی اس پتھر پر مار تو اس سے بارہ چشمے پھوٹ نکلے ہر قبیلہ نے اپنے گھاٹ پہچان لیا اور ہم نے ان پر ابر کا سایہ کیا اور ہم نے من و سلویٰ اتارا ہم نے جو ستھری چیزیں تمہیں دی ہیں وہ کھاؤ اور انہوں نے ہمارا کوئی نقصان نہیں کیا لیکن اپنا ہی نقصان کرتے تھے\qt@no{(160)}}%
\qt@newcmd\qurantrans@ur@mcxv{اور جب انہیں حکم دیا گیا کہ تم اس بستی میں جا کر رہو اور وہاں جہاں سے تم چاہو کھاؤ اور زباں سے یہ کہتے جاؤ توبہ ہے اور دروازہ میں جھک کر داخل ہو ہم تمہاری غلطیاں معاف کر دیں گے اور نیکو کاروں کو اور زیادہ اجر دیں گے\qt@no{(161)}}%
\qt@newcmd\qurantrans@ur@mcxvi{سو ان میں سے ظالموں نے دوسرا لفظ اس کے سوا بدل دیا جو ان سے کہا گیا تھا پھر ہم نے ان پر آسمان سے عذاب بھیجا اس لیے کہ وہ ظلم کرتے تھے\qt@no{(162)}}%
\qt@newcmd\qurantrans@ur@mcxvii{اور ان سے اس بستی کا حال پوچھ جو دریا کے کنارے پر تھی جب ہفتہ کے معاملہ میں حد سے بڑھنے لگے جب ان کے پاس مچھلیاں ہفتہ کے دن پانی کے اوپر آنے لگیں اور جس دن ہفتہ نہ ہو تو نہ آتی تھیں ہم نے انہیں اس طرح آزمایا اس لیے کہ وہ نافرمان تھے\qt@no{(163)}}%
\qt@newcmd\qurantrans@ur@mcxviii{اور جب ان میں سے ایک جماعت نے کہا ان لوگوں کو کیوں نصیحت کرتے ہو جنہیں الله ہلاک کرنے والا ہے انہیں سخت عذاب دینے والا ہے انہوں نے کہا تمہارے رب کے روبر عذر کرنے کے لیے اور شاید کہ یہ ڈر جائیں\qt@no{(164)}}%
\qt@newcmd\qurantrans@ur@mcxix{پھر جب وہ بھول گئے اس چیز کو جو انہیں سمجھائی گئی تھی توہم نے انہیں نجات دی جو برے کام سے منع کرتے تھے اور ظالموں کو ان کی نافرمانی کے باعث برے عذاب میں پکڑا\qt@no{(165)}}%
\qt@newcmd\qurantrans@ur@mcxx{پھر جب وہ اس کام میں حد سے آگے بڑھ گئے جس سے روکے گئے تھے تو ہم نے حکم دیا کہ ذلیل ہونے والے بندر ہو جاؤ\qt@no{(166)}}%
\qt@newcmd\qurantrans@ur@mcxxi{اور یاد کر جب تیرے رب نے خبر دی تھی کہ یہودپر قیامت کے دن تک ایسے شخص کو ضرور بھیجتا رہے گا جو انہیں براعذاب دیتا رہے بے شک تیرا رب جلدی عذاب دینے والا ہے اور تحقیق وہ بحشنے والا مہربان ہے\qt@no{(167)}}%
\qt@newcmd\qurantrans@ur@mcxxii{اورہم نے انہیں ملک میں مختلف جماعتوں میں متفرق کر دیا بعضے ان میں سے نیک ہیں اور بعضے اور طرح کے اور ہم نے انہیں بھلائیوں اور برائیوں سے آزمایاتاکہ وہ لوٹ آئيں\qt@no{(168)}}%
\qt@newcmd\qurantrans@ur@mcxxiii{پھر ان کے بعد ان کے ایسے جانشین ہوئے جو کتاب کے وارث بنے اس ادنیٰ زندگی کا مال و متاع لےلیتے ہیں اور کہتے ہیں کہ ہمیں معاف کر دیا جائے گا اور اگر ایسا ہی مال ان کے سامنے پھر آئے تو اسے لے لیتے ہیں کیا ان سے کتاب میں عہد نہیں لے لیا گیا تھا کہ الله کے سوا سچ کے اور کچھ نہ کہیں اور انہوں نے جو کچھ اس میں لکھا ہے پڑھا ہے اور آخرت کا گھر ڈرنے والوں کے لیے بہتر ہے کیا تم سمجھتے نہیں\qt@no{(169)}}%
\qt@newcmd\qurantrans@ur@mcxxiv{اور جو لوگ کتاب کے پابند ہیں اور نماز کی پابندی کرتے ہیں بے شک ہم نیکی کرنے والوں کا ثواب ضائع نہیں کریں گے\qt@no{(170)}}%
\qt@newcmd\qurantrans@ur@mcxxv{اورجب ہم نے ان پر پہاڑ اٹھایا گویا کہ وہ سائبان ہے اور وہ ڈرے کہ ان پر گرے گا ہم نے کہا جو ہم نے تمہیں دیا ہے اسے مضبوطی سے پکڑو اور جو اس میں ہے اسے یاد رکھو تاکہ تم پرہیزگار ہو جاؤ\qt@no{(171)}}%
\qt@newcmd\qurantrans@ur@mcxxvi{اور جب تیرے رب نے بنی آدم کی پیٹھوں سے ان کی اولاد کو نکالا اور ان سے ان کی جانوں پر اقرار کرایا کہ میں تمہارا رب نہیں ہوں انہوں نے کہا ہاں ہے ہم اقرار کرتے ہیں کبھی قیامت کے دن کہنے لگو کہ ہمیں تو اس کی خبر نہیں تھی\qt@no{(172)}}%
\qt@newcmd\qurantrans@ur@mcxxvii{یا کہنے لگو ہمارے باپ دادا نے ہم سے پہلے شرک کیاتھا اور ہم ان کے بعد ان کی اولاد تھے کیاتو ہمیں اس کام پر ہلاک کرتا ہے جو گمراہوں نے کیا\qt@no{(173)}}%
\qt@newcmd\qurantrans@ur@mcxxviii{اور اسی طرح ہم کھول کر آیتیں بیان کرتے ہیں تاکہ وہ لوٹ آئيں\qt@no{(174)}}%
\qt@newcmd\qurantrans@ur@mcxxix{اور انہیں اس شخص کا حال سنا دے جسے ہم نے اپنی آیتیں دی تھیں پھر وہ ان سے نکل گیا پھر اس کے پیچھے شیطان لگا تو وہ گمراہوں میں سے ہو گیا\qt@no{(175)}}%
\qt@newcmd\qurantrans@ur@mcxxx{اور اگر ہم چاتے تو ان کی آیتو ں کی برکت سے اس کا رتبہ بلند کرتے لیکن وہ دنیا کی طرف مائل ہو گیا اور اپنی خواہش کے تابع ہو گیا اس کا تو ایسا حال ہے جیسے کتا اس پر تو سختی کرے تو بھی ہانپے اور اگر چھوڑ دے تو بھی ہانپے یہ ان لوگوں کی مثال ہے جنہوں نے ہماری آیتوں کو جھٹلایا سو یہ حالات بیان کر دے شاید کہ وہ فکر کریں\qt@no{(176)}}%
\qt@newcmd\qurantrans@ur@mcxxxi{جنہوں نے ہماری آیتوں کو جھٹلایا ان کی بری مثال ہے اور وہ اپنا ہی نقصان کرتے رہے\qt@no{(177)}}%
\qt@newcmd\qurantrans@ur@mcxxxii{جسے الله تعالیٰ ہدایت دے وہی راہ پاتا ہے اور جسے گمراہ کر دےپس وہی لوگ نقصان اٹھانے والے ہیں\qt@no{(178)}}%
\qt@newcmd\qurantrans@ur@mcxxxiii{اور ہم نے دوزخ کے لیے بہت سے جن اور آدمی پیدا کیے ہیں ان کے دل ہیں کہ ان سے سمجھتے نہیں اور آنکھیں ہیں کہ ان سے دیکھتے نہیں اور کان ہیں کہ ان سے سنتے نہیں وہ ایسے ہیں جیسے چوپائے بلکہ ان سے بھی گمراہی میں زیادہ ہیں یہی لوگ غافل ہیں\qt@no{(179)}}%
\qt@newcmd\qurantrans@ur@mcxxxiv{اور سب اچھے نام الله ہی کے لیے ہیں سو اسے انہیں نامو ں سے پکارو اور چھوڑ دو ان کو جو الله کے نامو ں میں کجروی اختیار کرتے ہیں وہ اپنے کیے کی سزا پا کر رہیں گے\qt@no{(180)}}%
\qt@newcmd\qurantrans@ur@mcxxxv{اور ان لوگوں میں سےجنہیں ہم نے پیدا کیا ایک جماعت ہے جو سچی راہ بتاتی ہے اور اسی کے موافق انصاف کرتے ہیں\qt@no{(181)}}%
\qt@newcmd\qurantrans@ur@mcxxxvi{اور جنہوں نے ہماری آیتوں کو جھٹلایا ہم انہیں آہستہ آہستہ پکڑیں گے ایسی جگہ سے جہاں انہیں خبر بھی نہ ہو گی\qt@no{(182)}}%
\qt@newcmd\qurantrans@ur@mcxxxvii{اور میں انہیں مہلت دوں گا بے شک میری تدبیر بڑی مضبوط ہے\qt@no{(183)}}%
\qt@newcmd\qurantrans@ur@mcxxxviii{کیا انہوں نے غور نہیں کیاکہ ان کے ساتھی کو جنوں تو نہیں ہے وہ تو کھلم کھلا ڈرانے والا ہے\qt@no{(184)}}%
\qt@newcmd\qurantrans@ur@mcxxxix{اور کیا انہوں نے آسمان اور زمین کی سلطنت کو نہیں دیکھا اور دوسری چیزوں کو جو الله نے پیدا کی ہیں اور یہ کہ ممکن ہے کہ ان کی اجل قریب ہی ہو پھرقرآن کے بعد کس بات پر یہ لوگ ایمان لائيں گے\qt@no{(185)}}%
\qt@newcmd\qurantrans@ur@mcxl{جسے الله گمراہ کر دے اسے کوئی راہ دکھانے والا نہیں اور انہیں الله چھوڑ دیتا ہے کہ اپنی سرکشی میں حیران پھیر یں\qt@no{(186)}}%
\qt@newcmd\qurantrans@ur@mcxli{قیامت کے متعلق تجھ سے پوچھتے ہیں کہ اس کی آمد کا کونسا وقت ہے کہہ دو اس کی خبر تو میرے رب ہی کے ہاں ہے وہی اس کے وقت پر ظاہر کر دکھائے گا وہ آسمانو ں اور زمین میں بھاری بات ہے وہ تم پر محض اچانک آجائے گی تجھ سے پوچھتے ہیں گویا کہ تو اس کی تلاش میں لگا ہوا ہے کہہ دو اس کی خبر خاص الله ہی کے ہاں ہے لیکن اکثر لوگ نہیں سمجھتے\qt@no{(187)}}%
\qt@newcmd\qurantrans@ur@mcxlii{کہہ دو میں اپنی ذات کے نفع و نقصان کا بھی مالک نہیں مگرجو الله چاہے اور اگر میں غیب کی بات جان سکتا تو بہت کچھ بھلائیاں حاصل کر لیتا اور مجھے تکلیف نہ پہنچتی میں تو محض ڈرانے والا اور خوشخبری دینے والا ہوں ان لوگوں کو جو ایمان دار ہیں\qt@no{(188)}}%
\qt@newcmd\qurantrans@ur@mcxliii{وہ وہی ہے جس نے تمہیں ایک جان سے پیدا کیا اور اسی سے اس کا جوڑ بنایا تاکہ اس سے آرام پائے پھر جب میاں نے بیوی سے ہم بستری کی تو اس کو ہلکا سا حمل رہ گیا پھر اسے لیے پھرتی رہی پھر جب وہ بوجھل ہو گئی تب دونوں میاں بیوی نے الله سے جو ان کا مالک ہے دعا کی اگر آپ نے ہمیں صحیح سالم اولاد دے دی تو ہم ضرور شکر گزار ہوں گے\qt@no{(189)}}%
\qt@newcmd\qurantrans@ur@mcxliv{پھر جب الله نے انکو صحیح سالم اولاد دی تو الله کی دی ہوئی چیزوں میں وہ دونوں الله کا شریک بنانے لگے سو الله ان کے شرک سے پاک ہے\qt@no{(190)}}%
\qt@newcmd\qurantrans@ur@mcxlv{کیا ایسوں کو شریک بناتے ہیں جو کچھ بھھی نہیں بنا سکتے اور وہ خود بنائے ہوئے ہیں\qt@no{(191)}}%
\qt@newcmd\qurantrans@ur@mcxlvi{اور نہ وہ ان کی مدد کر سکتے ہیں اور نہ اپنی ہی مدد کر سکتے ہیں\qt@no{(192)}}%
\qt@newcmd\qurantrans@ur@mcxlvii{اور اگر تم انہیں راستہ کی طرف بلاؤ تو تمہاری تابعداری نہ کریں برابر ہے کہ تم انہیں پکارو یا چپکے رہو\qt@no{(193)}}%
\qt@newcmd\qurantrans@ur@mcxlviii{بے شک جنہیں تم الله کے سوا پکارتے ہو وہ تمہاری طرح کے بندے ہیں پھر انہیں پکار کر دیکھو پھر چاہے کہ وہ تمہاری پکار کو قبول کریں اگر تم سچے ہو\qt@no{(194)}}%
\qt@newcmd\qurantrans@ur@mcxlix{کیا ان کے پاؤں ہیں جن سے وہ چلیں یا ان کے ہاتھ ہیں جن سے وہ پکڑیں یا ان کی آنکھیں ہیں جن سے وہ دیکھیں یا ان کے کان ہیں جن سے وہ سنیں کہ تو اپنے شریکوں کو پکارو پھر میری برائی کی تدبیر کرو پھر مجھے ذرا مہلت نہ دو\qt@no{(195)}}%
\qt@newcmd\qurantrans@ur@mcl{بےشک میرا حمایتی الله ہے جس نے کتاب نازل فرمائی اور وہ نیکو کاروں کی حمایت کرتا ہے\qt@no{(196)}}%
\qt@newcmd\qurantrans@ur@mcli{اور جنہیں تم پکارتے ہو وہ تمہاری مدد نہیں کر سکتے اور نہ اپنی جان کی مدد کر سکتے ہیں\qt@no{(197)}}%
\qt@newcmd\qurantrans@ur@mclii{اور اگر تم انہیں راستہ کی طرف پکارو تو وہ کچھ نہیں سنیں گے اور تو دیکھے گا کہ وہ تیری طرف دیکھتے ہیں حالانکہ وہ کچھ نہیں دیکھتے\qt@no{(198)}}%
\qt@newcmd\qurantrans@ur@mcliii{درگزر کر اور نیکی کا حکم دے اور جاہلوں سے الگ رہ\qt@no{(199)}}%
\qt@newcmd\qurantrans@ur@mcliv{اور اگر تجھے کوئی وسوسہ شیطان کی طرف سے آئے تو الله کی پناہ مانگ لیا کر بے شک وہ سننے والا جاننے والا ہے\qt@no{(200)}}%
\qt@newcmd\qurantrans@ur@mclv{بے شک جو لوگ خدا سے ڈرتے ہیں جب انہیں کوئي خطرہ شیطان کی طرف سے آتا ہے تو وہ یاد میں لگ جاتے ہیں پھر اچانک ان کیآنکھیں کھل جاتی ہیں\qt@no{(201)}}%
\qt@newcmd\qurantrans@ur@mclvi{اور جو شیاطین کے تابع ہیں وہ انہیں گمراہی میں کھینچے چلے جاتے ہیں پھر وہ باز نہیں آتے\qt@no{(202)}}%
\qt@newcmd\qurantrans@ur@mclvii{اور جب توان کے پاس کوئی معجزہ نہیں لاتا تو کہتے ہیں کہ تو فلاں معجزہ کیوں نہیں لایا کہہ دو میں اس کا اتباع کرتا ہوں جو مجھ پر میرے رب کی طرف سے بھیجا جاتا ہے یہ تمہارے رب کی طرف سے بہت سی دلیلیں ہیں اور ہدایت اور رحمت ہے ان لوگو ں کے لیے جو ایمان دار ہیں\qt@no{(203)}}%
\qt@newcmd\qurantrans@ur@mclviii{اورجب قرآن پڑھا جاتا جائے تو اسے کان لگا کر سنو اور چپ رہو تاکہ تم پر رحم کیا جائے\qt@no{(204)}}%
\qt@newcmd\qurantrans@ur@mclix{اوراپنے رب کو اپنے دل میں عاجزی کرتا ہوا اور ڈرتاہوا یاد کرتا رہ اور صبح اور شام بلند آواز کی نسبت ہلکی آواز سے اور غافلوں سے نہ ہو\qt@no{(205)}}%
\qt@newcmd\qurantrans@ur@mclx{بے شک جو تیرے رب کے ہاں ہیں وہ اس کی بندگی سے تکبر نہیں کرتے اور اس کی پاک ذات کو یاد کرتے ہیں اور اسی کو سجدہ کرتے ہیں\qt@no{(206)}}%
\qt@newcmd\qurantrans@ur@mclxi{\basmalahur تجھ سے غنیمت کا حکم پوچھتے ہیں کہہ دے غنیمت کا مال الله اور رسول کا ہے سو الله سے ڈرو اور آپس میں صلح کرو اور الله اور اس کے رسول کا حکم مانو اگر ایمان دار ہو\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mclxii{ایمان والے وہی ہیں جب الله کا نام آئے تو ان کے دل ڈر جائیں اورجب اس کی آیتیں ان پر پڑھی جائیں تو ان کا ایمان زیادہ ہو جاتا ہے اور اور وہ اپنے رب پر بھروسہ رکھتے ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mclxiii{وہ جو نماز قائم کرتے ہیں اور جو ہم نے انہیں رزق دیا ہے اس میں سے خرچ کرتے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mclxiv{یہی سچے ایمان والے ہیں ان کے رب کے ہاں ان کے لیے درجے ہیں اور بخشش ہے اور عزت کا رزق ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mclxv{جیسے تیرے رب نے تیرے گھر سے سچائی کے ساتھ نکالا اور بے شک ایک جماعت مسلمانوں میں سے نا پسند کرنے والی تھی\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mclxvi{وہ تجھ سے حق بات میں اس کے ظاہر ہو چکنے کے بعد جھگڑتے تھے گویا وہ آنکھوں سے دیکھتے ہوئے موت کی طرف ہانکے جاتے ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mclxvii{اور جس وقت دو جماعتوں میں سے ایک کا الله تم سے وعدہ کرتا تھا کہ وہ تمہارے ہاتھ لگے گی اور تم چاہتے تھے جس میں کانٹا نہ ہو وہ تمہیں ملے اور الله چاہتا تھا کہ اپنے حکم سے حق کو ثابت کردے اور کافروں کی جڑ کاٹ دے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mclxviii{تاکہ حق کو ثابت کر دے اور باطل کو مٹا دے اگرچہ گناہگار ناراض ہوں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mclxix{جب تم اپنے رب سے فریاد کر رہے تھے اس نے جواب میں فرمایا کہ میں تمہاری مدد کے لیے پے درپے ایک ہزار فرشتے بھیج رہا ہوں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mclxx{اور یہ تو الله نے فقط خوش خبری دی تھی اور تاکہ تمہارے دل اس سے مطمئن ہو جائیں اور مدد تو صرف الله ہی کی طرف سے ہے بے شک الله غالب حکمت والا ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mclxxi{جس وقت اس نے تم پر اپنی طرف سے تسکین کے لیے اونگھ ڈال دی اور تم پر آسمان سے پانی اتارا تاکہ اس سے تمہیں پاک کر دے اور شیطان کی نجاست تم سے دور کر دے اور تمہارے دلوں کو مضبوط کر دے اور اس سے تمہارے قدم جما دے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mclxxii{جب تیرے رب نے فرشتوں کو حکم بھیجا کہ میں تمہارے ساتھ ہوں تم مسلمانوں کے دل ثابت رکھو میں کافروں کے دلوں میں دہشت ڈال دوں گا سو گردنوں پر مارواور ان کے پور پور پر مارو\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mclxxiii{یہ اس لیے ہے کہ وہ الله اوراس کے رسول کے مخالف ہیں اور جو کوئی اللہ اور اس کےرسول کا مخالف ہو تو بے شک الله سخت عذب دینے والا ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mclxxiv{یہ تو چکھ لو اور جان لو کہ بے شک کافروں کے لیے دوزخ کا عذاب ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mclxxv{اے ایمان والو جب تم کافروں سے میدان جنگ میں ملو تو ان سے پیٹھیں نہ پھیرو\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mclxxvi{اور جو کوئی اس دن ان سے پیٹھ پھیرے گا مگر یہ کہ لڑائی کا ہنر کرتا ہو یا فوج میں جا ملتا ہو سو وہ الله کا غضب لے کر پھرا اور اس کا ٹھکانا دوزخ ہے اور بہت برا ٹھکانا ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mclxxvii{سو تم نے انہیں قتل نہیں کیا بلکہ الله نے انہیں قتل کیا اور تو نے مٹھی نہیں پھینکی جب کہ پھینکی تھی بلکہ الله نے پھینکی تھی اور تاکہ ایمان والوں پر اپنی طرف سے خوب احسان کرے بے شک الله سننے والا جاننے والا ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mclxxviii{یہ تو ہو چکا اور بےشک الله کافروں کی تدبیر کو کمزور کرنے والا ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mclxxix{اگر تم فیصلہ چاہتے ہو تو تمہارا فیصلہ آ چکا اور اگر باز آؤ تو تمہارے لیے بہتر ہے اور اگر پھر یہی کرو گے تو ہم بھی پھر یہی کریں گے اور تمہاری جمعیت ذرا بھی کام نہیں آئے گی اگرچہ وہ بہت ہوں اوربے شک اللہ ایمان والوں کے ساتھ ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mclxxx{اے ایمان والو الله اور اس کے رسول کا حکم مانو اور سن کر اس سے مت پھرو\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mclxxxi{اور ان لوگو ں کی طرح نہ ہو جنہوں نے کہا ہم نے سن لیا اور وہ سنتے نہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mclxxxii{بے شک سب جانوں میں سے بدتر الله کے نزدیک وہی بہرے گونگے ہیں جو نہیں سمجھتے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mclxxxiii{اور اگر الله ان میں کچھ بھلائی جانتا تو انہیں سنا دیتا اور اگر انہیں اب سنا دے تو منہ پھیر کر بھاگیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mclxxxiv{اے ایمان والو الله اور رسول کا حکم مانو جس وقت تمہیں اس کام کی طرف بلائے جس میں تمہاری زندگی ہے اور جان لو کہ الله آدمی اور اس کے دل کے درمیان آڑ بن جاتا ہے اور بے شک اسی کی طرف جمع کیے جاؤ گے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mclxxxv{اور تم اس فتنہ سے بچتے رہو جو تم میں سے خاص ظالموں پر ہی نہ پڑے گا اور جان لو کہ بے شک الله سخت عذاب کرنے والا ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mclxxxvi{اور یاد کرو جس وقت تم تھوڑے تھے ملک میں کمزور سمجھے جاتے تھے تم ڈرتے تھے کہ لوگ تمہیں اچک لیں پھر اس نے تمہیں ٹھکانا بنا دیا اور اپنی مدد سے تمہیں قوت دی اور تمہیں ستھری چیزوں سے رزق دیاتاکہ تم شکر کرو\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mclxxxvii{اے ایمان والو الله اور اس کے رسول سے خیانت نہ کرو اور آپس کی امانتوں میں بھی خیانت نہ کرو حالانکہ تم جانتے ہو\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mclxxxviii{اور جان لو کہ تمہارے مال اور تمہاری اولاد ایک امتحان کی چیز ہے اور بے شک الله کہ ہاں بڑا اجر ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mclxxxix{اے ایمان والو اگر تم الله سے ڑرتے رہو گے تو الله تمہیں ایک فیصلہ کی چیز دے گا اور تم سے تمہارے گناہ دور کر دے گا اور تمہیں بخش دے گا اور الله بڑے فضل والا ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mcxc{اور جب کافر تیرے متعلق تدبیریں سوچ رہے تھے کہ تمہیں قید کر دیں یا تمہیں قتل کر دیں یا تمہیں دیس بدر کر دیں وہ اپنی تدبیریں کر رہے تھے اور الله ہی اپنی تدبیر کر ہا تھا اور الله بہترین تدبیر کرنے والا ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mcxci{اور جب ان کے سامنے ہماری آیتیں پڑھی جاتی ہیں تو کہتے ہیں کہ ہم نے سن لیا اور اگر ہم چاہیں تو اس کے برابر ہم بھی کہہ دیں اس میں پہلو ں کے قصے کے سوا اور کچھ نہیں\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mcxcii{اورجب انہوں نے کہا کہ اے الله اگر یہ دین تیری طرف سے حق ہے تو ہم پر آسمان سے پتھر برسا یا ہم پر دردناک عذاب لا\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mcxciii{اور الله ایسا نہ کرے گا کہ انہیں تیرتے ہوئے عذاب دے اور الله عذاب کرنے الا نہیں درآنحالیکہ وہ بخشش مانگتے ہوں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mcxciv{اور الله انہیں عذاب کیوں نہ دے حالانکہ وہ مسجد حرام سے روکتے ہیں اور وہ اس کے اہل نہیں ہیں اس میں تو اہل پرہیزگاری ہیں لیکن ان میں سے اکثر نہیں سمجھتے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mcxcv{اورکعبہ کے پاس ان کی نماز سوائے سیٹیاں اور تالیاں بجانے کے اور کچھ نہیں تھی سو عذاب سبب اس کے کہ تم کفر کرتے تھے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mcxcvi{بے شک جو لوگ کافر ہیں وہ اپنے مال خرچ کرتے ہیں تاکہ الله کی راہ سے روکیں سو ابھی اور بھی خرچ کریں گے پھر وہ ان کے لیے حسرت ہو گا پھر مغلوب کیے جائیں گے اور جو کافر ہیں وہ دوزخ کی طرف جمع کیے جائیں گے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mcxcvii{تاکہ الله ناپاک کو پاک سے جدا کر دے اور ایک ناپاک کو دوسرے پر دھر کر ڈھیر بنائے پھر اسے دوزخ میں ڈال دے وہی لوگ نقصان اٹھانے والے ہیں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mcxcviii{کافروں سے کہہ دو اگر وہ باز آجائيں تو جو کچھ گزر چکا وہ انہیں معاف کر دیا جائے گا اور اگر لوٹیں گے تو پہلے کافروں کے حق میں قانون نافذ ہو چکا ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mcxcix{اور تم ان سے اس حد تک لڑو کہ شرک کا غلبہ نہ رہنے پائے اور سارا دین الله ہی کا ہو جکائے پھر اگر یہ باز آجائیں تو الله ان کے اعمال دیکھنے والا ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mcc{اور اگر وہ پھر جائیں تو جان لو کہ الله تمہارا دوست ہے اور بہت اچھا دوست ہے اوربہت اچھا مددگار ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mcci{اور جان لو کہ جو کچھ تمہیں بطور غنیمت ملے خواہ کوئی چیز ہو تو اس میں سے پانچواں حصہ الله اور اس کے رسول کا ہے اور رشتہ داروں اور یتیموں اور مسکینوں اور مسافروں کے لیے ہے اگر تمہیں الله پر یقین ہے اور اس چیز پر جو ہم نے اپنے بندے پر فیصلہ کے دن اتاری جس دن دونوں جماعتیں ملیں اور الله ہر چیز پر قادر ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mccii{جس وقت تم درلے کنارے پر تھے اور وہ پرلےکنارے پر اور قافلہ تم سے نیچے اتر گیا تھا اور اگرتم آپس میں وعدہ کرتے تو ایک ساتھ وعدہ پر نہ پہنچتے لیکن الله کو ایک کام کرنا تھا جو مقرر ہو چکا تھا تاکہ جو ہلاک وہ اتمام حجت کے بعد ہلاک ہو اور جو زندہ رہے وہ اتمام حجت کے بعد زندہ رہے اور بے شک الله سننے والا جاننے والا ہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mcciii{جب کہ الله نے وہ کافر تجھے تیرے خواب میں تھوڑے کر کے دکھلائے اور اگرتجھے بہت دکھلا دیتا تو تم لوگ نامردی کر تے اور کام میں جھگڑا ڈالتے لیکن الله نے بچا لیا جو بات دلوں میں ہے وہ اسے خوب معلوم ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mcciv{اور جب تمہیں وہ فوج مقابلہ کے وقت تمہاری آنکھوں میں تھوڑی کر کے دکھائی اور تمہیں ان کی آنکھوں میں تھوڑا کر کے دکھایا تاکہ الله ایک کام پورا کر دے جو مقرر ہو چکا تھا اور ہر کام الله تک ہی پہنچتا ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mccv{اے ایمان والو! جب کسی فوج سے ملو تو ثابت قدم رہو اور الله کو بہت یاد کرو تاکہ تم نجات پاؤ\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mccvi{اور الله اوراس کے رسول کا کہا مانو اور آپس میں نہ جھگڑو ورنہ بزدل ہو جاؤ گے اور تمہاری ہوا اکھڑ جائے گی اور صبر کرو بے شک الله صبر کرنے والوں کے ساتھ ہے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mccvii{اور ان لوگوں جیسا نہ ہونا جو اتراتے ہوئے اور لوگوں کو دکھانے کے لیے گھروں سے نکل آئے اور الله کی راہ سے روکتے تھے اور جو کچھ یہ کرتے ہیں الله اس پر احاطہ کرنے والا ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mccviii{اورجس وقت شیطان نے ان کے اعمال کو ان کی نظروں میں خوشنما کر دیا اورکہا کہ آج کے دن لوگوں میں سے کوئی بھی تم پر غالب نہ ہوگا اور میں تمہارا حمایتی ہوں پھر جب دونوں فوجیں سامنے ہوئیں تووہ اپنے ایڑیوں پر الٹا پھرا اور کہا میں تمہارے ساتھ نہیں ہوں میں ایسی چیر دیکھتا ہوں جو تم نہیں دیکھتے میں الله سے ڈرتا ہوں اور الله سخت عذاب کرنے والا ہے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mccix{اس وقت منافق اور جن کے دلو ں میں مرض تھا کہتے تھے کہ انہیں ان کے دین نے مغلوب کر رکھا ہے اور جو کوئی الله پر بھروسہ کرے تو الله زبردست حکمت والا ہے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mccx{اور اگر تو دیکھے جس وقت فرشتے کافروں کی جان قبض کرتے ہیں ان کے مونہوں او رپیٹہوں پر مارتے ہیں اور کہتے ہیں جلنے کا عذاب چکھو\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mccxi{یہ اسی کا بدلہ ہے جو تمہارے ہاتھوں نے آگے بھیجا اور بے شک الله بندوں پر ظلم نہیں کرتا\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mccxii{جیسا فرعونیوں اوران سے پہلے لوگوں کا حال ہوا تھا انہوں نے الله کی آیتوں سے انکار کیا تو الله نے ان کے گناہوں کی سزا میں انہیں پکڑ لیا بے شک الله زبردست اور سخت عذاب کرنے والا ہے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mccxiii{اس کا سبب یہ ہے کہ الله ہر گز اس نعمت کو نہیں بدلتا جو اس نے کسی قوم کو دی تھی جب تک وہ خود اپنے دلوں کی حالت نہ بدلیں اوراس لیے کہ الله سننے والا جاننے والا ہے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mccxiv{جیسے فرعونیوں اور ان سے پہلے لوگوں کاحال ہوا تھا انہوں نے اپنے رب کی آیتوں کو جھٹلایا تو ہم نے انہیں ان کے گناہوں کے سبب ہلاک کر ڈالا اور فرعونیوں کو ڈبو دیا اور سب ظالم تھے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mccxv{اور الله کے ہاں سب جانداروں میں سے بدتر وہ ہیں جنہوں نے کفر کیا پھر وہ ایمان نہیں لاتے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mccxvi{جن لوگوں سے تو نے عہد لیا پھر وہ ہر دفعہ اپنے عہد کو توڑتے ہیں اور وہ نہیں ڈرتے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mccxvii{سو اگر کبھی تو انہیں لڑائی میں پائے تو انہیں ایسی سزا دے کہ ان کے پچھلے دیکھ کر بھاگ جائیں تاکہ انہیں عبرت ہو\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mccxviii{اور اگر تمہیں کسی قوم سے دغابازی کا ڈر ہو تو ان کا عہد ان کی طرف پھینک دو ایسی طرح پر کہ تم اور وہ برابر ہو جاؤ بے شک الله دغا بازوں کو پسند نہیں کرتا\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mccxix{اور کافر یہ نہ خیال کریں کہ وہ بھاگ نکلے ہیں بے شک وہ ہمیں ہر گز عاجز نہ کر سکیں گے\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mccxx{اور ان سے لڑنے کے لیے جو کچھ (سپاہیانہ) قوت سے پلے ہوئے گھوڑوں سے جمع کر سکو سو تیار رکھو کہ اس سے الله کے دشمنوں پر اور تمہارے دشمنوں پر اور ان کےسوا دوسروں پر جنہیں تم نہیں جانتے الله انہیں جانتا ہے ہیبت پڑے اور الله کی راہ میں جو کچھ تم خرچ کرو گےتمہیں (اس کا ثواب) پورا ملے گا اور تم سے بے انصافی نہیں ہو گی\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mccxxi{اور اگر وہ صلح کے لیے مائل ہوں تو تم بھی مائل ہو جاؤ اور الله پر بھروسہ کرو بے شک وہی سننے والا جاننے والا ہے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mccxxii{اور اگر وہ چاہیں کہ تمہیں دھوکہ دیں تو تجھے الله کافی ہے جس نے تمہیں اپنی مدد سے اور مسلمانوں سے قوت بحشی\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mccxxiii{اور ان کے دلو ں میں الفت ڈال دی جو کچھ زمین میں ہے اگر سارا تو خرچ کر دیتا ان کے دلوں میں الفت نہ ڈال سکتا لیکن الله نے ان میں الفت ڈال دی بے شک الله غالب حکمت والا ہے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mccxxiv{اے نبی! تجھے اور مومنوں کو جو تیرے تابعدار ہیں الله کافی ہے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mccxxv{اے نبی! مسلمانوں کو جہاد کی ترغیب دو اگر تم میں بیس آدمی ثابت قدم رہنے والے ہوں گے تو وہ سو پر غالب آئیں گے اور اگر تم میں سو ہوں گے تو ہزار کافروں پر غالب آئیں گے اس لیے کہ وہ لوگ کچھ نہیں سمجھتے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mccxxvi{اب الله نےتم سے بوجھ ہلکا کر دیا اور معلوم کر لیا کہ تم میں کس قدر کمزوری ہے پس اگر تم سو ثابت قدم رہنے والے ہوں گے تو دو سو پر غالب آئيں گے اور اگر ہرار ہوں گے تو الله کے حکم سے دو ہزار پر غالب آئيں گے اور الله صبر کرنے والوں کے ساتھ ہے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mccxxvii{نبی کو نہیں چاہیئے کہ اپنے ہاں قیدیوں کو رکھے یہاں تک کہ ملک میں خوب خونریزی کر لے تم دنیا کی زندگی کا سامان چاہتے ہو اور الله آخرت کا ارادہ کرتا ہے اور الله غالب حکمت والا ہے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mccxxviii{اگر الله کا حکم پہلے نہ ہو چکا ہوتا تو جو تم نے لیا اس کے بدلے تم پربڑا عذاب ہوتا\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mccxxix{پس جو مال تمہیں غنیمت میں حلال اور طیب ملا ہے اسے کھاؤ اور الله سے ڈرو بے شک الله بخشنے والا مہربان ہے\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mccxxx{اے نبی! جو قیدی تمہارے ہاتھ میں ہیں ان سے کہہ دو کہ اگر الله تمہارے دلوں میں نیکی معلوم کر ے گا تو تمہیں اس سے بہتر دے گا جو تم سے لیا گیا ہے اور تمہیں بخشے گا اور الله بحشنے والا مہربان ہے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mccxxxi{اور اگر یہ لوگ تم سے دغا کرنا چاہیں گےیہ تو پہلے ہی الله سے دغا کر چکے ہیں پھر الله نے انہیں گرفتار کرا دیا اور الله جاننے والا حکمت والا ہے\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mccxxxii{بے شک جو لوگ ایمان لائے اور گھر چھوڑا اور اپنے مالوں اور جانوں سے الله کی راہ میں لڑے اور جن لوگوں نے جگہ دی اور مدد کی وہ آپس میں ایک دوسرے کے رفیق ہیں اورجو ایمان لائے اور گھر نہیں چھوڑا تمہیں ان کی وراثت سے کوئی تعلق نہیں یہاں تک کہ وہ ہجرت کریں اور اگر وہ دین کے معاملہ میں مدد چاہیں تو تمہیں ان کی مدد کرنی لازم ہے مگران لوگو ں کے مقابلہ میں کہ ان میں اور تم میں عہد ہو اور جو تم کرتے ہو الله اسے دیکھتا ہے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mccxxxiii{اور جو لوگ کافر ہیں وہ ایک دوسرے کے رفیق ہیں اگر تم یوں نہ کرو گے تو ملک میں فتنہ پھیلے گا اوروہ بڑا فساد ہوگا\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mccxxxiv{اور جو لوگ ایمان لائے اوراپنے گھر چھوڑے اور الله کی راہ میں لڑے اورجن لوگوں نے انہیں جگہ دی اور ان کی مدد کی وہی سچے مسلمان ہیں ان کے لیے بخشش اور عزت کی روزی ہے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mccxxxv{اورجو لوگ اس کے بعد ایمان لائے اور گھر چھوڑے اور تمہارے ساتھ ہو کر لڑے سو وہ لوگ بھی تمہیں میں سے ہیں اور رشتہ دار آپس میں الله کے حکم کے مطابق ایک دوسرے کے زیادہ حق دار ہیں بے شک الله ہر چیز سے خبردار ہے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mccxxxvi{\basmalahur الله اور اس کے رسول کی طرف سے ان مشرکوں سے بیزاری ہے جن سے تم نے عہد کیا تھا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mccxxxvii{سو اس ملک میں چار مہینے پھر لو اور جان لو کہ تم الله کو عاجز نہیں کر سکوگے اور بے شک الله کافروں کو ذلیل کرنے والا ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mccxxxviii{اور اللہ اور اس کے رسول کی طرف سے بڑے حج کے دن لوگوں کو آگاہ کیا جاتا ہے کہ اللہ اور اس کا رسول مشرکوں سے بیزار ہیں پس اگر تم توبہ کرو تو تمہارے لئے بہتر ہے اور اگر نہ مانو تو جان لو کہ تم اللہ کو ہرگز عاجز کرنے والے نہیں اور کافروں کو درد ناک عذاب کی خوشخبری سنادو\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mccxxxix{مگر جن مشرکوں سے تم نے عہد کیا تھا پھر انہوں نے تمہارے ساتھ کوئی قصور نہیں کیا اور تمہارے مقابلے میں کسی کی مد نہیں کی سو ان سے ان کا عہد ان کی مدت تک پورا کر دو بے شک الله پرہیز گارو ں کو پسند کرتا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mccxl{پھر جب عزت والے مہینے گزر جائیں تو مشرکوں کو جہاں پاؤ قتل کر دو اور پکڑو اور انہیں گھیر لو اور ان کی تاک میں ہر جگہ بیٹھو پھر اگر وہ توبہ کریں اور نماز قائم کریں اور زکواة دیں تو ان کا راستہ چھوڑ دو بے شک الله بخشنے والا مہربان ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mccxli{اور اگر کوئی مشرک تم سے پناہ مانگے تو اسے پناہ دے دو یہاں تک کہ الله کا کلام سنے پھر اسے اس کی امن کی جگہ پہنچا دو یہ اس لیے ہے کہ وہ لوگ بے سمجھ ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mccxlii{بھلا مشرکوں کے لیے الله اور اس کے رسول کے ہاں عہدکیوں کر ہو سکتا ہے ہاں جن لوگوں کے ساتھ تم نے مسجد حرام کے نزدیک عہد کیا ہے اگر وہ قائم رہیں توتم بھی قائم رہو بے شک الله پرہیزگاروں کو پسند کرتا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mccxliii{کیوں کر صلح ہو اور اگر وہ تم پر غلبہ پائیں تو نہ تمہاری قرابت کا لحاظ کریں اور نہ عہد کا تمہیں اپنی منہ کی باتوں سے راضی کرتے ہیں اور ان کے دل نہیں مانتے اور ان میں سے اکثر بد عہد ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mccxliv{انہوں نے الله کی آیتوں کو تھوڑی قیمت پر بیچ ڈالا پھر الله کے راستے سے روکتے ہیں بے شک وہ برا ہے جو کچھ وہ کرتے ہیں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mccxlv{یہ لوگ کسی مومن کے حق میں نہ رشتہ داری کا خیال کرتے ہیں اور نہ عہد اور یہی لوگ حد سے گزرنے والے ہیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mccxlvi{اگر یہ توبہ کریں اور نماز قائم کریں اور زکواة دیں تو دین میں تمہارے بھائی ہیں اور ہم سمجھ داروں کے لیے کھول کھول کر احکام بیان کرتے ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mccxlvii{اور اگر وہ عہد کرنے کے بعد اپنی قسمیں تو ڑ دیں اور تمہارے دین میں عیب نکالیں تو کفر کے سرداروں سے لڑو ان کی قسموں کوئی اعتبار نہیں تاکہ وہ باز آ آئیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mccxlviii{خبردار! تم ایسے لوگوں سے کیوں نہ لڑو جنہوں نے اپنی قسموں کو توڑ ڈالا اور پیغمبر کو جلا وطن کرنے کا ارادہ کیا اور انہوں نے پہلے تم سے عہد شکنی کی کیا تم ان سے ڈرتے ہو الله زيادہ حق دار ہے کہ تم اس سے ڈرو اگر تم ایمان دار ہو\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mccxlix{ان سے لڑو تاکہ الله انہیں تمہارے ہاتھوں سے عذاب دے اور انہیں ذلیل کرے اور تمہیں ان پر غلبہ دے اور مسلمانوں کے دلوں کو ٹھنڈا کرے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mccl{اور ان کے دلوں سے غصہ دور کر ے اور الله جسے چاہے توبہ نصیب کرے اور الله جاننے والا حکمت والا ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mccli{کیا تم یہ خیال کرتے ہو کہ چھوڑ دیے جاؤ گے حالانکہ ابھی الله نے ایسے لوگو ں کو جدا ہی نہیں کیا جنہوں نے تم میں سے جہاد کیا اور الله اور اس کے رسول اورمومنوں کے سوا کسی کو دلی دوست نہیں بنایا اور الله تمہارے سب کاموں سے با خبر ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mcclii{مشرکوں کا کام نہیں کہ الله کی مسجدیں آباد کریں جب کہ وہ اپنے آپ پر کفر کی گواہی دے رہے ہوں ان لوگوں کے سب اعمال بے کار ہیں اور وہ ہمیشہ آگ میں رہیں گے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mccliii{الله کی مسجدیں وہی آباد کرتا ہے جو الله پر اور آخرت پر ایمان لایا اور نماز قائم کی اور زکواة دی اور الله کے سوا کسی سے نہ ڈرا سو وہ لوگ امیدوار ہیں کہ ہدایت والوں میں سے ہوں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mccliv{کیا تم نے حاجیوں کا پانی پلانا اور مسجد حرام کا آباد کرنا اس کے برابر کر دیا جو الله پر اور آخرت کے دن پر ایمان لایا اور الله کی راہ میں لڑا الله کہ ہاں یہ برابر نہیں ہیں اور الله ظالم لوگوں کو راستہ نہیں دکھاتا\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mcclv{جو لوگ ایمان لائے اور گھر چھوڑے اور الله کی راہ میں اپنے مالوں اور جانوں سے لڑے الله کے ہاں ان کے لیے بڑا درجہ ہے اور وہی لوگ مراد پانے والے ہیں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mcclvi{انہیں ان کا رب اپنی طرف سے مہربانی اور رضا مندی اور باغوں کی خوشخبری دیتا ہے جن میں انہیں ہمیشہ آرام ہوگا\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mcclvii{ان میں ہمیشہ رہیں گے بے شک الله کے ہاں بڑا ثواب ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mcclviii{اے ایمان والو! اپنے باپوں اور بھائیوں سے دوستی نہ رکھو اگر وہ ایمان پر کفر کو پسند کریں اور تم میں سے جو ان سے دوستی رکھے گا سو وہی لوگ ظالم ہیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mcclix{کہہ دے اگر تمہارے باپ اور بیٹے اور بھائی اوربیویاں اور برادری اور مال جو تم نے کمائے ہیں اور سوداگری جس کے بند ہونے سے تم ڈرتے ہو اور مکانات جنہیں تم پسند کر تے ہو تمہیں الله اور اس کے رسول اوراس کی راہ میں لڑنے سے زیادہ پیارے ہیں تو انتظار کرو یہاں تک کہ الله اپنا حکم بھیجے اور الله نافرمانوں کو راستہ نہیں دکھاتا\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mcclx{الله بہت سے میدانوں میں تمہاری مدد کر چکا ہے اور حنین کے دن جب تم اپنی کثرت پر خوش ہوئے پھر وہ تمہارے کچھ کام نہ آئی اور تم پر زمین باوجود اپنی فراخی کے تنگ ہو گئی پھر تم پیٹھ پھیر کر ہٹ گئے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mcclxi{پھر الله نے اپنی طرف سے اپنے رسول پر اور ایمان والوں پر تسکین نازل فرمائی اور وہ فوجیں اتاریں کہ جنہیں تم نے نہیں دیکھا اور کافروں کو عذاب دیا اور کافروں کو یہی سزا ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mcclxii{پھر اس کے بعد جسے الله چاہے تو بہ نصیب کرے گا اور الله بخشنے والا مہربان ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mcclxiii{اے ایمان والو! مشرک تو پلید ہیں سو اس برس کے بعد مسجد حرام کے نزدیک نہ آنے پائیں اور اگر تم تنگدستی سے ڈرتے ہو تو آئندہ اگر الله چاہے تمہیں اپنے فضل سے غنسی کر دے گا بے شک الله جاننے والا حکمت والا ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mcclxiv{ان لوگوں سے لڑو جو الله پر اور آخرت کے دن پر ایمان نہیں لاتے اور نہ اسے حرام جانتے ہیں جسے الله اور اس کے رسول نے حرام کیا ہے اور سچا دین قبول نہیں کرتے ان لوگوں میں سے جو اہلِ کتاب ہیں یہاں تک کہ ذلیل ہو کر اپنے ہاتھ سے جزیہ دیں\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mcclxv{اور یہود کہتے ہیں کہ عزیر الله کا بیٹا ہے اور عیسائی کہتے ہیں مسیح الله کا بیٹا ہے یہ ان کی منہ کی باتیں ہیں وہ کافروں کی سی باتیں بنانے لگے ہیں جو ان سے پہلے گزرے ہیں الله انہیں ہلاک کرے یہ کدھر الٹے جا رہے ہیں\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mcclxvi{انہوں نے اپنے عالموں اور درویشوں کو الله کے سوا خدا بنا لیا ہے اور مسیح مریم کے بیٹےکو بھی حالانکہ انہیں حکم یہی ہوا تھا کہ ایک الله کے سوا کسی کی عبادت نہ کریں اس کے سوا کوئی معبود نہیں وہ ان لوگوں کے شریک مقرر کرنے سے پاک ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mcclxvii{چاہتے ہیں کہ الله کی روشنی کو اپنے مونہوں سے بجھا دیں الله اپنی روشنی کو پورا کیے بغیر نہیں رہے گا اور اگرچہ کافر ناپسند ہی کریں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mcclxviii{اس نے اپنے رسول کو ہدایت اور سچا دین دے کر بھیجا ہے تاکہ اسے سب دینوں پر غالب کرے اور اگرچہ مشرک نا پسندکریں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mcclxix{اے ایمان والو! بہت سے عالم اور فقیر لوگوں کا مال ناحق کھاتے ہیں اور الله کی راہ سے روکتے ہیں اور جو لوگ سونا اورچاندی جمع کرتے ہیں اور اسے الله کی راہ میں خرچ نہیں کرتے انہیں دردناک عذاب کی خوشخبری سنا دیجیئے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mcclxx{جس دن وہ دوزخ کی آگ میں گرم کیا جائے گا پھر اس سے ان کی پیشانیاں اور پہلو اور پیٹھیں داغی جائیں گی یہ وہی ہے جو تم نے اپنے لیے جمع کیا تھا سو اس کا مزہ چکھو جوتم جمع کرتے تھے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mcclxxi{بے شک الله کے ہاں مہینوں کی گنتی بارہ مہینے ہیں الله کی کتاب میں جس دن سے الله نے زمین اور آسمان پیدا کیے ان میں سے چار عزت والے ہیں یہی سیدھا دین ہے سو ان میں اپنے اوپر ظلم نہ کرو اور تم سب مشرکوں سے لڑو جیسے وہ سب تم سے لڑتے ہیں اور جان لو کہ الله پرہیزگاروں کے ساتھ ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mcclxxii{یہ مہینوں کا ہٹا دینا کفر میں اور ترقی ہے اس سے کا فر گمراہی میں پڑتے ہیں اس مہینے کو ایک برس تو حلال کر لیتے ہیں اور دوسرے برس اسے حرام رکھتے ہیں تاکہ ان بارہ مہینوں کی گنتی پوری کر لیں جنہیں الله نے عزت دی ہے پھر حلا ل کر لیتے ہیں جو الله نے حرام کیا ہے ان کے برے اعمال انھیں بھلے دکھائی دیتے ہیں اور الله کافروں کو ہدایت نہیں کرتا\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mcclxxiii{اے ایمان والو تمہیں کیا ہوا جب تمہیں کہا جاتا ہے کہ الله کی راہ میں کوچ کرو تو زمین پر گرے جاتے ہو کیا تم آخرت کو چھوڑ کر دنیا کی زندگی پر خوش ہو گئے ہو دنیا کی زندگی کا فائدہ تو آخرت کے مقابلہ میں بہت ہی کم ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mcclxxiv{اگر تم نہ نکلو گے تو الله تمہیں دردناک عذاب میں مبتلا کر ے گا اور تمہاری جگہ اور لوگ پیدا کر ے گا اور تم اسے کوئی نقصان نہیں پہنچا سکو گے اور الله ہر چیز پر قادر ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mcclxxv{اگرتم رسول کی مدد نہ کرو گے تو اس کی الله نے مدد کی ہے جس وقت اسے کافروں نے نکالا تھا کہ وہ دو میں سے دوسرا تھاجب وہ دونوں غار میں تھے جب وہ اپنے ساتھی سے کہہ رہا تھا تو غم نہ کھا بے شک الله ہمارے ساتھ ہے پھر الله نے اپنی طرف سے اس پر تسکین اتاری اور اس کی مدد کو وہ فوجیں بھیجیں جنہیں تم نے نہیں دیکھا اورکافروں کی بات کو پست کر دیا اور بات تو الله ہی کی بلند ہے اور الله زبردست (اور) حکمت والا ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mcclxxvi{تم ہلکے ہو یا بوجھل نکلو اور اپنے مالوں اور جانوں سے الله کی راہ میں لڑو یہ تمہارے حق میں بہتر ہے اگر تم سمجھتے ہو\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mcclxxvii{اگر مال نزدیک ہوتا اور سفر ہلکا ہوتا تو وہ ضرور تیرے ساتھ ہوتے لیکن انہیں مسافت لمبی نظر آئی اور اب الله کی قسمیں کھائیں گے کہ اگر ہم سے ہو سکتا تو ہم تمہارے ساتھ ضرور چلتے اپنی جانوں کو ہلاک کرتے ہیں اور الله جانتا ہے کہ وہ جھوٹے ہیں\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mcclxxviii{الله نے تمہیں معاف کر دیا تم نےانہیں کیوں رخصت دی یہاں تک کہ تیرے لیے سچے ظاہر ہو جاتے اور تو جھوٹوں کو جان لیتا\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mcclxxix{جو لوگ الله پر اور آخرت کے دن پر ایمان لاتے ہیں وہ تم سے رخصت نہیں مانگتے اس سے کہ اپنے مالوں اورجانوں سے جہاد کریں اور الله پرہیزگاروں کو خوب جانتا ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mcclxxx{تم سے رخصت وہی مانگتے ہیں جو الله پر اور آخرت کے دن پر ایمان نہیں رکھتے اور ان کے دل شک میں پڑے ہوئے ہیں سو وہ اپنے شک میں بھٹک رہے ہیں\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mcclxxxi{اور اگر وہ نکلنا چاہتے تو اس کے لیے کوئی سامان ضرور تیار کرتے لیکن الله نے ان کا اٹھنا پسند نہ کیا سو انہیں روک دیا اور حکم ہوا کہ بیٹھنے والوں کے ساتھ بیٹھے رہو\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mcclxxxii{اگر وہ تم میں نکلتے تو سوائے فساد کے اور کچھ نہ بڑھاتے اور تم میں فساد ڈلوانے کی غرض سے دوڑے دوڑے پھرتے اورتم میں ان کے جاسوس بھی ہیں اور الله ظالموں کو خوب جانتا ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mcclxxxiii{یہ پہلے بھی فساد کے طالب رہے ہیں اور بہت سی باتوں میں تمہارے لئےالٹ پھیر کرتے رہے ہیں یہاں تک کہ حق آ پہنچا اور الله کا حکم غالب ہوا اور وہ ناخوش ہی رہے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mcclxxxiv{اور ان میں سے بعض کہتے ہیں کہ مجھے تو اجازت ہی دیجیئے اور فتنہ میں نہ ڈالیے خبردار! وہ فتنہ میں پڑ چکے ہیں اوربے شک دوزخ کافروں پر احاطہ کرنے والی ہے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mcclxxxv{اگر تمہیں آسائش حاصل ہوتی ہے تو انہیں بری لگتی ہے اور اگر کوئی مشکل پڑتی ہے تو کہتے ہیں کہ ہم نے تو اپنا کام پہلے ہی سنبھال لیا تھا اور خوشیاں مناتے لوٹ جاتے ہیں\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mcclxxxvi{کہہ دو ہمیں ہر گز نہ پہنچے گا مگر وہی جو الله نے ہمارے لیے لکھ دیا وہی ہمارا کارساز ہے اور الله ہی پر چاہیئے کہ مومن بھروسہ کریں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mcclxxxvii{کہہ دو تم ہمارے حق میں دو بھلائیوں میں سے ایک کے منتظر ہو اور ہم تمہارے حق میں اس بات کے منتظر ہیں کہ الله اپنے ہاں سے تم پرکوئی عذاب نازل کرے یا ہمارے ہاتھوں سے تم بھی انتظار کرو ہم بھی تمہارے ساتھ انتظار کرتے ہیں\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mcclxxxviii{کہہ دو تم خوشی سے خر چ کرو یا ناخوشی سے تم سے ہرگز قبول نہیں کیا جائے گا بے شک تم نافرمان لوگ ہو\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mcclxxxix{اور ان کے خر چ کے قبول ہونے سے کوئی چیز مانع نہیں ہوئی سوائے اس کے کہ انہوں نے الله اور اس کے رسول سے کفرکیا اورنماز میں سست ہو کر آتے ہیں اور ناخوش ہو کر خرچ کرتے ہیں\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mccxc{سو تو ان کے مال اور اولاد سے تعجب نہ کر الله یہی چاہتا ہے کہ ان چیزوں کی وجہ سے دنیا کی زندگی میں انہیں عذاب دے اور کفر کی حالت میں ان کی جانیں نکلیں\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mccxci{اور الله کی قسمیں کھاتے ہیں کہ وہ بے شک تم میں سے ہیں حالانکہ وہ تم میں سے نہیں لیکن وہ ڈرتے ہیں\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mccxcii{اگر وہ کوئی پناہ کی جگہ یا غاریا گھسنے کی جگہ پائیں تو دوڑتے ہوئے ادھر جائیں\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mccxciii{اور بعضے ان میں سے وہ ہیں جو خیرات مانگتے ہیں تجھے طعن دیتے ہیں سو اگر انہیں اس میں سے مل جائے تو راضی ہوتے ہیں اور اگر نہ ملے تو فوراً ناراض ہو جاتے ہیں\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mccxciv{اور کیا اچھا ہوتا اگر وہ اس پر راضی ہو جاتے جو انہیں الله اور اس کے رسول نے دیا ہے اور کہتے ہیں ہمیں الله کافی ہے وہ ہمیں اپنے فضل سے دے گا اور اس کا رسول ہم الله ہی کی طرف رغبت کرنے والے ہیں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mccxcv{زکوة مفلسوں اور محتاجوں اوراس کا کام کرنے والوں کا حق ہے اورجن کی دلجوئی کرنی ہے اور غلاموں کی گردن چھوڑانے میں اور قرض داروں کے قرض میں اور الله کی راہ میں اورمسافر کو یہ الله کی طرف سے مقرر کیاہوا ہے اور الله جاننے والا حکمت والا ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mccxcvi{اور بعضے ان میں سے پیغمبر کو ایذا دیتے ہیں اور کہتے ہیں کہ یہ شخص نِرا کان ہے کہہ دے وہ کان تمہاری بھلائی کے لیے ہے الله پر یقین رکھتا ہے اور مسلمانوں کی بات کا یقین کرتا ہے اور تم میں سے ایمان والوں کے حق میں رحمت ہے اور جو لوگ رسول الله کو ایذا دیتے ہیں ان کے لیے دردناک عذاب ہے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mccxcvii{تمہارے سامنے الله کی قسمیں کھاتے ہیں تاکہ تمہیں راضی کریں اور الله اور اس کے رسول کو راضی کرنا بہت ضروری ہے اگر وہ ایمان رکھتے ہیں\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mccxcviii{کیا وہ نہیں جانتے کہ جو شخص الله اور اس کے رسول کا مقابلہ کرتا ہے تو اس کے واسطے دوزخ کی آگ ہے اس میں ہمیشہ رہے گا یہ بڑی ذلت ہے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mccxcix{منافق اس بات سے ڈرتے ہیں کہ مسلمانوں پر کوئی ایسی سورة نازل ہو کہ انہیں بتا دے جو منافقوں کے دل میں ہے کہہ دو ہنسی کیے جاؤ جس بات سے تم ڈرتے ہو الله اسے ضرور ظاہر کر دے گا\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mccc{اور اگر تم ان سے دریافت کرو تو کہیں گے کہ ہم یونہی بات چیت اور دل لگی کر رہے تھےکہہ دو کیا الله سے اور اس کی آیتوں سے اور اس کے رسول سے تم ہنسی کرتے تھے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mccci{بہانے مت بناؤ ایمان لانے کے بعد تم کافر ہو گئے اگر ہم تم میں سے بعض کو معاف کر دیں گے تو بعض کو عذاب بھی دیں گے کیوں کہ وہ گناہ کرتے رہے ہیں\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mcccii{منافق مر د اور منافق عورتیں ایک دوسرے کے ہم جنس ہیں برے کامو ں کا حکم کرتے ہیں اور نیک کاموں سے منع کرتے ہیں او رہاتھ بند کیے رہتے ہیں وہ الله کو بھول گئے سوالله نے انہیں بھلا دیا بے شک منافق وہی نافرمان ہیں\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mccciii{الله نے منافق مردوں اورمنافق عورتوں اور کافروں کو دوزخ کی آگ کا وعدہ دیا ہے پڑے رہیں گے اس میں وہی انہیں کافی ہے اور الله نے ان پر لعنت کی ہے اوران کے لیے دائمی عذاب ہے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mccciv{جس طرح تم سے پہلے لوگ تم سے طاقت میں زيادہ تھے اور مال اور اولاد میں بھی زيادہ تھے پھر وہ اپنے حصہ سے فائدہ اٹھا گئے اور تم نے اپنے حصہ سے فائدہ اٹھایا جیسے تم سے پہلہے لوگ اپنے حصہ سے فائدہ اٹھا گئے اور تم بھی انہیں کی سی چال چلتے ہو یہ وہ لوگ ہیں جن کے اعمال دنیا اور آخرت میں ضائع ہو گئے اور وہی نقصان اٹھانے والے ہیں\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mcccv{کیا انہیں ان لوگو ں کی خبر نہیں پہنچی جو ان سے پہلے تھے نوح کی قوم اور عاد اور ثمود اورابراھیم کی قوم اورمدین والوں کی اوران بستیوں کی خبر جو الٹ دی گئی تھیں ان کے پاس ان کے رسول صاف احکام لے کر پہنچے سو الله ایسا نہ تھا کہ ان پر ظلم کرتا لیکن وہی اپنے آپ پر ظلم کرتے تھے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mcccvi{اور ایمان والے مرد اور ایمان والی عورتیں ایک دوسرے کےمددگار ہیں نیکی کا حکم کرتے ہیں اوربرائی سے روکتے ہیں اورنماز قائم کرتے ہیں اور زکواة دیتے ہیں اور الله اور اس کے رسول کی فرمانبرداری کرتے ہیں یہی لوگ ہیں جن پر الله رحم کرے گا بے شک الله زبردست حکمت والا ہے\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mcccvii{الله نے ایمان دار مردوں اورایمان والی عورتوں کو باغوں کا وعدہ دیا ہے جن کے نیچے نہریں بہتی ہوں گیان میں ہمیشہ رہنے والے ہوں گے اورعمدہ مکانوں اور ہمیشگی کے باغوں میں اور الله کی رضا ان سب سے بڑی ہے یہی وہ بڑی کامیابی ہے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mcccviii{اے نبی! کافروں اور منافقوں سے لڑائی کر اوران پر سختی کر اور ان کا ٹھکانا دوزخ ہے اور وہ بری جگہ ہے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mcccix{الله کی قسمیں کھاتے ہیں کہ ہم نے نہیں کہا اوربے شک انہوں نے کفر کا کلمہ کہا ہے اورمسلمان ہونے کے بعد کافر ہوگئے اورانہوں نے قصد کیا تھا ایسی چیز کا جونہیں پا سکے اور یہ سب کچھ اسی کا بدلہ تھا کہ انہیں الله اور اس کے رسول نے اپنے فضل سے دولتمند کر دیا ہے سو اگر وہ توبہ کریں تو ان کے لیے بہتر ہے اور اگر وہ منہ پھیر لیں تو الله انہیں دنیا اور آخرت میں دردناک عذاب دے گا اور انہیں روئے زمین پر کوئی دوست اور کوئی مددگار نہیں ملے گا\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mcccx{اور بعضے ان میں سے وہ ہیں جنہوں نے الله سے عہد کیا تھا کہ اگر وہ ہمیں اپنے فضل سے دے تو ہم ضرور خیرات کیا کریں گے اور نیکو ں میں سےہو جائیں\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mcccxi{پھر جب الله نے اپنے فضل سے دیا تو اس میں بخل کرنے لگے اورمنہ موڑ کر پھر بیٹھے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mcccxii{تو نتیجہ یہ ہوا کہ اس دن تک الله سے ملیں گے الله نے ان کے دلوں میں نفاق پیدا کر دیا اس لیے کہ انہوں نے جو الله سے وعدہ کیا تھا اسے پورا نہ کیا اوروہ اس لیے جھوٹ بولا کرتے تھے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mcccxiii{کیا وہ نہیں جانتے کہ الله ان کا بھید اور ان کا مشورہ جانتا ہے اوریہ کہ الله غیب کی باتیں جاننے والا ہے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mcccxiv{وہ لوگ جو ان مسلمانوں پر طعن کرتے ہیں جودل کھول کر خیرات کرتے ہیں اور جو لوگ اپنی محنت کے سوا طاقت نہیں رکھتے پھر ان پر ٹھٹھا کرتے ہیں الله ان سے ٹھٹھا کرتا ہے اوران کے لیے دردناک عذاب ہے\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mcccxv{تو ان کے لیے بخشش مانگ یا نہ مانگ اگر تو ان کے لیے ستر دفعہ بھی بخشش مانگے گا تو بھی الله انہیں ہر گز نہیں بخشے گا یہ اس لیے کہ انہوں نے الله اور اس کے رسول سےکفر کیا اور الله نافرمانوں کو راستہ نہیں دکھاتا\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mcccxvi{جو لوگ پیچھے رہ گئے وہ رسول الله کی مرضی کے خلاف بیٹھ رہنے سے خوش ہوتے ہیں اوراس بات کو ناپسند کیا کہ اپنے مالوں اور جانوں سے الله کی راہ میں جہاد کریں اور کہا گرمی میں مت نکلو کہہ دو کہ دوزخ کی آگ کہیں زیادہ گرم ہے کاش یہ سمجھ سکتے\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mcccxvii{سووہ تھوڑا سا ہنسیں اور زیادہ روئیں ان کے اعمال کے بدلے جو کرتے رہے ہیں\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mcccxviii{سواگر تجھے الله ان میں سے کسی فرقہ کی طرف پھر لے جائے پھر تجھ سے نکلنے کی اجازت چاہیں تو کہہ دو کہ تم میرے ساتھ کبھی بھی ہرگز نہ نکلو گے اور میرے ساتھ ہو کر کسی دشمن سے نہ لڑو گے تمہیں پہلی مرتبہ بیٹھنا پسند آیا سو پیچھے رہنے والوں کے ساتھ بیٹھے رہو\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mcccxix{اوران میں سے جو مرجائے کسی پر کبھی نماز نہ پڑھ اور نہ اس کی قبر پر کھڑا ہو بے شک انہوں نے الله اور اس کے رسول سے کفر کیا اور نافرمانی کی حالت میں مر گئے\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mcccxx{اور ان کے مالوں اوراولاد سے تعجب نہ کر الله یہی چاہتا ہے کہ انہیں ان چیزوں کے باعث دنیا میں عذاب دے اور ان کی جانیں نکلیں ایسے حال میں کہ وہ کافر ہی ہوں\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mcccxxi{اور جب کوئی سورة نازل ہوتی ہے کہ الله پر ایمان لاؤ اور اس کے رسول کےساتھ ہو کر جہاد کرو تو ان میں سے دولت مند بھی تجھ سے رخصت مانگتے ہیں اورکہتے ہیں کہ ہمیں چھوڑ دے کہ بیٹھنے والوں کے ساتھ ہو جائیں\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mcccxxii{وہ خوش ہیں کہ پیچھے رہ جانے والی عورتوں کے ساتھ رہ جائیں اور ان کے دلوں پر مہر کر دی گئی ہے سووہ نہیں سمجھتے\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mcccxxiii{لیکن رسول اور جو لوگ ان کے ساتھ ایمان والے ہیں وہ اپنے مالوں اور جانوں سے جہاد کرتے ہیں اور انہیں لوگو ں کے لیے بھلائیاں ہیں اور وہی نجات پانے والے ہیں\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mcccxxiv{الله نے ان کے لیے باغ تیار کیے ہیں جن کے نیچے نہریں بہتی ہیں ان میں ہمیشہ رہیں گےیہی بڑی کامیابی ہے\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mcccxxv{اور بہانے کرنے والے گنوار آئے تاکہ انہیں رخصت مل جائے اوربیٹھ رہے وہ جنہوں نے الله اوراس کے رسول سے جھوٹ بولا تھا جو ان میں سے کافر ہیں عنقریب انہیں دردناک عذاب پہنچے گا\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mcccxxvi{ضعیفوں اور مریضوں پر اور ان لوگوں پر جو نہیں پاتے جو خر چ کریں کوئی گناہ نہیں ہے جب الله اور اس کے رسول کے ساتھ خیر خواہی کریں نیکو کاروں پر کوئی الزام نہیں ہے اور الله بخشنے والا مہربان ہے\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mcccxxvii{اور ان لوگو ں پر بھی کوئی گناہ نہیں کہ جب وہ تیرے پاس آئیں کہ انہیں سواری دے تو نے کہا میرے پاس کوئی چیز نہیں کہ تمہیں اس پر سوار کر دوں تو وہ لوٹ گئے اوراس غم سے کہ ان کے پاس خرچ موجود نہیں تھا ان کی آنکھوں سے آنسو بہہ رہے تھے\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mcccxxviii{الزام ان لوگوں پر ہے جو دولتمند ہیں اورتم سے اجازت طلب کرتے ہیں اس بات سے وہ خوش ہیں کہ پیچھے رہنے والیوں کے ساتھ رہ جائیں اور الله نے ان کے دلوں پر مہر کر دی ہے پس وہ نہیں سمجھتے\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mcccxxix{جب تم ان کی طرف واپس جاؤ گے تو تم سے عذر کریں گے کہہ دو عذر مت کرو ہم تمہاری بات ہرگز نہیں مانیں گے تمہارے سب حالات اللہ ہمیں بتاچکا ہے اور ابھی الله اور اس کا رسول تمہارے کام کو دیکھے گا پھر تم غائب اور حاضر کے جاننے والےکی طرف لوٹائے جاؤ گے سو وہ تمہیں بتا دے گا جو تم کر رہے تھے\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mcccxxx{جب تم ان کی طرف پھر جاؤ گے تو تمہارے سامنے الله کی قسمیں کھائیں گےتاکہ تم ان سے در گزر کرو بے شک وہ پلید ہیں اور جو کام کرتے رہے ہیں ان کے بدلے ان کا ٹھکانا دوزخ ہے\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mcccxxxi{وہ لوگ تمہارے سامنے قسمیں کھائیں گے تاکہ تم ان سے خوش ہو جاؤ اگر تم ان سے خوش بھی ہو جاؤ تو بھی الله نافرمانوں سے خوش نہیں ہوتا\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mcccxxxii{گنوار کفر اور نفاق میں بہت سخت ہیں اور اس قابل ہیں کہ جو احکام الله نے اپنے رسول پر نازل فرمائے ہیں ان سے واقف نہ ہوں اور الله جاننے والا حکمت والا ہے\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mcccxxxiii{اور بعض گنوار ایسے ہیں کہ جو کچھ خرچ کرتے ہیں اسے تاوان سمجھتے ہیں اور تم پر زمانہ کی گردشوں کا انتظار کرتے ہیں انہیں پر بری گردش آئے اور الله سننے والا جاننے والا ہے\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mcccxxxiv{اور بعضے گنوار ایسے ہیں کہ الله پر اور قیامت کے دن پر ایمان لاتے ہیں اور جو کچھ خرچ کرتے ہیں اسے الله کے نزدیک ہونے اور پیغمبر کی دعاؤں کا ذریعہ سمجھتے ہیں خبردار بے شک وہ ان کے لیے نزدیکی کا سبب ہے عنقریب انہیں اللہ اپنی رحمت میں داخل کرے گا بے شک الله بخشنے والا مہربان ہے\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mcccxxxv{اور جو لوگ قدیم میں پہلے ہجرت کرنے والوں اور مدد دینے والو ں میں سے اور وہ لوگ جو نیکی میں ان کی پیروی کرنے والے ہیں الله ان سے راضی ہوئےاوروہ اس سے راضی ہوئےان کے لیے ایسے باغ تیار کیے ہیں جن کے نیچے نہریں بہتی ہیں ان میں ہمیشہ رہیں گے یہ بڑی کامیابی ہے\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mcccxxxvi{اور تمہارے گرد و نواح کے بعضے گنوار منافق ہیں اور بعض مدینہ والے بھی نفاق پر اڑے ہوئے ہیں تم انہیں نہیں جانتے ہم انہیں جانتے ہیں ہم انہیں دوہری سزا دیں گے پھر وہ بڑے عذاب کی طرف لوٹائے جائیں گے\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mcccxxxvii{اور کچھ اور بھی ہیں کہ انھوں نے اپنے گناہوں کا اقرار کیا ہے انہوں نے اپنے نیک اور بد کاموں کو ملا دیاہے قریب ہے کہ الله انہیں معاف کر دے بے شک الله بخشنے والا مہربان ہے\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mcccxxxviii{ان کے مالوں میں سے زکواة لے کہ اس سے ان کے ظاہر کو پاک اور ان کے باطن کو صاف کر دے اورانہیں دعا دے بے شک تیری دعا ان کے لیے تسکین ہے اوراللہ سننے والا جاننے والا ہے\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mcccxxxix{کیا یہ لوگ نہیں جانتے الله ہی اپنے بندوں کی توبہ قبول فرماتا ہے اور صدقات لیتا ہے اور بے شک الله ہی توبہ قبول کرنے والا مہربان ہے\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mcccxl{اور کہہ دےکہ کام کیے جاؤ پھر عنقریب الله اور اس کا رسول اور مسلمان تمہارے کام کو دیکھ لیں گے اور عنقریب تم غائب اور حاضر کے جاننے والے کی طرف لوٹائے جاؤ گےپھر وہ تمہیں بتا دے گا جو کچھ تم کرتے تھے\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mcccxli{اور کچھ اور لوگ ہیں جن کا کام الله کے حکم پر موقوف ہے خواہ انہیں عذاب دے یا انہیں معاف کر دے اور الله جاننے والا حکمت والا ہے\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mcccxlii{اور جنہوں نے نقصان پہنچانے اور کفر کرنے اورمسلمانوں میں تفریق ڈالنے کے لیے مسجد بنائی ہے اورواسطے گھات لگانے ان لوگوں کے جو الله اور اس کے رسول سے پہلے لڑ چکے ہیں اور البتہ قسمیں کھائیں گہ ہمارا مقصد تو صرف بھلائی تھی اور اللهگواہی دیتا ہے کہ بے شک وہ جھوٹے ہیں\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mcccxliii{تو اس میں کبھی کھڑانہ ہو البتہ وہ مسجد جس کی بنیاد پہلے دن سے پرہیزگاری پر رکھی گئی ہے وہ اس کے قابل ہے تو اس میں کھڑا ہو اس میں ایسے لوگ ہیں جو پاک رہنے کو پسند کرتے ہیں اور الله پاک رہنے والوں کو پسند کرتا ہے\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mcccxliv{بھلا جس نے اپنی عمارت کی بنیاد الله سے ڈرنے اوراس کی رضا مندی پر رکھی ہو وہ بہتر ہے یا جس نے اپنی عمارت کی بنیاد ایک کھائی کے کنارے پررکھی جو گرنے والی ہے پھر وہ اسے دوزخ کی آگ میں لے گری اور الله ظالموں کو راہ نہیں دکھاتا\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mcccxlv{جوعمارت انہوں نے بنائی ہے ہمیشہ ان کے دلو ں میں کھٹکتی رہے گی مگر جب ان کے دل ٹکڑے ہوجائیں اور الله جاننے والا حکمت والا ہے\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mcccxlvi{بے شک الله مسلمانوں سے ان کی جان اوران کا مال اس قیمت پر خرید لیے ہیں کہ ان کی جنت ہے الله کی راہ میں لڑتے ہیں پھر قتل کرتے ہیں اور قتل بھی کیے جاتے ہیں یہ توریت اور انجیل اور قرآن میں سچا وعدہ ہے جس کا پورا کرنااسے ضروری ہے اور الله سے زیادہ وعدہ پورا کرنے والا کون ہے جو سودا تم نے اس سے کیا ہے اس سے خوش رہو اور یہ بڑی کامیابی ہے\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mcccxlvii{توبہ کرنے والے عبادت کرنے والے شکر کرنے والے روزہ رکھنے والے رکوع کرنے والے سجدہ کرنے والے اچھے کاموں کا حکم کرنے والے بری باتوں سے روکنے والے الله کی حدوں کی حفاظت کرنے والے اور ایسے مومنو ں کو خوشخبری سنا دے\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@mcccxlviii{پیغمبراور مسلمانوں کو یہ بات مناسب نہیں کہ مشرکوں کے لیے بخشش کی دعا کریں اگرچہ وہ رشتہ دار ہی ہوں جب کہ ان پر ظاہر ہو گیا ہے کہ وہ دوزخی ہیں\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@mcccxlix{اور ابراھیم کا اپنے باپ کے لیے بخشش کی دعا کرنا اور ایک وعدہ کے سبب سے تھا جو وہ اس سے کر چکے تھے پھر جب انہیں معلوم ہوا کہ وہ الله کا دشمن ہے تو اس سے بیزار ہو گئے بے شک ابراھیم بڑے نرم دل تحمل والے تھے\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@mcccl{اورالله ایسا نہیں ہے کہ کسی قوم کو صحیح راستہ بتلانے کے بعد گمراہ کر دے جب تک ان پر واضح نہ کر دے وہ چیز جس سے انہیں بچنا چاہیے بے شک الله ہر چیز کو جاننے والا ہے\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@mcccli{آسمانوں اور زمین میں الله ہی کی سلطنت ہے وہی جلاتا ہے اور مارتا ہے اور الله کے سوا تمہارا کوئی دوست اور مددگار نہیں\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@mccclii{الله نے نبی کے حال پر رحمت سے توجہ فرمائی اور مہاجرین اور انصار کے حال پر بھی جنہوں نے ایسی تنگی کے وقت میں نبی کا ساتھ دیا بعد اس کے کہ ان میں سے بعض کے دل پھر جانے کے قریب تھے اپنی رحمت سے ان پر توجہ فرمائی بے شک وہ ان پر شفقت کرنے والا مہربان ہے\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@mcccliii{اور ان تینوں پر بھی جن کا معاملہ ملتوی کیا گیا یہاں تک کہ جب ان پر زمین باوجود کشادہ ہونے کے تنگ ہوگئی اور ان کی جانیں بھی ان پر تنگ ہوگئیں اور انہوں نے سمجھ لیا کہ الله سے کوئی پناہ نہیں سو اسی کی طرف آنے کے پھر بھی اپنی رحمت سے ان پر متوجہ ہوا تاکہ وہ توبہ کریں بے شک الله توبہ قبول کرنے والا مہربان ہے\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@mcccliv{اے ایمان والو! الله سے ڈرتے رہو اور سچوں کے ساتھ رہو\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@mccclv{مدینہ والوں اور ان کے آس پاس دیہات کے رہنے والوں کو یہ مناسب نہیں تھا کہ الله کے رسول سے پیچھے رہ جائیں اور نہ یہ کہ اپنی جانوں کو اس کی جان سے زیادہ عزیز سمجھیں یہ اس لیے ہے کہ انہیں الله کی راہ میں جو تکلیف پہنچتی ہے پیاس کی یا ماندگی کی یا بھوک کی یاہ وہ ایسی جگہ چلتے ہیں جو کافروں کے غصہ کو بھڑکائے اور یا کافروں سے کوئی چیز چھین لیتے ہیں ہر بات پر ان کے لیے عمل صالح لکھا جاتا ہے بے شک الله نیکی کرنے والوں کا اجر ضائع نہیں کرتا\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@mccclvi{اور جو وہ تھوڑا یا بہت خرچ کرتے ہیں یا کوئی میدان طے کرتے ہیں تو یہ سب کچھ ان کے لیے لکھ لیا جاتا ہے تاکہ الله انہیں ان کے اعمال کا اچھا بدلہ دے\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@mccclvii{اورایسا تو نہیں ہوسکتا کہ مسلمان سب کے سب کوچ کریں سو کیوں نہ نکلا ہر فرقے میں سے ایک حصہ تاکہ دین میں سمجھ پیدا کریں اور جب اپنی قوم کی طرف واپس آئیں تو ان کو ڈرائیں تاکہ وہ بچتے رہیں\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@mccclviii{اے ایمان والو اپنے نزدیک کے کافروں سے لڑو اور چاہئے کہ وہ تم میں سختی پائیں اور جان لو کہ اللہ پر ہیزگاروں کے ساتھ ہے\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@mccclix{اور جب کوئی سورت نازل ہوتی ہے تو ان میں سے بعض کہتے ہیں کہ اس سورت نےتم میں سے کس کے ایمان کو بڑھایا ہے سو جو لوگ ایمان والے ہیں اس سورت نے ان کے ایمان کو بڑھایا ہے اور وہ خوش ہوتے ہیں\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@mccclx{اور جن کے دلوں میں مرض ہے سوان کے حق میں نجاست پر نجاست بڑھا دی اور وہ مرتے دم تک کافر ہی رہے\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@mccclxi{کیا وہ نہیں دیکھتے کہ وہ ہر سال میں ایک دفعہ یا دو دفعہ آزمائے جاتے ہیں پھر بھی توبہ نہیں کرتے اور نہ نصیحت حاصل کرتے ہیں\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@mccclxii{اورجب کوئی سورت نازل ہوتی ہے تو ان میں ایک دوسرے کی طرف دیکھنے لگتا ہے کہ کیا تمہیں کوئی مسلمان دیکھتا ہے پھر چل نکلتے ہیں الله نے ان کے دل پھیر دئے ہیں اور لیے کہ وہ لوگ سمجھ نہیں رکھتے\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@mccclxiii{البتہ تحقیق تمہارے پاس تم ہی میں سے رسول آیا ہے اسے تمہاری تکلیف گراں معلوم ہوتی ہے تمہاری بھلائی پر وہ حریص ہے مومنوں پر نہایت شفقت کرنے والا مہربان ہے\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@mccclxiv{پھر اگر یہ لوگ پھر جائیں تو کہہ دو مجھے الله ہی کافی ہے اس کے سوا اور کوئی معبود نہیں اسی پر میں بھروسہ کرتا ہوں اور وہی عرش عظیم کا مالک ہے\qt@no{(129)}}%
\qt@newcmd\qurantrans@ur@mccclxv{\basmalahur یہ حکمت والی کتا ب کی آیتیں ہیں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mccclxvi{کیا اس بات سے لوگوں کو تعجب ہوا کہ ہم نے ان میں سے ایک شخص کے پاس وحی بھیج دی کہ سب آدمیوں کو ڈرائے اور جو ایمان لائیں انہیں یہ خوشخبری سنائے کہ انہیں اپنے رب کے ہاں پہنچ کر پورا مرتبہ ملے گا کافر کہتے ہیں کہ یہ شخص صریح جادوگر ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mccclxvii{بے شک تمہارا رب الله ہی ہے جس نے آسمان اور زمین چھ دن میں بنائے پھر عرش پر قائم ہوا وہی ہر کام کا انتظام کرتا ہے اس کی اجازت کے سوا کوئی سفارش کرنے والا نہیں ہے یہی الله تمہارا پروردگار ہے سو اسی کی عبادت کرو کیا تم پھر بھی نہیں سمجھتے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mccclxviii{تم سب کو اسی کی طرف لوٹ کر جانا ہے الله کا وعدہ سچا ہے وہی پہلی مرتبہ پیدا کرتا ہے پھر وہی دوبارہ پیدا کرے گا تاکہ جو لوگ ایمان لائے اورنیک کام کیے انہیں انصاف کے ساتھ بدلہ دے اور جن لوگو ں نے کفر کیا ان کے واسطے کھولتا ہوا پانی پینے کو ہوگا اوران کے کفر کے سبب سے دردناک عذاب ہوگا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mccclxix{وہی ہے جس نے سورج کو روشن بنایا اور چاند کو منور فرمایا اور چاند کی منزلیں مقرر کیں تاکہ تم برسوں کا شمار اور حساب معلوم کر سکو یہ سب کچھ الله نے تدبیر سے پیدا کیا ہے وہ اپنی آیتیں سمجھداروں کے لیے کھول کھول کر بیان فرماتا ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mccclxx{رات اور دن کے آنے جانے میں اور جو چیزیں الله نے آسمانوں اور زمین میں پیدا کی ہیں ان میں ان لوگو ں کے لیے نشانیاں ہیں جو ڈرتے ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mccclxxi{البتہ جو لوگ ہم سے ملنے کی امید نہیں رکھتے اور دنیاکی زندگی پر خوش ہوئے اور اسی پر مطمئن ہو گئے اور جو لوگ ہماری نشانیوں سے غافل ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mccclxxii{ان کا ٹھکانا آگ ہے بسبب اس کے جو کرتے تھے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mccclxxiii{بے شک جو لوگ ایمان لائے اورانہوں نے نیک کام کیے انہیں ان کا رب ان کے ایمان کے سبب ہدایت کرے گا ان کے نیچے نعمت کے باغوں میں نہریں بہتی ہوں گی\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mccclxxiv{اس جگہ ان کی دعا یہ ہو گی کہ اے الله تیری ذات پاک ہے اوروہاں ان کا باہمی تحفہ سلام ہوگا اور ان کی دعا کا خاتمہ اس پر ہوگا سب تعریف الله کے لیے ہے جو سارے جہان کا پالنے والا ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mccclxxv{اور اگر الله لوگوں کو برائی جلد پہنچا دے جس طرح وہ بھلائی جلدی مانگتے ہیں تو ان کی عمر ختم کر دی جائے سو ہم چھوڑے رکھتے ہیں ان لوگوں کو جنہیں ہماری ملاقات کی امید نہیں کہ اپنی سرکشی میں بھٹکتے رہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mccclxxvi{اورجب انسان کو تکلیف پہنچتی ہے تو لیٹے اور بیٹھے اورکھڑے ہونے کی حالت میں ہمیں پکارتا ہے پھر جب ہم اس سے اس تکلیف کودور کر دیتے ہیں تو اس طرح گزر جاتا ہے گویا کہ ہمیں کسی تکلیف پہنچنے پر پکارا ہی نہ تھا اس طرح بیباکوں کو پسند آیا ہے جو کچھ وہ کر رہے ہیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mccclxxvii{اور البتہ ہم تم سے پہلے کئی امتوں کو ہلاک کر چکے ہیں جب انہوں نے ظلم اختیار کیا حالانکہ پیغمبر ان کے پاس کھلی نشانیاں لائے تھے اور وہ ہر گز ایمان لانے والے نہ تھے ہم گناہگارو ں کو ایسی ہی سزا دیا کرتے ہیں\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mccclxxviii{پھر ہم نے تمہیں ان کے بعد زمین میں نائب بنایا تاکہ دیکھیں تم کیا کرتے ہو\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mccclxxix{اور جب ان کے سامنے ہماری واضح آیتیں پڑھی جاتی ہیں وہ لوگ کہتے ہیں جنہیں ہم سے ملاقات کی امید نہیں کہ اس کے سوا کوئی قرآن لے آ یا اسے بدل دے تو کہہ دے میرا کام نہیں کہ اپنی طرف سے اسے بدل دوں میں اس کی تابعداری کرتا ہوں جو میری طرف وحی کی جائے اگر میں اپنے رب کی نافرمانی کروں توبڑے دن کے عذاب سے ڈرتا ہوں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mccclxxx{کہہ دو اگر الله چاہتا تو میں اسے تمہارےسامنے نہ پڑھتا اورنہ وہی تمہیں اس سے خبردار کرتا کیوں کہ اس سے پہلے تم میں ایک عمر گذار چکا ہوں کیا پھر تم نہیں سمجھتے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mccclxxxi{پھر اس سے بڑا ظالم کون ہو گا جو الله پر بہتان باندھے یا اس کی آیتوں کو جھٹلائے بے شک گناہگاروں کابھلا نہیں ہوتا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mccclxxxii{اور الله کے سوا اس چیز کی پرستش کرتے ہیں جونہ انہیں نقصان پہنچا سکے اورنہ انہیں نفع دے سکے اور کہتے ہیں الله کے ہاں یہ ہمارے سفارشی ہیں کہہ دو کیا تم الله کو بتلاتے ہو جو اسے آسمانوں اور زمین میں معلوم نہیں وہ پاک ہے اوران لوگو ں کے شرک سے بلند ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mccclxxxiii{اوروہ لوگ ایک ہی امت تھے پھر جدا جدا ہو گئے اور اگر ایک بات تمہارے پرودگار کی طرف سے پہلے نہ ہو چکی ہو تی تو جن باتوں میں وہ اختلاف کر تے ہیں ان میں فیصلہ کر دیا جاتا ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mccclxxxiv{اور کہتے ہیں اس پر اس کے رب سے کوئی نشانی کیوں نہ اتری سو تو کہہ دے کہ غیب کی بات الله ہی جانتا ہے سو تم انتظار کرو میں بھی تمہارے ساتھ انتظار کرتا ہوں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mccclxxxv{اورجب ہم لوگوں کو اپنی رحمت کا مزہ چکھاتے ہیں اس تکلیف کے بعد جو انہیں پہنچی تھی تو وہ ہماری آیتو ں کے متعلق حیلے کرنے لگتے ہیں کہہ دو کہ الله بہت جلد حیلہ کرنے والا ہے بے شک ہمارے فرشتے تمہارے سب حیلو ں کو لکھ رہے ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mccclxxxvi{وہ وہی ہے جو تمہیں جنگل اور دریا میں سیر کرنے کی توفیق دیتا ہے یہاں تک کہ جب تم کشتیوں میں بیٹھتے ہو اور وہ کشتیاں لوگو ں کو موافق ہوا کے ذریعہ سے لے کرچلتی ہیں اور وہ لوگ ان سے خوش ہوتے ہیں تو ناگہاں تیز ہوا چلتی ہے اور ہر طرف سے ان پر لہریں چھانے لگتی ہیں اور و ہ خیال کرتے ہیں کہ بےشک وہ لہروں میں گھر گئے ہیں تو سب خالص اعتقاد سے الله ہی کو پکارنے لگتے ہیں کہ اگر تو ہمیں اس مصیبت سے بچادے تو ہم ضرور شکر گزار رہیں گے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mccclxxxvii{پھر جب الله انہیں نجات دے دیتا ہے تو ملک میں ناحق شرارت کرنے لگتے ہیں اے لوگو تمہاری شرارت کا وبال تمہاری جانو ں پر ہی پڑے گا دنیا کی زندگی کا نفع اٹھا لو پھر ہمارے ہاں ہی تمہیں لوٹ کر آناہے پھر ہم تمہیں بتلادیں گے جو کچھ تم کیا کرتے تھے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mccclxxxviii{دنیا کی زندگی کی مثال مینہ کی سی ہے کہ اسے ہم نے آسمان سے اتارا پھراس کے ساتھ سبزہ مل کر نکلا جسے آدمی اور جانور کھاتے ہیں یہاں تک کہ جب زمین سبزے سے خوبصورت اور آراستہ ہو گئی اورزمین والوں نے خیال کیا کہ وہ اس پر بالکل قابض ہو چکے ہیں تو اس پر ہماری طرف سے دن یا رات میں کوئی حادثہ آ پڑا سو ہم نے اسے ایسا صاف کر دیا کہ گویا کل وہا ں کچھ بھی نہ تھا اس طرح ہم نشانیوں کو کھول کر بیان کرتے ہیں اور لوگو ں کے سامنے جو غور کرتے ہیں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mccclxxxix{اور الله سلامتی کے گھر کی طرف بلاتا ہے اور جسے چاہے سیدھا راستہ دکھاتا ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mcccxc{جنہوں نے بھلائی کی ان کے لئے بھلائی ہے اور زیادتی بھی اور ان کے منہ پر سیاہی اور رسوائی نہیں چڑھے گی وہ بہشتی ہیں وہ اسی میں ہمیشہ رہیں گے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mcccxci{اور جنہوں نے برے کام کئے تو برائی کا بدلہ ویسا ہی ہوگا کہ ان پر ذلت چھائے گی اور انہیں اللہ سے بچانے والا کوئی نہ ہوگا گویا کہ ان کے مونہوں پر اندھیری رات کے ٹکڑے اوڑدئے گئے ہیں یہی دوزخی ہیں وہ اس میں ہمیشہ رہیں گے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mcccxcii{اور جس دن ہم ان سب کو جمع کرینگے پھر مشرکوں سے کہیں گے تم اور تمہارے شریک اپنی جگہ کھڑے رہو تو ہم ان میں پھوٹ ڈال دینگے اور ان کے شریک کہیں گے کہ تم ہماری عبادت نہیں کرتے تھے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mcccxciii{سو اللہ ہمارے اور تمہارے درمیان گواہ کافی ہے کہ ہمیں تمہاری عبادت کی خبر ہی نہ تھی\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mcccxciv{اس جگہ ہر شخص اپنے پہلے کئے ہوئے کاموں کو جانچ لے گا اور یہ لوگ اللہ کی طرف لوٹائے جائینگے جو ان کا حقیقی مالک ہے اور جو جھوٹ وہ باندھا کرتے تھے ان سے جاتا رہے گا\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mcccxcv{کہو تمہیں آسمان اور زمین سے کون روزی دیتا ہے یا کانوں اور آنکھوں کا کون مالک ہے اور زندہ کو مردہ سے کون نکلتا ہے اور مردہ کو زندہ سے کون نکلتا ہے اور سب کاموں کا کون انتظام کرتا ہے سو کہیں گے کہ اللہ تو کہہ دو کہ پھر (اللہ) سے کیوں نہیں ڈرتے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mcccxcvi{یہی الله تمہارا سچا رب ہے حق کے بعد گمراہی کے سوا اور ہے کیا سوتم کدھر پھرے جاتے ہو\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mcccxcvii{اسی طرح ان نافرمانوں کے حق میں تیرے رب کا فیصلہ ثابت ہو کر رہا کہ یہ ایمان نہیں لائیں گے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mcccxcviii{کہہ دو آیا تمہارے شریکوں میں کوئی ایسا ہے جو مخلوقات کو پیدا کرے پھر اسے دوبارہ زندہ کرے کہہ دو الله پہلے پیدا کرتا ہے پھر اسے لوٹائے گا سو تم کہاں پھیرے جاتے ہو\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mcccxcix{کہہ دو آیا تمہارے شریکوں میں کوئی ہے جو صحیح راہ بتلائے کہہ دو الله ہی صحیح راہ بتلاتا ہے تو جو اب صحیح راستہ بتلائے اسکی بات ماننی چاہیئے یا اس کی جو خود راہ نہ پائے مگر جب کوئی اوراسے راہ بتلائے سو تمہیں کیا ہوگیا کیا انصاف کرتے ہو\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mcd{اور وہ اکثر اٹکل پر چلتے ہیں بےشک حق بات کے سمجھنے میں اٹکل ذرا بھی کام نہیں دیتی بے شک الله جانتا ہے جو کچھ وہ کرتے ہیں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mcdi{اوریہ قرآن ایسا نہیں کہ الله کے سوا اسے کوئی اپنی طرف سے بنا لائے اور لیکن اپنے سے پہلے کلام کی تصدیق کرتا ہے اوران چیزوں کو بیان کرتا ہے جو تم پر لکھی گئی اس میں کوئی شک نہیں کہ یہ رب العالمین کی طرف سے ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mcdii{کیا یہ لوگ کہتے ہیں اس نے اسے خود بنایا ہے کہہ دو تم ایک ہی ایسی سورت لے آؤ اور الله کے سوا جسے بلا سکو بلا لو اگر تم سچے ہو\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mcdiii{بلکہ انہوں نے اس چیز کو جھٹلایا جسے وہ سمجھ نہ سکے اوربھی اس کی حقیقت ان پر کھلی نہیں اسی طرح جو لوگ ان سے پہلے تھے انہوں نے بھی جھٹلایا تھا سو دیکھ لو کہ ظالموں کاانجام کیسا ہوا\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mcdiv{اور ان میں سے بعض ایسے ہیں کہ اس پر ایمان لے آتے ہیں اور بعض ایسے ہیں کہ ایمان نہیں لاتے اور تمہارا رب شریروں سے خوب واقف ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mcdv{اوراگر تجھے جھٹلائیں تو کہہ دے میرے لیے میرا کام اور تمہارے لیے تمہارا کام تم میرے کام کے جواب دہ نہیں اور میں تمہارے کام کا جواب دہ نہیں ہوں\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mcdvi{اور ان میں بعض ایسے ہیں کہ تمہاری طرف کان لگاتے ہیں کیا تم بہروں کو سنا سکتے ہو اگرچہ وہ نہ سمجھیں\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mcdvii{اور ان میں بعض ایسے ہیں کہ تمہاری طرف دیکھتے ہیں کیا تم اندھوں کو راہ دکھا دوگے اگر کچھ بھی نہ دیکھتے ہوں\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mcdviii{بے شک الله لوگوں پر ذرہ ظلم نہیں کرتا لیکن لوگ ہی اپنے آپ پر ظلم کرتے ہیں\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mcdix{اور جس دن انہیں جمع کرے گا گویا وہ نہیں رہے تھے مگر ایک گھڑی دن کی ایک دوسرے کو پہچانیں گے بے شک خسارے میں رہے جنہوں نے الله کی ملاقات کو جھٹلایا اور راہ پانے والے نہ ہوئے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mcdx{اور اگر ہم تمہیں ان وعدوں میں سے کوئی چیز دکھا دیں جو ہم نے ان سے کیے ہیں یاتمہیں وفات دیں پھر انہیں ہماری طرف لوٹنا ہے پھرالله شاہدہے ان کاموں پر جو کرتے ہیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mcdxi{اورہر امت کا یک رسول ہے پھر جب ان کے پاس ان کا رسول آیا تو ان کے درمیان انصاف سے فیصلہ کیا گیا اور ان پر ظلم نہیں کیا جاتا\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mcdxii{اور کہتے ہیں یہ وعدہ کب ہے اگر تم سچے ہو\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mcdxiii{کہہ دومیں اپنی ذات کے برے اور بھلے کا بھی مالک نہیں مگر جو الله چاہے ہر امت کا ایک وقت مقرر ہے جب وہ وقت آتا ہے تو ایک گھڑی بھی دیر نہیں کر سکتےہیں اور نہ جلدی کر سکتے ہیں\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mcdxiv{کہہ دو بھلا دیکھو تو اگر تم پر اس کا عذاب رات یا دن کو آجائے تو عذاب میں سے کون سی ایسی چیز ہے کہ مجرم اس کو جلدی مانگتے ہیں\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mcdxv{کیا پھر جب وہ آ چکے گا تب اس پر ایمان لاؤ گے اب مانتے ہو اور تم اس کی جلدی کرتے تھے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mcdxvi{پھر ظالموں سے کہا جائے گا ہمیشگی کا عذاب چکھتے رہو تمہیں نہیں بدلا دیا جاتا مگر اس چیز کا جو تم کرتے تھے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mcdxvii{اور تم سے پوچھتے ہیں کیا یہ بات سچ ہے کہہ دو ہاں میرے رب کی قسم بے شک یہ سچ ہے اور تم عاجز کرنے والے نہیں ہو\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mcdxviii{اور اگر ہر ایک نافرمان کے پاس روئے زمین کی تمام چیزیں ہوں البتہ اپنے بدلے میں دے ڈالے اور جب وہ عذاب دیکھیں گے تو دل میں نادم ہوں گے اور ان کے درمیان انصاف سے فیصلہ ہوگا اور ان پر ظلم نہیں کیا جائے گا\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mcdxix{خبردار بےشک الله ہی کا ہے جو کچھ آسمان اور زمین میں ہے خبردار بے شک الله کا وعدہ سچا ہے لیکن اکثر لوگ نہیں جانتے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mcdxx{وہی زندہ کرتا ہے اور مارتا ہے اور اسی کی طرف پھر کر جاؤ گے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mcdxxi{اے لوگو تمہارے رب سے نصیحت اور دلوں کے روگ کی شفا تمہارے پاس آئی ہے اور ایمان داروں کے لیے ہدایت اور رحمت ہے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mcdxxii{کہہ دو (قرآن) الله کے فضل اور اس کی رحمت سےہے سو اسی پر انہیں خوش ہونا چاہیئے یہ ان چیزوں سے بہتر ہے جو جمع کرتے ہیں\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mcdxxiii{کہہ دو بھلا دیکھو تو الله نے تمہارے لیے جو رزق نازل فرمایاہے تم نے اس میں سے بعض کو حرام اوربعض کو حلال کر دیا کہہ دو الله نے تمہیں حکم دیا ہے یا الله پر افترا کرتے ہو\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mcdxxiv{اور جو لوگ الله پر افترا کرتے ہیں قیامت کے دن کی نسبت ان کا کیا خیال ہے بے شک الله لوگوں پر مہربان ہے لیکن اکثر لوگ شکر نہیں کرتے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mcdxxv{اور تم جس حال میں ہوتے ہو یا قرآن میں سے کچھ پڑھتے ہو یا تم لوگ کوئی کام کرتے ہوتو ہم وہاں موجود ہوتے ہیں جب تم اس میں مصروف ہوتے ہو اور تمہارے رب سے ذرہ بھر بھی کوئی چیز پوشدیہ نہیں ہے نہ زمین میں اور نہ آسمان میں اور نہ کوئی چیز اس سے چھوٹی اور نہ بڑی مگر کتاب روشن میں ہے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mcdxxvi{خبردار بے شک جو الله کے دوست ہیں نہ ان پر ڈر ہے اور نہ وہ غمگین ہوں گے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mcdxxvii{جو لوگ ایمان لائے اور ڈرتے رہے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mcdxxviii{ان کے لیے دنیا کی زندگی اور آخرت میں خوشخبری ہے الله کی باتوں میں تبدیلی نہیں ہوتی یہی بڑی کامیابی ہے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mcdxxix{اور ان کی بات سے غم نہ کربے شک عزت سب الله ہی کے لیے ہے وہی سننے والا جاننے والا ہے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mcdxxx{خبردار جو کوئی آسمانوں میں ہے اور جو کوئی زمین میں ہے سب الله کا ہے اور یہ جو الله کے سوا شریکوں کو پکارتے ہیں وہ نہیں پیروی کرتے مگر گمان کی اور نہیں ہیں وہ مگر اٹکل کرتے ہیں\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mcdxxxi{وہی تو ہے جس نے تمہارے لیے رات بنائی تاکہ اسمیں آرام کرو اور دن دکھلانے والا بنایا بے شک اس میں ان لوگوں کے لیے نشانیاں ہیں جو سنتے ہیں\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mcdxxxii{کہتے ہیں الله نے بیٹا بنا لیا وہ پاک ہے وہ بے نیاز ہے جو کچھ آسمانوں میں اور جو کچھ زمین میں ہے سب اسی کا ہے تمہارے پاس اس کی کوئی سند نہیں ہے تم الله پر ایسی باتیں کیوں کہتے ہو جو جانتے نہیں\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mcdxxxiii{کہہ دو جو لوگ الله پر افترا کرتے ہیں نجات نہیں پائیں گے\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mcdxxxiv{دنیا میں تھوڑا سا نفع اٹھا لینا ہے پھر ہماری طرف انہیں لوٹنا ہے پھر ہم انہیں سخت عذاب چکھائیں گے بسبب اس کے کہ کفر کرتے تھے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mcdxxxv{اور انہیں نوح کا حال سنا جب اس نے اپنی قوم سے کہا اے قوم اگر تمہیں میرا تم میں رہنا اور الله کی آیتوں سے نصیحت کرنا ناگوار ہو تو میں الله پر بھروسہ کرتا ہوں اب تم سب ملکر اپنا کام مقرر کرو اور اپنے شریکوں کو جمع کرو پھر تمہیں اپنے کام میں شبہ نہ رہے پھر وہ کام میرے ساتھ کر گزرو اور مجھے مہلت نہ دو\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mcdxxxvi{پھر اگر منہ پھیرو تو میں نے تم سے کچھ معاوضہ نہیں مانگا میرا معاوضہ الله پر ہے اور مجھے حکم دیا گیا ہے کہ فرمانبرداروں میں سے رہوں\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mcdxxxvii{پھر انہوں نے اسے جھٹلایا پھر ہم نے اسے اور اس کے ساتھیوں کو کشتی میں بچا لیا اور انہیں خلیفہ بنا دیا اور جن لوگو ں نے ہماری آیتوں کو جھٹلایا انہیں غرق کر دیا سو دیکھ لو کہ جو لوگ ڈرائے گئے تھے ان کا انجام کیسا ہوا\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mcdxxxviii{پھر ہم نے نوح کے بعد اور پیغمبر اپنی اپنی قوم کی طرف بھیجے تو وہ ان کے پاس کھلی نشانیاں لائے پھر بھی ان سے یہ نہ ہوا کہ اس بات پر ایمان لے آئيں جسے پہلے وہ جھٹلا چکے تھے اسی طرح ہم حد سے نکل جانے والوں کے دلوں پر مہر لگا دیتے ہیں\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mcdxxxix{پھر ہم نے ان کے بعد موسیٰ اورہارون کو فرعون اور اس کےسرداروں کے پاس اپنی نشانیاں دے کر بھیجا پھر انہوں نے تکبر کیا اور وہ لوگ گنہگار تھے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mcdxl{پھر جب انہیں ہمارے ہاں سے سچی بات پہنچی کہنے لگے یہ تو کھلا جادو ہے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mcdxli{موسیٰ نے کہا کیاتم حق بات کو یہ کہتے ہو جب وہ تمہارے پاس آئی کیا یہ جادو ہے اور جادو کرنے والے نجات نہیں پاتے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mcdxlii{انہوں نے کہا کیاتو ہمارے ہاں آیا ہے کہ ہمیں اس راستہ سے پھیر دے جس پر ہم نے اپنے باپ دادوں کو پایا ہے تم دونوں کو اس ملک میں سرداری مل جائے اور ہم تو تمہیں ماننے والے نہیں ہیں\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mcdxliii{اور فرعون نے کہا میرے پاس ہردانا جادوگر کو لے آؤ\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mcdxliv{پھر جب جادوگر آئے انہیں موسیٰ نے کہا ڈالو جو تم ڈالتے ہو\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mcdxlv{پھر جب انہوں نے ڈالا موسیٰ نے کہا جو تم لائے ہو وہ جادو ہے الله اسے ابھی درہم برہم کر دے گا بے شک الله شریروں کے کام نہیں سنوارتا\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mcdxlvi{اور الله اپنے حکم سےحق بات کو سچا کرتا ہے اگرچہ گنہگار برا ہی مانیں\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mcdxlvii{پھر کوئی بھی موسیٰ پر ایمان نہ لایا مگر اس کی قوم کے چند لڑکے اور وہ بھی فرعون اور ان کے سرداروں سے ڈرتے ڈرتے کہ کہیں وہ انہیں مصیبت میں نہ ڈال دے اور بے شک فرعون زمین میں سرکشی کرنے والا تھا اوربے شک وہ حد سے گزرنے والوں میں سے تھا\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mcdxlviii{اور موسیٰ نے کہا اے میری قوم اگر تم الله پر ایمان لائے ہو تو اسی پر بھروسہ کرو اگر تم فرمانبردار ہو\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mcdxlix{تب وہ بولے ہم الله ہی پر بھروسہ کرتے ہیں اے رب ہمارے ہم پر اس ظالم قوم کا زور نہ آزما\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mcdl{اور ہمیں مہربانی فرما کر ان کافروں سے چھڑا دے\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mcdli{اور ہم نے موسیٰ اور اس کے بھائی کو حکم بھیجا کہ اپنی قوم کے واسطے مصر میں گھر بناؤ اوراپنے گھروں کو مسجدیں سمجھو اور نماز قائم کرو اورایمان والوں کو خوشخبری دو\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mcdlii{اورموسیٰ نے کہا اے رب ہمارے تو نے فرعون اوراس کے سرداروں کو دنیا کی زندگی میں آرائش اور ہر طرح کا مال دیا ہے اے رب ہمارے یہاں تک کہ انہوں نےتیرے راستہ سے گمراہ کر دیا اے رب ہمارے ان کے مالوں کو برباد کر دے اور ان کے دلوں کو سخت کر دے پس یہ ایمان نہیں لائیں گے یہاں تک کہ دردناک عذاب دیکھیں\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mcdliii{فرمایا تمہاری دعا قبول ہو چکی سو تم دونوں ثابت قدم رہو اوربے عقلوں کی راہ پر مت چلو\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mcdliv{اور ہم نے بنی اسرائیل کو دریا سے پار کر دیا پھر فرعون اور اس کے لشکر نے ظلم اور زيادتی سے ان کا پیچھا کیا یہاں تک کہ جب ڈوبنےلگا کہا میں ایمان لایا کہ کوئی معبود نہیں مگر جس پر بنی اسرائیل ایمان لائے ہیں اور میں فرمانبردار میں سے ہوں\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mcdlv{اب یہ کہتا ہے اورتو اس سے پہلے نافرمانی کرتا رہا اور مفسدوں میں داخل رہا\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mcdlvi{سو آج ہم تیرے بدن کو نکال لیں گے تاکہ تو پچھلوں کے لیے عبرت ہو اوربے شک بہت سے لوگ ہماری نشانیوں سے بے خبر ہیں\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mcdlvii{اور البتہ تحقیق ہم نے بنی اسرائیل کو رہنے کی عمدہ جگہ دی اور کھانے کو ستھری چیزیں دیں وہ باوجود علم ہونے کے خلاف کرتے رہے بےشک تیرا رب قیامت کے دن ان میں فیصلہ کرے گا جس بات میں کہ وہ اختلاف کرتے تھے\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mcdlviii{سو اگرتمہیں اس چیز میں شک ہے جو ہم نے تیری طرف اتاری تو ان سے پوچھ لے جو تجھ سے پہلے کتاب پڑھتے ہیں بے شک تیرے پاس تیرے رب سے حق بات آئی ہے سو شک کرنے والوں میں ہرگز نہ ہو\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mcdlix{اوران میں سے بھی نہ ہو جنہوں نے الله کی آیتوں کو جھٹلایا پھر تو بھی نقصان اٹھانے والوں میں سے ہوگا\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mcdlx{جن پر تیرے رب کی بات ثابت ہو چکی ہے وہ ایمان نہیں لائیں گے\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mcdlxi{اگرچہ انہیں ساری نشانیاں پہنچ جائیں جب تک کہ دردناک عذاب نہ دیکھ لیں\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mcdlxii{سو کوئی بستی ایسی کیوں نہ ہوئی جو ایمان لاتی تو اس کا ایمان اسے نفع دیتا سوائے یونس کی قوم کے کہ جب وہ ایمان لائے تو ہم نے دنیا کی زندگی میں ان سے ذلت کا عذاب دور کر دیا اور ہم نے انہیں ایک وقت تک فائدہ پہنچایا\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mcdlxiii{اور اگر تیرا رب چاہتا تو جتنے لوگ زمین میں ہیں سب کے سب ایمان لے آتے پھر کیا تو لوگوں پر زبردستی کرے گا کہ وہ ایمان لے آئيں\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mcdlxiv{اورکسی کے بھی بس میں نہیں کہ الله کے حکم کے سوا ایمان لے آئے اور الله انکے لیے کفر کا فیصلہ کرتا ہے جو نہیں سوچتے\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mcdlxv{کہہ دو دیکھوکہ آسمانوں اور زمین میں کیا کچھ ہے اور بے ایمان قوم کو معجزے اور ڈرانے والے کچھ فائدہ نہیں دیتے\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mcdlxvi{پھر کیا وہ انہیں لوگوں کے دنوں کا سا انتظار کرتے ہیں جو ان سے پہلے گزرے ہیں کہہ دو اچھا انتظار کرو میں بھی تمہارے ساتھ انتظار کرتا ہوں\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mcdlxvii{پھر ہم اپنے رسولوں اوران لوگوں کو جو ایمان لاتے ہیں بچا لیتے ہیں اسی طرح ہمارا ذمہ ہے کہ ایمان والوں کوبچا لیں\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mcdlxviii{کہہ دو اے لوگو اگر تمہیں میرے دین میں شک ہے تو الله کے سوا جن کی تم عبادت کرتے ہو میں ان کی عبادت نہیں کرتا بلکہ میں الله کی عبادت کرتا ہوں جو تمہیں وفات دیتا ہے اور مجھے حکم ہوا ہے کہ ایمانداروں میں رہوں\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mcdlxix{اور یہ بھی کہ یک سوہوکر دین کی طرف رخ کیے رہو اور مشرکوں میں نہ ہو\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mcdlxx{اور الله کے سوا ایسی چیز کونہ پکار جو نہ تیرا بھلا کرے اور نہ برا پھر اگرتو نے ایسا کیا تو بے شک ظالموں میں سے ہو جائے گا\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mcdlxxi{اوراگر الله تمہیں کوئی تکلیف پہنچائے تو اس کے سوا اسے ہٹانے والا کوئی نہیں اور اگر تمہیں کوئی بھلائی پہنچانا چاہے توکوئی اس کے فضل کو پھیرنے والا نہیں اپنے بندوں میں سے جسے چاہتا ہے اپنا فضل پہنچاتا ہے اور وہی بحشنے والا مہربان ہے\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mcdlxxii{کہہ دو اے لوگو تمہیں تمہارے رب سے حق پہنچ چکا ہے پس جو کوئی راہ پر آئے سو وہ اپنے بھلے کے لیے راہ پاتا ہے اور جو گمراہ رہے گا اس کا وبال اسی پر پڑے گا اور میں تمہارا ذمہ دارنہیں ہوں\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mcdlxxiii{اورجو کچھ تیری طرف وحی کیا گیا ہے ا س پر چل اور صبر کر یہاں تک کہ الله فیصلہ کر دے اور وہ بہتر فیصلہ کرنے والا ہے\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mcdlxxiv{\basmalahur یہ ایسی کتاب ہےکہ جس کی آیتیں حکیم خبردار کی طرف سے مستحکم کر دی گئی ہیں پھر مفصل بیان کی گئی ہیں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mcdlxxv{یہ کہ الله کے سوا کسی کی عبادت نہ کرو میں تمہارے لیے اس کی طرف سے ڈرانے والا اور خوشخبری دینے والا ہوں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mcdlxxvi{اور یہ کہ تم اپنے رب سے معافی مانگو پھراس کی طرف رجوع کرو تاکہ تمہیں ایک وقت مقرر تک اچھا فائدپہنچائے اورجس نے بڑھ کر نیکی کی ہو اس کو بڑھ کر بدلہ دے اور اگر تم پھر جاؤ گے تو میں تم پر ایک بڑے دن کے عذاب سے ڈرتا ہوں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mcdlxxvii{تمہیں الله کی طرف لوٹ کر جانا ہے اوروہ ہر چیز پر قادر ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mcdlxxviii{خبردار جس وقت وہ کپڑے ڈھانکتے ہیں وہ جانتا ہے جو کچھ وہ چھپا کر اور ظاہر کر کے کرتے ہیں بےشک وہ دلوں کی باتوں کو جاننے والا ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mcdlxxix{ارو زمین پر کوئی چلنے والا نہیں مگر اس کی روزی الله پر ہے اور جانتا ہے جہاں وہ ٹھیرتا ہے اور جہاں وہ سونپا جاتا ہے سب کچھ واضح کتاب میں ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mcdlxxx{اور وہی ہےجس نے آسمان اور زمین چھ دن میں بنائے اور اس کا تخت پانی پر تھا کہ تمہیں آزمائے کہ تم میں سے کون اچھا کام کرتا ہے اور اگر تو کہے کہ مرنے کے بعد اٹھو گے تو منکرین یہ کہیں گے کہ یہ تو صریح جادو ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mcdlxxxi{اور اگر ہم ایک مدت معلوم تک ان سے عذاب کو روک رکھیں توضرور کہیں گے کس چیر نے عذاب کو روک دیا خبردار جس دن ان پر عذاب آئے گا ان سے نہ پھیرا جائے گا اور انہیں وہ چیز گھیرے گی جس پر ٹھٹایا کیاکرتے تھے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mcdlxxxii{اور اگر ہم انسان کو اپنی رحمت کا مزہ چکھا کر پھر اس سے چھین لیتے ہیں تو وہ ناامید ناشکرا ہو جاتا ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mcdlxxxiii{اور اگر مصیبت پہنچنے کے بعد نعمتوں کا مزہ چکھاتے ہیں تو کہتا ہے کہ میری سختیاں جاتی رہیں کیوں کہ وہ اترانے والا شیخی خورا ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mcdlxxxiv{مگر جو لوگ صابر ہیں اور نیکیاں کرتے ہیں ان کے لیے بخشش اوربڑا ثواب ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mcdlxxxv{پھر شاید آپ اس میں سے کچھ چھوڑ بیٹھیں گے جو آپ کی طرف وحی کیا گیا ہے اور ان کے اس کہنے سے آپ کا دل تنگ ہوگا کہ اس پر کوئی خزانہ کیوں نہ اتر آیا یا اس کے ساتھ کوئی فرشتہ کیوں نہ آیا آپ تو محض ڈرانے والے ہیں اور الله ہر چیز کا ذمہ دار ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mcdlxxxvi{کیا کہتے ہیں کہ تو نے قرآن خود بنا لیا ہے کہہ دو تم بھی ایسی دس سورتیں بنا لاؤ اور الله کے سوا جس کو بلا سکو بلا لو اگر تم سچے ہو\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mcdlxxxvii{پھر اگر تمہارا کہنا پورا نہ کریں تو جان لو کہ قرآن الله کے علم سے نازل کیا گیا ہے اور یہ بھی کہ اس کے سوا کوئی معبود نہیں پس کیا تم فرمانبرداری کرنے والے ہو\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mcdlxxxviii{جو کوئی دنیا کی زندگی اور اس کی آرائش چاہتا ہے تو انکے اعمال ہم یہیں پورے کر دیتے ہیں اور انہیں کچھ نقصان نہیں دیا جاتا\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mcdlxxxix{یہ وہی ہیں جن کیلئے آخرت میں آگ کے سوا کچھ نہیں اور برباد ہوگیا جو کچھ انہوں نے دنیا میں کیا تھا اور خراب ہو گیا جو کچھ کمایا تھا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mcdxc{بھلا وہ شخص جو اپنے رب کے صاف راستہ پر ہو اور اس کے ساتھ الله کی طرف سے ایک گواہ بھی ہو اور اس سے پہلے موسیٰ کی کتاب گواہ تھی جو امام اور رحمت تھی یہی لوگ قرآن کو مانتے ہیں اور جو کوئی سب فرقوں میں سے اس کا منکر ہوتو اس کا ٹھکانا دوزخ ہے سو تو قرآ ن کی طرف سے شبہ میں نہ رہ بے شک یہ تیرے رب کی طرف سے حق ہے لیکن اکثر لوگ ایمان نہیں لاتے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mcdxci{اور اس سے بڑھ کر ظالم کون ہوگا جو الله پر جھوٹ باندھے وہ لوگ اپنے رب کے روبر پیش کیے جائیں گے اور گواہ کہیں گے کہ یہی ہیں کہ جنہوں نے اپنے رب پر جھوٹ بولا تھا خبرادر ظالموں پر الله کی لعنت ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mcdxcii{جو الله کی راہ سے روکتے ہیں اور اس میں کجی پیدا کرنا چاہتے ہیں اوروہی آخرت کے منکر ہیں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mcdxciii{یہ لوگ زمین میں عاجز کرنے والے نہیں تھے اور ان کے لیے سوا الله کے کوئی دوست نہ تھا انہیں دگنا عذاب کیا جائے گا یہ لوگ نہ سن سکتے تھے اور نہ دیکھتے تھے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mcdxciv{انہوں نے اپنے آپ کو خسارہ میں ڈال دیا اور ان سے ضائع ہوگیا جو جھوٹ وہ باندھتے تھے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mcdxcv{بے شک یہی لوگ آخرت میں سب سے زیادہ نقصان میں ہوں گے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mcdxcvi{البتہ جولوگ ایمان لائے اورنیک کام کیے اور اپنے رب کے سامنے عاجزی کی وہ جنت میں رہنے والے ہیں وہ اس میں ہمیشہ رہیں گے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mcdxcvii{دونوں فریق کی مثال ایسی ہے جیسے ایک اندھا اوربہرا ہو اور دوسرا دیکھنے والا اور سننے والاکیا دونوں کا حال برابر ہے پھر تم کیوں نہیں سمجھتے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mcdxcviii{اور ہم نے نوح کو اس کی قوم کی طرف بھیجا بے شک میں تمہیں صاف ڈرانے والا ہوں\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mcdxcix{کہ الله کے سوا کسی کی عبادت نہ کرو بے شک میں تم پر دردناک دن کے عذاب سے ڈرتا ہوں\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@md{پھر اس کی قوم کے جو کافر سردار تھے وہ بولے ہمیں تو تم ہم جیسے ہی ایک آدمی نظر آتے ہو اور ہمیں تو تمہارے پیرو وہی نظر آتے ہیں جو ہم میں سے رذیل ہیں وہ بھی سرسری نظر سے اورہم تم میں اپنے سے کوئی فضیلت بھی نہیں پاتے بلکہ تمہیں جھوٹا خیال کرتے ہیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mdi{اس نے کہا اے میری قوم دیکھو تو اگر میں اپنے رب کی طرف سے صاف راستہ پر ہوں اور اس نے مجھ پر اپنے ہاں سے رحمت بھیجی ہو پھر وہ تمہیں دکھائی نہ دے تو کیا میں زبردستی تمہارے گلے مڑھ دوں اور تم اس سے نفرت کرتے ہو\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mdii{اور اے میری قوم میں تم سے اس پر کچھ مال نہیں مانگتا میری مزدوری الله ہی کے ذمہ ہے اور میں ایمانداروں کو ہٹانے والا نہیں بے شک و ہ اپنے رب سے ملنے والے ہیں لیکن تمہیں جاہل قوم دیکھتا ہوں\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mdiii{اور اے میری قوم اگر میں انہیں ہٹا دوں تو مجھے الله سے کون چھڑائے گا کیا پھر تم نہیں سمجھتے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mdiv{اور میں تمہیں نہیں کہتا کہ میرے پاس الله کے خزانے ہیں اور نہ یہ کہ میں غیب دان ہوں اور نہ یہ کہتا ہوں کہ میں فرشتہ ہوں اور نہ یہ کہوں گاکہ جو لوگ تمہاری نظر میں حقیر ہیں الله ان کو بھلائی نہ دے گا الله خوب جانتا ہے جو کچھ ان کے دلوں میں ہے ایسا کہوں تو میں بے انصاف ہوں\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mdv{کہا اے نوح تو نے ہم سے جھگڑا کیا او ربہت جھگڑا کر چکا اب لے آ جو تو ہم سے وعدہ کرتا ہے اگر تو سچا ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mdvi{نوح نے کہا اسے تو اگرچاہے گا الله ہی لائے گا اور تم اسے روک نہ سکو گے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mdvii{اور میری نصیحت تمہیں فائدہ نہ دے گی خواہ میں کتنی ہی نصیحت کرنا چاہوں اگر الله کو تمہیں گمراہ رکھنا ہی منظور ہے وہی تمہارا رب ہے اور اسی کی طرف تمہیں پھر جانا ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mdviii{کیا کہتے ہیں کہ قرآن کو خود بنا لایا ہے کہہ دو اگر میں بنا لایا ہوں تو اس کا گناہ مجھ پر ہے اور میں تمہارے گناہوں سے بری ہوں\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mdix{اور نوح کی طرف وحی کی گئی کہ تیری قوم میں سے اب کوئی ایمان نہیں لائے گا مگر جو لا چکا پھر غم نہ کر اور کاموں پر جو کر رہے ہیں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mdx{اور ہمارے روبرو اور ہمارے حکم سے کشتی بنا اور ظالمو ں کے حق میں مجھ سے کوئی بات نہ کر بے شک وہ غرق کیے جائیں گے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mdxi{اور وہ کشتی بناتے تھے اور جب اس کی قوم کے سردار اس پر گزرتے اس سے ہنسی کرتے کہتے اگر تم ہم پر ہنستے ہو تو ہم بھی تم پر ہنسیں گے جیسے تم ہنستے ہو\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mdxii{تمہیں جلدی معلوم ہو جائے گا کہ کس پر عذاب آتا ہے جو اسے رسوا کرے گا اورکسی پر دائمی عذاب اترتا ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mdxiii{یہاں تک کہ جب ہمارا حکم پہنچا اور تنور نے جوش مارا ہم نے کہا کشتی میں ہر قسم کے جوڑا نر مادہ چڑھا لے اور اپنے گھر والوں کو مگر وہ جن کے متعلق فیصلہ ہو چکا ہے اور سب ایمان والوں کو اور اس کے ساتھ ایمان تو بہت کم لائے تھے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mdxiv{اور کہا اس میں سوار ہو جاؤ اس کا چلنا اور ٹھیرنا الله کے نا م سے ہےبے شک میرا رب بخشنے والا مہربان ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mdxv{اور وہ انہیں پہاڑ جیسی لہروں میں لیے جارہی تھی اورنوح نے اپنے بیٹے کو پکارا جب کہ وہ کنارے پر تھا اے بیٹے ہمارے ساتھ سوار ہو جا اور کافروں کے ساتھ نہ رہ\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mdxvi{کہا میں ابھی کسی پہاڑ کی پناہ لے لیتا ہوں جو مجھے پانی سے بچا لے گا کہا آج الله کے حکم سے کوئی بچانے والا نہیں مگر جس پر وہی رحم کرے اور دونوں کے درمیان موج حائل ہو گئی پھر ڈوبنے والوں میں ہوگیا\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mdxvii{اور حکم آیا اے زمین اپنا پانی نگل جا اور اے آسمان تھم جا اور پانی سکھا دیا گیا اور کام ہو چکا اور کشتی جودی پہاڑ پر ٹھری اور کہہ دیا گیا کہ ظالموں پر پھٹکار ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mdxviii{اور نوح نے اپنے رب کو پکارا اے رب میرا بیٹا میرے گھر والو ں میں سے ہے اوربے شک تیار وعدہ سچا ہے اور تو سب سے بڑا حاکم ہے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mdxix{فرمایا اے نوح وہ تیرے گھر والو ں میں سے نہیں ہے کیوں کہ اس کے عمل اچھے نہیں ہیں سو مجھ سے مت پوچھ جس کا تجھے علم نہیں میں تمہیں نصیحت کرتا ہوں کہ کہیں جاہلوں میں نہ ہو جاؤ\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mdxx{کہا اے رب میں تیری پناہ لیتا ہوں اس بات سے کہ تجھ سے وہ بات پوچھوں جو مجھے معلوم نہیں اور اگر تو نے مجھے نہ بخشا اورمجھ پر رحم نہ کیا تو میں نقصان والوں میں ہو جاؤں گا\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mdxxi{کہا گیا اے نوح ہماری طرف سے سلامتی اور برکتوں کے ساتھ جو تم پر اور تمہارے ساتھ والوں پر رہیں گی کشتی سے اتر اور دوسرے فرقے ہیں کہ ہم انھیں دنیا میں فائدہ دیں گے پھر انہیں ہماری طرف سے دردناک عذاب پہنچے گا\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mdxxii{یہ غیب کی خبریں ہیں جنہیں ہم آپ کی طرف وحی کر رہے ہیں اس سے پہلے نہ تو آپ ہی جانتے تھے اور نہ آپ کی قوم جانتی تھی پس صبر کر کیوں کہ بہتر انجام پرہیزگاروں کے لیے ہے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mdxxiii{اور ہم نے عاد کی طرف ان کے بھائی ہود کو بھیجا اے قوم الله کی بندگی کرو اس کے سوا تمہارا کوئی حاکم نہیں تم سب جھوٹ کہتے ہو\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mdxxiv{اے قوم میں اس پر تم سے مزدوری نہیں مانگتا میری مزدوری اسی پر ہے جس نے مجھے پیدا کیا پھر کیا تم نہیں سمجھتے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mdxxv{اور اے قوم اپنے رب سے معافی مانگو پھر اس کی طرف رجوع کرو وہ تم پر خوب بارشیں برسائے گا اور تمہاری قوت کو اوربڑھائے گا اورتم نافرمان ہو کر نہ پھر جاؤ\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mdxxvi{کہا اے ہود تو ہمارے پاس کوئی معجزہ بھی نہ لایا اور ہم تیرے کہنے سے اپنے معبودوں کو چھوڑنے والے نہیں اورنہ ہم تجھے ماننے والے ہیں\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mdxxvii{ہم تو یہی کہتے ہیں کہ تجھےہمارے کسی معبود نے بری طرح جھپٹ لیا ہے کہا بے شک میں الله کو گواہ کرتا ہوں اورتم بھی گواہ رہو کہ میں ان چیزوں سے بیزار ہوں جنہیں تم الله کے سوا شریک کرتے ہو\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mdxxviii{سوتم سب مل کر میرے حق میں برائی کرو پھر مجھے مہلت نہ دو\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mdxxix{میں نے الله پر بھروسہ کیا ہے جو میرا اور تمہارا رب ہے کوئی بھی زمین پر ایسا چلنے والا نہیں کہ جس کی چوٹی اس نے نہ پکڑ رکھی ہو بے شک میرا رب سیدھے راستے پر ہے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mdxxx{پھر اگر تم منہ پھیرو گے تو جو مجھے دے کر بھیجا گیا تھا وہ تمہیں پہنچا دیا اور میرا رب تمہاری جگہ اور قوم پیدا کر دے گا اور تم اس کا کچھ بھی بگاڑنہیں سکو گے بے شک میرا رب ہر چیزپر نگہبان ہے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mdxxxi{اور جب ہمارا حکم پہنچا تو ہم نے ہود کو اورانہیں جو اس کے ساتھ ایمان لائے تھے اپنی رحمت سے بچا لیا اور ہم نے انہیں سخت عذاب سے نجات دی\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mdxxxii{اور یہ عاد تھے کہ اپنے رب کی باتوں سے منکر ہوئے اوراس کے رسولوں کو نہ مانا اور ہر ایک جبار سرکش کا حکم مانتے تھے\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mdxxxiii{اور اس دنیا میں بھی اپنے پیچھے لعنت چھوڑ گئے اور قیامت کے دن بھی خبردار بےشک عاد نے اپنے رب کا انکار کیا تھا خبردار عاد جو ہود کی قوم تھی الله کی رحمت سے دور کی گئی\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mdxxxiv{اور ثمود کی طرف ان کے بھائی صالح کو بھیجا اے میری قوم الله کی بندگی کرو اس کے سوا تمہارا کوئی معبود نہیں اسی نے تمہیں زمین سے بنایا اورتمہیں اس میں آباد کیا پس اس سے معافی مانگو پھر اس کی طرف رجوع کرو بے شک میرا رب نزدیک ہے قبول کرنے والا\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mdxxxv{انہوں نے کہا اے صالح اس سے پہلے تو ہمیں تجھ سے بڑی امید تھی تم ہمیں ان معبودوں کے پوجنے سےمنع کرتے ہو جنہیں ہمارے باپ دادا پوجتے چلے آئے ہیں اورجس طرف تم ہمیں بلاتے ہو اس سے تو ہم بڑے شک میں ہیں\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mdxxxvi{صالح نے کہا اےمیری قوم بھلا دیکھو تو اگر میں اپنے رب کی طرف سے کوئی کھلی دلیل رکھتا ہوں اور اس کی طرف سے میرے پاس رحمت بھی آ چکی ہو پھر اگر میں اس کی نافرمانی کروں تو مجھے اس سے کون بچا سکتا ہے پھر تم مجھے نقصان کے سوا اور کیا دے سکو گے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mdxxxvii{اور اےمیری قوم یہ الله کی اونٹنی تمہارے لیے نشانی ہے سواسے چھوڑ دو الله کی زمین میں کھاتی پھرے اور اسے برائی سے چھونا بھی نہیں (ورنہ) پھر تمہیں عذاب بہت جلد آ پکڑے گا\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mdxxxviii{پھر انہوں نے اس کے پاؤں کاٹ ڈالے تب صالح نے کہا تین دن تک اپنے گھروں میں فائدہ اٹھا لو یہ وعدہ ہے جو جھوٹا نہ ہوگا\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mdxxxix{پھر جب ہمارا حکم آ پہنچا تو ہم نے صالح کو اورجو اس کے ساتھ ایمان لائے تھے اپنی رحمت سے بچا لیا اور اس دن کی رسوائی سے نجات دی بے شک تیرا رب وہی زور والا زبردست ہے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mdxl{اوران ظالموں کو ہولناک آواز نے پکڑ لیا پھر صبح کو اپنے گھروں میں اوندھے پڑے ہوئے رہ گئے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mdxli{گویا کہ کبھی وہاں رہے ہی نہ تھے خبردار ثمود نے اپنے رب کا انکار کیا تھا خبردار ثمود پر پھٹکار ہے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mdxlii{اور ہمارے بھیجے ہوئے ابراھیم کے پاس خوشخبری لے کر آئے انہوں نے کہا سلام اس نے کہا سلام پس دیر نہ کی کہ ایک بھنا ہوا بچھڑا لے آیا\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mdxliii{پھر جب دیکھا کہ ان کے ہاتھ اس تک نہیں پہنچتے تو انہیں اجنبی سمجھا اوران سے ڈرا انہوں نے کہا خوف نہ کرو ہم تو لوط کی قوم کی طرف بھیجحے گئے ہیں\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mdxliv{اور اس کی عورت کھڑی تھی تب وہ ہنس پڑی پھر ہم نے اسے اسحاق کے پیدا ہونے کی خوشخبری دی اور اسحاق کے بعد یعقوب کی\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mdxlv{وہ بولی اے افسوس کیا میں بوڑھی ہو کر جنوں گی میرا خاوند بھی بوڑھا ہے یہ تو ایک عجیب بات ہے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mdxlvi{انہوں نے کہا کیاتو الله کے حکم سے تعجب کرتی ہے تم پر اے گھر والو الله کی رحمت اور اس کی برکتیں ہیں بے شک وہ تعریف کیا ہوا بزرگ ہے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mdxlvii{جب ابراھیم سے ڈر جاتا رہا اور اسے خوشخبری آئی ہم سے قوم لوط کے حق میں جھگڑنے لگا\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mdxlviii{بے شک ابراھیم بردبار نرم دل اور الله کی طرف رجوع کرنے والا تھا\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mdxlix{اے ابراھیم یہ خیال چھوڑ دے کیوں کہ تیرے رب کا حکم آ چکا ہے اور بے شک ان پرعذاب آ کر ہی رہے گا جو ٹلنے والا نہیں\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mdl{اور جب ہمارے بھیجے ہوئے لوط کے پاس پہنچے تو ان کے آنے سے غمگین ہوا اور دل میں تنگ ہوا اور کہا آج کا دن بڑا سخت ہے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mdli{اور اس کے پاس اس کی قوم بے اختیار دوڑتی آئی اور یہ لوگ پہلے ہی سے برے کام کیا کرتے تھے کہا اےمیری قوم یہ میری بیٹیاں ہیں یہ تمہارے لیے پاک ہیں سو تم الله سے ڈرو اور میرے مہمانو ں میں مجھے ذلیل نہ کرو کیا تم میں کوئی بھی بھلا آدمی نہیں\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mdlii{انہوں نے کہا البتہ تحقیق تو جانتا ہے کہ ہمیں تیری بیٹیوں سے کوئی غرض نہیں اور تجھے معلوم ہے جو ہم چاہتے ہیں\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mdliii{کہا کاش کہ مجھے تمہارے مقابلے کی طاقت ہو تی یا میں کسی زبردست سہارے کی پناہ جا لیتا\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mdliv{فرشتوں نے کہا اے لوط بے شک ہم تیرے رب کے بھیجے ہوئے ہیں یہ تم تک ہرگز نہ پہنچ سکیں گے سو کچھ حصہ رات رہے اپنے لوگوں کو لے نکل اور تم میں سے کوئی مڑ کر نہ دیکھے مگر تیری عورت کہ اس پر بھی وہی بلا آنے والی ہے جو ان پر آئے گی ان کے وعدہ کا وقت صبح ہے کیا صبح کا وقت نزدیک نہیں ہے\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mdlv{پھر جب ہمارا حکم پہنچا تو ہم نے وہ بستیاں الٹ دیں اور اس زمین پر کھنگر کے پتھر برسانا شروع کیے جو لگاتار گر رہے تھے\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mdlvi{جن پر تیرے رب کے ہاں سے خاص نشان بھی تھا اور یہ بستیاں ان ظالموں سے کچھ دور نہیں ہیں\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mdlvii{اورمدین کی طرف ان کے بھائی شعیب کو بھیجا کہ اے میری قوم الله کی بندگی کرو اس کے سوا تمہارا کوئی معبود نہیں اور ناپ اور تول کو نہ گھٹاؤ میں تمہیں آسودہ حال دیکھتا ہوں اور تم پر ایک گھیر لینے والے دن کے عذاب سے ڈرتا ہوں\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mdlviii{اور اے میری قوم انصاف سے ناپ اور تول کو پورا کرو اور لوگو ں کو ان کی چیزیں گھٹا کر نہ دو اور زمین میں فساد نہ مچاؤ\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mdlix{الله کا دیا جو باقی بچ رہے وہ تمہارے لیے بہتر ہے اگر تم ایماندار ہو اور میں تمہارا نگہبان نہیں ہوں\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mdlx{انہوں نے کہا اے شعیب کیا تیری نماز تجھے یہی حکم دیتی ہے کہ ہم ان چیزوں کو چھوڑ دیں جنہیں ہمارے باپ باپ دادا پوجتے تھے یا اپنے مالوں میں اپنی خواہش کے مطابق معاملہ نہ کریں بے شک تو البتہ بردبار نیک چلن ہے\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mdlxi{کہا اے میری قوم دیکھو تو سہی اگر مجھے اپنے رب کی طرف سے سمجھ آ گئی ہے اور اس نے مجھے عمدہ روزی دی ہے اور میں یہ نہیں چاہتا کہ جس کام سے تجھے منع کروں میں اس کے خلاف کروں میں تو اپنی طاقت کے مطابق اصلاح ہی چاہتا ہوں اور مجھے تو صرف الله ہی سے توفیق حاصل ہوتی ہے میں اسی پر بھروسہ کرتا ہوں اور اسی کی طرف رجوع کرتا ہوں\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mdlxii{اوراے میری قوم کہیں میری ضد سے ایسا جرم نہ کر بیٹھنا جس سے وہی مصیبت نہ آ پڑے جیسی کہ قوم نوح یا قوم ہود یا قوم صالح پر پڑی تھی اور لوط کی قوم بھی تم سے دور نہیں\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mdlxiii{اور اپنے الله سے معافی مانگو پھر اس کی طرف رجوع کرو بے شک میرا رب مہربان محبت والا ہے\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mdlxiv{انہوں نے کہا اے شعیب ہم بہت سی باتیں نہیں سمجھتے جو تم کہتے ہو اوربے شک ہم البتہ تمہیں اپنےمیں کمزور پاتے ہیں اور اگر تیری برادری نہ ہوتی تو تجھے ہم سنگسارکردیتے اور ہماری نظر میں تیری کوئی عزت نہیں ہے\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mdlxv{کہا اے میری قوم کیا میری برادری کا دباؤ تم پر الله سے زیادہ ہے اس کو تم نے پس پشت ڈال دیا ہے بے شک میرا رب تمہارے سب اعمال پر احاطہ کرنے والا ہے\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mdlxvi{اور اے میری قوم اپنی جگہ پر کام کیے جاؤ میں تم بھی کام کرتا ہوں آئندہ معلوم کر لو گے کس پر رسوا کرنے والا عذاب آتا ہے اور جھوٹا کون ہے اورانتظار کرو بے شک میں بھی تمہارے ساتھ انتظار کر رہا ہوں\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mdlxvii{اور جب ہمارا حکم آ گیا تو ہم نے شعیب کو اور ان لوگوں کو جو ان کے ساتھ ایمان لائے تھے اپنی رحمت سے بچا لیا اوران ظالموں کو کڑک نے آ پکڑا پھر صبح کو اپنے گھروں میں اوندھے پڑے ہوئے رہ گئے\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mdlxviii{گویا کبھی وہاں بسے ہی نہ تھے خبردار مدین پر پھٹکار ہے جیسے ثمود پر پھٹکار ہوئی تھی\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mdlxix{اور البتہ تحقیق ہم نے موسیٰ کو اپنی نشانیاں اور واضع سند دے کر بھیجا\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mdlxx{فرعون اور اس کے سرداروں کے ہاں پھر وہ فرعون کے حکم پر چلے اور فرعون کا حکم ٹھیک بھی نہ تھا\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mdlxxi{قیامت کے دن اپنی قوم کے آگے ہو گا پھر انہیں آگ میں لاڈالے گا اوربرا گھاٹ ہے جس پر وہ پہنچے\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mdlxxii{اور اپنے پیچھے اس جہان میں بھی لعنت چھوڑ گئے اور قیامت کے دن کے لیے بھی برا ہی انعام ہے جو انہیں دیا جائے گا\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mdlxxiii{یہ بستیوں کے تھوڑے سے حالات ہیں کہ تجھے سنا رہے ہیں ان میں سے کچھ تو اب تک باقی ہیں اورکچھ اجڑی پڑی ہیں\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mdlxxiv{اور ہم نے ان پر ظلم نہیں کیا لیکن وہی اپنی جانو ں پر ظلم کر گئے پھر ان کے وہ معبود کچھ کام نہ آئے جنہیں و ہ الله کے سوا پکارتے تھے جس وقت تیرے رب کا حکم آ پہنچا اور ان معبودوں نے سوا ہلاکت کے انہیں کچھ بھی فائدہ نہ دیا\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mdlxxv{اور تیرے رب کی پکڑ ایسی ہی ہوتی ہے جب وہ ظالم بستیوں کو پکڑتا ہے اور اس کی پکڑ سخت تکلیف دہ ہے\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mdlxxvi{اس بات میں نشانی ہے اس کے لیے جو آخرت کے عذاب سے ڈرتا ہے یہ ایک ایسا دن ہوگا جس میں سب لوگ جمع ہوں گے اور یہی دن ہے جس میں سب حاضر کیے جائیں گے\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mdlxxvii{اور ہم اسے تھوڑی مدت کے لیے ملتوی کیے ہوئے ہیں\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mdlxxviii{جب وہ دن آئے گا تو کوئی شخص الله کی اجازت کے سوا بات بھی نہ کر سکے گا سو ان میں سے بعض بدبخت ہیں اوربعض نیک بخت\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mdlxxix{پھر جو بد ہوں گےتو وہ آگ میں ہوں گے کہ اس میں ان کی چیخ و پکار پڑی رہے گی\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mdlxxx{اس میں ہمیشہ رہیں گے جب تک آسمان زمین قائم ہیں ہاں اگر تیرے الله ہی کو منظور ہو (تو دوسری بات ہے) بے شک تیار رب جو چاہے اسے پورےطور سے کر سکتا ہے\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mdlxxxi{اور جو لوگ نیک بخت ہیں سو جنت میں ہو ں گے اس میں ہمیشہ رہیں گے جب تک آسمان زمین قائم ہیں ہاں اگر تیرے الله ہی کو منظور ہو تو (دوسری بات ہے) یہ بے انتہا عطیہ ہو گا\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mdlxxxii{سو تو ان چیزوں سے شک میں نہ رہ جنہیں یہ پوجتے ہیں یہ لوگ کچھ نہیں پوجتے مگر اسی طرح سے کہ جس طرح ان سے پہلے ان کے باپ دادا پوجتے تھے اور بے شک ہم انہیں عذاب کا پورا حصہ دے کر رہیں گے\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mdlxxxiii{اور البتہ ہم نے موسیٰ کو کتاب دی تھی پھراس میں اختلاف کیا گیا اور اگر تیرے رب کی طرف سے ایک بات مقرر نہ ہو چکی ہوتی تو ان میں فیصلہ ہو جاتا اور بے شک اس کی طرف سے ایسے شک میں ہیں کہ مطمئن نہیں ہو نے دیتا\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mdlxxxiv{اورجتنے لوگ ہیں جب وقت آیا تیرا رب انہیں ان کے اعمال پورے دے گا بےشک وہ خبردار ہے اس چیز سے جو کر رہے ہیں\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mdlxxxv{سو تو پکا رجیسا تجھے حکم دیا گیا ہے اور جنہوں نے تیرے ساتھ توبہ کی ہے اور حد سے نہ بڑھو بے شک وہ دیکھتا ہے جو کچھ تم کرتے ہو\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@mdlxxxvi{اوران کی طرف مت جھکو جو ظالم ہیں پھر تمہیں بھی آگ چھوئے گی اور الله کے سوا تمہارا کوئی مددگار نہیں ہے پھر کہیں سے مدد نہ پاؤ گے\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@mdlxxxvii{اور دن کے دونو ں طرف اورکچھ حصہ رات کا نماز قائم کر بے شک نیکیاں برائیوں کو دور کرتی ہیں یہ نصیحت حاصل کرنے والوں کے لیے نصیحت ہے\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@mdlxxxviii{اور صبر کر بے شک الله نیکی کرنے والوں کا اجر ضائع نہیں کرتا\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@mdlxxxix{سو ان جماعتوں میں ایسے لوگ کیوں نہ ہوئے جو تم سے پہلے تھیں جو ملک میں فساد پھیلانے سے منع کرتے بجز چند آدمیوں کے جنہیں ہم نے ان میں سے بچا لیا تھا اور جن لوگو ں نے نافرمانی کی تھی وہ تو انہیں لذتوں کے پیچھے پڑے رہے جو ان کو دی گئی تھیں اور وہ مجرم تھے\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@mdxc{اور تیرا رب ہرگز ایسا نہیں جو بستیوں کو زبردستی ہلاک کر دے اور وہاں کے لوگ نیک ہوں\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@mdxci{اور اگر تیرا رب چاہتا تو سب لوگو ں کو ایک رستہ پر ڈال دیتا اور ہمیشہ اختلاف میں رہیں گے\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@mdxcii{مگر جس پر تیرے رب نے رحم کیا اور اسی لیے انہیں پیدا کیا ہے اور تیرے رب کی یہ بات پوری ہو کر رہے گی کہ البتہ دوزخ کو اکھٹے جنوں اور آدمیوں سے بھر دوں گا\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@mdxciii{اور ہم رسولوں کے حالات تیرے پاس اس لیے بیان کرتے ہیں کہ ان سے تیرے دل کو مضبوط کر دیں اور ان واقعات میں تیرے پاس حق بات پہنچ جائے گی اور ایمانداروں کے لیے نصیحت اور یاد دہانی ہے\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@mdxciv{اوران سے کہہ دو جو ایمان نہیں لاتے اپنے جگہ پر کام کیے جاؤ ہم بھی کام کرتے ہیں\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@mdxcv{اور انتظار کرو ہم بھی منتظر ہیں\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@mdxcvi{اور آسمانوں اور زمین کی پوشیدہ بات الله ہی جانتا ہے اور سب کام کا رجوع اسی کی طرف ہے پس اسی کی عبادت کرو اور اسی پر بھروسہ رکھ اور تیرا رب بے خبر نہیں اس سے جو کرتے ہو\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@mdxcvii{\basmalahur یہ روشن کتاب کی آیتیں ہیں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mdxcviii{ہم نے اس قرآن کو عربی زبان میں تمہارے سمجھنے کے لیے نازل کیا\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mdxcix{ہم تیرے پاس بہت اچھا قصہ بیان کرتے ہیں اس واسطے کہ ہم نے تیری طرف یہ قرآن بھیجا ہے اور تو اس سے پہلے البتہ بے خبروں میں سے تھا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mdc{جس وقت یوسف نے اپنے باپ سے کہا اے باپ میں گیارہ ستاروں اور سورج اور چاند کو خواب میں دیکھا کہ وہ مجھے سجدہ کر رہے ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mdci{کہا اے بیٹا اپنا خواب بھائیوں کے سامنے بیان مت کرنا وہ تیرے لیے کوئی نہ کوئی فریب بنا دیں گے شیطان انسان کا صریح دشمن ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mdcii{اوراسی طرح تیرا رب تجھے برگزیدہ کرے گا اور تجھےخواب کی تعبیر سکھائے گا اور اپنی نعمتیں تجھ پر اور یعقوب کے گھرانے پر پوری کرے گا جس طرح کہ اس سے پہلے تیرے باپ دادا ابراھیم اور اسحاق پر پوری کر چکا ہےبے شک تیرا رب جاننے والا حکمت والا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mdciii{البتہ یوسف اور اس کے بھائیوں کے قصہ میں پوچھنے والو ں کے لیے نشانیاں ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mdciv{جب انہوں نے کہا البتہ یوسف اور اس کا بھائی ہمارے باپ کو ہم سے زیادہ پیارا ہے حالانکہ ہم طاقتور جماعت ہیں بے شک ہمارا باپ صریح غلطی پر ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mdcv{یوسف کو مار ڈالو یا کسی ملک میں پھینک دو تاکہ باپ کی توجہ اکیلے تم پر رہے اور اس کے بعد نیک آدمی ہو جانا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mdcvi{ان میں سے ایک کہنے والے نے کہا کہ یوسف کو قتل نہ کرواور اسے گمنام کنوئیں میں ڈال دو کہ اسے کوئی مسافر اٹھا لے جائے اگر تم کرنے ہی والے ہو\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mdcvii{انہوں نے کہااےباپ کیا بات ہے کہ تو یوسف پر ہمارا اعتبار نہیں کرتا اور ہم تو اس کے خیر خواہ ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mdcviii{کل اسے ہمارے ساتھ بھیج دے کہ وہ کھائے اور کھیلے اوربےشک ہم ا سکے نگہبان ہیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mdcix{اس نے کہا مجھے اس سے غم ہوتا ہے کہ تم اسے لے جاؤ اور اس سے ڈرتا ہوں کہ اسے بھیڑیا کھا جائے اورتم اس سے بے خبر رہو\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mdcx{انہوں نے کہا اگر اسے بھیڑیا کھا گیا اور ہم ایک طاقتور جماعت ہیں بے شک ہم اس وقت البتہ نقصان اٹھانے والے ہوں گے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mdcxi{جب اسے لے کر چلے اور متفق ہوئے کہ اسے گمنام کنوئیں میں ڈالیں تو ہم نے یوسف کی طرف وحی بھیجی کہ تو ضرور انہیں ایک دن آگاہ کرے گا ان کے اس کام سے اور وہ تجھے نہ پہچانیں گے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mdcxii{اور کچھ رات گئی اپنےباپ کے پاس روتے ہوئے آئے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mdcxiii{کہا اے ہمارے باپ ہم تو آپس میں دوڑنے میں مصروف ہوئے اور یوسف کو اپنے اسباب کے پاس چھوڑ گئے تب اسے بھیڑیا کھا گیا او رتو ہمارے کہنے پر یقین نہیں کرے گا اگرچہ ہم سچےہی ہوں\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mdcxiv{اور اسی کے کرتے پر جھوٹ موٹ کا خون بھی لگا لائے اس نے کہا نہیں بلکہ تم نے دل سے ایک بات بنائی ہے اب صبر ہی بہتر ہے اورالله ہی سے مدد مانگتا ہوں اس بات پر جو تم بیان کر تے ہو\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mdcxv{اور ایک قافلہ آیا پھر انہوں نے اپنا پانی بھرنے والا بھیجا اس نے اپنا ڈول لٹکایا کہا کیا خوشی کی بات ہے یہ ایک لڑکا ہے اور اسے تجارت کا مال سمجھ کر چھپا لیا اور الله خوب جانتا ہے جو کچھ وہ کر رہے تھے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mdcxvi{اسے بھائی ناقص قیمت پر بیچ آئے گنتی کی چونیوں پر اور اس سے بیزار ہو رہے تھے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mdcxvii{اور جس نے اسے مصر میں خرید کیا اس نے اپنی عورت سے کہا اس کی عزت کر شاید ہمارے کام آئے یا ہم اسے بیٹا بنا لیں اس طرح ہم نے یوسف کو اس ملک میں جگہ دی اور تاکہ ہم اسے خواب کی تعبیر سکھائیں اور الله اپنا کام جیت کر رہتا ہے لیکن اکثر لوگ نہیں جانتے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mdcxviii{اور جب اپنی جوانی کو پہنچا تو ہم نے اسے حکم اور علم دیا اور نیکوں کو ایسا ہی بدلہ دیتے ہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mdcxix{اورجس عورت کے گھر میں تھا وہ اسے پھسلا نے لگی اور دروازے بند کر لیے اور کہنے لگی لو آؤ اس نے کہا الله کی پناہ وہ تو میرا آقا ہے جس نے مجھے عزت سے رکھا ہے بے شک ظالم نجات نہیں پاتے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mdcxx{اور البتہ اس عورت نے تو اس پر ارادہ کر لیا تھا اور اگر وہ اپنے رب کی دلیل نہ دیکھ لیتا تو اس کا اردہ کر لیتا اسی طرح ہوا تاکہ ہم اس سے برائی اور بے حیائی کو ٹال دیں بے شک وہ ہمارے چنے ہوئے بندوں میں سے تھا\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mdcxxi{اور دونوں دروازے کی طرف دوڑے اور عورت نے اس کا کرتہ پیچھے سےپھاڑ ڈالا اور دونوں نے عور ت کے خاوند کو دروازے کے پاس پایا کہنے لگی کہ جو تیرے گھر کے لوگوں سے برااردہ کرے اس کی تو یہی سزا ہے کہ قید کیا جائے یا سخت سزا دی جائے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mdcxxii{کہا یہی مجھ سے اپنا مطلب نکالنے کو پھسلاتی تھی اور عورت کے گھر والوں میں سے ایک گواہ نے گواہی دی اگر اس کا کرتہ آگے سے پھٹا ہوا ہے تو عورت سچی ہے اور وہ جھوٹا ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mdcxxiii{اور اگر اس کا کرتہ پیچھے سے پھٹاہوا ہے تو یہ جھوٹی ہے اور وہ سچا ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mdcxxiv{پھر جب عزیز نے اس کا کرتہ پیچھے سے پھٹا ہوا دیکھا کہابے شک یہ تم عورتوں کا ایک فریب ہے بے شک تمہارا فریب بڑا ہوتا ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mdcxxv{یوسف تو اس سے درگزر کر اور تو اے عورت اپنے گنا ہ کی معافی مانگ کیوں کہ تو ہی خطا کار ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mdcxxvi{اورعوتوں نے شہر میں چرچا کیا کہ عزیز کی عورت اپنے غلام کو چاہتی ہے بے شک اس کی محبت میں فریفتہ ہوگئی ہے ہم تو اسے صریح غلطی پر دیکھتے ہیں\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mdcxxvii{پھر جب عزیز کی بیوی نے ان کی ملامت سنی تو انہیں بھلا بھیجا اور ان کے واسطے ایک مجلس تیار کی اور ان میں سے ہر ایک کے ہاتھ میں ایک چھری دی اور کہا ان کے سامنے نکل آ پھر جب انہوں نےاسے دیکھا تو حیرت میں رہ گئیں اور اپنے ہاتھ کاٹ لیے اور کہا الله پاک ہے یہ انسان تو نہیں ہے یہ تو کوئی بزرگ فرشتہ ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mdcxxviii{کہا یہی وہ ہے کہ جس کے معاملہ میں تم نے مجھےملامت کی تھی اور البتہ تحقیق میں نے اس سے دلی خواہش ظاہر کی تھی پھر اس نے اپنے آپ کو روک لیا اور اگر وہ میرا کہنا نہ مانے گا تو ضرور قید کر دیا جائے گا اور ذلیل ہو کررہے گا\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mdcxxix{یوسف نے کہا اے میرے رب میرے لیے قید حانہ بہتر ہے اس کام سے کہ جس کی طرف مجھے بلا رہی ہیں اوراگر تو مجھ سے ان کا فریب دفع نہ کرے گا تو ان کی طرف مائل ہوجاؤں گا اور جاہلوں میں سے ہو جاؤں گا\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mdcxxx{پھر اس کے رب نے اس کی دعا قبول کی پس ان کا فریب ان سے دور کر دیا گیا کیوں کہ وہی سننے والا جاننے والا ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mdcxxxi{ان لوگو ں کو نشانیاں دیکھنے کے بعد یوں سمجھ میں آیا کہ اسے ایک مدت تک قید کر دیں\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mdcxxxii{اور اس کے ساتھ دو جوان قید خانہ میں داخل ہوئے ان میں سے ایک نے کہا میں دیکھتا ہوں کہ شراب نچوڑتا ہوں اور دوسرے نے کہا میں دیکھتا ہوں کہ اپنے سر پر روٹی اٹھا رہا ہوں کہ اس میں سے جانور کھاتے ہیں ہمیں اس کی تعبیر بتلا ہم تجھے نیکو کار سمجھتے ہیں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mdcxxxiii{کہا جو کھانا تمہیں دیا جاتا ہے وہ ابھی آنے نہ پائے گا کہ اس سے پہلے میں تمہیں اس کی تعبیر بتلا دوں گا یہ ان چیزو ں سے ہے جو میرے رب نے مجھے سکھائی ہیں بے شک میں نے اس قوم کا مذہب ترک کر دیا ہے جو الله پرایمان نہیں لاتی اور وہ آخرت کے بھی منکر ہیں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mdcxxxiv{اور میں اپنے باپ دادا ابراھیم اور اسحاق اور یعقوب کے مذہب کا تابع ہو گیا ہوں ہمیں یہ جائز نہیں کی اللہ کے ساتھ کسی کو بھی شریک کریں یہ ہم پر اور سب لوگوں پر اللہ کا فضل ہے لیکن بہت لوگ شکر نہیں کرتے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mdcxxxv{اے قید خانہ کے رفیقو کیا کئی جدا جدا معبود بہتر ہیں یا اکیلا الله جو زبردست ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mdcxxxvi{تم اس کے سوا کچھ نہیں پوجتے مگر چند ناموں کو جو تم نے اور تمہارے باپ داداؤں نے مقرر کر لیے ہیں الله نے ان کے متعلق کوئی سند نہیں اتاری حکومت سوا الله کے کسی کی نہیں ہے اس نے حکم دیا ہے کہ اس کے سوا کسی کی عبادت نہ کرو یہی سیدھا راستہ ہے لیکن اکثر آدمی نہیں جانتے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mdcxxxvii{اے قید خانہ کے رفیقو تم دونوں میں سے ایک جو ہے وہ اپنے آقا کو شراب پلائے گا جو دوسرا ہے وہ سولی دیا جائے گا پھر اس کے سر میں سے پرندے کھائیں گے اس کام کا فیصلہ ہو گیا ہے جس کی تم تحقیق چاہتے تھے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mdcxxxviii{اوران دونو ں میں سے جسے شیطان نے اسے اپنے آقا سے ذکر کرنا بھلا دیا پھر قید میں کئی برس رہا\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mdcxxxix{اور بادشاہ نے کہا میں خواب دیکھتا ہوں کہ سات موٹی گائیں ہیں انہیں سات دبلی گائی ں کھاتی ہیں اور سات سبز خوشے ہیں اور سات خشک اے دربار والو مجھے میرے خواب کی تعبیر بتلاؤ اگر تم خواب کی تعبیر دینے والے ہو\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mdcxl{انہوں نے کہا یہ خیالی خواب ہیں اور ہم ایسے خوابوں کی تعبیر نہیں جانتے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mdcxli{اور وہ بولا جو ان دونو ں میں سے بچا تھا اور اسے مدت کے بعد یاد آ گیا میں تمہیں اس کی تعبیر بتلاؤں گا سو تم مجھے بھیج دو\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mdcxlii{اے یوسف اے سچے ہمیں اس کی تعبیر بتلا کہ سات موٹی گایوں کو سات دبلی کھا رہی ہیں اور سات سبز خوشےہیں اور سات خشک تاکہ میں لوگو ں کے پاس لے جاؤں شاید وہ سمجھ جائیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mdcxliii{کہا تم سات برس لگاتار کھیتی کرو گے پھر جو کاٹو تو اسے اس کے خوشوں میں رہن ے دو مگر تھوڑا سا جو تم کھاؤ\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mdcxliv{پھر اس کے بعد سات برس سختی کے آئيں گے جو تم نے ان کے لیے رکھا تھا کھا جائیں گے مگر تھوڑا سا جوتم بیج کے واسطے روک رکھو گے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mdcxlv{پھر اس کے بعد ایک سال آئے گا اس میں لوگوں پر مینہ برسے گا اسمیں رس نچوڑیں گے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mdcxlvi{اور بادشاہ نے کہا اسے میرے پاس لے آؤ پھر جب اس کے پاس قاصد پہنچا کہا اپنے آقا کے ہاں واپس جا اور اس سے پوچھ ان عورتوں کا کیا حال ہے جنہوں نے اپنے ہاتھ کاٹے تھے بے شک میرا رب ان کے فریب سے خوب واقف ہے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mdcxlvii{کہاتمہارا کیا واقعہ تھا جب تم نے یوسف کو پھسلایا تھا انہوں نے کہا الله پاک ہے ہمیں اس میں کوئی برائی معلوم نہیں ہوئی عزیز کی عورت بولی اب سچی بات ظاہر ہو گئی میں نے ہی اسے پھسلانا چاہا تھا اور وہ سچا ہے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mdcxlviii{یہ اس لیے کیا تاکہ عزیز معلوم کر لے کہ میں نے اس کی غائبانہ خیانت نہیں کی تھی اوربے شک الله خیانت کرنے والوں کے فریب کو چلنے نہیں دیتا\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mdcxlix{اور میں اپنے نفس کو پاک نہیں کہتا بے شک نفس تو برائی سکھاتاہے مگر جس پرمیرا رب مہربانی کرے بے شک میرا رب بخشنے والا مہربان ہے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mdcl{اور بادشاہ نے کہا کہ اسے میرے پاس لے آؤ تاکہ اسے خاص اپنے پاس رکھوں پھر جب اس سے بات چیت کی کہا بے شک تو آج سے ہمارے ہاں تو بڑا معزز اور معتبر ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mdcli{کہا مجھے ملکی خزانوں پر مامور کر دو بے شک میں خوب حفاظت کرنے والا جاننے والا ہوں\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mdclii{اور ہم نے اس طور پر یوسف کو اس ملک میں بااختیار بنا دیا کہ اس میں جہاں چاہے رہےہم جس پر چاہیں اپنی رحمت متوجہ کر دیں اور ہم نیکی کرنے والوں کا اجر ضائع نہیں کرتے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mdcliii{اور آخرت کا ثواب ان کے لیے بہتر ہے جو ایمان لائے اور پرہیزگاری میں رہے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mdcliv{اور یوسف کے بھائی آئے پھر اس کے ہاں داخل ہوئے تواس نے انہیں پہچان لیا اور وہ پہچان نہیں سکے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mdclv{اور جب انہیں ان کا سامان تیار کر دیا کہا میرے پاس وہ بھائی بھی لے آنا جو تمہارے باپ کی طرف سے ہے تم نہیں دیکھتے میں ناپ پورا دیتا ہوں اوربڑا مہمان نواز ہوں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mdclvi{پھر اگر تم اسے میرے پاس نہ لائے تو نہ تمہیں میرے ہاں سے پیمانہ ملے گا اور نہ تم میرے پاس آنا\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mdclvii{انہوں نے کہا اس کے باپ سے خواہش کریں گے اور ہم یہ کر کے ہی رہیں گے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mdclviii{اور اپنے خدمتگاروں سے کہہ دیا کہ ان کی پونجی ان کے اسباب میں رکھ دو تاکہ وہ اسے پہچانیں جب وہ لوٹ کر اپنےگھر جائیں شاید وہ پھر آجائیں\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mdclix{پھر جب اپنے باپ کے ہاں پہنچے کہا اے باپ! ہمارا پیمانہ روک لیا گیا پس آپ ہمارے ساتھ ہمارے بھائی کو بھیج دیجیئے کہ ہم پیمانہ لائیں اور بے شک ہم اس کا نگہبان ہیں\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mdclx{کہا میں تمہارا اس پرکیا اعتبارکروں مگر وہی جیسا اس سے پہلے اس کے بھائی پر اعتبار کیا تھا سو الله بہتر نگہبان ہے اور وہ سب مہربانوں سے مہربان ہے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mdclxi{اورجب انہوں نے اپنا اسباب کھولا انہوں نے اپنی پونجی پائی جو انہیں واپس کر دی گئی تھی کہا اے ہمارے باپ! ہمیں اور کیا چاہیئے یہ ہماری پونجی ہمیں واپس کر دی گئی ہے اور اپنے گھر والوں کے لیے غلہ لائیں گے او راپنے بھائی کی حفاظت کریں گے اور ایک اونٹ کا بوجھ اور زیادہ لائیں گے اور یہ بوجھ ملنا آسان ہے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mdclxii{کہا اسے ہرگز تمہارے ساتھ نہیں بھیجوں گا یہاں تک کہ مجھے الله کا عہد دو کہ البتہ اسے میرے ہاں ضرور پہنچا دویں گے مگر یہ کہ تم سب گھر جاؤ پھر جب سب نے اسے عہد دیا کہا ہماری باتوں کا الله شاہد ہے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mdclxiii{اور کہا اے میرے بیٹو! ایک دروازے سے داخل نہ ہونا اور مختلف دروازوں سے داخل ہونا اور میں تمہیں الله کی کیسی بات سے بچا نہیں سکتا الله کے سوا کسی کا حکم نہیں ہے اسی پر میرا بھروسہ ہے اوربھروسہ کرنے والوں کو اسی پر بھروسہ کرنا چاہئے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mdclxiv{اور جب کہ اسی طرح داخل ہوئے جس طرح ان کے باپ نے حکم دیا تھا انہیں الله کی کسی بات سے کچھ نہ بچا سکتا تھا مگر یعقوب کے دل میں ایک خواہش تھی جسے اس نے پورا کیا اور وہ تو ہمارے سکھلانے سے علم والا تھا لیکن اکثر آدمی نہیں جانتے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mdclxv{اور جب وہ یوسف کے پاس گئے تو اس نے اپنے بھائی کو اپنے پاس جگہ دی کہا کہ بے شک میں تیرا بھائی ہوں پس جو کچھ یہ کرتے رہے ہیں اس پر غم نہ کر\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mdclxvi{پھر جب یوسف نے اس کا سامان تیار کر دیا تو اپنے بھائی کے اسباب میں کٹورا رکھ دیا پھر پکارے نے والے نے پکارا اے قافلہ والو! بے شک تم البتہ چور ہو\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mdclxvii{اس کی طرف متوجہ ہو کر کہنے لگے تمہاری کیا چیز گم ہوگئی ہے\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mdclxviii{انہوں نے کہا ہمیں بادشاہ کا کٹورا نہیں ملتا جو اسے لا ئےگا ایک اونٹ بھر کا غلہ پائے گا اور میں اس کا ضامن ہوں\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mdclxix{انہوں نے کہا الله کی قسم تمہیں معلوم ہے ہم اس ملک میں شرارت کرنے کے لیے نہیں آئے اور نہ ہم کبھی چور تھے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mdclxx{انہوں نے کہا پھر اس کی کیا سزا ہے اگر تم جھوٹے نکلو\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mdclxxi{انہوں نے کہا اس کی سزا یہ ہے کہ جس کےاسباب میں سے پایا جائے پس وہی اس کے بدلہ میں جائے ہم ظالموں کو یہی سزا دیتے ہیں\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mdclxxii{پھر یوسف نے اپنے بھائی کے اسباب سے پہلےان کے اسباب دیکھنے شروع کیے پھر وہ کٹورا اپنے بھائی کے اسباب سے نکالا ہم نے یوسف کو ایسی تدبیر بتائی تھی بادشاہ کے قانون سے تو وہ اپنے بھائی کو ہرگز نہ لے سکتا تھا مگر یہ کہ الله چاہے ہم جس کے چاہیں درجے بلند کرتے ہیں اور ہر ایک دانا سے بڑھ کر دوسرا دانا ہے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mdclxxiii{انہوں نے کہا اگر اس نے چوری کی ہے تو اس سے پہلے اس کے بھائی نے بھی چوری کی تھی تب یوسف نے اپنے دل میں آہستہ سے کہا اور انہیں نہیں جتایا کہا تم درجے میں بدتر ہو اور الله خوب جانتا ہے جو کچھ تم بیان کرتے ہو\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mdclxxiv{انہوں نے کہا اے عزیز! بے شک اس کا باپ بوڑھا بڑی عمر کا ہے سو اسکی جگہ ہم میں سے ایک کو رکھ لے ہم تم کو احسان کرنے والا دیکھتے ہیں\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mdclxxv{کہا الله کی پناہ کہ ہم بجز اس کے جس کے پاس اپنا اسباب پایا کسی اور کو پکڑیں تب تو ہم بڑے ظالم ہیں\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mdclxxvi{پھر جب اس سےناامید ہوئے مشورہ کرنے کے لیے اکیلے ہو بیٹھے ان میں سے بڑے نے کہا کیا تمہیں معلوم نہیں کہ تمہارے باپ نے تم سے الله کا عہد لیا تھا اور پہلے جویوسف کے حق میں قصور کر چکے ہو سو میں تو اس ملک سے ہرگز نہیں جاؤں گا یہاں تک کہ میرا با پ مجھے حکم دے یا میرے لیے الله کوئی حکم فرمائے اور وہ بہتر فیصلہ کرنے والا ہے\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mdclxxvii{تم اپنے باپ کے پاس لوٹ جاؤ اور کہو اے ہمارے باپ! تیرے بیٹے نے چوری کی اور ہم نے وہی کہا تھا جس کا ہمیں علم تھا اور ہمیں غیب کی خبر نہ تھی\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mdclxxviii{اوراس گاؤں سے پوچھ لیجیئے جس میں ہم تھے اور اس قافلہ سے بھی جس میں ہم آئے ہیں اور بے شک ہم سچے ہیں\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mdclxxix{کہا بلکہ تم نے دل سے ایک بات بنا لی ہے اب صبر ہی بہتر ہے الله سے امید ہے کہ شاید الله ان سب کو میرے پاس لے آئے وہی جاننے والا حکمت والا ہے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mdclxxx{اور اس نے ان سے منہ پھیر لیا اور کہا ہائے یوسف! اور غم سے اس کی آنکھیں سفید ہو گئیں پس وہ سخت غمگین ہوا\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mdclxxxi{انہوں نے کہا الله کی قسم تو یوسف کی یاد کو نہیں چھوڑے گا یہاں تک کہ نکما ہو جائے یا ہلاک ہوجائے\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mdclxxxii{کہا میں تو اپنی پریشانی اور غم کا اظہار الله ہی کے سامنے کرتا ہوں اور الله کی طرف سے میں وہ جانتا ہوں جو تم نہیں جانتے\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mdclxxxiii{اے میرے بیٹو! جاؤ یوسف اور اس کے بھائی کی تلاش کرو اور الله کی رحمت سے نا امید نہ ہو بے شک الله کی رحمت سے نا امید نہیں ہوتے مگر وہی لوگ جو کافر ہیں\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mdclxxxiv{پھر جب وہ ان کے پاس آئے تو کہا اے عزیز! ہمیں اور ہمارے گھر والوں کو قحط کی وجہ سے بڑی تکلیف ہے اور کچھ نکمی چیز لائے ہیں سو آپ پورا غلہ بھر دیجیئے اورخیرات دیجئے بے شک الله خیرات دینے والوں کو ثواب دیتا ہے\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mdclxxxv{کہا تمہیں یاد ہے جو کچھ تم نے یوسف اور اس کے بھائی کے ساتھ کیا تھا جب تمہیں سمجھ نہ تھی\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mdclxxxvi{کہا کیا تو ہی یوسف ہے کہا میں ہی یوسف ہوں اور یہ میرا بھائی ہے الله نے ہم پر احسان کیابے شک جو ڈرتا ہے اور صبر کتا ہے تو الله بھی نیکوں کا اجر ضائع نہیں کرتا\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mdclxxxvii{انہوں نے کہا الله کی قسم البتہ تحقیق الله نے تمہیں ہم پر بزرگی دی اوربے شک ہم غلط کار تھے\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mdclxxxviii{کہا آج تم پر کوئی الزام نہیں الله تمہیں بخشے اور وہ سب سے زیادہ مہربان ہے\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mdclxxxix{یہ کرتہ میرا لے جاؤ اور اسے میرے باپ کے منہ پر ڈال دو کہ وہ بینا ہوجائے اور میرے پاس اپنے سب کنبے کو لے آؤ\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mdcxc{اور جب قافلہ روانہ ہوا تو ان کے باپ نے کہا بے شک میں یوسف کی بو پاتا ہوں اگر مجھے دیوانہ نہ بناؤ\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mdcxci{لوگو ں نے کہا الله کی قسم بے شک تو البتہ اپنی گمراہی میں مبتلا ہے\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mdcxcii{پھر جب خوشخبری دینے والا آیا اس نے وہ کرتہ اس کے منہ پر ڈال دیا تو بینا ہو گیا کہا میں نے تمہیں نہیں کہا تھا کہ میں الله کی طرف سے وہ جانتا ہوں جو تم نہیں جانتے\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mdcxciii{انہوں نے کہا اے ہمارے باپ! ہمارے گناہ بحشوا دیجیئے بے شک ہم ہی غلط کار تھے\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mdcxciv{کہا عنقریب اپنے رب سے تمہارے لی معافی مانگوں گا بے شک وہ غفور رحیم ہے\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mdcxcv{پھر جب یوسف کے پاس آئے تو اس نے اپنے ماں باپ کو اپنے پاس جگہ دی اور کہا مصر میں داخل ہو جاؤ اگر الله نے چاہا تو امن سے رہو گے\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mdcxcvi{اور اپنے ماں باپ کو تخت پر اونچا بٹھایا اور اس کے آگے سب سجدہ میں گر پڑے اور کہا اےباپ میرے اس پہلے خواب کی یہ تعبیر ہے اسے میرے رب نے سچ کر دکھایا اوراس نے مجھ پر احسان کیا جب مجھے قید خانے سے نکالا اور تمہیں گاؤں سے لے آیا اس کے بعد کہ شیطان مجھ میں اورمیرے بھائیوں میں جھگڑا ڈال چکا بے شک میرا رب جس کے لیے چاہتا ہے مہربانی فرماتا ہے بے شک وہی جاننے والا حکمت والا ہے\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mdcxcvii{اے میرے رب تو نے مجھےکچھ حکومت دی ہے اور مجھے خوابوں کی تعبیر کا علم بھی سکھلایا ہے اے آسمانو ں اور زمین کے بنانے والے! دنیا اور آخرت میں تو ہی میرا کارساز ہے تو مجھے اسلام پر موت دے اور مجھے نیک بختوں میں شامل کر دے\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mdcxcviii{یہ غیب کی خبریں کہیں جو ہم تیرے ہاں بھیجتے ہیں اور تو ان کے پاس نہیں تھا جب کہ انہوں نے اپنا ارادہ پکا کر لیا اور وہ تدبیریں کر رہے تھے\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mdcxcix{اور اکثر لوگ ایمان لانے والے نہیں خواہ تو کتنا ہی چاہے\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mdcc{اور آپ اس پر ان سے کوئی مزدوری بھی تو نہیں مانگتے یہ تو صرف تمام جہانوں کے لیے نصیحت ہے\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mdcci{اور آسمانوں اور زمین میں بہتی سی نشانیاں ہیں جن پر سے یہ گزرتے ہیں اوران سے منہ پھیر لیتے ہیں\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mdccii{اوران میں سے اکثر ایسے بھی ہیں جو الله کو مانتے بھی ہیں اور شرک بھی کرتے ہیں\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mdcciii{کیا اس سے بے خوف ہو چکے ہیں کہ انہیں الله کے عذاب کی ایک آفت آپہنچے یا اچانک قیامت ان پر آ جائے اور انہیں خبر بھی نہ ہو\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mdcciv{کہہ دو میرا اور میرے تابعداروں کا بصیرت کے ساتھ یہ راستہ ہے کہ میں لوگوں کو الله کی طرف بلا رہا ہوں اور الله پا ک ہے اور میں شرک کرنے والوں میں سے نہیں ہوں\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mdccv{ااور تجھ سے پہلے ہم نے جتنے پیغمبر بھیجے وہ سب بستیو ں کے رہنے و الے مرد ہی تھے ہم ان کی طرف وحی بھیجتے تھے پھر وہ زمین میں سیر کر کے کیوں نہیں دیکھتے کہ ان لوگو ں کا انجام کیا ہوا جوان سے پہلے تھے اور البتہ آخرت کا گھر پرہیز کرنے والوں کے لیے بہتر ہے پھر تم کیوں نہیں سمجھتے\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mdccvi{یہاں تک کہ جب رسول ناامید ہونے لگے اورخیال کیا کہ ان سے جھوٹ کہا گیا تھا تب انہیں ہماری مدد پہنچی پھر جنہیں ہم نے چاہا بچا لیا اور ہمارے عذاب کو نافرمانوں سے کوئی بھی روک نہیں سکتا\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mdccvii{البتہ ان لوگو ں کے حالات میں عقلمندوں کے لیے عبرت ہے کوئی بنائی ہوئی بات نہیں ہے بلکہ اس کلام کے موافق ہے جو اس سے پہلے ہے اور ہر چیز کا بیان اور ہدایت اور رحمت ان لوگوں کے لیے ہے جو ایمان لاتے ہیں\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mdccviii{\basmalahur یہ کتاب کی آیتیں ہیں اور جو کچھ تجھ پر تیرے رب سے اترا سوحق ہے اورلیکن اکثر آدمی ایمان نہیں لاتے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mdccix{الله وہ ہے جس نے آسمانوں کو ستونوں کے بغیر بلند کیا جنہیں تم دیکھ رہے ہو پھر عرش پر قائم ہوا اور سورج اور چاند کو کام پر لگا دیا ہر ایک اپنے وقت معین پر چل رہا ہے وہ ہر ایک کام کاانتظام کرتا ہے نشانیاں کھول کر بتاتا ہے تاکہ تم اپنے رب سے ملنے کا یقین کر لو\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mdccx{اور اسی نے زمین کو پھیلایا اور اس میں پہاڑاور دریا بنائے اور زمین میں ہر ایک پھل دوقسم کا بنایا دن کو رات سے چھپا دیتا ہے بے شک اس میں سوچنے والوں کے لیے نشانیاں ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mdccxi{اور زمین میں ٹکڑے ایک دوسرے سے ملے ہوئے ہیں اور انگور کے باغ ہیں اور کھیتیاں اور کھجوریں ہیں ایک کی جڑ ملی ہوئی بعض بن ملی انہیں پانی بھی ایک ہی دیا جاتا ہے اور ہم ایک کو دوسرے پر پھلوں میں فضیلت دیتے ہیں بے شک اسمیں عقل مندوں کے لیے بڑی نشانیاں ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mdccxii{اگر تو عجیب بات چاہے تو ان کا یہ کہنا عجب ہے کہ کیا جب ہم مٹی ہو گئے کیا نئے سرے سے بنائیں جائیں گے یہی وہ ہیں جو اپنے رب سے منکر ہو گئے اور انہیں کی گردنوں میں طوق ہوں گے اور یہی دوزخی ہیں و ہ اس میں ہمیشہ رہیں گے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mdccxiii{اور تجھ سے بھلائی سے پہلے برائی کو جلد مانگتے ہیں اور ان سے پہلے بہت سے عذاب سے گزر چکے ہیں اور بے شک تیرا رب لوگو ں کو باوجود ان کے ظلم کے معاف بھی کرتا ہے اور تیرے رب کا عذاب بھی سخت ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mdccxiv{اورکافر کہتے ہیں اس کے رب سے اس پر کوئی نشانی کیوں نہیں اتری تم تومحض ڈرانے والے ہوں اور ہر قوم کے لیے ایک رہبر ہوتا آیا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mdccxv{الله کو معلوم ہے کہ جو کچھ ہر مادہ اپنے پیٹ میں لیے ہوئے ہے اورجو کچھ پیٹ میں سکڑتا اور بڑھتا ہے اور اس کے ہاں ہر چیز کا اندازہ ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mdccxvi{پوشیدہ اور ظاہر کا جاننے والا ہے سب سے بڑا بلند مرتبہ ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mdccxvii{تم میں سے جو شخص کوئی بات چپکے سے کہے یا پکار کرکہے اور جو شخص رات میں کہیں چھپ جائے یا دن میں چلے پھرے یہ سب برابر ہیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mdccxviii{ہر شخص حفاظت کے لیے کچھ فرشتے ہیں اس کے آگے اورپیچھے الله کے حکم سے اس کی نگہبانی کرتے ہیں بے شک الله کسی قوم کی حالت نہیں بدلتا جب تک وہ خود اپنی حالت کو نہ بدلے اور جب الله کو کسی قوم کی برائی چاہتا ہے پھر اسے کوئی نہیں روک سکتا اور اس کے سوا ان کا کوئی مددگار نہیں ہو سکتا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mdccxix{وہی ہے جو تمہیں خوف یا امید دلانے کے لیے بجلی دکھاتا اور بھاری بادلوں کو اٹھاتا ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mdccxx{اور رعد ا سکی پاکی کے ساتھ ا سکی تعریف کرتا ہے اور سب فرشتے اس کے ڈر سے اور بجلیاں بھیجتا ہے پھر انہیں جس پر چاہتا ہے گرا دیتا ہے اور یہ تو الله کے بارے میں جھگڑتے ہیں حالانکہ وہ بڑی قوت والا ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mdccxxi{اسی کو پکارنا بجا ہے اوراس کے سوا جن لوگوں کو پکارتے ہیں وہ ان کے کچھ بھی کام نہیں آتے مگر جیسا کوئی پانی کی طرف اپنے دونوں ہاتھ پھیلائے کہ اس کے منہ میں آجائے حالانکہ وہ اس کے منہ تک نہیں پہنچتا اور کافروں کی جتنی پکار ہے سب گمراہی ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mdccxxii{اور چارو ناچار الله ہی کو آسمان والے اور زمین والے سجدہ کرتے ہیں اور ان کے سائے بھی صبح اور شام\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mdccxxiii{کہو آسمانوں اور زمین کا رب کون ہے کہہ دو الله کہو پھر کیا تم نے الله کے سوا ان چیزوں کو معبود نہیں بنا رکھا جو اپنے نفسوں کے نفع اور نقصان کےبھی مالک نہیں کہو کیا اندھا اور دیکھنے والا برابر ہوسکتا ہے یا کہیں اندھیرا اور روشنی برابر ہو سکتے ہیں کیا جنہیں انہوں نے الله کا شریک بنا رکھا ہے انہو ں نے بھی الله کی مخلوق جیسی کوئی مخلوق بنائی ہے پھر مخلوق ان کی نظر میں مشتبہ ہو گئی ہے پیدا کرنے والااللہ ہے اور وہ اکیلا زبردست ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mdccxxiv{اس نے آسمان سے پانی اتارا پھر اس سے اپنی مقدار میں نالے بہنے لگے پھر وہ سیلاب پھولا ہوا جھاگ اوپر لایا اور جس چیز کو آگ میں زیور یا کسی اور اسباب بنانے کے لیے پگھلاتے ہیں اس پر بھی ویسا ہی جھاگ ہوتا ہے الله حق اور باطل کی مثال بیان فرماتا ہے پھر جو جھاگ ہے وہ یونہی جاتا رہتا ہے اور جو لوگوں کو فائدہ دے وہ زمین میں ٹھیر جاتا ہے اسی طرح الله مثالیں بیان فرماتا ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mdccxxv{جنہو ں نے اپنے رب کا حکم مانا ان کے واسطے بھلائی ہے اور جنہوں نے اس کا حکم نہ مانا اگر ان کے پاس سارا ہو جو کچھ زمین میں ہے اور اس کے ساتھ اتنا ہی او رہو تو سب جرمانہ میں دینا قبول کریں گے ان لوگو ں کے لیے برا حساب ہے اور ان کا ٹھکانا دوزخ ہے اوروہ برا ٹھکانا ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mdccxxvi{بھلا جو شخص جانتا ہے کہ تیرے رب سے تجھ پر جو کچھ اترا ہے حق ہے اس کےبرابر ہو سکتا ہے جو اندھا ہے سمجھتے تو عقل والے ہی ہیں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mdccxxvii{وہ لوگ جو الله کے عہد کو پوراکرتے ہیں اور اس عہد کو نہیں توڑتے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mdccxxviii{اور وہ لوگ جو ملاتے ہیں جس کے ملانے کو الله نے فرمایا ہے اور اپنے رب سے ڈرتے ہیں اور برے حساب کا خوف رکھتے ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mdccxxix{وہ جنہوں نے اپنے رب کی رضا مندی کے لیے صبر کیا اور نماز قائم کی اور ہمارے دیئے ہوئے میں سے پوشیدہ اور ظاہر خرچ کیا اور برائی کے مقابلے میں بھلائی کرتے ہیں انہیں کے لیے آخرت کا گھر ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mdccxxx{ہمیشہ رہنے کے باغ جن میں وہ خود بھی رہیں گے اور ان کے باپ دادا اوربیویوں اور اولاد میں سے بھی جو نیکو کار ہیں اور ان کے پاس فرشتے ہر دروازے سے آئیں گے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mdccxxxi{کہیں گے تم پر سلامتی ہو تمہارے صبر کرنے کی وجہ سے پھر آخرت کا گھر کیا ہی اچھا ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mdccxxxii{اور جو لو گ الله کا عہد مضبوط کرنے کے بعد توڑ تے ہیں اور اس چیز کو توڑتے ہیں جسے الله نے جوڑنے کا حکم فرمایا اور ملک میں فساد کرتے ہیں ان کے لیے لعنت ہے اور ان کے لیے برا گھر ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mdccxxxiii{الله ہی جس کے لیے چاہتا ہے روزی فراخ اور تنگ کرتا ہے اور دنیا کی زندگی پر خوش ہیں اور دنیا کی زندگی آخرت کے مقابلے میں کچھ نہیں مگر تھوڑاسا اسباب\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mdccxxxiv{اور کافر کہتے ہیں اس پراس کے رب سے کوئی نشانی کیوں نہیں اتری کہہ دو الله جس کو چاہتا ہے گمراہ کر دیتاہے اور جو اس کی طرف رجوع کرتا ہے اسے اپنے تک پہنچنے کا راستہ دکھاتا ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mdccxxxv{وہ لوگ جو ایمان لائے اور ان کے دلوں کو الله کی یاد سے تسکین ہوتی ہے خبردار! الله کی یاد ہی سے دل تسکین پاتے ہیں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mdccxxxvi{جو لوگ ایمان لائے او راچھے کام کیے ان کے لیے خوشخبری اور اچھا ٹھکانا ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mdccxxxvii{اسی طرح ہم نے تجھےایک امت میں بھیجا ہے کہ اس سے پہلے کئی امتیں گزرچکی ہیں تاکہ تو انہیں سناد ے جو ہم نے تیری طرف حکم بھیجا ہے اور وہ تو رحمنٰ کے منکر ہیں کہہ دو وہی میرا رب ہے جس کے سوا کوئی معبود نہیں اسی پر میں نے بھروسہ کیا ہے اور اسی کی طرف میرا رجوع ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mdccxxxviii{اور اگر تحقیق کوئی ایسا قرآن نازل ہوتا جس سے پہاڑ چلتے یا اس سے زمین کے ٹکڑے ہو جاتے یا اس سے مردے بول اٹھتے (تب بھی نہ مانتے) بلکہ سب کام الله کے ہاتھ میں ہیں پھر کیا ایمان والے اس بات سے نا امید ہو گئے ہیں کہ اگر الله چاہتا تو سب آدمیوں کو ہدایت کر دیتا اور کافروں پر تو ہمیشہ ان کی بداعمالی سے کوئی نہ کوئی مصیبت آتی رہے گی یا وہ بلا ان کے گھر کے قریب نازل ہوگی یہاں تک کہ الله کا وعدہ پورا ہو بے شک الله اپنے وعدے کے خلاف نہیں کرتا\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mdccxxxix{اور تجھ سے پہلے کئی رسولوں سے ہنسی کی گئی ہے پھر میں نے کافروں کو مہلت دی پھر انہیں پکڑ لیا پھر ہمارا عذاب کیسا تھا\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mdccxl{بھلا جو ہر کسی کے سر پر لیے کھڑا ہے جو اس نے کیا ہے اور انہوں نے الله کے لیے شریک بنا رکھے ہیں کہہ دو ان کے نام بتلاؤ کیا الله کو وہ بات بتاتے ہو جسے وہ زمین میں نہیں جانتا یا اوپر ہی کی باتیں کرتے ہو بلکہ کافروں کے فریب انہیں بھلے معلوم کرائے گئے ہیں اور وہ راستہ سے روکے گئے ہیں اور جسے الله گمراہ کرے پھر اسے کوئی بھی ہدایت دینے والا نہیں ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mdccxli{ان کے لیے دنیا کی زندگی میں عذاب ہے اور البتہ آخرت کا عذاب تو بہت ہی سخت ہے اور انہیں الله سے بچانےوالا کوئی نہیں ہو گا\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mdccxlii{اس جنت کا حال جس کا پرہیزگاروں سے وعدہ کیا گیا ہے اس کے نیچے نہریں بہتی ہیں جس کے میوے اور سائے ہمیشہ رہیں گے یہ پرہیزگاروں کا انجام ہے اور کافروں کا انجام آگ ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mdccxliii{اور وہ لوگ جنہیں ہم نے کتاب دی ہے اس سےخوش ہوتے ہیں جو تجھ پر نازل ہوا اور جماعتوں میں سے بعض لوگ اس کی بعضی بات نہیں مانتے کہہ دو مجھے تو یہی حکم ہوا ہے کہ الله کی بندگی کروں اور اس کے ساتھ کسی کو شریک نہ کروں اس کی طرف بلاتا ہوں اور اسی کی طرف میرا ٹھکانا ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mdccxliv{اور اسی طرح ہم نے یہ کلام اتارا کتاب عربی زبان میں اور اگرتو ان کی خواہش کے مطابق چلے بعد اس علم کے جو تجھے پہنچ چکا ہے تیرا الله سے کوئی حمایتی اور بچانے والا نہ ہوگا\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mdccxlv{او رالبتہ تحقیق ہم نے تجھ سے پہلے کئی رسول بھیجے اور ہم نے انہیں بیویاں اور اولاد بھی دی تھی اور کسی رسول کے اختیار میں نہ تھا کہ وہ الله کے حکم کے سوا کوئی معجزہ لاتا ہر زمانے کے مناسب احکام ہوتے ہیں\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mdccxlvi{الله جو چاہے موقوف کر دیتا ہے اور باقی رکھتا ہے اور اسی کے پاس اصل کتاب ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mdccxlvii{اور اگر ہم تجھے کوئی وعدہ دکھا دیں جو ہم نے ان سے کیا ہے یا تجھے اٹھا لیں سوتیرے ذمہ تو پہنچا دینا ہے اور ہمارے ذمہ حساب لینا ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mdccxlviii{کیا وہ نہیں دیکھتے کہ ہم زمین کو اس کے کناروں سے گھٹاتے چلے آتے ہیں اور الله حکم کرتاہے کوئی اس کے حکم کو ہٹا نہیں سکتا اور وہ جلد حساب لینے والا ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mdccxlix{اور ان سے پہلےلوگ بھی تدبیریں کر چکے ہیں سو اصل تدبیر تو الله ہی کی ہےجو کچھ کوئی کرتا ہے اسے سب خبر رہتی ہے اورابھی کافروں کو معلوم ہو جائے گا کہ نیک انجام کس کا ہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mdccl{اور کہتے ہیں کہ تو رسول نہیں ہے کہہ دو میرے اور تمہارے درمیان الله گواہ کافی ہے اور وہ شخص جس کے پاس کتاب کا علم ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mdccli{\basmalahur یہ ایک کتا ب ہے ہم نے اسے تیری طرف نازل کیا ہے تاکہ تو لوگوں کو ان کے رب کے حکم سے اندھیروں سے روشنی کی طرف غالب تعرف کیے ہوئے راستہ کی طرف نکالے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mdcclii{یعنی الله جس کے لیے ہے جو کچھ آسمانوں اور زمین میں ہے اور کافروں پر افسوس کہ انہیں سخت عذاب ہونا ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mdccliii{جو دنیا کی زندگی کو آخرت کے مقابلہ میں پسند کرتے ہیں اور الله کی راہ سے روکتے ہیں اور اس میں کجی تلاش کرتے ہیں وہ دور کی گمراہی میں پڑے ہوئے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mdccliv{اور ہم نے ہر پیغمبر کو اس کی قوم کی زبان میں پیغمبر بنا کر بھیجا ہے تاکہ انہیں سمجھا سکے پھر الله جسے چاہتا ہے گمراہ کرتا ہے اور جسے چاہتا ہے ہدایت دیتا ہے اوروہ غالب حکمت والا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mdcclv{اورالبتہ تحقیق ہم نے موسیٰ کو اپنی نشانیاں دےکر بھیجا تھا کہاپنی قوم کو اندھیروں سے روشنی کی طرف نکال اورانہیں الله کے دن یاد دلا بے شک اس میں ہر ایک صبر شکر کرنے والے کے لیے بڑی نشانیاں ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mdcclvi{اورجب موسیٰ نے اپنی قوم سے کہا الله کا احسان اپنے اوپر یاد کرو جب تمہیں فرعون کی قوم سے چھڑا یا وہ تمہیں برا عذاب چکھاتے تھے اور تمہارے بیٹوں کو ذبح کرتے تھے اور تمہاری عورتوں کو زندہ رکھتے تھے اور اسمیں تمہارے رب کی طرف سے بڑی آزمائش تھی\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mdcclvii{اور جب تمہارے رب نے سنا دیا تھا کہ البتہ اگر تم شکر گزاری کرو گے تو اور زیادہ دوں گا اور اگر ناشکری کرو گے تو میرا عذاب بھی سخت ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mdcclviii{اور موسیٰ نے کہا اگر تم اور جو لوگ زمین میں ہیں سارے کفر کرو گے تو الله بے پروا تعریف کیا ہوا ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mdcclix{کیا تمہیں ان لوگوں کی خبر نہیں پہنچی جوتم سے پہلے تھے نوح کی قوم اور عاد اور ثمود اورجو ان کے بعد ہوئے الله کےسوا جنہیں کوئی نہیں جانتا ان کے پاس ان کے رسول نشانیاں لے کر آئے پھرانہوں نے اپنے ہاتھ اپنے مونہوں میں لوٹائے اور کہا ہم نہیں مانتے جو تمہیں دے کر بھیجا گیا ہے اور جس دین کی طرف تم ہمیں بلاتے ہو ہمیں تو اس میں بڑا شک ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mdcclx{ان کے رسولوں نے کہا کیا تمہیں الله میں شک ہے جس نے آسمان او زمین بنائے وہ تمہیں بلاتا ہے تاکہ تمہارے کچھ گناہ بخشے اور تمہیں ایک مقررہ وقت تک مہلت دے انہوں نے کہا تم بھی تو ہمارے جیسے انسان ہو تم چاہتے ہو کہ ہمیں ان چیزوں سے روک دو جنہیں ہمارے باپ دادا پوجتے رہے سو کوئی کھلا ہوامعجزہ لاؤ\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mdcclxi{ان سے ان کے رسولوں نے کہا ضرور ہم بھی تمہارے جیسے ہی آدمی ہیں لیکن الله اپنے بندوں میں جس پر چاھتا ہے احسان کرتا ہے اور ہمارا کام نہیں کہ ہم الله کی اجازت کے سوا تمہیں کوئی معجزہ لا کر دکھائیں اور ایمان والوں کا بھروسہ اللهہی پر ہونا چاہیئے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mdcclxii{اور ہم کیوں الله پر بھروسہ نہ کریں حالانکہ اسی نے ہمیں (سیدھے) راستوں کی راہ نمائی کی ہے اور ہم ضرور صبر کریں گے اس ایذاپر جو تم ہمیں دیتے ہو اور توکل کرنے والوں کو الله ہی پر بھروسہ کرنا چاہیے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mdcclxiii{اور کافروں نے اپنے رسولوں سے کہا ہم تمہیں اپنے ملک سے نکال دیں گے یا ہمارے دین میں لوٹ آؤ تب انہیں ان کے رب نے حکم بھیجا کہ ہم ان ظالموں کو ضرور ہلاک کر دیں گے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mdcclxiv{اور ان کے بعد اس زمین میں تمہیں آباد کر دیں گے یہ اس کے لیے ہے جو میرے سامنے کھڑا ہونے سے ڈرا اور جس نے میرے عذاب سے خوف کھایا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mdcclxv{اور پیغمبروں نے فیصلہ چاہا اور ہر ایک سرکش ضدی نامراد ہوا\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mdcclxvi{اوراس کے پیچھے دوزخ ہے اور اسے پیپ کا پانی پلایا جائے گا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mdcclxvii{جسے گھونٹ گھونٹ پیے گا اور اسے گلےسے نہ اتار سکے گا اور اس پر ہر طرف سے موت آئے گی اور وہ نہیں مرے گا اوراس کے پیچھے سخت عذاب ہوگا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mdcclxviii{ان کی مثال جنہوں نے اپنے رب سے انکار کیا ایسی ہے کہ ان کے اعمال گویا راکھ ہیں کہ جیسی آندھی کے دن ہوا اڑا کر لے گئی ہو جوکچھ انہوں نے کمایا تھا اس میں کچھ بھی ان کے ہاتھ میں نہ رہا ہویہ بھی بڑی دو رکی گمراہی ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mdcclxix{کیا تو نے نہیں دیکھا کہ الله نے آسمانوں اور زمین کو ٹھیک طور پر بنایا اگر وہ چاہے تو تمہیں لے جائے اور نئی مخلوق لے آئے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mdcclxx{اور یہ الله پر کچھ مشکل نہیں ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mdcclxxi{اوریہ سب الله کے سامنے کھڑیں ہوں گے تب کمزور متکبروں سے کہیں گے ہم تو تمہارے تابع تھے سوہمیں الله کے عذاب سے کچھ بچاؤ گے وہ کہیں گے اگر ہمیں الله ہدایت کرتا تو ہم تمہیں ہدایت کرتے اب ہمارے لیے برابر ہے کہ ہم چیخیں چلائیں یا صبر کریں ہمارے بچنے کی کوئی صورت نہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mdcclxxii{اور جب فیصلہ ہو چکے گا تو شیطان کہے گا بےشک الله نے تم سے سچا وعدہ کیا تھا اورمیں نے بھی تم سے وعدہ کیا تھا پھر میں نے وعدہ خلافی کی اور میرا تم پر اس کے سوا کوئی زور نہ تھا کہ میں نے تمہیں بلایا پھر تم نے میری بات کو مان لیا پھر مجھے الزام نہ دو اور اپنے آپ کو الزام دونہ میں تمہارا فریادرس ہوں اور نہ تم میرے فریاد رس ہو میں خود تمہارے اس فعل سے بیزار ہوں کہ تم اس سےپہلے مجھے شریک بناتے تھے بے شک ظالموں کے لیے دردناک عذاب ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mdcclxxiii{اور جو لوگ ایمان لائے تھے اورنیک کام کیے تھے وہ باغوں میں داخل کیے جائیں گے جن کے نیچے نہریں بہتی ہوں گی ان میں اپنے رب کے حکم سے ہمیشہ رہیں گے آپس میں دعائے خیر ان کی سلام ہو گی\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mdcclxxiv{کیاتو نےنہیں دیکھا کہ الله نے کلمہ پاک کی ایک مثال بیان کی ہے گویا وہ ایک پاک درخت ہے کہ جس کی جڑ مضبوط اور اس کی شاخ آسمان ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mdcclxxv{وہ اپنے رب کے حکم سے ہر وقت اپنا پھل لاتا ہے اور الله لوگوں کے واسطے مثالیں بیان کرتا ہے تاکہ وہ سمجھیں\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mdcclxxvi{اور ناپاک کلمہ کی مثال ایک ناپاک درخت کی سی ہے جو زمین کے اوپر ہی سے اکھاڑ لیا جائے اسے کچھ ٹھیراؤ نہیں ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mdcclxxvii{الله ایمان والوں کو دنیا اور آخرت کی زندگی میں سچی بات پر ثابت قدم رکھتا ہے اور ظالمو ں کو گمراہ کر تا ہے اور الله جوچاہتا ہے کرتا ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mdcclxxviii{کیاتو نے انہیں نہیں دیکھا کہ جنہوں نے الله کی نعمت کےبدلے میں ناشکری کی اور اپنی قوم کو تباہی کے گھر میں اتارا\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mdcclxxix{جو دوزخ ہے اس میں داخل ہوں گے اور وہ برا ٹھکانا ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mdcclxxx{اور لوگو ں نے الله کی راہ سے بہکانے کے لیے شریک بنا رکھے ہیں کہہ دو نفع اٹھا لو پھر تمہیں آگ کی طرف لوٹنا ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mdcclxxxi{میرے بندوں کو کہہ دو جو ایمان لائے ہیں نماز قائم رکھیں اور ہمارے دیے ہوئے رزق میں سے پوشیدہ اور ظاہر خرچ کریں اس سے پہلے کہ وہ دن آئے جس میں نہ خرید و فروخت ہے نہ دوستی\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mdcclxxxii{الله وہ ہے جس نے آسمان اور زمین بنائے اور آسمان سے پانی نازل کیا پھر اس سے تمہارے کھانے کو پھل نکالے اور کشتیاں تمہارے تابع کر دیں تاکہ دریا میں اس کے حکم سے چلتی رہیں اور نہریں تمہارے تابع کر دیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mdcclxxxiii{اور سورج اور چاند کو تمہارے تابع کر دیا جو ہمیشہ چلنے والے ہیں اور تمہارے لیے رات اور دن کوتابع کیا\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mdcclxxxiv{اور جو چیز تم نے ان سے مانگی اس نے تمہیں دی اور اگر الله کی نعمتیں شمار کرنے لگو تو انہیں شمار نہ کر سکو بے شک انسان بڑا بےانصاف اور ناشکرا ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mdcclxxxv{اورجس وقت ابراھیم نے کہا اے میرے رب! اس شہر کوامن والا کر دے اور مجھے اور میری اولاد کو بت پرستی سے بچا\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mdcclxxxvi{اے میرے رب! انہوں نے بہت لوگوں کو گمراہ کیا ہے پس جس نے میری پیروی کی وہ تو میرا ہے اورجس نے نافرمانی کی پس تحقیق تو بخشنے والا مہربان ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mdcclxxxvii{اے رب میرے! میں نے اپنی کچھ اولاد ایسےمیدان میں بسائی ہے جہاں کھیتی نہیں تیرے عزت والے گھر کے پاس اے رب ہمارے! تاکہ نماز کو قائم رکھیں پھرکچھ لوگو ں کے دل ان کی طرف مائل کر دے اور انہیں میووں کی روزی دے تاکہ وہ شکر کریں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mdcclxxxviii{اے رب ہمارے! بے شک تو جانتا ہے جو کچھ ہم چھپاتے ہیں اورجو کچھ ظاہر کرتے ہیں اور الله پر کوئی چیز زمین اورآسمان میں پوشیدہ نہیں\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mdcclxxxix{الله کا شکر ہے جس نے مجھے اتنی بڑی عمر میں اسماعیل اور اسحاق بخشے بے شک میرا رب دعاؤں کا سننے والا ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mdccxc{اے میرے رب! مجھے اور میری اولاد کو نماز قائم کرنے والا بنا دے اے ہمارے رب! اورمیری دعا قبول فرما\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mdccxci{اے ہمارے رب! مجھے اورمیرے ماں باپ کو اور ایمانداروں کو حساب قائم ہونے کے دن بخش دے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mdccxcii{تو ہر گز خیال نہ کر کہ الله ان کاموں سے بے خبر ہے جو ظالم کرتے ہیں انہیں صرف اس دن تک مہلت دے رکھی ہے جس میں نگاہیں پھٹی رہ جائیں گی\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mdccxciii{وہ سرا اٹھائے ہوئے دوڑتے چلے جارہے ہوں گے کہ ا ن کی نظر ان کی طرف ہٹ کرنہیں آوے گی اور ان کے دل اڑ گئے ہوں گے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mdccxciv{اور لوگوں کو اس دن سے ڈراوے کہ ان پر عذاب آئے گا تب ظالم کہیں گے اے رب ہمارے! ہمیں تھوڑی مدت تک مہلت دے کہ ہم تیرا بلانا قبول کر لیں اور رسولوں کی پیروی کر لیں کیاتم نے پہلے قسم نہیں کھائی تھی کہ تمہیں کہیں جانا ہی نہیں ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mdccxcv{اور تم انہیں لوگو ں کی بستیوں میں آباد تھے جنہوں نے اپنی جانوں پر ظلم کیا تھا اور تمہیں معلوم ہو چکا تھا کہ ہم نے ان کے ساتھ کیا کیا تھا او رہم نے تمہیں سب قصے بتلائے تھے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mdccxcvi{اور ان لوگو ں نے اپنی تدبیریں کی تھیں اوران کی تدبیریں الله کے سامنے تھیں اگرچہ ان کی تدبیریں ایسی تھی کہ ان سے پہاڑ بھی ٹل جائیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mdccxcvii{پس الله کو اپنے رسولوں سے وعدہ خلافی کرنے والا خیال نہ کریں بے شک الله زبردست بدلہ لینے والا ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mdccxcviii{جس دن اس زمین میں سے اور زمین بدلی جائے گی اور آسمان بدلے جاویں گے اور سب کے سب ایک زبردست الله کے روبرو پیش ہوں گے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mdccxcix{اورتو اس دن گناہگاروں کو زنجیروں میں جکڑے ہوئے دیکھے گا\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mdccc{کرتےان کے گندھک کے ہوں گے اوران کے چہرو ں پر آگ لپٹی ہو گی\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mdccci{تاکہ الله ہر شخص کو اس کے کیے کی سزا دے بے شک الله بڑی جلدی حساب لینے والا ہے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mdcccii{یہ قرآن لوگو ں کے لیے اعلان ہے اور تاکہ اس کے ذریعے سے لوگوں کو ڈرایا جائے اور تاکہ وہ معلوم کر لیں کہ وہی ایک معبود ہے اور تاکہ عقلمند نصیحت حاصل کریں\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mdccciii{\basmalahur یہ آیتیں کتاب کی ہیں اور قرآن واضح کی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mdccciv{کافر بڑی حسرت کریں گے کہ کاش وہ مسلمان ہو جاتے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mdcccv{انہیں چھوڑ دو کھا لیں اور فائدہ اٹھا لیں اور انہیں آرزو بھلائے رکھے سو آئندہ معلوم کر لیں گے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mdcccvi{اور ہم نے جتنی بستیاں ہلاک کی ہیں ان سب کے لیے ایک مقرر وقت لکھا ہوا تھا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mdcccvii{کوئی قوم اپنے وقت مقرر سے نہ پہلے ہلاک ہوئی ہے نہ پیچھے رہی ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mdcccviii{اور انہوں نے کہا اے وہ شخص جس پر قرآن نازل کیا گیا ہے بے شک تو مجنون ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mdcccix{اگر تم سچے ہو تو ہمارے پاس فرشتوں کو کیوں نہیں لاتے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mdcccx{ہم فرشتہ تو فیصلہ ہی کے لیے بھیجا کرتے ہیں اور اس وقت انہیں مہلت نہیں ملے گی\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mdcccxi{ہم نے یہ نصیحت اتار دی ہے اور بے شک ہم اس کے نگہبان ہیں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mdcccxii{اور تجھ سے پہلے ہم پہلی قوموں میں بھی رسول بھیج چکے ہیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mdcccxiii{اور وہ بھی جب کوئی رسول ان کے پاس آتا ہے تو اس سے ٹھٹھا ہی کرتے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mdcccxiv{اسی طرح ہم یہ ٹھٹھا ان مجرمو ں کے دلوں میں ڈال دیتے ہیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mdcccxv{یہ لوگ قرآن پر ایمان نہیں لاتے اور یہ پہلوں کا دستور چلا آیا ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mdcccxvi{اور اگر ہم ان پر آسمان سے دروازہ کھول دیں پھراس میں سے چڑھ جائیں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mdcccxvii{البتہ کہیں گے کہ ہماری نظر بندی کر دی گئی تھی بلکہ ہم پر جادو کیا گیا ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mdcccxviii{او رالبتہ تحقیق ہم نے آسمان پر برج بنائے ہیں اور دیکھنے والو ں کی نطر میں اسے رونق دی ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mdcccxix{اور ہم نے اسے ہرشیطان مردود سے محفوظ رکھا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mdcccxx{مگر جس نے چوری سے سن لیا تو اس کے پیچھے چمکتا ہوا انگارہ پڑا\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mdcccxxi{اور ہم نے زمین کو پھیلایا اور اس پر پہاڑ رکھ دیے اوراس میں ہر چیز اندازے سے اگائی\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mdcccxxii{اوراس میں تمہارے لیے روزی کے اسباب بنا دیئے اوران کے لیے بھی جنہیں تم روزی دینے والے نہیں ہو\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mdcccxxiii{او رہر چیز کے ہمارے پاس خزانے ہیں اورہم صرف اسے اندازہ معین پر نازل کرتے ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mdcccxxiv{اور ہم نے بادل اٹھانے والی ہوائیں بھیجیں پھر ہم نے آسمان سے پانی نازل کیا پھر وہ تمہیں پلایا اور تمہارے پاس اس کا خزانہ نہیں ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mdcccxxv{اور بے شک ہم ہی زندہ کرتے اور مارتے ہیں اورا خیر مالک بھی ہم ہی ہیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mdcccxxvi{اور ہمیں تم میں سے اگلے او رپچھلے سب معلوم کر لیں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mdcccxxvii{اور بے شک تیرا رب ہی انہیں جمع کرے گا بے شک وہ حکمت والا خبردار ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mdcccxxviii{اور البتہ تحقیق ہم نے انسان کو بجتی ہوئی مٹی سے جو سڑے ہوئے گارے سے تھی پیدا کیا\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mdcccxxix{اور ہم نے اس سے پہلے جنوں کو آگ کے شعلے سے بنایا تھا\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mdcccxxx{اور جب تیرے رب نے فرشتوں سے کہا کہ میں ایک بشر کو بجتی ہوئی مٹی سے جو کےسڑے ہوئے گارے کی ہو گی پیدا کرنے والا ہوں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mdcccxxxi{پھر جب میں اسے ٹھیک بنالوں اور اس میں اپنی روح پھونک دوں تو تم اس کے آگے سجدہ میں گر پڑنا\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mdcccxxxii{پھر سب کے سب فرشتوں نے سجدہ کیا\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mdcccxxxiii{مگر ابلیس نے انکار کیا کہ سجدہ کرنے والوں کے ساتھ ہو\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mdcccxxxiv{فرمایا اے ابلیس! تجھے کیا ہوا کہ سجدہ کرنے والوں کے ساتھ نہ ہوا\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mdcccxxxv{کہا میں ایسا نہ تھا کہ ایک ایسے بشر کو سجدہ کروں جسے تو نے بجتی ہوئی مٹی سے جو سڑے ہوئے گارے کی تھی پیدا کیا ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mdcccxxxvi{کہا تو آسمان سے نکل جا بے شک تو مردود ہو گیا\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mdcccxxxvii{اور بے شک تجھ پر قیامت کے دن تک لعنت رہے گی\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mdcccxxxviii{کہا اے میرے رب! تو پھر مجھے قیامت کے دن تک مہلت دے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mdcccxxxix{فرمایا بےشک تجھے مہلت ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mdcccxl{وقت معلوم کے دن تک\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mdcccxli{کہا اے میرے رب! جیسا تو نے مجھے گمراہ لیا ہے البتہ ضرور ضرور میں زمین میں انہیں ان کے گناہوں کو مرغوب کر کے دکھاؤں گا اور ان سب کو گمراہ کروں گا\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mdcccxlii{سوائے تیرے ان بندوں کے جو ان میں مخلص ہو ں گے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mdcccxliii{فرمایا یہ راستہ مجھ پر سیدھا ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mdcccxliv{بے شک میرے بندوں پر تیرا کچھ بھی بس نہیں چلے گا مگر جو گمراہوں میں سے تیرا تابعدار ہوا\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mdcccxlv{اور بے شک ان سب کا وعدہ دوزخ پر ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mdcccxlvi{اس کے سات دروازے ہیں ہر دروازے کے لیے ان کے الگ الگ حصے ہیں\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mdcccxlvii{بے شک پرہیزگار باغوں اور چشموں میں رہیں گے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mdcccxlviii{ان باغوں میں سلامتی اور امن سے جا کر رہو\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mdcccxlix{اور ان کے دلوں میں جو کینہ تھا ہم وہ سب دور کر دیں گے سب بھائی بھائی ہوں گے تختوں پر آمنے سامنے بیٹھنے والے ہوں گے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mdcccl{انہیں وہاں کوئی تکلیف نہیں پہنچے گی اور نہ وہ وہاں سے نکالے جائیں گے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mdcccli{میرے بندوں کو اطلاع دے کہ بےشک میں بحشنے والا مہربان ہوں\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mdccclii{اور بے شک میرا عذاب وہی دردناک عذاب ہے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mdcccliii{اور انہیں ابراھیم کے مہمانوں کا حال سنا دو\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mdcccliv{جب اس کے گھر میں داخل ہوئے اور کہا سلام اس نے کہا بے شک ہمیں تم سے ڈر معلوم ہوتا ہے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mdccclv{کہا ڈرو مت بے شک ہم تمہیں ایک دن لڑکے کی خوشخبری سناتے ہیں\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mdccclvi{کہا مجھے اب بڑھاپے میں خوشخبری سناتے ہو سو کس چیز کی خوشخبری سناتے ہو\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mdccclvii{انہوں نے کہا ہم نے تمہیں بھی سچی خوشخبری سنائی ہے سو تو نا امید نہ ہو\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mdccclviii{کہا اپنے رب کی رحمت سے نا امید تو گمراہ لوگ ہی ہوا کرتے ہیں\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mdccclix{کہا اے فرشتو! پھر تمہارا کیا مقصد ہے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mdccclx{انہوں نے کہا ہم ایک نافرمان قوم کی طرف بھیجے گئے ہیں\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mdccclxi{مگر لوط کے گھر والے کہ ہم ان سب کو بچا لیں گے\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mdccclxii{مگر اس کی بیوی ہم نے فیصلہ کیا ہے کہ وہ پیچھے رہنے والو ں میں سے ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mdccclxiii{پھر جب لوط کے گھر فرشتے پہنچے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mdccclxiv{کہا بے شک تم اجنبی لوگ ہو\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mdccclxv{انہوں نے کہا بلکہ ہم تیرے پاس وہ چیز لے کر آئے ہیں جس میں وہ جھگڑتے تھے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mdccclxvi{او رہم تیرے پاس پکی بات لائے ہیں اوربے شک ہم سچ کہتے ہیں\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mdccclxvii{پس تم اپنے گھر والوں کو کچھ رات رہے لے نکلو اور تو ان کے پیچھے چل اور تم میں سے کوئی مڑ کر نہ دیکھے اور چلے جاؤ جہاں تمہیں حکم ہے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mdccclxviii{اور ہم نے لوط کو قطعی طور پر یہ بات واضح کر دی تھی کہ صبح ہوتے ہی ان کی جڑ کاٹ دی جائے گی\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mdccclxix{اور شہر والے خوشیاں کرتے ہوئے آئے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mdccclxx{لوط نے کہا یہ لوگ میرے مہمان ہیں سو مجھے ذلیل نہ کرو\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mdccclxxi{اور الله سے ڈرو اور مجھے بے آبرو نہ کرو\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mdccclxxii{انہوں نے کہا کیاہم نے تمہیں دنیا بھر کی حمایت سے منع نہیں کیا ہے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mdccclxxiii{کہا یہ میری بیٹیاں حاضر ہیں اگر تم کرنے والے ہو\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mdccclxxiv{تیری جان کی قسم ہے وہ اپنی مستی میں اندھے ہو رہے تھے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mdccclxxv{پھر دن نکلتے ہی انہیں ہولناک آواز نے آ لیا\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mdccclxxvi{پھر ہم نے ان بستیوں کو زیرو زبر کر دیا اور ان پر کنکر کے پتھر برسائے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mdccclxxvii{بے شک اس واقعہ میں اہلِ بصیرت کے لیے نشانیاں ہیں\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mdccclxxviii{اور بے شک یہ بستیاں سیدھے راستے پر واقع ہیں\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mdccclxxix{بے شک اس میں ایمانداروں کے لیے نشانیاں ہیں\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mdccclxxx{اوربن کے لوگ بھی بدکار تھے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mdccclxxxi{پھر ہم نےان سےبھی بدلہ لیا اور یہ دونوں بستیاں کھلے راستہ پر واقع ہیں\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mdccclxxxii{او ربے شک حجر والوں نے رسولوں کو جھٹلایا تھا\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mdccclxxxiii{اور ہم نے انہیں اپنی نشانیاں بھی دی تھیں پر وہ ان سے روگردانی کرتے تھے\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mdccclxxxiv{او وہ لوگ پہاڑوں کو تراش کر گھر بناتے تھے کہ امن میں رہیں\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mdccclxxxv{پھر انہیں صبح کے وقت سخت آواز نے آ پکڑا\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mdccclxxxvi{پھر ان کے دنیاوی ہنر ان کے کچھ بھی کام نہ آئے\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mdccclxxxvii{اور ہم نے آسمانوں اور زمین اور ان کی درمیانی چیزوں کو بغیر حکمت کے پیدا نہیں کیا اور قیامت ضرور آنے والی ہے پر تو ان سے خوش خلقی کے ساتھ کنارہ کر\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mdccclxxxviii{بے شک تیار رب وہی پیدا کرنے والا جاننے والا ہے\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mdccclxxxix{اور ہم نے تمہیں سات آیتیں دیں جو (نماز میں) دہرائی جاتی ہیں اور قرآن عظمت والا دیا\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mdcccxc{اور تو اپنی آنکھ اٹھا کر بھی ان چیزوں کو نہ دیکھ جو ہم نے مختلف قسم کے کافروں کو استعمال کے لیے دے رکھی ہیں اور ان پر غم نہ کر اور اپنے بازو ایمان والوں کے لیے جھکا دے\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mdcccxci{اور کہہ دو بے شک میں کھلم کھلا ڈرانے والا ہوں\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mdcccxcii{جیسا ہم نے (عذاب) ان بانٹنے والو ں پر بھیجا ہے\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mdcccxciii{جنہوں نے قرآن کو ٹکڑے ٹکڑے کیا ہے\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mdcccxciv{پھر تیرے رب کی قسم ہے البتہ ہم ان سب سے سوال کریں گے\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mdcccxcv{اس چیز سے کہ وہ کرتے تھے\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mdcccxcvi{سو تو کھول کر سنا دے جو تجھے حکم دیا گیا ہے اور مشرکوں کی پروا نہ کر\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mdcccxcvii{بے شک ہم تیری طرف سے ٹھٹھا کرنے والوں کے لیے کافی ہیں\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mdcccxcviii{اور جو الله کے ساتھ دوسرا خدا مقرر کرتے ہیں سو عنقریب معلوم کر لیں گے\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mdcccxcix{اور ہم جانتے ہیں کہ تیرا دل ان باتوں سے تنگ ہوتا ہے جو وہ کہتے ہیں\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mcm{سو تو اپنے رب کی تسبیح حمد کے ساتھ کیے جا اور سجدہ کرنے والوں میں سے ہو\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mcmi{اور اپنے رب کی عبادت کرتے رہو یہاں تک کہ تمہیں موت آجائے\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mcmii{\basmalahur الله کا حکم آ پہنچا تم اس میں جلدی مت کرو وہ لوگو ں کے شرک سے پاک اور برتر ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mcmiii{وہ اپنے بندوں سے جس کے پاس چاہتا ہے فرشتوں کو وحی دے کر بھیج دیتا ہے یہ کہ خبردار کر دو کہ میرے سوا کوئی عبادت کے لائق نہیں پس مجھ سے ڈرتے رہو\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mcmiv{اسی نے آسمان اور زمین کو ٹھیک طور پر بنایا ہے وہ ان کے شرک سے پاک ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mcmv{اسی نے آدمی کو ایک بوند سے پیدا کیا پھر وہ یکایک کھلم کھلا جھگڑنے لگا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mcmvi{اور تمہارے واسطے چار پایوں کو بھی اسی نے بنایا ان میں تمہارے لیے جاڑے کابھی سامان ہے اوربھی بہت سے فائدے ہیں اور ان میں سے کھاتے بھی ہو\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mcmvii{اور تمہاے لیے ان میں زینت بھی ہے جب شام کو چرا کر لاتے ہو اور جب چرانے لے جاتے ہو\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mcmviii{اور وہ تمہارے بوجھ اٹھا کر ان شہروں تک لے جاتے ہیں کہ جہاں تک تم جان کو تکلیف میں ڈالنے کے سوا نہیں پہنچ سکتے تھے بے شک تمہارا رب شفقت کرنے والا مہربان ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mcmix{اور گھوڑے خچر اور گدھے پیدا کیے کہ ان پر سوار ہو اور زینت کے لیے اور وہ چیزیں پیدا کرتا ہے جو تم نہیں جانتے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mcmx{اور الله تک سیدھی راہ پہنچتی ہے اور بعض ان میں ٹیڑھی بھی ہیں اور اگر الله چاہتا تو تم سب کو سیدھی راہ بھی دکھا دیتا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mcmxi{وہی ہے جس نے آسمان سے تمہارے لیے پانی نازل کیا اسی میں سے پیتے ہو اور اسی سے درخت ہوتے ہیں جن میں چراتے ہو\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mcmxii{تمہارے واسطے اسی سے کھیتی اور زیتوں اورکھجوریں اورانگور اور ہر قسم کے میوے اگاتا ہے بے شک اس میں ان لوگو ں کے لیے نشانی ہے جو غور کرتے ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mcmxiii{اور رات اور دن اور سورج اور چاند کو تمہارے کام میں لگا دیا ہے اور اسی کے حکم سے ستارے بھی کام میں لگے ہوئے ہیں بے شک اس میں لوگوں کے لیے نشانیاں ہیں جو سمجھ رکھتے ہیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mcmxiv{اور تمہارے واسطے جو چیزیں زمین میں رنگ برنگ کی پھیلائی ہیں ان میں لوگوں کے لیے نشانی ہے ہے جو سوچتے ہیں\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mcmxv{اور وہ وہی ہے جس نے دریا کو کام میں لگا دیا کہ اس میں تازہ گوشت کھاؤ اور اسی سے زیور نکالو جسے تم پہنتے ہو اور تو اس میں جہازوں کو دیکھتا ہے کہ پانی کو چیرتے ہوئے چلے جاتے ہیں اور تاکہ تم اس کے فضل کو تلاش کرو اور تاکہ تم شکر کرو\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mcmxvi{اور زمین پر پہاڑوں کے بوجھ ڈال دیے تاکہ تمہیں لے کر نہ ڈگمگائے اور تمہارے لیے نہریں اور راستے بنا دیے تاکہ تم راہ پاؤ\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mcmxvii{اور نشانیاں بنائیں اور ستاروں سے لوگ راہ پاتے ہیں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mcmxviii{پھر کیا جو شخص پیدا کرے اس کے برابر ہے جو کچھ بھی پیدا نہ کرے کیا تم سوچتے نہیں\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mcmxix{اور اگر تم الله کی نعمتو ں کو گننے لگو تو ان کا شمار نہیں کر سکو گےبے شک الله بخشنے والا مہربان ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mcmxx{اور الله جانتا ہے جو تم چھپاتے ہو اور جو تم ظاہر کرتےہو\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mcmxxi{اور جنہیں الله کے سوا پکارتے ہیں وہ کچھ بھی پیدانہیں کرتے اور وہ خود پیدا کیے ہوئے ہیں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mcmxxii{وہ تو مردے ہیں جن میں جان نہیں اور وہ نہیں جانتے کہ لوگ کب اٹھائے جائیں گے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mcmxxiii{تمہارا معبود اکیلا معبود ہے پھر جو آخرت پر ایمان نہیں رکھتے ان کے دل نہیں مانتے اور وہ تکبر کرنے والے ہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mcmxxiv{ضرور الله جانتا ہے جو کچھ چھپاتے ہیں اور جو کچھ ظاہر کرتے ہیں بے شک وہ غرور کرنے والوں کو پسند نہیں کرتا\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mcmxxv{اور جب ان سے کہا جائے کہ تمہارے رب نے کیا نازل کیا ہے کہتے ہیں پہلے لوگوں کے قصے ہیں تاکہ قیامت کے دن اپنے بوجھ پورے اٹھائيں اورکچھ ان کے بوجھ جنہیں بے علمی سے گمراہ کرتے ہیں خبردار برا بوجھ ہے جواٹھاتے ہیں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mcmxxvi{ان سے پہلےلوگوں نے بھی مکر کیا تھا پھر الله نے ان کی عمارت کو جڑوں سے ڈھا دیا پھر ان پر اوپر سے چھت گر پڑی اور ان پر عذاب آیا جہاں سے انہیں خبر بھی نہ تھی\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mcmxxvii{پھر قیامت کے دن انہیں رسوا کرے گا اور کہے گا میرے شریک کہاں ہیں جن پر تمہیں بڑی ضد تھی جنہیں علم دیا گیا تھا وہ کہیں گے کہ بے شک آج کافروں کے لیے رسوائی اور برائی ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mcmxxviii{یہ وہ لوگ ہیں کہ فرشتوں نے ان کی ایسی حالت میں روح نکالی تھی کہ وہ اپنے آپ پر ظلم کر رہے تھے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mcmxxix{پھر وہ صلح کا پیغام بھیجیں گے کہ ہم تو کوئی برا کام نہ کرتے تھے کیوں نہیں بے شک الله کو تمہارے اعمال کی پوری خبر ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mcmxxx{سو دوزخ کے دروازوں میں داخل ہو جاؤ اس میں ہمیشہ رہو پس متکبرین کا کیا ہی برا ٹھکانہ ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mcmxxxi{اور پرہیزگاروں سے کہا جاتا ہے کہ تمہارے رب نے کیا نازل کیا ہے تو کہتے ہیں اچھی چیز جنہوں نے نیکی کی ہے (ان کے لیے) اس دنیا میں بھی بہتری ہے اور البتہ آخرت کا گھر تو بہت ہی بہتر ہے اور پرہیزگاروں کا کیا ہی اچھا گھر ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mcmxxxii{ہمیشہ رہنے کے باغ ہیں جن میں وہ داخل ہوں گے اور ان کے نیچے نہریں بہتی ہوں گی جو چاہیں گے انہیں وہاں ملے گا الله پرہیزگاروں کو ایسا ہی بدلہ دے گا\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mcmxxxiii{جن کی جان فرشتے قبض کرتے ہیں ایسے حال میں کہ وہ پاک ہیں فرشتے کہیں گے تم پر سلامتی ہو بہشت میں داخل ہو جاؤ بسبب ان کاموں کے جو تم کرتے تھے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mcmxxxiv{کیا اب اس کے منتظر ہیں کہ ان پر فرشتے آویں یا تیرے رب کا حکم آئے اسی طرح ان سے پہلوں نے بھی کیا تھا اور الله نے ان پر ظلم نہیں کیا اور لیکن وہ اپنے نفسوں پر ظلم کرتے تھے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mcmxxxv{پھر انہیں ان کے بد اعمال کے نتیجے مل کر رہے اورجس کی وہ ہنسی اڑایا کرتے تھے وہی ان پر نازل ہوا\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mcmxxxvi{اور مشرک کہتے ہیں اگر الله چاہتا تو ہم اس کے سوا کسی چیز کی عبادت نہ کرتے اور نہ ہمارے باپ دادا اور اس کے حکم کے سوا ہم کسی چیز کو حرام نہ ٹھیراتے اسی طرح کیا ان لوگو ں نے جو ان سے پہلے تھے پھر رسولوں کے ذمہ تو صرف صاف پہنچا دینا ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mcmxxxvii{اور البتہ تحقیق ہم نے ہر امت میں یہ پیغام دے کر رسول بھیجا کہ الله کی عبادت کرو اور شیطان سے بچو پھر ان میں سے بعض کو الله نے ہدایت دی اوربعض پر گمراہی ثابت ہوئی پھر ملک میں پھر کر دیکھو کہ جھٹلانے والوں کا انجام کیا ہوا\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mcmxxxviii{اگر تو انہیں ہدایت پرلانے کی طمع کرے تو الله ہدایت نہیں دیتا اس شخص کو جسے گمراہ کر دے اور نہ ان کے لیے کوئی مددگار ہوگا\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mcmxxxix{اور الله کی سخت قسمیں کھا کر کہتے ہیں کہ الله انہیں اٹھائے گا اس شخص کو جو مر جائے گا ہاں اس نے اپنے ذمہ پکا وعدہ کر لیا ہے لیکن بہت سے لوگ نہیں جانتے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mcmxl{تاکہ ان پر ظاہر کر دے وہ بات جس میں یہ جھگڑتے ہیں اور تاکہ کافر معلوم کر لیں کہ وہ جھوٹے تھے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mcmxli{ہم جس کام کےکرنے کا ارادہ کرتے ہیں تو اس کے لیے ہمارا اتنا ہی کہنا کافی ہے کہ ہم اسے کہہ دیں کہ ہو جا پھر ہو جاتا ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mcmxlii{اورجنہوں نے الله کے واسطے گھر چھوڑا اس کےبعد ان پر ظلم کیا گیا تھا تو البتہ ہم نے انہیں دنیا میں اچھی جگہ دیں گے اور آخرت کا ثواب تو بہت ہی بڑا ہے کاش یہ لوگ سمجھ جاتے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mcmxliii{جو لوگ ثابت قدم رہے اور اپنے رب پر بھروسہ کیا\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mcmxliv{اور ہم نے تجھ سے پہلے بھی تو انسان ہی بھیجے تھے جن کی طرف ہم وحی بھیجا کرتے تھے سو اگر تمہیں معلوم نہیں تو اہلِ علم سے پوچھ لو\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mcmxlv{ہم نے انہیں معجزات اور کتابیں دے کر بھیجا تھا اور ہم نے تیری طرف قرآن نازل کیا تاکہ لوگو ں کے لیے واضح کر دے جو ان کی طرف نازل کیا گیا ہے اور تاکہ وہ سوچ لیں\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mcmxlvi{پس کیا وہ لوگ نڈر ہو گئے ہیں جو برے فریب کرتے ہیں اس سے کہ الله انہیں زمین میں دھنسا دے یاان پر عذاب آئے جہاں سے انہیں خبر بھی نہ ہو\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mcmxlvii{یا انہیں چلتے پھرتے پکڑے پس وہ عاجز کرنے والے نہیں ہیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mcmxlviii{یا انہیں ڈرانے کے بعد پکڑے پس تحقیق تمہارا رب نہایت ہی شفیق رحم کرنے والا ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mcmxlix{کیا وہ الله کی پیدا کی ہوئی چیزوں کونہیں دیکھتے کہ کے سائے دائیں اوربائیں طرف جھکے جارہے ہیں اور نہایت عاجزی کے ساتھ الله کو سجدہ کررہے ہیں\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mcml{اور جو آسمان میں ہے اور جو زمین میں ہے جانداروں سے اور فرشتے سب الله ہی کو سجدہ کرتے ہیں اوروہ تکبرنہیں کرتے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mcmli{وہ اپنے بالادست رب سے ڈرتے ہیں اور انہیں جو حکم دیا جاتا ہے وہ بجا لاتے ہیں\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mcmlii{الله نے کہا ہے دو معبود نہ بناؤ وہ ایک ہی معبود ہے پھر مجھ ہی سے ڈرو\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mcmliii{اوراسی کا ہے جوکچھ آسمانوں اور زمین میں ہے اور عبادت اسی کی لازم ہے پھرکیا الله کے سوا اوروں سے ڈرتے ہو\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mcmliv{اور تمہارے پاس جو نعمت بھی ہے سو الله کی طرف سے ہے پھر جب تمہیں تکلیف پہنچتی ہے تواسی سے فریاد کرتے ہو\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mcmlv{پھر جب تم سے تکلیف دور کر دیتا ہےتو فوراً تم میں سے ایک جماعت اپنے رب کے ساتھ شریک بنانے لگتی ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mcmlvi{تاکہ جو نعمتیں ہم نےانہیں دی تھیں ان کی ناشکری کریں خیر نفع اٹھالو آ گے چل کر معلوم کر لو گے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mcmlvii{اور جنہیں وہ جانتے بھی نہیں ان کے لیے ہماری دی ہوئی چیزوں میں سے ایک حصہ مقرر کرتے ہیں الله کی قسم البتہ تم سے ان بہتانوں کی ضرور باز پرس ہوگی\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mcmlviii{اور الله کے لیے بیٹیاں ٹھیراتے ہیں وہ اس سے پاک ہے اور اپنے لیے جو دل چاہتا ہے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mcmlix{اور جب ان میں سے کسی کی بیٹی کی خوشخبری دی جائے اس کا منہ سیاہ ہو جاتا ہے اور وہ غمگین ہوتا ہے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mcmlx{اس خوشخبری کی برائی باعث لوگوں سے چھپتا پھرتا ہے آیا اسے ذلت قبول کر کے رہنے دے یااس کو مٹی میں دفن کر دے دیکھو کیا ہی برا فیصلہ کرتے ہیں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mcmlxi{جو آخرت کو نہیں مانتے ان کی بری مثال ہے اور الله کی شان سب سے بلند ہے اور وہی زبردست حکمت والا ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mcmlxii{اور اگر الله لوگوں کوانکی بے انصافی پر پکڑے تو زمین پر کسی جاندار کو نہ چھوڑے لیکن ایک مدت مقرر تک انہیں مہلت دیتا ہے پھر جب ان کا وقت آتا ہے تو نہ ایک گھڑی پیچھے ہٹ سکتے ہیں اورنہ آگے بڑھ سکتے ہیں\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mcmlxiii{اور اللهکے لیے وہ چیزیں تجویز کرتے ہیں جنہیں آپ بھی پسند نہیں کرتے اورزبان سے جھوٹے دعوے کرتے ہیں کہ آخرت کی بھلائی انہیں کے لیے ہے اسمیں شک نہیں کہ ان کے لیے آگ ہے اور بے شک وہ سب سے پہلے دوزخ میں بھیجے جائیں گے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mcmlxiv{الله کی قسم ہے! ہم نے تجھ سے پہلے بھی قوموں میں رسول بھیجے تھے پھر شیطان نے لوگوں کو ان کی بداعمالیاں اچھی کر دکھائیں سو آج بھی ان کا وہی دوست ہے اور ان کے لیے دردناک عذاب ہے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mcmlxv{اور ہم نے اسی لیے تجھ پر کتاب اتاری ہے کہ تو انہیں وہ چیز کھول کر سنا دے جس میں وہ جھگڑ رہے ہیں اور ایمانداروں کے لیے ہدایت اور رحمت بھی ہے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mcmlxvi{اور الله نے آسمان سے پانی اتارا پھراس سے مردہ زمین کو زندہ کر دیا اس میں ان لوگو ں کے لیے نشانی ہے جو سنتے ہیں\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mcmlxvii{اوربے شک تمہارے لیے چارپایوں میں سوچنے کی جگہ ہے ہم نےان کے جسم سے خون او رگوبر کے درمیان خالص دودھ پیدا کردیتے ہیں جو پینے والوں کے لیے خوشگوار ہے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mcmlxviii{اور کھجور اور انگور کے پھلوں سے نشہ اور اچھی غذا بھی بناتے ہو اس میں لوگوں کے لیے نشانی ہے جو سمجھتے ہیں\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mcmlxix{اور تیرے رب نے شہد کی مکھی کو حکم دیا کہ پہاڑوں میں اور درختوں میں اور ان چھتوں میں گھر بنائے جو اس کے لیے بناتے ہیں\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mcmlxx{پھر ہر قسم کے میوں سے کھا پھر اپنے رب کی تجویز کردہ آسان راہوں پر چل ان کے پیٹ سے پینے کی چیز نکلتی ہے جس کے رنگ مختلف ہیں اس میں لوگوں کے لیے شفا ہے بے شک اس میں ان لوگو ں کے لیے نشانی ہے جو سوچتے ہیں\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mcmlxxi{اور الله نے تمہیں پیدا کیا پھر وہی تمہیں مارتاہے اور کوئی تم میں سے نکمی عمر تک پہنچایا جاتا ہے جو سمجھ دار ہونے کے بعد نادان ہو جاتا ہے بےشک الله جاننے والا قدرت والا ہے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mcmlxxii{اور الله نے تم میں سے بعض کو بعض پر روزی میں فضیلت دی پھر جنہیں فضیلت دی گئی وہ اپنے حصہ کا مال اپنے غلاموں کو دینےو الے نہیں کہ وہ اس میں برابر ہو جائیں پھر کیا الله کی نعمت کا انکار کرتے ہیں\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mcmlxxiii{اور الله نے تمہارے واسطے تمہاری ہی قسم سے عورتیں پیدا کیں اور تمہیں تمہاری عورتوں سے بیٹے اور پوتے دیئے اور تمہیں کھانے کے لیے اچھی چیزیں دیں پھرکیا جھوٹی باتیں تو مان لیتے ہیں اور الله کی نعمتوں کا انکار کرتے ہیں\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mcmlxxiv{اور الله کے سوا ان کی عبادت کرتے ہیں جو آسمانوں ارو زمین سے انہیں رزق پہنچانے میں کچھ بھی اختیارنہیں رکھتے اور نہ رکھ سکتے ہیں\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mcmlxxv{پس الله کے لئے مثالیں نہ گھڑو بے شک الله جانتا ہے اور تم نہیں جانتے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mcmlxxvi{الله ایک مثال بیان فرماتا ہے ایک غلام ہے کسی دوسرے کی ملک میں جو کسی چیز کا اختیارنہیں رکھتا اور ایک دوسرا آدمی ہے جسے ہم نے اچھی روزی دے رکھی ہے اور وہ ظاہر اور پوشیدہ اسے خرچ کرتا ہے کیا دونوں برابر ہیں سب تعریف الله کے لیے ہے مگر اکثر ان میں سے نہیں جانتے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mcmlxxvii{اور الله ایک او رمثال دو آدمیوں کی بیان فرماتا ہے ایک ان میں سے گونگا ہے کچھ بھی نہیں کر سکتااور اپنے آقا پر ایک بوجھ ہے جہاں کہیں اسے بھیجے اس سے کوئی خوبی کی بات بن نہ آئے کیا یہ اور وہ برابر ہے جو لوگوں کو انصاف کا حکم دیتا ہے اور وہ خود بھی سیدھے راستے پر قائم ہے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mcmlxxviii{اور آسمانوں اور زمین کی پوشیدہ باتیں تو الله ہی کو معلوم ہیں اور قیامت کا معاملہ تو ایسا ہے جیسا آنکھ کا جھپکنا یا اس سےبھی قریب تر بے شک الله ہر چیز پر قادر ہے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mcmlxxix{اور الله نے تمہیں تمہاری ماؤں کے پیٹ سے نکالا تم کسی چیز کو نہ جانتے تھے اور تمہیں کان اور آنکھیں اور دل دیئے تاکہ تم شکر کرو\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mcmlxxx{کیا پرندوں کو نہیں دیکھتے کہ آسمان کی فضا میں تھمے ہوئے ہیں انہیں الله کے سوا کون تھامے ہوئے ہے بے شک اس میں بھی ایمانداروں کے لیے بڑی نشانیاں ہیں\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mcmlxxxi{اور الله نے تمہارے گھروں کو تمہارے لیے آرام کی جگہ بنایا ہے اور تمہارے لیے چارپایوں کی کھالوں سے خیمے بنائے جنہیں تم اپنے سفر اور قیام کے دن ہلکے پاتے ہو اوربھیڑوں کی اون سے اور اونٹوں کی روؤں سے اوربکریوں کے بالوں سے کتنے ہی سامان اور مفید چیزیں وقت مقرر تک کے لیے بنا دیں\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mcmlxxxii{اور الله نے تمہارے لیے اپنی بنائی ہوئی چیزوں کے سائےبنا دیئے اور تمہارے لیے پہاڑوں میں چھپنے کی جگہیں بنا دیں اور تمہارے لیے کرتے بنا دیئے جو تمہیں گرمی سے بچاتے ہیں اور زرہیں جو تمہیں لڑائیں میں بچاتی ہیں اسی طرح الله اپنا احسان تم پر پورا کرتا ہے تاکہ تم فرمانبردار ہو جاؤ\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mcmlxxxiii{پھربھی اگر نہ مانیں تو تم پر صاف صاف پیغام پہنچا دینا ہی ہے\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mcmlxxxiv{وہ الله کی نعمتیں پہچانتے ہیں پھر منکر ہو جاتے ہیں اوراکثر ان میں سے ناشکر گزار ہیں\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mcmlxxxv{اور جس دن ہم ہر قوم میں سے ایک گواہ کھڑا کریں گے پھر نہ کافروں کو اجازت دی جائے گی اورنہ ان کا کوئی عذر قبول کیا جائے گا\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mcmlxxxvi{اور جب ظالم عذاب دیکھیں گے پھر نہ ان سے ہلکا کیا جائے گا اورنہ انہیں مہلت دی جائے گی\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mcmlxxxvii{اور جب مشرک اپنے شریکوں کو دیکھیں گے تو کہیں گے اے ہمارے رب! یہی ہمارے شریک ہیں جنہیں ہم تیرے سوا پکارتے تھے پھر وہ انہیں جواب دیں گے کہ تم سراسر جھوٹے ہو\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mcmlxxxviii{اور وہ اس دن الله کے سامنے سر جھکا دیں گے اور بھول جائیں گے وہ جو جھوٹ بناتے تھے\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mcmlxxxix{جو لوگ منکر ہوئے اور الله کی راہ سے روکتے رہے ہم ان پر عذاب پر عذاب بڑھاتے جائیں گے بسبب اس کے کہ وہ فساد کرتے تھے\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mcmxc{اور جس دن ہر ایک گروہ میں سے ان پر انہیں میں سے ایک گواہ کھڑا کریں گے اور تجھے ان پر گواہ بنائیں گے اور ہم نے تجھ پر ایک ایسی کتاب نازل کی ہے جس میں ہر چیز کا کافی بیان ہے اور وہ مسلمانوں کے لیے ہدات اور رحمت اور خوشخبری ہے\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mcmxci{بے شک الله انصاف کرنے کا اوربھلائی کرنے کا اور رشتہ داروں کو دینے کا حکم کرتا ہے اوربے حیائی اوربری بات اور ظلم سے منع کرتا ہے تمہیں سمجھاتا ہے تاکہ تم سمجھو\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mcmxcii{اور الله کا عہد پورا کرو جب آپس میں عہد کرو اور قسموں کو پکاکرنے کے بعد نہ توڑو حالانکہ تم نے الله کو اپنے اوپر گواہ بنا یا ہے بے شک الله جانتا ہے جو تم کرتے ہو\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mcmxciii{اور اس عورت جیسے نہ بنو جواپنا سوت محنت کے بعد کاٹ کر توڑ ڈالے کہ تم اپنی قسموں کو آپس میں فساد کا ذریعہ بنانے لگو محض اس لیے کہ ایک گروہ دوسرے گروہ سے بڑھ جائے الله اس میں تمہاری آزمائش کرتا ہے اور جس چیز میں تم اختلاف کرتے ہو الله اسے ضرور قیامت کے دن ظاہر کردے گا\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mcmxciv{اور اگر الله چاہتا تو تم سب کو ایک ہی جماعت بنا دیتا اورلیکن وہ جسے چاہتا ہے گمراہی میں پڑا رہنے دیتا ہے اور جسے چاہتاہے ہدایت دیتا ہے اور البتہ تم سے پوچھا جائے گا کہ کیا کرتےتھے\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mcmxcv{اور تم اپنی قسموں کو آپس میں فساد کا ذریعہ نہ بناؤ کبھی قدم جمنے کے بعد پھسل نہ جائے پھر تمہیں اس سبب سے کہ تم نے راہِ خدا سے روکا تکلیف اٹھانی پڑے اور تمہیں بڑا عذاب ہو\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mcmxcvi{اور الله سے عہد کو تھوڑے سے داموں پر نہ بیچو جو کچھ الله کے ہاں ہے وہی تمہارے لیے بہتر ہے اگر تم جانتے ہو\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mcmxcvii{جو تمہارے پاس ہے ختم ہو جائے گا اور جو الله کے پاس ہے کبھی ختم نہ ہوگا اور ہم صبر کرنے والوں کو ان کے اچھے کاموں کا جو کرتے تھے ضرور بدلہ دیں گے\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mcmxcviii{جس نے نیک کام کیا مرد ہو یا عورت اور وہ ایمان بھی رکھتا ہے تو ہم اسے ضروراچھی زندگی بسر کرائیں گے اور ان کا حق انہیں بدلےمیں دیں گے انکےاچھے کاموں کے عوض میں جو کرتے تھے\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mcmxcix{سو جب تو قرآن پڑھنے لگے تو شیطان مردود سے الله کی پناہ لے\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mm{اس کا زور ان پرنہیں چلتا جو ایمان رکھتے ہیں اور اپنے رب پر بھروسہ کرتے ہیں\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mmi{اس کا زور تو انہیں پر ہے جو اسے دوست بناتے ہیں اور جو الله کے ساتھ شریک مانتے ہیں\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mmii{اورجب ہم ایک آیت کی جگہ دوسری بدلتے ہیں اور الله خوب جانتا ہے جو اتارتا ہے تو کہتے ہیں کہ تو بنا لاتا ہے یہ بات نہیں لیکن اکثر ان میں سے نہیں سمجھتے\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mmiii{تو کہہ دے اسےتیرے رب کی طرف سے پاک فرشتے نے سچائی کے ساتھ اتارا ہے تاکہ ایمان والوں کے دل جما دے اور فرمانبرداروں کے لیے ہدایت اور خوشخبری ہے\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mmiv{اور ہمیں خوب معلوم ہے کہ وہ کہتے ہیں اسے تو ایک آدمی سکھاتا ہے حالانکہ جس کی طرف نسبت کرتے ہیں اس کی زبان عجمی ہے اور یہ صاف عربی زبان ہے\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mmv{وہ لوگ جنہیں الله کی باتوں پر یقین نہیں الله بھی انہیں ہدایت نہیں دیتا اور ان کے لیے دردناک عذاب ہے\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mmvi{جھوٹ تو وہ لوگ بناتے ہیں جنہیں الله کی باتوں پر یقین نہیں اور وہی لوگ جھوٹے ہیں\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mmvii{جو کوئی ایمان لانے کے بعد الله سے منکر ہوا مگر وہ جو مجبور کیا گیا ہو اور اس کا دل ایمان پر مطمئن ہو اور لیکن وہ جو دل کھول کر منکر ہوا تو ان پر الله کا غضب ہے اور ان کے لیے بہت بڑا عذاب ہے\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mmviii{یہ اس لیے کہ انہوں نے دنیا کی زندگی کو آخرت پر محبوب بنایا اور نیز اس لیے کہ الله کافروں کو ہدایت نہیں دیتا\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mmix{یہ وہی ہیں کہ الله نے ان کے دلوں پر اورکانوں پر اور آنکھوں پر مہر کر دی اور وہی غافل بھی ہیں\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mmx{ضرور وہی لوگ آخرت میں نقصان اٹھانے والے ہیں\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mmxi{پھر بے شک تیرا رب ان کے لئے جنہوں نےمصیبت میں پڑنے کے بعد ہجرت کی پھر جہاد کیا اور صبر کیا بے شک تیرارب ان باتو ں کے بعد بحشنے والا مہربان ہے\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mmxii{ٰجس دن ہر شخص اپنے ہی لیے جھگڑتا ہو آئے گا اور ہر شخص کو اس کے عمل کا پورا بدلہ دیا جائے گا اوران پر کچھ بھی ظلم نہ ہوگا\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mmxiii{اور الله ایک ایسی بستی کی مثال بیان فرماتا ہے جہاں ہر طرح کا امن چین تھا اس کی روزی بافراغت ہر جگہ سے چلی آتی تھی پھر الله کےاحسانوں کی ناشکری کی پھر الله نے ان کے برے کاموں کے سبب سے جو وہ کیا کرتے تھے یہ مزہ چکھایا کہ ان پر فاقہ اور خوف چھا گیا\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@mmxiv{اور البتہ ان کے پاس انہیں میں سے رسول بھی آیا مگر انہوں نے اسے جھٹلایا پھر انہیں عذاب نے آ پکڑا ایسے حال میں کہ وہ ظالم تھے\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@mmxv{پھر تمہیں جو الله نے حلال طیب روزی دی ہے کھاؤ اور الله کے احسان کا شکر کرو اگر تم صرف اسی کو پوجتے ہو\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@mmxvi{تم پر صرف مردار اور خون اور سور کا گوشت حرام کیا ہے اوروہ چیز بھی جو الله کے سوا کسی اور کے نام سے پکاری گئی ہو پھر جوبھوک کے مارے بیتاب ہو جائے نہ وہ باغی ہو اورنہ حد سے گزرنے والا توالله بخشنے والا مہربان ہے\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@mmxvii{اور اپنی زبانوں سے جھوٹ بنا کر نہ کہو کہ یہ حلا ل ہے اوریہ حرا م ہے تاکہ الله پر بہتان باندھو بے شک جو الله پر بہتان باندھتے ہیں انکا بھلانہ ہوگا\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@mmxviii{تھوڑا سا فائدہ اٹھا لیں اوران کے لیے دردناک عذاب ہے\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@mmxix{اورجو لوگ یہودی ہیں ہم نے ان پر حرا م کی جو تجھے پہلے سنا چکے ہیں اورہم نے ان پر ظلم نہیں کیا لیکن وہ اپنے اوپر آپ ظلم کرتے تھے\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@mmxx{پھر تیرا رب ان کے لیے جو جہالت سے برے کام کرتے رہے پھر اس کے بعد انہوں نے توبہ کر لی اور سدھر گئے بے شک تیرا رب اس کے بعد البتہ بخشنے والا مہربان ہے\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@mmxxi{بے شک ابراہیم ایک پوری امت تھا الله کا فرمانبردار تمام راہوں سے ہٹا ہوا اور مشرکوں میں سے نہ تھا\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@mmxxii{اس کی نعمتوں کا شکر کرنے والا اسے الله نے چن لیا اور اسے سیدھی راہ پر چلایا\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@mmxxiii{اور ہم نے اسے دنیا میں بھی خوبی دی تھی اور وہ آخرت میں بھی اچھے لوگو ں میں ہو گا\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@mmxxiv{پھر ہم نے تیرے پاس وحی بھیجی کہ تمام راہوں سے ہٹنے والے ابراہیم کے دین پر چل اور وہ مشرکوں میں سے نہ تھا\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@mmxxv{ہفتہ کا دن انہی پر مقرر کیا گیا تھا جو اس میں اختلاف کرتےتھے او رتیرا رب ان میں قیامت کےدن فیصلہ کرے گا جس میں وہ اختلاف کرتے تھے\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@mmxxvi{اپنے رب کے راستے کی طرف دانشمندی اور عمدہ نصیحت سے بلا اور ان سے پسندیدہ طریقہ سے بحث کر بے شک تیرا رب خوب جانتا ہے کہ کون اس کے راستہ سے بھٹکا ہوا ہے اور ہدایت یافتہ کو بھی خوب جانتا ہے\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@mmxxvii{اور اگر بدلہ لو تو اتنا بدلہ لو جتنی تمہیں تکلیف پہنچائی گئی ہے اور اگر صبر کرو تو یہ صبر کرنے والوں کے لیے بہتر ہے\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@mmxxviii{اورصبر کر اور تیرا صبر کرنا الله ہی کی توفیق سے ہے اور ان پر غم نہ کھا اور ان کے مکروں سے تنگ دل نہ ہو\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@mmxxix{بے شک الله ان کے ساتھ ہے جو پرہیزگار ہیں اور جو نیکی کرتے ہیں\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@mmxxx{\basmalahur وہ پاک ہے جس نے راتوں رات اپنے بندے کو مسجدحرام سے مسجد اقصیٰ تک سیر کرائی جس کے اردگرد ہم نے برکت رکھی ہے تاکہ ہم اسے اپنی کچھ نشانیاں دکھائیں بے شک وہ سننے والا دیکھنے ولا ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmxxxi{اور ہم نے موسیٰ کو کتاب دی اور اسے بنی اسرائیل کے لیے ہدایت بنایا کہ میرے سوا کسی کو کارساز نہ بناؤ\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmxxxii{اے ان کی نسل جنہیں ہم نے نوح کے ساتھ سوار کیا تھا بے شک وہ شکر گزار بندہ تھا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmxxxiii{اور ہم نے بنی اسرائیل کو کتاب میں یہ بات بتلا دی تھی کہ تم ضرور ملک میں دو مرتبہ خرابی کرو گے اوربڑی سرکشی کرو گے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmxxxiv{پھر جب پہلا وعدہ آیا تو ہم نے تم پر اپنے بندے سخت لڑائی والے بھیجے پھر وہ تمہارے گھروں میں گھس گئے اور الله کا وعدہ تو پورا ہونا ہی تھا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmxxxv{پھر ہم نے تمہیں دشمنوں پر غلبہ دیا اور تمہیں مال اور اولاد میں ترقی دی اور تمہیں بڑی جماعت والا بنا دیا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmxxxvi{اگر تم نے بھلائی کی تو اپنے ہی لیےکی اور اگر برائی کی تو وہ بھی اپنے ہی لیےکی پھر جب دوسرا وعدہ آیا تاکہ تمہارے چہروں پر رسوائی پھیر دیں اور مسجد میں گھس جائیں جس طرح پہلی بار گھس گئے تھے اور جس چیز پر قابو پائیں اس کا ستیاناس کر دیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmxxxvii{تمہارا رب قریب ہے کہ تم پر رحم کرے اور اگر تم پھر وہی کرو گے تو ہم بھی پھر وہی کریں گے اور ہم نے دوزخ کو کافروں کے لیے قید خانہ بنایا ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmxxxviii{بے شک یہ قرآن وہ راہ بتاتا ہے جو سب سے سیدھی ہے اور ایمان والوں کو جو نیک کام کرتے ہیں اس بات کی خوشخبری دیتاہے ان کے لیے بڑا ثواب ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmxxxix{اور یہ بھی بتاتا ہے کہ جو لوگ آخرت پر ایمان نہیں لاتے ہم نے ان کے لیے دردناک عذاب تیار کیا ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmxl{اور انسان برائی مانگتا ہے جس طرح وہ بھلائی مانگتا ہے اور انسان جلد باز ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmxli{اور ہم نے رات اور دن کے دو نمونے بنا دیے پھر رات کے نمونے کو دھندلا کر دیا اور دن کا نمونہ نظر آنے کے لیے روشن کر دیا تاکہ تم اپنے رب کا فضل تلاش کرو اور تاکہ تم برسوں کی گنتی اور حساب معلوم کر لو اور ہم نے ہر چیز کی تفصیل کر دی\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmxlii{اور ہم نے ہر آدمی کا نامہ اعمال اس کی گردن کےساتھ لگادیا ہے اور قیامت کے دن ہم اس کا نامہ اعمال نکال کر سامنے کردیں گے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmxliii{اپنا نامہ اعمال پڑھ لے آج اپنا حساب لینے کے لیے تو ہی کافی ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmxliv{جو سیدھے راستے پر چلا تو اپنے ہی لیے چلا اور جو بھٹک گیا تو بھٹکنے کا نقصان بھی وہی اٹھائے گا اور کوئی بوجھ اٹھانے والا دوسرے کا بوجھ نہیں اٹھائے گا اور ہم سزا نہیں دیتے جب تک کسی رسول کو نہیں بھیج لیتے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmxlv{اور جب ہم کسی بستی کو ہلاک کرنا چاہتے ہیں تو وہاں کے دولتمندوں کو کوئی حکم دیتے ہیں پھر وہ وہاں نافرمانی کرتے ہیں تب ان پر حجت تمام ہوجاتی ہے اور ہم اسے برباد کر دیتے ہیں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmxlvi{اور نوح کے بعد ہم نےقوموں کے کئی دور ہلاک کر دیئے ہیں اور تیرا رب اپنے بندوں کے گناہوں کا جاننے والا دیکھنے والا کافی ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmxlvii{جو کوئی دنیا چاہتا ہے تو ہم اسے سردست دنیا میں سے جس قدر چاہتے ہیں دیتے ہیں پھر ہم نے اس کے لیے جہنم تیار کر رکھی ہے جس میں وہ ذلیل و خوار ہوکر رہے گا\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmxlviii{اورجو آخرت چاہتا ہے اوراس کے لیے مناسب کوشش بھی کرتا ہے اور وہ مومن بھی ہے تو ایسے لوگوں کی کوشش مقبول ہو گی\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmxlix{ہم ہر فریق کو اپنی پروردگاری بخششوں سے مدد دیتے ہیں ان کو بھی اور تیرے رب کی بخشش کسی پر بند نہیں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mml{دیکھو ہم نے ایک کو دوسرے پر کیسی فضیلت دی ہے اور آخرت کے تو بڑے درجے اوربڑی فضیلت ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmli{الله کے ساتھ اور کوئی معبود نہ بنا ورنہ تو ذلیل بے کس ہو کر بیٹھے گا\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmlii{اور تیرا رب فیصلہ کر چکا ہے اس کے سوا کسی کی عبادت نہ کرو اور ماں باپ کے ساتھ نیکی کرو اور اگر تیرے سامنے ان میں سے ایک یا دونوں بڑھاپے کو پہنچ جائیں تو انہیں اف بھی نہ کہو اور نہ انہیں جھڑکو اور ان سے ادب سے بات کرو\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmliii{اوران کے سامنے شفقت سے عاجزی کے ساتھ جھکے رہو اور کہو اے میرے رب جس طرح انہوں نے مجھے بچپن سےپالا ہے اسی طرح تو بھی ان پر رحم فرما\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmliv{جو تمہارے دلوں میں ہے تمہارا رب خوب جانتا ہے اگر تم نیک ہو گے تو وہ توبہ کرنے والوں کو بخشنے والا ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmlv{اور رشتہ دار اور مسکین اور مسافر کو اس کا حق دے دو اور مال کو بے جا خرچ نہ کرو\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmlvi{بے شک بیجا خرچ کرنے والے شیطانو ں کے بھائی ہیں اور شیطان اپنے رب کا ناشکر گزار ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmlvii{اوراگر تجھے اپنے رب کے فضل کے انتظار میں کہ جس کی تجھے امید ہے منہ پھیرنا پڑے تو ان سے نرم بات کہہ دے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmlviii{اور اپنا ہاتھ اپنی گردن کے ساتھ بندھا ہوانہ رکھ اور نہ اسے کھول دے بالکل ہی کھول دینا پھر تو پشیمان تہی دست ہو کر بیٹھ رہے گا\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmlix{بے شک تیرا رب جس کے لئے چاہے رزق کشادہ کر تا ہے اور تنگ بھی کرتا ہے بے شک وہ اپنے بندوں کو جاننے والا دیکھنے والا ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmlx{اور اپنی اولاد کو تنگدستی کے ڈر سے قتل نہ کرو ہم انہیں بھی رزق دیتے ہیں اور تمہیں بھی بے شک ان کا قتل کرنا بڑا گناہ ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmlxi{اور زنا کے قریب نہ جاؤ بے شک وہ بے حیائی ہے اور بری راہ ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmlxii{اور جس جان کو قتل کرنا الله نے حرام کر دیا ہے اسے ناحق قتل نہ کرنا اور جو کوئی ظلم سے مارا جائے تو ہم نے اس کے ولی کے واسطے اختیار دے دیا ہے لہذاا قصاص میں زيادتی نہ کرے بے شک اس کی مدد کی گئی ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmlxiii{اور یتیم کے مال کے پاس نہ جاؤ مگر جس طریقہ سے بہتر ہو جب تک وہ اپنی جوانی کو پہنچے اور عہد کو پورا کرو بے شک عہد کی بازپرس ہو گی\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmlxiv{اور ناپ تول کر دو تو پورا ناپو اور صحیح ترازو سے تول کر دو یہ بہتر ہے اور انجام بھی اس کا اچھا ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmlxv{اورجس بات کی تجھے خبر نہیں اس کے پیچھے نہ پڑ بے شک کان اورآنکھ اور دل ہر ایک سے باز پرس ہو گی\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmlxvi{اور زمین پر اتراتا ہوا نہ چل بے شک تو نہ زمین کو پھاڑ ڈالے گا او رنہ لمبائی میں پہاڑوں تک پہنچے گا\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmlxvii{ان میں سے ہر ایک بات تیرے رب کے ہاں ناپسند ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmlxviii{یہ اس حکمت میں سے ہے جسے تیرے رب نے تیری طرف وحی کیا ہے اور الله کے ساتھ اور کسی کو معبود نہ بنا ورنہ تو ملزم مردود بنا کر جہنم میں ڈال دیا جائے گا\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmlxix{کیا تمہارے رب نے تمہیں چن کر بیٹے دے دیئے اور اپنے لئےفرشتوں کو بیٹیاں بنا لیا تم بڑی بات کہتے ہو\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmlxx{اور ہم نے اس قرآن میں کئی طرح سے بیان کیا تاکہ وہ سمجھیں حالانکہ اس سے انہیں نفرت ہی بڑھتی جاتی ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmlxxi{کہہ دو اگر اس کے ساتھ اور بھی معبود ہوتے جیسا وہ کہتے ہیں تب تو انہوں نے عرش والے تک کوئی راستہ نکال لیا ہوتا\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmlxxii{وہ پاک ہے اور جو کچھ وہ کہتے ہیں اس سے وہ بہت ہی بلند ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmlxxiii{ساتوں آسمان اور زمین اور جو کوئی ان میں ہے اس کی پاکی بیان کرتے ہیں اور ایسی کوئی چیز نہیں جو ا سکی حمد کے ساتھ تسبیح نہ کرتی ہو لیکن تم ان کی تسبیح کو نہیں سمجھتے بے شک وہ بردبار بخشنے والا ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmlxxiv{اورجب تو قرآن پڑھتا ہے ہم تیرے اور ان لوگو ں کے درمیان جو آخرت کو نہیں مانتے ایک چھپا ہو ا پردہ کر دیتے ہیں\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmlxxv{اور ہم نے ان کے دلو ں پر پردے کر دیے ہیں تاکہ اسے نہ سمجھیں اور ان کے کانوں میں گرانی ڈال دی ہے اور جب تو قرآن میں صرف اپنے رب ہی کا ذکر کرتا ہے تو پیٹھ پھیر کر کفرت سے بھاگتے ہیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmlxxvi{ہم خوب جانتے ہیں جس غرض سے یہ سنتے ہیں جب یہ لوگ تیری طرف کان لگاتے ہیں اور جس وقت آپس میں سرگوشیاں کرتے ہیں جب یہ ظالم کہتے ہیں کہ تم محض ایسے شخص کا ساتھ دیتے ہو جس پر جادو کیا گیا ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmlxxvii{دیکھ تیرے لیے کیسی مثالیں بیان کرتے ہیں سو گمراہ ہو گئے پھر وہ راستہ نہیں پا سکتے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmlxxviii{اور کہتے ہیں کیا جب ہم ہڈیاں اور چورا ہو جائیں گے پھر نئے بن کر اٹھیں گے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmlxxix{کہہ دو تم پتھر یا لوہا ہوجاؤ\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmlxxx{یا کوئی اور چیز جسے تم اپنے دلوں میں مشکل سمجھتے ہو پھر وہ کہیں گے ہمیں دوبارہ کون لوٹائے گا کہہ دو وہی جس نے تمہیں پہلی مرتبہ پیدا کیا ہے پھر تمہارے سامنے سروں کو ہلاکر کہیں گے کہ وہ کب ہو گا کہہ دو شاید وہ وقت بھی قریب آ گیا ہو\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmlxxxi{جس دن تمہیں پکارے گا پھر اس کی تعریف کرتے ہوئے چلے آؤ گے اور خیال کرو گے کہ بہت ہی کم ٹھہرے تھے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmlxxxii{اور میرے بندوں سے کہہ دو کہ وہی بات کہیں جو بہتر ہو بےشک شیطان آپس میں لڑا دیتا ہے بے شک شیطان انسان کا کھلا دشمن ہے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmlxxxiii{تمہارا رب خوب جانتا ہے اگر چاہے تم پر رحم کرے اور اگر چاہے تمہیں عذاب دے او رہم نے تجھے ان پر ذمہ دار بنا کر نہیں بھیجا\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmlxxxiv{اور تیرا رب خوب جانتا ہے جو آسمانوں اور زمین میں ہے اور ہم نے بعض پیغمبروں کو بعض پر فضیلت دی ہے او رہم نے داؤد کو زبور دی تھی\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmlxxxv{کہہ دو انہیں پکارو جنہیں تم اس کے سوا سمجھتے ہو وہ نہ تمہاری تکلیف دور کر سکیں گے اور نہ اسے بدلیں گے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmlxxxvi{وہ لوگ جنہیں یہ پکارتے ہیں جو ان میں سے زیادہ مقرب ہیں وہ بھی اپنے رب کی طرف نیکیوں کا ذریعہ تلاش کرتے ہیں اور اس کی مہربانی کی امید رکھتے ہیں اور اس کے عذاب سے ڈرتے ہیں بےشک تیرے رب کا عذاب ڈرنے کی چیز ہے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmlxxxvii{اور ایسی کوئی بستی نہیں جسے ہم قیامت سے پہلے ہلاک نہ کریں یا اسے سخت عذاب نہ دیں یہ بات کتاب میں لکھی ہوئی ہے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmlxxxviii{اور ہم نے اس لیےمعجزات بھیجنے موقوف کر دیےکہ پہلوں نے انہیں جھٹلایا تھا اور ہم نے ثمود کو اونٹنی کا کھلا ہوا معجزہ دیا تھا پھر بھی انہوں نے اس پر ظلم کیا اور یہ معجزات تو ہم محض ڈرانے کے لیے بھیجتے ہیں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmlxxxix{اور جب ہم نے تم سے کہہ دیا کہ تیرے رب نے سب کو قابو میں کر رکھا ہے اور وہ خواب جو ہم نے تمہیں دکھایا اور وہ خبیث درخت جس کا ذکر قرآن میں ہے ان سب کو ان لوگو ں کے لیے فتنہ بنا دیا اور ہم تو انہیں ڈراتے ہیں سو اس سے ان کی شرارت اوربھی بڑھتی جاتی ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmxc{اور جب ہم نے فرشتوں سے کہا آدم کو سجدہ کرو تو سوائے ابلیس کے سب سجدہ میں گر پڑے کہا کیا میں ایسے شخص کو سجدہ کروں جسےتو نے مٹی بنایا ہے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmxci{کہا بھلا دیکھ تو یہ شخص جسے تو نے مجھ سے بڑھایا اگرتو مجھے قیامت کے دن تک مہلت دے تو میں بھی سوائے چند لوگوں کے اس کی نسل کو قابو میں کر کے رہونگا\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmxcii{فرمایا جا۔ پھر ان میں سے جو کوئی تیرے ساتھ ہوا تو جہنم تم سب کی پوری سزا ہے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmxciii{ان میں سے جسے تو اپنی آواز سنا کر بہکا سکتا ہے بہکا لے اور ان پر اپنے سوار اور پیادے بھی چڑھا دے اوران کے مال اور اولاد میں بھی شریک ہو جا اور ان سے وعدے کر اور شیطان کے وعدے بھی محض فریب ہی تو ہیں\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmxciv{بے شک میرے بندوں پر تیرا غلبہ نہیں ہو گا اور تیرا رب کافی کارساز ہے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmxcv{تمہارا رب وہ ہے جو تمہارے لیے دریا میں کشتیاں چلاتا ہے تاکہ تم اس کا فضل تلاش کرو بے شک وہی تم پر بڑا مہربان ہے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmxcvi{اور جب تم پر دریا میں کوئی مصیبت آتی ہے تو بھول جاتے ہو جنہیں الله کے سوا پکارتے تھےپھر جب وہ تمہیں خشکی کی طرف بچا لاتا ہے تو تم اس سے منہ موڑ لیتے ہو اور انسان بڑا ہی ناشکرا ہے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmxcvii{پھر کیا تم اس بات سے نڈر ہو گئے کہ وہ تمہیں خشکی کی طرف لاکر زمین میں دھنسا دے یا تم پر پتھر برسانے والی آندھی بھیج دے پھر تم کسی کو اپنا مددگار نہ پاؤ\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmxcviii{یا تم اس بات سے بالکل نڈر ہو گئے ہو کہ وہ دوبارہ تمہیں پھر دریا میں لوٹا لائے پھر تم پر ہوا کا سخت طوفان بھیج دے پھر تمہاری ناشکری سے تمہیں غرق کر دے پھر اپنی طرف سے ہم پر کوئی باز پرس کرنے والا بھی نہ پاؤ\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmxcix{اور ہم نے آدم کی اولاد کو عزت دی ہے اور خشکی اور دریا میں اسے سوار کیا اور ہم نے انہیں ستھری چیزو ں سے رزق دیا اور اپنی بہت سی مخلوقات پر انہیں فضیلت عطا کی\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmc{جس دن ہم ہر فرقہ کو ان کے سرداروں کے ساتھ بلائیں گے سوجسے اس کا اعمال نامہ ا سکے داہنے ہاتھ میں دیا گیا سو وہ لوگ اپنا اعمال نامہ پڑھیں گے اور وہ تاگے کے برابر ظلم نہیں کئے جائیں گے\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmci{اور جو کوئی اس جہان میں اندھا رہا تو وہ آخرت میں بھی اندھا ہو گا اور راستہ سے بہت دور ہٹا ہوا\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmcii{اور بے شک وہ قریب تھے کہ تجھے اس چیز سے بہکا دیں جو ہم نے تجھ پر بذریعہ وحی بھیجی ہے تاکہ تو اس کے سوا ہم پر بہتان باندھنے لگے اور پھر تجھے اپنا دوست بنا لیں\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmciii{اور اگرہم تجھے ثابت قدم نہ رکھتے تو کچھ تھوڑا سا ان کی طرف جھکنے کے قریب تھا\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmciv{اس وقت ہم تجھے زندگی میں اور موت کے بعد دہرا عذاب چکھاتے پھر تو اپنے واسطے ہمارے مقابلے میں کوئی مددگار نہ پاتا\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmcv{اور وہ تو تجھے اس زمین سے دھکیل دینے کو تھے تاکہ تجھے اس سے نکال دیں پھر وہ بھی تیرے بعد بہت ہی کم ٹھرتے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmcvi{تم سے پہلے جتنے رسول ہم نے بھیجے ہیں ان کا یہی دستور رہا ہے او رہمارے دستور میں تم تبدیلی نہیں پاؤ گے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmcvii{آفتاب کے ڈھلنےسے رات کے اندھیرے تک نماز پڑھا کرو اور صبح کی نماز بھی بے شک صبح کی نماز میں مجمع ہو تا ہے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmcviii{اور کسی وقت رات میں تہجد پڑھا کرو جو تیرے لیے زائد چیز ہے قریب ہے کہ تیرا رب مقام محمود میں پہنچا دے\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmcix{اور کہہ اے میرے رب مجھے خوبی کے ساتھ پہنچا دے اور مجھے خوبی کے ساتھ نکال لے اور میرے لیے اپنی طرف سے غلبہ دے جس کے ساتھ نصرت ہو\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmcx{اور کہہ دو کہ حق آیا اور باطل مٹ گیا بے شک باطل مٹنے ہی والا تھا\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmcxi{اور ہم قرآن میں ایسی چیزیں نازل کرتے ہیں کہ وہ ایمانداروں کے حق میں شفا اور رحمت ہیں اور ظالموں کو اس سےاور زیادہ نقصان پہنچتا ہے\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmcxii{اورجب ہم انسان پر انعام کرتے ہیں تو منہ پھیر لیتا ہے اور پہلو تہی کرتا ہے اور جب اسے کوئی تکلیف پہنچتی ہے تو نا امیدہوجاتا ہے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmcxiii{کہہ دو کہ ہر شخص اپنے طریقہ پر کام کرتا ہے پھر تمہارا رب خوب جانتا ہے کہ سب سے زیادہ ٹھیک راہ پر کون ہے\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmcxiv{اور یہ لوگ تجھے رو ح کے متعلق سوال کرتے ہیں کہہ دو روح میرے رب کے حکم سے ہے اور تمہیں جو علم دیا گیا ہے وہ بہت ہی تھوڑا ہے\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmcxv{او راگر ہم چاہیں تو جو کچھ ہم نے تیری طرف وحی کی ہے اسے اٹھا لیں پھر تجھے اس کے لیے ہمارے مقابلہ میں کوئی حمایتی نہ ملے\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmcxvi{مگر یہ صرف تیرے رب کی رحمت ہے بے شک تجھ پر اس کی بڑی عنایت ہے\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmcxvii{کہہ دو اگر سب آدمی اور سب جن مل کر بھی ایسا قرآن لانا چاہیں تو ایسا نہیں لا سکتے اگرچہ ان میں سے ہر ایک دوسرے کا مددگار کیوں نہ ہو\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmcxviii{او رہم نے اس قرآن میں لوگوں کے لیے ہر ایک قسم کی مثال بھی کھول کر بیان کر دی ہے پھر بھی اکثر لوگ انکار کیے بغیر نہ رہے\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmcxix{اور کہا ہم تمہیں ہرگز نہ مانیں گے یہاں تک کہ تو ہمارے لیے زمین میں سے کوئی چشمہ جاری کر دے\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmcxx{یا تیرے لیے کھجور اور انگور کا کوئی باغ ہو پھر تو اس باغ میں بہت سی نہریں جاری کر دے\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmcxxi{یا جیسا تو خیال کرتا ہے ہم پرکوئی آسمان کا ٹکڑا گرادے یا تو الله اور فرشتوں کو روبرو لے آ\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmcxxii{یا تیرے پاس کوئی سونے کا گھر ہو یا تو آسمان پر چڑھ جائے او رہم تو تیرے چڑھنے کا بھی یقین نہیں کریں گے یہاں تک کہ توہمارے پاس ایسی کتاب لائے جسے ہم بھی پڑھ سکیں کہہ دو میرا رب پاک ہے میں تو فقط ایک بھیجا ہوا انسان ہوں\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmcxxiii{اورلوگوں کو ایمان لانے سے جب کہ ان کے پاس ہدایت آ گئی صرف اسی چیز نے روکا ہے کہ کہنے لگے کیا الله نے آدمی کو رسول بنا کر بھیجا ہے\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mmcxxiv{کہہ دو اگر زمین میں فرشتے اطمینان سے چلتے پھرتے ہوتے تو ہم آسمان سے ان پر فرشتہ ہی رسول بنا کر بھیجتے\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mmcxxv{کہہ دوکہ الله میرے اور تمہارے درمیان گواہ کافی ہے بے شک وہ اپنے بندوں سے خبردار دیکھنے والا ہے\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mmcxxvi{اور جسے الله راہ دکھا دے وہی راہ پانے والا ہے اورجسے گمراہ کر دے پھر تو ان کے لیے الله کے سوا کوئی دوست نہیں پائے گا اور ہم نے انہیں قیامت کے دن مونہوں کے بل اندھے گونگے بہرے کر کے اٹھائیں گے ان کا ٹھکانا دوزخ ہے جب بجھنے لگے گی تو ان پر اوربھڑکا دیں گے\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mmcxxvii{یہ ان کی سزا اس لیے ہے کہ انہوں نے ہماری آیتوں کا انکار کیا اور کہا کہ کیا جب ہم ہڈیاں اور چورا ہو جائیں گے توپھر نئے ے سرے سے بنا کر اٹھائے جائیں گے\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mmcxxviii{کیا انہوں نے نہیں دیکھا جس الله نے آسمانوں اور زمین کوبنایا ہے وہ ان جیسے اوپر بھی بنا سکتا ہے اور اس نے ان کے لیے ایک وقت مقرر کر رکھا ہے جس میں کوئی شک نہیں اس پر بھی ظالم انکار کیئے بغیر نہ رہے\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mmcxxix{کہہ دو اگر میرے رب کی رحمت کے خزانے تمہارے ہاتھ میں ہوتے تو تم انہیں خرچ ہو جانے کے ڈر سے بند ہی کر رکھتے اور انسان بڑا تنگ دل ہے\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mmcxxx{اور البتہ تحقیق ہم نے موسیٰ کو نو کھلی نشانیاں دی تھیں پھر بھی بنی اسرائیل سےبھی پوچھ لو جب موسیٰ ان کے پاس آئے تو فرعون نے اسے کہا اے موسیٰ میں تو تجھے جادو کیا ہوا خیال کرتا ہوں\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mmcxxxi{کہا یہ تو تجھے معلوم ہے کہ یہ آسمانوں اور زمین کے مالک ہی نے لوگوں کو سوجھانے کے لیے نازل کی ہیں اور بے شک میں تجھے اے فرعون ہلاک کیا ہوا خیال کرتا ہوں\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mmcxxxii{پھر اس نے ارادہ کیا کہ انہیں اس زمین سے نکال دے تب ہم نے اسے اور اس کے سب ساتھیوں کو غرق کر دیا\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mmcxxxiii{اور اس کے بعد ہم نے بنی اسرائیل سے کہا کہ تم اس زمین میں آباد رہو پھر جب آخرت کا وعدہ آ ئے گا ہم تمہیں سمیٹ کر لے آئیں گے\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mmcxxxiv{اور ہم نے اس قرآن کو سچائی سے نازل کیا اور وہ سچائی سے ہی نازل ہوا اور ہم نے تجھے صرف خوشی سنانے والا اور ڈرانے والا بنا کر بھیجا ہے\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mmcxxxv{اور ہم نے قرآن کو تھوڑا تھوڑا کر کے اتارا تاکہ تو مہلت کے ساتھ اسے لوگوں کو پڑھ کر سنائے اور ہم نے اسے آہستہ آہستہ اتارا ہے\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mmcxxxvi{کہہ دوتم اسے مانو یا نہ مانو بے شک وہ لوگ جنہیں اس سے پہلے علم دیا گیا ہے جب ان پر پڑھا جاتا ہے تو تھوڑیوں پر سجدہ میں گرتے ہیں\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mmcxxxvii{اورکہتے ہیں ہمارا رب پاک ہے بے شک ہمارے رب کا وعدہ ہو کر رہے گا\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mmcxxxviii{اور تھوڑیوں پر روتے ہوئے گرتے ہیں اور ان میں عاجزی زیادہ کر دیتا ہے\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mmcxxxix{کہہ دو الله کہہ کر یا رحمٰن کہہ کر پکارو جس نام سے پکاروسب اسی کے عمدہ نام ہیں اور اپنی نماز میں نہ چلا کر پڑھ اور نہ بالکل ہی آہستہ پڑھ اور اس کے درمیان راستہ اختیار کر\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mmcxl{اور کہہ دو سب تعریفیں الله کے لیے ہیں جس کی نہ کوئی اولاد ہے اورنہ کوئی اس کا سلطنت میں شریک ہے اور نہ کوئی کمزوری کی وجہ سے اس کا مددگار ہے اور اس کی بڑائی بیان کرتےر ہو\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mmcxli{\basmalahur سب تعریف الله کے لیے جس نے اپنے بندہ پر کتاب اتاری اور اس میں ذرا بھی کجی نہیں رکھی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmcxlii{ٹھیک اتاری تاکہ اس سخت عذاب سے ڈراوے جو اس کے ہاں ہے اورایمان داروں کو خوشخبری دے جو اچھے کام کرتے ہیں کہ ان کے لیے اچھا بدلہ ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmcxliii{جس میں وہ ہمیشہ رہیں گے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmcxliv{اور انہیں بھی ڈرائے جو کہتے ہیں کہ الله اولاد رکھتا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmcxlv{ان کے پاس اس کی کوئی دلیل نہیں ہے اور نہ ان کے باپ دادا کے پاس تھی کیسی سخت بات ہے جو ان کے منہ سے نکلتی ہے وہ لوگ بالکل جھوٹ کہتے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmcxlvi{پھر شایدتو ان کے پیچھے افسوس سے اپنی جان ہلاک کر دے گا اگر یہ لوگ اس بات پر ایمان نہ لائے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmcxlvii{جو کچھ زمین پر ہے بے شک ہم نے اسے زمین کی زینت بنا دیا ہے تاکہ ہم انہیں آزمائیں کہ ان میں کون اچھے کام کرتا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmcxlviii{اورجو کچھ اس پر ہے بے شک ہم سب کو چٹیل میدان کر دیں گے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmcxlix{کیا تم خیال کرتے ہو کہ غار اور کتبہ والے ہماری نشانیوں والے عجیب چیز تھے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmcl{جب کہ چند جوان اس غار میں آ بیٹھے پھر کہا اے ہمارے رب ہم پر اپنی طرف سے رحمت نازل فرما اور ہمارے اس کام کے لیے کامیابی کا سامان کر دے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmcli{پھر ہم نے کئی سال تک غار میں ان کے کان بند کر دیے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmclii{پھر ہم نے انہیں اٹھایا تاکہ معلوم کریں کہ دونوں جماعتوں میں سے کس نے یاد رکھی ہے جتنی مدت وہ رہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmcliii{ہم تمہیں ان کا صحیح حال سناتے ہیں بے شک وہ کئی جوان تھے جو اپنے رب پر ایمان لائے اور ہم نے انہیں اور زيادہ ہدایت دی\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmcliv{اورہم نے ان کے دل مضبوط کر دیے جب وہ یہ کہہ کر اٹھ کھڑے ہوئے کہ ہمارا رب آسمانوں اور زمین کا رب ہے ہم اس کے سوا کسی معبود کو ہرگز نہ پکاریں گے ورنہ ہم نے بڑی ہی بیجا بات کہی\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmclv{یہ ہماری قوم ہے انہوں نے الله کے سوا اورمعبود بنا لیے ہیں ان پر کوئی کھلی دلیل کیوں نہیں لاتے پھر اس سے بڑا ظالم کون ہوگا جس نے الله پر جھوٹ باندھا\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmclvi{اور جب تم ان سے الگ ہو گئے ہواور الله کے سوا جنہیں وہ معبود بناتے ہیں تب غار میں چل کر پناہ لو تم پر تمہارا رب اپنی رحمت پھیلا دے گا اور تمہارے لیے تمہارےاس کام میں آرام کا سامان کر دے گا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmclvii{اور تو سورج کو دیکھے گا جب وہ نکلتا ہے تو ان کے غار کے دائیں طرف سے ہٹا ہوا رہتا ہے اور جب ڈوبتا ہے تو ان کی بائیں طرف سے کتراتا ہو گزر جاتا ہے وہ اس کے میدان میں ہیں یہ الله کی نشانیوں میں سے ہے جسے الله ہدایت دے وہی ہدایت پانے والا ہے اور جسے وہ گمراہ کر دے پھر اس کے لیے تمہیں کوئی بھی کارساز پر لانے والا نہیں ملے گا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmclviii{اور تو انہیں جاگتا ہوا خیال کرے گا حالانکہ وہ سو رہے ہیں اورہم انہیں دائیں بائیں پلٹتے رہتے ہیں اور ان کا کتا چوکھٹ کی جگہ اپنے دونوں بازو پھیلائے بیٹھا ہے اگر تم انہیں جھانک کر دیکھو تو الٹے پاؤں بھاگ کھڑے ہوئے اورالبتہ تم پر ان کی دہشت چھا جائے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmclix{اوراسی طرح ہم نے انہیں جگا دیا تاکہ ایک دوسرے سے پوچھیں ان میں سے ایک نے کہا تم کتنی دیر ٹہرے ہو انہوں نے کہا ہم ایک دن یا دن سے کم ٹھیرے ہیں کہا تمہارا رب خوب جانتا ہے جتنی دیر تم ٹھہرے ہو اب اپنے میں سے ایک کو یہ اپنا روپیہ دے کر اس شہر میں بھیجو پھر دیکھے کون سا کھانا ستھرا ہے پھر تمہارے پاس اس میں سے کھانا لائے اور نرمی سے جائے اور تمہارے متعلق کسی کو نہ بتائے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmclx{بے شک وہ لوگ اگر تمہاری اطلاع پائیں گے تو تمہیں سنگسار کر دیں گےیا اپنے دین میں لوٹا لیں گے پھر تم کبھی فلاح نہیں پا سکو گے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmclxi{اور اسی طرح ہم نے ان کی خبر ظاہر کر دی تاکہ لوگ سمجھ لیں کہ الله کا وعدہ سچا ہے اور قیامت میں کوئی شک نہیں جبکہ لوگ ان کے معاملہ میں جھگڑ رہے تھے پھر کہا ان پر ایک عمارت بنا دو انکا رب ان کا حال خوب جانتا ہے ان لوگوں نے کہا جو اپنے معاملے میں غالب آ گئے تھے کہ ہم ان پر ضرور ایک مسجد بنائیں گے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmclxii{بعض کہیں گے تین ہیں چوتھا ان کا کتا ہے اور بعض اٹکل پچو سے کہیں گے پانچ ہیں چھٹا ان کا کتا ہے اور بعض کہیں گے سات ہیں آٹھواں ان کا کتا ہے کہہ دو ان کی گنتی میرا رب ہی خوب جانتا ہے ان کا اصلی حال تو بہت ہی کم لوگ جانتے ہیں سو تو ان کے بارے میں سرسری گفتگو کے سوا جھگڑا نہ کرو ان میں سے کسی سےبھی انکا حال دریافت نہ کر\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmclxiii{اورکسی چیز کے متعلق یہ ہر گز نہ کہو کہ میں کل اسے کر ہی دوں گا\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmclxiv{مگر یہ کہ الله چاہے اور اپنے رب کو یاد کر لے جب بھول جائے اور کہہ دو امید ہے کہ میرا رب مجھے اس سے بھی بہتر راستہ دکھائے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmclxv{اور وہ اپنے غار میں تین سو سے زائد نو برس رہے ہیں\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmclxvi{کہہ دو الله بہتر جانتا ہے کہ کتنی مدت رہے تمام آسمانوں اور زمین کا علم غیب اسی کو ہے کیا عجیب دیکھتا اور سنتا ہے ان کا الله کے سوا کوئی بھی مددگار نہیں اور نہ ہی وہ اپنے حکم میں کسی کو شریک کرتا ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmclxvii{اور اپنے رب کی کتاب سے جو تیری طرف وحی کی گئی ہے پڑھا کرو اس کی باتوں کوکوئی بدلنے والا نہیں ہے اور تو اس کے سوا کوئی پناہ کی جگہ نہیں پائے گا\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmclxviii{تو ان لوگو ں کی صحبت میں رہ جو صبح اور شام اپنے رب کو پکارتے ہیں اسی کی رضا مندی چاہتے ہیں اور تو اپنی آنکھوں کو ان سے نہ ہٹا کہ دنیا کی زندگی کی زینت تلاش کرنے لگ جائے اور اس شخص کا کہنا نہ مان جس کے دل کو ہم نے اپنی یاد سے غافل کر دیاہے اور اپنی خواہش کے تابع ہو گیا ہے اور ا سکا معاملہ حد سے گزر ا ہوا ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmclxix{اور کہہ دو سچی بات تمہارے رب کی طرف سے ہے پھر جو چاہے مان لے اور جو چاہے انکار کر دے بے شک ہم نے ظالموں کے لیے آگ تیار کر رکھی ہے انہیں اس کی قناتیں گھیر لیں گی اور اگر فریاد کریں گے تو ایسے پانی سے فریاد رسی کیے جائیں گے جو تانبے کی طرح پگھلا ہوا ہو گا مونہوں کو جھلس دے گا کیا ہی برا پانی ہو گا او رکیا ہی بری آرام گاہ ہو گی\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmclxx{بے شک جو لوگ ایمان لائے اور اچھے کام کیے ہم بھی اس کا اجر ضائع نہیں کریں گے جس نے اچھے کام کیے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmclxxi{وہی لوگ ہیں جن کے لیے ہمیشہ رہنے کے باغ ہیں جن کے نیچے نہریں بہہ رہی ہوں گی انہیں وہاں سونے کے کنگن پہنائے جائیں گے اور باریک اور موٹے ریشم کا سبز لباس پہنیں گے وہاں تختوں پر تکیے لگانے والے ہوں گے کیا ہی اچھا بدلہ ہے اور کیا ہی اچھی آرام گا ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmclxxii{اور انہیں دو شحصوں کی مثال سنا دو ان دونوں میں سے ایک لیے ہم نے انگور کے دو باغ تیار کیے اور ان کے گرد اگر کھجوریں لگائیں اوران دونو ں کے درمیان کھیتی بھی لگا رکھی تھی\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmclxxiii{دونوں باغ اپنے پھل لاتے ہیں اور پھل لانے میں کچھ کمی نہیں کرتے اور ان دونوں کے درمیان ہم نے ایک نہر بھی جاری کردی ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmclxxiv{اور اسے پھل مل گیا پھر اس نے اپنے ساتھی سے باتیں کرتے ہوئے کہا کہ میں تجھ سے مال میں بھی زيادہ ہوں اور جماعت کے لحاظ سے بھی زیادہ معزز ہوں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmclxxv{اور اپنے باغ میں داخل ہوا ایسے حال میں کہ وہ اپنی جان پر ظلم کرنے والا تھا کہا میں نہیں خیال کرتا کہ یہ باغ کبھی برباد ہو گا\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmclxxvi{اورمیں قیامت کو ہونے والی خیال نہیں کرتا اور البتہ اگر میں اپنے رب کے ہاں لوٹایا بھی گیا تو اس سے بھی بہتر جگہ پاؤں گا\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmclxxvii{اسے اس کے ساتھی نے گفتگو کے دوران میں نے کہا کیا تو اس کا منکر ہو گیا ہے جس نے تجھے مٹی سے پھر نطفہ سے بنایا پھر تجھے پورا آدمی بنا دیا\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmclxxviii{لیکن میرا تو الله ہی رب ہے اور میں اس کے ساتھ کسی کو شریک نہیں کروں گا\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmclxxix{اور جب تو اپنے باغ میں آیا تھا تو نے کیوں نہ کہا جو الله چاہے تو ہوتا ہے اور الله کی مدد کے سوا کوئی طاقت نہیں اگر تو مجھے دیکھتا ہے کہ میں تجھ سے مال اور اولاد میں کم ہوں\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmclxxx{پھر امید ہے کہ میرا رب مجھے تیرے باغ سے بہتر دے اور اس پر لو کا ایک جھونکا آسمان سے بھیج دے پھر وہ چٹیل میدان ہوجائے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmclxxxi{یا اس کا پانی خشک ہوجائے پھر تو اسے ہرگز تلاش کرکے نہ لاسکے گا\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmclxxxii{اور اس کا پھل سمیٹ لیا گیا پھر وہ اپنے ہاتھ ہی ملتا رہ گیا اس پر جو اس نے اس باغ میں خرچ کیا تھا اور وہ اپنی چھتریوں پر گرا پڑا تھا اور کہا کاش میں اپنے رب کے ساتھ کسی کو شریک نہیں کرتا\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmclxxxiii{اور اس کی کوئی جماعت نہ تھی جو الله کےسوا اس کی مدد کرتے اور نہ وہ خود ہی بدلہ لے سکا\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmclxxxiv{یہاں سب اختیار الله سچے ہی کا ہے اسی کا انعام بہتر ہے اور اسی کا دیاہوا بدلہ اچھا ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmclxxxv{اور ان سے دنیا کی زندگی کی مثال بیان کرو مثل ایک پانی کے ہے جسے ہم نے آسمان سے برسایا پھر زمین کی روئیدگی پانی کے ساتھ مل گئی پھر وہ ریزہ ریز ہ ہو گئی کہ اسے ہوا ئیں اڑاتی پھرتی ہیں اور الله ہر چیز پر قدرت رکنے والا ہے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmclxxxvi{مال اور اولاد تو دنیا کی زندگی کی رونق ہیں اور تیرے رب کے ہاں باقی رہنے والی نیکیاں ثواب اور آخرت کی امید کے لحاظ سے بہتر ہیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmclxxxvii{اورجس دن ہم پہاڑوں کو چلائیں گے اور تو زمین کو صاف میدان دیکھے گا اور سب کو جمع کریں گے اور ان میں سے کسی کو بھی نہ چھوڑیں گے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmclxxxviii{اور سب تیرے رب کے سامنے صف باندھ کر پیش کیے جائیں گے البتہ تحقیق تم ہمارے پاس آئے ہو جیسا ہم نے تم کو پہلی بار پیدا کیا تھا بلکہ تم نے خیال کیا تھا کہ ہم تمہارے لیے کوئی وعدہ مقرر نہ کریں گے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmclxxxix{اور اعمال نامہ رکھ دیا جائے گا پھر مجرموں کو دیکھے گا اس چیز سے ڈرنے والے ہوں گے جو اس میں ہے اور کہیں گے افسوس ہم پر یہ کیسا اعمال نامہ ہے کہ اس نے کوئی چھوٹی یا بڑی بات نہیں چھوڑی مگر سب کو محفوظ کیا ہوا ہے اورجو کچھ انہوں نے کیا تھا سب کو موجود پائیں گے اور تیرا رب کسی پر ظلم نہیں کرے گا\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmcxc{اور جب ہم نے فرشتوں سے کہا آدم کو سجدہ کرو تو سوائے ابلیس کے سب نے سجدہ کیا وہ جنوں میں سے تھا سو اپنے رب کے حکم کی نافرمانی کی پھر کیا تم مجھے چھوڑ کر اسے اور اس کی اولاد کو کارساز بناتے ہو حالانکہ وہ تمہارے دشمن ہیں بے انصافوں کو برا بدل ملا\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmcxci{نہ تو آسمان اور زمین کے بناتے وقت اور نہ انہیں بناتے وقت میں نے انہیں بلایا اورمیں گمراہ کرنے والوں کو اپنا مددگار بنانے والا نہ تھا\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmcxcii{اورجس دن فرمائے گا میرے شریکوں کو پکارو جنہیں تم مانتے تھے پھر وہ انہیں پکاریں گے سو وہ انہیں جواب نہیں دیں گے اور ہم نے ان کے درمیان ہلاکت کی جگہ بنا دی ہے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmcxciii{اور گناہگار آگ کو دیکھیں گے اور سمجھیں گے کہ وہ اس میں گرنے والے ہیں اور اس سے بچنے کی کوئی راہ نہ پائیں گے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmcxciv{اور البتہ تحقیق ہم نے اس قرآن میں ان لوگوں کے لیے ہر ایک مثال کو کئی طرح سے بیان کیا ہے اور انسان بڑا ہی جھگڑالو ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmcxcv{اور جب ان کے پاس ہدایت آئی تو انہیں ایمان لانے اور اپنے رب سے معافی مانگنے سے کوئی چیز مانع نہیں ہوئی سوائے اس کے کہ انہیں پہلی امتوں کا سا معاملہ پیش آئے یا عذاب ان کے سامنے آجائے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmcxcvi{اور ہم رسولوں کو صرف خوشخبری دینے اور ڈرانے والا بنا کر بھیجتے ہیں اور کافر نا حق جھگڑا کرتے ہیں تاکہ ا س سے سچی بات کو ٹلا دیں اور انہوں نے میری آیتوں کو اور جس سے انہیں ڈرایا گیا ہے مذاق بنا لیا ہے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmcxcvii{اور اس سے زیادہ ظالم کون ہے جسے اس کے رب کی آیتوں سے نصیحت کی جائے پھر ان سے منہ پھیر لے اور جو کچھ اس کے ہاتھوں نے آگے بھیجا ہے بھول جائے بے شک ہم نے ان کے دلوں پر پردے ڈال دیے ہیں کہ اسے نہ سمجھیں اور ان کے کانوں میں گرانی ہے اور اگر تو انہیں ہدایت کی طرف بلائے تو بھی وہ ہر گز کبھی راہ پر نہ آئیں گے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmcxcviii{اور تیرا رب بڑا بخنشے والا رحمت والا ہے اگر ان کے کیے پر انہیں پکڑنا چاہتا تو فوراً ہی عذاب بھیج دیتا بلکہ ان کے لیے ایک معیاد مقرر ہے اس کے سوا کوئی پناہ کی جگہ نہیں پائیں گے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmcxcix{اور یہ بستیاں ہیں جنہیں ہم نے ہلک کیا ہے جب انہوں نے ظلم کیا تھا اور ہم نے ان کی ہلاکت کا بھی ایک وقت مقرر کیا تھا\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmcc{اورجب موسیٰ نے اپنے جوان سے کہا کہ میں نہ ہٹوں گا یہاں تک کہ دو دریاؤں کے ملنے کی جگہ پر پہنچ جاؤں یا سالہا سال چلتا جاؤں\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmcci{پھر جب وہ دو دریاؤں کے جمع ہونے کی جگہ پر پہنچے دونوں اپنی مچھلی کو بھول گئے پھر مچھلی نے دریا میں سرنگ کی طرح کا راستہ بنا لیا\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmccii{پھر جب وہ دونوں آگے بڑھ گئے تو اپنے جوان سے کہا کہ ہمارا ناشہ لے آ۔ البتہ تحقیق ہم نے اس سفر میں تکلیف اٹھائی ہے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmcciii{کہا کیا تو نے دیکھا جب ہم اس پتھر کے پاس ٹھرے تومیں مچھلی کو وہیں بھول آیا اور مجھے شیطان ہی نے بھلایا ہے کہ اس کا ذکر کروں اور اس نے اپنی راہ سمندر میں عجیب طرح سے بنا لی\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmcciv{کہا یہی ہے جو ہم چاہتے تھے پھر اپنے قدموں کے نشان دیکھتے ہی الٹے پھرے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmccv{پھر ہمارے بندوں میں سے ایک بندہ کو پایا جسے ہم نے اپنے ہاں سے رحمت دی تھی اوراسے ہم نے اپنے پاس سے ایک علم سکھایا تھا\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmccvi{اسے موسیٰ نے کہا کیا میں تیرے ساتھ رہوں اس شرط پر کہ تو مجھے سکھائے اس میں سے جو تجھے ہدایت کا طریقہ سکھایا گیا ہے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmccvii{کہا بے شک تو میرے ساتھ ہر گز صبر نہیں کر سکے گا\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmccviii{اورتو صبر کیسے کرے گا اس بات پر جو تیری سمجھ میں نہیں آئے گی\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmccix{کہا انشاالله تو مجھے صابر ہی پائے گا اور میں کسی بات میں بھی تیری مخالفت نہیں کروں گا\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmccx{کہا پس اگر تو میرے ساتھ رہے تو مجھ سے کسی بات کا سوال نہ کر یہاں تک کہ میں تیرے سامنے اس کا ذکر کروں پس دونوں چلے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmccxi{یہاں تک کہ جب کشتی میں سوار ہوئے تو اسے پھاڑ دیا کہا کیا تو نے اس لیے پھاڑا ہے کہ کشتی کے لوگوں کو غرق کر دے البتہ تو نے خطرناک بات کی ہے\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmccxii{کہا کیا میں نے تجھے نہیں کہا تھا کہ تو میرے ساتھ صبر نہیں کر سکے گا\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmccxiii{کہا میرے بھول جانے پر گرفت نہ کر اورمیرے معاملہ میں سختی نہ کر\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmccxiv{پھر دونوں چلے یہاں تک کہ انہیں ایک لڑکا ملا تو اسے مار ڈالا کہا تو نے ایک بے گناہ کو ناحق مار ڈالا البتہ تو نے بڑی بات کی\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmccxv{کہا کیا میں نے تجھے نہیں کہا تھا کہ تو میرے ساتھ صبر نہیں کر سکے گا\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmccxvi{کہا اگراس کے بعدمیں آپ سے کسی چیز کا سوال کروں تو مجھے ساتھ نہ رکھیں آپ میری طرف سے معذوری تک پہنچ جائیں گے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmccxvii{پھر ودنوں چلے یہاں تک کہ جب ایک گاؤں والوں پر گزرے توان سے کھانا مانگا انہوں نے مہمان نوازی سے انکار کر دیا پھر انہوں نے وہاں ایک دیوار پائی جو گرنےہی والی تھی تب اسے سیدھا کر دیا کہا اگر آپ چاہتے تو اس کام پر کوئی اجرت ہی لے لیتے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmccxviii{کہا اب میرے اور تیرے درمیان جدائی ہے اب میں تجھے ان باتوں کا راز بتاتا ہوں جن پر تو صبر نہ کر سکا\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmccxix{جو کشتی تھی سو وہ محتاج لوگوں کی تھی جو دریا میں مزدوری کرتے تھے پھر میں نے اس میں عیب کر دینا چاہا اور ان کے آگے ایک بادشاہ تھا جو ہر ایک کشتی کو زبردستی پکڑ رہا تھا\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmccxx{اور رہا لڑکا سو اس کے ماں باپ ایمان دار تھے سو ہم ڈرے کہ انہیں بھی سر کشی اور کفر میں مبتلا نہ کرے\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmccxxi{پھر ہم نے چاہا کہ ان کا رب اس کے بدلہ میں انہیں ایسی اولاد دے جو پاکیزگی میں اس سے بہتر اور محبت میں اس سے بڑھ کر ہو\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmccxxii{اور جو دیوار تھی سو وہ اس شہر کے دو یتیم بچوں کی تھی اور اس کے نیچے ان کا خزانہ تھا اور ان کا باپ نیک آدمی تھا پس تیرے رب نے چاہا کہ وہ جوان ہو کر اپنا خزانہ تیرے رب کی مہربانی سے نکالیں اور یہ کام میں نے اپنے ارادے سے نہیں کیا یہ حقیقت ہے اس کی جس پر تو صبر نہیں کر سکا\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmccxxiii{اور آپ سے ذوالقرنین کا حال پوچھتے ہیں کہہ دو کہ اب میں تمہیں اس کا حال سناتا ہوں\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmccxxiv{ہم نے اسے زمین میں حکمرانی دی تھی اور اسے ہر طرح کا سازو سامان دیا تھا\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmccxxv{تو اس نے ایک ساز و سامان تار کیا\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmccxxvi{یہاں تک کہ جب سورج ڈوبنے کی جگہ پہنچا تو اسے ایک گرم چشمے میں ڈوبتا ہوا پایا اور وہاں ایک قوم بھی پائی ہم نے کہااے ذوالقرنین یا انھیں سزا دے اور یا ان سے نیک سلوک کر\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmccxxvii{کہا جو ان میں ظالم ہے اسے تو ہم سزا ہی دیں گے پھر وہ اپنے رب کے ہاں لوٹایا جائے گا پھر وہ اسے اوربھی سخت سزا دے گا\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmccxxviii{اور جو کوئی ایمان لائے گا اور نیکی کرے گا تو اسے نیک بدلہ ملے گا اور ہم بھی اپنے معاملے میں اسے آسان ہی حکم دیں گے\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmccxxix{پھر اس نے ایک ساز و سامان تیار کیا\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmccxxx{یہاں تک کہ جب سورج نکلنے کی جگہ پہنچا تو اس نے سورج کو ایک ایسی قوم پر نکلتے ہوئے پایا کہ جس کے لیے ہم نے سورج کے ادھر کوئی آڑ نہیں رکھی تھی\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmccxxxi{اسی طرح ہی ہے اور اس کے حال کی پوری خبر ہمارےہی پاس ہے\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmccxxxii{پھر اس نے ایک ساز و سامان تیار کیا\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmccxxxiii{یہاں تک کہ جب دو پہاڑوں کے درمیان پہنچا ان دونوں سے اس طرف ایک ایسی قوم کو دیکھا جو بات نہیں سمجھ سکتی تھی\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmccxxxiv{انہوں نے کہا کہ اے ذوالقرنین بے شک یاجوج ماجوج اس ملک میں فساد کرنے والے ہیں پھر کیا ہم آپ کے لیے کچھ محصول مقرر کر دیں اس شرط پر کہ آپ ہمارےاور ان کے درمیان ایک دیوار بنا دیں\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mmccxxxv{کہا جو میرے رب نے قدرت دی ہے کافی ہے سو طاقت سے میری مدد کرو کہ میں تمہارے اور ان کے درمیان ایک مضبوط دیوار بنا دوں\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mmccxxxvi{مجھے لوہے کے تختے لا دو یہاں تک کہ جب دونوں سروں کے بیچ کو برابر کر دیا تو کہا کہ دھونکو یہاں تک کہ جب اسے آگ کر دیا تو کہا کہ تم میرے پاس تانبا لاؤ تاکہ اس پر ڈال دوں\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mmccxxxvii{پھر وہ نہ اس پر چڑھ سکتے تھے اور نہ اس میں نقب لگا سکتے تھے\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mmccxxxviii{کہا یہ میرے رب کی رحمت ہے پھر جب میرے رب کا وعدہ آئے گا تو اسے ریزہ ریزہ کر دے گا اور میرے رب کا وعدہ سچا ہے\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mmccxxxix{اور ہم چھوڑدیں گے بعض ان کے اس دن بعض میں گھسیں گے اور صورمیں پھونکا جائے گا پھر ہم ان سب کو جمع کر یں گے\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mmccxl{اور ہم دوزخ کو اس دن کافروں کے سامنے پیش کریں گے\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mmccxli{جن کی آنکھوں پر ہماری یاد سے پردہ پڑا ہوا تھا اور وہ سن بھی نہ سکتے تھے\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mmccxlii{پھر کافر کیا خیال کرتے ہیں کہ میرے سوا میرےبندوں کو اپنا کارساز بنا لیں گے بے شک ہم نے کافروں کے لیے دوزخ کو مہمانی بنایاہے\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mmccxliii{کہہ دو کیا میں تمہیں بتاؤں جو اعمال کے لحاظ سے بالکل خسارے میں ہیں\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mmccxliv{وہ جن کی ساری کوشش دنیا کی زندگی میں کھوئی گئی اور وہ خیال کرتے ہیں کہ بے شک وہ اچھے کام کر رہے ہیں\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mmccxlv{یہ وہی لوگ ہیں جنہوں نے اپنے رب کی نشانیوں کا اور اس کے روبرو جانے کا انکار کیا ہے پھر ان کے سارے اعمال ضائع ہو گئے سو ہم ان کے لیے قیامت کے دن کوئی وزن قائم نہیں کریں گے\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mmccxlvi{یہ سزا ا ن کی جہنم ہے ا سلیے کہ انہوں نے کفر کیا اور میری آیتوں اور میرے رسولوں کا مذاق بنایا تھا\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mmccxlvii{بے شک جو لوگ ایمان لائے اور اچھے کام کئے ان کی مہمانی کے لیے فردوس کے باغ ہوں گےبے شک جو لوگ ایمان لائے اور اچھےکام کئےان کی مہمانی کے لیے فردوس کے باغ ہوں گے\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mmccxlviii{ان میں ہمیشہ رہیں گے وہاں سے جگہ بدلنی نہ چاہیں گے\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mmccxlix{کہہ دو اگر میرے رب کی باتیں لکھنےکے لئے سمندر سیاہی بن جائے تو میرے رب کی باتیں ختم ہونے سے پہلے سمندر ختم ہو جائے اور اگرچہ اس کی مدد کے لیے ہم ایسا ہی اور سمندر لائیں\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mmccl{کہہ دو کہ میں بھی تمہارے جیسا آدمی ہی ہوں میری طرف وحی کی جاتی ہے کہ تمہارا معبود ایک ہی معبود ہے پھر جو کوئی اپنے رب سے ملنے کی امید رکھے تو اسے چاہیئے کہ اچھے کام کرے اور اپنے رب کی عبادت میں کسی کو شریک نہ بنائے\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mmccli{\basmalahur کھیصۤ\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmcclii{یہ تیرے رب کی مہربانی کا ذکر ہے جو اس کے بندے زکریا پر ہوئی\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmccliii{جب اس نے اپنے رب کو خفیہ آواز سے پکارا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmccliv{کہا اے میرے رب میری ہڈیاں کمزور ہو گئی ہیں اور سر میں بڑھاپا چمکنے لگا ہے او رمیرے رب تجھ سے مانگ کر میں کبھی محروم نہیں ہوا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmcclv{اور بے شک میں اپنے بعد اپنے رشتہ داروں سے ڈرتا ہوں اور میری بیوی بانجھ ہے پس تو اپنے ہاں سے ایک وارث عطا کر\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmcclvi{جو میرا اور یعقوب کے خاندان کا بھی وارث ہو اور میرے رب اسے پسندیدہ بنا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmcclvii{اے زکریا بے شک ہم تجھے ایک لڑکے کی خوشخبری دیتے ہیں جس کا نام یحییٰ ہوگا اس سےپہلے ہم نے اس نام کا کوئی پیدا نہیں کیا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmcclviii{کہا اے میرے رب میرے لیے لڑکا کہاں سے ہوگا حالانکہ میری بیوی بانجھ ہے اور میں بڑھاپے میں انتہائی درجہ کو پہنچ گیا ہوں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmcclix{کہا ایسا ہی ہوگا تیرے رب نے کہاہے وہ مجھ پر آسان ہے اور میں نے تجھے اس سے پہلے پیدا کیا حالانکہ تو کوئی چیز نہ تھا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmcclx{کہا اے میرے رب میرے لئےکوئی نشانی مقرر کر کہا تیری نشانی یہ ہے کہ توتین رات تک مسلسل لوگوں سے بات نہیں کر سکے گا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmcclxi{پھر حجرہ سے نکل کر اپنی قوم کے پاس آئے اور انہیں اشارہ سے کہا کہ تم صبح و شام خدا کی تسبیح کیا کرو\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmcclxii{اے یحییٰ کتاب کو مضبوطی سے پکڑ اور ہم نے اسےبچپن ہی میں حکمت عطا کی\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmcclxiii{اور اسے اپنے ہاں سے رحم دلی او رپاکیز گی عنایت کی اور وہ پرہیز گار تھا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmcclxiv{اور اپنے ماں باپ کے ساتھ نیک سلوک کرنے والا اور سرکش نافرمان نہ تھا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmcclxv{اور اس پر سلام ہو جس دن وہ پیدا ہوا اور جس دن مرے گا اور جس دن وہ زندہ کرکے اٹھایا جائے گا\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmcclxvi{اور اس کتاب میں مریم کا ذکر کر جب کہ وہ اپنے لوگوں سے علیحدہ ہو کر مشرقی مقام میں جا بیٹھی\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmcclxvii{پھر لوگوں کے سامنے سے پردہ ڈال لیا پھر ہم نے اس کے پاس اپنے فرشتے کو بھیجا پھر وہ اس کے سامنے پورا آدمی بن کر ظاہر ہوا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmcclxviii{کہا بے شک میں تجھ سے الله کی پناہ مانگتی ہوں اگر تو پرہیزگار ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmcclxix{کہا میں تو بس تیرے رب کا بھیجا ہوا ہوں تاکہ تجھے پاکیزہ لڑکا دوں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmcclxx{کہا میرے لیے لڑکا کہاں سے ہوگا حالانکہ مجھے کسی آدمی نے ہاتھ نہیں لگایا اور نہ میں بدکار ہوں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmcclxxi{کہا ایسا ہی ہوگا تیرے رب نے کہا ہے وہ مجھ پر آسان ہے اور تاکہ ہم اسے لوگوں کے لیے نشانی اور اپنی طرف سے رحمت بنائیں اور یہ بات طے ہو چکی ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmcclxxii{پھر اس (بچہ کے ساتھ) حاملہ ہوئی پھر اسے لے کر کسی دور جگہ میں چلی گئی\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmcclxxiii{پھر اسے درد زہ ایک کھجور کی جڑ میں لے آیا کہا اے افسوس میں اس سے پہلے مرگئی ہوتی اور میں بھولی بھلائی ہوتی\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmcclxxiv{پھر اسے اس کے نیچے سے پکارا کہ غم نہ کر تیرے رب نے تیرے نیچے سے ایک چشمہ پیدا کر دیا\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmcclxxv{اورتو کھجور کے تنہ کو پکڑ کر اپنی طرف ہلا تجھ پر پکی تازہ کھجوریں گریں گی\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmcclxxvi{سوکھا اور پی اور آنکھ ٹھنڈی کر پھر اگر تو کوئی آدمی دیکھے تو کہہ دے کہ میں نے رحمان کے لیے روزہ کی نذر مانی ہے سو آج میں کسی انسان سے بات نہیں کروں گی\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmcclxxvii{پھر وہ اسے قوم کے پا س اٹھا کر لائی انہوں نے کہا اے مریم البتہ تو نے عجیب بات کر دکھائی\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmcclxxviii{اے ہارون کی بہن نہ تو تیرا باپ ہی برا آدمی تھا اور نہ ہی تیری ماں بدکار تھی\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmcclxxix{تب اس نے لڑکے کی طرف اشارہ کیا انہوں نے کہا ہم پنگوڑھے والے بچے سے کیسے بات کریں\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmcclxxx{کہا بے شک میں الله کا بندہ ہوں مجھےاس نے کتاب دی ہے اور مجھے نبی بنایا ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmcclxxxi{اور مجھے با برکت بنایاہے جہاں کہیں ہوں اور مجھے کو نماز اور زکواة کی وصیت کی ہے جب تک میں زندہ ہوں\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmcclxxxii{اور اپنی ماں کے ساتھ نیکی کرنے والا اور مجھے سرکش بدبخت نہیں بنایا\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmcclxxxiii{اور مجھ پر سلام ہے جس دن میں پیدا ہوا اور جس دن مروں گا اور جس دن زندہ کر کے اٹھایا جاؤں گا\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmcclxxxiv{یہ عیسیٰ مریم کا بیٹا ہے سچی بات جس میں وہ جھگڑ رہے ہیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmcclxxxv{الله کی شان نہیں کہ وہ کسی کو بیٹا بنائے وہ پاک ہے جب کسی کام کا فیصلہ کرتا ہے توصرف اسے کن کہتا ہے پھر وہ ہو جاتا ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmcclxxxvi{اور بے شک الله تعالیٰ میرا اور تمہارا رب ہے سواسی کی عبادت کرو یہ سیدھا راستہ ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmcclxxxvii{پھر جماعتیں آپس میں مختلف ہو گئیں سوکافروں کے لیے ایک بڑے دن کے آنے سے خرابی ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmcclxxxviii{کیا خوب سنتے اور دیکھتے ہوں گے جس دن ہمارے پاس آئیں گے لیکن ظالم آج صریح گمراہی میں ہیں\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmcclxxxix{اور انہیں حسرت کے دن سے ڈرا جس دن سارے معاملہ کا فیصلہ ہوگا اور وہ غفلت میں ہیں او رایمان نہیں لاتے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmccxc{بے شک ہم ہی زمین کے وارث ہوں گے اور ان کے بھی جو اس پر ہیں اور ہماری طرف لوٹائے جائیں گے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmccxci{اور کتاب میں ابراھیم کا ذکر بے شک وہ سچا نبی تھا\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmccxcii{جب اپنے باپ سے کہا اے میرے باپ تو کیوں پوجتاہے ایسے کو جونہ سنتا ہے اور نہ دیکھتا ہے اور نہ تیرےکچھ کام آ سکے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmccxciii{اے میرے باپ بے شک مجھے وہ علم حاصل ہوا ہے جو تمہیں حاصل نہیں تو آپ میری تابعداری کریں میں آپ کو سیدھا راستہ دکھاؤں گا\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmccxciv{اے میرے باپ شیطان کی عبادت نہ کر بے شک شیطان الله کا نافرمان ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmccxcv{اے میرے باپ بے شک مجھے خوف ہے کہ تم پر الله کا عذاب آئے پھر شیطان کے ساتھی ہوجاؤ\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmccxcvi{کہا اے ابراھیم کیا تو میرے معبودوں سے پھرا ہوا ہے البتہ اگر تو باز نہ آیا میں تجھے سنگسار کردوں گا اور مجھ سے ایک مدت تک دور ہو جا\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmccxcvii{کہا تیری سلامتی رہے اب میں اپنے رب سے تیری بخشش کی دعا کروں گا بے شک وہ مجھ پر بڑا مہربان ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmccxcviii{اور میں تمہیں چھوڑتا ہوں اور جنہیں تم الله کے سوا پکارتے ہو اور میں اپنے رب ہی کو پکاروں گا امید ہے کہ میں اپنے رب کو پکار کر محروم نہ رہوں گا\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmccxcix{پھر جب ان سے علیحدٰہ ہوا اور اس چیز سے جنہیں وہ الله کے سوا پوجتے تھے ہم نے اسے اسحاق اور یعقوب عطا کیا اور ہم نے ہر ایک کو نبی بنایا\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmccc{اور ہم نے ان سب کو اپنی رحمت سے حصہ دیا اور ہم نے ان کا نیک نام بلند کیا\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmccci{اور کتاب میں موسیٰ کا ذکر کر بے شک وہ خاص بندے اور بھیجے ہوئے پیغمبر تھے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmcccii{اور ہم نے اسے کوہِ طور کے دائیں طرف سے پکارا اور اسے راز کی بات کہنے کے لیے قریب بلایا\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmccciii{اور ہم نے اسے اپنی رحمت سے ان کے بھائی ہارون کو نبی بنا کر عطا کیا\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmccciv{اور کتاب میں اسماعیل کا بھی ذکر کر بے شک وہ وعدہ کا سچا اور بھیجا ہوا پیغمبر تھا\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmcccv{اور اپنے گھر والوں کو نماز اور زکوٰةکا حکم کرتا تھا اور وہ اپنے رب کے ہاں پسندیدہ تھا\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmcccvi{اور کتاب میں ادریس کا ذکر کر بے شک وہ سچا نبی تھا\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmcccvii{اور ہم نے اسے بلند مرتبہ پر پہنچایا\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmcccviii{یہ وہ لوگ ہیں جن پر الله نے انعام کیا پیغمبروں میں اور آدم کی اولاد میں سے اور ان میں سے جنہیں ہم نے نوح کے ساتھ سوار کیا تھا اور ابراھیم اور اسرائیل کی اولاد میں سے اور ان میں سے جنہیں ہم نے ہدایت کی اور پسند کیا جب ان پر الله کی آیتیں پڑھی جاتی ہیں تو روتے ہوئے سجدے میں گرتے ہیں\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmcccix{پھر ان کی جگہ ایسے ناخلف آئے جنہو ں نے نماز ضائع کی اور خواہشوں کے پیچھے پڑ گئے پھر عنقریب گمراہی کی سزا پائیں گے\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmcccx{مگر جس نے توبہ کی اور ایمان لایا اور نیک کام کیے سو وہ لوگ بہشت میں داخل ہوں گے اور ان کا ذرا نقصان نہ کیا جائے گا\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmcccxi{ہمیشگی کے باغوں میں جن کا رحمان نے اپنے بندوں سے وعدہ کیا ہے جو ان کی آنکھوں سے پوشیدہ ہے بے شک اس کا وعدہ پورا ہونے والا ہے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmcccxii{اس میں سوائے سلام کے کوئی فضول بات نہ سنیں گے اور انہیں وہاں صبح و شام کھانا ملے گا\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmcccxiii{یہ وہ جنت ہے کہ ہم اپنے بندوں میں سے اس کو وارث بنائیں گے جو پرہیزگار ہوگا\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmcccxiv{اورہم تیرے رب کے حکم کے سوا نہیں اترتے اسی کا ہے جو کچھ ہمارے سامنے ہے اور جو کچھ ہمارے پیچھے ہے اور جو کچھ اس کے درمیان ہے او ر تیرا رب بھولنے والا نہیں\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmcccxv{آسمانوں اور زمین کا رب ہے اور جو چیز ان کے درمیان ہے سو اسی کی عبادت کرو اسی کی عبادت پر قائم رہ کیا تیرے علم میں ا س جیسا کوئی اور ہے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmcccxvi{اور انسان کہتا ہے جب میں مرجاؤں گا تو کیا پھر زندہ کر کے نکالا جاؤں گا\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmcccxvii{کیا انسان کو یاد نہیں ہے کہ اس سے پہلے ہم نے اسےبنایا تھا اور وہ کوئی چیز بھی نہ تھا\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmcccxviii{سو تیرے رب کی قسم ہے ہم انہیں اور ان کے شیطانوں کو ضرور جمع کریں گے پھر ہم انہیں گھٹنوں پر گرے ہوئے دوزخ کے گرد حاضر کریں گے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmcccxix{پھر ہر گروہ میں سے ان لوگوں کو الگ کر لیں گے جو الله سے بہت ہی سرکش تھے\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmcccxx{پھر ہم ان لوگو ں کو خوب جانتے ہیں جو دوزخ میں جانے کے زیادہ مستحق ہیں\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmcccxxi{اور تم میں سے کوئی بھی ایسا نہیں جس کا اس پر گزر نہ ہو یہ تیرے رب پر لازم مقرر کیا ہوا ہے\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmcccxxii{پھر ہم انہیں بچا لیں گے جو ڈرتے ہیں اور ظالموں کو اس میں گھٹنوں پر گرے ہوئے چھوڑ دیں گے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmcccxxiii{اور جب انہیں ہماری کھلی ہوئی آیتیں سنائی جاتی ہیں تو کافر ایمان داروں سے کہتے ہیں دونوں فریقوں میں سے کس کا مرتبہ بہتر ہے اور محفل کس کی اچھی ہے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmcccxxiv{اور ہم ان سے پہلے کتنی جماعتیں ہلاک کرچکے ہیں وہ سامان اور نمود میں بہتر تھے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmcccxxv{کہہ دو جو شخص گمراہی میں پڑا ہوا ہے سو الله بھی اسے ڈھیل دیتا ہے یہاں تک کہ جب اس چیز کو دیکھیں گے جس کا انہیں نے وعدہ دیا گیا تھا یا عذاب یا قیامت تب معلوم کر لیں گے مرتبے میں کون برا ہے اور لشکر کس کا کمزور ہے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmcccxxvi{اور جو لوگ ہدایت پر ہیں الله انہیں زیادہ ہدایت دیتا ہے اور باقی رہنے والی نیکیاں تیرے رب کے نزدیک ثواب اور انجام کے لحاظ سے بہت ہی بہتر ہیں\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmcccxxvii{کیا تو نے اس شخص کو دیکھا جس نے ہماری آیتوں کا انکار کیا اور کہتا ہے کہ مجھے ضرور مال اور اولاد ملے گی\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmcccxxviii{کیا اس نے غیب پر اطلاع پائی ہے یا اس نے الله سے اقرار لے رکھا ہے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmcccxxix{ہرگز نہیں ہم لکھ لیتے ہیں جو کچھ وہ کہتا ہے اور اس کے لیے عذاب بڑھاتے جاتے ہیں\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmcccxxx{اور ہم اس کے وارث ہوں گے جو کچھ وہ کہتا ہے او رہمارے ہاں تنہا آئے گا\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmcccxxxi{اور انہوں نے الله کے سوا معبود بنا لیے ہیں تاکہ وہ ان کے مددگار ہوں\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmcccxxxii{ہرگز نہیں وہ جلد ہی ان کی عبادت کا انکار کریں گے اور ان کے مخالف ہوجائیں گے\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmcccxxxiii{کیا تو نے نہیں دیکھا ہم نے شیطانو ں کوکافروں پر چھوڑ رکھا ہے وہ انھیں ابھارتے رہتے ہیں\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmcccxxxiv{سوتو ان کے لیے عذاب کی جلدی نہ کر ہم خود ان کے دن گن رہے ہیں\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmcccxxxv{جس دن ہم پرہیزگاروں کے رحمان کے پاس مہمان بنا کر جمع کریں گے\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmcccxxxvi{اور گناہگاروں کو دوزخ کی طرف پیاسا ہانکیں گے\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmcccxxxvii{کسی کو سفارش کا اختیار نہیں ہوگا مگر جس نے رحمان کے ہاں سے اجازت لی ہو\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmcccxxxviii{اورکہتے ہیں کہ رحمان نے بیٹا بنا لیا\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmcccxxxix{البتہ تحقیق تم سخت بات زبان پر لائے ہو\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmcccxl{کہ جس سے ابھی آسمان پھٹ جائیں اور زمین چر جائے اور پہاڑ ٹکڑے ہو کر گر پڑیں\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmcccxli{اس لئے کہ انہوں نے رحمان کے لیے بیٹا تجویز کیا\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmcccxlii{اور رحمان کی یہ شان نہیں کہ کسی کوبیٹا بنائے\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmcccxliii{جو کچھ آسمانوں اور زمین میں ہے ان میں سے ایسا کوئی نہیں جو رحمان کا بندہ بن کر نہ آئے\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmcccxliv{البتہ تحقیق اس نے انھیں شمار کر رکھا ہے اور ان کی گنتی گن رکھی ہے\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mmcccxlv{او رہر ایک ان میں سے اس کے ہاں اکیلا آئے گا\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mmcccxlvi{بے شک جو ایمان لائے اور نیک کام کیے عنقریب رحمان ان کے لیے محبت پیدا کرے گالاشبہ جو لوگ ایمان لائے اور انہوں نے اچھے کام کیے الله تعالیٰ ان کے لیے محبت پیدا کر ے گا\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mmcccxlvii{سو ہم نے فرمان کو تیری زبان میں اس لیےآسان کیا ہے کہ تو اس سے پرہیز گاروں کو خوشخبری سنا دے اور جھگڑنے والوں کو ڈرا دے\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mmcccxlviii{اور ہم ان سے پہلے کئی جماعتیں ہلاک کر چکے ہیں کیا تو کسی کی ان میں سے آہٹ پاتا ہے یا ان کی بھنک سنتا ہے\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mmcccxlix{\basmalahur طہۤ\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmcccl{ہم نے تم پر قرآن اس لیے نازل نہیں کیا کہ تم تکلیف اٹھاؤ\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmcccli{بلکہ اس شخص کے لیے نصیحت ہےجو ڈرتا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmccclii{اس کی طرف سے نازل ہوا ہے جس نے زمین اور بلند آسمانوں کو پیدا کیا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmcccliii{رحمان جو عرش پر جلوہ گر ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmcccliv{اسی کا ہے جو کچھ آسمانوں میں ہے اور جو کچھ زمین میں ہے اور جوکچھ گیلی زمین کے نیچے ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmccclv{اور اگرتو پکار کر بات کہے تو وہ پوشیدہ اور اس سے بھی زیادہ پوشیدہ کو جانتا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmccclvi{الله ہے جس کے سوا کوئی معبود نہیں اس کے سب نام اچھے ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmccclvii{اور کیا تجھے موسیٰ کی بات پہنچی ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmccclviii{جب اس نے آگ دیکھی تو اپنے گھر والوں سے کہا کہ ٹھہرو میں نے آگ دیکھی ہے شاید کہ میں اس سے تمہارے پاس کوئی چنگاری لاؤں یا وہاں کوئی رہبر پاؤں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmccclix{پھر جب وہ اس کے پاس آئے تو آواز آئی کہ اے موسیٰ\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmccclx{میں تمہارا رب ہوں سو تم اپنی جوتیاں اتار دو بے شک تم پاک وادی طویٰ میں ہو\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmccclxi{اور میں نے تجھے پسند کیا ہے جو کچھ وحی کی جارہی ہےاسے سن لو\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmccclxii{بے شک میں ہی الله ہوں میرے سوا کوئی معبود نہیں پس میری ہی بندگی کر اور میری ہی یاد کے لیے نماز پڑھا کر\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmccclxiii{بے شک قیامت آنے والی ہے میں اسے پوشیدہ رکھنا چاہتا ہوں تاکہ ہر شخص کو اس کے کیے کا بدلہ مل جائے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmccclxiv{سو تمہیں قیامت سے ایسا شخص باز نہ رکھنے پائے جو اس پر ایمان نہیں رکھتا اوراپنی خواہشوں پر چلتا ہے پھر تم تباہ ہوجاؤ\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmccclxv{اور اے موسیٰ تیرے دائیں ہاتھ میں کیا ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmccclxvi{کہا یہ میری لاٹھی ہے ا س پر ٹیک لگاتا ہوں اور اس سے اپنی بکریوں پر پتے جھاڑتا ہوں اور اس میں میرے لیے اور بھی فائدے ہیں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmccclxvii{فرمایا اے موسیٰ اسے ڈال دو\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmccclxviii{پھر اسے ڈال دیا تو اسی وقت وہ دوڑتا ہوا سانپ ہو گیا\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmccclxix{فرمایا اسے پکڑ لے اور نہ ڈر ہم ابھی اسےپہلی حالت پر پھیر دیں گے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmccclxx{اور اپنا ہاتھ اپنی بغل سے ملا دے بلا عیب سفید ہو کر نکلے گا یہ دوسری نشانی ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmccclxxi{تاکہ ہم تجھے اپنی بڑی نشانیوں میں سے بعض دکھائیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmccclxxii{فرعون کے پاس جا بے شک وہ سرکش ہو گیا ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmccclxxiii{کہا اے میرے رب میرا سینہ کھول دے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmccclxxiv{اورمیرا کام آسان کر\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmccclxxv{اور میری زبان سے گرہ کھول دے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmccclxxvi{کہ میری بات سمجھ لیں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmccclxxvii{اور میرے لیے میرے کنبے میں سے ایک معاون بنا دے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmccclxxviii{ہارون کو جو میرا بھائی ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmccclxxix{ا س سے میری کمر مضبوط کر دے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmccclxxx{اور اسے میرے کام میں شریک کر دے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmccclxxxi{تاکہ ہم تیری پاک ذات کا بہت بیان کریں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmccclxxxii{اور تجھے بہت یاد کریں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmccclxxxiii{بے شک تو ہمیں خوب دیکھتا ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmccclxxxiv{فرمایا اے موسیٰ تیری درخواست منظور ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmccclxxxv{اورالبتہ تحقیق ہم نے تجھ پر ایک دفعہ اور بھی احسان کیا ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmccclxxxvi{جب ہم نے تیری ماں کے دل میں بات ڈال دی تھی\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmccclxxxvii{کہ اسے صندوق میں ڈال دے پھر اسے دریا میں ڈال دے پر اسے دریا کنارے پر ڈال دے گا اسے میرا دشمن اور اس کا دشمن اٹھا لے گا اور میں نے تجھ پر اپنی طرف سے محبت ڈال دی اور تاکہ تو میرے سامنے پرورش پائے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmccclxxxviii{جب تیری بہن کہتی جا رہی تھی کیا تمہیں ایسی عورت بتاؤں جو اسے اچھی طرح پالے پھر ہم نے تجھے تیری ماں کے پاس پہنچا دیا کہ اس کی آنکھ ٹھنڈی ہو اور غم نہ کھائے اور تو نے ایک شخص کو مار ڈالا پھر ہم نے تجھے اس غم سے نکالا اور ہم نے تجھے کئی مرتبہ آزمائش میں ڈالا پھر تو مدین والوں میں کئی برس رہا پھر تو اے موسیٰ تقدیر سے یہاں آیا\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmccclxxxix{اور میں نے تجھے خاص اپنے واسطے بنایا\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmcccxc{تو اور تیرا بھائی میری نشانیاں لے کر جاؤ اور میری یاد میں کوتاہی نہ کرو\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmcccxci{فرعون کے پاس جاؤ بے شک وہ سرکش ہو گیا ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmcccxcii{سو اس سے نرمی سے بات کرو شاید وہ نصیحت حاصل کرے یا ڈر جائے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmcccxciii{کہا اے ہمارے رب ہمیں ڈر ہے کہ وہ ہم پر زیادتی کرے یا یہ کہ زیادہ سرکشی کرے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmcccxciv{فرمایا ڈرو مت میں تمہارے ساتھ سنتا اور دیکھتا ہوں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmcccxcv{سو تم دونوں اس کے پاس جاؤ اورکہو کہ بے شک ہم تیرے رب کی طرف سے پیغام لے کر آئے ہیں کہ بنی اسرائیل کو ہمارے ساتھ بھیج دے اور انہیں تکلیف نہ دے ہم تیرے پاس تیرے رب کی طرف سے نشانی لے کر آئے ہیں اور سلامتی اس کے لیے ہے جو سیدھی راہ پر چلے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmcccxcvi{بے شک ہمیں وحی سے بتایا گیا ہے کہ عذاب اسی پر ہوگا جو جھٹلائے اور منہ پھیر لے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmcccxcvii{کہا اے موسیٰ پھر تمہارا رب کون ہے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmcccxcviii{کہا ہمارا رب وہ ہے جس نے ہر چیز کو اس کی صورت عطا کی پھر راہ دکھائی\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmcccxcix{کہا پھر پہلی جماعتوں کا کیا حال ہے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmcd{کہا ان کا علم میرے رب کے ہاں کتاب میں ہے میرا رب نہ غلطی کرتا ہے اور نہ بھولتا ہے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmcdi{جس نے تمہارے لیے زمین کو بچھونا بنایا اور تمہارے لیے اس میں راستے بنائے اور آسمان سے پانی نازل کیا پھر ہم نے اس میں طرح طرح کی مختلف سبزیاں نکالیں\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmcdii{کھاؤ اور اپنے مویشیوں کو چراؤ بے شک اس میں عقل والوں کے لیے نشانیاں ہیں\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmcdiii{اسی زمین سے ہم نے تمہیں بنایا اور اسی میں لوٹائیں گے اور دوبارہ اسی سے نکالیں گے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmcdiv{اورہم نے فرعون کو اپنی سب نشانیاں دکھا دیں پھر اس نے جھٹلایا اورانکار کیا\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmcdv{کہا اے موسیٰ کیا تو ہمیں اپنے جادو سے ہمارے ملک سے نکالنے کے لیے آیا ہے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmcdvi{سو ہم بھی تیرے مقابلے میں ایک ایسا ہی جادو لائیں گے سوہمارے او راپنے درمیان ایک وعدہ مقرر کر دے نہ ہم اس کے خلاف کریں اورنہ تو کسی صاف میدان میں\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmcdvii{کہا تمہارا وعدہ جشن کا دن ہے اور دن چڑھے لوگ اکھٹے کیے جائیں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmcdviii{پھر فرعون لوٹ گیا اور اپنے مکر کا سامان جمع کیا پھر آیا\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmcdix{موسیٰ نے کہا افسوس تم الله پر بہتان نہ باندھو ورنہ وہ کسی عذاب سے تمہیں ہلاک کر دے گا اوربے شک جس نے جھوٹ بنایا وہ غارت ہوا\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmcdx{پھر ان کا آپس میں اختلاف ہو گیا اور خفیہ گفتگو کرتے رہے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmcdxi{کہا بے شک یہ دونوں جادوگر ہیں چاہتے ہیں کہ اپنے جادو کے زور سے تمہیں تمہارے ملک سے نکال دیں اور تمہارے عمدہ طریقہ کو موقوف کر دیں\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmcdxii{پھر تم اپنی تدبیر جمع کر کے صف باندھ کر آؤ اور تحقیق آج جیت گیا جو غالب رہا\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmcdxiii{کہا اے موسیٰ یا تو ڈال اوریا ہم پہلے ڈالنے والے ہوں\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmcdxiv{کہا بلکہ تم ڈالو پس اچانک ان کی رسیاں او رلاٹھیاں ان کے جادو سے اس کے خیال میں دوڑ رہی ہیں\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmcdxv{پھر موسیٰ نے اپنے دل میں ڈر محسوس کیا\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmcdxvi{ہم نے کہا ڈرو مت بیشک تو ہی غالب ہوگا\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmcdxvii{او رجو تیرے دائیں ہاتھ میں ہے ڈال دے کہ نگل جائے جو کچھ انہوں نے بنایا ہےجو کچھ کہ انہوں نے بنایا ہے صرف جادوگر کا فریب ہے اورجادوگر کا بھلا نہیں ہوتا جہاں بھی ہو\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmcdxviii{پھر جادوگر سجدہ میں گر پڑے کہا ہم ہارون اورموسیٰ کے رب پر ایمان لائے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmcdxix{کہا تم میری اجازت سے پہلےہی اس پر ایمان لے آئے بے شک یہ تمہارا سردار ہے جس نے تمہیں جادو سکھایا سو اب میں تمہارے ہاتھ اور دوسری طرف کے پاؤں کٹواؤں گا اورتمہیں کھجور کے تنوں پر سولی دوں گا اورتمہیں معلوم ہوجائے گا ہم میں سے کس کا عذاب سخت اور دیر تک رہنے والا ہے\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmcdxx{کہا ہم تجھے ہرگزترجیح نہ دیں گے ان کھلی ہوئی نشانیوں کے مقابلہ میں جو ہمارے پاس آ چکی ہیں اورنہ اس کے مقابلہ میں جس نے ہمیں پیدا کیا ہے سو تو کر گزر جو تجھے کرنا ہے تو صرف اس دنیا کی زندگی پر حکم چلا سکتا ہے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmcdxxi{بے شک ہم اپنے رب پر ایمان لائے ہیں تاکہ ہمارے گناہ معاف کرے اور جو تو نے ہم سے زبردستی جادو کرایا اور الله بہتر اور سدا باقی رہنے والا ہے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmcdxxii{بے شک جو شخص اپنے رب کے پا س مجرم ہو کر آئے گا سواس کے لیے دوزخ ہے جس میں نہ مرے گا اور نہ جیے گا\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmcdxxiii{اورجو اس کے پاس مومن ہوکر آئے گا حالانکہ اس نے اچھے کام بھی کیے ہوں تو ان کے لیے بلند مرتبے ہوں گے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmcdxxiv{ہمیشہ رہنے کے باغ جن کے نیچے نہریں بہتی ہوں گی وہ ان میں ہمیشہ رہیں گے اور یہ اس کی جزا ہے جو گناہ سے پاک ہوا\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmcdxxv{او رہم نے البتہ موسیٰ کو وحی کی کہ میرے بندوں کو راتوں رات لے جا پھر ان کے لیے دریامیں خشک راستہ بنا دے پکڑے جانے سے نہ ڈر اور نہ کسی خطرہ کا خوف کھا\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmcdxxvi{پھر فرعون نے اپنے لشکر کو لے کر ان کا پیچھا کیا پھر انہیں دریا نےڈھانپ لیا جیسا ڈھانپا\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmcdxxvii{اور فرعون نے اپنی قوم کو بہکایا اور راہ پر نہ لایا\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmcdxxviii{اے بنی اسرائیل ہم نے تمہیں تمہارے دشمن سے نجات دی اور تم سے طور کی دائیں طرف کا وعدہ کیا اور تم پر من و سلویٰ اتارا\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmcdxxix{کھاؤ جو ستھری چیزیں ہم نے تمہیں دی ہیں اور اس میں حد سے نہ گزرو پھر تم پر میرا غضب نازل ہو گا اور جس پرمیرا غضب نازل ہوا سو وہ گڑھے میں جا گرا\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmcdxxx{اور بے شک میں بڑا بخشنے والا ہوں اس کو جو توبہ کرے اور ایمان لائے اور اچھے کام کرے پھر ہدایت پر قائم رہے\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmcdxxxi{اور اے موسیٰ تجھے اپنی قوم سے پہلے جلدی آنے کا کیا سبب ہوا\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmcdxxxii{کہا وہ بھی میرے پیچھے یہ آ رہے ہیں اور اے میرے رب میں جلدی تیرے طرف آیا تاکہ تو خوش ہو\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmcdxxxiii{فرمایا تیری قوم کو تیرے بعد ہم نے آزمائش میں ڈال دیاہےاور انہیں سامری نے گمراہ کر دیا ہے\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmcdxxxiv{پھر موسیٰ اپنی قوم کی طرف غصہ میں بھرے ہوئے افسوس کرتے ہوئے لوٹے کہا اے میری قوم کیا تمہارے رب نے تم سے اچھا وعدہ نہیں کیا تھا پھر کیا تم پر بہت زمانہ گزر گیا تھا یا تم نے چاہا کہ تم پر تمہارے رب کا غصہ نازل ہو تب تم نے مجھ سے وعدہ خلافی کی\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmcdxxxv{کہا ہم نےاپنے اختیا ر سے آپ سے وعدہ خلافی نہیں کی لیکن ہم سے اس قوم کے زیور کا بوجھ اٹھوایا گیا تھا سو ہم نے اسے ڈال دیا پھر اسی طرح سامری نے ڈال دیا\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmcdxxxvi{پھر ان کے لیے ایک بچھڑا نکال لایا ایک جسم جس میں گائے کی آواز تھی پھر کہا یہ تمہارا اور موسیٰ کا معبود ہے سو وہ بھول گیا ہے\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmcdxxxvii{کیا پس وہ نہیں دیکھتے کہ وہ انہیں کس بات کا جواب نہیں دیتا اور ان کے نقصان اور نفع کا بھی اسے اختیار نہیں\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmcdxxxviii{اور انہیں ہارون نے اس سے پہلے کہہ دیا تھا اے میری قوم اس سے تمہاری آزمائش کی گئی ہے اور بے شک تمہارا رب رحمان ہے سو میری پیروی کرو اور میرا کہا مانو\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmcdxxxix{کہا ہم برابر اسی پر جمے بیٹھے رہیں گے یہاں تک کہ موسیٰ ہمارے پاس لوٹ کر آئے\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmcdxl{کہا اے ہارون تمہیں کس چیز نے روکا جب تم نے دیکھا تھا کہ وہ گمراہ ہو گئے ہیں\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmcdxli{تو میرے پیچھے نہ آیا کیا تو نے بھی میری حکم عدولی کی\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmcdxlii{کہا اے میری ماں کے بیٹے میری داڑھی اور اور سر نہ پکڑ بیشک میں ڈرا اس سے کہ تو کہے گا تو نے بنی اسرائیل میں پھوٹ ڈال دی اور میرے فیصلہ کا انتظار نہ کیا\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mmcdxliii{کہا اے سامری تیرا کیا معاملہ ہے\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mmcdxliv{کہا میں نے وہ چیز دیکھی تھی جو دوسروں نے نہ دیکھی پھر میں نے رسول کے نقشِ قدم کی ایک مٹھی مٹی میں لے کر ڈال دی اور میرے دل نے مجھے ایسی ہی بات سوجھائی\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mmcdxlv{کہا بس چلا جا تیرے لیے زندگی میں یہ سزا ہے کہ توکہے گا ہاتھ نہ لگانا اورتیرے لیے ایک وعدہ ہے جو تجھ سے ٹلنے والا نہیں اور تو اپنے معبود کو دیکھ جس پر تو جما بیٹھا تھا ہم اسے ضرور جلا دیں گے پھر اسے دریا میں بکھیر کر بہا دیں گے\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mmcdxlvi{تمہارا معبود ہی الله ہے جس کے سوا کوئی معبود نہیں اس کے علم میں سب چیز سما گئی ہے\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mmcdxlvii{ہم اسی طرح سے تجھے گزشتہ لوگوں کی کچھ خبریں سناتے ہیں اور ہم نے تجھے اپنے ہاں سے ایک نصیحت نامہ دیا ہے\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mmcdxlviii{جس نے اس سے منہ پھیرا سو وہ قیامت کے دن بوجھ اٹھائے گا\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mmcdxlix{اس میں ہمیشہ رہیں گے اوران کے لیے قیامت کے دن بُرا بوجھ ہوگا\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mmcdl{جس دن صور میں پھونکا جائے گا اور ہم اس دن مجرموں کو نیلی آنکھوں والے کر کے جمع کر دیں گے\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mmcdli{چپکے چپکے آپس میں باتیں کہتے ہوں گے کہ تم صرف دس دن ٹھیرے ہو\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mmcdlii{ہم خوب جان لیں گے جو کچھ وہ کہیں گے جب ان میں سے بڑا سمجھدار کہے گا کہ تم صرف ایک ہی دن ٹھہرے ہو\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mmcdliii{اور تجھ سے پہاڑوں کا حال پوچھتے ہیں سوکہہ دے میرا رب انہیں بالکل اڑا دے گا\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mmcdliv{پھر زمین کو چٹیل میدان کر کے چھوڑے گا\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mmcdlv{تو اس میں کجی اور ٹیلا نہیں دیکھے گا\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mmcdlvi{اس دن پکارےنے والے کا اتباع کریں گے اس میں کوئی کجی نہیں ہوگی اور رحمان کے ڈر سے آوازیں دب جائیں گی پھر تو پاؤں کی آہٹ کے سوا کچھ نہیں سنے گا\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mmcdlvii{اس دن سفارش کام نہیں آئے گی مگر جسے رحمان نے اجازت دی اور اس کی بات پسند کی\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mmcdlviii{وہ جانتا ہے جو کچھ ان کے آگے اور پیچھے ہے اور ان کا علم اسے احاطہ نہیں کر سکتا\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mmcdlix{اور سب منہ حّی و قیوم کے سامنے جھک جائیں گے اور تحقیق نامراد ہوا جس نے ظلم کا بوجھ اٹھایا\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mmcdlx{اور جو نیک کام کرے گا اور وہ مومن بھی ہو تو اسے ظلم اور حق تلفی کا کوئی خوف نہیں ہو گا\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@mmcdlxi{اور اسی طرح ہم نے اسے عربی قرآن نازل کیا ہے اور ہم نے اس میں طرح طرح سے ڈرانے کی باتیں سنائیں تاکہ وہ ڈریں یا ان میں سمجھ پیدا کر دے\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@mmcdlxii{سو الله بادشاہ حقیقی بلند مرتبے والا ہے اور تو قرآن کے لینے میں جلدی نہ کر جب تک اس کا اترنا پورا نہ ہوجائےاور کہہ اے میرے رب مجھے اور زیادہ علم دے\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@mmcdlxiii{اور ہم نے اس سے پہلے آدم سے بھی عہد لیا تھا پھر وہ بھول گیا اور ہم نے اس میں پختگی نہ پائی\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@mmcdlxiv{اور جب ہم نے فرشتوں سے کہا کہ آدم کو سجدہ کرو تو سوائے ابلیس کے سب نے سجدہ کیا اس نے انکار کیا\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@mmcdlxv{پھر ہم نے کہا اے آدم بے شک یہ تیرا اور تیری بیوی کا دشمن ہے سو تمہیں جنت سے نہ نکلوا دے پھر تو تکلیف میں پڑ جائے\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@mmcdlxvi{بے شک تو اس میں بھوکا اورننگا نہیں ہوگا\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@mmcdlxvii{اور بے شک تو اس میں نہ پیاسا ہوگا اور نہ تجھے دھوپ لگے گی\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@mmcdlxviii{پھر شیطان نے اس کے دل میں خیال ڈالا کہا اے آدم کیا میں تجھے ہمیشگی کا درخت بتاؤں اور ایسی بادشاہی جس میں ضعف نہ آئے\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@mmcdlxix{پھر دونوں نے اس درخت سے کھایا تب ان پر ان کی برہنگی ظاہر ہوگئی اور اپنے اوپر جنت کے پتے چپکانے لگے اور آدم نے اپنے رب کی نافرمانی کی پھر بھٹک گیا\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@mmcdlxx{پھر اس کے رب نے اسے سرفراز کیا پھر اس کی توبہ قبول کی اور راہ دکھائی\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxi{فرمایا تم دونوں یہاں سے نکل جاؤ تم میں سے ایک دوسرے کا دشمن ہے پھر اگرتمہیں میری طرف سے ہدایت پہنچے پھر جو میری ہدایت پر چلے گا تو گمراہ نہیں ہو گا اور نہ تکلیف اٹھائے گا\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxii{اور جو میرے ذکر سے منہ پھیرے گا تو اس کی زندگی بھی تنگ ہوگی اور اسے قیامت کے دن اندھا کر کے اٹھا ئيں گے\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxiii{کہے گا اے میرے رب تو نے مجھے اندھا کر کے کیوں اٹھایا حالانکہ میں بینا تھا\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxiv{فرمائے گا اسی طرح تیرے پاس ہماری آیتیں پہنچی تھیں پھر تو نے انھیں بھلا دیا تھا اور اسی طرح آج تو بھی بھلایا گیا ہے\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxv{اور اسی طرح ہم بدلہ دیں گے جو حد سے نکلا اور اپنے رب کی آیتوں پر ایمان نہیں لیا اور البتہ آخرت کا عذاب بڑا سخت اور دیرپا ہے\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxvi{سو کیا انہیں اس بات سے بھی سمجھ نہیں آئی کہ ہم نے ان سے پہلے کئی جماعتیں ہلاک کر دی ہیں یہ لوگ ان کی جگہوں پر پھرتے ہیں بیشک اس میں عقل والوں کے لیے نشانیاں ہیں\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxvii{اور اگر تیرے رب کی طرف سے ایک بات پہلے طے شدہ نہ ہوتی اور معیاد معین نہ ہوتی تو عذاب لازمی طور پر ہوتا\qt@no{(129)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxviii{پس صبر کر اس پر جو کہتے ہیں اور سورج کے نکلنے اور ڈوبنے سے پہلے اپنے رب کی حمد کے ساتھ تسبیح بیان کر اور رات کی کچھ گھڑیوں میں اور دن کے اول اور آخر میں تسبیح کر تاکہ تجھے خوشی حاصل ہو\qt@no{(130)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxix{اور تو اپنی نظر ان چیزو ں کی طرف نہ دوڑا جو ہم نے مختلف قسم کے لوگوں کو دنیاوی زندگی کی رونق کے سامان دے رکھے ہیں تاکہ ہم انہیں اس میں آزمائیں او رتیرے رب کا رزق بہتر اور دیرپا ہے\qt@no{(131)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxx{اور اپنے گھر والو ں کو نماز کا حکم کر اور خود بھی اس پر قائم رہ ہم تجھ سے روزی نہیں مانگتے ہم تجھے روزی دیتے ہیں اور پرہیزگاری کا انجام اچھا ہے\qt@no{(132)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxi{اور لوگ کہتے ہیں کہ یہ ہمارے پاس اپنے رب سے کوئی نشانی کیوں نہیں لے آتا کیا ان کے پاس پہلی کتابوں کی شہادت نہیں پہنچی\qt@no{(133)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxii{اور اگر ہم انہیں اس سے پہلے کسی عذاب سے ہلاک کر دیتے تو کہتے اے ہمارے رب تو نے ہمارے پاس کوئی رسول کیوں نہ بھیجا تاکہ ہم ذلیل و خوار ہونے سے پہلے تیرے حکموں پر چلتے\qt@no{(134)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxiii{کہہ دو ہر ایک انتظار کرنے والا ہے سو تم بھی انتظار کرو آئندہ تمہیں معلوم ہو جائے گا کہ سیدھی راہ پر کون ہے اور ہدایت پانے والا کون ہے\qt@no{(135)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxiv{\basmalahur لوگو ں کے حساب کا وقت قریب آ گیا ہے اوروہ غفلت میں پڑ کر منہ پھیرنے والے ہیں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxv{ان کے رب کی طرف سمجھانے کے لیے کوئی ایسی نئی بات ان کے پاس نہیں آتی کہ جسے سن کر ہنسی میں نہ ٹال دیتے ہوں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxvi{ان کے دل کھیل میں لگے ہوئے ہیں اور ظالم پوشیدہ سرگوشیاں کرتے ہیں کہ یہ تمہاری طرح ایک انسان ہی تو ہے پھر کیا تم دیدہ دانستہ جادو کی باتیں سنتے جاتے ہو\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxvii{رسول نے کہا میرا رب آسمان اور زمین کی سب باتیں جانتا ہے اور وہ سننے والا اور جاننے والا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxviii{بلکہ کہتے ہیں کہ یہ بیہودہ خواب ہیں بلکہ اس نے جھوٹ بنایا ہے بلکہ وہ شاعر ہے پھر چاہیے کہ ہمارے پاس کوئی نشانی لائے جس طرح پہلے پیغمبر بھیجے گئے تھے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxix{ان سے پہلے کوئی بستی ایمان نہیں لائی تھی جسے ہم نے ہلاک کیا کیا اب یہ ایمان لائیں گے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmcdxc{اور ہم نے تم سے پہلے بھی تو آدمیوں ہی کو رسول بنا کر بھیجا تھا ان کی طرف ہم وحی بھیجا کرتے تھے اگر تم نہیں جانتے تو علم والوں سے پوچھ لو\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmcdxci{او رہم نے ان کے ایسے بدن بھی نہیں بنائے تھے کہ وہ کھانانہ کھائیں اور نہ وہ ہمیشہ رہنے والے تھے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmcdxcii{پھر ہم نے ان سے وعدہ سچا کر دیا تب انہیں اور جسے ہم نے چاہا نجات دی اور ہم نے حد سے بڑھنے والوں کوہلاک کر دیا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmcdxciii{البتہ تحقیق ہم نے تمہارے پاس ایک ایسی کتاب بھیجی ہے جس میں تمہاری نصیحت ہے کیا پس تم نہیں سمجھتے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmcdxciv{اور ہم نے بہت سی بستیوں کو جو ظالم تھیں غارت کر دیا ہے اور ان کے بعد ہم نے اور قومیں پیدا کیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmcdxcv{پھر جب انہوں نے ہمارے عذاب کی آہٹ پائی تو وہ فوراً وہاں سے بھاگنے لگے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmcdxcvi{مت بھاگو اور لوٹ جاؤ جہاں تم نے عیش کیا تھا اور اپنے گھروں میں جاؤ تاکہ تم سے پوچھا جائے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmcdxcvii{کہنے لگے ہائے ہماری کم بختی بے شک ہم ہی ظالم تھے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmcdxcviii{سو ان کی یہی پکار رہی یہاں تک کہ ہم نے انہیں ایسا کر دیا جس طرح کھیتی کٹی ہوئی ہو اور وہ بجھ کر رہ گئے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmcdxcix{اور ہم نے آسمان اور زمین کو اورجو کچھ ان کے بیچ میں ہے کھیلتے ہوئے نہیں بنایا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmd{اور اگر ہم کھیل ہی بنانا چاہتے تو اپنے پا س کی چیزوں کو بناتے اگر ہمیں یہی کرنا ہوتا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmdi{بلکہ ہم حق کو باطل پر پھینک مارتے ہیں پھر وہ باطل کا سر توڑ دیتا ہے پھر وہ مٹنے والا ہوتا ہے او رتم پر افسوس ہے ان باتوں سے جو تم بناتے ہو\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmdii{اور اسی کا ہے جو کوئي آسمانوں اور زمین میں ہے اور جو اس کے ہاں ہیں اس کی عبادت سے سرکشی نہیں کرتےاور نہ تھکتے ہیں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmdiii{رات اور دن تسبیح کرتے ہیں سستی نہیں کرتے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmdiv{کیاانہوں نے زمین کی چیزوں سے ایسے معبود بنا رکھے ہیں جو زندہ کریں گے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmdv{اگر ان دونوں میں الله کے سوا اور معبود ہوتے تو دونوں خراب ہو جاتے سو الله عرش کا مالک ان باتوں سے پاک ہے جو یہ بیان کرتے ہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmdvi{جو کچھ وہ کرتاہے اس سے پوچھا نہیں جاتا اور وہ پوچھے جاتے ہیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmdvii{کیا انہوں نے اس کے سوا اور بھی معبود بنا رکھے ہیں کہہ دو اپنی دلیل لاؤ یہ میرے ساتھ والو ں کی کتاب اور مجھ سے پہلے لوگوں کی کتابیں موجود ہیں بلکہ اکثران میں سے حق جانتے ہی نہیں اس لیے منہ پھیرے ہوئے ہیں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmdviii{اور ہم نے تم سے پہلے ایسا کوئی رسول نہیں بھیجا جس کی طرف یہ وحی نہ کی ہو کہ میرے سوا اور کوئی معبود نہیں سومیری ہی عبادت کرو\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmdix{اور کہتے ہیں کہ الله نے اولاد بنا رکھی ہے وہ پاک ہے لیکن وہ معزز بندے ہیں\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmdx{بات کرنے میں اس سے پیش قدمی نہیں کرتے اور وہ اسی کے حکم پر کام کرتے ہیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmdxi{وہ جانتا ہے جو ان کے آگے اور جو ان کے پیچھے ہے اور وہ شفاعت بھی نہیں کرتے مگر اسی کے لیے جس سے وہ خوش ہو اور وہ اس کی ہیبت سے ڈرتے ہیں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmdxii{اورجو کوئی ان میں سے یہ کہے کہ بے شک میں اس کے سوا خدا ہوں تو اسی پر ہم اسے جہنم کی سزاد یں گے ہم اسی طرح ظالموں کو سزا دیا کرتے ہیں\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmdxiii{کیا منکروں نے نہیں دیکھا کہ آسمان اور زمین جڑے ہوئے تھے پھر ہم نے انھیں جدا جدا کر دیا اورہم نے ہر جاندار چیز کو پانی سے بنایا کیا پھر بھی یقین نہیں کرتے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmdxiv{اورہم نے زمین میں بھاری پہاڑ رکھ دیئے تاکہ انہیں لے کر داھر اُدھر نہ جھکنے پائے اور ہم نے اس میں کشادہ راہیں بنا دی ہیں تاکہ وہ راہ پائیں\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmdxv{اور ہم نے آسمان کو ایک محفوظ چھت بنا دیا اور وہ آسمان کی نشانیوں سے منہ موڑنے واے ہیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmdxvi{اور وہی ہے جس نے رات اور دن اور سورج اور چاند بنائے سب اپنے اپنے چکر میں پھرتے ہیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmdxvii{اور ہم نے تجھ سے پہلے کسی آدمی کو ہمیشہ کے لیے زندہ رہنے نہیں دیا پھر کیا اگر تو مر گیا تو وہ رہ جائیں گے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmdxviii{ہر ایک جاندار موت کا مزہ چکھنے والا ہے اور ہم تمہیں برائی اوربھلائی سے آزمانے کے لیے جانچتے ہیں اورہماری طرف لوٹائے جاؤ گے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmdxix{اور جہاں تمہیں کافر دیکھتے ہیں تو انہیں تجھ سے سوائے ٹھٹھا کرنے کے اور کوئی کام نہیں کیا یہی شخص ہے جو تمہارے معبودوں کا نام لیتا ہے اور وہ رحمان کے نام سے منکر ہیں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmdxx{آدمی جلد باز بنایا گیا ہے میں تمہیں اپنی نشانیاں ابھی دکھاتا ہوں سو جلدی مت کرو\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmdxxi{ور کہتے ہیں یہ وعدہ کب ہوگا اگر تم سچے ہو\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmdxxii{کاش یہ منکر اس وقت کو جان لیں کہ اپنے مونہوں اوراپنی پیٹھوں سے آگ کو روک نہیں سکیں گے اور نہ وہ مدد کیے جائیں گے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmdxxiii{بلکہ وہ ان پر ناگہان آئے گی پھر وہ ان کے ہوش کھو دے گی پھر نہ اسے ٹال سکیں گے اورنہ انہیں مہلت دی جائے گی\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmdxxiv{اور تجھ سے پہلے بھی رسولوں کے ساتھ ٹھٹھا کیا گیا ہے پھر جس عذاب کی بابت وہ ہنسی کیا کرتے تھے ان ٹھٹھا کرنے والوں پر وہی آ پڑا\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmdxxv{کہہ دو تمہاری رات اور دن میں رحمان سے کون نگہبانی کرتا ہے بلکہ وہ اپنے رب کے ذکر سے منہ موڑنے والے ہیں\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmdxxvi{کیا ہم سے ان کےمعبود انہیں بچائے رکھتے ہیں وہ تو خود اپنی بھی مدد نہیں کر سکتے اورنہ ہمارے مقابلہ میں ان کا کوئی ساتھ دے گا\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmdxxvii{بلکہ ہم نے ان کو اور ان کے باپ دادا کو خوب سامان دیا یہاں تک کہ ان پر ایک عرصہ دراز گزر گیا کیا وہ یہ نہیں دیکھتے کہ بے شک ہم زمین کو ہر طرف سے گھٹاتے چلے جاتے ہیں سو کیا یہ لوگ غالب آنے والے ہیں\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmdxxviii{کہہ دو کہ میں تو صرف وحی کے ذریعہ سے تمہیں ڈراتا ہوں اور یہ بہرے جس وقت ڈرائے جاتے ہیں سنتے ہی نہیں\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmdxxix{اور البتہ اگر انہیں تیرے رب کا عذاب کا ایک جھونکا بھی لگ جائے تو ضرور کہیں گے کہ ہائے ہماری کم بختی بے شک ہم ظالم تھے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmdxxx{اور قیامت کے دن ہم انصاف کی ترازو قائم کریں گے پھرکسی پر کچھ ظلم نہ کیا جائے گا اور اگر رائی کے دانہ کے برابر بھی عمل ہو گا تو اسے بھی ہم لے آئیں گے اور ہم ہی حساب لینے کے لیے کافی ہیں\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmdxxxi{اور البتہ تحقیق ہم نے موسیٰ اور ہارون کو فیصلہ کرنے والی اور روشنی دینے والی اور پرہیز گاروں کو نصیحت کرنے والی کتاب دی تھی\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmdxxxii{جو اپنے رب سے بن دیکھے ڈرتے ہیں اور قیامت کا بھی خوف رکھنے والے ہیں\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmdxxxiii{اور یہ ایک مبارک نصیحت ہے جسے ہم نازل کیاہے پھر کیا تم اس کے بھی منکر ہو\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmdxxxiv{اور ہم نے پہلے ہی سے ابراھیم کو اس کی صلاحیت عطا کی تھی اور ہم اس سے واقف تھے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmdxxxv{جب اس نے اپنے باپ اور اپنی قوم سے کہا کہ یہ کیسی مورتیں ہیں جن پر تم مجاور بنے بیٹھے ہو\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmdxxxvi{انہوں نے کہا ہم نے اپنے باپ دااد کو انہیں کی پوجا کرتے پایا ہے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmdxxxvii{کہا البتہ تحقیق تم اور تمہارے باپ دادا صریح گمراہی میں رہے ہو\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmdxxxviii{انھوں نے کہا کیا تو ہمارے پاس سچی بات لایا ہے یا تو دل لگی کرتا ہے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmdxxxix{کہا بلکہ تمہارا رب تو آسمانوں اور زمین کا رب ہے جس نے انہیں بنایا ہے اور میں اسی بات کا قائل ہوں\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmdxl{اور الله کی قسم میں تمہارے بتوں کا علاج کروں گا جب تم پیٹھ پھیر کر جا چکو گے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmdxli{پھر ان کے بڑے کے سوا سب کو ٹکڑے ٹکڑے کر دیا تاکہ اس کی طرف رجوع کریں\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmdxlii{انہوں نے کہا ہمارے معبودوں کے ساتھ کس نے یہ کیا ہے بے شک وہ ظالموں میں سے ہے\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmdxliii{انہو ں نے کہا ہم نے سنا ہے کہ ایک جو ان بتوں کو کچھ کہا کرتا ہے اسے ابراھیم کہتے ہیں\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmdxliv{کہنے لگے اسے لوگوں کے سامنے لے آؤ تاکہ وہ دیکھیں\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmdxlv{کہنے لگے اے ابراھیم کیا تو نے ہمارے معبودوں کے ساتھ یہ کیا ہے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmdxlvi{کہا بلکہ ان کے اس بڑے نے یہ کیا ہے سو ان سے پوچھ لو اگر وہ بولتے ہیں\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmdxlvii{پھر وہ اپنے دل میں سوچ کر کہنے لگے بے شک تم ہی بے انصاف ہو\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmdxlviii{پھر انہو ں نے سر نیچا کر کے کہا تو جانتا ہے کہ یہ بولا نہیں کرتے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmdxlix{کہا پھر کیا تم الله کے سوا اس چیز کی پوجا کرتے ہو جو نہ تمہیں نفع دے سکےاور نہ نقصان پہنچا سکے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmdl{میں تم سے اور جنہیں الله کے سوا پوجتے ہو بیزار ہوں پھر کیا تمھیں عقل نہیں ہے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmdli{انھوں نے کہا اگر تمہیں کچھ کرنا ہے تو اسے جلا دو اور اپنے معبودوں کی مدد کرو\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmdlii{ہم نے کہا اے آگ ابراھیم پر سرد اورراحت ہو جا\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmdliii{اور انہوں نے اس کی برائی چاہی سو ہم نے انہیں ناکام کر دیا\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmdliv{اور ہم اسے اورلوط کو بچا کراس زمین کی طرف لے آئے جس میں ہم نے جہان کے لیے برکت رکھی ہے\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmdlv{اور ہم نے اسے اسحاق بخشا اور انعام میں یعقوب دیا اور سب کونیک بخت کیا\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmdlvi{اورہم نے انہیں پیشوا بنایا جو ہمارے حکم سے رہنمائی کیا کرتے تھے اور ہم نے انہیں اچھے کام کرنے اور نماز قائم کرنے اور زکوٰة دینے کا حکم دیا تھا اور وہ ہماری ہی بندگی کیا کرتے تھے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmdlvii{اور لوط کو ہم نے حکمت اور علم عطا کیا تھا اور ہم اسے اس بستی سے جو گندے کام کیا کرتی تھی بچا کر لے آئے بے شک وہ لوگ برے نافرمانی کرنے والے تھے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmdlviii{اوراسے ہم نے اپنی رحمت میں لے لیا بے شک وہ نیک بختوں میں سے تھا\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmdlix{اور نوح کو جب اس نے اس سے پہلے پکارا پھر ہم نے اس کی دعا قبول کر لی پھر ہم نے اسے اور اس کے گھر والوں کو گھبراہٹ سے بچا لیا\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmdlx{اور ہم نے اس کی مدد کی ان لوگوں پر جو ہماری آیتیں جھٹلاتے تھے بے شک وہ بُرے لوگ تھے پھر ہم نے ان سب کو غرق کر دیا\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmdlxi{اور داؤد اور سلیمان کو جب وہ کھیتی کے جھگڑا میں فیصلہ کرنے لگے جب کہ اس میں کچھ لوگوں کی بکریاں رات کے وقت جا پڑیں اور ہم اس فیصلہ کو دیکھ رہے تھے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmdlxii{پھر ہم نے وہ فیصلہ سلیمان کو سمجھا دیا اور ہر ایک کو ہم نے حکمت اور علم دیا تھا اور ہم نے داؤد کے ساتھ پہاڑ او رپرندے تابع کیے جو تسبیح کیا کرتے تھے اور یہ سب کچھ ہم ہی کرنے والے تھے\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmdlxiii{اور ہم نےاسے تمہارے لیے زر ہیں بنانا بھی سکھایا تاکہ تمہیں لڑائی میں محفوظ رکھیں پھر کیا تم شکر کرتے ہو\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmdlxiv{اور زور سے چلنے والی ہوا سلیمان کے تابع کی جو اس کے حکم سے اس زمین کی طرف چلتی جہاں ہم نے برکت دی ہے اور ہم ہر چیز کو جاننے والے ہیں\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmdlxv{اورتو کچھ ایسے جن تھے جو دریا میں اس کے واسطے غوطہ لگاتے تھے اور اس کے سوا اور کام بھی کرتے تھے اور ہم ان کی حفاظت کرنے والے تھے\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmdlxvi{اورجب کہ ایوب نے اپنے رب کو پکارا کہ مجھے روگ لگ گیا ہے حالانکہ تو سب رحم کرنے والوں سے زیادہ رحم کرنے والا ہے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmdlxvii{پھر ہم نے اس کی دعا قبول کی اورجواسے تکلیف تھی ہم نے دور کر دی اور اسے اس کے گھر والے دیئے اور اتنا ہی ان کے ساتھ اپنی رحمت سے اوربھی دیا اور عبادت کرنے والوں کے لیے نصیحت ہے\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmdlxviii{اور اسماعیل اور ادریس اور ذوالکفل کو یہ سب صبر کرنے والے تھے\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmdlxix{اور ہم نے انہیں اپنی رحمت میں داخل کر لیا بے شک وہ نیک بختوں میں سے تھے\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmdlxx{اور مچھلی والے کو جب غصہ ہو کر چلا گیا پھر خیال کیا کہ ہم اسے نہیں پکڑیں گے اندھیروں میں پکارا کہ تیرے سوا کوئی معبود نہیں ہے تو بے عیب ہے بے شک میں بے انصافوں میں سے تھا\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmdlxxi{پھر ہم نے اس کی دعا قبول کی اور اسے غم سے نجات دی اور ہم ایمان داروں کو یونہی نجات دیا کرتے ہیں\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmdlxxii{اور ذکریا کو جب اس نے اپنے رب کو پکارا اے رب مجھے اکیلا نہ چھوڑ اور تو سب سے بہتر وارث ہے\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmdlxxiii{پھر ہم نے اس کی دعا قبول کی اور اسے یحییٰ عطا کیا اور اس کے لیے اس کی بیوی کو درست کر دیا بے شک یہ لوگ نیک کاموں میں دوڑ پڑتے تھے اور ہمیں امید اور ڈر سے پکارا کرتے تھے اور ہمارے سامنے عاجزی کرنے والے تھے\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmdlxxiv{اوروہ عورت جس نے اپنی عصمت کو محفوظ رکھا پھر ہم نے اس میں اپنی روح پھونک دی اور اسے اور اس کے بیٹے کو جہان کے لیے نشانی بنایا\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmdlxxv{یہ لوگ تمہارے گروہ کے ہیں جو ایک ہی گروہ ہے اور میں تمہارا رب ہوں پھر میری ہی عبادت کرو\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmdlxxvi{اور ان لوگوں نے اپنے دین میں اختلاف پیدا کر لیا سب ہمارے پاس ہی آنے والے ہیں\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmdlxxvii{پھر جو کوئی اچھے کام کرے گا اور وہ مومن بھی ہوگا تو اس کی کوشش رائگان نہ جائے گی اوربے شک ہم اس کے لکھنے والے ہیں\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mmdlxxviii{اورجن بستیوں کو ہم فنا کر چکے ہیں ان کے لیے ناممکن ہے کہ وہ پھر لوٹ کر آئيں\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mmdlxxix{یہاں تک کہ جب یاجوج اور ماجوج کھول دیئے جائیں گے اور وہ ہر بلندی سے دوڑتے چلے آئيں گے\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mmdlxxx{اور سچا وعدہ نزدیک آ پہنچے گا پھر اس وقت منکرو ں کی آنکھیں اوپر لگی رہ جائیں گی ہائے کم بختی ہماری بے شک ہم تو اس سے غفلت میں پڑے ہوئے تھے بلکہ ہم ہی ظالم تھے\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mmdlxxxi{بے شک تم اور الله کے سوا جو کچھ پوجتے ہو دوزخ کا ایندھن ہے تم سب اس میں داخل ہو گے\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mmdlxxxii{اگر یہ معبود ہوتے تو اس میں داخل نہ ہوتے اور سب اس میں ہمیشہ رہنے والے ہیں\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mmdlxxxiii{ان کے لیے دوزخ میں چیخیں ہو ں گی اوروہ اس میں کچھ نہیں سنیں گے\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mmdlxxxiv{بے شک جن کے لیے ہماری طرف سے بھلائی مقدر ہو چکی ہے وہ اس سے دور رکھے جائیں گے\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mmdlxxxv{اس کی آہٹ بھی نہ سنیں گے اور وہ اپنی من مانی مرادوں میں ہمیشہ رہیں گے\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mmdlxxxvi{اور انہیں بڑا بھاری خوف بھی پریشان نہیں کرے گا اور ان سے فرشتے آ ملیں گے یہی وہ تمہارا دن ہے جس کا تمہیں وعدہ دیا جاتا تھا\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mmdlxxxvii{جس دن ہم آسمان کو اس طرح لپیٹیں گے جیسے خطوں کا طومار لپیٹا جاتا ہے جس طرح ہم نے پہلی بار پیدا کیا تھا دوبارہ بھی پیدا کریں گے یہ ہمارے ذمہ وعدہ ہے بے شک ہم پورا کرنے والے ہیں\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mmdlxxxviii{اور البتہ تحقیق ہم نصیحت کے بعد زبور میں لکھ چکے ہیں کہ بے شک زمین کے وارث ہمارے نیک بندے ہی ہوں گے\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mmdlxxxix{بےشک اس میں خدا پرستوں کے لیے ایک پیغام ہے\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mmdxc{او رہم نے توتمہیں تمام جہان کے لوگوں کے حق میں رحمت بنا کر بھیجا ہے\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mmdxci{کہہ دو مجھے تو یہی حکم آیا ہے کہ تمہارا معبود ایک معبود ہے پھر کیا اس کے آگے سر جھکاتے ہو\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mmdxcii{پھر اگر وہ منہ موڑیں تو کہہ دو کہ میں نے یکساں طور پر خبر دے دی ہے اورمجھے معلوم نہیں کہ نزدیک ہے یا دور ہے جس کا تم سے وعدہ کیا جاتا ہے\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mmdxciii{بے شک وہ جانتا ہے جو بات پکار کر کہو اور جانتا ہے جو تم چھپاتے ہو\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mmdxciv{اور میں نہیں جانتا شاید وہ تمہارے لیے امتحان ہو اور ایک وقت تک دنیا کا فائدہ پہنچانا منظور ہو\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mmdxcv{کہ اے رب انصاف کا فیصلہ کر دے اور ہمارا رب بڑا مہربان ہے اسی سے مدد مانگتے ہیں ان باتوں پر جو تم بیان کرتے ہو\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@mmdxcvi{\basmalahur اے لوگو اپنے رب سے ڈرو بے شک قیامت کا زلزلہ ایک بڑی چیز ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmdxcvii{جس دن اسے دیکھو گے ہر دودھ پلانے والی اپنے دودھ پیتے کو بھول جائے گی اور ہر حمل والی اپنا حمل ڈال دے گی اور تجھے لوگ مدہوش نظر آئیں گے اور وہ مدہوش نہ ہوں گے لیکن الله کا عذاب سخت ہوگا\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmdxcviii{اور بعضے لوگ وہ ہیں جو الله کے معاملے میں بے سمجھی سے جھگڑتے ہیں اور ہر شیطان سرکش کے کہنے پر چلتے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmdxcix{جس کے حق میں لکھاجا چکا ہے کہ جو اسے یار بنائے گا تو وہ اسے گمراہ کر کے رہے گا اور اسے دوزخ کے عذاب کا راستہ دکھائے گا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmdc{اے لوگو اگر تمہیں دوبارہ زندہ ہونے میں شک ہے تو ہم نے تمہیں مٹی سے پھر قطرہ سے پھر جمے ہوئے خون سے پھر گوشت کی بوٹی نقشہ بنی ہوئی اور بغیر نقشہ بنی ہوئی سے بنایا تاکہ ہم تمہارے سامنے ظاہر کر دیں اور ہم ر حم میں جس کو چاہتے ہیں ایک مدت معین تک ٹھیراتے ہیں پھر ہم تمہیں بچہ بنا کر باہر لاتے ہیں پھر تاکہ تم اپنی جوانی کو پہنچو اور کچھ تم میں سے مرجاتے ہیں اور کچھ تم میں سے نکمی عمر تک پہنچائے جاتے ہیں کہ سمجھ بوجھ کا درجہ پاکر ناسمجھی کی حالت میں جا پڑتا ہے اور تم زمین کوسوکھی دیکھتے ہو پھر جب ہم اس پر پانی برساتے ہیں تو تر و تازہ ہو جاتی ہے او رہر قسم کے خوش نمانباتات اُگ آتے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmdci{یہ اس لیے ہے کہ الله ہی برحق ہے اور مردوں کو زندہ کرے گا اور وہ ہر بات پر قادر ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmdcii{اور بے شک قیامت آنے والی ہے جس میں کوئی شک نہیں اور بے شک الله قبروں والوں کو دوبارہ اٹھائے گا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmdciii{اور بعضاً وہ شخص ہے جو الله کے معاملہ میں بے سمجھی اور دلیل اور روشن کتاب کے بغیر تکبر سے جھگڑتا ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmdciv{تاکہ الله کی راہ سے بہکائے اس کے لیے دنیا میں رسوائی ہے اور قیامت کے دن بھی ہم اسے دوزخ کے عذاب کا مزہ چکھاویں گے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmdcv{یہ تیرے ہاتھوں کے کیے ہوئے کاموں کا بدلہ ہے اور بےشک الله بندوں پر ظلم کرنے والا نہیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmdcvi{اور بعض وہ لوگ ہیں کہ الله کی بندگی کنارے پر ہو کر کرتے ہیں پھر اگر اسے کچھ فائدہ پہنچ گیا تو اس عبادت پر قائم ہو گیا اور اگر تکلیف پہنچ گئی تو منہ کے بل پھر گیا دنیا اور آخرت گنوائی یہی وہ صریح خسارا ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmdcvii{الله کے سوا ایسی چیز کو پکارتا ہے جو نہ اسے ضرر دے سکے اور نہ اسے فائدہ پہنچا سکے یہی وہ پرلے درجہ کی گمراہی ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmdcviii{ایسے کو پکارتا ہے جس کا ضرر اس کے نفع سے نزدیک تر ہے ایسا کارساز بھی برا اور ایسا رفیق بھی برا ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmdcix{بے شک الله ان لوگوں کو جو ایمان لائے اور اچھے کام کیے ایسے باغوں میں داخل کرے گا جن کے نیچے نہریں بہتی ہوں گی بے شک الله جو چاہتا ہے کرتا ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmdcx{جسے یہ خیال ہو کہ الله دنیا اور آخرت میں اس کی ہرگز مدد نہ کرے گااسے چاہیے کہ چھت میں ایک رسی لٹکائے پھر اسے کاٹ دے پھر دیکھے کہ اس کی تدبیر اس کے غصہ کو دور کرتی ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmdcxi{اور اسی طرح ہم نےاس قرآن کو واضح آیتیں بنا کر نازل کیا ہے اور بے شک الله جسے چاہتا ہے ہدایت کرتا ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmdcxii{بے شک الله مسلمانوں اور یہودیوں اور صابیوں اور عیسائیوں اورمجوسیوں اور مشرکوں میں قیامت کے دن فیصلہ کرے گا بےشک ہر چیز الله کے سامنے ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmdcxiii{کیا تم نےنہیں دیکھا کہ جو کوئی آسمانوں میں ہے اور جو کوئی زمین میں ہے اور سورج اور چاند اور ستارے اور پہاڑ اور درخت اورچار پائے اور بہت سے آدمی الله ہی کو سجدہ کرتے ہیں اور بہت سے ہیں کہ جن پر عذاب مقرر ہو چکا ہے اور جسے الله ذلیل کرتا ہے پھر اسے کوئی عزت نہیں دےسکتا بے شک الله جو چاہتا ہے کرتا ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmdcxiv{یہ دو فریق ہیں جو اپنے رب کے معاملہ میں جھگڑتے ہیں پھر جو منکر ہیں ان کے لیے آگ کے کپڑے قطع کیے گئے ہیں اور ان کےسروں پر کھولتا ہوا پانی ڈالا جائے گا\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmdcxv{جس سے جو کچھ ان کے پیٹ میں ہے اور کھالیں جھلس دی جائیں گی\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmdcxvi{اور ان پر لوہے کے گرز پڑیں گے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmdcxvii{جب گھبرا کر وہاں سے نکلنا چاہیں گے اسی میں لوٹا دیئے جائیں گے اور دوزخ کا عذاب چکھتے رہو\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmdcxviii{بے شک الله ان لوگوں کو جو ایمان لائے اور اچھے کام کیے باغوں میں داخل کرے گا جن کے نیچے نہریں بہتی ہوں گی وہاں انہیں سونے کے کنگن اور موتی پہنائیں جائیں گے اور وہاں ان کا لباس ریشمی ہوگا\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmdcxix{اور انہوں نے عمدہ بات کی راہ پائی اور تعریف والے الله کی راہ پائی\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmdcxx{بے شک جو منکر ہوئے اور لوگوں کو الله کے راستہ اور مسجد حرام سے روکتے ہیں جسے ہم نے سب لوگو ں کے لیے بنایا ہے وہاں اس جگہ کا رہنے والا اورباہروالادونوں برابر ہیں اور جو وہاں ظلم سے کجروی کرنا چاہے تو ہم اسے دردناک عذاب چکھائیں گے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmdcxxi{اور جب ہم نے ابراھیم کے لیے کعبہ کی جگہ معین کر دی کہ میرے ساتھ کسی کو شریک نہ کراور میرے گھر کو طواف کرنے والوں اور قیام کرنے والوں اور رکوع و سجود کرنے والوں کے لیے پاک رکھ\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmdcxxii{اور لوگوں میں حج کا اعلان کر دے کہ تیرے پاس پا پیادہ او رپتلے دُبلے اونٹوں پر دور دراز راستوں سے آئیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmdcxxiii{تاکہ اپنے فائدوں کے لیے آموجود ہوں اورتاکہ جو چار پائے الله نےانہیں دیے ہیں ان پر مقررہ دنوں میں الله کا نام یاد کریں پھر ان میں سے خود بھی کھاؤ اور محتاج فقیر کو بھی کھلاؤ\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmdcxxiv{پھر چاہیئے کہ اپنا میل کچیل دور کریں اور اپنی نذریں پوری کریں اور قدیم گھر کا طواف کریں\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmdcxxv{یہی حکم ہے اور جو الله کی معزز چیزوں کی تعظیم کرے گا سو یہ اس کے لیے اس کے رب کے ہاں بہتر ہے اور تمہارے لیے مویشی حلال کر دیئے گئے ہیں مگر وہ جو تمہیں پڑھ کر سنائے جاتے ہیں پھر بتوں کی ناپاکی سے بچو اور جھوٹی بات سے بھی پرہیز کرو\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmdcxxvi{خاص الله کے ہو کر رہو اس کے ساتھ کسی کو شریک نہ کرو اور جو الله کے ساتھ کسی کو شریک کرتا ہے تو گویا وہ آسمان سے گر پڑا پھر اسے پرندے اچک لیتے ہیں یا اسے ہوا اڑا کر کسی دور جگہ پھینک دیتی ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmdcxxvii{بات یہی ہے اور جو شخص الله کی نامزد چیزوں کی تعظیم کرتا ہے سو یہ دل کی پرہیز گاری ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmdcxxviii{تمہارے لیے ان میں ایک وقت معین تک فائدے ہیں پھر اس کے ذبح ہونے کی جگہ قدیم گھر کے قریب ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmdcxxix{اور ہر امت کے لیے ہم نے قربانی مقرر کر دی تھی تاکہ الله نے جو چار پائے انہیں دیے ہیں ان پر الله کا نام یاد کیا کریں پھر تم سب کا معبود تو ایک الله ہی ہے پس اس کے فرمانبردار رہو اور عاجزی کرنے والوں کو خوشخبری سنا دو\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmdcxxx{وہ لوگ جب الله کا نام لیا جائے تو ان کے دل ڈر جاتے ہیں اور جب ان پر مصیبت آئے تو صبر کرنے والے ہیں اور نماز قائم کرنے والے ہیں اور جو کچھ ہم نے انہیں دیا ہے اس میں سے خرچ کرتے ہیں\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmdcxxxi{اور ہم نے تمہارے لیے قربانی کے اونٹ کو الله کی نشانیوں میں سے بنایا ہے تمہارے لیے ان میں فائدے بھی ہیں پھر ان پر الله کا نام کھڑا کر کے لو پھر جب وہ کسی پہلو پر گر پڑیں تو ان میں سے خود کھاؤ اور صبر سے بیٹھنے والے اور سائل کو بھی کھلاؤ الله نے انہیں تمہارے لیے ایسا مسخر کر دیا ہے تاکہ تم شکر کرو\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmdcxxxii{الله کو نہ ان کا گوشت اور نہ ان کا خون پہنچتا ہے البتہ تمہاری پرہیز گاری اس کے ہاں پہنچتی ہے اسی طرح انہیں تمہارے تابع کر دیا تاکہ تم الله کی بزرگی بیان کرو اس پر کہ اس نے تمہیں ہدایت کی اور نیکوں کو خوشخبری سنا دو\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmdcxxxiii{بیشک الله ایمان والوں سے دشمنوں کو ہٹا دے گا الله کسی دغا باز نا شکر گزار کو پسند نہیں کرتا\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmdcxxxiv{جن سے کافر لڑتے ہیں انہیں بھی لڑنے کی اجازت دی گئی ہے اس لیے کہ ان پر ظلم کیا گیا اور بیشک الله ان کی مدد کرنے پر قادر ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmdcxxxv{وہ لوگ جنہیں ناحق ان کے گھروں سے نکال دیا گیا ہے صرف اس کہنے پر کہ ہمارا رب الله ہے اور اگر الله لوگوں کو ایک دوسرے سے نہ ہٹاتا تو تکیئے اور مدرسے اورعبادت خانے اور مسجدیں ڈھا دی جاتیں جن میں الله کا نام کثرت سے لیا جاتا ہے اور الله ضرور اس کی مدد کر ے گا جو اللہ کی مددکرے گابیشک الله زبردست غالب ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmdcxxxvi{وہ لوگ اگر ہم انہیں دنیا میں حکومت دے دیں تو نماز کی پابندی کریں اور زکوٰة دیں اور نیک کام کا حکم کریں اور برے کاموں سے روکیں اور ہر کام کا انجام تو الله کے ہی ہاتھ میں ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmdcxxxvii{اور اگر تمہیں جھٹلائیں تو ان سے پہلے نوح کی قوم اور عاد اور ثمود\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmdcxxxviii{اور ابراھیم کی قوم اور لوط کی قوم\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmdcxxxix{اور مدین والے اپنے اپنے نبی کو جھٹلا چکے ہیں اور موسیٰ کو بھی جھٹلایا گیا پھر میں نے منکروں کو مہلت دی پھر میں نے انہیں پکڑا پھر میری پکڑ کیسی تھی\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmdcxl{سو کتنی بستیاں ہم نے ہلاک کر دیں اور وہ گناہ گار تھیں اب وہ اپنی چھتوں پر گری پڑی ہیں اور کتنے کنوئیں نکمے اور کتنے پکے محل اجڑے اجڑے پڑے ہیں\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmdcxli{کیا انھوں نے ملک میں سیر نہیں کی پھر ان کے ایسے دل ہوجاتے جن سے سمجھتے یا ایسے کان ہو جاتے جن سے سنتے پس تحقیق بات یہ ہے کہ آنکھیں اندھی نہیں ہوتیں بلکہ دل جو سینوں میں ہیں اندھے ہو جاتے ہیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmdcxlii{اور تجھ سے عذاب جلدی مانگتے ہیں اور الله اپنے وعدہ کا ہرگز خلاف نہیں کرے گا اور ایک دن تیرے رب کے ہاں ہزار برس کے برابر ہوتا ہے جوتم گنتے ہو\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmdcxliii{اور کتنی بستیوں کو میں نے مہلت دی حالانکہ وہ ظالم تھیں پھر میں نے انہیں پکڑا اور میری طرف ہی پھر کر آنا ہے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmdcxliv{کہہ دو اے لوگو میں تو صرف تمہیں صاف صاف ڈرانے والا ہوں\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmdcxlv{پھر جو لوگ ایمان لائے اوراچھے کام کیے ان کے لیے بخشش اور عزت کی روزی ہے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmdcxlvi{اور جنہوں نے ہماری آیتیوں کے پست کرنے میں کوشش کی وہی دوزخی ہیں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmdcxlvii{اور ہم نے تجھ سے پہلے کوئی بھی ایسا رسول اور نبی نہیں بھیجا کہ جس نے جب کوئی تمنا کی ہو اور شیطان نے اس کی تمنا میں کچھ آمیزش نہ کی ہو پھر الله ّ شیطان کی آمیزش کو دور کرکے اپنی آیتوں کو محفوظ کردیتا ہے اور الله جاننے والا حکمت والا ہے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmdcxlviii{تاکہ شیطان کی آمیزش کو ان لوگوں کے لیے آزمائش بنا دے جن کے دلوں میں بیماری ہے اور جن کے دل سخت ہیں اور بے شک ظالم بڑی ضدی میں پڑے ہوئے ہیں\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmdcxlix{اور تاکہ علم والے اسے تیرے رب کی طرف سے حق سمجھ کر ایمان لے آئیں پھر ان کے دل اس کے لیے جھک جائیں اور بیشک الله ایمان داروں کو سیدھے راستہ کی طرف ہدایت کرنے والا ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmdcl{اور منکر قرآن کی طرف سے ہمیشہ شک میں رہیں گے یہاں تک کہ قیامت یکاک ان پر آ مودجود ہو یا منحوس دن کا عذاب ان پر نازل ہو\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmdcli{اس دن الله ہی کی حکومت ہوگی وہی ان میں فیصلہ کر لے گا پھر جو ایمان لائے اور اچھے کام کیے وہ نعمت کے باغوں میں ہوں گے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmdclii{اورجو منکر ہوئے اور ہماری آیتوں کو جھٹلایا سو انکے لیے ذلت کا عذاب ہے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmdcliii{اور جنہوں نے الله کی راہ میں ہجرت کی پھر قتل کیے گئے یا مر گئے البتہ انہیں الله اچھا رزق دے گا اور بے شک الله سب سے بہتر رزق دینے والا ہے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmdcliv{البتہ انہیں ایسی جگہ پہنچائے گا جسے پسند کریں گے اور بیشک الله جاننے والا بردبار ہے\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmdclv{بات یہ ہے اور جس نے اسی قدر بدلہ لیا جس قدر اسے تکلیف دی گئی تھی پھر اس پر زیادتی کی گئی تو الله ضرور اس کی مد کرے گا بے شک الله درگزر کرنے والا معاف کرنے والا ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmdclvi{وہ اس لیے کہ الله رات کو دن میں اور دن کو رات میں داخل کیا کرتا ہے اور بے شک الله سننے والا دیکھنے والا ہے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmdclvii{یہ اس لیے کہ حق الله ہی کی ہستی ہے اور جنہیں اس کے سوا پکارتے ہیں باطل ہیں اور بے شک الله ہی بلند مرتبہ بڑائی والا ہے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmdclviii{کیا تو نے نہیں دیکھا کہ الله نے آسمان سے پانی نازل کیا پھر زمین سرسبز ہوجاتی ہے بے شک الله مہربان خبردار ہے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmdclix{جوکچھ آسمانوں اور زمین میں ہے سب اسی کا ہے اور بے شک الله وہی بے نیاز قابل تعریف ہے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmdclx{کیا تم نے نہیں دیکھا کہ الله نے زمین کی سب چیزوں اور کشتیوں کو تمہارے تابع کر دیا ہےجو دریا میں اس کے حکم سے چلتی ہیں اور آسمان کو زمین پر گرنے سے تھامے ہوئے ہے مگر اس کے حکم سے بے شک الله لوگوں پر نرمی کرنے والا نہایت رحم کرنے والا ہے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmdclxi{اور وہ وہی ہے جس نے تمہیں زندہ کیا پھر تمہیں مارے گا پھر تمہیں زندہ کرے گا بے شک انسان البتہ بڑا ہی نا شکرا ہے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmdclxii{ہم نے ہر قوم کے لیے ایک دستور مقرر کر دیا ہے جس پر وہ چلتے ہیں پھر انہیں تمہارے ساتھ اس معاملہ میں جھگڑنا نہ چاہیئے اور اپنے رب کی طرف بلا بے شک تو البتہ سیدھے راستہ پر ہے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmdclxiii{اور اگر تجھ سے جھگڑا کریں تو کہہ دے الله بہتر جانتا ہے جو تم کرتے ہو\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmdclxiv{الله قیامت کے دن تمہارے درمیان فیصلہ کرے گا جس چیز میں تم اختلاف کرتے تھے\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmdclxv{کیا تجھے معلوم نہیں کہ الله جانتا ہے جو کچھ آسمان اور زمین میں ہے یہ سب کتاب میں لکھا ہوا ہے یہ الله پر آسان ہے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmdclxvi{اور الله کے سوا ایسی چیزکو پوجتے ہیں جس پر اس نے کوئی سند نہیں اتاری اور نہ انکے پاس کوئی اس کا علم ہے اور ظالموں کا کوئی مددگار نہ ہوگا\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmdclxvii{اور جب انہیں ہماری کھلی کھلی آیتیں پڑھ کر سنائی جائیں تو تم منکروں کے چہروں میں ناراضگی دیکھو گے قریب ہوتے ہیں کہ جو لوگ انہیں ہماری آیتیں پڑھ کر سناتے ہیں ان پر حملہ کر دیں کہہ دو کیا میں تمہیں اس سے بھی بدتر بات بتاؤں آگ ہے کہ جس کا الله نے منکروں سے وعدہ کیا ہے اور وہ بری جگہ ہے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmdclxviii{اے لوگو ایک مثال بیان کی جاتی ہے اسے کان لگا کر سنو جنہیں تم الله کے سوا پکارتے ہو وہ ایک مکھی بھی نہیں بنا سکتے اگرچہ وہ سب اس کے لیے جمع ہوجائیں اور اگر ان سے مکھی کوئی چیز چھین لے تو اسے مکھی سے چھڑا نہیں سکتے عابد اور معبود دونوں ہی عاجز ہیں\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmdclxix{انہوں نے الله کی کچھ بھی قدر نہ کی بے شک الله زوروالا غالب ہے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmdclxx{فرشتوں اور آدمیوں میں سے الله ہی پیغام پہنچانے کے لیے چن لیتا ہے بے شک الله سننے والا دیکھنے والا ہے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmdclxxi{وہ ان کے اگلے اور پچھلے حالات جانتا ہے اور سب کاموں کا مدار الله پر ہے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmdclxxii{اے ایمان والو رکوع اور سجدہ کرو اور اپنے رب کی بندگی کرو اور بھلائی کرو تاکہ تمہارا بھلا ہو\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmdclxxiii{اور الله کی راہ میں کوشش کرو جیسا کوشش کرنے کا حق ہے اس نے تمہیں پسند کیا ہے اور دین میں تم پر کسی طرح کی سختی نہیں کی تمہارے باپ ابراھیم کا دین ہے اسی نے تمہارا نام پہلے سےمسلمان رکھا تھااوراس قرآن میں بھی تاکہ رسول تم پر گواہ بنے اور تم لوگو ں پر گواہ بنو پس نماز قائم کرو اور زکوٰة دو اور الله کو مضبوط ہو کر پکڑو وہی تمہارا مولیٰ ہے پھر کیا ہی اچھامولیٰ اور کیا ہی اچھا مددگار ہے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmdclxxiv{\basmalahur ٰبے شک ایمان والے کامیاب ہو گئے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmdclxxv{جو اپنی نماز میں عاجزی کرنے والے ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmdclxxvi{اور جو بے ہودہ باتو ں سے منہ موڑنے والے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmdclxxvii{اور جو زکواة دینے والے ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmdclxxviii{اور جو اپنی شرم گاہوں کی حفاظت کرنے والے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmdclxxix{مگر اپنی بیویوں یا لونڈیوں پر اس لیے کہ ان میں کوئی الزام نہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmdclxxx{پس جو شخص اس کے علاوہ طلب گار ہو تو وہی حد سے نکلنے والے ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmdclxxxi{اور جو اپنی امانتوں اور اپنے وعدہ کا لحاظ رکھنے والے ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmdclxxxii{اور جو اپنی نمازوں کی حفاظت کرتے ہیں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmdclxxxiii{وہی وارث ہیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmdclxxxiv{جو جنت الفردوس کے وارث ہوں گے وہ اس میں ہمیشہ رہنے والے ہوں گے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmdclxxxv{اور البتہ ہم نے انسان کومٹی کے خلاصہ سے پیدا کیا\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmdclxxxvi{پھر ہم نے حفاظت کی جگہ میں نطفہ بنا کر رکھا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmdclxxxvii{پھر ہم نے نطفہ کا لوتھڑا بنایا پھر ہم نے لوتھڑے سے گوشت کی بوٹی بنائی پھر ہم نے اس بوٹی سے ہڈیاں بنائیں پھر ہم نے ہڈیوں پر گوشت پہنایا پھر اسے ایک نئی صورت میں بنا دیا سو الله بڑی برکت والا سب سےبہتر بنانے والا ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmdclxxxviii{پھر تم اس کے بعد مرنے والے ہو\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmdclxxxix{پھر تم قیامت کے دن اٹھائے جاؤ گے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmdcxc{اورہم ہی نے تمہارے اوپر سات آسمان بنائے ہیں اور ہم بنانے میں بے خبر نہ تھے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmdcxci{اور ہم نے ایک اندازہ کے ساتھ آسمان سے پانی نازل کیا پھر اسے زمین میں ٹھیرایا اور ہم اس کے لے جانے پر بھی قادر ہیں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmdcxcii{پھر ہم نے اس سے تمہارے لیے کھجور اور انگور کے باغ اگا دیے جن میں تمہارے بہت سے میوے ہیں اور انہی میں سے کھاتے ہو\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmdcxciii{اور وہ درخت جو طور سینا سے نکلتا ہے جو کھانے والوں کے لیے روغن اور سالن لے کر اگتا ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmdcxciv{اور بے شک تمہارے لیے چارپایوں میں بھی عبرت ہے کہ ہم تمہیں ان کے پیٹ کی چیزوں میں سے پلاتے ہیں اور تمہارے لیے ان میں اوربھی بہت سے فائدے ہیں اور ان میں سے بعض کو کھاتے ہو\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmdcxcv{اور ان پر اور کشتیوں پر سوار بھی کیے جاتے ہو\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmdcxcvi{اور ہم نے نوح کو اس کی قوم کے پاس بھیجا پھر اس نے کہا اے میری قوم الله کی بندگی کرو اس کے سوا تمہارا کوئی معبود نہیں پھر تم کیوں نہیں ڈرتے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmdcxcvii{سواس کی قوم کے کافر سرداروں نے کہا کہ یہ بس تم ہی جیسا آدمی ہے تم پر بڑائی حاصل کرنا چاہتا ہے اور اگر الله چاہتا تو فرشتے بھیج دیتا ہم نے اپنے پہلے باب دادا سے یہ بات کبھی نہیں سنی\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmdcxcviii{یہ تو بس ایک دیوانہ آدمی ہے پس اس کا ایک وقت تک انتظار کرو\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmdcxcix{کہا اے میرے رب تو میری مدد کر کیوں کہ انہو ں نے مجھے جھٹلایا ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmdcc{پھر ہم نے اس کی طرف وحی کی کہ ہماری آنکھوں کے سامنے اور ہمارے حکم سے کشتی بنا پھر جب ہمارا حکم آ پہنچے اور تنور ابلنے لگے پس تو کشتی میں ہر چیز کا جوڑا نر مادہ اور اپنے گھر والوں کو بٹھا لے مگر ان میں سے وہ شخص جس کے لیے پہلے فیصلہ ہو چکا ہے او رظالموں کے معاملہ میں مجھ سے بات نہ کر بے شک وہ غرق کیے جائیں گے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmdcci{پھر جب تو اور جو تیرے ساتھ ہے کشتی پر چڑھ بیٹھو تو کہہ الله کا شکر ہے جس نے ہمیں ظالموں سے چھوڑایا\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmdccii{اور کہہ اے میرے رب مجھے برکت کے ساتھ اتار اور تو بہتر اتارنے والا ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmdcciii{اس واقعہ میں بہت سی نشانیاں ہیں بے شک ہم تو آزمائش کرنے والے تھے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmdcciv{پھر ہم نے انکے بعد ایک دوسرا دور پیدا کیا\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmdccv{پھر ان میں بھی انہیں میں سے ایک رسول بھیجا کہ الله کی عبادت کرو تمہارے لیے اس کے سوا اورکوئی معبود نہیں پھر تم کیوں نہیں ڈرتے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmdccvi{اوراس کی قوم کے سرداروں نے کہا جنہوں نے کفر کیا تھا اور قیامت کی آمد کو جھٹلاتے تھے اور جنہیں ہم نے دنیا کی زندگی میں آسودہ کر رکھا تھا کہ یہ بس تمہیں جیسا آدمی ہے وہی کھاتا ہے جو تم کھاتے ہو اور وہی پیتا ہے جو تم پیتے ہو\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmdccvii{اوراگر تم نےاپنے جیسے آدمی کی فرمانبرداری کی توبے شک تم گھاٹے میں پڑ گئے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmdccviii{کیا تمہیں وعدہ دیتا ہے کہ جب تم مر جاؤ گے اورمٹی اور ہڈیاں ہو جاؤ گے تو تم نکالے جاؤ گے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmdccix{بہت ہی بعید بہت ہی بعید بات ہے جو تم سے کہی جاتی ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmdccx{ہماری صرف یہی دنیا کی زندگی ہے مرتے اور جیتےہیں اور ہم اٹھائے نہیں جائیں گے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmdccxi{بس یہ ایک ایسا شخص ہے جو الله پر جھوٹ باندھتا ہے اور ہم اسے ماننے والے نہیں ہیں\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmdccxii{کہا اے میرے رب میری مدد کر کہ انہو ں نے مجھے جھٹلایا ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmdccxiii{فرمایا تھوڑی دیر کے بعد یہ خود نادم ہوں گے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmdccxiv{پھر انہیں ایک سخت آواز نے سچے وعدہ کا موافق آ پکڑا پھر ہم نے انہیں خس و خاشاک کر دیا پھر ظالموں پر الله کی پٹکار ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmdccxv{پھر ہم نے ان کے بعد اوربہت سے دور پیدا کیے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmdccxvi{کوئی جماعت نہ اپنے وقت سے آگے بڑھ سکتی ہے نہ پیچھے ہٹ سکتی ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmdccxvii{پھر ہم اپنے رسول لگاتار بھیجتے رہے جب کوئی رسول اپنی قوم کے پاس آیا وہ اسے جھٹلاتی ہی رہی پھر ہم بھی ایک کے بعد دوسری کو ہلاک کرتے گئے اور ہم نے ان کو افسانے بنا دیے پھر ان لوگوں پر پھٹکار ہے جو ایمان نہیں لاتے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmdccxviii{پھر ہم نے موسیٰ اور اس کے بھائی ہارون کو اپنی نشانیاں اور کھلی سند دے کر\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmdccxix{فرعون اور اس کے سرداروں کے پاس بھیجا پھر انہوں نے تکبر کیا اور وہ سرکش لوگ تھے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmdccxx{پھر کہا کیا ہم اپنے جیسے دو شخصوں پر ایمان لائیں جن کی قوم ہماری غلامی کر رہی ہو\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmdccxxi{پھر ان دونوں کو جھٹلایا پھر ہلاک کر دیے گئے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmdccxxii{اور البتہ ہم نے موسیٰ کو کتاب دی تھی تاکہ وہ ہدایت پائیں\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmdccxxiii{اور ہم نے مریم کے بیٹے اور اس کی ماں کو نشانی بنایا تھا اور انہیں ایک ٹیلہ پر جگہ دی جہاں ٹھیرےنے کا موقع اور پانی جاری تھا\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmdccxxiv{ا ے رسولو! ستھری چیزیں کھاؤ اور اچھے کام کرو بے شک میں جانتا ہوں جو تم کرتے ہو\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmdccxxv{اور بے شک یہ تمہاری جماعت ایک ہی جماعت ہے اور میں تم سب کا رب ہوں پس مجھ سے ڈرو\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmdccxxvi{پھر انہوں نے اپنے دین کو آپس میں ٹکڑے ٹکڑے کر لیا ہر ایک جماعت اس ٹکڑے پو جو ان کے پاس ہے خوش ہونے والے ہیں\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmdccxxvii{پھر ایک وقت تک انہیں اپنے نشہ میں پڑا رہنے دو\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmdccxxviii{کیا وہ یہ خیال کرتے ہیں کہ ہم انہیں مال اور اولاد میں ترقی دے رہے ہیں\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmdccxxix{انہیں فائدہ پہچانے میں جلدی کر رہے ہیں بلکہ یہ نہیں سمجھتے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmdccxxx{بے شک جو اپنے رب کی ہیبت سے ڈرنے والے ہیں\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmdccxxxi{اور جو اپنے رب کی آیتوں پر ایمان لاتے ہیں\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmdccxxxii{اور جو اپنے رب کے ساتھ کسی کو شریک نہیں کرتے\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmdccxxxiii{اور جو دیتے ہیں جو کچھ دیتے ہیں اور ان کے دل اس سے ڈرتے ہیں کہ وہ اپنے رب کی طرف لوٹنے والے ہیں\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmdccxxxiv{یہی لوگ نیک کامو ں میں جلدی کرتے ہیں اور وہی نیکیوں میں آگے بڑھنے والے ہیں\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmdccxxxv{اور ہم کسی پر اس کی طاقت سے بڑھ کر بوجھ نہیں ڈالتے اور ہمارے پاس ایک کتاب ہے جو سچ بولے گی اور ان پر ظلم نہیں کیا جائے گا\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmdccxxxvi{بلکہ ان کے دل اس سے بے ہوشی میں پڑے ہوئے ہیں اوراس کے سوا ان کے اوربھی کام ہیں کہ جنہیں وہ کیا کرتے ہیں\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmdccxxxvii{یہاں تک کہ جب ہم ان میں سے آسودہ حال لوگوں کو عذاب میں پکڑیں گے فوراً وہ چلائیں گے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmdccxxxviii{آج کے دن مت چلاؤ بے شک تم ہم سے چھڑائے نہ جاؤ گے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmdccxxxix{تمہیں میری آیتیں سنائی جاتی تھیں پھر تم ایڑیوں پر الٹے بھاگتے تھے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmdccxl{غرور میں آ کر اسے کہانی سمجھ کر چلے جایا کرتے تھے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmdccxli{کیا انہوں نے اس ارشاد میں غور ہی نہیں کیا یا ان کے پاس ایسی بات آئی ہے جو ان کے پہلے باپ دادا کے پاس نہیں آئی تھی\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmdccxlii{یا یہ لوگ اپنے رسول کو پہچانتے نہیں تب یہ اس کے منکر ہیں\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmdccxliii{یا کہتے ہیں کہ اسے جنون ہے بلکہ رسول ان کے پاس حق بات لے کر آیا ہے اور ان میں سے اکثر حق کو ناپسند کرنے والے ہیں\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmdccxliv{اوراگر حق ان کی خواہشوں کے مطابق ہوتا تو آسمان اور زمین میں اورجو کچھ ان میں ہے درہم برہم ہو گیا ہوتا بلکہ ہم نے تو ان کی نصیحت انہیں پہنچا دی ہے سو وہ اپنی نصیحت سے منہ موڑنے والے ہیں\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmdccxlv{کیا تو ان سے کچھ اجرت مانگتا ہے سو تیرے رب کی اجرت بہتر ہے اور وہی سب سے بہتر روزی دینے والا ہے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmdccxlvi{اوربے شک تو انہیں سیدھے راستہ کی طرف بلاتا ہے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmdccxlvii{اور جو لوگ آخرت کو نہیں مانتے سیدھے راستہ سے ہٹنے والے ہیں\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmdccxlviii{اور اگر ہم ا ن پر رحم کر کے ان کی تکلیف کو دور کر دیں تو بھی وہ اپنی سرکشی میں گمراہ پڑے رہیں گے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmdccxlix{اور البتہ ہم نے انہیں عذاب میں مبتلا بھی کیا پھر بھی اپنے رب کے سامنے عاجزی نہ کی اورنہ گڑگڑائے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmdccl{یہاں تک کہ جب ہم نے ان پر سخت عذاب کا دروازہ کھولا تو فوراً اس میں نا امید ہوگئے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmdccli{اور اسی نے تمہارے کان اور آنکھیں اور دل بنائےہیں تم بہت ہی کم شکر کرتے ہو\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmdcclii{اور اسی نے تمہیں زمین میں پھیلا رکھا ہے اور اسی کی طرف جمع کیے جاؤ گے\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmdccliii{اور وہی زندہ کرتا ہے اورمارتا ہے اور رات اور دن کا بدلنا اسی کی اختیار میں ہے سو کیا تم نہیں سمجھتے\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmdccliv{بلکہ وہی کہتے ہیں جو پہلے لوگ کہتے تھے\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmdcclv{کہتے ہیں کیا جب ہم مرجائیں گے اور مٹی اور ہڈیاں ہو جائیں گے تو کیا ہم دوبارہ زندہ کیے جائیں گے\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmdcclvi{اس کا تو ہم سے اوراس سے پہلے اور ہمارے باپ دادا سے وعدہ ہوتا چلاآیا ہے یہ صرف اگلےلوگوں کی کہانیاں ہیں\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmdcclvii{ان سے پوچھو یہ زمین اور جو کچھ اس میں ہے کس کا ہے اگر تم جانتے ہو\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmdcclviii{وہ فوراً کہیں گے الله کاہے کہہ دو پھر تم کیوں نہیں سمجھتے\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmdcclix{ان سے پوچھو کہ ساتوں آسمانوں اور عرش عظیم کا مالک کون ہے\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmdcclx{وہ فوراً کہیں گے الله ہے کہہ دوکیاپھر تم الله سے نہیں ڈرتے\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmdcclxi{ان سے پوچھو کہ ہر چیز کی حکومت کس کے ہاتھ میں ہے اور وہ بچا لیتا ہے اور اسے کوئی نہیں بچا سکتا اگر تم جانتے ہو\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmdcclxii{وہ فوراً کہیں گے الله ہی کے ہاتھ میں ہے کہہ دو پھرتم کیسے دیوانے ہو رہے ہو\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmdcclxiii{بلکہ ہم نے تو ان کے پاس حق بات پہنچا دی اور بے شک وہ البتہ جھوٹے ہیں\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmdcclxiv{الله نے کوئی بھی بیٹا نہیں بنایا اورنہ اس کے ساتھ کوئی معبود ہی ہے اگر ہوتا تو ہر خدا اپنی بنائی ہوئی چیز کو الگ لے جاتا اور ایک دوسرے پر چڑھائی کرتا الله پاک ہے جو یہ بیان کرتے ہیں\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmdcclxv{غائب اور حاضر سب کا جاننے والا ہے وہ بہت بلند ہے اس سے جسے یہ شریک بناتے ہیں\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmdcclxvi{کہہ دو اے میرے رب اگر تو مجھے دکھائے وہ چیز جس کا انہیں وعدہ دیا جارہا ہے\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmdcclxvii{تو اے میرے رب مجھے ظالموں میں شامل نہ کر\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mmdcclxviii{اور ہم اس پر قادر ہیں کہ تجھے دکھا دیں جو ہم نے ان سے وعدہ کیا ہے\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mmdcclxix{بری بات کے جواب میں وہ کہو جو بہتر ہے ہم خوب جانتے ہیں جو یہ بیان کرتے ہیں\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mmdcclxx{اور کہواے میرے رب میں شیطانی خطرات سے تیری پناہ مانگتا ہوں\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxi{اوراےمیرے رب میں تیری پناہ چاہتا ہوں اس سے کہ شیطان میرے پاس آئيں\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxii{یہاں تک کہ جب ان میں سے کسی کو موت آئے گی تو کہے گا اے میرے رب مجھے پھر بھیج دے\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxiii{تاکہ جسے میں چھوڑ آیا ہوں اس میں نیک کام کر لوں ہر گز نہیں ایک بات ہی بات ہے جسے یہ کہہ رہا ہے اور ان کے آگے قیامت تک ایک پردہ پڑا ہوا ہے\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxiv{پھر جب صور پھونکا جائے گا تو اس دن ان میں نہ رشتہ داریاں رہیں گے اور نہ کوئی کسی کو پوچھے گا\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxv{پھر جن کا پلہ بھاری ہوا تو وہی فلاح پائیں گے\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxvi{اورجن کا پلہ ہلکا ہوگا تو وہی یہ لوگ ہوں گے جنہوں نے اپنا نقصان کیا ہمیشہ جہنم میں رہنے والے ہوں گے\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxvii{ان کے مونہوں کو آگ جھلس دے گی اور وہ اس میں بدشکل ہونے والے ہوں گے\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxviii{کیا تمہیں ہماری آیتیں نہیں سنائی جاتی تھیں پھر تم انہیں جھٹلاتے تھے\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxix{کہیں گے اے ہمارے رب ہم پر ہماری بدبختی غالب آگئی تھی اور ہم لوگ گمراہ تھے\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxx{اے رب ہمارے ہمیں اس سے نکال دے اگر پھر کریں تو بے شک ہم ظالم ہوں گے\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxi{فرمائے گا اس میں پھٹکارے ہوئے پڑے رہو اور مجھ سے نہ بولو\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxii{میرے بندوں میں سے ایک گروہ تھا جو کہتے تھے اے ہمارے رب ہم ایمان لائے تو ہمیں بخش دے اور ہم پر رحم کرو اور تو بہت بڑا رحم کرنے والا ہے\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxiii{سو تم نے ان کی ہنسی اڑائی یہا ں تک کہ انہوں نے تمہیں میری یاد بھی بھلادی اور تم ان سے ہنسی ہی کرتے رہے\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxiv{آج میں نے انہیں ان کے صبر کا بدلہ دیا کہ وہی کامیاب ہوئے\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxv{فرمائے گا تم زمین پر گنتی کے کتنےبرس رہے\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxvi{کہیں گے ایک دن یا اس سے بھی کم رہے ہیں پس آپ گنتی کرنے والوں سے پوچھ لیں\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxvii{فرمائے گا تم اس میں بہت نہیں تھوڑا ہی رہے ہو کاش کہ تم سمجھ لیتے\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxviii{سو کیا تم یہ خیال کرتے ہو کہ ہم نے تمہیں نکما پیدا کیا ہے اور یہ کہ تم ہمارے پاس لوٹ کر نہیں آؤ گے\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxix{سو الله بہت ہی عالیشان ہے جو حقیقی بادشاہ ہے اس کے سوا اور کوئی معبود نہیں عرش عظیم کا مالک ہے\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@mmdccxc{اور جس نے الله کے ساتھ اور معبو کو پکارا جس کی اس کے پاس کوئی سند نہیں تو اس کا حساب اسی کے رب کے ہاں ہوگا بے شک کافر نجات نہیں پائیں گے\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@mmdccxci{اورکہو اے میرے رب معاف کر اور رحم کر اور تو سب سے بہتر رحم کرنے والا ہے\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@mmdccxcii{\basmalahur یہ ایک سورت ہے جسے ہم نے نازل کیا ہے اور اس کے احکام ہم نے ہی فرض کئے ہیں اور ہم نے اس میں صاف صاف آیتیں نازل کی ہیں تاکہ تم سمجھو\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmdccxciii{بدکار عورت اور بدکار مرد سو دونوں میں سے ہر ایک کو سو سو دُرّے مارو اور تمہیں الله کے معاملہ میں ان پر ذرا رحم نہ آنا چاہیئے اگر تم الله پر اور قیامت کے دن پر ایمان رکھتے ہو اور ان کی سزا کے وقت مسلمانوں کی ایک جماعت کو حاضر رہنا چاہیئے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmdccxciv{بدکار مرد سوائے بدکار عورت یا مشرکہ کے نکاح نہیں کرے گا اور بدکار عورت سے سوائے بد کار مرد یا مشرک کے اور کوئی نکاح نہیں کرے گا اور ایمان والوں پر یہ حرام کیا گیا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmdccxcv{اور جو لوگ پاک دامن عورتوں پر تہمت لگاتے ہیں اور پھر چار گواہ نہیں لاتے تو انہیں اسّی درے مارو اور کبھی ان کی گواہی قبول نہ کرو اور وہی لوگ نافرمان ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmdccxcvi{مگر جنہوں نے اس کے بعد توبہ کر لی اور درست ہو گئے تو بے شک الله ہی بخشنے والا نہایت رحم والا ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmdccxcvii{او رجو لوگ اپنی بیویوں پر تہمت لگاتے ہیں اور ان کے لیے سوائے اپنے اورکوئی گواہ نہیں تو ایسے شخص کی گواہی کی یہ صورت ہے کہ چار مرتبہ الله کی قسم کھا کر گواہی دے کہ بے شک وہ سچا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmdccxcviii{او رپانچویں مرتبہ یہ کہے کہ اس پر اللہ کی لعنت ہواگر وہ جھوٹا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmdccxcix{او رعورت کی سزا کو یہ بات دور کر دے گی کہ الله کو گواہ کر کے چار مرتبہ یہ کہے کہ بے شک اس پر الله کا غضب پڑے اگر وہ سچا ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmdccc{اور پانچویں مرتبہ کہے کہ بے شک اس پر الله کا غضب پڑے اگر وہ سچا ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmdccci{اور اگر تم پر الله کا فضل اور اس کی رحمت نہ ہوتی اور یہ کہ الله توبہ قبول کرنے والا حکمت والا ہے (تو کیا کچھ نہ ہوتا)\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmdcccii{بے شک جو لوگ یہ طوفان لائے ہیں تم ہی میں سے ایک گروہ ہے تم سے اپنے حق میں برا نہ سمجھو بلکہ وہ تمہارے لیے بہتر ہے ان میں سے ہر ایک کے لیے بقدرِ عمل گناہ ہے اور جس نے ان میں سے سب سے زیادہ حصہ لیا اس کے لیے بڑا عذاب ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmdccciii{جب تم نے یہ بات سنی تھی تو مسلمان مردوں اور مسلمان عورتوں نے اپنے لوگوں کے ساتھ نیک گمان کیوں نہ کیا او رکیو ں نہ کہا کہ یہ صریح بہتان ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmdccciv{یہ لوگ اس پرچار گواہ کیو ں نہ لائے پھر جب وہ گواہ نہ لائے تو الله کے نزدیک وہی جھوٹے ہیں\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmdcccv{اور اگر تم پر الله کا فضل اور دنیا اور آخرت میں اس کی رحمت نہ ہوتی تو اس چرچا کرنے میں تم پر کوئی بڑی آفت پڑتی\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmdcccvi{جب تم اسے اپنی زبانوں سے نکالنے لگے اور اپنے مونہوں سے وہ بات کہنی شروع کر دی جس کا تمہیں علم بھی نہ تھا اور تم نے اسے ہلکی بات سمجھ لیا تھا حالانکہ وہ الله کے نزدیک بڑی بات ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmdcccvii{اور جب تم نے اسے سنا تھا تو کیوں نہ کہہ دیا کہ ہمیں تو اس کا منہ سے نکالنا بھی لائق نہیں سبحان الله یہ بڑا بہتان ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmdcccviii{الله تمہیں نصیحت کرتا ہے کہ پھر کبھی ایسا نہ کرنا اگر تم ایمان دار ہو\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmdcccix{اور الله تمہارے لیے آیتیں بیان کرتا ہے اور الله جاننے والا حکمت والا ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmdcccx{بے شک جو لوگ چاہتے ہیں کہ ایمانداروں میں بدکاری کا چرچا ہو ان کے لیے دنیا اور آخرت میں دردناک عذاب ہے اور الله جانتا ہے اور تم نہیں جانتے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmdcccxi{اور اگرتم پر الله کا فضل اوراس کی رحمت نہ ہوتی اوریہ کہ الله نرمی کرنے والا مہربان ہے (تو کیا کچھ نہ ہوتا)\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmdcccxii{اے ایمان والو شیطان کے قدموں پر نہ چلو اورجو کوئی شیطان کے قدموں پرچلے گا سو وہ تو اسے بے حیائی اور بری باتیں ہی بتائے گا اوراگر تم پر الله کا فضل اوراس کی رحمت نہ ہوتی تو تم میں سے کوئی کبھی بھی پاک صاف نہ ہوتا اورلیکن الله جسے چاہتا ہے پاک کر دیتا ہے اور الله سننے والا جاننے والا ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmdcccxiii{اور تم میں سے بزرگی اور کشائش والے اس بات پر قسم نہ کھائیں کہ رشتہ داروں اور مسکینوں اور الله کی راہ میں ہجرت کرنے والوں کو نہ دیا کریں گے اور انہیں معاف کرنا اور درگذر کرنا چاہیے کیا تم نہیں چاہتے کہ الله تمہیں معاف کر دے اور الله بخشنے والا نہایت رحم والا ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmdcccxiv{جو لوگ پاک دامنوں بے خبر ایمان والیوں پر تہمت لگاتے ہیں ان پر دنیا اور آخرت میں لعنت ہے اوران کے لیےبڑا عذاب ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmdcccxv{جس دن ان پر ان کی زبانیں اور ان کے ہاتھ پاؤں گواہی دیں گے جو کچھ وہ کیا کرتے تھے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmdcccxvi{اس دن الله انہیں انصاف سے پوری جزا دے گا اور جان لیں گے بے شک الله ہی حق بیان کرنے والا ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmdcccxvii{ناپاک عورتیں ناپاک مردوں کے لیے ہیں اور ناپاک مرد ناپاک عورتو ں کے لیے ہیں او رپاک عورتیں پاک مردوں کے لیے ہیں اور پاک مرد پاک عورتوں کے لیے ہیں وہ لوگ اس سے پاک ہیں جو یہ کہتے ہیں ا ن کے لیے بخشش اورعزت کی روزی ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmdcccxviii{اے ایمان والو اپنے گھروں کے سوا اور کسی کے گھروں میں نہ جایا کرو جب تک اجازت نہ لے لو او رگھر والوں پر سلام نہ کر لو یہ تہارے لیے بہتر ہے تاکہ تم نصیحت حاصل کرو\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmdcccxix{پھر اگر وہاں کسی کو نہ پاؤ تو اندر نہ جاؤ جب تک کہ تمہیں اجازت نہ دی جائے اور اگر تمہیں کہا جائے کہ لوٹ جاؤ تو اپس چلے جاؤ یہ تمہارے حق میں بہتر ہے اور جو کچھ تم کرتے ہو الله جانتا ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmdcccxx{تم پراس میں کوئی گناہ نہیں کہ ان گھروں میں جاؤ جہاں کوئی نہیں بستا ان میں تمہارا سامان ہے اور الله جانتا ہے جو تم ظاہر کرتے ہو اور جو تم چھپاتے ہو\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxi{ایمان والوں سے کہہ دو کہ وہ اپنی نگاہ نیچی رکھا کریں اور اپنی شرم گاہوں کو بھی محفوظ رکھیں یہ ان کے لیے بہت پاکیزہ ہے بے شک الله جانتا ہے جو وہ کرتے ہیں\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxii{اور ایمان والیوں سے کہہ دو کہ اپنی نگاہ نیچی رکھیں اور اپنی عصمت کی حفاظت کریں اور اپنی زینت کو ظاہر نہ کریں مگر جو جگہ اس میں سے کھلی رہتی ہے اوراپنے دوپٹے اپنے سینوں پر ڈالے رکھیں اوراپنی زینت ظاہر نہ کریں مگر اپنے خاوندوں پر یا اپنے باپ یا خاوند کے باپ یا اپنے بھائیوں یا بھتیجوں یا بھانجوں پر یا اپنی عورتوں پر یا اپنے غلاموں پر یا ان خدمت گاروں پر جنہیں عورت کی حاجت نہیں یا ان لڑکوں پر جو عورتوں کی پردہ کی چیزوں سے واقف نہیں اور اپنے پاؤں زمین پر زور سے نہ ماریں کہ ان کا مخفی زیور معلوم ہوجائے اوراے مسلمانو تم سب الله کے سامنے توبہ کرو تاکہ تم نجات پاؤ\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxiii{اور جو تم میں مجرّد ہوں اور جو تمہارے غلام اور لونڈیاں نیک ہوں سب کے نکاح کرادو اگر وہ مفلس ہو ں گے تو الله اپنے فضل سے انہیں غنی کر دے گا اور الله کشائش والا سب کچھ جاننے والا ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxiv{اور چاہیے کہ پاک دامن رہیں وہ جو نکاح کی توفیق نہیں رکھتے یہاں تک کہ الله انہیں اپنے فضل سے غنی کر دے اور تمہارے غلاموں میں سے جو لوگ مال دے کر آزادی کی تحریر چاہیں تو انہیں لکھ دو بشرطیکہ ان میں بہتری کے آثار پاؤ اور انہیں الله کے مال میں سے دو جو اس نے تمہیں دیا ہے اور تمہاری لونڈیاں جو پاک دامن رہنا چاہتی ہیں انہیں دنیا کی زندگی کے فائدہ کی غرض سے زنا پر مجبور نہ کرو اور جو انہیں مجبور کرے گا تو الله ان کے مجبور ہونے کے بعد بخشنے والا مہربان ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxv{اور البتہ ہم نے تمہارے پاس روشن آیتیں بھیج دی ہیں اور جن میں تم سے پہلوں کے حالات ہیں او رجو پرہیز گاروں کے لیے نصیحت ہیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxvi{الله آسمانوں اور زمین کا نور ہے اس کے نور کی مثال ایسی ہے جیسے طاق میں چراغ ہو چراغ شیشے کی قندیل میں ہے قندیل گویا کہ موتی کی طرح چمکتا ہوا ستارا ہے زیتون کے مبارک درخت سے روشن کیا جاتا ہے نہ مشرق کی طرف ہے اور نہ مغرب کی طرف اس کا تیل قریب ہے کہ روشن ہوجائے اگرچہ اسے آگ نے نہ چھوا ہو روشنی ہے الله جسے چاہتا ہے اپنی روشنی کی راہ دکھاتا ہے اور الله کے لیے مثالیں بیان فرماتا ہے اور الله ہر چیز کا جاننے والا ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxvii{ان گھروں میں جن کی تعظیم کرنے اور ان میں اس کا نام یاد کرنے کا الله نے حکم دیا ان میں صبح اور شام الله کی تسبیح پڑھتے ہیں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxviii{ایسے آدمی جنہیں سوداگری اور خرید و فروخت الله کے ذکر اور نماز کے پڑھنے اور زکوٰة کے دینے سے غافل نہیں کرتی اس دن سے ڈرتے ہیں جس میں دل اور آنکھیں الٹ جائیں گی\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxix{تاکہ الله انہیں ان کے عمل کا اچھا بدلہ دے اور انہیں اپنے فضل سے اور بھی دے اور الله جسے چاہتا ہے بے حساب روزی دیتا ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxx{اور جو کافر ہیں ان کے اعمال ایسے ہیں جیسے جنگل میں چمکتی ہوئی ریت ہو جسے پیاسا پانی سمجھتا ہے یہاں تک کہ جب اس کے پاس آتا ہے اسے کچھ بھی نہیں پاتا اور الله ہی کو اپنے پاس پاتا ہے پھر الله نے اس کا حساب پورا کر دیا اور الله جلد حساب لینے والا ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxi{یا جیسے گہرے دریا میں اندھیرے ہوں اس پر ایک لہر چڑھ آتی ہے اس پرایک او رلہر ہے اس کے اوپر بادل ہے اوپر تلے بہت سے اندھیرے ہیں جب اپنا ہاتھ نکالے تو اسے کچھ بھی دیکھ نہ سکے اور جسے الله ہی نے نور نہ دیا ہو اس کے لیے کہیں نور نہیں ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxii{کیا تم نے نہیں دیکھا کہ آسمانوں اور زمین کے رہنے والے اور پرند جو پر پھیلائے اڑتے ہیں سب الله ہی کی تسبیح کرتے ہیں ہر ایک نے اپنی نماز اور تسبیح سمجھ رکھی ہے اور الله جانتا ہے جو کچھ وہ کرتے ہیں\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxiii{اور آسمانوں اور زمین کی بادشاہی الله ہی کی ہے اور الله ہی کی طرف لوٹ کر جانا ہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxiv{کیا تو نے نہیں دیکھا الله ہی بادل کو چلاتا ہے پھر اسے ملاتا ہے پھر اسے تہہ بر تہہ کرتا ہے پھر تو بارش کو دیکھتا ہے کہ اس کے بیچ میں سے نکلتی ہے اور آسمان سے جو ان میں اولوں کے پہاڑ ہیں ان میں سے اولے برساتا ہے پھر انہیں جس پر چاہتا ہے گراتا ہے اور جس سے چاہتا ہے روک لیتا ہے قریب ہے کہ اس کی بجلی کی چمک آنکھوں کو لے جائے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxv{الله ہی رات اور دن کو بدلتا ہے بے شک اس میں آنکھوں والوں کے لیے عبرت ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxvi{اور الله نے ہر جاندار کو پانی سے بنایا ہے سو بعض ان میں سے اپنےپیٹ کے بل چلتے ہیں اور بعض ان میں سے دو پاؤں پر چلتے ہیں اور اور بعض ان میں سے چار پاؤں پر چلتے ہیں الله جو چاہتا ہے پیدا کرتا ہے بے شک الله ہر چیز پر قادر ہے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxvii{البتہ ہم نے کھلی کھلی آیتیں نازل کر دی ہیں اور الله جسے چاہے سیدھے راستہ پر چلاتا ہے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxviii{اور کہتے ہیں ہم الله اور رسول پرایمان لائے اور ہم فرمانبردار ہو گئے پھر ایک گروہ ان میں سے اس کے بعد پھر جاتا ہے اور وہ لوگ مومن نہیں ہیں\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxix{اورجب انہیں الله اور اس کے رسول کی طرف بلایا جائے تاکہ ان میں فیصلہ کرے تب ہی ایک گروہ ان میں سے منہ موڑنے والے ہیں\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmdcccxl{اور اگر انہیں حق پہنچتا ہو تو اس کی طرف گردن جھکائے آتے ہیں\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmdcccxli{کیا ان کے دلوں میں بیماری ہے یا شک میں پڑے ہیں یا ڈرتے ہیں اس سے کہ ان پر الله اور اس کا رسول ظلم کرے گا بلکہ وہی ظالم ہیں\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmdcccxlii{مومنوں کی بات تو یہی ہوتی ہے جب انہیں الله اور اس کے رسول کی طرف بلایا جاتا ہے تاکہ وہ ان کے درمیان فیصلہ کرے وہ کہتے ہیں کہ ہم نے سنا اور مان لیا اور وہی لوگ نجات پانے والے ہیں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmdcccxliii{اور جو شخص الله اور اس کے رسول کی اطاعت کرتا ہے اور الله سے ڈرتا ہے اور اس کی نافرمانی سے بچتا ہے بس وہی کامیاب ہونے والے ہیں\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmdcccxliv{اور الله کی پکی قسمیں کھا کر کہتے ہیں کہ اگر آپ انہیں حکم دیں تو سب کچھ چھوڑ کر نکل جائیں کہہ دو قسمیں نہ کھاؤ دستور کے موافق فرمانبرداری چاہیئے بے شک الله جانتا ہے جو تم کرتے ہو\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmdcccxlv{کہہ دو الله اور اس کے رسول کی فرمانبرداری کرو پھر اگر منہ پھیرو گے تو پیغمبر تو وہی ہے جس کا وہ ذمہ دار ہے اورتم پر وہ ہے جو تمہارے ذمہ لازم کیا گیا ہے اور اگر اس کی فرمانبرداری کرو گے تو ہدایت پاؤ گے اور رسول کے ذمہ صرف صاف طور پر پہنچا دینا ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmdcccxlvi{الله نے ان لوگوں سے وعدہ کیا ہے جو تم میں سے ایمان لائے اور نیک عمل کیے کہ انہیں ضرور ملک کی حکومت عطا کرے گا جیسا کہ ان سے پہلوں کو عطا کی تھی اور ان کے لیے جس دین کو پسند کیا ہے اسے ضرور مستحکم کر دے گا اور البتہ ان کے خوف کو امن سے بدل دے گا بشرطیکہ میری عبادت کرتے رہیں اور میرے ساتھ کسی کو شریک نہ کریں اور جواس کے بعد ناشکری کرے وہی فاسق ہوں گے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmdcccxlvii{اور نماز پڑھا کرو اور زکوٰة دیا کرو اور رسول کی فرمانبرداری کرو تاکہ تم پر رحم کیا جائے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmdcccxlviii{کافروں کی نسبت یہ خیال نہ کر کہ ملک میں عاجز کر دیں گے اور ان کا ٹھکانہ دوزخ ہے اور بہت ہی برا ٹھکانہ ہے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmdcccxlix{اے ایمان والو تمہارے غلام اور تمہارےوہ لڑکے جو ابھی بالغ نہیں ہوئے تم سے ان تین وقتوں میں اجازت لے کر آیا کریں صبح کی نماز سے پہلے اور دوپہر کے وقت جب کہ تم اپنے کپڑے اتار دیتے ہو اور عشا کی نماز کے بعد یہ تین وقت تمہارے پردوں کے ہیں ان کے بعد تم پر اور نہ ان پر کوئی الزام ہے تم آپس میں ایک دوسرے کے پاس آنے جانے والے ہو اسی طرح الله تمہارے لیے آیتیں کھول کر بیان کرتا ہے اور الله جاننے والا حکمت والا ہے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmdcccl{اورجب تمہارے لڑکے بلوغ کو پہنچ جائیں انہیں بھی اجازت لے کر آنا چاہیے جس طرح کہ ان سے پہلے لوگ اجازت لے کر آتے ہیں الله اس طرح تمہارے لیے کھول کر احکام بیان کرتا ہے اور الله جاننے والا حکمت والا ہے\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmdcccli{اوروہ بڑی بوڑھی عورتیں جو نکاح کی رغبت نہیں رکھتیں ان پر اس بات میں کوئی گناہ نہیں کہ اپنے کپڑے اتار رکھیں بشرطیکہ زینت کا اظہار نہ کریں اور اس سے بھی بچیں توان کے لیے بہتر ہے اور الله سننے والا جاننے والا ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmdccclii{اندھے پر اور لنگڑ ے پر اور بیمار پر اور خود تم پر اس بات میں کوئی گناہ نہیں کہ تم اپنے گھروں سے کھانا کھاؤ یا اپنے باپ کے گھروں سے یا اپنی ماؤں کے گھروں سے یا اپنے بھائیوں کے گھروں سے یا اپنی بہنوں کے گھروں سے یا اپنے چچاؤں کے گھروں سے یا اپنی پھوپھیوں کے گھروں سے یا اپنے ماموؤں کے گھروں سے یا اپنی خالاؤں کےگھروں سے یا ان گھروں سے جنکی کنجیاں تمہارے اختیار میں ہیں یا اپنے دوستوں کے گھروں سے تم پر کوئی گناہ نہیں کہ مل کر کھاؤ یا الگ الگ کھاؤ پھر جب گھروں میں داخل ہونا چاہو تو اپنے لوگوں سے سلام کیا کرو جو الله کی طرف سے مبارک اور عمدہ دعا ہے اسی طرح الله تمہارے لیے احکام بیان فرماتا ہے تاکہ تم سمجھو\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmdcccliii{مومن تو وہی ہیں جو الله اور اس کے رسول پر ایمان لائے ہیں اور جب وہ اس کے ساتھ کسی جمع ہونے کے کام میں ہوتے ہیں تو چلے نہیں جاتے جب تک اس سے اجازت نہ لیں جو لوگ تجھ سے اجازت لیتے ہیں وہی ہیں جوالله اور اس کے رسول پرایمان لائے ہیں پھر جب تجھ سے اپنے کسی کام کے لیے اجازت مانگیں تو ان میں سے جسے تو چاہے عزت دے اور ان کے لیے الله سے بخشش کی دعا کر الله بخشنے والا نہایت رحم والا ہے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmdcccliv{رسول کے بلانے کو آپس میں ایک دوسرے کے بلانے جیسا نہ سمجھو الله انہیں جانتا ہے جو تم میں سے چھپ کر کھسک جاتے ہیں سو جو لوگ الله کے حکم کی مخالفت کرتے ہیں انہیں اس سے ڈرنا چاہیئے کہ ان پر کوئی آفت آئے یا ان پر کوئی دردناک عذاب نازل ہوجائے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmdccclv{خبردار الله ہی کا ہے جو کچھ آسمانوں اور زمین میں ہے اسے معلوم ہے جس حال پر تم ہو اور جس دن اس کی طرف پھیر لائے جائیں گے تو انہیں بتائے گا جو کچھ وہ کرتے تھے اور الله ہر چیز کو جاننے والا ہے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmdccclvi{\basmalahur وہ بڑی برکت والا ہے جس نے اپنے بندے پر قرآن نازل کیا تاکہ تمام جہان کے لیےڈرانے والا ہو\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmdccclvii{وہ جس کی آسمانوں اور زمین میں سلطنت ہے اور اس نے نہ کسی کو بیٹا بنایا ہے اور نہ کوئی سلطنت میں اس کا شریک ہے اور اس نے ہر چیز کو پیدا کر کے اندازہ پر قائم کر دیا\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmdccclviii{اور انہوں نے الله کے سوا ایسے معبود بنا رکھے ہیں جو کچھ بھی پیدا نہیں کر سکتے حالانکہ وہ خود پیدا کیے گئے ہیں اور وہ اپنی ذات کے لیے نقصان اور نفع کے مالک نہیں اور موت اور زندگی اور دوبارہ اٹھنے کے بھی مالک نہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmdccclix{اور کافر کہتے ہیں کہ یہ تو محض جھوٹ ہے جسے اس نے بنا لیا ہے اور دوسرے لوگوں نے اس میں ا س کی مدد کی ہے پس وہ بڑے ظلم اور جھوٹ پر اتر آئے ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmdccclx{اور کہتے ہیں کہ پہلوں کی کہانیاں ہیں کہ جنہیں اس نے لکھ رکھا ہے پس وہی اس پر صبح اور شام پڑھی جاتی ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmdccclxi{کہہ دو کہ اسے تو اس نے نازل کیا ہے جو آسمانوں اور زمین کی پوشیدہ باتیں جانتا ہے بے شک وہ بخشنے والا نہایت رحم والا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmdccclxii{اور کہتے ہیں اس رسول کو کیا ہوگیا کہ کھاناکھاتا اور بازاروں میں پھرتا ہے اس کے پاس کوئی فرشتہ کیوں نہیں بھیجا گیا کہ اس کے ساتھ وہ بھی ڈرانے والا ہوتا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmdccclxiii{یا اس کے پاس کوئی خزانہ آجاتا یا اس کے لیے باغ ہوتا جس میں سےکھاتا اور بے انصافوں نے کہا کہ تم تو بس ایک ایسے شخص کے تابع ہوگئے جس پر جادو کیا گیا ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmdccclxiv{دیکھو تو تمہارے لیے کیسی مثالیں بیان کرتے ہیں پس وہ ایسے گمراہ ہو ئے کہ راستہ بھی نہیں پا سکتے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmdccclxv{بڑی برکت ہے اس کی جو چاہے تو تیرے لیے اس سے بہتر باغ بنا دے جن کے نیچے نہریں بہتی ہوں اور تیرے لیے محل بنا دے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmdccclxvi{بلکہ انہوں نے تو قیامت کو جھوٹ سمجھ لیا ہے اور ہم نے اس کے لیے آگ تیار کی ہے جو قیامت کو جھٹلاتا ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmdccclxvii{جب وہ انہیں دور سے دیکھے گی تو اس کے جوش و خروش کی آواز سنیں گے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmdccclxviii{اور جب وہ اس کے کسی تنگ مکان میں جکڑکر ڈال دیے جائیں گے تو وہاں موت کو پکاریں گے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmdccclxix{آج ایک موت کو نہ پکارو اور بہت سی موتوں کو پکارو\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmdccclxx{کہہ دو کیا بہتر ہے یا وہ بہشت جس کا پرہیز گارو ں کے لیے وعدہ کیا گیا ہے جو ان کا بدلہ اور ٹھکانہ ہوگی\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxi{وہاں انہیں جو چاہیں گے ملے گا وہ اس میں ہمیشہ رہیں گے یہ وعدہ تیرے رب کے ذمہ ہے جو قابل درخواست ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxii{اورجس دن انہیں اور ان کے معبودوں کو جمع کرے گا جنھیں وہ الله کے سوا پوجتے تھے تو فرمائے گا کیا تم ہی نے میرے ان بندوں کو گمراہ کیا تھا یا وہ خود راستہ بھول گئے تھے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxiii{کہیں گے تو پاک ہے ہمیں یہ کب لایق تھا کہ تیرے سوا کسی اور کو کارساز بناتے لیکن تو نے انہیں اور ان کے باپ دادا کو یہاں تک آسودگی دی تھی کہ وہ یاد کرنا بھول گئے اور یہ لوگ تباہ ہونے والے تھے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxiv{سو تمہارے معبودوں نے تمہاری باتو ں میں تمہیں جھٹلا دیا سو تم نہ تو ٹال سکتے ہو اور نہ مدد دے سکتے ہو اور جو تم میں سے ظلم کرے گا ہم اسے بڑا عذاب چکھائیں گے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxv{اور ہم نے تجھ سے پہلے جتنے پیغمبر بھیجے وہ کھانا بھی کھاتے تھے اور بازاروں میں بھی چلتے پھرتے تھے اورہم نے تمہیں ایک دوسرے کے لیے آزمائش بنایا کیا تم ثابت قدم رہتے ہو اور تیرا رب سب کچھ دیکھنے والا ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxvi{اور ان لوگوں نے کہا جو ہم سے ملنے کی امید نہیں رکھتے کہ ہمارے پاس فرشتے کیوں نہ بھیجے گئے یا ہم اپنے رب کو دیکھ لیتے البتہ انہوں نے اپنے آپ کو بہت بڑاسمجھ لیا ہے اور بہت بڑی سرکشی کی ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxvii{جس دن فرشتوں کو دیکھیں گے اس دن مجرموں کے لیے کوئی خوشی نہیں ہو گی اورکہیں گے آڑ کر دی جائے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxviii{اور جو عمل انہوں نے کیے تھے ہم ان کی طرف متوجہ ہوں گے پھر انہیں اڑتی ہوئی خاک کر دیں گے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxix{اس دن بہشتیوں کا ٹھکانا بہتر ہوگا اور دوپہر کی آرام گاہ بھی عمدہ ہو گی\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxx{اور جس دن آسمان بادل سے پھٹ جائے گا اور فرشتے بکثرت اتارے جائیں گے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxi{اس دن حقیقی حکومت رحمنٰ ہی کی ہوگی اور وہ دن کافروں پر بڑا سخت ہوگا\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxii{اور اس دن ظالم اپنے ہاتھ کاٹ کاٹ کھائے گا کہے گا اے کاش میں بھی رسول کے ساتھ راہ چلتا\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxiii{ہائے میری شامت کاش میں نے فلاں کو دوست نہ بنایا ہوتا\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxiv{اسی نے تو نصیحت کے آنے کےبعد مجھے بہکا دیا اور شیطان تو انسان کو رسوا کرنے والا ہی ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxv{اور رسول کہے گا اے میرے رب بےشک میری قوم نے اس قرآن کو نظر انداز کر رکھا تھا\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxvi{اور ہم اسی مجرموں کو ہر ایک نبی کا دشمن بناتے رہے ہیں اور ہدایت کرنے اور مدد کرنے کے لیے تیرا رب کافی ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxvii{اور کافر کہتے ہیں کہ اس پر یکبارگی قرآن کیوں نازل نہیں کیا گیا اسی طرح اتارا گیا تاکہ ہم اس سے تیرے دل کو اطمینان دیں اور ہم نے اسے ٹھہر ٹھہر کر پڑھ سنایا\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxviii{اور جو انوکھی بات تیرے سامنے لائیں گے ہم بھی تمہیں اس کا بہت ٹھیک جواب اوربہت عمدہ حل بتائیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxix{جو لوگ مونہوں کے بل گھسیٹ کر جہنم میں ڈالیں جائیں گے یہی برے درجے والے ہیں اور بہت ہی بڑے گمراہ ہیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmdcccxc{اور البتہ تحقیق ہم نے موسیٰ کو کتاب دی اور ہم نے اس کے ساتھ اس کے بھائی ہارون کو وزیر بنایا\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmdcccxci{پھر ہم نے کہا تم دونو ان لوگوں کی طرف جاؤ جنہو ں نے ہماری آیتیں جھٹلائی ہیں پھر ہم نے انہیں جڑ سے اکھاڑ کر پھینک دیا\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmdcccxcii{اور نوح کی قوم کوبھی جب انہو ں نے رسولوں کو جھٹلایا تو ہم نے انہیں غرق کر دیا اور ہم نے انہیں لوگوں کے لیے نشانی بنا دیا اور ہم نے ظالموں کے لیے دردناک عذاب تیار کیا ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmdcccxciii{اور عاد اور ثمود اورکنوئیں والوں کو بھی اوربہت سے دور جو ان کے درمیان تھے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmdcccxciv{اور ہم نے ہر ایک کو مثالیں دے کر سمجھایا تھا اور سب کو ہم نے ہلاک کر دیا\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmdcccxcv{اور یہ اس بستی پر بھی گزرے ہیں جس پر بری طرح پتھر برسائے گئے سو کیا یہ لوگ اسے دیکھتے نہیں رہتے بلکہ یہ لوگ مر کر زندہ ہونے کی امید ہی نہیں رکھتے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmdcccxcvi{اور جب یہ لوگ تمہیں دیکھتے ہیں تو بس تم سے مذاق کرنے لگتے ہیں کیا یہی ہے جسےالله نے رسول بنا کر بھیجا\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmdcccxcvii{اس نے تو ہمیں ہمارے معبودوں سے ہٹا ہی دیا ہوتا اگر ہم ان پر قائم نہ رہتے اور انہیں جلدی معلوم ہوجائے گا جب عذاب دیکھیں گے کہ کون شخص گمراہ تھا\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmdcccxcviii{کیا تم نے اس شخص کو دیکھا جس نے اپنا خدا اپنی خوہشات نفسانی کو بنا رکھا ہے پھر کیا تو اس کا ذمہ دار ہو سکتا ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmdcccxcix{یا تو خیال کرتا ہے کہ اکثر ان میں سے سنتے یا سمجھتے ہیں یہ تو محض چوپایوں کی طرح ہیں بلکہ ان سے بھی زیادہ گمراہ ہیں\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmcm{کیا تو نے اپنے رب کی طرف نہیں دیکھا کہ اس نے سایہ کو کیسے پھیلایا ہے اور اگر چاہتا تو اسے ٹھہرا رکھتا پھر ہم نے سورج کو اس کا سبب بنا دیا ہے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmcmi{پھر ہم اسے آہستہ آہستہ اپنی طرف سمیٹتے ہیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmcmii{اور وہی ہے جس نے تمہارے لیے رات کو اوڑھنا اور نیند کو راحت بنا دیا اور دن چلنے پھرنے کے لیے بنایا\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmcmiii{اوروہی تو ہے جو اپنی رحمت سے پہلے خوشخبری لانے والی ہوائیں چلاتا ہے اور ہم نے آسمان سے پاک پانی نازل فرمایا\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmcmiv{تاکہ ہم اس سے مرے ہوئے شہر کو زندہ کریں اور اسے اپنی پیدا کی ہوئی چیزوں، چارپایوں اوربہت سے آدمیوں کوپلائیں\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmcmv{اور ہم نے اسے لوگوں میں بانٹ دیا ہے تاکہ نصیحت حاصل کریں پس بہت سے آدمی ناشکری کیے بغیر نہ رہے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmcmvi{اور اگر ہم چاہتے تو ہر گاؤں میں ایک ڈرانے والا بھیج دیتے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmcmvii{پس کافروں کا کہا نہ مان اس کے ساتھ بڑے زور سے ان کا مقابلہ کر\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmcmviii{اور وہی ہے جس نے دو دریاؤں کو آپس میں ملا دیا یہ میٹھا خوشگوار ہے او ریہ کھاری کڑوا ہے اوران دونوں میں ایک پردہ اور مستحکم آڑ بنا دی\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmcmix{اوروہی ہے جس نے انسان کو پانی سے پیدا کیا پھر ا س کے لیے رشتہ نسب اور دامادی قائم کیا اور تیرا رب ہر چیز پر قادر ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmcmx{اور وہ الله کے سوا ایسے کو پوجتے ہیں جو انہیں نہ نفع دے سکتے ہیں نہ نقصان پہنچا سکتے ہیں اور کافر اپنے رب کی طرف پیٹھ پھیرنے والا ہے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmcmxi{اور ہم نےتمہیں محض خوشخبری دینے والا اور ڈرانے والا بنا کر بھیجا ہے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmcmxii{کہہ دو میں اس پر تم سے کوئی مزدوری نہیں مانگتا مگر جو شخص اپنے رب کی طرف راستہ معلوم کرنا چاہے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmcmxiii{اورتم اس زندہ خدا پر بھروسہ رکھو جو کبھی نہ مرے گا اور اس کی تسبیح اورحمد کرتے رہو اور وہ اپنے بندوں کے گناہوں سے کافی خبردار ہے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmcmxiv{جس نے آسمان اور زمین اور جو کچھ ان میں ہے چھ دن میں بنایا پھر عرش پر قائم ہوا وہ رحمنٰ ہے پس ا س کی شان کسی خبردار سے پوچھو\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmcmxv{اورجب ان سے کہا جاتا ہے کہ رحمنٰ کو سجدہ کرو توکہتے ہیں رحمنٰ کیا ہے کیا ہم اسے سجدہ کریں جس کے لیے تو کہہ دے اور اس سے انہیں اور زیادہ نفرت ہوتی ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmcmxvi{بڑا برکت والا ہے وہ جس نے آسمان میں ستارے بنائے اور اس میں چراغ اور چمکتا ہوا چاند بھی بنایا\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmcmxvii{اور وہی ہے جس نے رات اور دن یکے بعد دیگرے آنے والے بنائے یہ اس کے لیے ہے جو سمجھنا چاہے یا شکر کرنا چاہے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmcmxviii{اور رحمنٰ کے بندے وہ ہیں جو زمین پردبے پاؤں چلتے ہیں اورجب ان سے بے سمجھ لوگ بات کریں تو کہتے ہیں سلام ہے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmcmxix{اور وہ لوگ جو اپنے رب کے سامنے سجدہ میں اور کھڑے ہوکر رات گزارتے ہیں\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmcmxx{اور وہ لوگ جو کہتے ہیں اے ہمارے رب ہم سے دوزخ کا عذاب دور کر دے بے شک اس کا عذاب پوری تباہی ہے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmcmxxi{بے شک وہ برا ٹھکانا اوربڑی قیام گاہ ہے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmcmxxii{اوروہ لوگ جب خرچ کرتے ہیں تو فضول خرچی نہیں کرتے اور نہ تنگی کرتے ہیں اور ان کا خرچ ان دونوں کے درمیان اعتدال پر ہوتا ہے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmcmxxiii{اوروہ جو الله کے سوا کسی اور معبود کونہیں پکارتے اور اس شخص کوناحق قتل نہیں کرتے جسے الله نے حرام کر دیا ہے اور زنا نہیں کرتے اور جس شخص نے یہ کیا وہ گناہ میں جا پڑا\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmcmxxiv{قیامت کے دن اسے دگنا عذاب ہو گا اس میں ذلیل ہو کر پڑا رہے گا\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmcmxxv{مگر جس نے توبہ کی اور ایمان لایا اور نیک کام کیے سو انہیں الله برائیوں کی جگہ بھلائیاں بدل دے گا اور الله بخشنے والا مہربان ہے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmcmxxvi{اور جس نے توبہ کی اور نیک کام کیے تو وہ الله کی طرف رجوع کرتا ہے\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmcmxxvii{اور جو بے ہودہ باتوں میں شامل نہیں ہوتے اور جب بیہودہ باتوں کے پاس سے گزریں تو شریفانہ طور سے گزرتے ہیں\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmcmxxviii{اور وہ لوگ جب انہیں ان کے رب کی آیتوں سے سمجھایا جاتا ہے تو ان پر بہرے اندھے ہو کر نہیں گرتے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmcmxxix{اور وہ جو کہتے ہیں کہ ہمارے رب ہمیں ہماری بیویوں اور اولاد کی طرف سے آنکھوں کی ٹھنڈک عطا فرما اور ہمیں پرہیزگاروں کا پیشوا بنا دے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmcmxxx{یہی لوگ ہیں جنہیں ان کے صبر کے بدلہ میں جنت کے بالا خانے دیے جائیں گے اور ان کا وہاں دعا اور سلام سے استقبال کیا جائے گا\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmcmxxxi{اس میں ہمیشہ رہنے والے ہوں گے ٹھیرنے اور رہنے کی خوب جگہ ہے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmcmxxxii{کہہ دو میرا رب تمہاری پروا نہیں کرتا اگرتم اسے نہ پکارو سو تم جھٹلا توچکے ہو پھر اب تو اس کا وبال پڑ کر رہے گا\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmcmxxxiii{\basmalahur طسمۤ\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmcmxxxiv{یہ روشن کتاب کی آیتیں ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmcmxxxv{شاید تو اپنی جان ہلاک کرنے والا ہے اس لیے کہ وہ ایمان نہیں لاتے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmcmxxxvi{اگر ہم چاہیں تو ان پر آسمان سے ایسی نشانی نازل کریں کہ اس کے آگے ان کی گردنیں جھک جائیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmcmxxxvii{اور ان کے پاس رحمنٰ کی طرف سے کوئی نئی بات نصیحت کی ایسی نہیں آئی کہ وہ اس سے منہ نہ موڑ لیتے ہوں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmcmxxxviii{سو یہ جھٹلاتو چکے اب ان کے پاس اس چیز کی حقیقت آئے گی جس پر ٹھٹھا کیا کرتے تھے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmcmxxxix{کیا وہ زمین کو نہیں دیکھتے ہم نے اس میں ہر ایک قسم کی کتنی عمدہ چیزیں اُگائی ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmcmxl{البتہ اس میں بڑی نشانی ہے اور ان میں سے اکثر ایمان لانے والے نہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmcmxli{اور بے شک تیرا رب زبردست رحم کرنے والا ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmcmxlii{اور جب تیرے رب نے موسیٰ کو پکارا کہ اس ظالم قوم کے پاس جا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmcmxliii{فرعون کی قوم کے پاس کیا وہ ڈرتے نہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmcmxliv{عرض کی اے میرے رب میں ڈرتا ہوں کہ مجھے جھٹلا دیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmcmxlv{اور میرا سینہ تنگ ہوجائے اور میری زبان نہ چلے پس ہارون کو پیغام دے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmcmxlvi{اور میرے ذمہ ان کا ایک گناہ بھی ہے سو میں ڈرتا ہوں کہ مجھے مار نہ ڈالیں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmcmxlvii{فرمایا ہر گز نہیں تم دونوں ہماری نشانیاں لے کر جاؤ ہم تمہارے ساتھ سننے والے ہیں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmcmxlviii{سو فرعون کے پاس جاؤ اور کہو کہ ہم پروردگار عالم کا پیغام لے کر آئے ہیں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmcmxlix{یہ کہ ہمارے ساتھ بنی اسرائیل کو بھیج دے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmcml{کہا کیا ہم نےتمہیں بچپن میں پرورش نہیں کیا اورتو نے ہم میں اپنی عمر کے کئی سال گزارے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmcmli{اور تو اپنا وہ کرتوت کر گیا جوکر گیا اور تو ناشکروں میں سے ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmcmlii{کہا جب میں نے وہ کام کیا تھاتو میں بےخبر تھا\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmcmliii{پھر میں تم سے تمہارے ڈر کے مارے بھاگ گیا تب مجھے میرے رب نے دانائی عطا کی اور مجھے رسول بنایا\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmcmliv{اور یہ احسان جو تو مجھ پر رکھتا ہے اسی لیے تو نے بنی اسرائیل کو غلام بنا رکھا ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmcmlv{فرعون نے کہا رب العالمین کیا چیز ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmcmlvi{فرمایا آسمانوں اور زمین اور جو کچھ ان کے درمیان ہے سب کا پروردگار ہے اگر تمہیں یقین آئے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmcmlvii{اپنے گرد والوں سے کہا کیا تم سنتے نہیں ہو\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmcmlviii{فرمایا تمہارا ور تمہارے پہلے باپ دادا کا رب ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmcmlix{کہا بے شک تمہارا رسول جو تمہارے پاس بھیجا گیا ہے ضرور دیوانہ ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmcmlx{فرمایا مشر ق مغرب اور جو ان کے درمیان ہے سب کا پروردگار ہے اگر تم عقل رکھتے ہو\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmcmlxi{کہا اگر تو نے میرے سوا اور کوئی معبود بنایا تو تمہیں قید میں ڈال دوں گا\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmcmlxii{فرمایا اگرچہ میں تیرے پاس ایک روشن چیز لے آؤں\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmcmlxiii{کہا اگر تو سچا ہے تو وہ چیز لا\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmcmlxiv{پھر اس نےاپناعصا ڈال دیا سو اسی وقت وہ صریح اژدھا ہو گیا\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmcmlxv{اوراپنا ہاتھ نکالا سو اسی وقت وہ دیکھنے والوں کو چمکتا ہوا دکھائی دیا\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmcmlxvi{اپنے گرد کے سرداروں سے کہا کہ بے شک یہ بڑا ماہر جادوگر ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmcmlxvii{چاہتا ہے کہ تمہیں تمہارے دیس سے اپنے جادو کے زور سےنکال دےپھر تم کیا رائے دیتے ہو\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmcmlxviii{کہا اسےاور اس کے بھائی کو مہلت دو اور شہروں میں چپڑاسیوں کو بھیج دیجیئے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmcmlxix{کہ تیرے پاس بڑے ماہر جادوگروں کو لے آئیں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmcmlxx{پھر سب جادوگر ایک مقرر دن پر جمع کیے گئے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxi{اور لوگوں سے کہا گیا کیا تم بھی اکھٹے ہوتے ہو\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxii{تاکہ اگر جادوگر غالب آجائیں تو ہم انہی کی راہ پر رہیں\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxiii{پھر جب جادوگر آئے تو فرعون سے کہا اگر ہم غالب آگئے تو کیا ہمیں کوئی بڑا انعام ملے گا\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxiv{کہا ہاں اور بیشک تم اس وقت مقربوں میں داخل ہو جاؤ گے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxv{موسیٰ نے ان سے کہا ڈالو جو تم ڈالتے ہو\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxvi{پھر انہوں نے اپنی رسیاں اور لاٹھیاں ڈال دیں اور کہا فرعون کے اقبال سے ہماری فتح ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxvii{پھر موسیٰ نے اپنا عصا ڈالا پھر وہ فوراً ہی نگلنے لگا جو انہوں نے جھوٹ بنایا تھا\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxviii{پھر جادوگر سجدے میں گر پڑے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxix{کہا ہم رب العالمین پر ایمان لائے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxx{جو موسیٰ اور ہارون کا رب ہے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxi{کہا کیا تم میری اجازت سے پہلے ہی ایمان لے آئے بے شک وہ تمہارا استاد ہے جس نے تمہیں جادو سکھایا ہے سو تمہیں ابھی معلوم ہو جائے گا البتہ میں تمہارا ایک طرف کا ہاتھ اور دوسری طرف کا پاؤں کاٹ دوں گا اور تم سب کو سولی پر چڑھا دوں گا\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxii{کہا کچھ حرج نہیں بے شک ہم اپنے رب کے پاس پہنچنے والا ہوں گے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxiii{ہمیں امید ہے کہ ہمارا رب ہمارے گناہوں کو معاف کر دے گا اس لیے کہ ہم سب سے پہلے ایمان لانے والے ہیں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxiv{اور ہم نے موسی ٰکو حکم بھیجا کہ میرے بندوں کو رات کو لے نکل البتہ تمہارا پیچھا کیا جائے گا\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxv{پھر فرعون نے شہروں میں چپڑاسی بھیجے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxvi{کہ یہ ایک تھوڑی سی جماعت ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxvii{اور انہوں نے ہمیں بہت غصہ دلایا ہے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxviii{اور بے شک ہم سب ہتھیار بند ہیں\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxix{پھر ہم نے انہیں باغوں اور چشموں سے نکال باہر کیا\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmcmxc{اور خزانوں اور عمدہ مکانو ں سے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmcmxci{اسی طرح ہوا اور ہم نے ان چیزوں کا بنی اسرائیل کو وارث بنایا\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmcmxcii{پھر سورج نکلنے کے وقت ان کے پیچھے پڑے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmcmxciii{پھر جب دونوں جماعتوں نےایک دوسرے کو دیکھا تو موسیٰ کے ساتھیوں نے کہا ہم تو پکڑے گئے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmcmxciv{کہا ہرگز نہیں میرا رب میرے ساتھ ہے وہ مجھے راہ بتائے گا\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmcmxcv{پھر ہم نےموسیٰ کو حکم بھیجا کہ اپنی لاٹھی کو دریا پر مار پھر پھٹ گیا پھر ہر ٹکڑا بڑے ٹیلے کی طرح ہو گیا\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmcmxcvi{اور ہم نے اس جگہ دوسروں کو پہنچا دیا\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmcmxcvii{اورہم نے موسیٰ کی اور جو اس کے ساتھ تھے سب کو نجات دی\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmcmxcviii{پھر ہم نے دوسروں کو غرق کر دیا\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmcmxcix{البتہ اس میں بڑی نشانی ہے اور ان میں سے اکثر ایمان لانے والے نہیں\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmm{اور بے شک تیرا رب زبردست رحم کرنے والا ہے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmi{اور انہیں ابراھیم کی خبر سنا دے\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmii{جب اپنے باپ اور اپنی قوم سے کہا تم کس کو پوجتے ہو\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmiii{کہنے لگے ہم بتوں کو پوجتے ہیں پھر انہی کے گرد رہا کرتے ہیں\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmiv{کہا کیا وہ تمہاری بات سنتے ہیں جب تم پکارتے ہو\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmv{یا تمہیں کچھ نفع یا نقصان پہنچا سکتے ہیں\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmvi{کہنے لگے بلکہ ہم نے اپنے باپ دادا کو ایسا کرتے پایا ہے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmvii{کہا کیا تمہیں خبر ہے جنہیں تم پوجتے ہو\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmviii{تم او رتمہارے پہلے باپ دادا جنہیں پوجتے تھے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmix{سو وہ سوائے رب العالمین کے میرے دشمن ہیں\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmx{جس نے مجھے پیدا کیا پھر وہی مجھے راہ دکھاتا ہے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmxi{اور وہ جو مجھے کھلاتا اور پلاتا ہے\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmmxii{اور جب میں بیمار ہوتا ہوں تو وہی مجھے شفا دیتا ہے\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmmxiii{اور وہ جو مجھے مارے گا پھر زندہ کرے گا\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmmxiv{اور وہ جو مجھے امید ہے کہ میرے گناہ قیامت کے دن مجھے بخش دے گا\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmmxv{اے میرے رب مجھے کمال علم عطا فرما اور مجھے نیکیوں کے ساتھ شامل کر\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmmxvi{اور آئندہ آنے والی نسلوں میں میرا ذکر خیر باقی رکھ\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmmxvii{اور مجھے نعمت کے باغ کے وارثوں میں کر دے\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmmxviii{اور میرے باپ کو بخش دے کہ وہ گمراہوں میں سے تھا\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmmxix{اور مجھے ذلیل نہ کر جس دن لوگ اٹھائے جائیں گے\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmmxx{جس دن مال اور اولاد نفع نہیں دے گی\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmmxxi{مگر جو الله کے پاس پاک دل لے کر آیا\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmmxxii{اور پرہیز گاروں کے لیے جنت قریب لائی جائے گی\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmmxxiii{اور دوزخ سرکشوں کے لیے ظاہر کی جائے گی\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmmxxiv{اور انہیں کہا جائے گا کہاں ہیں جنہیں تم پوجتے تھے\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmmxxv{الله کے سوا کیا وہ تمہاری مدد کر سکتے ہیں یا بدلہ لے سکتے ہیں\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmmxxvi{پھر وہ اور سب گمراہ اس میں اوندھے ڈال دیے جائیں گے\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mmmxxvii{اور شیطان کے سارے لشکروں کو بھی\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mmmxxviii{اوروہ وہاں آپس میں جھگڑتے ہوئے کہیں گے\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mmmxxix{الله کی قسم بیشک ہم صریح گمراہی میں تھے\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mmmxxx{جب ہم تمہیں رب العالمین کے برابر کیا کرتے تھے\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mmmxxxi{اور ہمیں ان بدکاروں کے سوا کسی نے گمراہ نہیں کیا\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mmmxxxii{پھر کوئی ہماری سفارش کرنے والا نہیں\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mmmxxxiii{اور نہ کوئی مخلص دوست ہے\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mmmxxxiv{پھر اگر ہمیں دوبارہ جانا ملے تو ہم ایمان والوں میں شامل ہوں\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mmmxxxv{البتہ اس میں بڑی نشانی ہے اور ان میں سے اکثر ایمان لانے والے نہیں\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mmmxxxvi{اور بے شک تیرا رب زبردست رحم کرنے والا ہے\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mmmxxxvii{نوح کی قوم نے پیغمبروں کو جھٹلایا\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mmmxxxviii{جب ان کے بھائی نوح نے کہا کیا تم ڈرتے نہیں\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mmmxxxix{میں تمہارے لیے امانت دار رسول ہوں\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mmmxl{پس الله سے ڈرو اور میرا کہا مانو\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mmmxli{اور میں تم سے اس پر کوئی مزدوری نہیں مانگتا میری مزدوری تو بس رب العالمین کے ذمہ ہے\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mmmxlii{سو الله سے ڈرو اور میرا کہا مانو\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mmmxliii{انہوں نے کہا کیا ہم تجھ پر ایمان لائیں حالانکہ تیرے تابع توکمینے لوگ ہوئے ہیں\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mmmxliv{کہا اور مجھے کیا خبر کہ وہ کیا کرتے تھے\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@mmmxlv{ان کا حساب تو میرے رب ہی کے ذمہ ہے کاش کہ تم سمجھتے\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@mmmxlvi{اور میں ایمان والوں کو دور کرنے والا نہیں ہوں\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@mmmxlvii{میں تو بس کھول کر ڈرانے والا ہوں\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@mmmxlviii{کہنے لگے اے نوح اگر تو باز نہ آیا تو ضرور سنگسار کیا جائے گا\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@mmmxlix{کہا اے میرے رب میری قوم نے مجھے جھٹلایا ہے\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@mmml{پس تو میرے اور ان کے درمیان فیصلہ ہی کر دے اور مجھے اور جو میرے ساتھ ایمان والے ہیں نجات دے\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@mmmli{پھر ہم نے اسے اورجو اس کے ساتھ بھری کشتی میں تھے بچا لیا\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@mmmlii{پھر ہم نے اس کے بعد باقی لوگوں کو غرق کر دیا\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@mmmliii{البتہ اس میں بڑی نشانی ہے اور ان میں سے اکثر ایمان لانے والے نہیں\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@mmmliv{اور بے شک تیرا رب زبردست رحم کرنے والا ہے\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@mmmlv{قوم عاد نے پیغمبروں کو جھٹلایا\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@mmmlvi{جب ان سے ان کے بھائی ہود نے کہا کہ تم کیوں نہیں ڈرتے\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@mmmlvii{البتہ میں تمہارے لیے امانت دار رسول ہوں\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@mmmlviii{پس الله سے ڈرو اور میرا کہا مانو\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@mmmlix{اور میں تم سے ا سپر کوئی مزدوری نہیں مانگتا میری مزدوری تو بس رب العالمین کے ذمہ ہے\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@mmmlx{کیا تم ہر اونچی زمین پر کھیلنے کے لیے ایک نشان بناتے ہو\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@mmmlxi{اوربڑے بڑے محل بناتے ہو شاید کہ تم ہمیشہ رہو گے\qt@no{(129)}}%
\qt@newcmd\qurantrans@ur@mmmlxii{اورجب ہاتھ ڈالتے ہو تو بڑی سختی سےپکڑتے ہو\qt@no{(130)}}%
\qt@newcmd\qurantrans@ur@mmmlxiii{پس الله سے ڈرو اور میرا کہا مانو\qt@no{(131)}}%
\qt@newcmd\qurantrans@ur@mmmlxiv{اور اس سے ڈرو جس نے تمہاری ان چیزوں سے مدد کی ہے جنہیں تم بھی جانتے ہو\qt@no{(132)}}%
\qt@newcmd\qurantrans@ur@mmmlxv{چارپایوں اور اولاد سے\qt@no{(133)}}%
\qt@newcmd\qurantrans@ur@mmmlxvi{اور باغوں اور چشموں سے تمہیں مدد دی\qt@no{(134)}}%
\qt@newcmd\qurantrans@ur@mmmlxvii{میں تم پر ایک بڑے دن کے عذاب سے ڈرتا ہوں\qt@no{(135)}}%
\qt@newcmd\qurantrans@ur@mmmlxviii{کہنے لگے تو نصیحت کر یا نہ کر ہمارے لیے سب برابر ہے\qt@no{(136)}}%
\qt@newcmd\qurantrans@ur@mmmlxix{یہ تو بس پہلے لوگوں کی ایک عادت ہے\qt@no{(137)}}%
\qt@newcmd\qurantrans@ur@mmmlxx{اور ہمیں عذاب نہیں ہوگا\qt@no{(138)}}%
\qt@newcmd\qurantrans@ur@mmmlxxi{پھر انہو ں نے پیغمبر کو جھٹلایا تب ہم نے انہیں ہلاک کر دیا البتہ اس میں بڑی نشانی ہے اور ان میں اکثر ایمان لانے والے نہیں\qt@no{(139)}}%
\qt@newcmd\qurantrans@ur@mmmlxxii{اور بے شک تیرا رب زبردست رحم کرنے والا ہے\qt@no{(140)}}%
\qt@newcmd\qurantrans@ur@mmmlxxiii{قوم ثمود نے پیغمبروں کو جھٹلایا\qt@no{(141)}}%
\qt@newcmd\qurantrans@ur@mmmlxxiv{جب ان سے ان کے بھائی صالح نے کہا کیا تم ڈرتے نہیں\qt@no{(142)}}%
\qt@newcmd\qurantrans@ur@mmmlxxv{میں تمہارے لیے امانت دار رسول ہوں\qt@no{(143)}}%
\qt@newcmd\qurantrans@ur@mmmlxxvi{پس الله سے ڈرو اور میرا کہا مانو\qt@no{(144)}}%
\qt@newcmd\qurantrans@ur@mmmlxxvii{اور میں تم سے اسپر کوئی مزدوری نہیں مانگتا میری مزدوری تو بس رب العالمین کے ذمہ ہے\qt@no{(145)}}%
\qt@newcmd\qurantrans@ur@mmmlxxviii{کیا تمہیں ان چیزو ں میں یہاں بے فکری سے رہنے دیا جائے گا\qt@no{(146)}}%
\qt@newcmd\qurantrans@ur@mmmlxxix{یعنی باغوں اور چشموں میں\qt@no{(147)}}%
\qt@newcmd\qurantrans@ur@mmmlxxx{اور کھیتوں اور کھجوروں میں جن کا خوشہ ملائم ہے\qt@no{(148)}}%
\qt@newcmd\qurantrans@ur@mmmlxxxi{او رتم پہاڑوں کوتراش کر تکلف کے گھر بناتے ہو\qt@no{(149)}}%
\qt@newcmd\qurantrans@ur@mmmlxxxii{پس الله سے ڈرو اور میرا کہا مانو\qt@no{(150)}}%
\qt@newcmd\qurantrans@ur@mmmlxxxiii{اوران حد سے نکلنے والوں کا کہا مت مانو\qt@no{(151)}}%
\qt@newcmd\qurantrans@ur@mmmlxxxiv{جو زمین میں فساد کرتے ہیں اور اصلاح نہیں کرتے\qt@no{(152)}}%
\qt@newcmd\qurantrans@ur@mmmlxxxv{کہنے لگے تم پر تو کسی نے جادو کیا ہے\qt@no{(153)}}%
\qt@newcmd\qurantrans@ur@mmmlxxxvi{توبھی ہم جیسا ایک آدمی ہے سو کوئی نشانی لے آ اگر تو سچا ہے\qt@no{(154)}}%
\qt@newcmd\qurantrans@ur@mmmlxxxvii{کہا یہ اونٹنی ہے اسکے پینے کا ایک دن ہے اور یک دن معین تمہارے پینے کے لیے ہے\qt@no{(155)}}%
\qt@newcmd\qurantrans@ur@mmmlxxxviii{اور اسے برائی سے ہاتھ نہ لگانا ورنہ تمہیں بڑے دن کا عذاب آ پکڑے گا\qt@no{(156)}}%
\qt@newcmd\qurantrans@ur@mmmlxxxix{سو انہوں نے اس کے پاؤں کاٹ ڈالے پھر پشیمان ہوئے\qt@no{(157)}}%
\qt@newcmd\qurantrans@ur@mmmxc{پھر انہیں عذاب نے آ پکڑا البتہ اس میں بڑی نشانی ہے اور ان میں سے اکثر ایمان لانے والے نہیں\qt@no{(158)}}%
\qt@newcmd\qurantrans@ur@mmmxci{اوربے شک تیرا رب زبردست رحم کرنے والا ہے\qt@no{(159)}}%
\qt@newcmd\qurantrans@ur@mmmxcii{لوط کی قوم نے پیغمبروں کو جھٹلایا\qt@no{(160)}}%
\qt@newcmd\qurantrans@ur@mmmxciii{جب انہیں ان کے بھائی لوط نے کہا کیا تم ڈرتے نہیں\qt@no{(161)}}%
\qt@newcmd\qurantrans@ur@mmmxciv{میں تمہارے لیے امانت دار رسول ہوں\qt@no{(162)}}%
\qt@newcmd\qurantrans@ur@mmmxcv{پس الله سے ڈرو اور میرا کہا مانو\qt@no{(163)}}%
\qt@newcmd\qurantrans@ur@mmmxcvi{اورمیں تم سے اس پر کوئی مزودری نہیں مانگتا میری مزدوری تو بس اللهرب العالمین کے ذمہ ہے\qt@no{(164)}}%
\qt@newcmd\qurantrans@ur@mmmxcvii{کیا تم دنیا کے لوگوں میں لڑکوں پر گرے پڑتے ہو\qt@no{(165)}}%
\qt@newcmd\qurantrans@ur@mmmxcviii{اور تمہارے رب نےجو تمہارے لیے بیویاں پیدا کر دی ہیں انہیں چھوڑ دیتے ہو بلکہ تم حد سے گزرنے والے لوگ ہو\qt@no{(166)}}%
\qt@newcmd\qurantrans@ur@mmmxcix{کہنے لگے اے لوط اگر تو ان باتوں سے باز نہ آیا تو ضرور تو نکال دیا جائے گا\qt@no{(167)}}%
\qt@newcmd\qurantrans@ur@mmmc{کہا میں تو تمہارے کام سے سخت بیزار ہوں\qt@no{(168)}}%
\qt@newcmd\qurantrans@ur@mmmci{اے میرے رب مجھے اور میرے گھر والوں کو اس کے وبال سے نجات دے جو وہ کرتے ہیں\qt@no{(169)}}%
\qt@newcmd\qurantrans@ur@mmmcii{پھر ہم نے اسے اور اس کے سارے کنبے کو بچا لیا\qt@no{(170)}}%
\qt@newcmd\qurantrans@ur@mmmciii{مگر ایک بڑھیا جو پیچھے رہ گئی تھی\qt@no{(171)}}%
\qt@newcmd\qurantrans@ur@mmmciv{پھر ہم نے اور سب کو ہلاک کر دیا\qt@no{(172)}}%
\qt@newcmd\qurantrans@ur@mmmcv{اور ہم نے ان پر مینہ برسایا پھر ڈرائے ہوؤں پر بُرا مینہ برسا\qt@no{(173)}}%
\qt@newcmd\qurantrans@ur@mmmcvi{البتہ اس میں بڑی نشانی ہے اور ان میں سے اکثر ایمان لانے والے نہیں\qt@no{(174)}}%
\qt@newcmd\qurantrans@ur@mmmcvii{اوربیشک تیرا رب زبردست رحم کرنے والا ہے\qt@no{(175)}}%
\qt@newcmd\qurantrans@ur@mmmcviii{بن والوں نے بھی پیعمبروں کو جھٹلایا\qt@no{(176)}}%
\qt@newcmd\qurantrans@ur@mmmcix{جب ان سے شعیب نے کہا کیا تم ڈرتے نہیں\qt@no{(177)}}%
\qt@newcmd\qurantrans@ur@mmmcx{میں تمہارے لیے امانت دار رسول ہوں\qt@no{(178)}}%
\qt@newcmd\qurantrans@ur@mmmcxi{پس الله سے ڈرو اور میرا کہا مانو\qt@no{(179)}}%
\qt@newcmd\qurantrans@ur@mmmcxii{اور میں تم سے اس پر کوئی مزدوری نہیں مانگتا میری مزدوری تو بس رب العالمین کے ذمہ ہے\qt@no{(180)}}%
\qt@newcmd\qurantrans@ur@mmmcxiii{پیمانہ پورا دو اور نقصان دینے والے نہ بنو\qt@no{(181)}}%
\qt@newcmd\qurantrans@ur@mmmcxiv{اور صحیح ترازو سے تولا کرو\qt@no{(182)}}%
\qt@newcmd\qurantrans@ur@mmmcxv{اور لوگوں کو ان کی چیزیں کم کر کے نہ دو اور ملک میں فساد مچاتے نہ پھرو\qt@no{(183)}}%
\qt@newcmd\qurantrans@ur@mmmcxvi{اور اس سے ڈرو جس نے تمہیں اور پہلی خلقت کو بنایا\qt@no{(184)}}%
\qt@newcmd\qurantrans@ur@mmmcxvii{کہنے لگے کہ تم پر تو کسی نے جادو کر دیا\qt@no{(185)}}%
\qt@newcmd\qurantrans@ur@mmmcxviii{اورتو بھی ہم جیسا ایک آدمی ہے اور ہمارے خیال میں تو تو جھوٹا ہے\qt@no{(186)}}%
\qt@newcmd\qurantrans@ur@mmmcxix{سو ہم پر آسمان کا کوئی ٹکڑا گرا دے اگر تو سچا ہے\qt@no{(187)}}%
\qt@newcmd\qurantrans@ur@mmmcxx{کہا میرا رب خوب جانتا ہے جو کچھ تم کرتے ہو\qt@no{(188)}}%
\qt@newcmd\qurantrans@ur@mmmcxxi{پھر اسے جھٹلایا پھر انہیں سائبان والے دن کے عذاب نے پکڑ لیا بے شک وہ بڑے دن کا عذاب تھا\qt@no{(189)}}%
\qt@newcmd\qurantrans@ur@mmmcxxii{البتہ اس میں بڑی نشانی ہے اور ان میں سے اکثر ایمان لانے والے نہیں\qt@no{(190)}}%
\qt@newcmd\qurantrans@ur@mmmcxxiii{اور بے شک تیرا رب زبردست رحم کرنے والا ہے\qt@no{(191)}}%
\qt@newcmd\qurantrans@ur@mmmcxxiv{اور یہ قرآن رب العالمین کا اتارا ہوا ہے\qt@no{(192)}}%
\qt@newcmd\qurantrans@ur@mmmcxxv{اسے امانت دار فرشتہ لے کر آیا ہے\qt@no{(193)}}%
\qt@newcmd\qurantrans@ur@mmmcxxvi{تیرے دل پر تاکہ تو ڈرانے والوں میں سے ہو\qt@no{(194)}}%
\qt@newcmd\qurantrans@ur@mmmcxxvii{صاف عربی زبان میں\qt@no{(195)}}%
\qt@newcmd\qurantrans@ur@mmmcxxviii{اور البتہ اس کی خبر پہلوں کی کتابوں میں بھی ہے\qt@no{(196)}}%
\qt@newcmd\qurantrans@ur@mmmcxxix{کیا ان کے لیے نشانی کافی نہیں کہ اسے بنی اسرائیل کے علماء بھی جانتے ہیں\qt@no{(197)}}%
\qt@newcmd\qurantrans@ur@mmmcxxx{اور اگر ہم اسے کسی عجمی پر نازل کرتے\qt@no{(198)}}%
\qt@newcmd\qurantrans@ur@mmmcxxxi{پھر وہ اسے ان کے سامنے پڑھتا تو بھی ایمان نہ لاتے\qt@no{(199)}}%
\qt@newcmd\qurantrans@ur@mmmcxxxii{اسی طرح ہم نے اس انکار کو گناہگاروں کے دل میں ڈال رکھا ہے\qt@no{(200)}}%
\qt@newcmd\qurantrans@ur@mmmcxxxiii{وہ دردناک عذاب دیکھے بغیر اس پر ایمان نہیں لائیں گے\qt@no{(201)}}%
\qt@newcmd\qurantrans@ur@mmmcxxxiv{پھر وہ ان پر اچاناک آئے گا اور انہیں خبر بھی نہ ہوگی\qt@no{(202)}}%
\qt@newcmd\qurantrans@ur@mmmcxxxv{پھر کہیں گے کیا ہمیں مہلت مل سکتی ہے\qt@no{(203)}}%
\qt@newcmd\qurantrans@ur@mmmcxxxvi{کیا ہمارے عذاب کو جلد چاہتے ہیں\qt@no{(204)}}%
\qt@newcmd\qurantrans@ur@mmmcxxxvii{بھلا دیکھ اگر ہم انہیں چند سال فائدہ اٹھانے دیں\qt@no{(205)}}%
\qt@newcmd\qurantrans@ur@mmmcxxxviii{پھر ان کے پاس وہ عذاب آئے جس کا وعدہ دیے جاتے ہیں\qt@no{(206)}}%
\qt@newcmd\qurantrans@ur@mmmcxxxix{تو جو انہوں نے فائدہ اٹھایا ہے کیا ان کے کچھ کام بھی آئے گا\qt@no{(207)}}%
\qt@newcmd\qurantrans@ur@mmmcxl{اور ہم نے ایسی کوئی بستی ہلاک نہیں کی جس کے لیے ڈرانے والے نہ آئے ہوں\qt@no{(208)}}%
\qt@newcmd\qurantrans@ur@mmmcxli{نصیحت دینے کے لیے اور ہم ظالم نہیں تھے\qt@no{(209)}}%
\qt@newcmd\qurantrans@ur@mmmcxlii{اور قرآن کو شیطان لے کر نہیں نازل ہوئے\qt@no{(210)}}%
\qt@newcmd\qurantrans@ur@mmmcxliii{اور نہ یہ ان کا کام ہے اور نہ وہ اسے کر سکتے ہیں\qt@no{(211)}}%
\qt@newcmd\qurantrans@ur@mmmcxliv{وہ تو سننے کی جگہ سے بھی دور کر دیے گئے ہیں\qt@no{(212)}}%
\qt@newcmd\qurantrans@ur@mmmcxlv{سو الله کے ساتھ کسی اور معبود کو نہ پکار ورنہ تو بھی عذاب میں مبتلا ہو جائے گا\qt@no{(213)}}%
\qt@newcmd\qurantrans@ur@mmmcxlvi{اور اپنے قریب کے رشتہ داروں کو ڈرا\qt@no{(214)}}%
\qt@newcmd\qurantrans@ur@mmmcxlvii{اور جو ایمان لانے والے تیرے ساتھ ہیں ان کے لیے اپنا بازو جھکا ئے رکھ\qt@no{(215)}}%
\qt@newcmd\qurantrans@ur@mmmcxlviii{پھر اگر تیری نافرمانی کریں تو کہہ دے میں تمہارے کام سے بیزار ہوں\qt@no{(216)}}%
\qt@newcmd\qurantrans@ur@mmmcxlix{اور زبردست رحم والے پر بھروسہ کر\qt@no{(217)}}%
\qt@newcmd\qurantrans@ur@mmmcl{جو تجھے دیکھتا ہے جب تو اٹھتا ہے\qt@no{(218)}}%
\qt@newcmd\qurantrans@ur@mmmcli{اور نمازیوں میں تیری نشست و برخاست دیکھتا ہے\qt@no{(219)}}%
\qt@newcmd\qurantrans@ur@mmmclii{بیشک وہ سننے والا جاننے والا ہے\qt@no{(220)}}%
\qt@newcmd\qurantrans@ur@mmmcliii{کیا میں تمہیں بتاؤں شیطان کس پر اترتے ہیں\qt@no{(221)}}%
\qt@newcmd\qurantrans@ur@mmmcliv{ہر جھوٹے گناہگار پر اترتے ہیں\qt@no{(222)}}%
\qt@newcmd\qurantrans@ur@mmmclv{وہ سنی ہوئی باتیں پہنچاتے ہیں اوراکثر ان میں سے جھوٹے ہوتے ہیں\qt@no{(223)}}%
\qt@newcmd\qurantrans@ur@mmmclvi{اور شاعروں کی پیروی تو گمراہ ہی کرتے ہیں\qt@no{(224)}}%
\qt@newcmd\qurantrans@ur@mmmclvii{کیا تم نےنہیں دیکھاکہ وہ ہر میدان میں بھٹکتے پھرتے ہیں\qt@no{(225)}}%
\qt@newcmd\qurantrans@ur@mmmclviii{اور جو وہ کہتے ہیں کرتے نہیں\qt@no{(226)}}%
\qt@newcmd\qurantrans@ur@mmmclix{مگروہ جو ایمان لائے اور نیک کام کیے اور الله کوبہت یاد کیا اور مظلوم ہونے کے بعد بدلہ لیا اور ظالموں کو ابھی معلوم ہو جائے گا کہ کس کروٹ پر پڑتے ہیں\qt@no{(227)}}%
\qt@newcmd\qurantrans@ur@mmmclx{\basmalahur طسۤ یہ آیتیں قرآن کی اور کتاب روشن کی ہیں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmclxi{ایمان داورں کے لیے ہدایت اور خوشخبری ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmclxii{جو نماز ادا کرتے ہیں اور زکوةٰ دیتے ہیں اور وہ آخرت پر یقین رکھتے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmclxiii{البتہ جو لوگ آخرت پر ایمان نہیں رکھتے ہم نےان کے اعمال ان کے لیے اچھے کر دکھائے ہیں پس وہ سرگرداں پھرتے ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmclxiv{وہی ہیں جنہیں برا عذاب ہونا ہے اور وہ آخرت میں بڑے ہی خسارہ میں ہوں گے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmclxv{اور تجھے بڑے حکمت والے علم والے کی طرف سے قرآن دیاجارہا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmclxvi{جب موسیٰ نے اپنے گھر والوں سے کہا کہ میں نے آگ دیکھی ہے میں ابھی وہاں سے تمہارے پاس کوئی خبر لاتا ہوں یا کوئی انگارا سلگا کر لاتا ہوں تاکہ تم سینکو\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmclxvii{پھر جب موسیٰ وہاں آئے تو آواز آئی کہ جو آگ میں اور اس کے پاس ہے وہ با برکت ہے اور الله پاک ہے جو تمام جہان کا رب ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmclxviii{اے موسیٰ وہ میں الله ہوں زبردست حکمت والا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmclxix{اور اپنی لاٹھی ڈال دے پھر جب اسے دیکھا کہ وہ سانپ کی طرح چل رہی ہے تو پیٹھ پھیر کر بھاگا اورپیچھے مڑ کر نہ دیکھا اے موسیٰ ڈرو مت کیونکہ میرے حضور میں رسول ڈرا نہیں کرتے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmclxx{مگر جس نے ظلم کیا پھر برائی کے بعد اسے نیکی سے بدل دیا ہوتو میں بخشنے والا مہربان ہوں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmclxxi{اور اپنا ہاتھ اپنےگریبان میں ڈال دے وہ سفید بے عیب نکلے گا یہ دونوں ملا کر نونشانیاں فرعون اور اس کی قوم کی طرف لے کرجا کیونکہ وہ بدکار لوگ ہیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmclxxii{پھر جب ان کے پاس آنکھیں کھولنے والی ہماری نشانیاں آئیں تو کہنے لگے یہ تو صاف جادو ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmclxxiii{اور انہوں نے انکا ظلم اور تکبر سے انکار کرد یا حالانکہ ان کے دل یقین کر چکے تھے پھر دیکھ مفسدوں کا انجام کیسا ہوا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmclxxiv{اور ہم نے داؤد اور سلیمان کو علم دیا اور کہنے لگے الله کا شکر ہے جس نے ہمیں بہت سے ایمان دار بندوں پر فضیلت دی\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmclxxv{اور سلیمان داؤد کا وارث ہوا اور کہا اے لوگو ہمیں پرندوں کی بولی سکھائی گئی ہے او رہمیں ہر قسم کے سازو سامان دیے گئے ہیں بے شک یہ صریح فضیلت ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmclxxvi{اور سلیمان کے پاس اس کے لشکر جن اور انسان اور پرندے جمع کیے جاتے پھر انکی جماعتیں بنائی جاتیں\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmclxxvii{یہاں تک کہ جب چیونٹیوں کے میدان پر پہنچے ایک چینوٹی نے کہا اے چیونٹیو اپنے گھروں میں گھس جاؤ تمہیں سلیمان اور اس کی فوجیں نہ پیس ڈالیں اور انہیں خبر بھی نہ ہو\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmclxxviii{پھر اس کی بات سے مسکرا کر ہنس پڑا اور کہا اے میرے رب مجھے توفیق دے کہ میں تیرے احسان کا شکر کروں جو تو نے مجھ پر اور میرے ماں باپ پر کیا اور یہ کہ میں نیک کام کروں جوتو پسند کرے اور مجھے اپنی رحمت سے اپنے نیک بندوں میں شامل کر لے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmclxxix{اور پرندوں کی حاضری لی تو کہا کیا بات ہے جو میں ہُد ہُد کو نہیں دیکھتا کیا وہ غیر حاضر ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmclxxx{میں اسے سخت سزا دوں گا یا اسے ذبح کر دوں گا یا وہ میرے پاس کوئی صاف دلیل بیان کرے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmclxxxi{پھر تھوڑی دیر کے بعد ہُد ہُد حاضر ہوا اور کہا کہ میں حضور کے پاس وہ خبر لایا ہوں جو حضور کو معلوم نہیں اور سباسے آپ کے پاس ایک یقینی خبر لایا ہوں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmclxxxii{میں نے ایک عورت کو پایا جو ان پر بادشاہی کرتی ہے اور اسے ہر چیز دی گئی ہے اور اس کا بڑا تخت ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmclxxxiii{میں نے پایا کہ وہ اور اس کی قوم الله کے سوا سورج کو سجدہ کرتے ہیں اور شیطان نے ان کے اعمال کو انہیں آرستہ کر دکھایا ہے اور انہیں راستہ سے روک دیا ہے سو وہ راہ پر نہیں چلتے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmclxxxiv{الله ہی کو کیوں نہ سجدہ کریں جو آسمانوں اور زمین کی چھپی ہوئی چیزوں کو ظاہر کرتا ہے اور جو تم چھپاتے ہو اورجو ظاہر کرتے ہو سب کو جانتا ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmclxxxv{الله ہی ایسا ہےکہ اس کے سواکوئی معبود نہیں ہے اوروہ عرش عظیم کا مالک ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmclxxxvi{کہا ہم ابھی دیکھ لیتے ہیں کہ تو سچ کہتا ہے یا جھوٹوں میں سے ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmclxxxvii{میرا یہ خط لے جا اور ان کی طرف ڈال دے پھر ان کے ہاں سے واپس آ جا پھر دیکھ وہ کیا جواب دیتے ہیں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmclxxxviii{کہنے لگی اے دربار والو میرے پاس ایک معزز خط ڈالا گیا ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmclxxxix{وہ خط سلیمان کی طرف سے ہے اور وہ یہ ہے الله کے نام سے شروع کرتا ہوں جو بے حد مہربان نہایت رحم والا ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmcxc{میرے سامنے تکبر نہ کرو اور میرے پاس مطیع ہو کر چلی آؤ\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmcxci{کہنے لگی اے دربار والو مجھے میرے کام میں مشورہ دو میں کوئی بات تمہارے حاضر ہوئے بغیر طے نہیں کر تی\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmcxcii{کہنے لگے ہم بڑے طاقتور اور بڑے لڑنے والے ہیں اور کام تیرے اختیار میں ہے سو دیکھ لے جو حکم دینا ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmcxciii{کہنے لگی بادشاہ جب کسی بستی میں داخل ہوتے ہیں اسے خراب کر دیتے ہیں اور وہاں کے سرداروں کو بے عزت کرتے ہیں اور ایسا ہی کریں گے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmcxciv{اور میں ان کی طرف کچھ تحفہ بھیجتی ہوں پھر دیکھتی ہوں کہ ایلچی کیا جواب لے کر آتے ہیں\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmcxcv{پھر جب سلیمان کے پاس آیا فرمایا کیا تم میری مال سے مدد کرنا چاہتے ہو سو جو کچھ مجھے الله نے دیا ہے اس سے بہتر ہے جو تمہیں دیا ہے بلکہ تم ہی اپنے تحفہ سے خوش رہو\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmcxcvi{ان کی طرف واپس جاؤ ہم ان پرا یسے لشکر لے کر پہنچیں گے جن کا وہ مقابلہ نہ کر سکیں گے اور ہم انہیں وہاں سے ذلیل کر کے نکال دیں گے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmcxcvii{کہا اے دربار والو تم میں کوئی ہے کہ میرے پاس اس کا تخت لے آئے اس سے پہلے کہ وہ میرے پاس فرمانبردار ہو کر آئيں\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmcxcviii{جنوں میں سے ایک دیو نے کہا میں تمہیں وہ لا دیتا ہوں اس سے پہلے کہ تو اپنی جگہ سے اٹھے اور میں اس کے لیے طاقتور امانت دار ہوں\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmcxcix{اس شخص نے کہا جس کے پاس کتاب کا علم تھا میں اسے تیری آنکھ جھپکنے سے پہلے لا دیتا ہوں پھر جب اسے اپنے روبرو رکھا دیکھا تو کہنے لگا یہ میرے رب کا ایک فضل ہے تاکہ میری آزمائش کرے کیا میں شکر کرتا ہوں یا ناشکری اور جو شخص شکر کرتا ہے اپنے ہی نفع کے لیے شکر کرتا ہے اورجو ناشکری کرتا ہے تو میرا رب بھی بے پرواہ عزت والا ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmcc{کہا اس کے لیے اس کے تخت کی صورت بدل دو ہم دیکھیں کیا اسے پتہ لگتا ہے یا انہیں میں ہوتی ہے جنہیں پتہ نہیں لگتا\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmcci{پھر جب آئی کہا گیا کیا تیرا تخت ایسا ہی ہے کہنے لگی گویاکہ یہ وہی ہے اور ہمیں تو پہلے ہی معلوم ہو گیا تھا اور ہم فرمانبردار ہو چکے ہیں\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmccii{اور اسے ان چیزو ں سے روک دیا جنہیں الله کےسوا پوجتی تھی بے شک وہ کافروں میں سے تھی\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmcciii{اسے کہا گیا اس محل میں داخل ہو پھر جب اسے دیکھا خیال کیا کہ وہ گہرا پانی ہے اور اپنی پنڈلیاں کھولیں کہا یہ تو ایسا محل ہے جس میں شیشے جڑے ہوئے ہیں کہنے لگی اے میرے رب میں نے اپنے نفس پر ظلم کیا تھا اور میں سلیمان کے ساتھ الله کی فرمانبردار ہوئی جو سارے جہاں کا رب ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmcciv{اور ہم نے ثمود کی طرف ان کے بھائی صالح کو بھیجاکہ الله کی بندگی کرو پھر وہ دو فریق ہو کر آپس میں جھگڑنے لگے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmccv{کہا اے میری قوم بھلائی سے پہلے برائی کو کیوں جلدی مانگتے ہو الله سے گناہ کیوں نہیں بخشواتے تاکہ تم پر رحم کیا جائے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmccvi{کہنے لگے ہمیں تو تجھ سے اور تیرے ساتھیوں سے نحوست معلوم ہوئی کہا تہاری نحوست الله کی طرف سے ہے بلکہ تم لوگ آزمائش میں ڈالے گئے ہو\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmccvii{اور اس شہر میں نو آدمی ایسے تھے جو زمین میں فساد کرتے تھے اوراصلاح نہیں کرتے تھے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmccviii{کہنے لگے آپس میں الله کی قسم کھاؤ کہ صالح اور اس کے گھر والوں پر شبخوں ماریں پھر اس کے وارث سے کہہ دیں ہم تو اس کے کنبہ کی ہلاکت کے وقت موجود ہی نہ تھے اور بے شک ہم سچے ہیں\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmccix{اور انہوں نے ایک داؤ کیا اور ہم نے بھی ایساداؤ کیا کہ انہیں خبربھی نہ ہوئی\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmccx{پھر دیکھو ان کے داؤ کا کیا انجام ہوا کہ ہم نے انہیں اوران کی ساری قوم کو ہلاک کر دیا\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmccxi{سو یہ ان کے گھر ہیں جو ان کے ظلم کے سبب سے ویران پڑے ہیں بے شک اس میں دانشمندو ں کے لیے عبرت ہے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmccxii{اور ہم نے ایمان اور تقویٰ والوں کو نجات دی\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmccxiii{اورلوط کو جب اس نے اپنی قوم کو کہا کیا تم بے حیائی کرتے ہو حالانکہ تم سمجھ دا ر ہو\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmccxiv{کیا تم عورتوں کو چھوڑ کر مردوں پر خواہش کر کے آتے ہو بلکہ تم لوگ جاہل ہو\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmccxv{پھر اس کی قوم کا اور کوئی جواب نہ تھا سوائے ا س کے کہ یہ کہا لوط کے گھر والوں کو اپنی بستی سے نکال دو یہ لوگ بڑے پاک بنتے ہیں\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmccxvi{پھر ہم نے لوط اور اس کے گھر والوں کو سوائے اس کی بیوی کے بچا لیا ہم اس کو پیچھے رہنے والو ں میں ٹھہرا چکے تھے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmccxvii{اورہم نے ان پر مینہ برسایا پھر ڈرائے ہوؤں کا مینہ برا تھا\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmccxviii{کہہ دے سب تعریف الله کے لیے ہے اور اس کے برگزیدہ بندوں پر سلام ہے بھلا الله بہتر ہے یا جنہیں وہ شریک بناتے ہیں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmccxix{بھلا کس نے آسمان اور زمین بنائے اور تمہارے لیے آسمان سے پانی اتار پھر ہم نے اس سے رونق والے باغ اگائے تمہارا کام نہ تھا کہ ان کے درخت اگاتے کیا الله تعالیٰ کے ساتھ کوئی اوربھی معبود ہے بلکہ یہ لوگ کجروی کر رہے ہیں\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmccxx{بھلا زمین کو ٹھہرنے کی جگہ کس نے بنایا اور اس میں ندیاں جاری کیں اور زمین کے لنگر بنائے اور دو دریاؤں میں پردہ رکھا کیا الله کے ساتھ کوئی اوربھی معبود ہے بلکہ اکثر ان میں بے سمجھ ہیں\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmccxxi{بھلا کون ہے جوبے قرار کی دعا قبول کرتا ہے اوربرائی کو دور کرتا ہے اور تمہیں زمین میں نائب بناتا ہے کیا الله کے ساتھ کوئی اور معبود بھی ہے تم بہت ہی کم سمجھتے ہو\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmccxxii{بھلا کون ہے جو تمہیں جنگل اور دریا کے اندھیروں میں راستہ بتاتاہے اور اپنی رحمت سے پہلے کون خوشخبری کی ہوائیں چلاتا ہے کیا الله کے ساتھ کوئی اور معبود ہے الله ان کے شرک کرنے سے بہت بلند ہے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmccxxiii{بھلا کون ہے جو از سرِ نو خلقت کو پیدا کرتا ہے پھر اسے دوبارہ بنائے گا اور کون ہے وہ جو تمہیں آسمان اور زمین سے روزی دیتا ہے کیا الله کے ساتھ کوئی اور بھی معبود ہے کہہ دے اپنی دلیل لاؤ اگر تم سچےہو\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmccxxiv{کہہ دے الله کے سوا آسمانوں اور زمین میں کوئی بھی غیب کی بات نہیں جانتا اور انہیں اس کی بھی خبر نہیں کہ کب اٹھائے جائیں گے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmccxxv{بلکہ آخرت کے معاملے میں تو ان کی سمجھ گئی گزری ہے بلکہ وہ اس سے شک میں ہیں بلکہ وہ اس سے اندھے ہی ہیں\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmccxxvi{اور کافر کہتے ہیں کہ کیا جب ہم اور ہمارے باپ دادا مٹی ہوگئے کیا ہم زمین سے نکالے جائیں گے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmccxxvii{اس کا تو ہم سے اور ہمارےپہلے باپ دادا سے وعدہ ہوتا آیا ہے یہ تو صرف پہلوں کی کہانیاں ہیں\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmccxxviii{کہہ دے تم زمین میں چل پھر کر دیکھو کہ گناہگاروں کا کیا انجام ہوا\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmccxxix{اور ان پر غم نہ کر اور ان کے فریب کرنے سے تنگ دل نہ ہو\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmccxxx{اور کہتے ہیں یہ وعدہ کب ہوگا اگر تم سچے ہو\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmccxxxi{کہہ دے شاید بعض وہ چیزیں جن کی تم جلدی کرتے ہو تمہاری پیٹھ کے پیچھے آلگی ہوں\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmccxxxii{اور بے شک تیرا رب تو لوگوں پر فضل کرتا ہے لیکن ان میں سے اکثر شکر نہیں کرتے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmccxxxiii{اور بے شک تیرا رب جانتا ہے جو ان کے دلوں میں پوشیدہ ہے اور جو وہ ظاہر کرتے ہیں\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmccxxxiv{اور آسمان اور زمین میں ایسی کوئی پوشیدہ بات نہیں جو روشن کتاب میں نہ ہو\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmccxxxv{بے شک یہ قرآن بنی اسرائیل پر اکثر ان باتوں کو ظاہر کرتا ہے جن میں وہ اختلاف کرتے ہیں\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmccxxxvi{اور بے شک وہ ایمانداروں کے لیے ہدایت اور رحمت ہے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmccxxxvii{بے شک تیرا رب ان کے درمیان اپنے حکم سے فیصلہ کرے گا اور وہ غالب علم والا ہے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmccxxxviii{سو الله پر بھروسہ کر بے شک تو صریح حق پر ہے\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmmccxxxix{البتہ تو مردوں کو نہیں سنا سکتا اور نہ بہروں کو اپنی پکارسنا سکتا ہے جب وہ پیٹھ پھیر کر لوٹیں\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmmccxl{اور نہ تو اندھوں کو ان کی گمراہی دور کر کے ہدایت کر سکتا ہے تو ان ہی کو سنا سکتا ہے جو ہماری آیتوں پر ایمان لائیں سو وہی مان بھی لیتے ہیں\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmmccxli{اور جب ان پر وعدہ پورا ہوگا تو ہم ان کے لیے زمین سے ایک جانور نکالیں گے جو ان سے باتیں کرے گا کہ لوگ ہماری آیتوں پر یقین نہیں لاتے تھے\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmmccxlii{اورجس دن ہم ہر امت میں سے ایک گروہ ان لوگوں کا جمع کریں گے جو ہماری آیتوں کو جھٹلاتے تھے پھر ان کی جماعت بندی ہو گی\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmmccxliii{یہاں تک کہ جب سب حاضر ہوں گے کہے گا کیا تم نے میری آیتوں کو جھٹلایا تھا حالانکہ تم انہیں سمجھے بھی نہ تھے یا کیا کرتے رہے ہو\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmmccxliv{اور ان کے ظلم سے ان پر الزام قائم ہو جائے گا پھر وہ بول بھی نہ سکیں گے\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmmccxlv{کیا نہیں دیکھتے کہ ہم نے رات بنائی تاکہ اس میں چین حاصل کریں اور دیکھنے کو دن بنایا البتہ اس میں ان لوگوں کے لیے نشانیاں ہیں جو ایمان لاتے ہیں\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmmccxlvi{اور جس دن صور پھونکا جائے گا تو جوکوئی آسمان میں ہے اور جو کوئی زمین میں ہے سب ہی گھبرائیں گے مگر جسے الله چاہے اور سب اس کے پاس عاجز ہو کر چلے آئیں گے\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmmccxlvii{اور تو جو پہاڑوں کو جمے ہوئے دیکھ رہا ہے یہ تو بادلوں کی طرح اڑتے پھریں گے اس الله کی کاریگری سے جس نے ہر چیز کو مضبوط بنا رکھا ہے اسے خبر ہے جو تم کرتے ہو\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmmccxlviii{جو نیکی لائے گا سواسے اس سے بہتر بدلہ ملے گا اور وہ اس دن کی گھبراہٹ سے بھی امن میں ہوں گے\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmmccxlix{اور جو برائی لائے گا سو ان کے منہ آگ میں اوندھے ڈالے جائیں گے تمہیں وہی بدلہ مل رہا ہے جو تم کرتے تھے\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmmccl{مجھے تو یہی حکم دیا گیا ہے کہ اس شہر کے مالک کی بندگی کروں جس نے اسے عزت دی ہے اور ہر ایک چیز اسی کی ہے اور مجھے حکم دیا گیا ہے کہ میں فرمانبرداروں میں رہوں\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmmccli{اور یہ بھی کہ قرآن سنا دوں پھر جو کوئی راہ پر آ گیا تو وہ اپنے بھلے کو راہ پر آتا ہے اور جو گمراہ ہوا تو کہہ دو میں تو صرف ڈرانے والوں میں سے ہوں\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmmcclii{اور کہہ دو سب تعریف الله کے لیے ہےتمہیں عنقریب اپنی نشانیاں دکھا دے گا پھرانہیں پہچان لو گے اور تیرا رب اس سے بے خبر نہیں جو تم کرتے ہو\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmmccliii{\basmalahur طسمۤ\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmccliv{یہ روشن کتاب کی آیتیں ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmcclv{ہم تجھے ایمان داروں کے فائدے کے لیے موسیٰ اور فرعون کا کچھ صحیح حال سناتے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmcclvi{بے شک فرعون زمین پر سرکش ہو گیا تھا اور وہاں کے لوگوں کے کئی گروہ کر دیئے تھے ان میں سے ایک گروہ کو کمزور کر رکھا تھا ان کے لڑکوں کو قتل کرتا تھا اور ان کی لڑکیوں کو زندہ رکھتا تھا بے شک وہ مفسدوں میں سے تھا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmcclvii{اور ہم چاہتے تھے کہ ان پر احسان کریں جو ملک میں کمزور کیے گئے تھے اورانہیں سردار بنا دیں اور انہیں وارث کریں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmcclviii{اور انہیں ملک پر قابض کریں اور فرعون ہامان اور ان کے لشکروں کو وہ چیز دکھا دیں جس کا وہ خطر کرتے تھے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmcclix{اور ہم نے موسیٰ کی ماں کو حکم بھیجا کہ اسے دودھ پلا پھر جب تجھے اس کا خوف ہو تو اسے دریا میں ڈال دے اور کچھ خوف اور غم نہ کر بے شک ہم اسے تیرے پاس واپس پہنچا دیں گے اور اسے رسولوں میں سے بنانے والے ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmcclx{پھر اسے فرعون کے گھر والو ں نے اٹھا لیا تاکہ بالآخر وہ ان کا دشمن اور غم کا باعث بنے بے شک فرعون اور ہامان اور ان کے لشکر خطا کار تھے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmcclxi{اور فرعون کی عورت نے کہا یہ تو میرے اور تیرے لیے آنکھوں کی ٹھنڈک ہے اسے قتل نہ کرو شاید ہمارے کام آئے یا ہم اسے بیٹا بنالیں اور انہیں کچھ خبر نہ تھی\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmcclxii{اور صبح کو موسی ٰکی ماں کا دل بے قرار ہو گیا قریب تھی کہ بے قراری ظاہر کر دے اگر ہم اس کے دل کو صبر نہ دیتے تاکہ اسے ہمارے وعدے کا یقین رہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmcclxiii{اور اس کی بہن سے کہا اس کے پیچھے چلی جا پھر اسے اجنبی ہو کر دیکھتی رہی اور انہیں خبر نہ ہوئی\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmcclxiv{اور ہم نے پہلے سے اس پر دائیوں کا دودھ حرام کر دیا تھا پھر بولی میں تمہیں ایسے گھر والے بتاؤں جو اس کی تمہارے لیے پرورش کریں اور وہ اس کے خیر خواہ ہوں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmcclxv{پھر ہم نے اسے اس کی ماں کے پا س پہنچا دیا تاکہ ا س کی آنکھیں ٹھنڈی رہیں اور غمگین نہ ہو اور جان لے کہ الله کا وعدہ سچا ہے لیکن اکثر آدمی نہیں جانتے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmcclxvi{اور جب اپنی جوانی کو پہنچا اور پورا توانا ہوا تو ہم نے اسے حکمت اور علم دیا اور ہم نیکوں کو اسی طرح بدلہ دیا کرتے ہیں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmcclxvii{اور شہر میں لوگوں کی بے خبری کے وقت داخل ہوا پھر وہاں دو شخصوں کو لڑتے ہوئے پایا یہ ایک اس کی جماعت کا تھااوریہ دوسرا اس کے دشمنوں میں سے تھا پھر اس نے جو اس کی جماعت کا تھا اپنے دشمن پر اس سے مدد چاہی تب موسیٰ نے اس پر مکا مارا پس اس کا کام تمام کر دیا کہا یہ تو شیطانی حرکت ہے بے شک وہ کھلا دشمن اور گمراہ کرنے والا ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmcclxviii{کہا اے میرے رب! بے شک میں نے اپنی جان پر ظلم کیا سو مجھے بخش دے پھر اسے بخش دیا بے شک وہ بخشنے والا مہربان ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmcclxix{کہا اے میرے رب! جیسا تو نے مجھ پر فضل کیا ہے پھر میں گناہگاروں کا کبھی مددگار نہیں ہوں گا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmcclxx{پھر شہر میں ڈرتا انتظار کرتا ہوا صبح کو گیا پھر وہی شخص جس نے کل اس سے مدد مانگی تھی اسے پکار رہا ہے موسیٰ نے اس سے کہا کہ بے شک تو صریح گمراہ ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxi{پھر جب ارادہ کیا کہ اس پر ہاتھ ڈالے جو ان دونوں کا دشمن تھا کہا اے موسیٰ! کیا تو چاہتا ہے کہ مجھے مار ڈالے جیسا تو نے کل ایک آدمی کو مار ڈالا ہے تو یہی چاہتا ہے کہ ملک میں زبردستی کرتا پھرے اور تو نہیں چاہتا کہ اصلاح کرنے والوں میں سے ہو\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxii{اور شہر کے پرلے سرے سے ایک آدمی دوڑتا ہوا آیا کہا اے موسیٰ! دریا والے ترے متعلق مشورہ کرتے ہیں کہ تجھ کو مار ڈالیں سو نکل بے شک میں تیرا بھلا چاہنے والا ہوں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxiii{پھر وہاں سے ڈرتا انتظار کرتا ہوا نکلا کہا اے میرے رب! مجھے ظالم قوم سے بچا لے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxiv{اور جب مدین کی طرف رخ کیا تو کہا امید ہے کہ میرا رب مجھے سیدھا راستہ بتا دے گا\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxv{اور جب مدین کے پانی پر پہنچا وہاں لوگوں کی ایک جماعت کو پانی پلاتے ہوئے پایا اور ان سے ورے دو عورتوں کو پایا جو اپنے جانور روکے ہوئے کھڑی تھیں کہا تمہارا کیا حال ہے بولیں جب تک چرواہے نہیں ہٹ جاتے ہم نہیں پلاتیں اور ہمارا باپ بوڑھابڑی عمر کا ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxvi{پھر ان کے جانوروں کو پانی پلا دیا پھر سایہ کی طرف ہٹ کر آیا کہ اے میرے رب تو میری طرف جو اچھی چیز اتارے میں اس کا محتاج ہوں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxvii{پھر ان دونوں میں سے ایک اس کے پاس شرم سے چلتی ہوئی آئی کہا میرے باپ نے تمہیں بلایا ہے کہ تمہیں پلائی کی اجرت دے پھر جب اس کے پاس پہنچا اور اس کے تمام حال بیان کیا کہا خوف نہ کر تواس بے انصاف قوم سے بچ آیا ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxviii{ان دونوں میں سے ایک بولی اے باپ! اسے نوکر رکھ لے بے شک بہتر نوکر جسے تو رکھنا چاہے وہ ہے جو زور آوار امانت دار ہو\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxix{کہا میں چاہتاہوں کہ اپنی ان دونوں بیٹیوں میں سے ایک کا تجھ سے نکاح کر دوں اس شرط پر کہ تو آٹھ برس تک میری نوکری کرے پھر اگر تو دس پورے کر دے تو تیری طرف سے احسان ہے او رمیں نہیں چاہتا کہ تجھے تکلیف میں ڈالوں اگر الله نے چاہا تو مجھے نیک بختوں سے پائے گا\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxx{کہا میرے او رتیرے درمیان یہ وعدہ ہو چکا ان دونو ں مدتوں میں سے جونسی پوری کر دوں تو مجھ پر زیادتی نہ ہو اور الله ہمارے قول پر گواہ ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxi{پھر جب موسیٰ وہ مدت پوری کر چکا اور اپنے گھر والوں کو لے کر چلا کوہِ طور کی طرف سے ایک آگ دیکھی اپنے گھر والوں سے کہا ٹھیرو میں نے ایک آگ دیکھی ہے شاید تمہارے پاس وہا ں کی کچھ خبر یا آگ کا انگارہ لے آؤں تاکہ تم سینکو\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxii{پھر جب اس کے پاس پہنچا تو میدان کے داہنے کنارے سے برکت والی جگہ میں ایک درخت سے آواز آئی کہ اے موسیٰ! میں الله جہان کا رب ہوں\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxiii{اور یہ کہ اپنی لاٹھی ڈال دے پھر جب اسے دیکھا کہ سانپ کی طرح لہرا رہا ہے تو منہ پھیر کر الٹا بھاگا اور پیچھے مڑ کر نہ دیکھا اے موسیٰ! سامنے آ اور ڈر نہیں بے شک تو امن والوں سے ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxiv{اپنے گریبان میں اپنا ہاتھ ڈال وہ بغیر کسی عیب کے چمکتا ہوا نکلے گا اور رفع خوف کے لیے اپنا بازو اپنی طرف ملا سو تیرے رب کی طرف سے فرعون اور اس کے سرداروں کے لیے یہ دو سندیں ہیں بے شک وہ نافرمان لوگ ہیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxv{کہا اے میرے رب! میں نے ان کے ایک آدمی کو قتل کیا ہے پس میں ڈرتا ہوں کہ مجھے مارڈ الیں گے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxvi{اور میرے بھائی ہارون کی زبان مجھ سے زياہ روان ہے اسے میرے ساتھ مددگار بنا کر بھیج کہ میری تصدیق کرےکیونکہ میں ڈرتا ہوں کہ وہ مجھے جھٹلائیں گے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxvii{فرمایا ہم تیرے بازو کو تیرے بھائی سے مضبوط کر دیں گے اور تمہیں غلبہ دیں گے پھر وہ تم تک پہنچ نہیں سکیں گے ہماری نشانیوں کے سبب سےتم اورتمہارے تابعدار غالب رہیں گے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxviii{پھر جب موسیٰ ان کے پاس ہماری کھلی نشانیاں لے کر آیا تو کہنے لگے کہ یہ تو محض ایک بنایا ہوا جادو ہے اور ہم نے اسے اپنے پہلے باپ دادا سے سنا ہی نہیں ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxix{اور موسیٰ نے کہا میرا رب خوب جانتاہے جو اس کی طرف سے ہدایت لے کر آیا ہے اور جس کے لیے آخرت کا گھر ہے بے شک ظالم نجات نہیں پائیں گے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmccxc{اور فرعون نے کہا اے سردارو! میں نہیں جانتا کہ میرے سوا تمہارا او رکوئی معبود ہے پس اے ہامان! تو میرے لیے گارا پکوا پھر میرے لیے ایک بلند محل بنوا کہ میں موسیٰ کے خدا کو جھانکوں اور بے شک میں اسے جھوٹا سمجھتا ہوں\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmccxci{اور اس نے اور اس کے لشکروں نے زمین پر ناحق تکبر کیا اور خیال کیا کہ وہ ہماری طرف لوٹ کر نہیں آئيں گے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmccxcii{پھر ہم نے اسے اور اس کے لشکروں کو پکڑ لیا پھر انہیں دریا میں پھینک دیا سو دیکھ لو ظالموں کا کیا انجام ہوا\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmccxciii{اور ہم نے انہیں پیشوا بنایا وہ دوزخ کی طرف بلاتے تھے اور قیامت کے دن انہیں مدد نہیں ملے گی\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmccxciv{اور ہم نے اس دنیا میں ان کے پیچھے لعنت لگا دی اور وہ قیامت کے دن بھی بدحالوں میں ہوں گے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmccxcv{اور ہم نے موسیٰ کو پہلی امتوں کے ہلاک کرنے کے بعد کتاب دی تھی جو لوگوں کے لیے بینائی اور ہدایت اور رحمت تھی تاکہ وہ سمجھیں\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmccxcvi{اور تم غربی جانب نہیں تھے جب ہم نے موسیٰ کی طرف حکم بھیجا اور نہ اس واقعہ کو دیکھنے والے تھے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmccxcvii{لیکن ہم نے بہت سی نسلیں پیدا کیں پھران پر مدت دراز گزاری اورتو مدین والوں میں نہیں رہتا تھا کہ انہیں ہماری آیتیں سناتا لیکن ہم رسول بھیجتے رہے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmccxcviii{اور تو طور کے کنارے پر نہ تھا جب ہم نے آواز دی لیکن تیرے رب کا یہ انعام ہے تاکہ ان لوگو ں کو ڈرائے جن کے پاس تجھ سے پہلے کوئی ڈرانے والا نہیں آیا تاکہ وہ نصیحت حاصل کریں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmccxcix{اور اگر یہ بات نہ ہوتی کہ ان کے اپنے ہی اعمال کے سبب سے ان پر مصیبت نازل ہوجائے پھر کہتے اے ہمارے رب! تو نے ہمارے پاس رسول کیوں نہ بھیجا تاکہ ہم تیرے حکموں کی تابعداری کرتے اور ایمان والو ں میں ہوتے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmccc{پھر جب ان کے پاس ہماری طرف سے حق آ پہنچا تو کہنے لگے کیوں نہیں دیا گیا جیسا موسی کو دیا گیا تھا کیا انہوں نے اس چیز کا انکار نہیں کیا تھا جو موسیٰ کو اس سے پہلے دی گئی تھی کہنے لگے دونوں جادو گر آپس میں موافق ہیں اور کہا ہم کسی کو بھی نہیں مانتے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmccci{کہہ دو پس الله کے ہاں سے کوئی ایسی کتاب لاؤ جو ان دونوں سے ہدایت میں بڑھ کر ہو کہ میں اس پر چلوں اگر تم سچے ہو\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmcccii{پھر اگر تمہارا کہنا نہ مانیں تو جان لو کہ وہ صرف اپنی خواہشوں کے تابع ہیں اور اس سے بڑھ کر کون گمراہ ہوگا جو الله کی ہدایت چھوڑ کر اپنی خواہشوں پر چلتا ہو بے شک الله ظالم قوم کو ہدایت نہیں کرتا\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmccciii{اور البتہ ہم ان کے پاس ہدایت بھیجتے رہے تاکہ وہ نصیحت حاصل کریں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmccciv{جن لوگوں کو ہم نے اس سے پہلے کتاب دی ہے وہ اس پر ایمان لاتے ہیں\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmcccv{اور جب ان پر پڑھا جاتا ہے کہتے ہیں ہم اس پر ایمان لائے ہمارے رب کی طرف سے یہ حق ہے ہم تو اسے پہلے ہی مانتے تھے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmcccvi{یہ وہ لوگ ہیں جنہیں ان کے صبر کی وجہ سے دگنا بدلہ ملے گا اوربھلائی سے برائی کو دور کرتے ہیں اور جو ہم نےانہیں دیا ہے اس میں سےخرچ کرتے ہیں\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmcccvii{اورجب بے ہودہ بات سنتے ہیں تو اس سے منہ پھیر لیتے ہیں اور کہتے ہیں ہمارے لے ہمارے اعمال تمہارے لیے تمہارے اعمال تم پر سلام ہو ہم بے سمجھوں کو نہیں چاہتے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmcccviii{بے شک تو ہدایت نہیں کر سکتا جسے تو چاہے لیکن الله ہدایت کرتا ہے جسے چاہے اور وہ ہدایت والوں کو خوب جانتا ہے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmcccix{اور کہتے ہیں اگر ہم تیرے ساتھ ہدایت پر چلیں تو اپنے ملک سے اچک لیے جائیں کیا ہم نے انہیں حرم میں جگہ نہیں دی جوامن کا مقام ہے جہاں ہر قسم کے میووں کا رزق ہماری طرف سے پہنچایا جاتا ہے لیکن اکثر ان میں سے نہیں جانتے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmcccx{اور ہم نے بہت سی بستیوں کو ہلاک کر ڈالا جو اپنے سامان عیش پر نازاں تھے سو یہ ان کے گھر ہیں کہ ان کے بعد آباد نہیں ہوئے مگر بہت کم اورہم ہی وارث ہوئے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmcccxi{اور تیرا رب بستیوں کو ہلاک نہیں کیا کرتا جب تک ان کے بڑے شہر میں پیغمبر نہ بھیج لے جو انہیں ہماری آیتیں پڑھ کر سنائے اور ہم بستیوں کو ہلاک نہیں کیا کرتے مگر اس حالت میں کہ وہاں کے باشندے ظالم ہوں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmcccxii{اور جو چیز تمہیں دی گئی ہے وہ دنیا کی زندگی کا فائدہ اور اس کی زینت ہے جو چیز الله کے ہاں ہے وہ بہتر اورباقی رہنے والی ہے کیا تم نہیں سمجھتے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmcccxiii{پھر کیا وہ شخص جس سے ہم نے اچھا وعدہ کیا ہو سو وہ اسے پانے والا بھی ہو اس کے برابر ہے جسے ہم نے دنیا کی زندگی کا فائدہ دیا پھر وہ قیامت کے دن پکڑا ہوا آئے گا\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmcccxiv{اور جس دن انہیں پکارے گا پھرکہے گا میرے شریک کہاں ہیں جن کا تم دعوی کرتے تھے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmcccxv{جن پر الزام قائم ہو گا وہ کہیں گے اے رب ہمارے! وہ یہی ہیں جنہیں ہم نے بہکایا تھا انہیں ہم نے گمرا کیا تھا جیسا کہ ہم گمراہ تھے ہم تیرے رو برو بیزار ہوتے ہیں یہ ہمیں نہیں پوجتے تھے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmcccxvi{اور کہا جائے گا اپنے شریکو ں کو پکارو پھرانہیں پکاریں گے تو وہ انہیں جواب نہ دیں گے اور عذاب دیکھیں گے کاش یہ لوگ ہدایت پر ہوتے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmcccxvii{اورجس دن انہیں پکارے گا پھر کہے گا تم نے پیغام پہچانے والوں کو کیا جواب دیا تھا\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmcccxviii{پھر اس دن انہیں کوئی بات نہیں سوجھے گی پھر وہ آپس میں بھی نہیں پوچھ سکیں گے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmcccxix{پھر جس نے توبہ کی اور ایمان لایا اور نیک عمل کیے سو امید ہے کہ وہ نجات پانے والوں میں سے ہوگا\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmcccxx{اور تیرا رب جو چاہے پیدا کرتا ہے اور جسے چاہے پسند کرے انہیں کوئی اختیار نہیں ہے الله ان کے شرک سے پاک اور برتر ہے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxi{اورتیرا رب جانتا ہے جو ان کے سینوں میں پوشیدہ ہے اور جو ظاہر کرتے ہیں\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxii{اور وہی الله ہے اس کے سوا کوئی معبود نہیں دنیا اور آخرت میں اسی کی تعریف ہے اور اسی کی حکومت ہے اورتم اسی کی طرف لوٹائے جاؤ گے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxiii{کہہ دو بھلا یہ تو بتاؤ اگر الله تم پر ہمیشہ کے لیے قیامت تک رات ہی رہنے دے تو الله کے سوا کون سا معبود ہے جو تمہارے لیے روشنی لائے کیا تم سنتے نہیں ہو\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxiv{کہہ دو بھلا یہ تو بتاؤ اگر الله تم پر ہمیشہ کے لیے قیامت تک دن ہی رہنے دے تو الله کے سوا کون سا معبود ہے جو تمہارے لیے رات لائے جس میں آرام پاؤ کیا تم دیکھتے نہیں ہو\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxv{اوراس نے اپنی رحمت سے تمہارے لیے رات اور دن کو بنایا تاکہ تم اس میں آرام پاؤ اور اپنے رب کا فضل تلاش کرو اور تاکہ تم شکر کرو\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxvi{اور جس دن انہیں پکارے گا پھر کہے گا وہ کہاں ہیں جنہیں تم میرا شریک سمجھتے تھے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxvii{اور ہم ہر امت میں سے ایک گواہ نکال کر لائیں گے پھر کہیں گے کہ اپنی دلیل پیش کرو تب جان لیں گے کہ سچی بات الله ہی کی تھی اور جو جھوٹ بنایا کرتے تھے ان سے جاتا رہے گا\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxviii{بے شک قارون موسیٰ کی قوم میں سے تھا پھر ان پر اکڑنے لگا اور ہم نے اسے اتنے خزانے دیے تھے کہ اسکی کنجیاں ایک طاقت ور جماعت کو اٹھانی مشکل ہوتیں جب اس سے اس کی قوم نے کہا اِترا مت بے شک الله اِترانے والوں کو پسند نہیں کرتا\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxix{اور جو کچھ تجھے الله نے دیا ہے اس سے آخرت کا گھر حاصل کر اور اپنا حصہ دنیا میں سے نہ بھول اور بھلائی کر جس طرح الله نے تیرے ساتھ بھلائی کی ہے اور ملک میں فساد کا خواہاں نہ ہو بے شک الله فساد کرنے والوں کو پسندنہیں کرتا\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxx{کہا یہ تو مجھے ایک ہنر سے ملا ہے جو میرے پاس ہے کیا اسے معلوم نہیں کہ الله نے اس سے پہلے بہت سی امتیں جو اس سے قوت میں بڑھ کر اور جمیعت میں زیادہ تھیں ہلاک کر ڈالی ہیں اور گناہگاروں سے ان کے گناہوں کے بارے میں پوچھا نہیں جائے گا\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxi{اپنی قوم کے سامنے اپنے ٹھاٹھ سے نکلا جو لوگ دنیا کی زندگی کے طالب تھے کہنے لگے اے کاش ہمارے لیے بھی ویسا ہوتا جیسا کہ قارون کو دیا گیا ہے بے شک وہ بڑے نصیب والا ہے\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxii{اور علم والوں نے کہا تم پر افسوس ہے الله کا ثواب بہتر ہے اس کے لیے جو ایمان لایا اور نیک کام کیا مگر صبر کرنے والوں سوا نہیں ملا کرتا\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxiii{پھر ہم نے اسے اور اس کے گھر کو زمین میں دھنسا دیا پھر اس کی ایسی کوئی جماعت نہ تھی جو اسے الله سے بچا لیتی اور نہ وہ خود بچ سکا\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxiv{اور وہ لوگ جو کل اس کے مرتبہ کی تمنا کرتے تھے آج صبح کو کہنے لگے کہ ہائے شامت! الله اپنے بندوں میں سے جس کے لیے چاہتا ہے روزی کشادہ کر دیتا ہے اور تنگ کر دیتا ہے اگر ہم پر الله کا احسان نہ ہوتا تو ہمیں بھی دھنسا دیتا ہائے! کافر نجات نہیں پا سکتے\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxv{یہ آخرت کا گھر ہم انہیں کو دیتے ہیں جو ملک میں ظلم اور فساد کا ارادہ نہیں رکھتے اور نیک انجام تو پرہیز گاروں ہی کا ہے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxvi{جو بھلائی لے کر آیا اسے اس سے بہتر ملے گا اور جو برائی لے کر آیا پس برائیاں کرنے والوں کو وہی سزا ملے گی جو کچھ وہ کرتے تھے\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxvii{جس نے تم پر قرآن فرض کیا وہ تمہیں لوٹنے کی جگہ پھیر لائے گا کہہ دو میرا رب خوب جانتا ہے کہ ہدایت کون لے کر آیا ہے اور کون صریح گمراہی میں پڑا ہواہے\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxviii{اور تمہیں امید نہ تھی کہ تم پر کتاب اتاری جائے گی مگر تمہارے رب کی مہربانی ہوئی پھر تم کافروں کی طرفداری نہ کرنا\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxix{اور وہ تمہیں الله کی آیتوں سے بعد اس کے کہ تم پر نازل ہو چکی ہیں روک نہ دیں اوراپنے رب کی طرف بلا اور مشرکوں میں ہر گز شامل نہ ہو\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmmcccxl{اور الله کے ساتھ اور کسی معبود کو نہ پکار اس کے سوا اور کوئی معبود نہیں اس کی ذات کے سوا ہر چیز فنا ہونے والی ہے اسی کا حکم ہے اور اسی کی طرف تم لوٹ کر جاؤ گے\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmmcccxli{\basmalahur المۤ\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmcccxlii{کیا لوگ خیال کرتے ہیں یہ کہنے سےکہ ہم ایمان لائے ہیں چھوڑ دیئے جائیں گے اور ان کی آزمائش نہیں کی جائے گی\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmcccxliii{اور جو لوگ ان سے پہلے گزر چکے ہیں ہم نے انہیں بھی آزمایا تھا سو الله انہیں ضرور معلوم کرے گا جو سچے ہیں اور ان کو بھی جو جھوٹے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmcccxliv{کیا وہ لوگ جو برے کام کرتے ہیں یہ سمجھتے ہیں کہ ہمارے قابو سے نکل جائیں گے برا ہے جو فیصلہ کرتے ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmcccxlv{جو شخص الله سے ملنے کی امید رکھتا ہو سو الله کا وعدہ آ رہا ہے اور وہ سننے والا جاننے والا ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmcccxlvi{اور جو شخص کوشش کرتا ہے تو اپنے ہی بھلے کے لیے کرتا ہے بے شک الله سارے جہان سے بے نیاز ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmcccxlvii{اور جو لوگ ایمان لائے اور نیک کام کیے ہم ان کے گناہوں کو ان سے دور کردیں گےاور انہیں ان کے اعمال کا بہت اچھا بدلہ دیں گے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmcccxlviii{اور ہم نے انسان کو اپنے ماں باپ کے ساتھ اچھا سلوک کرنے کا حکم دیا ہے اور اگر وہ تجھے اس بات پر مجبور کریں کہ تو میرے ساتھ اسے شریک بنائے جسے تو جانتا بھی نہیں تو ان کا کہنا نہ مان تم سب نے لوٹ کرمیرے ہاں ہی آنا ہے تب میں تمہیں بتا دوں گا جو کچھ تم کرتے تھے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmcccxlix{اور جو لوگ ایمان لائے اور اچھے کام کیے ہم انہیں ضرور نیک بندوں میں داخل کر یں گے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmcccl{اورکچھ ایسے لوگ بھی ہیں جو کہتے ہیں ہم الله پر ایمان لائے پھر جب انہیں الله کی راہ میں کوئی تکلیف پہنچتی ہے لوگوں کی تکلیف کو الله کے عذاب کے برابر سمجھتے ہیں اور اگر تیرے رب کی طرف سے مدد پہنچے تو کہتے ہیں ہم تو تمہارے ساتھ تھے اور کیا الله جہان والوں کے دلوں کی باتوں سے اچھی طرح واقف نہیں ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmcccli{اور البتہ الله انہیں ضرور معلوم کرے گا جو ایمان لائے اور البتہ منافقوں کو بھی معلوم کرکے رہے گا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmccclii{اور کافر ایمان والوں سے کہتے ہیں کہ تم ہمارے طریقہ پر چلو اور ہم تمہارے گناہ اٹھا لیں گے حالانکہ وہ ان کے گناہوں میں سے کچھ بھی اٹھانے والے نہیں بے شک وہ جھوٹے ہیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmcccliii{اور البتہ اپنے بوجھ اٹھائیں گے اور اپنےبوجھ کے ساتھ اور کتنے بوجھ اور البتہ قیامت کےد ن ان سے ضرور پوچھا جائے گا ان باتو ں کے متعلق جو وہ بناتے تھے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmcccliv{اور ہم نے نوح کو اس کی قوم کی طرف بھیجا پھر وہ ان میں پچاس برس کم ہزار برس رہے پھر انہیں طوفان نے آ پکڑا اور وہ ظالم تھے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmccclv{پھر ہم نے نوح کو اور کشتی والوں کو نجات دی اور ہم نے کشتی کو جہان والوں کے لیے نشانی بنا دیا\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmccclvi{اور ابراھیم کو جب اس نے اپنی قوم سے کہا کہ الله کی عبادت کرو اور اس سے ڈرو اگر تم سمجھ رکھتے ہو تو تمہارے لیے یہی بہتر ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmccclvii{تم الله کے سوا بتوں ہی کی عبادت کرتے ہو اور جھوٹ بناتے ہو جنہیں تم الله کے سوا پوجتے ہو وہ تمہاری روزی کے مالک نہیں سو تم الله ہی سے روزی مانگو اور اسی کی عبادت کرو اوراسی کا شکر کرو اسی کے پاس لوٹائے جاؤ گے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmccclviii{اور اگر تم جھٹلاؤ تو تم سے پہلے بہت سی جماعتیں جھٹلا چکی ہیں اور رسول کے ذمہ تو بس کھول کر پہنچا دینا ہی ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmccclix{کیا انہوں نے نہیں دیکھا کہ الله کس طرح پہلی دفعہ مخلوق کوپیدا کرتا ہے پھر اسے لوٹائے گا بے شک یہ الله پر آسان ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmccclx{کہہ دو ملک میں چلو پھرو پھر دیکھو کہ اس نے کس طرح مخلوق کو پہلی دفعہ پیدا کیا پھر الله آخری دفعہ بھی پیدا کرے گا بےشک الله ہر چیز پر قادر ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmccclxi{جسے چاہے گا عذاب دے گا اور جس پر چاہے رحم کرے گا اور اسی کی طرف لوٹائے جاؤ گے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmccclxii{اور تم زمین اور آسمان میں عاجز نہیں کر سکتے اور الله کےسوا تمہارا کوئی دوست اور مددگار نہیں ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmccclxiii{اور جن لوگو ں نے الله کی آیتوں اور اس کے ملنے سے انکار کیا وہ میری رحمت سے نا امید ہو گئے ہیں اور ان کے لیے دردناک عذاب ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmccclxiv{پھر اس کی قوم کا اس کے سوا اور کوئی جواب نہ تھا کہ اسے مار ڈالو یا جلا ڈالو پھر الله نے اسے آگ سے نجات دی بے شک اس میں ان کے لیے نشانیاں ہیں جو ایماندار ہیں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmccclxv{او رکہا تم الله کو چھوڑ کر بتوں کو لیے بیٹھے ہو تمہاری آپس کی محبت دنیا کی زندگی میں ہے پھر قیامت کے دن ایک دوسرے کا انکار کرے گا اور ایک دوسرے پر لعنت کرے گا اور تمہارا ٹھکانہ آگ ہوگا اور تمہارے لیے کوئی بھی مددگار نہ ہوگا\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmccclxvi{پھر اس پر لوط ایمان لایا اور ابراھیم نے کہا بے شک میں اپنے رب کی طرف ہجرت کرنے والا ہوں بے شک وہ غالب حکمت والا ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmccclxvii{اور ہم نے اسے اسحاق اور یعقوب عطا کیا اور اس کی نسل میں نبوت اور کتاب مقرر کردی اور ہم نے اسے اس کا بدلہ دنیا میں دیا اور وہ آخرت میں بھی البتہ نیکوں میں سے ہو گا\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmccclxviii{اور لوط کو بھیجا جب اس نے اپنی قوم سے کہا کہ تم وہ بے حیائی کرتے ہو جو تم سے پہلے کسی نے نہیں کی\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmccclxix{کیا تم مردوں کے پاس جاتے ہو اور تم ڈاکے ڈالتے ہو اور اپنی مجلس میں برا کام کرتے ہو پھر اس کی قوم کے پاس اس کے سوا کوئی جواب نہ تھا کہ تو ہم پر الله کا عذاب لے آ اگر تو سچا ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmccclxx{کہا اے میرے رب ان شریر لوگو ں پر میری مدد کر\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxi{اور جب ہمارے بھیجے ہوئے ابراھیم کے پاس خوشخبری لے کر آئے کہنے لگے ہم اس بستی کے لوگوں کو ہلاک کرنے والے ہیں یہاں کے لوگ بڑے ظالم ہیں\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxii{کہا اس میں لوط بھی ہے کہنے لگے ہم خوب جانتے ہیں جو اس میں ہے ہم لوط اور اس کے کنبہ کو بچا لیں گے مگر اس کی بیوی وہ پیچھے رہ جانے والوں میں ہو گی\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxiii{اور جب ہمارے بھیجے ہوئے لوط کے پاس آئے تو اسے ان کا آنا برا معلوم ہوا اور تنگدل ہوئے فرشتوں نے کہا خوف نہ کر اور غم نہ کھا بے شک ہم تجھے اور تیرے کنبہ کو بچا لیں گے مگرتیری بیوی پیچھے رہنے والوں میں ہوگی\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxiv{ہم ا س بستی والوں پر اس لیے کہ بدکاری کرتے رہے ہیں آسمان سے عذاب نازل کرنے والے ہیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxv{اور ہم نے عقلمندوں کے لیے اس بستی کا نشان نظر آتا ہوا چھوڑ دیا\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxvi{اور مدین کے پاس ان کے بھائی شعیب کو بھیجا پس کہا اے میری قوم! الله کی عبادت کرو اور قیامت کے دن کی امید رکھو اور ملک میں فساد نہ مچاؤ\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxvii{سو انہوں نے اسےجھٹلایا تب انہیں زلزلہ نے آ پکڑا پھر وہ اپنے گھروں میں اوندھے پڑے رہ گئے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxviii{اور ہم نے عاد اور ثمود کو ہلاک کیا اور تمہیں ان کے کچھ مکانات بھی دکھائی دیتے ہیں اور شیطان نے ان کے اعمال انہیں آراستہ کر دکھائے اور انہیں راہ سے روک دیا حالانکہ وہ سمجھدار تھے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxix{اور قارون اور فرعون اور ہامان کو ہلاک کیا اور البتہ ان کے پاس موسیٰ نشانیاں بھی لے کر آئے تھے پھر انہوں نے ملک میں سرکشی کی اور وہ بھاگ کر نہ جا سکے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxx{پھر ہم نے ہر ایک کو اس کے گناہ پر پکڑا پھر کسی پر تو ہم نے پتھروں کا مینہ بر سایا اور ان میں سے کسی کو کڑک نے آپکڑا اور کسی کو ان میں سے زمین میں دھنسا دیا اور کسی کو ان میں سے غرق کر دیا اور الله ایسا نہ تھا کہ ان پر ظلم کرے لیکن وہی اپنے اوپر ظلم کیا کرتے تھے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxi{ان لوگوں کی مثال جنہوں نے الله کے سوا حمایت بنا رکھے ہیں مکڑی کی سی مثال ہے جس نے گھر بنایا اور بے شک سب گھروں سے کمزور گھر مکڑی کا ہے کاش وہ جانتے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxii{بےشک الله جانتا ہے جسے وہ اس کے سوا پکارتے ہیں اور وہ غالب حکمت والا ہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxiii{اور یہ مثالیں ہیں جنہیں ہم لوگوں کے لیے بیان کرتے ہیں اور انہیں وہی سمجھتے ہیں جو علم والے ہیں\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxiv{الله نے آسمانو ں اور زمین کو مناسب طور پر بنایا ہے بے شک اس میں ایمان والوں کے لیے بڑی نشانی ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxv{جو کتاب تیری طرف وحی کی گئی ہے اسے پڑھا کرو اور نماز کے پابند رہو بے شک نماز بے حیائی اوربری بات سے روکتی ہے اور الله کی یاد بہت بڑی چیز ہے اور الله جانتا ہے جو تم کرتے ہو\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxvi{اور اہل کتاب سے نہ جھگڑو مگر ایسے طریقے سے جو عمدہ ہو مگر جو ان میں بے انصاف ہیں اور کہہ دو ہم اس پر ایمان لائے جو ہماری طرف نازل کیا گیا اور تمہاری طرف نازل کیا گیا اور ہمارا اور تمہارا معبود ایک ہی ہے اور ہم اسی کے فرمانبردار ہونے والے ہیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxvii{اور اسی طرح ہم نے تیری طرف کتاب نازل کی ہے پھر جنہیں ہم نے کتاب دی تھی وہ تو اس پر ایمان لائے ہیں اور ان میں سے بھی کچھ لوگ اس پر ایمان لائے ہیں اور ہماری آیتوں کا کافر ہی انکار کیا کرتے ہیں\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxviii{اور اس سے پہلے نہ تو کوئی کتاب پڑھتا تھا اور نہ اسے اپنے دائیں ہاتھ سے لکھتا تھا اس وقت االبتہ باطل پرست شک کرتے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxix{بلکہ وہ روشن آیتیں ہیں ان کے دلوں میں جنہیں علم دیا گیاہے اور ہماری آیتوں کا صرف ظالم ہی انکار کرتے ہیں\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmcccxc{اور کہتے ہیں اس پر اس کے رب کی طرف سے نشانیاں کیوں نہ اتریں کہہ دو نشانیاں تو الله ہی کے اختیار میں ہیں اور میں تو بس کھول کر سنا دینے والا ہوں\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmcccxci{کیا ان کے لیے یہ کافی نہیں کہ ہم نے تجھ پر کتاب نازل کی جو ان پر پڑھی جاتی ہے بے شک اس میں رحمت ہے اور ایمان والوں کے لیے نصیحت ہے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmcccxcii{کہہ دو الله میرے اور تمہارے درمیان گواہ کافی ہے جو کچھ آسمانوں اور زمین میں ہے جانتا ہے اور جو لوگ جھوٹ پر ایمان لائے اورالله کا انکار کیا وہی نقصان پانے والے ہیں\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmcccxciii{اور تجھ سے عذاب جلدی مانگتے ہیں اور اگر ایک وعدہ مقرر نہ ہوتا تو ا ن پر عذاب آ جاتا اور البتہ ان پر اچانک آئے گا اور انہیں خبر بھی نہ ہوگی\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmcccxciv{تجھ سے عذاب جلدی مانگتے ہیں اور بے شک دوزخ کافروں کو گھیرلینے والی ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmcccxcv{جس دن عذاب انہیں ان کے اوپر سے اور پاؤں کے نیچے سے گھیر لے گا اور کہے گا جو تم کیا کرتے تھے اس کا مزہ چکھو\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmcccxcvi{اے میرے بندو جو ایمان لائے ہو میری زمین کشادہ ہے پس میری ہی عبادت کرو\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmcccxcvii{ہر جاندار موت کا مزہ چکھنے والا ہے پھر ہمارے ہی پاس پھر کر آؤ گے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmcccxcviii{اور جو ایمان لائے اور نیک کام کیے البتہ ہم انہیں جنت کے بالا خانوں میں جگہ دیں گے جن کے نیچے نہریں بہتی ہوں گی وہاں ہمیشہ رہیں گے عمل کرنے والوں کا کیا اچھا بدلہ ہے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmcccxcix{جنہوں نے صبر کیا اور اپنے رب پر بھروسہ رکھتے ہیں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmcd{اور بہت سے جانور ہیں جو اپنا رزق اٹھائے نہیں پھرتے الله ہی انہیں اور تمہیں رزق دیتا ہے اور وہ سننے والا جاننے والا ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmcdi{اور البتہ اگر تو اان سے پوچھے کہ آسمانوں اور زمین کو کس نے پیدا کیا اور سورج اور چاند کو کس نے کام میں لگایا تو ضرور کہیں گے الله نے پھر کہاں الٹے جا رہے ہیں\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmcdii{الله ہی اپنے بندوں میں سے جس کے لیے چاہتا ہے رزق کشادہ کر دیتا ہے اورتنگ کر دیتا ہے بے شک الله ہر چیز کا جاننے والا ہے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmcdiii{اور البتہ اگر تو ان سے پوچھے آسمان سے کس نے پانی اتارا پھر اس سے زمین کو اس کے مرنے کے بعد زندہ کیا کہیں گے الله نے کہہ دو سب تعریف الله ہی کے لیے ہے لیکن ان میں سے اکثر نہیں سمجھتے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmcdiv{اور یہ دنیا کی زندگی تو صرف کھیل اور تماشا ہے اور اصل زندگی عالم آخرت کی ہے کاش وہ سمجھتے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmcdv{پھر جب کشتی میں سوار ہوتے ہیں تو خالص اعتقاد سے الله ہی کو پکارتے ہیں پھر جب انہیں نجات دے کر خشکی کی طرف لے آتا ہے فوراً ہی شرک کرنے لگتے ہیں\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmcdvi{تاکہ ناشکری کریں اس نعمت کی جو ہم نے انہیں دی تھی اور مزے اڑاتے رہیں عنقریب انہیں معلوم ہو جائے گا\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmcdvii{کیا وہ نہیں دیکھتے کہ ہم نے حرم کو امن کی جگہ بنا دیا ہے اور لوگ ان کے آس پاس سے اچک لیے جاتے ہیں کیا یہ لوگ جھوٹ پر ایمان رکھتے ہیں اور الله کی نعمت کی ناشکری کرتے ہیں\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmcdviii{اور اس سے بڑھ کر کون ظالم ہے جو الله پر جھوٹ باندھے یا حق کو جھٹلائے جب اس کے پاس آئے کیا دوزخ میں کافروں کا ٹھکانہ نہیں ہے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmcdix{اور جنہوں نے ہمارے لیے کوشش کی ہم انہیں ضرور اپنی راہیں سمجھا دیں گے اور بے شک الله نیکو کاروں کے ساتھ ہے\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmcdx{\basmalahur المۤ\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmcdxi{روم مغلوب ہو گئے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmcdxii{نزدیک کے ملک میں اور وہ مغلوب ہونے کے بعد عنقریب غالب آجائیں گے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmcdxiii{چند ہی سال میں پہلے اور پچھلے سب کا م الله کے ہاتھ میں ہیں اور اس دن مسلمان خوش ہوں گے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmcdxiv{الله کی مدد سے مدد کرتا ہے جس کی چاہتا ہے اور وہ غالب رحم والا ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmcdxv{الله کا وعدہ ہو چکا الله اپنے وعدہ کا خلاف نہیں کرے گا لیکن اکثر آدمی نہیں جانتے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmcdxvi{دنیا کی زندگی کی ظاہر باتیں جانتے ہیں اور وہ آخرت سے غافل ہی ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmcdxvii{کیا وہ اپنے دل میں خیال نہیں کرتے کہ الله نے آسمانوں اور زمین کواور جو کچھ ان دونوں کے درمیان ہے عمدگی سے اور وقت مقرر تک کے لیے بنایا ہے اور بے شک بہت سے لوگ اپنے رب سے ملنے کے منکر ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmcdxviii{کیا انہوں نے ملک میں پھر کر نہیں دیکھا کہ ان سے پہلوں کا کیسا انجام ہوا وہ ان سے بھی بڑھ کر قوت والے تھے اور انہوں نے زمین کو جوتا تھا اور ان سے بہت زیادہ آباد کیا تھا اور ان کے پاس ان کے رسول معجزات لے کر بھی آئے تھے پھر الله ایسا نہ تھا کہ ان پر ظلم کرتا بلکہ وہی اپنے نفسوں پر ظلم کرتے تھے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmcdxix{پھر برا کرنے والوں کا انجام بھی برا ہی ہوا اس لیے کہ انہوں نے الله کی آیتوں کو جھٹلایا اور ان کی ہنسی اڑاتے رہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmcdxx{الله ہی مخلوق کو پہلی بار پیدا کرتا ہے پھر وہ اسے دوبارہ پیدا کرے گا پھر اس کے پاس لوٹ کر آؤ گے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxi{اور جس دن قیامت قائم ہو گی گناہگار نا امید ہو جائیں گے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxii{اور ان کے معبودوں میں سے کوئی ان کی سفارش کرنے والا نہ ہوگا اور اپنے معبودوں سے منکر ہو جائیں گے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxiii{اور جس دن قیامت قائم ہوگی اس دن لوگ جدا جدا ہوجائیں گے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxiv{پھر جو ایما ن لائے اورنیک کام کیے سووہ بہشت میں خوش حال ہوں گے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxv{اورجنہوں نے انکار کیا اور ہماری آیتوں اور آخرت کے آنے کو جھٹلایا وہ عذاب میں ڈالے جائیں گے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxvi{پھر الله کی تسبیح کرو جب تم شام کرو اور جب تم صبح کرو\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxvii{اور آسمانوں اور زمین میں اسی کی تعریف ہے اور پچھلے پہر بھی اور جب دوپہر ہو\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxviii{زندہ کو مردہ سے اور مردہ کو زندہ سے نکالتا ہے اور زمین کو اس کے مرنے کے بعد زندہ کرتا ہے اور اسی طرح تم نکالے جاؤ گے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxix{اور اس کی نشانیوں میں سے ہے کہ تمہیں مٹی سے بنایا پھر تم انسان بن کر پھیل رہے ہو\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxx{اور اس کی نشانیوں میں سے یہ بھی ہے کہ تمہارے لیے تمہیں میں سے بیویاں پیدا کیں تاکہ ان کے پاس چین سے رہو اور تمہارے درمیان محبت اور مہربانی پیدا کر دی جو لوگ غور کرتے ہیں ان کے لیے اس میں نشانیاں ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxi{اور اس کی نشانیوں میں سے آسمانوں اور زمین کا پیدا کرنا اور تمہاری زبانوں اور رنگتوں کا مختلف ہونا ہے بے شک اس میں علم والوں کے لیے نشانیاں ہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxii{اور اس کی نشانیوں میں سے تمہارا رات اور دن میں سونا اور اس کے فضل کا تلاش کرنا ہے بے شک اس میں سننے والوں کے لیے نشانیاں ہیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxiii{اور اس کی نشانیوں میں سے یہ ہے کہ تمہیں خوف اور امید دلانے کو بجلی دکھاتا ہے اور اوپر سے پانی برساتا ہے پھراس سے زمین خشک ہو جانے کے بعد زندہ کرتا ہے بے شک اس میں عقلمندوں کے لئےنشانیاں ہیں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxiv{اور اس کی نشانیوں میں سے یہ ہے کہ آسمان اور زمین ا س کے حکم سے قائم ہیں پھر جب تمہیں پکار کر زمین میں سے بلائے گا اسی وقت تم نکل آؤ گے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxv{اور اسی کا ہے جو کچھ آسمانوں اور زمین میں ہے سب اسکے حکم کے تابع ہیں\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxvi{اور وہی ہے جو پہلی بار بناتا ہے پھر اسے لوٹائے گا اور وہ اس پر آسان ہے اور آسمانوں اور زمین میں اس کی شان نہایت بلند ہے اور وہ غالب حکمت والا ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxvii{وہ تمہارے لیے تمہارے ہی حال کی ایک مثال بیان فرماتا ہے کیا جن کے تم مالک ہو وہ اس میں جو ہم نے تمہیں دیا ہے تمہارے شریک ہیں پھر اس میں تم برابر ہو تم ان سے اس طرح ڈرتے ہو جس طرح اپنوں سے ڈرتے ہو اس طرح ہم عقل والوں کے لیے آیتیں کھول کر بیان کرتے ہیں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxviii{بلکہ یہ بے انصاف بے سمجھے اپنی خوہشوں پر چلتے ہیں پھر کون ہدایت کر سکتا ہے جسے الله نے گمراہ کر دیا اور ان کا کوئی بھی مددگار نہیں\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxix{سو تو ایک طرف کا ہو کر دین پرسیدھا منہ کیے چلا جا الله کی دی ہوئی قابلیت پر جس پر اس نے لوگوں کو پیدا کیا ہے الله کی بناوٹ میں ردو بدل نہیں یہی سیدھا دین ہے لیکن اکثر آدمی نہیں جانتے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmcdxl{اسی کی طرف رجوع کیے رہو اور اس سے ڈرو اور نماز قائم کرو اور مشرکوں میں سے نہ ہوجاؤ\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmcdxli{جنہوں نے اپنے دین کو ٹکڑے ٹکڑے کر دیا اور کئی فرقے ہو گئے سب فرقے اسی سے خوش ہیں جو ان کے پا س ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmcdxlii{اور ولوگوں کو جب کوئی دکھ پہنچتا ہے تو اپنے رب کی طرف رجوع ہو کر اسے پکارتے ہیں پھر جب وہ انہیں اپنی رحمت کا مزہ چکھاتا ہے توایک گروہ ان میں سے اپنے رب سے شرک کرنے لگتا ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmcdxliii{تاکہ جو ہم نے انہیں دیا ہے اس کی ناشکری کریں سوفائدہ اٹھا لو عنقریب تمہیں معلوم ہو جائے گا\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmcdxliv{کیا ہم نے ان کے لیے کوئی سند بھیجی ہے کہ وہ انہیں شرک کرنا بتا رہی ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmcdxlv{اور جب ہم لوگوں کو رحمت کا مزہ چکھاتے ہیں تو اس پر خوش ہوجاتے ہیں اور اگر انہیں ان کے گذشتہ اعمال کے سبب سے دکھ پہنچتا ہے تو فوراً نا امید ہو جاتے ہیں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmcdxlvi{کیا وہ نہیں دیکھتے کہ الله جس کے لیے چاہتا ہے رزق کشادہ کرتا ہے اور تنگ کرتا ہے بے شک اس میں ایمان لانے والوں کے لیے نشانیاں ہیں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmcdxlvii{پھر رشتہ دار اور محتاج اور مسافر کو اس کا حق دے یہ بہتر ہے ان کے لیے جو الله کی رضا چاہتے ہیں اور وہی نجات پانے والے ہیں\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmcdxlviii{اور جو سود پر تم دیتے ہو تاکہ لوگوں کے مال میں بڑھتا رہے سو الله کے ہاں وہ نہیں بڑھتا اور جو زکواة دیتے ہو جس سے الله کی رضا چاہتے ہو سو یہ وہ ہی لوگ ہیں جن کے دونے ہوئے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmcdxlix{الله وہ ہے جس نے تمہیں پیدا کیا پھر تمہیں روزی دی پھر تمہیں مارے گا پھر تمہیں زندہ کرے گا کیا تمہارے معبودوں میں سے کبھی کوئی ایسا ہے جو ان کاموں میں سے کچھ بھی کر سکے وہ پاک ہے اور ان کے شریکوں سے بلند ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmcdl{خشکی اور تری میں لوگوں کے اعمال کے سبب سے فساد پھیل گیا ہے تاکہ الله انہیں ان کے بعض اعمال کا مزہ چکھائے تاکہ وہ باز آجائیں\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmcdli{کہہ دو ملک میں چلو پھرو اور دیکھو جو لوگ پہلے گزرے ہیں ان کا کیسا انجام ہوا ان میں سے اکثر مشرک ہی تھے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmcdlii{سو تو اپنا منہ سیدھی راہ پرسیدھا رکھ اس سے پہلے کہ وہ دن آ پہنچے جسے الله کی طرف سے پھرنا نہیں اس دن لوگ جدا جدا ہوں گے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmcdliii{جس نے کفر کیا سو اس کے کفر کا وبال اسی پر ہے اور جس نے اچھے کام کیے تو وہ اپنے لیے سامان کر رہے ہیں\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmcdliv{تاکہ جو ایمان لائے اور اچھےے کام کیے الله انہیں اپنے فضل سے بدلہ دے بے شک الله ناشکروں کو پسند نہیں کرتا\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmcdlv{اور اس کی نشانیوں میں سے ایک یہ ہے کہ خوشخبری لانے والی ہوائیں چلاتا ہے اور تاکہ تمہیں اپنی مہربانی کا کچھ مزہ چکھا دیں اور تاکہ کشتیاں اس کے حکم سے چلیں اور تاکہ اس کے فضل سے تلاش کرو اور تاکہ تم شکر کرو\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmcdlvi{اور ہم تم سے پہلے کتنے رسول اپنی اپنی قوم کے پاس بھیج چکے ہیں سو ان کے پاس نشانیاں لے کر آئے پھر ہم نے ان سے بدلہ لیا جو گناہگار تھے اور مومنوں کی مدد ہم پر لازم تھی\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmcdlvii{الله وہ ہے جو ہوائیں چلاتا ہے پھر وہ بادل کو اٹھاتی ہیں پھر اسے آسمان میں جس طرح چاہے پھیلا دیتا ہےاور اسے ٹکڑے ٹکڑے کر دیتا ہے پھر تو مینہ کو دیکھے گا کہ اس کے اندر سے نکلتا ہے پھر جب اسے اپنے بندوں میں سے جسے چاہتا ہے پہنچاتا ہے تو وہ خوش ہو جاتے ہیں\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmcdlviii{اور اگرچہ ان پر برسنے سے پہلے وہ نا امید تھے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmcdlix{پھر تو الله کی رحمت کی نشانیوں کو دیکھ کہ زمین کو خشک ہونے کے بعد کس طرح سر سبز کرتا ہے بے شک وہی مردوں کو پھر زندہ کرنے والا ہے اوروہ ہر چیز پر قادر ہے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmcdlx{اور اگر ہم ایسی ہوا چلائیں کہ جس سے وہ کھیتی کو زرد دیکھیں تو اس کے بعدوہ ناشکری کرنے لگ جائیں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxi{بے شک تو مردوں کو نہیں سنا سکتا اور نہ بہروں کو آواز سنا سکتا ہے جب وہ پیٹھ پھیر کرپھر جائیں\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxii{اور تم اندھوں کوان کے الٹے راستے سے سیدھے راستہ پر نہیں لا سکتے تم تو بس انہیں لوگوں کو سنا سکتے ہو جو ہماری آیتوں پر ایمان لاتے ہیں سو وہی ماننے والے ہیں\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxiii{الله ہی ہے جس نے تمہیں کمزوری کی حالت میں پیدا کیا پھر کمزوری کے بعد قوت عطا کی پھر قوت کے بعد ضعف اور بڑھاپا بنایا جو چاہتاہے پیدا کرتا ہے اوروہی جاننے والا قدرت والا ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxiv{اورجس دن قیامت قائم ہو گی گناہگار قسمیں کھائیں گے کہ ہم ایک گھڑی سے بھی زیادہ نہیں ٹھہرے تھے اسی طرح وہ الٹے جاتے تھے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxv{اور جن لوگو ں کو علم اور ایمان دیا گیا تھا کہیں گے کہ الله کی کتاب کے مطابق تم قیامت تک رہے ہو سو یہ قیامت کا ہی دن ہے لیکن تمہیں اس کا یقین ہی نہ تھا\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxvi{تو اس دن ظالموں کو ان کا عذر کچھ فائدہ نہ دے گا اور نہ ان سے توبہ قبول کی جائے گی\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxvii{اور ہم نے لوگوں کے لیے اس قرآن میں ہر طرح کی مثال بیان کر دی ہے اور اگر تم ان کے سامنے کوئی نشانی پیش کرو تو کافر یہ کہہ دیں گے کہ تم تو جھوٹے ہو\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxviii{جو لوگ یقین نہیں کرتے الله ان کے دلوں پر یونہی مہر کر دیتا ہے\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxix{سوتو صبر کر بے شک الله کاوعدہ سچا ہے اور جو لوگ یقین نہیں رکھتے وہ تجھے بےبرداشت نہ بنادیں\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxx{\basmalahur المۤ\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxi{یہ آیتیں حکمت والی کتا ب کی ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxii{جو نیک بختوں کے لیے ہدایت اور رحمت ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxiii{وہ جو نماز ادا کرتے ہیں اور زکواة دیتے ہیں اور آخرت پر بھی یقین رکھتے ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxiv{یہی لوگ اپنے رب کی ہدایت پر ہیں اور یہی لوگ نجات پانے والے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxv{اور بعض ایسے آدمی بھی ہیں جو کھیل کی باتوں کے خریدار ہیں تاکہ بن سمجھے الله کی راہ سے بہکائیں اور اس کی ہنسی اڑائیں ایسے لوگو ں کے لیے ذلت کا عذاب ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxvi{اورجب اس پر ہماری آیتیں پڑھی جاتی ہیں تو تکبرکرتا ہوا منہ موڑ لیتا ہے جیسے اس نے سنا ہی نہیں گویا اس کے دونوں کان بہرے ہیں سواسے دردناک عذاب کی خوشخبری دے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxvii{بے شک جو لوگ ایمان لائے اور نیک کام کیے ان کے لیے نعمت کے باغ ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxviii{جہاں ہمیشہ رہیں گے الله کا سچا وعدہ ہو چکا اور وہ زبردست حکمت والا ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxix{آسمانوں کو بے ستون بنایا تم انہیں دیکھ رہے ہو اور زمین میں مضبوط پہاڑ رکھ دیے تاکہ تمہیں لے کر ادھر ادھر نہ جھکے اور اس میں ہر قسم کے جانور پھیلا دیے اور ہم نے آسمان سے مینہ برسایا پھر ہم نے زمین میں ہر قسم کی عمدہ چیزیں اگائیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxx{یہ تو الله کی ساخت ہے پھر مجھے دکھاؤ کہ اس کے سوا غیر نے کیاپیدا کیا ہے بلکہ ظالم صریح گمراہی میں پڑے ہوئے ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxi{اور ہم نے لقمان کو دانائی عطا فرمائی کہ اللہ کا شکر کرتے رہو اور جو شخص شکر کرے گا وہ اپنے ذاتی نفع کے لیے شکر کرتا ہے اور جو ناشکری کرے گا تو الله بے نیاز خوبیوں والا ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxii{اور جب لقمان نے اپنے بیٹے کو نصیحت کرتے ہوئے کہا تھا کہ بیٹا الله کے ساتھ کسی کو شریک نہ ٹھہرانا بے شک شرک کرنا بڑا بھاری ظلم ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxiii{اور ہم نے انسان کو اس کے ماں باپ کے متعلق تاکید کی ہے اس کی ماں نے ضعف پر ضعف اٹھا کر اسے پیٹ میں رکھا اور دو برس میں اس کا دودھ چھڑانا ہے تو میری اور اپنے ماں باپ کی شکر گزاری کرے میری ہی طرف لوٹ کر آنا ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxiv{اور اگر تجھ پر اس بات کا زور ڈالیں تو میرے ساتھ اس کو شریک بنائے جس کو تو جانتا بھی نہ ہو تو ان کا کہنا نہ مان اور دنیا میں ان کے ساتھ نیکی سے پیش آ اور ان لوگوں کی راہ پر چل جو میری طرف رجوع ہوگئے پھر تمہیں لوٹ کر میرے ہی پاس آنا ہے پھر میں تمہیں بتاؤں گا کہ تم کیا کیا کرتے تھے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxv{بیٹا اگر کوئی عمل رائی کے دانہ کے برابر ہو پھر وہ کسی پتھر کے اندر ہو یا وہ آسمان کے اندر ہو یا زمین کے اندر ہو تب بھی الله اس کو حاضر کر دے گا بے شک الله بڑا باریک بین (اور) باخبر ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxvi{بیٹا نماز پڑھا کر اور اچھے کاموں کی نصیحت کیا کر اوربرے کاموں سے منع کیا کر اور تجھ پر جو مصیبت آئے اس پر صبر کیا کر بے شک یہ ہمت کے کاموں میں سے ہیں\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxvii{اور لوگوں سے اپنا رخ نہ پھیر اور زمین پر اترا کر نہ چل بے شک الله کسی تکبر کرنے والے فخر کرنے والے کو پسند نہیں کرتا\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxviii{اور اپنے چلنے میں میانہ روی اختیار کر اور اپنی آواز پست کر بے شک آوازوں میں سب سے بری آواز گدھوں کی ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxix{کیا تم نے نہیں دیکھا جو کچھ آسمانوں میں اورجوکچھ زمین میں ہے سب کو الله نے تمہارے کام پر لگایا رکھا ہے اور تم پراپنی ظاہری اور باطنی نعمتیں پوری کر دی ہیں اور لوگوں میں سے ایسے بھی ہیں جو الله کے معاملے میں جھگڑتے ہیں نہ انہیں علم ہے اور نہ ہدایت ہے اور نہ روشنی بخشنے والی کتاب ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmcdxc{اور جب ان سے کہا جاتا ہے اس پر چلو جو الله اس پر چلو جو الله نے نازل کیا ہے تو کہتے ہیں کہ ہم تو اس پر چلیں گے جس پر ہم نے اپنے باپ دادا کو پایا ہے کیا اگرچہ شیطان ان کے بڑوں کو دوزخ کے عذاب کی طرف بلاتا رہا ہو\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmcdxci{اور جس نے نیک ہو کر اپنا منہ الله کے سامنے جھکا دیا تو اس نے مضبوط کڑے کو تھام لیا اور آخر کار ہر معاملہ الله ہی کے حضور میں پیش ہونا ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmcdxcii{اور جس نے انکار کیا پس تو اس کے انکار سے غم نہ کھا انہیں ہمارے پاس آنا ہے پھر ہم انہیں بتا دیں گے کہ انہوں نے کیا کیا ہے بے شک الله دلوں کے راز جانتا ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmcdxciii{ہم انہیں تھوڑا سا عیش دے رہے ہیں پھر ہم انہیں سخت عذاب کی طرف گھسیٹ کر لے جائیں گے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmcdxciv{اور اگر آپ ان سے پوچھیں کہ آسمانوں اور زمین کو کس نے بنایا ہے تو ضرور کہیں گے کہ الله نے کہہ دو الحمدُلله بلکہ ان میں سے اکثر نہیں جانتے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmcdxcv{الله ہی کا ہے جو کچھ آسمانوں اور زمین میں ہے بے شک الله بے نیاز سب خوبیوں والا ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmcdxcvi{اوراگروہ جو زمین میں درخت ہیں سب قلم ہوجائیں گے اور دریا سیاہی اس کے بعد اس دریا میں سات اور دریا سیاہی کے آ ملیں تو بھی الله کی باتیں ختم نہ ہوں بے شک الله زبردست حکمت والا ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmcdxcvii{تم سب کا پیدا کرنا اور مرنے کے بعد زندہ کرنا ایسا ہی ہے جیسا ایک شخص کا بے شک الله سنتا دیکھتا ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmcdxcviii{کیا تو نے نہیں دیکھا کہ الله رات کو دن میں داخل کرتا ہے اور دن کو رات میں داخل کرتا ہے اور سورج اور چاند کو کام پر لگا رکھا ہے ہر ایک وقت مقرر تک چلتا رہے گا اور یہ کہ الله تمہارے کام سے خبردار ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmcdxcix{یہ اس لیے کہ الله ہی حق ہے اور اس کے سوا جس کو وہ پکارتے ہیں جھوٹ ہے اور الله ہی بلند مرتبہ بزرگ ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmd{کیا آپ نے نہیں دیکھا کہ الله ہی کے فضل سے دریا میں کشتیاں چلتی ہیں تاکہ تمہیں اپنی نشانیاں دکھائے بے شک اس میں ہر ایک صابر شاکر کےلیے نشانیاں ہیں\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmdi{اور جب انہیں سائبانوں کی طرح موج ڈھانک لیتی ہے تو خالص اعتقاد سے الله ہی کو پکارتے ہیں پھر جب انہیں نجات دے کر خشکی کی طرف لےآتا ہے تو بعض ان میں سے راہِ راست پر رہتے ہیں اور ہماری نشانیوں سے وہی لوگ انکار کرتے ہیں جو بد عہد نا شکر گزار ہیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmdii{اے لوگو اپنے رب سے ڈرو اور اس دن سے ڈرو جس میں نہ باپ اپنے بیٹے کے کام آئے گا اور نہ بیٹا اپنے باپ کے کچھ کام آئے گا الله کا وعدہ سچا ہے پھر دنیا کی زندگی تمہیں دھوکا میں نہ ڈال دے اور نہ دغا باز تمہیں الله سے دھوکہ میں رکھیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmdiii{بے شک الله ہی کو قیامت کی خبر ہے اور وہی مینہ برساتا ہے اور وہی جانتا ہے جو کچھ ماؤں کے پیٹوں میں ہوتا ہے اور کوئی نہیں جانتا کہ کل کیا کرے گا اور کوئی نہیں جانتا کہ کس زمین پر مرے گا بے شک الله جاننے والا خبردار ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmdiv{\basmalahur المۤ\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmdv{اس میں کچھ شک نہیں کہ یہ کتاب جہان کے پالنے والے کی طرف سے نازل ہوئی ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmdvi{کیا وہ کہتے ہیں کہ اس نے خود بنائی ہے بلکہ یہ سچی کتاب تیرے رب کی طرف سے ہے تاکہ تو اس قوم کوڈرائے جن کے پاس تجھ سے پہلے کوئی ڈرانے والا نہیں آیا تاکہ وہ راہ پر آئيں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmdvii{الله وہ ہے جس نے آسمانوں اور زمین کو اورجو کچھ ان میں ہے چھ روز میں بنایا پھر عرش پر قائم ہوا تمہارے لیے اس کے سوا نہ کوئی کارساز ہے نہ سفارشی پھر کیا تم نہیں سمجھتے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmdviii{وہ آسمان سے لے کر زمین تک ہر کام کی تدبیر کرتا ہے پھراس دن بھی جس کی مقدار تمہاری گنتی سے ہزار برس ہو گی وہ انتظام اس کی طرف رجوع کرے گا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmdix{وہی چھپی اور کھلی بات کا جاننے والا زبردست مہربان ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmdx{جس نے جو چیز بنائی خوب بنائی اور انسان کی پیدائش مٹی سے شروع کی\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmdxi{پھر اس کی اولاد نچڑے ہوئے حقیر پانی سے بنائی\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmdxii{پھراس کے اعضا درست کیے اور اس میں اپنی روح پھونکی اور تمہارے لیے کان اور آنکھیں اور دل بنایا تم بہت تھوڑا شکر کرتے ہو\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmdxiii{اور کہتے ہیں کہ ہم جب زمین میں نیست و نابود ہو گئے تو کیا پھر نئے سرے سے پیدا ہوں گے بلکہ وہ اپنے رب سے ملنے کے منکر ہیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmdxiv{کہہ دو تمہاری جان موت کا وہ فرشتہ قبض کرے گا جو تم پر مقرر کیا گیا ہے پھر تم اپنے رب کے پاس لوٹائے جاؤ گے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmdxv{اور کبھی تو دیکھے جس وقت منکر اپنے رب کے سامنے سر جھکائے ہوئے ہوں گے اے رب ہمارے ہم نے دیکھ اور سن لیا اب ہمیں پھر بھیج دے کہ اچھے کام کریں ہمیں یقین آ گیا ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmdxvi{اور اگر ہم چاہتے ہیں تو ہر شخص کو ہدایت پر لے آتے لیکن ہماری بات پوری ہو کر رہی کہ ہم جنوں اور آدمیوں سے جہنم بھر کر رہیں گے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmdxvii{تو اب اس کا مزہ چکھو کہ تم اپنے اس دن کے آنے کو بھول گئے تھے ہم نے تمہیں بھلا دیا اور اپنے کیے کے بدلہ میں ہمیشہ کا عذاب چکھو\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmdxviii{بس ہماری آیتوں پر وہ ایمان لاتے ہیں کہ جب انہیں وہ آیتیں یاد دلائی جاتی ہیں تو وہ سجدہ میں گر پڑتے ہیں اور اپنے رب کی حمد کے ساتھ تسبیح بیان کرتے ہیں اور وہ تکبر نہیں کرتے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmdxix{اپنے بستروں سے اٹھ کر اپنے رب کو خوف اور امید سے پکارتے ہیں اور ہمارے دیئے میں سے کچھ خرچ بھی کرتے ہیں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmdxx{پھر کوئی شخص نہیں جانتا کہ ان کے عمل کے بدلہ میں ان کی آنکھو ں کی کیا ٹھنڈک چھپا رکھی ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmdxxi{کیا مومن اس کے برابر ہے جو نا فرمان ہو برابر نہیں ہو سکتے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmdxxii{سو وہ لوگ جو ایمان لائے اور اچھے کام کیے تو ان کے ان کاموں کے سبب جو وہ کیا کرتے تھے مہمانی میں ہمیشہ رہنے کے باغ ہیں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmdxxiii{اور جنہوں نے نافرمانی کی ان کا ٹھکانا آگ ہے جب وہاں سے نکلنے کا ارداہ کریں گے تو اس میں پھر لوٹا دیئے جائیں گے اور انہیں کہا جائے گا آگ کا وہ عذاب چکھو جسے تم جھٹلایا کرتے تھے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmdxxiv{اور ہم انہیں قریب کا عذاب بھی اس بڑے عذاب سے پہلے چکھائیں گے تاکہ وہ باز آ جائیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmdxxv{اوراس سے بڑھ کر کون ظالم ہوگا جسے اس کے رب کی آیتوں سے سمجھایا جائے پھر وہ ان سے منہ موڑے ہمیں تو گنہگاروں سے بدلہ لینا ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmdxxvi{اور البتہ ہم نے موسیٰ کو کتاب دی تھی پھر آپ اس کے ملنے میں شک نہ کریں اور ہم نے ہی اسے بنی اسرائیل کے لیے راہ نما بنایا تھا\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmdxxvii{اور ہم نے ان میں سے پیشوا بنائے تھے جو ہمارے حکم سے رہنمائی کرتے تھے جب انہوں نے صبر کیا تھا اور وہ ہماری آیتوں پر یقین بھی رکھتے تھے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmdxxviii{بے شک تیرا رب ہی قیامت کے دن ان میں فیصلہ کرے گا جس بات میں وہ اختلاف کرتے تھے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmdxxix{کیا انھیں اس سے بھی رہنمائی نہ ہوئی کہ ان سے پہلے ہم نے کتنی جماعتیں ہلاک کر دی ہیں جن کے گھروں میں یہ چلتے پھرتے ہیں بے شک اس میں بڑی نشانیاں ہیں پھر کیا وہ سنتے بھی نہیں\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmdxxx{کیا وہ نہیں دیکھتے کہ ہم پانی کو خشک زمین کی طرف رواں کر کے ا س سے کھیتی نکالتے ہیں جس سے ان کے چار پائے اوروہ خود بھی کھاتے ہیں پھر کیا وہ دیکھتے نہیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmdxxxi{اور کہتے ہیں کہ اگر تم سچے ہو تو یہ فیصلہ کب ہوگا\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmdxxxii{کہہ دو کہ فیصلہ کا دن کافرو ں کو ان کا ایمان لانا نفع نہ دے گا اور نہ ہی انہیں مہلت دی جائے گی\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmdxxxiii{سو ان سے کنارہ کر اور انتظار کر وہ بھی انتظار کر رہے ہیں\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmdxxxiv{\basmalahur اے نبی الله سے ڈر اور کافروں اور منافقوں کا کہا نہ مان بے شک الله جاننے والا حکمت والا ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmdxxxv{اور اس کی تابعداری کر جو تیرے رب کی طرف سے تیری طرف بھیجا گیا ہے بے شک الله تمہارے کاموں سے خبردار ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmdxxxvi{اور الله پر بھروسہ کر اور الله ہی کارساز کافی ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmdxxxvii{الله نے کسی شخص کے سینہ میں دو دل نہیں بنائے اور نہ الله نے تمہاری ان بیویوں کوجن سے تم اظہار کرتے ہو تمہاری ماں بنایا ہے اور نہ تمہارے منہ بولے بیٹوں کو تمہارا بیٹا بنایا ہے یہ تمہارے منہ کی بات ہے اور الله سچ فرماتا ہے اور وہی سیدھا راستہ بتاتا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmdxxxviii{انہیں ان کے اصلی باپوں کے نام سے پکارو الله کے ہاں یہی پورا انصاف ہے سواگر تمہیں ان کے باپ معلوم نہ ہوں تو تمہارے دینی بھائی اور دوست ہیں اور تمہیں اس میں بھول چوک ہو جائے تو تم پر کچھ گناہ نہیں لیکن وہ جو تم دل کے ارادہ سے کرو اور الله بخشنے والا مہربان ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmdxxxix{نبی مسلمانو ں کے معاملہ میں ان سے بھی زيادہ دخل دینے کا حقدار ہے اور اس کی بیویاں ان کی مائیں ہیں اور رشتہ دار الله کی کتاب میں ایک دوسرے سے زیادہ تعلق رکھتے ہیں بہ نسبت دوسرے مومنین اور مہاجرین کے مگر یہ کہ تم اپنے دوستوں سے کچھ سلوک کرنا چاہو یہ بات لوح محفوظ میں لکھی ہوئی ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmdxl{اور جب ہم نے نبیوں سے عہد لیا اورآپ سے اورنوح اور ابراھیم اور موسیٰ اور مریم کے بیٹے عیسیٰ سے بھی اور ان سے ہم نے پکا عہد لیا تھا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmdxli{تاکہ سچوں سے ان کے سچ کا حال دریافت کرے اور کافروں کے لیے دردناک عذاب تیار کیا ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmdxlii{اے ایمان والو! الله کے احسان کو یاد کرو جو تم پر ہوا جب تم پر کئی لشکر چڑھ آئے پھر ہم نے ان پر ایک آندھی بھیجی اور وہ لشکر بھیجے جنہیں تم نے نہیں دیکھا اورجو کچھ تم کر رہے تھے الله دیکھ رہا تھا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmdxliii{جب وہ لوگ تم پر تمہارے اوپر کی طرف اورنیچے کی طرف سے چڑھ آئے اورجب آنکھیں پتھرا گئی تھیں اور کلیجے منہ کو آنے لگے تھے اورتم الله کے ساتھ طرح طرح کے گمان کر رہے تھے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmdxliv{اس موقع پر ایماندار آزمائے گئے اور سخت ہلا دیے گئے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmdxlv{اورجب کہ منافق اورجن کے دلوں میں شک تھا کہنے لگے کہ الله اور اس کے رسول نے جو ہم سے وعدہ کیا تھا صرف دھوکا ہی تھا\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmdxlvi{اورجب کہ ان میں سے ایک جماعت کہنے لگی اے مدینہ والو! تمہارے لیے ٹھیرنے کا موقع نہیں سو لوٹ چلو اور ان میں سے کچھ لوگ نبی سے رخصت مانگنے لگے کہنے لگے کہ ہمارے گھر اکیلے ہیں اور حالانکہ وہ اکیلے نہ تھے وہ صرف بھاگنا چاہتے تھے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmdxlvii{اور اگر کسی طرف سے کوئی ان پر گُھس آتا پھر ان سے فساد کی درخواست کی جاتی تو فساد پر آمادہ ہو جاتے اور دیر نہ کرتے مگر بہت ہی کم\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmdxlviii{حالانکہ اس سے پہلے الله سے عہد کر چکے تھے کہ پیٹھ نہ پھیریں گے اور الله سے عہد کرنے کی باز پرس ہوگی\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmdxlix{کہہ دو اگر تم موت یا قتل سے بھاگو گے تو تمہیں کوئی فائدہ نہیں ہوگا اور اس وقت سوائے تھوڑے دنوں کے نفع نہیں اٹھاؤ گے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmdl{کہہ دو کون ہے جو تمہیں الله سے بچا سکے اگر وہ تمہارے ساتھ برائی کرنا چاہے یا تم پر مہربانی کرنا چاہے اور الله کے سوا نہ کوئی اپنا حمایتی پائیں گے اور نہ کوئی مددگار\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmdli{تحقیق الله تم میں سے روکنے والوں کو جانتاہے اور جو اپنے بھائیوں سے کہتے ہیں کہ ہمارے پاس آجاؤ اورلڑائی میں بہت ہی کم آتے ہیں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmdlii{تم سے ہمدردی کرتے ہوئے پھر جب ڈر کا وقت آجائے تو تُو انھیں دیکھے گا کہ تیری طرف دیکھتے ہیں ان کی آنکھیں پھرتی ہیں جیسے کسی پر موت کی بے ہوشی آئے پھر جب ڈر جاتا رہے تو تمہیں تیز زبانوں سے طعنہ دیتے ہیں مال کے لالچی ہیں یہ لوگ ایمان نہیں لائے تو الله نے ان کے تمام اعمال ضائع کر دیے اور یہ بات الله پر بالکل آسان ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmdliii{خیال کرتے ہیں کہ فوجیں نہیں گئیں اور اگر فوجیں آجائیں تو آرزوکریں کہ کاش ہم باہر گاؤں میں جا رہیں تمہاری خبریں پوچھا کریں اور اگر تم میں بھی رہیں تو بہت ہی کم لڑیں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmdliv{البتہ تمہارے لیے رسول الله میں اچھا نمونہ ہے جو الله اور قیامت کی امید رکھتا ہے اور الله کو بہت یاد کرتا ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmdlv{اور جب مومنوں نے فوجوں کو دیکھا تو کہا یہ وہ ہے جس کا ہم سے الله اور اس کے رسول نے وعدہ کیا تھا اور الله اور اس کے رسول نے سچ کہا تھا اور اس سے ان کے ایمان اور فرمانبرداری میں ترقی ہو گئی\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmdlvi{ایمان والوں میں سے ایسے آدمی بھی ہیں جنہوں نے الله سے جو عہد کیا تھا اسے سچ کر دکھایا پھر ان میں سے بعض تو اپنا کام پورا کر چکے اور بعض منتظر ہیں اور عہد میں کوئی تبدیلی نہیں کی\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmdlvii{تاکہ الله سچوں کو ان کے سچ کا بدلہ دے اور اگر چاہے تو منافقوں کوعذاب دے یا ان کی توبہ قبول کرے بے شک الله بخشنے والا مہربان ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmdlviii{اور الله نے کافروں کو ان کے غصہ میں بھرا ہوا لوٹایا انہیں کچھ بھی ہاتھ نہ آیا اور الله نے مسلمانوں کی لڑائی اپنے ذمہ لے لی اور الله طاقت ور غالب ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmdlix{اور جن جن اہل کتاب نے ان کی مدد ی تھی انہیں ان کے قلعوں سے نیچے اتار دیا اور ان کے دلوں میں خوف ڈال دیا بعض کو تم قتل کرنے لگے اور بعض کو قید کر لیا\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmdlx{اور ان کی زمین اوران کے گھروں اور ان کےمالوں کا تمہیں مالک بنا دیا اور زمین کا جس پر تم نے کبھی قدم نہیں رکھا تھا اور الله ہر چیز پر قادر ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmdlxi{اے نبی اپنی بیویوں سے کہہ دو اگر تمہیں دنیا کی زندگی اور اس کی آرائش منظور ہے تو آؤ میں تمہیں کچھ دے دلا کر اچھی طرح سے رخصت کر دوں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmdlxii{اور اگر تم الله اور اس کے رسول اور آخرت کو چاہتی ہو تو الله نے تم میں سے نیک بختوں کے لیے بڑا اجر تیار کیا ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmdlxiii{اے نبی کی بیویو تم میں سے جو کوئی کھلی ہوئی بدکاری کرے تو اسے دگنا عذاب دیا جائے گا اور یہ الله پر آسان ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmdlxiv{اور جو تم میں سے الله اور اس کےرسول کی فرمانبرداری کرے گی اور نیک کام کرے گی تو ہم اسے اس کا دہرااجر دیں گے اور ہم نے اس کے لیے عزت کا رزق بھی تیار کر رکھا ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmdlxv{اے نبی کی بیویو تم معمولی عورتوں کی طرح نہیں ہو اگر تم الله سے ڈرتی ر ہو اور دبی زبان سے بات نہ کہو کیونکہ جس کے دل میں مرض ہے وہ طمع کرے گا اور بات معقول کہو\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmdlxvi{اور اپنے گھروں میں بیٹھی رہو اور گزشتہ زمانہ جاہلیت کی طرح بناؤ سنگھار دکھاتی نہ پھرو اور نماز پڑھو اور زکواة دو اور الله اور اس کے رسول کی فرمانبرداری کرو الله یہی چاہتا ہے کہ اے اس گھر والو تم سے ناپاکی دور کرے اور تمہیں خوب پاک کرے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmdlxvii{اور تمہارے گھروں میں جو الله کی آیتیں اور حکمت کی باتیں پڑھی جاتیں ہیں انہیں یاد رکھو بیشک الله رازدان خبردار ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmdlxviii{بیشک الله نے مسلمان مردوں اور مسلمان عورتوں اور ایمان دار مردوں اور ایماندار عورتوں اور فرمانبردار مردوں اور فرمانبردارعورتوں اور سچے مردوں اور سچی عورتوں اور صبر کرنے والے مردوں اور صبر کرنے والی عورتوں اور عاجزی کرنے والے مردوں اور عاجزی کرنے والی عورتوں اور خیرات کرنے والے مردوں اور خیرات کرنے والی عورتوں اور روزہ دار مردوں اور روزدار عورتوں اور پاک دامن مردوں اور پاک دامن عورتوں اور الله کو بہت یاد کرنے والے مردوں اور بہت یاد کرنے والی عورتوں کے لیے بخشش اور بڑا اجر تیار کیا ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmdlxix{اور کسی مومن مرد اور مومن عورت کو لائق نہیں کہ جب الله اور اس کا رسول کسی کام کا حکم دے تو انہیں اپنے کام میں اختیار باقی رہے اور جس نے الله اور اس کے رسول کی نافرمانی کی تو وہ صریح گمراہ ہوا\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmdlxx{اور جب تو نے اس شخص سے کہا جس پر الله نے احسان کیا اور تو نے احسان کیا اپنی بیوی کو اپنے پاس رکھ الله سے ڈر اور تو اپنے دل میں ایک چیز چھپاتا تھا جسے الله ظاہر کرنے والا تھا اور تو لوگوں سے ڈرتا تھا حالانکہ الله زیادہ حق رکھتا ہے کہ تو اس سے ڈرے پھر جب زید اس سے حاجت پوری کر چکا تو ہم نے تجھ سے اس کا نکاح کر دیا تاکہ مسلمانوں پر ان کے منہ بولے بیٹوں کی بیویوں کے بارے میں کوئی گناہ نہ ہو جب کہ وہ ان سے حاجت پوری کر لیں اور الله کا حکم ہوکر رہنے والا ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxi{نبی پر اس بات میں کوئی گناہ نہیں ہے جو الله نے اس اس کے لیے مقرر کر دی ہے جیسا کہ الله کا پہلے لوگو ں میں دستور تھا اور الله کا کام اندازے پر مقرر کیا ہوا ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxii{جو لوگ الله کا پیغام پہنچاتے رہے اور الله سے ڈرتے رہے اور الله حساب لینے والا کافی ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxiii{محمد تم میں سے کسی مرد کے باپ نہیں لیکن وہ الله کے رسول اور سب نبیوں کے خاتمے پر ہیں اور الله ہر بات جانتا ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxiv{اے ایمان والو الله کو بہت یاد کرو\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxv{اور اس کی صبح و شام پاکی بیان کرو\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxvi{وہی ہے جو تم پر رحمت بھیجتا ہے اور اس کے فرشتے بھی تاکہ تمہیں اندھیروں سے روشنی کی طرف نکالے اور وہ ایمان والوں پر نہایت رحم والا ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxvii{جس دن وہ اس سے ملیں گے ان کے لیے سلام کا تحفہ ہوگا اور ان کے لیے عزت کا اجر تیار کر رکھا ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxviii{اے نبی ہم نے آپ کو بلاشبہ گواہی دینے والا اور خوشخبری دینے والا اور ڈرانے والا بنا کر بھیجا ہے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxix{اور الله کی طرف اس کے حکم سے بلانے اور چراغ روشن بنایا ہے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxx{اور ایمان والوں کو خوشخبری دے اس بات کی کہ ان کے لیے الله کی طرف سے بہت بڑا فضل ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxi{اور کفار اور منافقین کا کہنا نہ مانیے اور ان کی ایذا رسانی کی پرواہ نہ کیجیے اور الله پر بھروسہ کیجیئے اور الله کارساز کافی ہے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxii{اے ایمان والو جب تم مومن عورتوں سے نکاح کرو پھر انہیں طلاق دے دو اس سے پہلے کہ تم انہیں چھوو تو تمہارے لیے ان پر کوئی عدت نہیں ہے کہ تم ان کی گنتی پوری کرنے لگو سو انہیں کچھ فائدہ دو اور انہیں اچھی طرح سے رخصت کر دو\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxiii{اے نبی ہم نے آپ کے لیے آپ کی بیویاں حلال کر دیں جن کے آپ مہر ادا کر چکے ہیں اور وہ عورتیں جو تمہاری مملومکہ ہیں جو الله نے آپ کو غنیمت میں دلوادی ہیں اور آپ کے چچا کی بیٹیاں اور آپ کی پھوپھیوں کی بیٹیاں اور آپ کے ماموں کی بیٹیاں اور آپ کے خالاؤں کی بیٹیاں جنہوں نے آپ کے ساتھ ہجرت کی اور اس مسلمان عورت کو بھی جو بلاعوض اپنے کوپیغمبر کو دے دے بشرطیکہ پیغمبر اس کو نکاح میں لانا چاہے یہ خالص آپ کے لیے ہے نہ اور مسلمانوں کے لیے ہمیں معلوم ہے جو کچھ ہم نے مسلمانو ں پر ان کی بیویوں اور لونڈیوں کے بارے میں مقرر کیا ہے تاکہ آپ پر کوئی دِقت نہ رہے اور الله معاف کرنے والا مہربان ہے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxiv{آپ ان میں سے جسے چاہیں چھوڑ دیں اور جسے چاہیں اپنے پاس جگہ دیں اور ان میں سے جسے آپ چاہیں جنہیں آپ نے علیحدہ کر دیا تھا تو آپ پر کوئی گناہ نہیں یہ اس سے زیادہ قریب ہے کہ ان کی آنکھیں ٹھنڈی ہوں اور غمزدہ نہ ہو اور ان سب کو جو آپ دیں اس پر راضی ہوں اور جو کچھ تمہارے دلوں میں ہے الله جانتا ہے اورالله جاننے والا بردبار ہے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxv{اس کے بعد آپ کے لیے عورتیں حلال نہیں اور نہ یہ کہ آپ ان سےاورعورتیں تبدیل کریں اگر چہ آپ کو ان کا حسن پسند آئے مگر جو آپ کی مملوکہ ہوں اور الله ہر ایک چیز پر نگران ہے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxvi{اے ایمان والو نبی کے گھروں میں داخل نہ ہو مگر اس وقت کہ تمہیں کھانے کےلئے اجازت دی جائے نہ اس کی تیاری کا انتظام کرتے ہوئے لیکن جب تمہیں بلایا جائے تب داخل ہو پھر جب تم کھا چکو تو اٹھ کر چلے جاؤ اور باتوں کے لیے جم کر نہ بیٹھو کیوں کہ اس سے نبی کو تکلیف پہنچتی ہے اور وہ تم سے شرم کرتا ہے اور حق بات کہنے سے الله شرم نہیں کرتا اور جب نبی کی بیویوں سے کوئی چیز مانگو تو پردہ کے باہر سے مانگا کرو اس میں تمہارے اوران کے دلوں کے لیے بہت پاکیزگی ہے اور تمہارے لیے جائز نہیں کہ تم رسول الله کو ایذا دو اور نہ یہ کہ تم اپ کی بیویوں سے آپ کے بعد کبھی بھی نکاح کرو بے شک یہ الله کےنزدیک بڑا گناہ ہے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxvii{اگر تم کوئی بات ظاہر کرو یا اسے چھپاؤ تو بے شک الله ہر چیز کو جاننے والا ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxviii{ان پر اپنے باپوں کے سامنے ہونے میں کوئی گناہ نہیں اور نہ اپنے بیٹوں کے اور نہ اپنے بھائیوں کے اور نہ اپنے بھتیجوں کے اورنہ اپنے بھانجوں کے اور نہ اپنی عورتوں کے اور نہ اپنے غلاموں کے اور الله سے ڈرتی رہو بے شک ہر چیز الله کے سامنے ہے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxix{بے شک الله اور اس کے فرشتے نبی پر درود بھیجتے ہیں اے ایمان والو تم بھی اسپر دورد اور سلام بھیجو\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmdxc{جو لوگ الله اور اس کے رسول کو ایذا دیتے ہیں ان پر اللهنے دنیا اور آخرت میں لعنت کی ہے اور ان کے لیے ذلت کا عذاب تیار کر کھا ہے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmdxci{اور جو ایمان دار مردوں اور عورتوں کو ناکردہ گناہوں پر ستاتے ہیں سو وہ اپنے سر بہتان اور صریح گناہ لیتے ہیں\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmdxcii{اے نبی اپنی بیویوں اور بیٹیوں اور مسلمانوں کی عورتوں سے کہہ دو کہ اپنے مونہوں پر نقاب ڈالا کریں یہ اس سے زیادہ قریب ہے کہ پہچانی جائیں پھر نہ ستائی جائیں اور الله بخشنے والا نہایت رحم والا ہے\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmdxciii{اگر منافق اور وہ جن کے دلوں میں مرض ہے اور مدینہ میں غلط خبریں اڑانے والے باز نہ آئیں گے تو آپ کوہم ان کے پیچھے لگا دیں گے پھر وہ اس شہر میں تیرے پاس نہ ٹھیریں گے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmdxciv{مگر بہت کم لعنت کیے گئے ہیں جہاں کہیں پائیں جائیں گے پکڑے جائیں گے اور قتل کیے جائیں گے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmdxcv{یہی الله کا قانون ہے ان لوگو ں میں جو اس سے پہلے ہو گزر چکے ہیں اور آپ الله کے قانون میں کوئی تبدیلی ہرگز نہ پائیں گے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmdxcvi{آپ سے لوگ قیامت کے متعلق پوچھتے ہیں کہہ دو اس کا علم تو صرف الله ہی کو ہے اور اپ کو کیا خبر کہ شاید قیامت قریب ہی ہو\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmdxcvii{بے شک الله نے کافروں پر لعنت کی ہے اور ان کے لیے دوزخ تیار کر رکھا ہے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmdxcviii{وہ اس میں ہمیشہ رہیں گے نہ کوئی دوست پائیں گے اور نہ کوئی مددگار\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmdxcix{جس دن ان کے منہ آگ میں الٹ دیے جائیں گے کہیں گے اے کاش ہم نے الله اور رسول کا کہا مانا ہوتا\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmdc{اور کہیں گے اے ہمارے رب ہم نے اپنے سرداروں اوربڑوں کا کہا مانا سو انہوں نے ہمیں گمراہ کیا\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmdci{اے ہمارے رب انہیں دگنا عذاب دے اور ان پر بڑی لعنت کر\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmdcii{اے ایمان والو تم ان لوگو ں جیسے نہ ہوجاؤ جنہوں نے موسیٰ کو ستایا پھر الله نے موسیٰ کو ان کی باتوں سے بری کر دیا اور وہ الله کے نزدیک بڑی عزت والا تھا\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmdciii{اے ایمان والو الله سے ڈرو اور ٹھیک بات کیا کرو\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmdciv{تاکہ وہ تمہارے اعمال کو درست کرے اور تمہارے گناہ معاف کر دے اور جس نے الله اور اس کے رسول کا کہنا مانا سو اس نے بڑی کامیابی حاصل کی\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmdcv{ہم نے آسمانوں اور زمین اور پہاڑوں کے سامنے امانت پیش کی پھر انہوں نے اسکے اٹھانے سے انکار کر دیا اور اس سے ڈر گئے اور اسے انسان نے اٹھا لیا بے شک وہ بڑا ظالم بڑا نادان تھا\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmdcvi{تاکہ الله منافق مردوں اور منافق عورتوں اورمشرک مردوں اورمشرک عورتوں کو عذاب دے اور مومن مردوں اورمومن عورتوں پر مہربانی کرے اور الله معاف کرنے والا مہربان ہے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmdcvii{\basmalahur سب تعریف الله ہی کے لیے ہے جو کچھ آسمانوں اور زمین میں ہے سب اسی کا ہے اور آخرت میں بھی اسی کے لیے سب تعریف ہے اور وہ حکمت والا خبردار ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmdcviii{وہ جانتا ہے جو زمین میں داخل ہوتا ہے اور جو اس میں سے نکلتا ہے اور جو آسمان سے نازل ہوتا ہے اور جو اس میں چڑھتا ہے اور وہ نہایت رحم والا بخشنے والا ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmdcix{اور کافر کہتے ہیں کہ ہم پر قیامت نہیں آئے گی کہہ دو ہاں (آئے گی) قسم ہے میرے رب غائب کے جاننے والے کی البتہ تم پر ضرور آئے گی جس سے آسمانوں اور زمین کی کوئی چیز ذرّہ کے برابر بھی غائب نہیں اور نہ ذرّہ سے چھوٹی اور نہ بڑی کوئی بھی ایسی چیز نہیں جو لوح محفوظ میں نہ ہو\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmdcx{تاکہ الله ان لوگوں کو جزا دے جو ایمان لائے اور انہوں نے نیک عمل کیے انہیں کے لیے بخشش اور عزت والا رزق ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmdcxi{اور جو ہماری آیتوں کے رد کرنے میں کوشش کرتے پھرتے ہیں ان کے لیے ذلت کا عذاب ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmdcxii{اور جنہیں علم دیا گیا ہے وہ خیال کرتے ہیں کہ جو کچھ آپ کی طرف آپ کے رب کی طرف سے نازل ہوا ہے وہ ٹھیک ہے اور وہ غالب تعریف کئےہوئے کی راہ دکھاتا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmdcxiii{اور کافر کہتے ہیں کیا ہم تمہیں وہ آدمی بتائیں جو تمہیں خبر دیتا ہے کہ جب تم پورے طور پر ریزہ ریزہ ہو جاؤ گے تو پھر نئے سرے سے پیدا کیے جاؤ گے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmdcxiv{کیا اس نے الله پر جھوٹ بنا لیا ہے یا اسے جنون ہے نہیں بلکہ جو لوگ آخرت پر یقین نہیں رکھتے وہ عذاب اور دور کی گمراہی میں ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmdcxv{کیا وہ آسمان اور زمین کو نہیں دیکھتے جو ان کے آگے اور پیچھے ہے اگر ہم چاہیں تو انہیں زمین میں دھنسا دیں یا ان پر کوئی آسمان کا ٹکڑا گرا دیں الله کی طرف رجوع کرنے والے بندے کے لیے اس میں بڑی نشانیاں ہیں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmdcxvi{اور بے شک ہم نے داؤد کو اپنی طرف سے بزرگی دی تھی اے پہاڑو ان کی تسبیح کی آواز کا جواب دیا کرو اور پرندوں کو تابع کر دیا تھا اور ہم نے ان کے لیے لوہا نرم کر دیا تھا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmdcxvii{کہ کشادہ زرہیں بنا اور اندازے سے کڑیاں جوڑ اور تم سب نیک کام کرو بے شک میں جو تم کرتے ہو خوب دیکھ رہا ہوں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmdcxviii{اور ہوا کو سلیمان کے تابع کر دیا تھا جس کی صبح کی منزل مہینے بھر کی راہ اور شام کی منزل مہینے بھر کی راہ تھی اور ہم نے اس کے لیے تانبے کا چشمہ بہا دیا تھا اور کچھ جن اس کے آگے اس کے رب کے حکم سے کام کیا کرتے تھے اور جو کوئی ان میں سے ہمارے حکم سے پھر جاتا تھاتو ہم اسے آگ کا عذاب چکھاتے تھے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmdcxix{جو وہ چاہتا اس کے لیے بناتے تھے قلعے اور تصویریں اور حوض جیسے لگن اور جمی رہنے والی دیگیں اے داؤد والو تم شکریہ میں نیک کام کیا کرو اور میرے بندوں میں سے شکر گزار تھوڑے ہیں\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmdcxx{پھر جب ہم نے اس پر موت کا حکم کیا تو انہیں ا سکی موت کا پتہ نہ دیا مگر گھن کے کیڑے نے جو اس کے عصا کو کھا رہا تھا پھر جب گر پڑا تو جنوں نے معلوم کیا کہ اگر وہ غیب کو جانتے ہوتے تو اس ذلت کے عذاب میں نہ پڑے رہتے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxi{بے شک قوم سبا کے لیے ان کی بستی میں ایک نشان تھا دائیں اور بائیں دو باغ اپنے رب کی روزی کھاؤ اور اس کا شکر کرو عمدہ شہر رہنے کو اور بخشنے والا رب\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxii{پھر انہوں نے نافرمانی کی پھر ہم نے ان پر سخت سیلاب بھیج دیا اور ہم نے ان کے دونوں باغوں کے بدلے میں دو باغ بد مزہ پھل کے اور جھاؤ کے اور کچھ تھوڑی سی بیریوں کے بدل دیے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxiii{یہ ہم نے ان کی ناشکری کا بدلہ دیا اور ہم ناشکروں ہی کو برا بدلہ دیا کرتے ہیں\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxiv{اورہم نے ان کے اور ان بستیوں کے درمیان جن میں ہم نے برکت رکھی تھی بہت سے گاؤں آباد کر رکھے تھے جو نظر آتے تھے اور ہم نے ان میں منزلیں مقرر کر دیں تھیں ان میں راتوں اور دنوں کو امن سے چلو\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxv{پھر انہوں نے کہا اے ہمارے رب ہماری منزلوں کو دور دور کردےا ور انہوں نے اپنی جانوں پر ظلم کیا سو ہم نے انہیں کہانیاں بنا دیا اور ہم نے انہیں پورے طور پر پارہ پارہ کر دیا بے شک اس میں ہر ایک صبر شکرکرنے والے کے لیے نشانیاں ہیں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxvi{اور البتہ شیطان نے ان پر اپنا گمان سچ کر دکھایا سوائے ایمان داروں کے ایک گروہ کے سب اس کے تابع ہو گئے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxvii{حالانکہ ان پر اس کا کوئی زور بھی نہیں تھا مگر یہی کہ ہم نے ظاہر کرنا تھا کون آخرت پر ایمان لاتا ہے اورکون اس سے شک میں پڑا ہوا ہے اور تیرا رب ہر چیز پر نگہبان ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxviii{کہہ دوالله کے سوا جن کا تمہیں گھمنڈ ہے انہیں پکارو وہ نہ تو آسمان ہی میں ذرّہ بھر اختیار رکھتے ہیں اور نہ زمین میں اور نہ ان کا ان میں کچھ حصہ ہے اور نہ ان میں سے الله کا کوئی مددکار ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxix{اور اس کے ہاں سفارش نفع نہ دے گی مگر اسی کو جس کے لیے وہ اجازت دے گا یہاں تک کہ جب ان کے دل سے گھبراہٹ دور ہوجاتی ہے کہتے ہیں تمہارے رب نے کیا فرمایا وہ کہتے ہیں سچی بات فرمائی اوروہی عالیشان اور سب سے بڑا ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxx{کہہ دو تمہیں آسمانوں اور زمین سے کون رزق دیتا ہے کہو الله اور بے شک ہم یا تم ہدایت پر ہیں یا صریح گمراہی میں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxi{کہہ دو نہ تم پوچھے جاؤ گے اس کی نسبت جو ہم نے جرم کیا ہے اور نہ ہم ہی پوچھیں جائیں گے ا سکی بابت جو تم کرتے ہو\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxii{کہہ دو ہم سب کو ہمارا رب جمع کرے گا پھر ہمارے درمیان انصاف سے فیصلہ کرے گا اور وہی فیصلہ کرنے والا جاننے ولا ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxiii{کہہ دو جنہیں تم نے اس سے شریک بنا کر ملا رکھا ہے مجھے بھی تو دکھاؤ بلکہ وہی الله غالب حکمت والا ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxiv{اور ہم نے آپ کو جو بھیجا ہے تو صرف سب لوگوں کو خوشی اور ڈر سنانے کے لیے لیکن اکثر لوگ نہیں جانتے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxv{اور کہتے ہیں یہ وعدہ کب ہے اگر تم سچے ہو\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxvi{کہہ دو تمہارے لیے ایک دن کا وعدہ ہے کہ جس سے نہ ایک گھڑی پیچھے ہو سکتے ہو اور نہ آگے بڑھ سکتے ہو\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxvii{اور کافر کہتے ہیں ہم اس قرآن پر ہرگز ایمان نہیں لائیں گے اور نہ اس پر جو اس سے پہلے موجود ہے اورکاش آپ دیکھتے جب کہ ظالم اپنے رب کے حضور میں کھڑے کیے جائیں گے ایک ان میں سے دوسرے کی بات کو رد کر رہا ہوگا جو لوگ کمزور سمجھے جاتے تھے وہ ان سے کہیں گے جو بڑے بنتے تھے اگر تم نہ ہوتے تو ہم ایمان دار ہوتے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxviii{جو لوگ بڑے بنتے تھے ان سے کہیں گے جو کمزور سمجھے جاتے تھے کیا ہم نے تمہیں ہدایت سے روکا تھا بعد اس کے کہ وہ تمہارے پاس آ چکی تھی بلکہ تم خود ہی مجرم تھے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxix{اورجو لوگ کمزور سمجھے جاتے تھے وہ ان سے کہیں گے جو متکبر تھے بلکہ (تمہارے) رات اور دن کے فریب نے جب تم ہمیں حکم دیا کرتے تھے کہ ہم الله کا انکار کر دیں اوراس کے لیے شریک ٹھیرائیں اور دل میں بڑے پشیمان ہوں گے جب عذاب کو سامنے دیکھیں گے اورکافروں کی گردنوں میں ہم طوق ڈالیں گے جو کچھ وہ کیا کرتے تھے اسی کا تو بدلہ پا رہے ہیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmdcxl{اور ہم نے جس کسی بستی میں کوئی ڈرانے والا بھیجا تو وہاں کے دولتمندوں نے یہی کہا کہ تم جو لے کر آئے ہو ہم نہیں مانتے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmdcxli{اور یہ بھی کہا کہ ہم مال اوراولاد میں تم سے بڑھ کر ہیں اور ہمیں کوئی عذاب نہ دیا جائے گا\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmdcxlii{کہہ دو میرا رب جس کے لیے چاہتا ہے روزی کشادہ کر دیتا ہے اور کم کر دیتا ہے اور لیکن اکثر آدمی نہیں جانتے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmdcxliii{اور تمہاے مال اور اولاد ایسی چیز نہیں جو تمہیں مرتبہ میں ہمارے قریب کر دے مگر جو ایمان لایا اور نیک کام کیے پس وہی لوگ ہیں جن کے لئے دگنا بدلہ ہے اس کا جو انہوں نے کیا اور وہی بالاخانوں میں امن سے ہوں گے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmdcxliv{اوروہ جو ہماری آیتوں کے رد کرنے میں کوشش کرتے ہیں وہ عذاب میں پکڑ کر حاضر کیے جائیں گے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmdcxlv{کہہ دو بے شک میرا رب ہی اپنے بندو ں میں سے جسے چاہے روزی کشادہ کر دیتا ہے اور جسے چاہے تنگ کر دیتا ہے اور جو کوئی چیز بھی تم خرچ کرتے ہو سو وہی اس کا عوض دیتا ہے اور وہ سب سے بہتر روزی دینے والا ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmdcxlvi{اور جس دن وہ ان سب کو جمع کرے گا پھر فرشتوں سے فرمائے گا کیا یہی ہیں جو تمہاری عبادت کیا کرتے تھے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmdcxlvii{وہ عرض کریں گے تو پاک ہے ہماراتو تجھ سے ہی تعلق ہے نہ ان سے بلکہ یہ شیطانوں کی عبادت کرتے تھے ان میں سے اکثر انہیں کے معتقد تھے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmdcxlviii{پھر آج تم میں سے کوئی کسی کے نفع اور نقصان کا مالک نہیں اور ہم ظالموں سے کہیں گے تم اس آگ کا عذاب چکھو جسے تم جھٹلایا کرتے تھے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmdcxlix{اور جب انہیں ہماری واضح آیتیں سنائی جاتی ہیں تو کہتے ہیں کہ یہ محض ایسا شخص ہے جو چاہتا ہے کہ تمہیں ان چیزوں سے رو ک دے جنہیں تمہارے باپ دادا پوجتے تھے اور (قرآن کی نسبت) کہتے ہیں کہ یہ محض ایک تراشا ہوا جھوٹ ہے اورکافروں نے حق کے متعلق کہا جب ان کے پاس آیا کہ یہ محض ایک صریح جادو ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmdcl{اورہم نے انہیں کوئی کتاب نہیں دی کہ وہ اسے پڑھتے ہوں اور ہم نے ان کی طرف آپ سے پہلے کوئی ڈرانے والا نہیں بھیجا\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmdcli{اوران لوگوں نے بھی جھٹلایا جو ان سے پہلے تھے اور یہ لوگ اس کے دسویں حصہ کونہیں پہنچے جو ہم نے انہیں دیا تھا پس انہوں نے میرے رسولوں کو جھٹلایا پھر میرا کیسا عذاب ہوا\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmdclii{کہہ دو میں تمہیں ایک بات نصیحت کرتا ہوں کہ تم الله کے لیے دو دو ایک ایک کھڑے ہو کر غور کرو کہ تمہارے اس ساتھی کو جنون تو نہیں ہے وہ تمہیں ایک سخت عذاب آنے سے پہلے ڈرانے والا ہے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmdcliii{کہہ دو اس پر جو اجرات میں نے تم سے مانگی ہو وہ تمہارے ہی پاس رہے میری مزدوری تو الله ہی پر ہے اوروہ ہر چیز پر گواہ ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmdcliv{کہہ دو میرا رب سچا دین برسا رہا ہے اور وہ چھپی ہوئی چیزوں کو خوب جانتا ہے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmdclv{کہہ دو حق آ گیا ہے اور جھوٹے معبود نہ پہلی بار پیدا کرتے ہیں اور نہ دوبارہ پیدا کریں گے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmdclvi{کہہ دو اگر میں غلط راستہ پر ہوں تو میری غلطی کا وبال مجھ ہی پر ہوگا اور اگر میں سیدھی راہ پر ہو ں تو ا سلیے کہ میرا رب میری طرف وحی کرتا ہے بے شک وہ سننے والا قریب ہے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmdclvii{اورکاش آپ دیکھیں جب کہ وہ گھبرائےہوئے ہوں گے پس نہ بچ سکیں گے اور پا س ہی سے پکڑ لیے جائیں گے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmdclviii{اور کہیں گے ہم اس (قرآن) پرایمان لے آئے ہیں اور اتنی دور سے (ایمان کا) ان کے ہاتھ آناکہاں ممکن ہے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmdclix{حالانکہ پہلے تو اس کا انکار کرتے رہے اور بے تحقیق باتیں دور ہی دور سے ہانکا کرتے تھے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmdclx{اور ان میں اور ان کی خواہش میں آڑ کر دی جائے گی جیسا کہ ان کے ہم خیال لوگوں کے ساتھ اس سے پہلے کیا گیا بے شک وہ بھی حیرت انگیز شک میں پڑے ہوئے تھے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmdclxi{\basmalahur سب تعریف الله کے لیے ہے جو آسمانوں اور زمین کا بنانے والا ہے فرشتوں کو رسول بنانے والا ہے جن کے دو دو تین تین چار چار پر ہیں وہ پیدائش میں جو چاہے زیادہ کر دیتا ہے بے شک الله ہر چیز پر قادر ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmdclxii{الله بندوں کے لیے جو رحمت کھولتا ہے اسے کوئی بند نہیں کر سکتا اور جسے وہ بند کر دے تو اس کے بعد کوئی کھولنے والا نہیں اور وہ زبردست حکمت والا ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmdclxiii{اے لوگو الله کے اس احسان کو یاد کرو جو تم پر ہے بھلا الله کے سوا کوئی اور بھی خالق ہے جو تمہیں آسمان اور زمین سے روزی دیتا ہو اس کے سوا اور کوئی معبود نہیں پھر کہاں الٹے جا رہے ہو\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmdclxiv{اور اگر وہ آپ کو جھٹلائیں تو آپ سے پہلے بھی کئی رسول جھٹلائے گئے اور الله ہی کی طرف سب کام لوٹائے جاتے ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmdclxv{اے لوگو بے شک الله کا وعدہ سچا ہے پھر تمہیں دنیا کی زندگی دھوکے میں نہ ڈالے اور تمہیں الله کے بارے میں دھوکہ باز دھوکا نہ دے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmdclxvi{بے شک شیطان تو تمہارا دشمن ہے سو تم بھی اسے دشمن سمجھو وہ تو اپنی جماعت کو بلاتا ہے تاکہ وہ دوزخیوں میں سے ہو جائیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmdclxvii{جن لوگوں نے انکار کیا ان کے لیے سخت عذاب ہے اور جو ایمان لائے اورنیک عمل کیے انہیں کے لیے بخشش اور بڑا اجر ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmdclxviii{بھلا جس کے برے کام بھلے کر دکھائے ہوں پھر وہ ان کو اچھا بھی جانتا ہو (نیک کے برابر ہو سکتا ہے) پھرالله جس کو چاہتا ہے گمراہ کر تا ہے اور جسے چاہتاہے ہدایت کرتا ہے پھر آپ ان پر افسوس کھا کھا کر ہلاک نہ ہوجائیں کیوں کہ الله خوب جانتا ہے جو وہ کر رہے ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmdclxix{اور الله ہی وہ ہے جوہوائیں چلاتا ہے پھروہ بادل اٹھاتی ہیں پھر ہم اسے مرے ہوئے شہروں کی طرف چلاتے ہیں پھر ہم اس سے زمین کو مرنے کے بعد زندہ کرتے ہیں اسی طرح دوبارہ اٹھایا جانا ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmdclxx{جو شخص عزت چاہتا ہو سو الله ہی کے لیے سب عزت ہے اسی کی طرف سب پاکیزہ باتیں چڑھتی ہیں اور نیک عمل اس کو بلند کرتا ہے اور جو لوگ بری تدبیریں کرتے ہیں انہی کے لیے سخت عذاب ہے اوران کی بری تدبیر ہی برباد ہو گی\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxi{اور الله ہی نے تمہیں مٹی سے پیدا کیا پھر نطفہ سے پھر تمہیں جوڑے بنایا اور کوئی مادہ حاملہ نہیں ہو تی اور نہ وہ جنتی ہے مگر اس کے علم سے اور نہ کوئی بڑی عمر والا عمر دیا جاتا ہے اور نہ اس کی عمر کم کی جاتی ہے مگر وہ کتاب میں درج ہے بے شک یہ بات الله پر آسان ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxii{اور دو سمندر برا بر نہیں ہوتے یہ ایک میٹھا پیاس بجھانے والا ہے کہ ا سکا پینا خوشگوار ہے اور یہ دوسرا کھاری کڑوا ہے اور ہر ایک میں سے تم تازہ گوشت کھاتے ہو اور زیور نکالتے ہو جو تم پہنتے ہو اور تو جہازوں کو دیکھتا ہے کہ اس میں پانی کو پھاڑتے جاتے ہیں تاکہ تم اس کا فضل تلاش کرو اور تاکہ اس کا شکر کرو\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxiii{وہ رات کو دن میں داخل کرتا ہے اور دن کو رات میں داخل کرتا ہے اور اسی نے سورج اور چاند کو کام میں لگا رکھا ہے ہر ایک وقت مقرر تک چل رہا ہے یہی الله تمہارا رب ہے اسی کی بادشاہی ہے اور جنہیں تم اس کے سوا پکارتے ہو وہ ایک گھٹلی کے چھلکے کے مالک نہیں\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxiv{اگر تم انہیں پکارو تو وہ تمہاری پکار کو نہیں سنتے اور اگر وہ سن بھی لیں تو تمہیں جواب نہیں دیتے اور قیامت کے دن تمہارے شرک کا انکار کر دیں گے اور تمہیں خبر رکھنے والے کی طرح کوئی نہیں بتائے گا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxv{اے لوگو تم الله کی طرف محتاج ہواور الله بے نیاز تعریف کیا ہوا ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxvi{اگر وہ چاہے تو تمہیں لے جائے اور نئی مخلوق لے آئے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxvii{اور یہ بات الله تعالیٰ پر کچھ مشکل نہیں\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxviii{اور کوئی بوجھ اٹھانے والا دوسرے کا بوجھ نہیں اٹھائے گا اور اگر کوئی بوجھ والا اپنے بوجھ کی طرف بلائے گا تو اس کے بوجھ میں سے کچھ بھی اٹھایا نہ جائے گا اگرچہ قریبی رشتہ داری ہو بے شک آپ انہیں لوگوں کو ڈراتے ہیں جو بن دیکھے اپنے رب سے ڈرتے ہیں اور نماز قائم کرتے ہیں اور جو پاک ہوتا ہے سو وہ اپنے ہی لیے پا ک ہوتا ہے اور الله ہی کی طرف لوٹ کر جانا ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxix{اور اندھا اور دیکھنے والا برابر نہیں ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxx{اور نہ اندھیرے اور نہ روشنی\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxi{اور نہ سایہ اور نہ دھوپ\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxii{اور زندے اور مردے برابر نہیں ہیں بے شک الله سناتا ہے جسے چاہے اور آپ انہیں سنانے والے نہیں جو قبروں میں ہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxiii{نہیں ہیں آپ مگر ڈرانے والے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxiv{بے شک ہم نے آپ کو سچا دین دے کر خوشخبری اور ڈرانے والا بنا کر بھیجا ہے اور کوئی امت نہیں گزری مگر اس میں ایک ڈرانے والا گزر چکا ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxv{اور اگر وہ آپ کو جھٹلائیں تو ان لوگوں نے بھی جھٹلایا ہے جو ان سے پہلے ہوئے ان کے پاس ان کے رسول واضح دلیلیں اور صحیفے اور کتاب روشن لے کر آئے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxvi{پھرمیں نے انہیں پکڑا جومنکر ہوئے پھر میرا عذاب کیسا ہوا\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxvii{کیا تو نے نہیں دیکھا کہ الله ہی آسمان سے پانی اتارتا ہے پھر ہم اس کےذریعے سے پھل نکالتے ہیں جن کے رنگ مختلف ہوتے ہیں اور پہاڑو ں میں مختلف رنگتو ں کے کچھ تو سفید اور کچھ سرخ اور بہت سیاہ بھی ہیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxviii{اور اسی طرح آدمیوں اور زمین پر چلنے والے جانوروں اور چوپایوں کے بھی مختلف رنگ ہیں بے شک الله سے اس کے بندوں میں سے عالم ہی ڈرتے ہیں بے شک الله غالب بخشنے والا ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxix{بے شک جو لوگ الله کی کتاب پڑھتے ہیں اور نماز قائم کرتے ہیں اور پوشیدہ اور ظاہر اس میں سے خرچ کرتے ہیں جو ہم نے انہیں دیا ہے وہ ایسی تجارت کے امیدوار ہیں کہ اس میں خسارہ نہیں\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmdcxc{تاکہ الله انہیں ان کے اجر پورے دے اور انہیں اپنے فضل سے زیادہ دےبے شک وہ بخشنے والا قدردان ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmdcxci{اور وہ کتاب جو ہم نے آپ کی طرف وحی کی ہے وہ ٹھیک ہے ا س کتاب کی تصدیق کرنے والی ہے جو اس سے پہلے آ چکی بے شک الله اپنے بندو ں سے باخبر دیکھنے والا ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmdcxcii{پھر ہم نے اپنی کتاب کا ان کو وارث بنایا جنہیں ہم نے اپنے بندوں میں سے چن لیا پس بعض ان میں سے اپنے نفس پرظلم کرنے والے ہیں اور بعض ان میں سے میانہ رو ہیں اور بعض ان میں سے الله کے حکم سے نیکیوں میں پیش قدمی کرنے والے ہیں یہی تو الله کا بڑا فضل ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmdcxciii{ہمیشہ رہنے کے باغ ہیں وہ ان میں داخل ہوں گے انہیں وہاں سونے کے کنگن اورموتی پہنائیں جائیں گے اور اس میں ان کا لباس ریشم کا ہوگا\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmdcxciv{اور وہ کہیں گے الله کا شکر ہے جس نے ہم سے غم دور کر دیا بے شک ہمارا رب بخشنے والا قدردان ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmdcxcv{وہ جس نے اپنے فضل سے ہمیں سدا رہنے کی جگہ میں اتارا جہاں ہمیں نہ کوئی رنج پہنچتا ہے اور نہ کوئی تکلیف\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmdcxcvi{اورجو منکر ہو گئے ان کے لیے دوزخ کی آگ ہے نہ ان پر قضا آئے گی کہ مرجائیں اور نہ ہی ان سے اس کا عذاب ہلکا کیا جائے گا اس طرح ہم ہر ناشکرے کو سزا دیا کرتے ہیں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmdcxcvii{اوروہ اس میں چلائیں گے کہ اے ہمارے رب ہمیں نکال ہم نیک کام کریں برخلاف ان کاموں کے جو کیا کرتے تھے کیا ہم نےتمہیں اتنی عمر نہیں دی تھی جس میں سمجھنے والا سمجھ سکتا تھا اور تمہارے پاس ڈرانے والا آیا تھا پس مزہ چکھو پس ظالموں کا کوئی مددگار نہیں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmdcxcviii{بے شک الله آسمانوں اور زمین کے غیب جانتا ہے بے شک وہ سینوں کے بھید خوب جانتا ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmdcxcix{وہی ہے جس نے تمہیں زمین میں قائم مقام بنایا پس جو کفر کرے گا اس کے کفر کا وبال اسی پر ہوگا اور کافروں کا کفر ان کے رب کے ہاں ناراضگی کے سوا اور کچھ نہیں زیادہ کرتا\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmdcc{کہہ دو کیا تم نے اپنے ان معبودو ں کو بھی دیکھا جنہیں تم الله کےسوا پکارتے ہو وہ مجھے دکھاؤ کہ انہوں نے زمین میں کیاپیداکیا ہے یا ان کا کچھ حصہ آسمانوں میں بھی ہے یا انہیں ہم نے کوئی کتاب دی ہے کہ وہ اس کی سند رکھتے ہیں (نہیں) بلکہ ظالم آپس میں ایک دوسرے کو دھوکہ دیتے ہیں\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmdcci{بے شک الله ہی آسمانوں اور زمین کو تھامے ہوئے ہے اس سے کہ وہ اپنی جگہ سے ٹل جائیں اور اگر وہ دونوں اپنی جگہ سے ہٹ جائیں تو ان کو کوئی بھی اس کے بعد روک نہیں سکتا بے شک وہ بردبار بخشنے والا ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmdccii{اوروہ الله کی پختہ قسمیں کھاتے تھے اگر ان کے پاس کوئی بھی ڈرانے والا آیا تو ہر ایک امت سے زیادہ ہدایت پر ہوں گے پھر جب ان کے پاس ڈرانے والا آیا تو اس سے ان کو اور بھی نفرت بڑھ گئی\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmdcciii{کہ ملک میں سرکشی اور بری تدبیریں کرنے لگ گئے اور بری تدبیر تو تدبیرکرنے والے ہی پر لٹ پڑتی ہے پھر کیا وہ اسی برتاؤ کے منتظر ہیں جو پہلے لوگوں سے برتا گیا پس تو الله کے قانون میں کوئی تبدیلی نہیں پائے گا اورتو الله کے قانوں میں کوئی تغیر نہیں پائے گا\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmdcciv{کیا انہوں نے زمین میں سیر نہیں کی کہ وہ دیکھتے ان لوگو ں کا کیسا برا انجام ہوا جو ان سے پہلے تھے اور وہ ان سے زیادہ طاقتور تھے اور الله ایسا نہیں ہے کہ اسے کوئی چیز آسمانوں میں اور نہ زمین میں عاجز کر دے بے شک وہ جاننے والا قدرت والا ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmdccv{اور اگر الله لوگوں سے ان کے اعمال پر گرفت کرتا تو سطح زمین پر کوئی جاندار نہ چھوڑتا لیکن وہ انہیں ایک وقت مقرر تک ڈھیل دیتا ہے پس جب ا نکا وقت مقرر آجائے گا تو بے شک الله اپنے بندوں کو خوب دیکھ رہا ہے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmdccvi{\basmalahur یسۤ\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmdccvii{قرآن حکمت والے کی قم ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmdccviii{بے شک آپ رسولوں میں سے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmdccix{سیدھے راستے پر\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmdccx{غالب رحمت والے کا اتارا ہوا ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmdccxi{تاکہ آپ اس قوم کو ڈرائیں جن کے باپ دادا نہیں ڈرائے گئے سو وہ غافل ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmdccxii{ان میں سے اکثر پر خدا کافرمان پورا ہو چکا ہے پس وہ ایمان نہیں لائیں گے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmdccxiii{بے شک ہم نے ان کی گردنوں میں طوق ڈال دیے ہیں پس وہ ٹھوڑیوں تک ہیں سو وہ اوپر کو سر اٹھائے ہوئے ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmdccxiv{اور ہم نے ان کے سامنے ایک دیواربنادی ہے اور ان کے پیچھے بھی ایک دیوارہے پھر ہم نے انہیں ڈھانک دیا ہے کہ وہ دیکھ نہیں سکتے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmdccxv{اور ان پر برابر ہے کیا آپ ان کو ڈرائیں یا نہ ڈرائیں وہ ایمان نہیں لائیں گے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmdccxvi{بے شک آپ اسی کو ڈرا سکتے ہیں جو نصیحت کی پیروی کرے اوربن دیکھے رحمان سے ڈرے پس خوشخبری دے دو اس کو بخشش اوراجر کی جو عزت والا ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmdccxvii{بے شک ہم ہی مردوں کو زندہ کریں گے اور جو انھوں نے آگے بھیجا اور جو پیچھے چھوڑا اس کو لکھتے ہیں اور ہم نے ہر چیز کو کتاب واضح (لوح محفوظ) میں محفوظ کر رکھا ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmdccxviii{اور ان سے بستی والوں کا حال مشال کے طور پر بیان کر جب کہ ان کے پاس رسول آئے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmdccxix{جب ہم نے ان کے پاس دو کو بھیجا انھوں نے ان کو جھٹلایا پھر ہم نے تیسرے سے مدد کی پھر انہوں نے کہا ہم تمہاری طرف بھیجے گئے ہیں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmdccxx{انہوں نے کہا تم کچھ اور نہیں ہو مگر ہماری طرح انسان ہو اور رحمان نے کوئی چیز نہیں اتاری تم اور کچھ نہیں ہو مگر جھوٹ بول رہے ہو\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxi{انہوں نے کہا ہمارا رب جانتا ہے کہ ہم تمہاری طرف بھیجے ہوئے ہیں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxii{اورہمارے ذمے کھلم کھلا پہنچا دینا ہی ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxiii{انہوں نے کہا ہم نے تو تمہیں منحوس سمجھا ہے اگر تم باز نہ آؤ گے توہم تمہیں سنگسار کر دیں گے اور تمہیں ہمارے ہاتھ سے ضرور دردناک عذاب پہنچے گا\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxiv{انہوں نے کہا تمہاری نحوست تو تمہارے ساتھ ہے کیا اگر تمہیں نصیحت کی جائے (تو اسے نحوست سمجھتے ہو) بلکہ تم حد سے بڑھنے والے ہو\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxv{اور شہر کے پرلے کنارے سے ایک آدمی دوڑتا ہوا آیا کہا اے میری قوم رسولوں کی پیروی کرو\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxvi{ان کی پیروی کرو جو تم سےکوئی اجر نہیں مانگتے اوروہ ہدایت پانے والے ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxvii{اور میرے لیے کیا ہے کہ میں اس کی عبادت نہ کروں جس نے مجھے پیدا کیا ہے اور اسی کی طرف تم لوٹائے جاؤ گے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxviii{کیا میں اس کے سوا اوروں کو معبود بناؤں کہ اگر رحمان مجھے تکلیف دینے کا ارادہ کرے تو ان کی سفارش کچھ بھی میرے کام نہ آئے اور نہ وہ مجھے چھڑا سکیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxix{بے شک تب میں صریح گمراہی میں ہوں گا\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxx{بے شک میں تمہارے رب پر ایمان لایا پس میری بات سنو\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxi{کہا گیا جنت میں داخل ہو جا اس نے کہا اے کاش! میری قوم بھی جان لیتی\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxii{کہ میرے رب نے مجھے بخش دیا اور مجھے عزت والوں میں کر دیا\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxiii{اور ہم نے اس کی قوم پر اس کے بعد کوئی فوج آسمان سے نہ اتاری اور نہ ہم اتارنے والے تھے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxiv{صرف ایک ہی چیخ تھی کہ جس سے وہ بجھ کر رہ گئے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxv{کیا افسوس ہے بندوں پر ان کے پاس ایساکوئی بھی رسول نہیں آیا جس سے انہوں نے ہنسی نہ کی ہو\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxvi{کیا یہ نہیں دیکھ چکے کہ ہم نے ان سے پہلے کتنی قوموں کو ہلاک کر دیا وہ ان کے پاس لوٹ کر نہیں آئے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxvii{اور سب کے سب ہمارے پاس حاضر ہیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxviii{اور ان کے لیے خشک زمین بھی ایک نشانی ہے جسے ہم نے زندہ کیا اور اس سے اناج نکالا جس سے وہ کھاتے ہیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxix{اور اس میں ہم نے کھجوروں اور انگوروں کے باغ بنائے اور ان میں چشمے جاری کیے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmdccxl{تاکہ وہ اس کے پھل کھائیں اور یہ چیزیں ان کے ہاتھوں کی بنائی ہوئی نہیں ہیں پھر کیوں شکر نہیں کرتے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmdccxli{وہ ذات پاک ہے جس نے زمین سے اگنے والی چیزوں کوگوناگوں بنایا اور خود ان میں سے بھی اور ان چیزوں میں سے بھی جنہیں وہ نہیں جانتے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmdccxlii{اور ان کے لیے رات بھی ایک نشانی ہے کہ ہم اس کے اوپرسے دن کو اتار دیتے ہیں پھر ناگہاں وہ اندھیرے میں رہ جاتے ہیں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmdccxliii{اور سورج اپنے ٹھکانے کی طرف چلتا رہتا ہے یہ زبردست خبردار کا اندازہ کیا ہوا ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmdccxliv{اور ہم نے چاند کی منزلیں مقرر کر دی ہیں یہاں تک کہ پرانی ٹہنی کی طرح ہوجاتا ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmdccxlv{نہ سورج کی مجال ہے ہ چاند کو جا پکڑے اور نہ رات ہی دن سے پہلے آ سکتی ہے اور ہر ایک ایک آسمان میں تیرتا پھرتا ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmdccxlvi{اور ان کے لیے یہ بھی نشانی ہے ہم نے ان کی نسل کوبھری کشتی میں سوار کیا\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmdccxlvii{اور ان کے لیے اسی طرح کی اور بھی چیزیں بنائی ہیں جن پر وہ سوار ہوتے ہیں\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmdccxlviii{اور اگر ہم چاہتے تو انہیں ڈبو دیتے پھر نہ ان کا کوئی فریاد رس ہوتا اور نہ وہ بچائے جاتے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmdccxlix{مگر یہ ہماری مہربانی ہے اور انہیں ایک مدت تک فائدہ دینا ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmdccl{اور جب ان سے کہا جاتا ہے کہ اپنے سامنے اور پیچھے آنے والے عذاب سے ڈرو تاکہ تم پر رحم کیا جائے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmdccli{اوران کے پاس ان کے رب کی نشانیوں میں سے ایسی کوئی بھی نشانی نہیں آتی جس سے وہ منہ موڑ لیتے ہوں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmdcclii{اور جب ان سے کہا جاتا ہےکہ الله کے رزق میں سے کچھ خرچ کیا کرو تو کافر ایمانداروں سے کہتے ہیں کیا ہم اسے کھلائیں گےکہ اگر الله چاہتا تو خود اسے کھلا سکتا تھا تم جو ہو تو صاف گمراہی میں پڑے ہوئے ہو\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmdccliii{اور کہتے ہیں یہ وعدہ کب ہوگا اگر تم سچے ہو\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmdccliv{وہ صرف ایک چیخ ہی کا انتظار کر رہے ہیں جو انہیں آ لے گی اور وہ آپس میں جھگڑ رہے ہوں گے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmdcclv{پس نہ تو وہ وصیت کر سکیں گے اور نہ اپنے گھر والوں کی طرف واپس جا سکیں گے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmdcclvi{اور صور پھونکا جائے گا تو وہ فوراً اپنی قبروں سے نکل کر اپنے رب کی طرف دوڑے چلے آئیں گے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmdcclvii{کہیں گے ہائے افسوس کس نے ہمیں ہماری خوابگاہ سے اٹھایا یہی ہے جو رحمان نے وعدہ کیا تھا اور رسولوں نے سچ کہا تھا\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmdcclviii{وہ تو صرف ایک ہی زور کی آواز ہو گی پھر وہ سب ہمارے سامنے حاضر کیے جائیں گے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmdcclix{پھر اس دن کسی پرکچھ بھی ظلم نہ کیا جائے گا اورتم اسی کا بدلہ پاؤ گے جو کیا کرتے تھے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmdcclx{بے شک بہشتی اس دن مزہ سے دل بہلا رہے ہوں گے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxi{وہ اوران کی بیویاں سایوں میں تختوں پر تکیہ لگائے ہوئے بیٹھے ہوں گے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxii{ان کے لیے وہاں میوہ ہوگا اور انہیں ملے گا جو وہ مانگیں گے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxiii{پروردگار نہایت رحم والے کی طرف سے انہیں سلام فرمایا جاوے گا\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxiv{اے مجرمو! آج الگ ہو جاؤ\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxv{اے آدم کی اولاد! کیا میں نے تمہیں تاکید نہ کر دی تھی کہ شیطان کی عبادت نہ کرنا کیونکہ وہ تمہارا صریح دشمن ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxvi{اور یہ کہ میری ہی عبادت کرنا یہ سیدھا راستہ ہے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxvii{اور البتہ اس نے تم میں سے بہت لوگوں کو گمراہ کیا تھا کیا پس تم نہیں سمجھتے تھے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxviii{یہی دوزخ ہے جس کا تم سے وعدہ کیا جاتا تھا\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxix{آج اس میں داخل ہو جاؤ اس کے بدلے جوتم کفر کیا کرتے تھے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxx{آج ہم ان کے مونہوں پر مہر لگا دیں گے اور ہمارے ساتھ ان کے ہاتھ بولیں گے اور ان کے پاؤں شہادت دیں گے اس پر جو وہ کیا کرتے تھے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxi{اور اگر ہم چاہیں تو ان کی آنکھیں مٹاڈالیں پس وہ راستہ کی طرف دوڑیں پھر وہ کیوں کر دیکھ سکیں\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxii{اور اگر ہم چاہیں تو ان کی صورتیں ان جگہوں پر مسخ کر دیں پس نہ وہ آگے چل سکیں او ر نہ ہی واپس لوٹ سکیں\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxiii{اور ہم جس کی عمر زیادہ کرتے ہیں بناوٹ میں اسے الٹا گھٹاتے چلے جاتے ہیں کیا یہ لوگ نہیں سمجھتے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxiv{اور ہم نے نبی کو شعر نہیں سکھایا اور نہ یہ اس کے مناسب ہی تھا یہ تو صرف نصیحت اور واضح قرآن ہے\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxv{تاکہ جو زندہ ہے اسے ڈرائے اور کافروں پر الزام ثابت ہو جائے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxvi{کیا انہوں نے نہیں دیکھا کہ ہم نے ان کے لیے اپنے ہاتھوں سے چار پائے بنائے جن کے وہ مالک ہیں\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxvii{اور انہیں ان کے بس میں کر دیا ہے پھر ان میں سے کسی پر چڑھتے ہیں اور کسی کو کھاتے ہیں\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxviii{اور ان کے لیے ان میں اور بہت سے فائدے اور پینے کی چیزیں ہیں پھر کیوں شکر نہیں کرتے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxix{اور الله کے سوا انہوں نے اور معبود بنا رکھے ہیں تاکہ وہ ان کی مدد کریں\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxx{وہ ان کی مدد نہیں کر سکیں گے اور وہ ان کے حق میں ایک فریق (مخالف) ہوں گے جو حاضر کیے جائیں گے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxi{پھر آپ ان کی بات سے غمزدہ نہ ہوں بے شک ہم جانتے ہیں جو وہ چھپاتے ہیں اور جو ظاہر کرتے ہیں\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxii{کیا آدمی نہیں جانتاکہ ہم نے اسے منی کے ایک قطرے سے بنایا ہے پھر وہ کھلم کھلا دشمن بن کر جھگڑنے لگا\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxiii{اور ہماری نسبت باتیں بنانے لگا اور اپنا پیدا ہونا بھول گیا کہنے لگا بوسیدہ ہڈیوں کو کون زندہ کر سکتا ہے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxiv{کہہ دوانہیں وہی زندہ کرے گا جس نے انہیں پہلی بار پیدا کیا تھا اور وہ سب کچھ بنانا جانتا ہے\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxv{وہ جس نے تمہارے لیے سبز درخت سے آگ پیدا کر دی کہ تم جھٹ پٹ اس سے آگ سلگا لیتے ہو\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxvi{کیا وہ جس نے آسمانوں اور زمین کو بنا دیا اس پر قاد رنہیں کہ ان جیسے اور بنائے کیوں نہیں وہ بہت کچھ بنانے ولا ماہر ہے\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxvii{اس کی تو یہ شان ہے کہ جب وہ کسی چیز کا ارادہ کرتا ہے تو اتنا ہی فرما دیتا ہے کہ ہو سو وہ ہو جاتی ہے\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxviii{پس وہ ذات پاک ہے جس کے ہاتھ میں ہر چیز کا کامل اختیار ہے اور اسی کی طرف تم لوٹائے جاؤ گے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxix{\basmalahur صف باندھ کر کھڑے ہونے والو ں کی قسم ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmdccxc{پھر جھڑک کر ڈانٹنے والوں کی\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmdccxci{پھر ذکر الہیٰ کے تلاوت کرنے والوں کی\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmdccxcii{البتہ تمہارا معبود ایک ہی ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmdccxciii{آسمانوں اور زمین اور اس کے اندر کی سب چیزو ں کا اور مشرقوں کا رب ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmdccxciv{ہم نے نیچے کے آسمان کو ستاروں سے سجایا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmdccxcv{اور اسے ہر ایک سرکش شیطان سے محفوظ رکھا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmdccxcvi{وہ عالم بالا کی باتیں نہیں سن سکتے اور ان پر ہر طرف سے (انگارے) پھینکے جاتے ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmdccxcvii{بھگانے کے لیے اور ان پر ہمیشہ کا عذاب ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmdccxcviii{مگر جو کوئی اچک لے جائے تو اس کے پیچھے دہکتا ہوا انگارہ پڑتا ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmdccxcix{پس ان سے پوچھیئے کیا ان کا بنانا زیادہ مشکل ہے یا ان کا جنہیں ہم نے پیدا کیا ہے بے شک ہم نے انہیں لیسدار مٹی سے پیدا کیا ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmdccc{بلکہ آپ نے تو تعجب کیاہے اور وہ ٹھٹھا کرتے ہیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmdccci{اور جب انہیں نصیحت کی جاتی ہے تو قبول نہیں کرتے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmdcccii{اور جب کوئی معجزہ دیکھتے ہیں تو ہسنی کرتے ہیں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmdccciii{اور کہتے ہیں یہ تو محض صریح جادو ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmdccciv{کیا جب ہم مر جائیں گے اور مٹی اور ہڈیاں ہو جائیں گے تو کیا ہم پھر اٹھائے جائیں گے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmdcccv{اور کیا ہمارے پہلے باپ دادا بھی\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmdcccvi{کہہ دو ہاں اور تم ذلیل ہونے والے ہوگے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmdcccvii{پس وہ تو ایک زور کی آواز ہو گی پس ناگہان وہ دیکھنے لگیں گے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmdcccviii{اور کہیں گے ہائے ہماری کمبختی! جزا کا دن یہی ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmdcccix{یہی فیصلے کا دن ہے جسے تم جھٹلایا کرتے تھے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmdcccx{انہیں جمع کر دو جنہوں نے ظلم کیا اور ان کی بیویوں کو اور جن کی وہ عبادت کرتے تھے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxi{سوائے الله کے پھر انہیں جہنم کے راستے کی طرف ہانک کر لے جاؤ\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxii{اور انہیں کھڑا کر و ان سے دریافت کرنا ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxiii{تمہیں کیا ہوا کہ آپس میں ایک دوسرےے کی مدد نہیں کرتے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxiv{بلکہ آج کے دن وہ سر جھکائے کھڑے ہوں گے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxv{اور ایک دوسرے کی طرف متوجہ ہو کر پوچھے گا\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxvi{کہیں گے بے شک تم ہمارے پاس دائیں طرف سے آتے تھے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxvii{کہیں گے بلکہ تم خود ہی ایمان والے نہیں تھے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxviii{اور ہمیں تم پر کوئی زور نہیں تھا بلکہ تم ہی سرکش لوگ تھے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxix{پھر ہم سب پر ہمارے رب کا قول پورا ہو گیا کہ ہم سب عذاب چکھنے والے ہیں\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxx{پھر ہم نے تمہیں بھی گمراہ کیا ہم خود بھی گمراہ تھے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxi{پھر اس دن عذاب میں وہ سب یکساں ہو ں گے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxii{بے شک ہم مجرمو ں سے ایسا ہی سلوک کیا کرتے ہیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxiii{بے شک وہ ایسے تھے کہ جب ان سے کہا جاتا تھا کہ سوائے الله کے اور کوئی معبود نہیں تو وہ تکبر کیا کرتے تھے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxiv{اور وہ کہتے تھے کیا ہم اپنے معبودوں کو ایک شاعر دیوانہ کے کہنے سے چھوڑ دیں گے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxv{بلکہ وہ حق لایا ہے اور اس نے سب رسولوں کی تصدیق کی ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxvi{بے شک اب تم دردناک عذاب چکھو گے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxvii{اور تمہیں وہی بدلہ دیا جائے گا جو تم کیا کرتے تھے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxviii{مگر جو الله کے خاص بندے ہیں\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxix{یہی لوگ ہیں جن کے لیے رزق معلوم ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxx{میوے اور انہیں کوعزت دی جائے گی\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxi{نعمتوں کے باغوں میں\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxii{ایک دوسرے کے سامنے تختوں پر\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxiii{ان میں صاف شراب کا دور چل رہا ہوگا\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxiv{سفید پینے والوں کے لیے لذیذ ہوگی\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxv{نہ اس میں درد سر ہوگا اور نہ انہیں اس سے نشہ ہوگا\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxvi{اور ان کے پاس نیچی نگاہ والی بڑی آنکھوں والی ہوں گی\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxvii{گویا کہ وہ پردہ میں رکھے ہوئے انڈے ہیں\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxviii{پس وہ ایک دوسرے کی طرف متوجہ ہو کر آپس میں سوال کریں گے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxix{ان میں سے ایک کہنے والا کہے گا کہ میرا ایک ساتھی تھا\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxl{وہ کہا کرتا تھا کہ کیا تو تصدیق کرنے والوں میں ہے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxli{کیا جب ہم مر جائیں گے اور مٹی اور ہڈیاں ہوجائیں گے تو کیا ہمیں بدلہ دیا جائے گا\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxlii{کہے گا کیا تم بھی دیکھنا چاہتے ہو\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxliii{پس وہ جھانکے گا تو اسے دوزح کے درمیان دیکھے گا\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxliv{کہے گا الله کی قسم! تو تو قریب تھا کہ مجھے ہلاک ہی کر دے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxlv{اور اگر میرے رب کا فضل نہ ہوتا تو میں بھی حاضر کیے ہوئے مجرموں میں ہوتا\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxlvi{پس کیا اب ہم مرنے والے نہیں\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxlvii{مگر ہمارا پہلی بار کا مرنا اور ہمیں عذاب نہیں دیا جائے گا\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxlviii{بے شک یہی بڑی کامیابی ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxlix{ایسی ہی کامیابی کے لیے عمل کرنے والوں کو عمل کرنا چاہیے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmdcccl{کیا یہ اچھی مہمانی ہے یا تھوہر کا درخت\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmdcccli{بے شک ہم نے اسے ظالموں کے لئےآزمائش بنایاہے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmdccclii{بے شک وہ ایک درخت ہے جو دوزخ کی جڑ میں اُگتا ہے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmdcccliii{اس کا پھل گویا کہ سانپوں کے پھن ہیں\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmdcccliv{پس بے شک وہ اس میں سے کھائیں گے پھر اس سے اپنے پیٹ بھر لیں گے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmdccclv{پھر اس پر ان کو کھولتا ہوا پانی (پیپ وغیرہ سے) ملا کر دیا جائے گا\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmdccclvi{پھر بے شک دوزخ کی طرف ان کا لوٹنا ہو گا\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmdccclvii{کیوں کہ انہوں نے اپنے باپ دادوں کو گمراہ پایا تھا\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmdccclviii{پھر وہ ان کے پیچھے دوڑتے چلے گئے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmdccclix{اور البتہ ان سے پہلے بہت سے اگلے لوگ گمراہ ہو چکے ہیں\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmdccclx{اور البتہ ہم نے ان میں ڈرانے والے بھیجے تھے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxi{پھر دیکھ جنہیں ڈرایا گیا تھا ان کا کیا انجام ہوا\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxii{مگر الله کے خالص بندے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxiii{اور ہمیں نوح نے پکارا پس ہم کیا خوب جواب دینے والے ہیں\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxiv{اور ہم نے اسے اور اس کے گھر والوں کو بڑی مصیبت سے نجات دی\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxv{اور ہم نے اس کی اولاد ہی کو باقی رہنے والی کر دیا\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxvi{اور ہم نے ان کے لیے پیچھے آنے والے لوگوں میں یہ بات رہنے دی\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxvii{کہ سارے جہان میں نوح پر سلام ہو\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxviii{بے شک ہم نیکو کاروں کو ایسا ہی بدلہ دیا کرتے ہیں\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxix{بے شک وہ ہمارے ایماندار بندوں میں تھے\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxx{پھر ہم نے دوسروں کو غرق کر دیا\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxi{اور بے شک اسی کے طریق پر چلنے والوں میں ابراھیم بھی تھا\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxii{جب کہ وہ پاک دل سے اپنے رب کی طرف رجوع ہوا\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxiii{جب کہ ا س نے اپنے باپ اور اپنی قوم سے کہا تم کس چیز کی عبادت کرتے ہو\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxiv{کیا تم جھوٹے معبودوں کو الله کے سوا چاہتے ہو\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxv{پھر تمہارا پروردگارِ عالم کی نسبت کیا خیال ہے\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxvi{پھر اس نے ایک بار ستاروں میں غور سے دیکھا\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxvii{پھر کہا بے شک میں بیمار ہوں\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxviii{پس وہ لوگ اس کے ہاں سے پیٹھ پھیر کر واپس پھرے\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxix{پس وہ چپکے سے ان کے معبودوں کے پاس گیا پھر کہا کیاتم کھاتے نہیں\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxx{تمہیں کیا ہوا کہ تم بولتے نہیں\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxi{پھر وہ بڑے زور کے ساتھ دائیں ہاتھ سے ان کے توڑنے پر پل پڑا\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxii{پھر وہ اس کی طرف دوڑتے ہوئے بڑھے\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxiii{کہا کیا تم پوجتے ہو جنہیں تم خود تراشتے ہو\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxiv{حالانکہ الله ہی نے تمہیں پیدا کیا اور جو تم بناتے ہو\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxv{انہوں نے کہا ا س کے لیے ایک مکان بناؤ پھر اس کو آگ میں ڈال دو\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxvi{پس انہوں نے اس سے داؤ کرنے کا ارادہ کیا سو ہم نے انہیں ذلیل کر دیا\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxvii{اور کہا میں نے اپنے رب کی طرف جانے والا ہوں وہ مجھے راہ بتائے گا\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxviii{اے میرے رب! مجھے ایک صالح (لڑکا) عطا کر\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxix{پس ہم نے اسے ایک لڑکے حلم والے کی خوشخبری دی\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxc{پھر جب وہ اس کے ہمراہ چلنے پھرنے لگا کہا اے بیٹے! بے شک میں خواب میں دیکھتا ہوں کہ میں تجھے ذبح کر کر رہا ہوں پس دیکھ تیری کیا رائےہے کہا اے ابا! جو حکم آپ کو ہوا ہے کر دیجیئے آپ مجھے انشاالله صبر کرنے والوں میں پائیں گے\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxci{پس جب دونوں نے قبول کر لیا اور اس نے پیشانی کے بل ڈال دیا\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxcii{اور ہم نے اسے پکارا کہ اے ابراھیم!\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxciii{تو نے خواب سچا کر دکھایا بے شک ہم اسی طرح ہم اسی طرح نیکو کاروں کو بدلہ دیا کرتے ہیں\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxciv{البتہ یہ صریح آزمائش ہے\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxcv{اور ہم نے ایک بڑا ذبیحہ ا سکے عوض دیا\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxcvi{اور ہم نے پیچھے آنے والوں میں یہ بات ان کے لیے رہنے دی\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxcvii{ابراھیم پر سلام ہو\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxcviii{اسی طرح ہم نیکو کاروں کو بدلہ دیا کرتے ہیں\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxcix{بے شک وہ ہمارے ایماندار بندوں میں سے تھے\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mmmcm{اور ہم نے اسے اسحاق کی بشارت دی کہ وہ نبی (اور) نیک لوگو ں میں سے ہوگا\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@mmmcmi{اور ہم نے ابراھیم اور اسحاق پر برکتیں نازل کیں اور ان کی اولاد میں سے کوئی نیک بھی ہیں اور کوئی اپنے آپ پر کھلم کھلا ظلم کرنے والے ہیں\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@mmmcmii{اور البتہ ہم نےموسیٰ اور ہارون پراحسان کیا\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@mmmcmiii{او رہم نے ان دونوں کو اور ان کی قوم کو بڑی مصیبت سے نجات دی\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@mmmcmiv{اور ہم نے ان کی مدد کی پس وہی غالب رہے\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@mmmcmv{اور ہم نے ان دونوں کو واضح کتاب دی\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@mmmcmvi{اور ہم نے دونوں کو راہِ راست پر چلایا\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@mmmcmvii{اور ان کے لیے آئندہ نسلوں میں یہ باقی رکھا\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@mmmcmviii{کہ موسیٰ اور ہارون پر سلام ہو\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@mmmcmix{بے شک ہم اسی طرح نیکو کاروں کو بدلہ دیا کرتے ہیں\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@mmmcmx{بے شک وہ دونوں ہمارے ایماندار بندوں میں سے تھے\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@mmmcmxi{اور بے شک الیاس رسولوں میں سے تھا\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@mmmcmxii{جب کہ اس نے اپنی قوم سے کہا کیا تم ڈرتے نہیں\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@mmmcmxiii{کیا تم بعل کو پکارتے ہو اور سب سے بہتر بنانے والے کو چھوڑدیتے ہو\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@mmmcmxiv{الله کو جو تمہارا رب ہے اور تمہارے پہلے باپ دادوں کا رب ہے\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@mmmcmxv{پس انہوں نے اس کو جھٹلایا پس بے شک وہ حاضر کیے جائیں گے\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@mmmcmxvi{مگرجو الله کے خالص بندے ہیں\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@mmmcmxvii{اور ہم نے اس پر پچھلے لوگوں میں چھوڑا\qt@no{(129)}}%
\qt@newcmd\qurantrans@ur@mmmcmxviii{کہ الیاس پر سلام ہو\qt@no{(130)}}%
\qt@newcmd\qurantrans@ur@mmmcmxix{بے شک ہم اسی طرح نیکو کاروں کو بدلہ دیا کرتے ہیں\qt@no{(131)}}%
\qt@newcmd\qurantrans@ur@mmmcmxx{بے شک وہ ہمار ایماندار بندوں میں سے تھا\qt@no{(132)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxi{اور بے شک لوط بھی رسولوں میں سے تھا\qt@no{(133)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxii{جب کہ ہم نے اس کو اور اس کے سب گھر والوں کو نجات دی\qt@no{(134)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxiii{مگر ایک بڑھیاکو جو عذاب پانے والوں میں رہ گئی\qt@no{(135)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxiv{پھر ہم نے دوسروں کو ہلاک کر دیا\qt@no{(136)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxv{اور بے شک تم ان کے پاس سے صبح کے وقت گزرتے ہو\qt@no{(137)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxvi{اور رات میں بھی پس کیا تم عقل نہیں رکھتے\qt@no{(138)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxvii{اور بے شک یونس بھی رسولوں میں سے تھا\qt@no{(139)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxviii{جب کہ وہ بھاگ گیا اس کشتی کی طرف جو بھری ہوئی تھی\qt@no{(140)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxix{پھر قرعہ ڈالا تو وہی خطا کاروں میں تھا\qt@no{(141)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxx{پھر اسے مچھلی نے لقمہ بنا لیا اوروہ پشیمان تھا\qt@no{(142)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxi{پس اگر یہ بات نہ ہوتی کہ وہ تسبیح کرنے والوں میں سے تھا\qt@no{(143)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxii{تو وہ اس کے پیٹ میں اس دن تک رہتا جس میں لوگ اٹھائے جائیں گے\qt@no{(144)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxiii{پھر ہم نے اسے میدان میں ڈال دیا اور وہ بیمار تھا\qt@no{(145)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxiv{اور ہم نے اس پر ایک درخت بیلدار اگا دیا\qt@no{(146)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxv{اور ہم نے اس کو ایک لاکھ یا اس سے زیادہ لوگوں کے پاس بھیجا\qt@no{(147)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxvi{پس وہ لوگ ایمان لائے پھر ہم نے انہیں ایک وقت تک فائدہ اٹھانے دیا\qt@no{(148)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxvii{پس ان سے پوچھیئے کیا آپ کے رب کے لیے تو لڑکیا ں ہیں اور ان کے لیے لڑکے\qt@no{(149)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxviii{کیا ہم نے فرشتوں کو عورتیں بنایا ہے اور وہ دیکھ رہے تھے\qt@no{(150)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxix{خبرادر! بے شک وہ اپنے جھوٹ سے کہتے ہیں\qt@no{(151)}}%
\qt@newcmd\qurantrans@ur@mmmcmxl{کہ الله کی اولاد ہے اور بے شک وہ جھوٹے ہیں\qt@no{(152)}}%
\qt@newcmd\qurantrans@ur@mmmcmxli{کیا اس نے بیٹیوں کو بیٹوں سے زیادہ پسند کیا ہے\qt@no{(153)}}%
\qt@newcmd\qurantrans@ur@mmmcmxlii{تمہیں کیا ہوا کیسا فیصلہ کرتے ہو\qt@no{(154)}}%
\qt@newcmd\qurantrans@ur@mmmcmxliii{پس کیا تم غور نہیں کرتے\qt@no{(155)}}%
\qt@newcmd\qurantrans@ur@mmmcmxliv{یا تمہارے پاس کوئی واضح دلیل ہے\qt@no{(156)}}%
\qt@newcmd\qurantrans@ur@mmmcmxlv{پس اپنی کتاب لے آؤ اگر تم سچے ہو\qt@no{(157)}}%
\qt@newcmd\qurantrans@ur@mmmcmxlvi{اور انہوں نے اس کے اور جنّوں کے درمیان رشتہ قائم کر دیا ہے اور جنوں کو معلوم ہے کہ وہ ضرور حاضر کیے جائیں گے\qt@no{(158)}}%
\qt@newcmd\qurantrans@ur@mmmcmxlvii{الله پا ک ہے ان باتو ں سے جو وہ بناتے ہیں\qt@no{(159)}}%
\qt@newcmd\qurantrans@ur@mmmcmxlviii{مگر الله کے خاص بندے\qt@no{(160)}}%
\qt@newcmd\qurantrans@ur@mmmcmxlix{پس بے شک تم اور جنہیں تم پوجتے ہو\qt@no{(161)}}%
\qt@newcmd\qurantrans@ur@mmmcml{کسی کو گمراہ نہیں کر سکتے\qt@no{(162)}}%
\qt@newcmd\qurantrans@ur@mmmcmli{مگر اسی کو جو دوزخ میں جانے والا ہے\qt@no{(163)}}%
\qt@newcmd\qurantrans@ur@mmmcmlii{اور ہم میں سے کوئی بھی ایسا نہیں کہ جس کے لیے ایک درجہ معین نہ ہو\qt@no{(164)}}%
\qt@newcmd\qurantrans@ur@mmmcmliii{اور بے شک ہم صف باندھے کھڑے رہنے والے ہیں\qt@no{(165)}}%
\qt@newcmd\qurantrans@ur@mmmcmliv{اور بے شک ہم ہی تسبیح کرنے والے ہیں\qt@no{(166)}}%
\qt@newcmd\qurantrans@ur@mmmcmlv{اور وہ تو کہا کرتے تھے\qt@no{(167)}}%
\qt@newcmd\qurantrans@ur@mmmcmlvi{اگر ہمارے پاس پہلے لوگوں کی کتاب ہوتی\qt@no{(168)}}%
\qt@newcmd\qurantrans@ur@mmmcmlvii{تو ہم الله کے خالص بندے ہوتے\qt@no{(169)}}%
\qt@newcmd\qurantrans@ur@mmmcmlviii{پس انہوں نے اس کا انکار کیا سو وہ جان لیں گے\qt@no{(170)}}%
\qt@newcmd\qurantrans@ur@mmmcmlix{اور ہمارا حکم ہمارے بندوں کے حق میں جو رسول ہیں پہلے سے ہو چکا ہے\qt@no{(171)}}%
\qt@newcmd\qurantrans@ur@mmmcmlx{بے شک وہی مدد دیئے جائیں گے\qt@no{(172)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxi{اور بےشک ہمارا لشکر ہی غالب رہے گا\qt@no{(173)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxii{پھر آپ ان سے کچھ مدت تک منہ موڑ لیجیئے\qt@no{(174)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxiii{اور انہیں دیکھتے رہیئے پس وہ بھی دیکھ لیں گے\qt@no{(175)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxiv{کیا وہ ہمارا عذاب جلدی مانگتے ہیں\qt@no{(176)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxv{پس جب ان کے میدان میں آ نازل ہوگا تو کیسی بری صبح ہو گی ان کی جو ڈرائے گئے\qt@no{(177)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxvi{اور ان سے کچھ مدت منہ موڑ لیجیئے\qt@no{(178)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxvii{اور دیکھتے رہیئےسو وہ بھی دیکھ لیں گے\qt@no{(179)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxviii{آپ کا رب پاک ہے عزت کا مالک ان باتوں سے جو وہ بیان کرتے ہیں\qt@no{(180)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxix{اور رسولوں پر سلام ہو\qt@no{(181)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxx{اور سب تعریف الله کے لیے ہے جو سارے جہان کا رب ہے\qt@no{(182)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxi{\basmalahur قرآن کی قسم ہے جو سراسر نصیحت ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxii{بلکہ جو لوگ منکر ہیں وہ محض تکبر اور مخالفت میں پڑے ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxiii{ہم نے ان سے پہلے کتنی قومیں ہلاک کر دی ہیں سو انہوں نے بڑی ہائے پکار کی اور وہ وقت خلاصی کا نہ تھا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxiv{اور انہوں نے تعجب کیا کہ ان کے پاس انہیں میں سے ڈرانے والا آیا اور منکروں نے کہا کہ یہ تو ایک بڑا جھوٹا جادوگر ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxv{کیا اس نے کئی معبودوں کو صرف ایک معبود بنایا ہے بے شک یہ بڑی عجیب بات ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxvi{اور ان میں سے سردار یہ کہتے ہوئے چل پڑے کہ چلو اور اپنے معبودوں پر جمے رہو بے شک اس میں کچھ غرض ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxvii{ہم نے یہ بات اپنے پچھلے دین میں نہیں سنی یہ تو ایک بنائی ہوئی بات ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxviii{کیا ہم میں سے اسی پر نصیحت اتاری گئی بلکہ انہیں تو میری نصیحت میں بھی شک ہے بلکہ انہوں نے میرا ابھی عذاب بھی نہیں چکھا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxix{کیا ان کے پاس تیرے خدائے غالب فیاض کی رحمت کے خزانے ہیں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxx{یا انہیں آسمانوں اور زمین کی حکومت اور جو کچھ ان کے درمیان ہے حاصل ہے تو سیڑھیاں لگا کر چڑھ جائیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxi{وہاں ان کے لشکر شکست پائیں گے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxii{ان سے پہلے قوم نوح اور عاد اور میخوں والا فرعون\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxiii{اور ثمود اور لوط کی قوم اور بن والے بھی جھٹلا چکے ہیں یہی وہ لشکر ہیں\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxiv{ان سب نے رسولوں کو جھٹلایا تھا پس میرا عذاب آ موجود ہوا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxv{اور یہ ایک ہی چیخ کے منتظر ہیں جسے کچھ دیر نہیں لگے گی\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxvi{اور کہتے ہیں اے رب ہمارے! ہمارا حصہ ہمیں حساب کے دن سے پہلے ہی دے دے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxvii{ان کی اِن باتوں پر صبر کر اور ہمارے بندے داؤد کو یاد کر جو بڑا طاقتور تھا بے شک وہ رجوع کرنے والا تھا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxviii{بے شک ہم نے پہاڑوں کو اس کے تابع کر دیا تھا کہ وہ شام اور صبح کو تسبیح کرتے تھے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxix{اور پرندوں کو بھی جو جمع ہوجاتے تھے ہر ایک اس کے تابع تھا\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmcmxc{اورہم نے اس کی سلطنت کو مضبوھ کر دیا تھا اور ہم نے اسے نبوت دی تھی اور مقدمات کے فیصلے کرنے کا سلیقہ (دیا تھا)\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmcmxci{اور کیا آپ کو دو جھگڑنے والوں کی خبر بھی پہنچی جب وہ عبادت خانہ کی دیوار پھاند کر آئے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmcmxcii{جب وہ داؤد کے پاس آئے تو وہ ان سے گھبرایا کہا ڈر نہیں دو جھگڑنے والے ہیں ایک نے دوسرے پر زیادتی کی ہے پس آپ ہمارے درمیا ن انصاف کا فیصلہ کیجیئے اور بات کو دور نہ ڈالیئے اور ہمیں سیدھی راہ پر چلائیے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmcmxciii{بے شک یہ میرا بھائی ہے اس کے پاس ننانوے دنبیاں ہیں اور میرے پاس صرف ایک دنبی ہے پس اس نے کہا مجھے وہ بھی دے دے اور اس نے مجھے گفتگو میں دبا لیا ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmcmxciv{کہا البتہ اس نے تجھ پر ظلم کیا جو تیری دنبی کو اپنی دنبیوں میں ملانے کا سوال کیا گور اکثر شریک ایک دوسرے پر زیادتی کیا کرتے ہیں مگر جو ایماندار ہیں اور انہوں نے نیک کام بھی کیے اور وہ بہت ہی کم ہیں اور داؤد سمجھ گیا کہ ہم نے اسے آزمایا ہے پھر اس نے اپنے رب سے معافی مانگی اور سجدہ میں گر پڑا اور توبہ کی\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmcmxcv{پھر ہم نے اس کی یہ غلطی معاف کر دی اور اس کے لیے ہمارے ہاں مرتبہ اور اچھا ٹھکانہ ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmcmxcvi{اے داؤد! ہم نے تجھے زمین میں بادشاہ بنایا ہے پس تم لوگو ں میں انصاف سے فیصلہ کیا کرو اور نفس کی خواہش کی پیروی نہ کرو کہ وہ تمہیں الله کی راہ سے ہٹا دے گی بے شک جو الله کی راہ سے گمراہ ہوتے ہیں ان کے لیے سخت عذاب ہے اس لیے کہ وہ حساب کے دن کوبھول گئے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmcmxcvii{اور ہم نے آسمان اور زمین کو اور جو کچھ ان کے بیچ میں ہے بیکار تو پیدا نہیں کیا یہ تو ان کا خیال ہے جو کافر ہیں پھرکافروں کے لیے ہلاکت ہے جو آگ ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmcmxcviii{کیا ہم کردیں گے ان کو جو ایمان لائے اور نیک کام کیے ان کی طرح جو زمین میں فساد کرتے ہیں یا ہم پرہیز گاروں کو بدکاروں کی طرح کر دیں گے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmcmxcix{ایک کتاب ہے جو ہم نے آپ کی طرف نازل کی بڑی برکت والی تاکہ وہ اس کی آیتوں میں غور کریں اور تاکہ عقلمند نصحیت حاصل کریں\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmm{اور ہم نے داؤد کو سلیمان عطا کیا کیسا اچھا بندہ تھا بےشک وہ رجوع کرنے والا تھا\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmi{جب اس کے سامنے شام کے وقت تیز رو گھوڑے حاضر کیے گئے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmii{تو کہا میں نے مال کی محبت کو یاد الہیٰ سے عزیز سمجھا یہاں تک کہ آفتاب غروب ہو گیا\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmiii{ان کو میرے پاس لوٹا لاؤ پس پنڈلیوں اور گردنوں پر (تلوار) پھیرنے لگا\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmiv{اور ہم نے سلیمان کو آزمایا تھا اور اس کی کرسی پر ایک دھڑ ڈال دیا تھا پھر وہ رجوع ہوا\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmv{کہا اے میرے رب! مجھے معاف کر اور مجھے ایسی حکومت عنایت فرما کہ کسی کو میرے بعد شایاں نہ ہو بے شک تو بہت بڑا عنایت کرنے والا ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmvi{پھر ہم نے ہوا کو اس کے تابع کر دیا کہ وہ اس کے حکم سے بڑی نرمی سے چلتی تھی جہاں اسے پہنچنا ہوتا تھا\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmvii{اور شیطان کو جو سب معمار اور غوطہ زن تھے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmviii{اور دوسروں کو جو زنجیروں میں جکڑے ہوئے تھے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmix{یہ ہماری بخشش ہے پس احسان کر یا اپنے پاس رکھ کوئی حساب نہیں\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmx{اور البتہ (سلیمان) کے لیے ہمارے پاس مرتبہ اورعمدہ مقام ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmxi{اور ہمارے بندے ایوب کو یاد کر جب اس نے اپنے رب کو پکارا کہ مجھے شیطان نے تکلیف اور عذاب پہنچایا ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmxii{اپنا پاؤں (زمین پر مار) یہ ٹھنڈا چشمہ نہانے اور پینے کو ہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmxiii{اور ہم نے ان کو ان کے اہل و عیال اور کتنے ہی اور بھی اپنی مہربانی سے عنایت فرمائے اور عقلمندوں کے لیے نصیحت ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmxiv{اور اپنے ہاتھ میں جھاڑو کا مٹھا لے کر مارے اور قسم نہ توڑ بے شک ہم نے ایوب کو صابر پایا وہ بڑے اچھے بندے الله کی طرف رجوع کرنے والے تھے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmxv{اور ہمارے بندوں ابراھیم اور اسحاق اور یعقوب کو یاد کر جو ہاتھو ں اور آنکھوں والے تھے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmxvi{بے شک ہم نے انہیں ایک خاص فضیلت دی یعنی ذکر آخرت کے لیے چن لیا تھا\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmxvii{اور بے شک وہ ہمارے نزدیک برگزیدہ بندوں میں سے تھے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmxviii{اور اسماعیل اور الیسع اور ذوالکفل کو بھی یاد کر اور یہ سب نیک لوگو ں میں سے تھے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmxix{یہ نصیحت ہے اور بے شک پرہیز گاروں کے لئے اچھا ٹھکانا ہے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmxx{ہمیشہ رہنے کے باغ ہیں ان کے لئے ان کے دروازے کھولے جائیں گے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmxxi{وہاں تکیہ لگا کر بیٹھیں گے وہاں بہت سے میوے اور شراب طلب کریں گے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmxxii{اور ان کے پاس نیچی نگاہ والی ہم عمر عورتیں ہوں گی\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmxxiii{یہی ہے جس کا تم سے حساب کے دن کے لیے وعدہ کیا جاتا ہے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmxxiv{بے شک یہ ہمارا رزق ہے جو کبھی ختم نہیں ہوگا\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmxxv{یہی بات ہے اور بے شک سرکشوں کے لیے برا ٹھکانا ہے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmxxvi{یعنی دوزخ جس میں وہ گریں گے پس وہ کیسی بری جگہ ہے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmxxvii{یہ ہے پھر وہ اس کو چکھیں جو کھولتا ہوا پانی اور پیپ ہے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmmxxviii{اور اس کی شکل اور بھی کئی طرح کی چیزیں ہوں گی\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmmxxix{یہ ایک جماعت ہے جو تمہارے ساتھ دوزخ میں داخل ہونے والی ہے (متبوع کہیں گے) ان پر خدا کی مار یہ بھی دوزخ ہی میں آ رہے ہیں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmmxxx{(تابع ہونے والے) کہیں گے بلکہ تم پر خدا کی مار تم ہی تو اس بلا کو ہمارے سامنے لائے جو بہت ہی برا ٹھکانا ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmmxxxi{تابع کہیں گے اے ہمارے رب! جو اس بلا کو آگے لایا اسے آگ میں دگنا عذاب دے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmmxxxii{اور کہیں گے کہ جن لوگوں کو ہم دنیا میں برا سمجھتے تھے ہمیں دکھائی کیوں نہیں دیتے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmmxxxiii{کیا ہم ان سے (ناحق) تمسخر کرتے تھے یا ان سے ہماری نگاہیں پھر گئی ہیں\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmmxxxiv{بے شک یہ دوزخیوں کا آپس میں جھگڑنا بالکل سچی بات ہے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmmxxxv{کہہ دو میں تو ایک ڈرانے والا ہوں اور الله کے سوا کوئی اور معبود نہیں ہے ایک ہے بڑا غالب\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmmxxxvi{آسمانوں اور زمین کا پرودگار اورجو کچھ ان کے درمیان ہے غالب بڑا معاف کرنے والا ہے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmmxxxvii{کہہ دو یہ ایک بڑی خبر ہے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmmxxxviii{تم اس سے منہ پھیرنے والے ہو\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmmxxxix{مجھے فرشتو ں کے متعلق کوئی علم نہیں تھا جب کہ وہ جھگڑ رہے تھے\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmmxl{مجھے تو یہی وحی کیا گیا ہے کہ میں تمہیں صاف صاف ڈراؤں\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmmxli{جب تیرے رب نے فرشتوں سے کہا کہ میں ایک انسان مٹی سے بنانے والا ہوں\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmmxlii{پھرجب میں اسے پورے طور پر بنا لوں اور اس میں اپنی رو ح پھونک دوں تو اس کے لیے سجدہ میں گر پڑنا\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmmxliii{پھر سب کے سب فرشتوں نے سجدہ کیا\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmmxliv{مگر ابلیس نے نہ کیا تکبر کیا اور کافروں میں سے ہو گیا\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmmxlv{فرمایا اے ابلیس! تمہیں اس کےے سجدہ کرنے سے کس نے منع کیا جسے میں نے اپنے ہاتھوں سے بنایا کیا تو نے تکبر کیا یا تو بڑوں میں سے تھا\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmmxlvi{اس نے عرض کی میں اس سے بہتر ہوں مجھے تو نے آگ سے بنایااور اسے مٹی سے بنایا\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmmxlvii{فرمایا پھر تو یہاں سے نکل جاکیوں نکہ تو راندہ گیا ہے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmmxlviii{اور تجھ پر قیامت تک میری لعنت ہے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmmxlix{عرض کی اے میرے رب! پھر مجھے مردوں کے زندہ ہونے تک مہلت دے\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmmml{فرمایا پس تمہیں مہلت ہے\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmmmli{وقت معین کے دن تک\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmmmlii{عرض کی تیری عز ت کی قسم! میں ان سب کو گمراہ کر دوں گا\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmmmliii{مگر ان میں جو تیرے خالص بندے ہوں گے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmmmliv{فرمایا حق بات یہ ہے اور میں حق ہی کہا کرتا ہوں\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmmmlv{میں تجھ سے اوران میں سے جو تیرے تابع ہوں گے سب سے جہنم بھر دوں گا\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmmmlvi{کہہ دو میں اس پر تم سے کوئی مزدوری نہیں مانگتا اور نہ میں تکلف کرنے والوں میں ہوں\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmmmlvii{یہ قرآن تو تمام جہان کے لیے نصیحت ہے\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmmmlviii{اور تم کچھ مدت کے بعد اس کا حال ضرور جان لوگے\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmmmlix{\basmalahur یہ کتاب الله کی طرف سے نازل کی گئی ہے جو غالب حکمت والا ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmlx{بے شک ہم نے یہ کتاب ٹھیک طور پر آپ کی طرف نازل کی ہے پس تو خالص الله ہی کی فرمانبرداری مدِ نظر رکھ کر اسی کی عبادت کر\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmlxi{خبردار! خالص فرمانبرداری الله ہی کے لیے ہے جنہوں نے اس کے سوا اور کارساز بنا لیے ہیں ہم ان کی عبادت نہیں کرتے مگر اس لیے کہ وہ ہمیں الله سے قریب کر دیں بے شک الله ان کے درمیان ان باتوں میں فیصلہ کرے گا جن میں وہ اختلاف کرتےتھے بے شک الله اسے ہدایت نہیں کرتا جو جھوٹا ناشکرگزار ہو\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmlxii{اگر الله چاہتا کہ کسی کو فرزند بنائے تواپنی مخلوقات میں سے جسے چاہتا چن لیتا وہ پاک ہے وہ الله ایک بڑا غالب ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmlxiii{اس نے آسمانوں اور زمین کو حکمت سے پیدا کیا وہ رات کو دن پر لپیٹ دیتا ہے اور دن کو رات پر لپیٹ دیتا ہے اور اس نے سورج اور چاند کو تابع کر دیا ہے ہر ایک وقت مقرر تک چل رہا ہے خبرادار! وہی غالب بخشنے والا ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmlxiv{اس نے تمہیں ایک جان سے پیدا کیا پھر اس نے اس سے اس کی بیوی بنائی اور تمہارے لیے آٹھ نر اور مادہ چارپایوں کے پیدا کیے وہ تمہیں تمہاری ماؤں کے پیٹوں میں ایک کیفیت کے بعد دوسری کیفیت پر تین اندھیروں میں بناتا ہے یہی الله تمہارا رب ہے اسی کی بادشاہی ہے اس کے سوا کوئی معبود نہیں پس تم کہاں پھرے جا رہے ہو\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmlxv{اگر تم انکار کرو تو بے شک الله تم سے بے نیاز ہے اور وہ اپنے بندوں کے لیے کفر کو پسند نہیں کرتا اور اگر تم شکر کرو تو وہ اسے تمہارے لیے پسند کرتا ہے اور کوئی بوجھ اٹھانے والا دوسرے کا بوجھ نہیں اٹھائے گا پھر اپنے رب ہی کی طرف تمہیں لوٹ کر جانا ہے سو وہ تمہیں بتا دے گا جو کچھ تم کرتے رہے ہو بے شک وہ سینوں کے بھید جاننے والا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmlxvi{اور جب انسان کو تکلیف پہنچتی ہے تو اپنے رب کواس کی طرف رجوع کر کے پکارتا ہے پھر جب وہ اسے کوئی نعمت اپنی طرف سے عطا کرتا ہے تو جس کے لیے پہلے پکارتا تھا اسے بھول جاتا ہے اور اس کے لیے شریک بناتا ہے تاکہ اس کی راہ سے گمراہ کرے کہہ دو اپنے کفر میں تھوڑی مدت فائد ہ اٹھا لے بے شک تو دوزخیوں میں سے ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmlxvii{(کیا کافر بہتر ہے) یا وہ جو رات کے اوقات میں سجدہ اور قیام کی حالت میں عبادت کر رہا ہو آخرت سے ڈر رہا ہو اور اپنے رب کی رحمت کی امید کر رہا ہو کہہ دو کیا علم والے اور بے علم برابر ہو سکتے ہیں سمجھتے وہی ہیں جو عقل والے ہیں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmlxviii{کہہ دو اے میرے بندو جو ایمان لائےہو اپنے رب سے ڈرو ان کے لیے جنھوں نے اس دنیا میں نیکی کی ہے اچھا بدلہ ہے اور الله کی زمین کشادہ ہے بے شک صبر کرنے والوں کو ان کا اجر بے حساب دیا جائے گا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmlxix{کہہ دو مجھے حکم ہوا ہے کہ میں الله کی اس طرح عبادت کروں کہ عبادت کو اس کے لیے خاص رکھوں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmlxx{اور مجھے یہ بھی حکم ہوا ہے کہ میں سب سے پہلا فرمانبردار بنوں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxi{کہہ دو میں بڑے دن کے عذاب سے ڈرتا ہوں اگر اپنے رب کی نافرمانی کروں\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxii{کہہ دو میں خالص الله ہی کی اطاعت کرتے ہوئے اس کی عبادت کر تا ہوں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxiii{پھر تم اس کے سوا جس کی چاہو عبادت کرو کہہ دو خسارہ اٹھانے والے وہ ہیں جنہوں نے اپنے جان اور اپنے گھر والوں کو قیامت کے روز خسارہ میں ڈال دیا یاد رکھو! یہ صریح خسارہ ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxiv{ان کے اوپر بھی آگ کے سائبان ہوں گے اور ان کے نیچے بھی سائبان ہوں گے یہی بات ہے جس کا ا لله اپنے بندوں کو خوف دلاتا ہے کہ اے میرے بندو! مجھ سے ڈرتے رہو\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxv{اور جو لوگ شیطانوں کو پوجنے سے بچتے رہے اور الله کی طرف رجوع ہوئے ان کے لیے خوشخبری ہے پس میرےبندوں کو خوشخبری دے دو\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxvi{جو توجہ سے بات کو سنتے ہیں پھر اچھی بات کی پیروی کرتے ہیں یہی ہیں جنہیں الله نے ہدایت کی ہے اور یہی عقل والے ہیں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxvii{پس کیا جسے عذاب کا حکم ہو چکا ہے (نجات والے کے برابر ہے) کیا آپ اسے چھوڑ سکتے ہیں جو آگ میں ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxviii{لیکن جو لوگ اپنےرب سے ڈرتے رہے ان کے لیے بالا خانے ہیں جن کے اوپر اوربالا خانے بنے ہوئے ہیں ان کے نیچے نہریں چلتی ہوں گی یہ الله کا وعدہ ہے اور الله اپنے وعدے کے خلاف نہیں کرتا\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxix{کیا آپ نے نہیں دیکھا کہ الله ہی آسمان سے پانی اتارتا ہے پھر اسے چشمے بنا کر زمین میں چلا دیتا ہے پھر اس کے ذریعے سے کھیتی مختلف رنگوں کی اگاتا ہے پھر خوب ابھرتی ہے پھر آپ اسے زردشدہ دیکھتے ہیں پھر اسے ریزہ ریزہ کر دیتا ہے بے شک اس میں عقل مندوں کے لیے عبرت ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxx{بھلا جس کا سینہ الله نے دین اسلام کے لئے کھول دیا ہے سو وہ اپنے رب کی طرف سے روشنی میں ہے سوجن لوگوں کے دل الله کے ذکر سے متاثر نہیں ہوتے ان کے لیے بڑی خرابی ہے یہ لوگ کھلی گمراہی میں ہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxi{الله ہی نے بہترین کلام نال کیا ہے یعنی کتاب باہم ملتی جلتی ہے (اس کی آیات) دہرائی جاتی ہیں جس سے خدا ترس لوگوں کے رونگٹے کھڑے ہو جاتے ہیں پھر ان کی کھالیں نرم ہوجاتی ہیں اور دل یاد الہیٰ کی طرف راغب ہوتے ہیں یہی الله کی ہدایت ہے اس کے ذریعے سے جسے چاہے راہ پر لے آتا ہے اور جسے الله گمراہ کر دے اسے راہ پر لانے والا کوئی نہیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxii{بھلا جو شخص اپنے منہ کو قیامت کے دن برے عذاب کی سپر بنائے گا اور ایسے ظالموں کو حکم ہوگا جو کچھ تم کیا کرتے تھے اس کا مزہ چکھو\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxiii{ان سے پہلے لوگوں نے بھی جھٹلایا تھاپھر ان پر اس طرح عذاب آیا کہ ان کو خبر بھی نہ ہوئی\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxiv{پھر الله نے ان کو دنیا ہی کی زندگی میں رسوائی کا مزہ چکھایا اور آخرت کا عذاب تو اور بھی زیادہ ہے کاش وہ جانتے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxv{اورہم نے لوگو ں کے لیے اس قرآن میں ہر قسم کی مثال بیان کر دی ہے تاکہ وہ نصیحت پکڑیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxvi{وہ عربی زبان کا بے عیب قرآن ہے تاکہ یہ لوگ ڈریں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxvii{الله نے ایک مثال بیان کی ہے ایک غلام ہے جس میں کئی ضدی شریک ہیں اور ایک غلام سالم ایک ہی شخص کا ہے کیا دونوں کی حالت برابر ہے سب تعریف الله ہی کے لیے ہے مگر ان میں سے اکثر نہیں سمجھتے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxviii{بے شک آپ کو بھی مرنا ہے اور ان کو بھی مرنا ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxix{پھر بے شک تم قیامت کے دن اپنے رب کے ہاں آپس میں جھگڑو گے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmxc{پھر اس سے کون زیادہ ظالم ہے جس نے الله پرجھوٹ بولا اور سچی بات کو جھٹلایا جب اس کے پاس آئی کیا دوزخ میں کافروں کا ٹھکانا نہیں ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmxci{اور جو سچی بات لایا اور جس نے اس کی تصدیق کی وہی پرہیزگار ہیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmxcii{ان کے لیے جو کچھ وہ چاہیں گے ان کے رب کے پاس موجود ہوگا نیکو کارو ں کا یہی بدلہ ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmxciii{تاکہ الله ان سے وہ برائیاں دور کر دے جو انہوں نے کی تھیں اور الله ان کو ان کا اجر دے ان نیک کاموں کے بدلہ میں جو وہ کیا کرتے تھے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmxciv{کیا الله اپنے بندے کو کافی نہیں اور وہ آپ کو ان لوگوں سے ڈراتے ہیں جو اس کے سوا ہیں اور جسے الله گمراہ کر دے تو اسے راہ پر لانے والا کوئی نہیں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmxcv{اور جسے الله راہ پر لے آئے تو اسے کوئی گمراہ کرنے والا نہیں کیا الله غالب بدلہ لینے والا نہیں ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmxcvi{او راگر آپ ان سے پوچھیں آسمانوں اور زمین کو کس نے پیدا کیا ہے تو وہ ضرور کہیں گے الله نے کہہ دو بھلا دیکھو تو سہی جنہیں تم الله کے سوا پکارتے ہو اگر الله مجھے تکلیف دینا چاہے تو کیا وہ اس کی تکلیف کو دور کر سکتے ہیں یا وہ مجھ پر مہربانی کرنا چاہے تو کیا وہ اس مہربانی کو روک سکتے ہیں کہہ دو مجھے الله کافی ہے توکل کرنے والے اسی پر توکل کیا کرتے ہیں\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmxcvii{کہہ دو اے میری قوم تم اپنی جگہ پر کام کیے جاؤ میں بھی کر رہا ہوں پھر تمہیں معلوم ہو جائے گا\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmxcviii{کہ کس پر عذاب آتا ہےجو اسے رسوا کردے اورکس پردائمی عذاب اترتا ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmxcix{بے شک ہم نے آپ پر یہ کتاب سچی لوگو ں کے لیے اتاری ہے پھر جو راہ پر آیا سو اپنے لیے اور جو گمراہ ہوا سو وہ گمراہ ہوتا ہے اپنے برے کو اور آپ ان کے ذمہ دار نہیں ہیں\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmc{اللہ ہی جانوں کو ان کی موت کے وقت قبض کرتا ہے اور ان جانوں کو بھی جن کی موت ان کے سونے کے وقت نہیں آئی پھر ان جانوں کو روک لیتا ہے جن پر موت کا حکم فرما چکا ہے اور باقی جانوں کو ایک میعاد معین تک بھیج دیتا ہے بے شک اس میں ان لوگوں کے لیے نشانیاں ہیں جو غور کرتے ہیں\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmci{کیا انہوں نے الله کےسوا اور حمایتی بنا رکھے ہیں کہہ دوکیا اگرچہ وہ کچھ بھی اختیار نہ رکھتے ہوں اور نہ عقل رکھتے ہوں\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmcii{کہہ دو ہر طرح کی حمایت الله ہی کے اختیار میں ہے آسمانوں اور زمین میں اسی کی حکومت ہے پھر اسی کی طرف تم لوٹائے جاؤ گے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmciii{اور جب ایک الله کا ذکر کیا جاتا ہے تو لوگ آخرت پر یقین نہیں رکھتے ان کے دل نفرت کرتے ہیں اور جب اس کے سوا اوروں کا ذکر کیا جاتا ہے تو فوراً خوش ہو جاتے ہیں\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmciv{کہہ دو اے الله آسمانوں اور زمین کے پیدا کرنے والے ہر چھپی او رکھلی بات کے جاننے والے تو ہی اپنے بندوں میں فیصلہ کرے گا اس بات میں جس میں وہ اختلاف کر رہے ہیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmcv{اور اگر ظالموں کے پاس جو کچھ زمین میں ہے سب ہو اور اسی قدر اس کے ساتھ اور بھی ہو تو قیامت کے بڑے عذاب کے معاوضہ میں دے کر چھوٹنا چاہیں گے اور اللہ کی طرف سے انہیں وہ پیش آئے گا کہ جس کا انہیں گمان بھی نہ تھا\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmcvi{اور برے کاموں کی برائی ان پر ظاہر ہو جائے گی اوران کو وہ عذاب کہ جس پر ہنسی کیا کرتے تھے پکڑ لے گا\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmcvii{پھر جب آدمی پر کوئی مصیبت آتی ہے تو ہمیں پکارتا ہے پھر جب ہم اسے اپنی نعمت عطا کرتے ہیں تو کہتا ہے یہ تومجھے میری عقل سے ملی ہے بلکہ یہ نعمت آزمائش ہے ولیکن ان میں سے اکثر نہیں جانتے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmcviii{بے شک یہی بات وہ لوگ کہہ چکے ہیں جو ان سے پہلے تھے پس ان کے نہ کام آیا جو کچھ وہ کماتے رہے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmcix{پھر ان پر ان کے اعمال کی برائی آ پڑی اور ان میں سے جو لوگ ظلم کر رہے ہیں عنقریب ان کو بھی برے نتائج ان برے عملوں کے پہنچیں گے اور وہ عاجز کرنے والے نہیں ہیں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmcx{اور کیا انہیں معلوم نہیں کہ الله ہی روزی کشادہ کر تا ہے جس کی چاہے اور تنگ کرتا ہے بے شک اس میں ان لوگو ں کے لیے نشانیاں ہیں جو ایمان رکھتے ہیں\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmcxi{کہہ دو اے میرے بندو جنہوں نے اپنی جانوں پر ظلم کیا ہے الله کی رحمت سے مایوس نہ ہو بے شک الله سب گناہ بخش دے گا بے شک وہ بخشنے والا رحم والا ہے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmcxii{اور اپنے رب کی طرف رجوع کرو اور اس کا حکم مانو اس سے پہلے کہ تم پر عذاب آئے پھر تمہیں مدد بھی نہ مل سکے گی\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmcxiii{اور ان اچھی باتوں کی پیروی کرو جو تمہارے رب کی طرف سے نازل کی گئی ہیں اس سے پہلے کہ تم پر ناگہاں عذاب آ جائے اور تمہیں خبر بھی نہ ہو\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmcxiv{کہیں کوئی نفس کہنے لگے ہائے افسوس اس پر جو میں نے الله کے حق میں کوتاہی کی اور میں تو ہنسی ہی کرتا رہ گیا\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmcxv{یا کہنے لگے اگر الله مجھے ہدایت کرتا تو میں پرہیزگاروں میں ہوتا\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmmcxvi{یا کہنے لگے جس وقت عذاب کو دیکھے گا کہ کاش مجھے میسر ہو واپس لوٹنا تو میں نیکو کاروں میں سے ہوجاؤں\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmmcxvii{ہاں تیرے پاس میری آیتیں آ چکی تھیں سو تو نے انہیں جھٹلایا اور تو نے تکبر کیا اور تو منکروں میں سے تھا\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmmcxviii{اور قیامت کے دن آپ ان لوگوں کو دیکھیں گے جو الله پر جھوٹے الزام لگاتے ہیں کہ ان کے منہ سیاہ ہوں گے کیا دوزخ میں تکبر کرنے والوں کا ٹھکانہ نہیں ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmmcxix{اور الله ان لوگوں کو کامیابی کے ساتھ نجات دے گا جو (شرک و کفر سے) بچتےتھے انہیں تکلیف نہیں پہنچے گی اور نہ وہ غمگین ہوں گے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmmcxx{الله ہی ہر چیز کا پیدا کرنے والا ہے اور وہی ہر چیز کا نگہبان ہے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxi{آسمانوں اور زمین کی کنجیاں اسی کے ہاتھ میں ہیں اور جو الله کی آیتوں کے منکر ہوئے وہی نقصان اٹھانے والے ہیں\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxii{کہہ دو اے جاہلو کیا مجھے الله کے سوا اور کی عبادت کرنے کا حکم دیتے ہو\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxiii{اور بے شک آپ کی طرف اور ان کی طرف وحی کیا جا چکا ہے جو آپ سے پہلے ہو گزرے ہیں کہ اگرتم نے شرک کیا تو ضرور تمہارے عمل برباد ہو جائیں گے اور تم نقصان اٹھانے والوں میں سے ہو گے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxiv{بلکہ الله ہی کی عبادت کرو اور جس کے شکر گزار رہو\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxv{اور انھوں نے الله کی قدر نہیں کی جیسا کہ اس کی قدر کرنے کا حق ہے اور یہ زمین قیامت کے دن سب اسی کی مٹھی میں ہو گی اور آسمان اس کے داہنے ہاتھ میں لپٹے ہوئےہوں گے وہ پاک اور برتر ہے اس سے جو وہ شریک ٹھیراتے ہیں\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxvi{اور صور پھونکا جائے گا تو بے ہوش ہو جاے گا جو کوئی آسمانوں اورجو کوئی زمین میں ہے مگر جسے الله چاہے پھر وہ دوسری دفعہ صور پھونکا جائے گا تو یکایک وہ کھڑے دیکھ رہے ہوں گے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxvii{اور زمین اپنے رب کے نور سے چمک اٹھے گی اور کتاب رکھ دی جاوے گی اور نبی اور گواہ لائے جاویں گے اور ان میں انصاف سے فیصلہ کیا جاوے گا اور ان پر ظلم نہ کیا جائے گا\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxviii{اورہر شخص کو جو کچھ اس نے کیا تھا پورا پورا بدلہ دیا جائے گا اور وہ خوب جانتا ہے جو کچھ وہ کر رہے ہیں\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxix{اور جو کافر ہیں دوزخ کی طرف گروہ گروہ ہانکے جائیں گے یہاں تک کہ جب اسکے پاس آئیں گے تو اس کے دروازے کھول دیے جائیں گے اور ان سے اس کے داروغہ کہیں گے کیا تمہارے پاس تم ہی میں سے رسول نہیں آئےتھے جو تمہیں تمہارے رب کی آیتیں پڑھ کر سناتے تھے اور آج کے دن کےپیش آنے سے تمہیں ڈراتے تھے کہیں گے ہاں لیکن عذاب کا حکم (علم ازلی میں) منکرو ں پر ہو چکا تھا\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxx{کہا جائے گا دوزخ کے دروازوں میں داخل ہو جاؤ اس میں سدا رہو گے پس وہ تکبر کرنے والوں کے لیے کیسا برا ٹھکانہ ہے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxi{اور وہ لوگ جو اپنے رب سے ڈرتے رہے جنت کی طرف گرو ہ گروہ لے جانے جائیں گے یہاں تک کہ جب وہ اس کے پا پہنچ جائیں گے اور اس کے دروازے کھلے ہوئے ہوں گے اور ان سے اس کے داروغہ کہیں گے تم پر سلام ہو تم اچھے لوگ ہو اس میں ہمیشہ کے لیے داخل ہو جاؤ\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxii{اوروہ کہیں گے الله کا شکر ہے جس نے ہم سے اپنا وعدہ سچا کیا اور ہمیں اس زمین کا وارث کر دیا کہ ہم جنت میں جہاں چاہیں رہیں پھر کیا خوب بدلہ ہے عمل کرنے والوں کا\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxiii{اور آپ فرشتوں کو حلقہ باندھے ہوئے عرش کے گرد دیکھیں گے اپنے رب کی حمد کے ساتھ تسبیح پڑھ رہے ہیں اور درمیان انصاف سے فیصلہ کیا جائے گا اور سب کہیں گے سب تعریف الله ہی کے لیے ہے جو سارے جہانوں کا رب ہے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxiv{\basmalahur حمۤ\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxv{یہ کتاب الله کی طرف سے نازل ہوئی ہے جو غالب ہر چیز کا جاننے والا ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxvi{گناہ بخشنے والا اور توبہ قبول کرنے والا سخت عذاب دینے والا قدرت والا ہے اس کے سوا کوئی معبود نہیں اسی کی طرف لوٹ کر جانا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxvii{الله کی آیتوں میں نہیں جھگڑتے مگر وہ لوگ جو کافر ہیں پس ان کا شہرو ں میں چلنا پھرنا آپ کو دھوکا نہ دے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxviii{ان سے پہلے قوم نوح اور ان کے بعد اور فرقے بھی جھٹلا چکے ہیں اور ہر ایک امت نے اپنے رسول کو پکڑنے کا ارادہ کیا اور غلط باتوں کے ساتھ بحث کرتے رہے تاکہ اس سے دین حق کو مٹا دیں پھر ہم نے انھیں پکڑ لیا پھر کیسی سزا ہوئی\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxix{اور اسی طرح منکروں پر الله کا کلام پورا ہوا کہ وہ دوزخی ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmcxl{جو (فرشتے) عرش کو اٹھائے ہوئے ہیں اور جو اس کے گرد ہیں وہ اپنے رب کی حمد کے ساتھ تسبیح کرتے رہتے ہیں اور اس پر ایمان لاتے ہیں اور ایمانداروں کے لیے بخشش مانگتے ہیں کہ اے ہمارے رب تیری رحمت اور تیرا علم سب پر حاوی ہے پھر جن لوگو ں نے توبہ کی ہے اور تیرے راستے پر چلتے ہیں انہیں بخش دے اور انہیں دوزخ کے عذاب سے بچا لے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmcxli{اے ہمارے رب اور انہیں بہشتوں میں داخل کر جو ہمیشہ رہیں گی جن کا تو نے ان سے وعدہ کیا ہے اور ان کو جو ان کے باپ دادوں اوران کی بیویوں اوران کی اولاد میں سے نیک ہیں بے شک تو غالب حکمت والا ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmcxlii{اور انہیں برائیوں سے بچا اور جس کو تو اس دن برائیوں سے بچائے گا سو اس پر تو نے رحم کر دیا اور یہ بڑی کامیابی ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmcxliii{بے شک جو لوگ کافر ہیں انہیں پکار کر کہا جائے گا جیسی تمہیں (اس وقت) اپنے سے نفرت ہے اس سے بڑھ کر الله کو (تم سے) نفرت تھی جبکہ تم ایمان کی طرف بلائے جاتے تھے پھر نہیں مانا کرتے تھے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmcxliv{وہ کہیں گے اے ہمارے رب تو نے ہمیں دو بار موت دی اورتو نے ہمیں دوبارہ زندہ کیا پس ہم نے اپنے گناہوں کا اقرار کر لیا پس کیا نکلنے کی بھی کوئی راہ ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmcxlv{یہ عذاب اس لیے ہے کہ جب تم اکیلے الله کی طرف بلایا جاتا تھا تو انکار کرتے تھے اورجب اس کے ساتھ شریک کیا جاتا تھا تو مان لیتے تھے سو یہ فیصلہ الله کا ہے جو عالیشان بڑے رتبے والا ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmcxlvi{وہی ہے جو تمہیں اپنی نشانیاں دکھاتا ہے اور تمہارے لیے آسمان سے رزق نازل کرتا ہے اور سمجھتا وہی ہے جو (الله کی طرف) رجوع کرتا ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmcxlvii{پس الله کو پکارو اس کے لیے عبادت کو خالص کرتے ہوئے اگرچہ کافر برا منائیں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmcxlviii{وہ اونچے درجوں والا عرش کا مالک ہے اپنے حکم سے اپنےبندوں میں سے جس کے پاس چاہتا ہے وحی بھیجتا ہے تاکہ وہ ملاقات (قیامت) کے دن سے ڈرائے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmcxlix{جس دن وہ سب نکل کھڑے ہوں گے الله پر ان کی کوئی بات چھپی نہ رہے گی آج کس کی حکومت ہے الله ہی کی جو ایک ہے بڑا غالب\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmcl{آج کے دن ہر شخص اپنے کیے کا بدلہ پائے گا آج کچھ ظلم نہ ہوگا بے شک الله جلد حساب لینے والا ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmcli{اور انہیں قریب آنے والی (مصیبت) کے دن سے ڈرا جب کہ غم کے مارے کلیجے منہ کو آ رہے ہوں گے ظالموں کا کوئی حمایتی نہیں ہوگا اور نہ کوئی سفارشی جس کی بات مانی جائے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmclii{وہ آنکھوں کی خیانت اور دل کے بھید جانتا ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmcliii{اور الله ہی انصاف کے ساتھ فیصلہ کرے گا اور جنہیں وہ اس کے سوا پکارتے ہیں وہ کچھ بھی فیصلہ نہیں کر سکتے بیشک الله ہی سب کچھ سننے والا دیکھنے والا ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmcliv{کیا انہوں نے زمین میں سیر نہیں کی کہ وہ دیکھتے ان لوگو ں کا انجام کیسا تھا جو ان سے پہلے ہو گزرے ہیں وہ قوت میں ان سے بڑھ کر تھے اور زمین میں آثار کے اعتبار سے بھی پھر الله نے انہیں ان کے گناہوں کے سبب سے پکڑ لیا اوران کے لیے الله سے کوئی بچانے والا نہ تھا\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmclv{یہ اس لیے کہ ان کے پاس ان کے رسول روشن دلیلیں لے کر آتے تھے تو وہ انکار کرتے تھے پس انہیں الله نے پکڑ لیا بے شک وہ بڑا قوت والا سخت عذاب دینے والا ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmclvi{اور ہم نے موسیٰ کو اپنے معجزات اور واضح دلیل دے کر بھیجا تھا\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmclvii{فرعون اور ہامان اور قارون کی طرف تو وہ کہنے لگے بڑا جھوٹا جادوگر ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmclviii{پس جب وہ ان کے پاس ہماری طرف سے سچا دین لائے تو کہنے لگے ان لوگوں کے بیٹوں کو قتل کر دو جو موسیٰ پر ایمان لائے ہیں اور ان کی عورتوں کو زندہ رہنے دو اور کافروں کے داؤ تو محض غلط ہوا کرتے ہیں\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmclix{اور فرعون نے کہا مجھے چھوڑ دو میں موسیٰ کو قتل کر دوں اور وہ اپنے رب کو پکارے میں ڈرتا ہوں کہ وہ تمہارے دین کو بدل ڈالے گا یا یہ کہ زمین میں فساد پھیلائے گا\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmclx{اور موسیٰ نے کہا میں تو اپنی اور تمہارے رب کی پناہ لے چکا ہوں ہر ایک متکبّر سے جو حساب کے دن پر یقین نہیں رکھتا\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmclxi{اور فرعون کی قوم میں سے ایک ایمان دار آدمی نے کہا جو اپنا ایمان چھپاتا تھا کیاتم ایسے آدمی کو قتل کرتے ہو جو یہ کہتا ہے کہ میرا رب الله ہے اوروہ تمہارے پاس وہ روشن دلیلیں تمہارے رب کی طرف سے لایا ہے اور اگر وہ جھوٹا ہے تو اسی پر ا س کے جھوٹ کا وبال ہے اور اگر وہ سچا ہے تو تمہیں کچھ نہ کچھ وہ (عذاب) جس کا وہ تم سے وعدہ کرتا ہے پہنچے گا اور الله اس کو راہ پر نہیں لاتا جو حد سے بڑھنے والا بڑا جھوٹا ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmclxii{اے میری قوم آج تو تمہاری حکومت ہے تم ملک میں غالب ہو ہماری کون مدد کرے گا اگر ہم پر الله کا عذاب آگیا فرعون نے کہا میں تو تمہیں وہی سوجھاتا ہوں جو مجھے سوجھی ہے اور میں تمہیں سیدھا ہی راستہ بتاتا ہوں\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmclxiii{اور اس شخص نے کہا جو ایمان لایا تھا کہ اےمیری قوم مجھے تو تمہاری نسبت (پہلی) امتوں جیسے دن کا اندیشہ ہو رہا ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmclxiv{جیسا کہ قوم نوح اور عاد اور ثمود اور ان سے پچھلوں کا حال ہوا اور الله تو بندوں پر کچھ بھی ظلم نہیں کرنا چاہتا\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmclxv{اور اے میری قوم مجھے تم پر چیخ و پکار (قیامت) کے دن کا اندیشہ ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmclxvi{جس دن تم پیٹھ پھیر کر بھاگو گے الله سے تمہیں کوئی بچانے والا نہیں ہوگا اور جسے الله گمراہ کر دے پھر اسے کوئی راہ بتانے والا نہیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmclxvii{اور تمہارے پاس یوسف بھی اس سے پہلے واضح دلیلیں لے کر آ چکا پس تم ہمیشہ اس سے شک میں رہے جو وہ تمہارے پاس لایا یہاں تک کہ جب وہ فوت ہو گیا تو تم نےکہا کہ الله اس کے بعد کوئی رسول ہر گز نہیں بھیجے گا اسی طرح الله گمراہ کرتا ہے اس کو جو حد سے بڑھنے والا شک کرنے والا ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmclxviii{جو لوگ الله کی آیتوں میں کسی دلیل کے سوا جو ان کے پاس پہنچی ہو جھگڑتے ہیں الله اور ایمان والوں کے نزدیک (یہ) بڑی نازیبا بات ہے الله ہر ایک متکبّر سرکش کے دل پر اسی طرح مہر کر دیا کرتا ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmclxix{اور فرعون نے کہا اے ہامان میرے لیے ایک محل بنا تاکہ میں راستوں پر پہنچوں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmclxx{یعنی آسمان کے راستوں پر پھر موسیٰ کے خدا کی طرف جھانک کر دیکھوں اور میں تو اسے جھوٹا خیال کرتا ہوں اور اسی طرح فرعون کو اس کا برا عمل اچھا معلوم ہوا اور وہ راستہ سے روکا گیا تھا اور فرعون کی ہر تدبیر غارت ہی گئی\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxi{اوراس شخص نے کہا جو ایمان لایا تھا اے میری قوم تم میری پیروی کرو میں تمہیں نیکی کی راہ بتاؤں گا\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxii{اے میری قوم دنیا کی زندگی بس (چند روزہ) فائدے ہیں اور آخرت کا گھر ہی ٹھہرنے کی جگہ ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxiii{جس نے برا کام کیا تو اتنی ہی سزا پائے گا اور جس نے نیک کام کیا خواہ وہ مرد ہو یا عورت اور وہ ایمانداربھی ہو سو وہ جنت میں داخل ہوں گے جہاں انہیں بے حساب روزی ملے گی\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxiv{اور اے میری قوم کیا بات ہے میں تو تمہیں نجات کی طرف بلاتا ہوں اور تم مجھے دوزخ کی طرف بلاتے ہو\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxv{تم مجھے اس بات کی طرف بلاتے ہو کہ میں الله کا منکر ہو جاؤں اور اس کے ساتھ اسے شریک کروں جسے میں جانتا بھی نہیں اور میں تمہیں غالب بخشنے والے کی طرف بلاتاہوں\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxvi{بے شک تم مجھے جس کی طرف بلاتے ہو وہ نہ دنیا میں بلانے کے قابل ہے اور نہ آخرت میں اور بےشک ہمیں الله کی طرف لوٹ کر جانا ہے اور بے شک حد سے بڑھنے والے ہی دوزخی ہیں\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxvii{پھر تم میری بات کو یاد کرو گے اور میں اپنا معاملہ الله کے سپرد کرتا ہوں بے شک الله بندوں کو دیکھ رہا ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxviii{پھر الله نے اسے تو ان کے فریبوں کی برائی سے بچایا اور خود فرعونیوں پر سخت عذاب آ پڑا\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxix{وہ صبح او رشام آگ کے سامنے لائے جاتے ہیں اور جس دن قیامت قائم ہو گی (حکم ہوگا) فرعونیوں کو سخت عذاب میں لے جاؤ\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxx{اور جب دوزخی آپس میں جھگڑیں گےپھر کمزور سرکشوں سے کہیں گے کہ ہم تمہارے پیرو تھے پھر کیا تم ہم سے کچھ بھی آگ دور کر سکتے ہو\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxi{سرکش کہیں گے ہم تم سبھی اس میں پڑے ہوئے ہیں بے شک الله اپنے بندوں میں فیصلہ کر چکا ہے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxii{اور دوزخی جہنم کے داروغہ سے کہیں گے کہ تم اپنے رب سے عرض کرو کہ وہ ہم سے کسی روز تو عذاب ہلکا کر دیا کرے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxiii{وہ کہیں گے کیا تمہارے پاس تمہارے رسول نشانیاں لے کر نہ آئے تھے کہیں گے ہاں (آئے تھے) کہیں گے پس پکارو اور کافروں کا پکارنا محض بے سود ہو گا\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxiv{ہم اپنے رسولوں اور ایمانداروں کے دنیا کی زندگی میں بھی مددگار ہیں اور اس دن جب کہ گواہ کھڑے ہوں گے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxv{جس دن ظالموں کو ان کا عذر کرنا کچھ بھی نفع نہ دے گا اور ان پر پھٹکار پڑے گی اور ان کے لیے برا گھر ہوگا\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxvi{اور ہم نے موسیٰ کو ہدایت دی تھی اور ہم نے بنی اسرائیل کو کتاب کا وارث کر دیا تھا\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxvii{جو عقلمندوں کے لیے ہدایت اور نصیحت تھی\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxviii{پس صبر کر بے شک الله کا وعدہ سچا ہے اور اپنے گناہ کی معافی مانگ اور شام اور صبح اپنے رب کی حمد کے ساتھ پاکی بیان کر\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxix{بے شک جو لوگ الله کی آیتوں میں بغیر اس کے کہ ان کے پاس کوئی دلیل آئی ہو جھگڑتے ہیں اور کچھ نہیں بس ان کے دل میں بڑائی ہے کہ وہ اس تک کبھی پہنچنے والے نہیں سو الله سے پناہ مانگو کیوں کہ وہ سننے والا دیکھنے والا ہے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmcxc{البتہ آسمانوں اور زمین کا پیدا کرنا آدمیوں کے پیدا کرنے کی نسبت بڑا کام ہے لیکن اکثر لوگ نہیں جانتے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmmcxci{اور اندھا اور دیکھنے والا برابر نہیں اور جو لوگ ایمان لائے اور نیک کام کئے وہ اور بدکار برابر نہیں تم بہت ہی کم سمجھتے ہو\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmmcxcii{بے شک قیامت آنے والی ہے اس میں کوئی شک نہیں لیکن اکثر لوگ یقین نہیں کرتے\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmmcxciii{اور تمہارے رب نے فرمایا ہے مجھے پکارو میں تمہاری دعا قبول کروں گا بے شک جو لوگ میری عبادت سے سرکشی کرتے ہیں عنقریب وہ ذلیل ہو کر دوزخ میں داخل ہوں گے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmmcxciv{الله ہی ہے جس نے تمہارے لیے رات بنائی تاکہ اس میں آرام کرو اور دن کو ہر چیز دکھانے والا بنایا بے شک الله لوگوں پر بڑے فضل والا ہے لیکن اکثر لوگ شکر نہیں کرتے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmmcxcv{یہی الله تمہارا رب ہے ہر چیز کا پیدا کرنے والا اس کے سوا کوئی معبود نہیں پھر کہاں الٹے جا رہے ہو\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmmcxcvi{اسی طرح وہ لوگ بھی الٹے چلا کرتے تھے جو الله کی نشانیوں کا انکار کیا کرتے تھے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmmcxcvii{الله ہی ہے جس نے تمہارے لیے زمین کو آرام گاہ بنایا اور آسمان کو چھت اور تمہاری صورتیں بنائیں اور پاکیزہ چیزوں سے تمہیں رزق دیا وہی الله تمہارا پالنے والا ہے پس سارے جہان کا پالنے والا الله با برکت ہے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmmcxcviii{وہی ہمیشہ زندہ ہے اس کے سوا کوئی معبود نہیں پس اسی کو پکارو خاص اسی کی بندگی کرتے ہوئے سب تعریف الله کے لیے ہے جو سارے جہان کا پالنے والا ہے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmmcxcix{کہہ دو مجھے تو ان چیزوں کی عبادت سے منع کیا گیا ہے جن کو تم الله کے سوا پکارتے ہو جب کہ میرے رب کی طرف سے میرے پاس کھلی کھلی نشانیاں آچکی ہیں اور مجھے یہ حکم دیا گیا ہے کہ میں رب العالمین کے سامنے سر جھکاؤں\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmmcc{وہی ہے جس نے تمہیں مٹی سے پھر نطفے سے پھر خون بستہ سے پیدا کیا پھر وہ تمہیں بچہ بنا کر نکالتا ہے پھر باقی رکھتا ہے تاکہ تم اپنی جوانی کو پہنچو پھر یہاں تک کہ تم بوڑھے ہو جاتے ہو کچھ تم میں اس سے پہلے مر جاتے ہیں (بعض کو زندہ رکھتا ہےاور تاکہ تم وقت مقررہ تک پہنچو اور تاکہ تم سمجھو\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmmcci{وہی ہے جو زندہ کرتا ہے اور مارتا ہے پس جب وہ کسی امر کیا فیصلہ کرلیتا ہے تو صرف اس سے یہی کہتا ہے کو ہو جا تو وہ ہو جاتا ہے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmmccii{کیا آپ نے ان لوگوں کو نہیں دیکھا جو الله کی آیتوں میں جھگڑتے ہیں وہ کہاں پھرے چلے جا رہے ہیں\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmmcciii{وہ لوگ جنہوں نے کتاب کو اور جو کچھ ہم نے رسولوں کو دے کر بھیجا تھا سب کو جھٹلا دیا پس انہیں معلوم ہو جائے گا\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmmcciv{جب کہ طوق اور زنجیریں ان کے گلے میں ڈال کر گھسیٹے جائيں گے\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmmccv{کھولتے پانی میں پھر آگ میں جھونکے جائیں گے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmmccvi{پھر ان سے کہا جائے گا کہاں ہیں جنھیں تم شریک بتاتے تھے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmmccvii{الله کے سوا وہ کہیں گے ہم سے وہ کھوئے گئے بلکہ ہم تو اس سے پہلے کسی چیز کو بھی نہیں پکارتے تھے اسی طرح الله کافروں کو گمراہ کرتا ہے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmmccviii{یہ عذاب تمہیں اس لیے ہوا کہ تم ملک میں ناحق خوشیاں مناتے تھے اور اس لیے بھی کہ تم اترایا کرتے تھے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmmccix{جہنم کے دروازوں میں ہمیشہ رہنے کے لیے داخل ہو جاؤ پھر تکبر کرنے والوں کا کیا ہی برا ٹھکانہ ہے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmmccx{پھر صبر کر بے شک الله کا وعدہ سچا ہے پھر جس (عذاب) کا ہم ان سے وعدہ کر رہے ہیں کچھ تھوڑا سا اگر ہم آپ کو دکھا دیں یا ہم آپ کو وفات دے د یں تو ہماری طرف ہی سب لوٹائے جائیں گے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmmccxi{اورہم نے آپ سے پہلے کئی رسول بھیجے تھے بعض ان میں سے وہ ہیں جن کا حال ہم نے آپ پر بیان کر دیا اور بعض وہ ہیں کہ ہم نے آپ پر انکا حال بیان نہیں کیا اور کسی رسول سے یہ نہ ہو سکا کہ کوئی معجزہ اذنِ الہیٰ کے سوا ظاہر کر سکے پھر جس وقت الله کا حکم آئے گا ٹھیک فیصلہ ہو جائے گا اوراس وقت باطل پرست نقصان اٹھائیں گے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmmccxii{الله ہی ہے جس نے تمہارے لیے چوپائے بنائے تاکہ تم ان میں سے بعض پر سوار ہو اور بعض کو تم کھاتے ہو\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmmmccxiii{اور تمہارے لیے ان میں بہت سے فوائد ہیں اور تاکہ تم ان پر سوار ہو کر اپنی حاجت کو پہنچو جو تمہارے سینوں میں ہے اور ان پر اور نیز کشتیوں پر تم سوارکیے جاتے ہو\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmmmccxiv{اور وہ تمہیں اپنی نشانیاں دکھاتا ہے پس تم الله کی کون کون سی نشانیوں کا انکار کرو گے\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmmmccxv{پس کیا انہوں نے ملک میں چل پھر کر نہیں دیکھا کہ جو لوگ ان سے پہلے ہو گزرے ہیں ان کا کیا انجام ہوا وہ لوگ ان سے زیادہ تھے اور قوت اور نشانوں میں (بھی) جو کہ زمین پر چھوڑگئے ہیں بڑھے ہوئے تھے پس ان کے نہ کام آیا جو کچھ وہ کماتے تھے\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmmmccxvi{پس جب ان کے رسول ان کے پا س کھلی دلیلیں لائے تووہ اپنے علم و دانش پر اترانے لگے اور جس پر وہ ہنسی کرتےتھے وہ ان پر الٹ پڑا\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmmmccxvii{پھر جب انہوں نے ہمارا عذاب آتے دیکھا تو کہنے لگے کہ ہم الله پر ایمان لائےجو ایک ہے اور ہم نے ان چیزوں کا انکار کیا جنہیں ہم اس کا شریک ٹھیراتے تھے\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmmmccxviii{پس انہیں ان کے ایمان نے نفع نہ دیا جب انہوں نے ہمارا عذاب دیکھ لیا یہ سنت الہیٰ ہے جو اس کے بندو ں میں گزر چکی ہے اور اس وقت کافر خسارہ میں رہ گئے\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmmmccxix{\basmalahur حمۤ\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmccxx{(یہ کتاب) بڑے مہربان نہایت رحم والے کی طرف سے نازل ہوئی ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxi{کہ جس کی آیتیں عربی زبان میں علم والوں کے لیے واضح ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxii{خوشخبری دینے والی ڈرانے والی ہےپھر ان میں سے اکثر نے تو منہ ہی پھیر لیا پھر وہ سنتے بھی نہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxiii{اور کہتے ہیں ہمارے دل اس بات سے کہ جس کی طرف تو ہمیں بلاتا ہے پردوں میں ہیں اور ہمارے کانوں میں بوجھ ہے اور ہمارے اور آپ کے درمیان پردہ پڑا ہوا ہے پھر آپ اپنا کام کیے جائیں ہم بھی اپنا کام کر رہے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxiv{آپ ان سے کہہ دیں کہ میں بھی تم جیسا ایک آدمی ہوں میری طرف یہی حکم آتا ہے کہ تمہارا معبود ایک ہی ہے پھراس کی طرف سیدھے چلے جاؤ اور اس سے معافی مانگو اور مشرکوں کے لیے ہلاکت ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxv{جو زکواة نہیں دیتے اور وہ آخرت کے بھی منکر ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxvi{بے شک جو لوگ ایمان لائے اور انہوں نے نیک کام بھی کیے ان کے لیے بے انتہا اجر ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxvii{کہہ دو کیا تم اس کا انکار کرتے ہو جس نے دو دن میں زمین بنائی اور تم اس کے لیے شریک ٹھیراتے ہو وہی سب جہانوں کا پروردگار ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxviii{اور اس نے زمین میں اوپر سے پہاڑ رکھے اور اس میں برکت دی اور چار دن میں اس کی غذاؤں کا اندازہ کیا (یہ جواب) پوچھنے والوں کے لیے پورا ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxix{پھر وہ آسمان کی طرف متوجہ ہوا اور وہ دھؤاں تھا پس اس کو اور زمین کو فرمایا کہ خوشی سے آؤ یا جبر سے دونوں نے کہا ہم خوشی سے آئے ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxx{پھر انہیں دو دن میں سات آسمان بنا دیا اور اس نے ہر ایک آسمان میں اس کا کام القا کیا اور ہم نے پہلے آسمان کو چراغوں سے زینت دی اور حفاظت کے لیے بھی یہ زبردست ہر چیز کے جاننے والے کا اندازہ ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxi{پس اگر وہ نہ مانیں تو کہہ دو میں تمہیں کڑک سے ڈراتا ہوں جیسا کہ قوم عاد اور ثمود پر کڑک آئی تھی\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxii{جب ان کے پاس رسول آئے ان کے سامنے سے اور ان کے پیچھے سے کہ سوائے الله کے کسی کی عبادت نہ کرو تو کہنے لگےکہ اگر ہمارا رب چاہتا تو فرشتے نازل کر دیتا پس ہم تو اس چیز سے جو تم دے کر بھیجے گئے ہو منکر ہیں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxiii{پس قوم عاد نے زمین میں ناحق تکبر کیا اورکہا ہم سے طاقت میں کون زیادہ ہے کیا انہوں نے دیکھا نہیں کہ الله جس نے انہیں پیدا کیا ہے وہ ان سے طاقت میں کہیں بڑھ کر ہے وہ ہماری آیتوں کا انکار کرتے رہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxiv{پس ہم نے ان پر منحوس دنوں میں تیز آندھی بھیجی تاکہ ہم انہیں ذلت کے عذاب کا مزہ دنیا کی زندگی میں چکھا دیں اور آخرت کا عذاب تواور بھی ذلت کا ہے اور ان کی مدد نہ کی جائے گی\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxv{اور وہ جو قوم ثمود تھی ہم نے انہیں ہدایت کی سو انہوں نے گمراہی کو بمقابلہ ہدایت کے پسند کیا پھر انہیں کڑاکے کے ذلیل کرنے والے عذاب نے آ لیا ان کے اعمال کے سبب سے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxvi{اورجو لوگ ایمان لائے اور ڈرتے رہتے تھے ہم نے انہیں بچا لیا\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxvii{اور جس دن الله کے دشمن دوزخ کی طرف ہانکیں جائیں گے تو وہ روک لیے جائیں گے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxviii{یہاں تک کہ جب وہ اس کے پاس آ پہنچیں گے تو ان پر ان کے کان اور ان کی آنکھیں اور ان کی کھالیں گواہی دیں گی جو کچھ وہ کیا کرتے تھے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxix{وہ اپنی کھالوں سے کہیں گے کہ تم نے ہمارے خلاف کیوں گواہی دی وہ کہیں گے کہ ہمیں الله نے گویائی دی جس نے ہر چیز کو گویائی بخشی ہے اور اسی نے پہلی مرتبہ تمہیں پیدا کیا اور اسی کی طرف تم لوٹائے جاؤ گے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmccxl{اور تم اپنے کانوں اور آنکھوں اور چمڑو ں کی اپنے اوپر گواہی دینے سے پردہ نہ کرتے تھے لیکن تم نے یہ گمان کیا تھا جو کچھ تم کرتے ہو اس میں سے بہت سی چیزوں کو الله نہیں جانتا\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmccxli{او رتمہارے اسی خیال نے جو تم نے اپنے رب کے حق میں کیا تھا تمہیں برباد کیا پھر تم نقصان اٹھانے والو ں میں سے ہوگئے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmccxlii{پس اگر وہ صبر کریں تو بھی ان کا ٹھکانہ آگ ہی ہے اور اگر وہ معافی چاہیں گے تو انہیں معافی نہیں دی جائے گی\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmccxliii{اورہم نے ان کے لیے کچھ ہمنشین مقرر کر دیئے پس انہوں نے ان کو وہ (برے کام) اچھے کر دکھائے جو پہلے کر چکے تھے اورجو پیچھے کریں گے اور ان پر حکم الہیٰ ثابت ہو چکا تھاپہلی امتوں کے ضمن میں جو ان سے پہلے جنوں اور انسانوں میں سے گزر چکی تھیں بے شک وہ نقصان اٹھانے والے تھے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmccxliv{اور کافروں نے کہا کہ تم اس قرآن کو نہ سنو اور اس میں غل مچاؤ تاکہ تم غالب ہو جاؤ\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmccxlv{پس ہم ضرور کافرو ں کو سخت عذاب کا مزہ چکھائیں گے اور ہم ان کے بدترین اعمال کا بدلہ دیں گے جو وہ کیا کرتے تھے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmccxlvi{الله کے دشمنوں کی یہی سزا آگ ہی ہے ان کے لیے اس میں ہمیشہ رہنے کا گھر ہے اس کا بدلہ جو ہماری آیتوں کاانکار کیا کرتے تھے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmccxlvii{اور کافر کہیں گے اے ہمارے رب ہمیں وہ لوگ دکھا جنہوں نے ہمیں گمراہ کیا تھا جنّوں اور انسانوں میں سے ہم انہیں اپنے قدموں کے نیچے ڈال دیں تاکہ وہ بہت ذلیل ہوں\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmccxlviii{بے شک جنہوں نے کہا تھا کہ ہمارا رب الله ہے پھر اس پر قائم رہے ان پر فرشتے اتریں گے کہ تم خوف نہ کرو اور نہ غم کرو اور جنت میں خوش رہو جس کا تم سے وعدہ کیا جاتا تھا\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmccxlix{ہم تمہارے دنیا میں بھی دوست تھے اور آخرت میں بھی اور بہشت میں تمہارے لیے ہر چیز موجود ہے جس کو تمہارا دل چاہے اور تم جو وہاں مانگو گے ملے گا\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmccl{بخشنے والے نہایت رحم والے کی طرف سے مہمانی ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmccli{اور اس سے بہتر کس کی بات ہے جس نے لوگوں کو الله کی طرف بلایا اور خود بھی اچھے کام کیے اور کہا بے شک میں بھی فرمانبرداروں میں سے ہوں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmcclii{اور نیکی اور بدی برابر نہیں ہو تی (برائی کا) دفعیہ اس بات سے کیجیئے جو اچھی ہو پھر ناگہاں وہ شخص جو تیرے اور اس کے درمیان دشمنی تھی ایسا ہوگا گویاکہ وہ مخلص دوست ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmccliii{اور یہ بات نہیں دی جاتی مگر انہیں جو صابر ہوتے ہیں اور یہ بات نہیں دی جاتی مگر اس کو جو بڑا بخت والا ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmccliv{اور اگر آپ کو شیطان سے کوئی وسوسہ آنے لگے تو الله کی پناہ مانگیئے بے شک وہی سب کچھ سننے والا جاننے والا ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmcclv{اور اس کی نشانیوں میں سے رات اور دن اور سورج اور چاند ہیں سورج کو سجدہ نہ کرو اور نہ چاند کو اور اس الله کو سجدہ کرو جس نے انہیں پیدا کیا ہے اگر تم اسی کی عبادت کرتے ہو\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmcclvi{پھر اگر وہ تکبر کریں تو وہ لوگ جو آپ کے رب کے پاس ہیں رات دن اس کی تسبیح کرتے ہیں اور تھکتے نہیں\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmcclvii{اور اس کی نشانیوں میں سے یہ ہے کہ تو زمین کو دبی ہوئی دیکھتا ہے پھر جب ہم اس پر پانی برساتے ہیں تو ابھرتی ہے اور پھولتی ہے بے شک جس نے اسےزندہ کیا وہی مردوں کو زندہ کرے گا بے شک وہی ہر چیز پر قادر ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmcclviii{بے شک جو لوگ ہماری آیتوں میں کجروی کرتے ہیں وہ ہم سے چھپے نہیں رہتے کیا وہ شخص جو آگ میں ڈالا جائے گا بہتر ہے یا وہ جو قیامت کے دن امن سے آئے گا جو چاہو کرو جو کچھ تم کرتے ہو وہ دیکھ رہا ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmcclix{بے شک وہ لوگ جنہوں نے نصیحت سے انکار کیا جب کہ وہ ان کے پاس آئی اور تحقیق وہ البتہ عزت والی کتاب ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmcclx{جس میں نہ آگے اور نہ پیچھے سے غلطی کا دخل ہے حکمت والے تعریف کیے ہوئے کی طرف سے نازل کی گئی ہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxi{آپ سے وہی بات کہی جاتی ہے جو آپ سے پہلے رسولوں سے کہی گئی تھی بے شک آپ کا رب بخشنے والا اور دردناک عذاب دینے والا بھی ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxii{اور اگر ہم اسے عجمی زبان کا قرآن بنا دیتے توکہتے کہ اس کی آیتیں صاف صاف بیان کیوں نہیں کی گئیں کیا عجمی کتاب اور عربی رسول کہہ دو یہ ایمان داروں کے لیے ہدایت اور شفا ہے او رجو لوگ ایمان نہیں لاتے ان کے کان بہرے ہیں اور وہ قرآن ان کے حق میں نابینائی ہے وہ لوگ (گو یاکہ) دور جگہ سے پکارے جا رہے ہیں\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxiii{اورہم نے موسیٰ کو کتاب دی تھی پھر اس میں اختلاف کیا گیا اور اگر آپ کے رب کی طرف سے ایک بات صادر نہ ہو چکی ہوتی تو ان کا فیصلہ ہی ہو چکا ہوتا اورانہیں تو قرآن میں قوی شک ہے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxiv{جو کوئی نیک کام کرتاہے تو اپنے لیے اور برائی کرتا ہے تو اپنے سر پر اور آپ کا رب تو بندوں پر کچھ بھی ظلم نہیں کرتا\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxv{قیامت کی خبرکا اسی کی طرف حوالہ دیا جاتا ہے اور کوئی پھل اپنے غلافوں سے نہیں نکلتا اور نہ کوئی مادہ حاملہ ہوتی ہے اور نہ وضح حمل کرتی ہے مگر اس کے علم سے اور جس دن انہیں پکارے گا کہ میرے شریک کہاں ہیں کہیں گے ہم نے آپ سے عرض کر دیا کہ ہم میں سے کسی کو بھی خبر نہیں\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxvi{اور ان سے وہ کھوئے جائیں گے جنہیں اس سے پہلے پکارتے تھے اوریقین کر لیں گے کہ انہیں کسی طرح بھی چھٹکارا نہیں\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxvii{انسان بھلائی مانگنے سے نہیں تھکتا اور اگر اسے کوئی تکلیف پہنچ جائے تو مایوس اور نا امید ہو جاتا ہے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxviii{اور اگر ہم اسے اس مصیبت کے بعدجو اس پر آئی تھی اپنی رحمت کا مزہ چکھاتے ہیں تو کہتا ہے یہ میرا حق تھا اور میں نہیں خیال کرتا کہ قیامت قائم ہو گی اور اگر میں اپنے رب کے پاس گیا بھی تو بے شک میرے لیے اس کے ہاں بھلائی ہی ہو گی ہم کافروں کو ضرور بتائیں گے جو کچھ وہ کرتے رہے اور ہم ضرور انہیں سخت عذاب چکھائیں گے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxix{اور جب ہم نے انسان پر انعام کیا تو اس نے منہ پھیر لیا اور کنارہ کش ہو گیا اور جب اس کو تکلیف پہنچی تو لمبی چوڑی دعا کرنے لگا\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxx{کہہ دو بھلا دیکھوتو سہی اگر یہ قرآن الله کی طرف سے ہو پھر تم اس کا انکار کر بیٹھے تو ایسے پرلے درجہ کے ضدی سے کون زیادہ گمراہ ہو گا\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxi{عنقریب ہم اپنی نشانیاں انہیں دنیا میں دکھائیں گے اور خود ان کے نفس میں یہاں تک کہ ان پر واضح ہو جائے گا کہ وہی حق ہے کیا ان کے رب کی یہ بات کافی نہیں کہ وہ ہر چیز کو دیکھ رہا ہے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxii{خبردار انہیں اپنے رب کے پاس حاضر ہونے میں شک ہے خبردار بے شک وہ ہر چیز کوگھیرے ہوئے ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxiii{\basmalahur حمۤ\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxiv{عۤسۤقۤ\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxv{اسی طرح سے الله زبردست حکمت والا آپ کی طرف وحی کرتا ہے اور ان کی طرف بھی (کرتا تھا) جو آپ سے پہلے تھے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxvi{اسی کا ہے جو کچھ آسمانوں اور زمین میں ہے اور وہ بلند مرتبہ بزرگی والا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxvii{قریب ہے کہ آسمان اوپر سے پھٹ جائیں اور سب فرشتے اپنے رب کی حمد کے ساتھ تسبیح کرتے ہیں اور ان کے لیے جو زمین میں ہیں مغفرت مانگتے ہیں خبردار بے شک الله ہی بخشنے والا نہایت رحم والا ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxviii{اور وہ لوگ جنہوں نے اس کے سوا اور کارساز بنا رکھے ہیں الله ان کا حال دیکھ رہا ہے اور آپ ان کے ذمہ دار نہیں ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxix{اور اسی طرح ہم نے آپ پر عربی زبان میں قرآن نازل کیا تاکہ آپ مکہ والوں اور اس کے آس پاس والوں کو ڈرائیں اور قیامت کے دن سے بھی ڈرائیں جس میں کوئی شبہ نہیں (اس روز) ایک جماعت جنت میں اور ایک جماعت جہنم میں ہو گی\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxx{اور اگر الله چاہتا تو ان سب کو ایک ہی جماعت کر دیتا لیکن الله جسے چاہتا ہے اپنی رحمت میں داخل کرتا ہے اور ظالموں کا نہ کوئی دوست ہے اور نہ کوئی مددگار\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxi{کیا انہوں نے اس کے سوا اوربھی مددگار بنا رکھے ہیں پھر الله ہی مددگار ہے اور وہی مردووں کو زندہ کرے گا اور وہ ہر چیز پر قادر ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxii{اور جس بات میں بھی تم اختلاف کرتے ہو سو اس کا فیصلہ الله کے سپرد ہے وہی الله میرا رب ہے اسی پر میرا بھروسہ ہے اور اس کی طرف میں رجوع کرتا ہوں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxiii{وہ آسمانوں اور زمین کا پیدا کرنے والا ہے اسی نے تمہاری جنس سے تمہارے جوڑے بنائے اور چارپایوں کےبھی جوڑے بنائے تمہیں زمین میں پھیلاتا ہے کوئی چیز اس کی مثل نہیں اور وہ سننے والا دیکھنے والا ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxiv{اس کے ہاتھ میں آسمانوں اور زمین کی کنجیاں ہیں روزی کشادہ کرتا ہے جس کی چاہے اور تنگ کر دیتا ہے بے شک وہ ہر چیز کو جاننے والا ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxv{تمہارے لیے وہی دین مقرر کیا جس کا نوح کو حکم دیا تھا اور اسی راستہ کی ہم نے آپ کی طرف وحی کی ہے اور اسی کا ہم نے ابراھیم اور موسیٰ اور عیسیٰ کو حکم دیا تھا کہ اسی دین پر قائم رہو اور اس میں پھوٹ نہ ڈالنا جس چیز کی طرف آپ مشرکوں کو بلاتے ہیں وہ ان پر گراں گزرتی ہے الله جسے چاہے اپنی طرف کھینچ لیتا ہے اور جو اس کی طرف رجوع کرتا ہے اسے راہ دکھاتا ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxvi{اور اہلِ کتاب جوجدا جدا فرقے ہوئے تو علم آنے کے بعد اپنی باہمی ضد سے ہوئے اور اگر تیرے رب کی طرف سے ایک وقت مقرر (قیامت) تک کا وعدہ نہ ہوتا تو ان میں فیصلہ ہوگیا ہوتا اور جو ان کے بعد کتاب کے وارث بنائے گئے ہیں (زمانہِ نبوی کے اہل کتاب) وہ اس (دین) کی نسبت حیرت انگیز شک میں ہیں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxvii{تو آپ اسی دین کی طرف بلائیے اور قائم رہیئے جیسا آپ کو حکم دیا گیا ہے اور ان کی خواہشوں پر نہ چلیئے اور کہہ دو کہ میں اس پر یقن لایا ہوں جو اللهنےکتاب نازل کی ہے اور مجھے حکم دیا گیا ہے کہ میں تمہارے درمیان انصاف کروں اللہ ہی ہمارا اور تمہارا پروردگار ہے ہمارے لیے ہمارےاعمال ہیں اور تمہارے لیے تمہارے اعمال اور تمہارے درمیان کوئی جھگڑا نہیں الله ہم سب کو جمع کر لے گا اور اسی کی طرف لوٹ کر جانا ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxviii{اور جو لوگ الله (کے دین) کے بارے میں جھگڑتے ہیں بعد اس کے کہ وہ مان لیا گیا ان لوگوں کی حجّت ان کے رب کے ہاں باطل ہے اور ان پر غضب ہے اور ان کے لیے سخت عذاب ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxix{الله ہی ہے جس نے سچی کتاب اور ترازو نازل کی اور آپ کو کیا معلوم شاید قیامت قریب ہو\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmccxc{اس کی جلدی تووہی کرتے ہیں جو اس پر ایمان نہیں رکھتے اور جو ایمان رکھتے ہیں وہ اس سے ڈر رہے ہیں اور جانتے ہیں کہ وہ برحق ہے خبردار بے شک جو لوگ قیامت کے بارہ میں جھگڑا کرتے ہیں وہ پرلے درجے کی گمراہی میں ہیں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmccxci{الله اپنے بندوں پر بڑا مہربان ہے جسے (جس قدر) چاہے روزی دیتا ہے اوروہ بڑا طاقتور زبردست ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmccxcii{جو کوئی آخرت کی کھیتی کا طالب ہو ہم اس کے لیے اس کھیتی میں برکت دیں گے اور جو دنیا کی کھیتی کا طالب ہو اسے (بقدر مناسب) دنیا میں دیں گے اور آخرت میں اس کا کچھ حصہ نہیں ہوگا\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmccxciii{کیا ان کے اور شریک ہیں جنہوں نے ان کے لیے دین کا وہ طریقہ نکالا ہے جس کی الله نے اجازت نہیں دی اور اگر فیصلہ کا وعدہ نہ ہوا ہوتا تو ان کا دنیا ہی میں فیصلہ ہو گیا ہو تا اور بے شک ظالموں کے لیے دردناک عذاب ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmccxciv{آپ ظالموں کو (قیامت کے دن) دیکھیں گے کہ اپنے اعمال (کے وبال) سے ڈر رہے ہوں گے اور ان پر پڑنے والا اور جو لوگ ایمان لائے اور نیک کام کیے وہ بہشت کے باغوں میں ہوں گے انہیں جو چاہیں گے اپنے رب کے ہاں سے ملے گا یہی وہ بڑا فضل ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmccxcv{یہی وہ (فضل) جس کی الله اپنے بندوں کو خوشخبری دے دیتا ہے جو ایمان لائے اور نیک کام کیے کہہ دو میں تم سے اس پر کوئی اجرات نہیں مانگتا بجز رشتہ داری کی محبت کے اور جو نیکی کمائے گا تو ہم اس میں اس کے لیے بھلائی زیادہ کردیں گے بے شک الله بخشنے والا قدردان ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmccxcvi{کیا وہ کہتے ہیں کہ آپ نے الله پر جھوٹ باندھا ہے پس اگر الله چاہے تو آپ کے دل پر مُہر کر دے اور الله باطل کو مٹا دیتا ہے اور سچ کو اپنی کلام سے ثابت کر دیتا ہے بے شک وہ سینوں کے بھید خوب جانتا ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmccxcvii{اور وہی ہے جو اپنے بندوں کی توبہ قبول کرتا ہے اور ان کے گناہ معاف کر دیتا ہے اور جانتا ہے جو تم کرتے ہو\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmccxcviii{اور ان کی دعا قبول کرتا ہے جو ایمان لائے اور نیک کام کیے اور انہیں اپنے فضل سے زیادہ دیتا ہے او رکافروں کے لیے سخت عذاب ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmccxcix{اور اگر الله اپنے بندوں کی روزی کشادہ کر دے تو زمین پر سرکشی کرنے لگیں لیکن وہ ایک اندازے سے اتارتا ہے جتنی چاہتا ہے بے شک وہ اپنے بندوں سے خوب خبردار دیکھنے والا ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmccc{اور وہی ہے جو ناامید ہو جانے کے بعد مینہ برساتا ہے اور اپنی رحمت کو پھیلاتا ہے اور وہی کارساز احمد کے لائق ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmccci{اور اس کی نشانیوں میں سے ایک یہ بھی ہے کہ آسمانوں اور زمین کو بنایا اور اس پر ہر قسم کے چلنے والے جانور پھیلائے اوروہ جب چاہے گا ان کے جمع کرنے پر قادر ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmcccii{اور تم پر جو مصیبت آتی ہے تو وہ تمہارے ہی ہاتھوں کے کیے ہوئے کاموں سے آتی ہے اور وہ بہت سے گناہ معاف کر دیتا ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmccciii{اور تم زمین میں عاجز کرنے والے نہیں اور سوائے الله کے نہ کوئی تمہارا کارساز ہے اور نہ کوئی مددگار\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmccciv{اور اس کی نشانیوں میں سے سمندر میں پہاڑوں جیسے جہاز ہیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmcccv{اگر وہ چاہے تو ہوا کو ٹھیرا دے پس وہ اس کی سطح پر کھڑ ے رہ جائیں بے شک اس میں ہر صبر کرنے والے شکر گزار کے لیے نشانیاں ہیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmcccvi{یا ان کے برے اعمال کے سبب سے انہیں تباہ کر دے اور بہتوں کو معاف بھی کر دیتا ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmcccvii{اور جان لیں وہ جو ہماری آیتوں میں جھگڑتے ہیں کہ ان کے لیے پناہ کی کوئی جگہ نہیں\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmcccviii{پھر جو کچھ تمہیں دیا گیا ہے وہ دنیا کی زندگی کا سامان ہے اور جو کچھ الله کے پاس ہے وہ بہتر اور سدا رہنے والا ہے یہ ان کے لیے ہے جو ایمان لائے اور اپنے رب پر توکل کرتے ہیں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmcccix{اوروہ جو بڑے بڑے گناہوں اور بے حیائی سے بچتے ہیں اور جب غضہ ہوتے ہیں تو معاف کر دیتے ہیں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmcccx{اور وہ جو اپنے رب کا حکم مانتے ہیں اور نماز ادا کرتے ہیں اور ان کا کام باہمی مشورے سے ہوتا ہے اور ہمارے دیے ہوئے میں سے کچھ دیا بھی کرتے ہیں\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxi{اور وہ لوگ جب ان پر ظلم ہوتا ہے تو بدلہ لیتے ہیں\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxii{اوربرائی کا بدلہ ویسی ہی برائی ہے پس جس نے معاف کر دیا اور صلح کر لی تو اس کا اجر الله کے ذمہ ہے بے شک وہ ظالموں کو پسند نہیں کرتا\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxiii{اور جو کوئی ظلم اٹھانے کے بعد بدلہ لے تو ان پر کوئی الزام نہیں\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxiv{الزام تو ان پر ہے جو لوگوں پر ظلم کرتے ہیں اور ملک میں ناحق سرکشی کرتے ہیں یہی ہیں جن کے لیے دردناک عذاب ہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxv{اور البتہ جس نے صبر کیا اور معاف کر دیا بے شکے یہ بڑی ہمت کا کام ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxvi{اور جسے الله گمراہ کر دے سو اس کے بعد اس کا کوئی کارساز نہیں اور ظالموں کو دیکھیں گے جب وہ عذاب دیکھیں گے تو کہیں گے کیا واپس جانے کا بھی کوئی راستہ ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxvii{اور آپ انہیں دیکھیں گے کہ وہ دوزخ کے سامنے لائے جائيں گے ایسے حال میں ذلت کے مارے جھکے ہوئے ہوں گے چھپی نگاہ سے دیکھ رہے ہوں گے اور وہ لوگ کہیں گے جو ایمان لائے تھے بے شک خسارہ اٹھانے والے وہی لوگ ہیں جنہوں نے اپنے آپ کو اوراپنے گھر والوں کو قیامت کے دن خسارہ میں رکھا خبردار بے شک ظالم ہی ہمیشہ عذاب میں ہوں گے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxviii{اور ان کا الله کے سوا کوئی بھی حمایتی نہ ہوگا کہ ان کو بچائے اورجسے الله گمراہ کرے اس کے لیے کوئی بھی راستہ نہیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxix{اس سے پہلے اپنے رب کا حکم مان لو کہ وہ دن آجائے جو الله کی طرف سے ٹلنے والا نہیں اس دن تمہارے لیے کوئی جائے پناہ نہیں ہو گی اور نہ تم انکارکر سکو گے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxx{پھر بھی اگر نہ مانیں تو ہم نے آپ کو ان پر محافظ بنا کرنہیں بھیجا ہے آپ پر تو صرف پہنچا دینا ہے اور جب ہم انسان کو اپنی کوئی رحمت چکھاتے ہیں تو اس سے خوش ہوجاتا ہے اور اگر اس پر اس کے اعمال سے اس سے کوئی مصیبت پڑ جاتی ہے تو انسان بڑا ہی ناشکرا ہے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxi{آسمانوں اور زمین میں الله ہی کی بادشاہی ہے جو چاہتا ہے پیدا کر تا ہے جسے چاہتا ہے لڑکیاں عطا کرتا ہے اور جسے چاہتا ہے لڑکے بخشتا ہے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxii{یا لڑکے اور لڑکیاں ملا کر دیتا ہے اور جسے چاہتا ہے بانجھ کر دیتا ہے بے شک وہ خبردار قدرت والا ہے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxiii{اور کسی انسان کا حق نہیں کہ اس سے الله کلام کر لے مگر بذریعہ وحی یا پردے کے پیچھے سے یا کوئی فرشتہ بھیج دے کہ وہ اس کے حکم سے القا کر لے جو چاہے بے شک وہ بڑاعالیشان حکمت والا ہے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxiv{اور اسی طرح ہم نے آپ کی طرف اپنا حکم سے قرآن نازل کیا آپ نہیں جانتے تھے کہ کتاب کیا ہے او رایمان کیا ہے او رلیکن ہم نے قرآن کو ایسا نور بنایا ہے کہ ہم اس کے ذریعہ سے ہم اپنے بندوں سے جسے چاہتے ہیں ہدایت کرتے ہیں اور بے شک آپ سیدھا راستہ بتاتے ہیں\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxv{اس الله کا راستہ جس کے قبضہ میں آسمانوں اور زمین کی سب چیزیں ہیں خبردار الله ہی کی طرف سب کام رجوع کرتے ہیں\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxvi{\basmalahur حمۤ\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxvii{روشن کتاب کی قسم ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxviii{ہم نے اسے عربی زبان میں قرآن بنایا ہے تاکہ تم سمجھو\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxix{اور یہ کتاب لوح محفوظ میں ہمارے نزدیک بلند مرتبہ حکمت والی ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxx{کیا تمہارے سمجھانے سے ہم اس لیے منہ پھیر لیں گے کہ تم بیہودہ لوگ ہو\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxi{اور پہلے لوگوں میں بھی ہم نے بہت سے نبی بھیجے ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxii{اور ان کے پاس ایسا کوئی نبی نہ آتا تھا کہ جس سے وہ ٹھٹھا نہ کرتے تھے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxiii{پھر ہم نے ان میں بڑے زور والوں کو ہلاک کر دیا او رپہلوں کی مثال گزرچکی ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxiv{اور اگر آپ ان سے پوچھیں کہ آسمانوں اور زمین کو کس نے پیدا کیا ہے تو ضرور کہیں گے کہ انہیں اس بڑے زبردست جاننے والے نے پیدا کیا ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxv{وہ جس نے زمین کو تمہارا بچھونا بنایا اور تمہارے لیے اس میں راستے بنائے تاکہ تم راہ پاؤ\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxvi{اور وہ جس نے آسمان سے اندازے کے ساتھ پانی اتارا پھر ہم نے اس سے مردہ بستی کو زندہ کیا تم بھی اس طرح (قبروں سے) نکالے جاؤ گے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxvii{اوروہ جس نے ہر قسم کے جوڑے بنائے اور تمہارے لیے وہ کشتیاں اور چار پائے بنائے جن پر تم سوار ہوتے ہو\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxviii{تاکہ ان کی پیٹھ پر چڑھ کر اپنے رب کا احسان یاد کرو جب کہ تم ان پر خوب بیٹھ جاؤ اورکہو وہ ذات پاک ہے جس نے ہمارے لیے اسے مطیع کر دیا اور ہم اسے قابو میں لانے والے نہ تھے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxix{اور بےشک ہم اپنے رب کی طرف لوٹنے والے ہیں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxl{اورلوگوں نے اس کے بندوں کو اس کی اولاد بنا دیا بے شک انسان صریح ناشکرا ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxli{کیا اس نے اپنی مخلوقات میں سے بیٹیاں لے لیں اور تمہیں بیٹے چن کر دیئے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxlii{اور جب ان میں سے کسی کو اس چیز کی خوشخبری دی جائے جسے رحمان کے لیے ٹھیراتا ہے تو اس کا منہ سیاہ ہو جاتا ہے اور و ہ دل میں کڑھتا رہتا ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxliii{کیا اس کے لیے وہ ہے جو زیور میں پلتی ہے اور وہ جھگڑتے میں بات نہیں کر سکتی\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxliv{اورفرشتوں کو جو رحمان کے بندے ہیں عورتیں فرض کر لیا کیا انھوں نے پیدا ہوتے دیکھا ہے ان کی گواہی لکھی جائے گی اور ان سے پوچھا ئے گا\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxlv{اور کہتے ہیں اگر رحمان چاہتا تو ہم انہیں نہ پوجتے انہیں اس کی کچھ خبر نہیں وہ محض اٹکل دوڑاتے ہیں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxlvi{کیا ہم نے انہیں اس سے پہلے کوئی کتاب دی ہے کہ یہ اس پر قائم ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxlvii{بلکہ وہ کہتے ہیں کہ ہم نے اپنے باپ دادا کو ایک طریقہ پر پایا ہے اور انہیں کے ہم پیرو ہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxlviii{اور اسی طرح ہم نے آپ سے پہلے کسی گاؤں میں بھی کوئی ڈرانے والا بھیجا تو وہاں کے دولت مندوں نے (یہی) کہا کہ ہم نے اپنے باپ دادا کو ایک طریقہ پر پایا اور ہم انہیں کے پیرو ہیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxlix{رسول نے کہا اگرچہ میں تمہارے پاس اس سے بھی بہتر طریقہ لاؤں جس پر تم نے اپنے باپ دادا کو پایا انہوں نے کہا جو کچھ تو لایا ہے ہم اس کے منکر ہیں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmcccl{پھر ہم نے ان سے بدلہ لیا پھر دیکھ جھٹلانے والوں کا انجام کیا ہوا\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmcccli{اور جب ابراھیم نے اپنے باپ اور اپنی قوم سے کہا کہ بے شک میں ان سے بیزار ہوں جن کی تم عبادت کرتے ہو\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmccclii{سوائے اس ذات کے جس نے تجھے پیدا کیا سو بے شک وہی تجھے راہ دکھائے گا\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmcccliii{اور یہی بات اپنی اولاد میں پیچھے چھوڑ گیا تاکہ وہ رجوع کریں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmcccliv{بلکہ میں نے ان کو اوران کے باپ دادا کو خوب سامان دیا یہاں تک کہ ان کے پاس سچا قرآن اور صاف صاف بتانے والا رسول آیا\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmccclv{اورجب ان کے پاس سچا قرآن پہنچا تو کہا کہ یہ توجادو ہے اور ہم اسے نہیں مانتے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmccclvi{اور کہا کیوں یہ قرآن ان دو بستیوں کےکسی سردار پر نازل نہیں کیا گیا\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmccclvii{کیا وہ آپ کے رب کی رحمت تقسیم کرتے ہیں ان کی روزی تو ہم نے ان کے درمیان دنیا کی زندگی میں تقسیم کی ہے اور ہم نے بعض کے بعض پر درجے بلند کیے تاکہ ایک دوسرے کو محکوم بنا کررکھے اور آپ کے رب کی رحمت اس سے کہیں بہتر ہے جو وہ جمع کرتے ہیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmccclviii{اوراگر یہ نہ ہوتا کہ سب لوگ ایک طریقہ کے ہوجائیں گے (کافر) تو جو الله کے منکر ہیں انکے گھروں کی چھت اور ان پر چڑھنے کی سیڑھیاں چاندی کی کر دیتے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmccclix{اوران کے گھروں کے دروازے اور تخت بھی چاندی کے کر دیتے جن پر وہ تکیہ لگا کر بیٹھتے ہیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmccclx{اور سونے کے بھی اور یہ سب کچھ دنیا کی زندگی کا سامان ہے اور آخرت آپ کے رب کے ہاں پرہیزگاروں کے لیے ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxi{اورجو الله کی یاد سے غافل ہوتا ہے تو ہم اس پر ایک شیطان متعین کر تے ہیں پھر وہ اس کا ساتھی رہتا ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxii{اور شیاطین آدمیوں کو راستے سے روکتے ہیں اور وہ سمجھتے ہیں کہ ہم راہِ راست پر ہیں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxiii{یہاں تک کہ جب وہ ہمارے پاس آئے گا تو کہے گا اے کاش میرے اور تیرے درمیان مشرق اور مغرب کی دوری ہوتی پس کیسا برا ساتھی ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxiv{اورآج تمہیں یہ بات ہر گز نفع نہ دے گی چونکہ تم نے ظلہم کیا تھا بے شک تم عذاب میں شریک ہو\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxv{پس کیا آپ بہروں کو سنا سکتے ہیں یااندھوں کو راہ دکھا سکتے ہیں اور انہیں جو صریح گمراہی میں ہیں\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxvi{پس اگر ہم آپ کو (دنیا سے) اٹھالیں تو بھی ہم ان سے بدلہ لیں گے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxvii{یا اگر ہم آپ کووہ دکھا بھی دیں جس کا ہم نے ان سے وعدہ کیا ہے تو ہم ان پر قادر ہیں\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxviii{پھر آپ مضبوطی سے پکڑیں اسے جو آپ کی طرف وحی کیا گیا ہے بے شک آپ سیدھے راستہ پر ہیں\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxix{اور بے شک وہ (قرآن) آپ کے لیے اور آپ کی قوم کے لیے ایک نصیحت ہے اور تم سب سے ا سکی باز پرس ہو گی\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxx{اور آپ ان سب پیغمبروں سے جنہیں ہم نے آپ سے پہلے بھیجا ہے پوچھ لیجیئے کیا ہم نے رحمان کے سوا دوسرے معبود ٹھیرا لئے تھے کہ انکی عبادت کی جائے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxi{اور ہم نے موسیٰ کو اپنی نشانیاں دے کر فرعون اور اس کے امرائے دربار کی طرف بھیجا تھا سو اس نے کہا کہ میں پروردگار عالم کا رسول ہوں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxii{پس جب وہ ان کے پاس ہماری نشانیاں لایا تو وہ اس کی ہنسی اڑانے لگے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxiii{اور ہم ان کو جو کوئی نشانی دکھاتے تھے تو ایک دوسرے سے بڑھ کر ہوتی تھی اور ہم نے انہیں عذاب میں پکڑا تاکہ وہ باز آ جائیں\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxiv{اور انہوں نے کہا اے جادوگر اپنے رب سے ہمارے لیے اس عہد سے جو تجھ سے اس نے کیا ہے دعا کر ہم ضرور راہ پر آجائیں گے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxv{پھر جب ہم ان سے عذاب ہٹا لیتے تو اسی وقت عہد کو توڑ دیتے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxvi{اور فرعون نے اپنی قوم میں منادی کر کے کہہ دیا اے میری قوم کیا میرےلیے مصر کی بادشاہت نہیں اور کیا یہ نہریں میرے (محل کے) نیچے سے نہیں بہہ رہی ہیں پھر کیا تم نہیں دیکھتے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxvii{کیا میں اس سے بہتر نہیں ہوں جو ذلیل ہے اور صاف صاف بات بھی نہیں کر سکتا\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxviii{پھر اس کے لیے سونےکے کنگن کیوں نہیں اتارے گئے یا اس کے ہمراہ فرشتے پرے باندھے ہوئے آئے ہوتے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxix{پس اس نے اپنی قوم کو احمق بنا دیا پھر ا س کے کہنے میں آ گئے کیو ں کہ وہ بدکار لوگ تھے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxx{پس جب انہوں نے ہمیں غصہ دلا دیا تو ہم نے ان سے بدلہ لیا ہم نے ان سب کو غرق کر دیا\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxi{پھر ہم نے انہیں گئے گزرے اور پیچھے آنے والوں کے لیے کہاوت بنا دیا\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxii{اورجب ابن مریم کی مثال بیان کی گئی تو اسی وقت آپ کی قوم کے لوگ اس سے کھلکھلا کر ہنسنے لگے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxiii{اورکہا کیا ہمارے معبود بہتر ہیں یا وہ یہ ذکر صرف آپ سے جھگڑنے کے لیے کرتے ہیں بلکہ وہ تو جھگڑالو ہی ہیں\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxiv{وہ تو ہمارا ایک بندہ ہے جس پر ہم نے انعام کیا اور اسے بنی اسرائیل کے لیے نمونہ بنا دیا تھا\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxv{اور اگر ہم چاہیں تم میں سے فرشتے پیدا کریں جو زمین میں تمہاری جگہ رہیں\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxvi{اور البتہ عیسیٰ قیامت کی ایک نشانی ہے پس تم اس میں شبہ نہ کرو اور میری تابعداری کرو یہی سیدھا راستہ ہے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxvii{اور تمہیں شیطان نہ روکنے پائیں کیوں کہ وہ تمہارا صریح دشمن ہے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxviii{اور جب عیسیٰ واضح دلیلیں لے کر آیا تھا تو اس نے کہا تھا کہ میں تمہارے پاس دانائی کی باتیں لایا ہوں اورتاکہ تم پر بعض وہ باتیں واضح کر دوں جن میں تم اختلاف کرتے تھے پس الله سے ڈرو اور میرا حکم مانو\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxix{بے شک الله ہی میرا اور تمہارا پروردگار ہے پس اسی کی عبادت کرو وہی سیدھا راستہ ہے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxc{پھر لوگ ایک دوسرے سے مختلف ہو گئے پس جنہوں نے ظلم کیا ان کے لیے دردناک دن کے عذاب سے تباہی ہے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxci{کیا وہ قیامت کے ہی منتظر ہیں کہ ان پر یکایک آجائے اور ان کو خبر بھی نہ ہو\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxcii{اس دن دوست بھی آپس میں دشمن ہو جائیں گے مگر پرہیز گار لوگ\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxciii{(کہا جائے گا) اے میرے بندو تم پر آج نہ کوئی خوف ہے اور نہ تم غمگین ہو گے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxciv{جو لوگ ہماری آیتوں پر ایمان لائے اور فرمانبردار تھے\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxcv{تم اور تمہاری بیویاں خوشیاں کرتے ہوئے جنت میں داخل ہوجاؤ\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxcvi{ان کے سامنے سونے کے پیالے پیش کیے جائیں گے اور آبخورے بھی اور وہاں جس چیز کو دل چاہے گا اوبر جس سے آنکھیں خوش ہوں گی موجود ہو گی اور تم اس میں ہمیشہ رہو گے\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxcvii{اور یہی وہ جنت ہے جس کے تم وارث بنائے گئے ہو ان اعمال کے بدلے میں جو تم کرتے تھے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxcviii{تمہارے لیے وہاں بہت سے میوے ہیں جن میں سے کھایا کرو گے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxcix{بے شک گناہگار عذاب دوزخ ہی میں ہمیشہ رہیں گے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmmcd{ان سے ہلکا نہ کیا جائے گا اور وہ اسی میں مایوس پڑے رہیں گے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmmcdi{اور ہم نے تو ان پر ظلم نہیں کیا لیکن وہ خود ہی ظالم تھے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmmcdii{اور وہ پکاریں گے اے مالک تیرا پروردگار ہمارا کام تمام کر دے وہ کہے گا بے شک تمہیں تو ہمیشہ رہنا ہے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmmcdiii{ہم تو تمہارے پاس سچا دین لا چکےاورلیکن تم میں سے اکثر دین حق سے نفرت کرتے ہیں\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmmcdiv{کیا انہوں نے کوئی بات طے کرلی ہے تو ہم بھی طے کرنے والے ہیں\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmmmcdv{کیا وہ خیال کرتے ہیں کہ ہم ان کا بھید اور مشورہ نہیں سنتے کیوں نہیں اور ہمارے بھیجے ہوئے فرشتے ان کے پاس لکھ رہے ہیں\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmmmcdvi{کہہ دو اگر الله کا بیٹا ہوتا تو سب سے پہلے میں عبادت کرتا\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmmmcdvii{آسمانوں اور زمین اور عرش کا رب پاک ہے ان باتوں سے جو وہ بناتے ہیں\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmmmcdviii{پھر انہیں چھوڑ دو بک بک اور کھیل کود میں لگے رہیں یہاں تک کہ وہ دن دیکھ لیں جس کا ان سے وعدہ کیا جاتا ہے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmmmcdix{او روہی ہے جو آسمان میں بھی معبود ہے اور زمین میں بھی معبود ہے اور وہی حکمت والا جاننے والا ہے\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmmmcdx{اور وہ بڑا بابرکت ہے جس کی حکومت آسمانوں اور زمین میں ہے اور جو ان دونوں کے درمیان موجود ہے اور اسی کے پاس قیامت کا علم ہے اور اسی کی طرف تم سب لوٹائے جاؤ گے\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxi{اورجنہیں وہ اس کے سوا پکارتے ہیں انہیں تو شفاعت کا بھی اختیا رنہیں ہاں جن لوگوں نے حق بات کا اقرار کیا تھا اور وہ تصدیق بھی کرتے تھے\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxii{اور اگر آپ ان سے پوچھیں کہ انہیں کس نے پیدا کیا ہے تو ضرور کہیں گے الله نے پھر کہا ں بہکے جا رہے ہیں\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxiii{اور قسم ہے رسول کے یا رب پکارنے کی بے شک یہ ایسے لوگ ہیں کہ ایمان نہ لائیں گے\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxiv{پس آپ بھی ان سے منہ پھیر لیں اور سلام کہہ دیں پس انہیں خو دمعلوم ہو جائے گا\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxv{\basmalahur حمۤ\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxvi{روشن کتاب کی قسم ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxvii{ہم نے اسے مبارک رات میں نازل کیا ہے بے شک ہمیں ڈرانا مقصود تھا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxviii{سارے کام جو حکمت پر مبنی ہیں اسی رات تصفیہ پاتے ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxix{ہمارے خاص حکم سے کیوں کہ ہمیں رسول بھیجنا منظور تھا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxx{آپ کے پروردگار کی رحمت ہے بے شک وہی سب کچھ سننے والا جاننے والا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxi{آسمانوں اور زمین کا رب ہے اور جو کچھ ان کے درمیان ہے اگر تم یقین کر نے والے ہو\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxii{اس کے سوا اورکوئی معبود نہیں زندہ کرتا ہے اور مارتا ہے تمہارا بھی رب ہے او رتمہارے پہلے باپ دادا کا بھی\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxiii{بلکہ وہ تو شک میں کھیل رہے ہیں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxiv{سو اس دن کا انتظار کیجیئے کہ آسمان دھواں ظاہر لائے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxv{جو لوگوں کو ڈھانپ لے یہی دردناک عذاب ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxvi{اے ہمارے رب ہم سے یہ عذاب دور کر دے بے شک ہم ایمان لانے والے ہیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxvii{وہ کہاں سمجھتے ہیں حالانکہ ان کے پاس کھول کر سنانے والا رسول بھی آ چکا ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxviii{پھر اس سے بھی پھر گئے اور کہا کہ سکھایا ہوا دیوانہ ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxix{ہم اس عذاب کو تھوڑی دیر کے لیےہٹا دیں گے تم پھر وہی کرنے والے ہو\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxx{جس دن ہم بڑی سخت پکڑ پکڑیں گے بے شک ہم بدلہ لینے والے ہیں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxi{اور ان سے پہلے ہم فرعون کی قوم کو آزما چکے ہیں اور ان کے پاس ایک عزت والا رسول بھی آیا تھا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxii{کہ الله کے بندوں کو میرے حوالہ کر دو بے شک میں تمہارے لیے ایک امانت دار رسول ہوں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxiii{اور یہ کہ الله کے خلاف سرکشی نہ کرو میں تمہارے پاس کھلی دلیل لایا ہوں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxiv{اور بے شک میں نے اپنے اور تمہارے رب کی پناہ لی ہے اس واسطے کہ تم مجھے سنگسار کرو\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxv{اور اگرتم میری بات پر ایمان نہیں لاتے تو مجھ سے الگ ہو جاؤ\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxvi{پس اس نے اپنے رب کو پکارا کہ یہ تو مجرم لوگ ہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxvii{حکم ہوا پس میرے بندوں کو رات کے وقت لے چل کیوں کہ تمہارا پیچھا کیا جائے گا\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxviii{اور سمندر کو ٹھہرا ہوا چھوڑ دے بے شک وہ لشکر ڈوبنے والے ہیں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxix{کتنے انہوں نے باغات اور چشمے چھوڑے ہیں\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxl{اور کھیتیاں اور مقام عمدہ\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxli{اورنعمت کے سازو سامان جس میں وہ مزے کیا کرتے تھے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxlii{اسی طرح ہوا اورہم نے ان کا ایک دوسری قوم کو وارث کر دیا\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxliii{پس ان پر نہ آسمان روویا اور نہ زمین اور نہ ان کو مہلت دی گئی\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxliv{اورہم نے بنی اسرائیل کو اس ذلت کےعذاب سے نجات دی\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxlv{(یعنی) فرعون سے بے شک وہ ایک سرکش حد سے بڑھنے والا تھا\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxlvi{اور ہم نے اپنے علم سے ان کو جہان والوں پر چن لیا تھا\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxlvii{اور ہم نے ان کو نشانیاں دی تھیں جن میں صریح آزمائش تھی\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxlviii{بے شک یہ لوگ کہتے ہیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxlix{کہ او رمرنا نہیں ہے مگر یہی ہمارا پہلی بار کا مرنا اور ہم دوبارہ اٹھائے جانے والے نہیں\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmcdl{پس ہمارے باپ دادا کو لے آؤ اگر تم سچے ہو\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmcdli{کیا وہ بہتر ہیں یا تبع کی قوم اوروہ لوگ جو ان سے پہلے ہوئے ہم نے انہیں ہلاک کر دیا کیوں کہ وہ مجرم تھے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlii{اور ہم نے آسمانوں اور زمین کو اورجو کچھ اس کے درمیان میں ہے کھیل کے لیے نہیں بنایا\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmcdliii{ہم نے انہیں بہت ہی مصلحت سے بنایا ہے لیکن اکثر ان میں سے نہیں جانتے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmcdliv{بے شک فیصلہ کا دن ان سب کے لیے مقرر ہو چکا ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlv{جس دن کوئی دوست کسی دوست کے کچھ بھی کام نہیں آئے گا اورنہ انہیں مدد ملے گی\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlvi{مگر جس پر الله نے رحم کیابے شک وہ زبردست رحم والا ہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlvii{بے شک تھوہر کا درخت\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlviii{گناہگارو ں کا کھانا ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlix{پگھلے ہوئے تانبے کی طرح پیٹو ں میں کھولے گا\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlx{جیسے پکتا ہوا پانی کھولتا ہے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxi{اسے پکڑ لو پس اسے دوزخ کے درمیان دھکیل کر لے جاؤ\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxii{پھر اس کے سر پر عذاب کا کھولتا ہوا پانی ڈالو\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxiii{چکھ بے شک تو تو بڑا عزت والا بزرگی والا ہے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxiv{بے شک یہی ہے جس کی نسبت تم شک کیا کرتے تھے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxv{بے شک پرہیزگار ہی امن کی جگہ میں ہوں گے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxvi{باغوں اور چشموں میں\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxvii{باریک ریشم اورگاڑھا پہن کر آمنے سامنے بیٹھے ہوں گے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxviii{یونہی ہوگا اور ہم ان کا نکاح بڑی آنکھوں والی حوروں سے کر دیں گے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxix{وہ اس میں ہر قسم کا میوہ امن و اطمینان سے طلب کریں گے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxx{وہا ں پہلی موت کے سوا اور موت کا مرہ نہ چکھیں گے اورانہیں الله دوزح کے عذاب سے بچا لے گا\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxi{یہ آپکے رب کا فضل ہوگا یہی وہ بڑی کامیابی ہے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxii{اس قرآن کو ہم نے آپ کی زبان میں آسان کر دیا تاکہ وہ سمجھیں\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxiii{پس آپ انتظار کیجیئے بے شک وہ بھی انتظار کر ہے ہیں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxiv{\basmalahur حمۤ\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxv{یہ کتاب الله زبردست حکمت والے کی طرف سے نازل ہوئی ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxvi{بے شک آسمانوں اور زمین میں ایمانداروں کے لیے نشانیاں ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxvii{اور (نیز) تمہارے پیدا کرنے میں اور جانوروں کے پھیلانے میں یقین والوں کے لیے نشانیاں ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxviii{اور (نیز) رات اور دن کے بدل کر آنے میں اور اس میں جو الله نے آسمان سے رزق (پانی) نازل کیا پھر اس کے ذریعے سے زمین کو اس کے مر جانے کے بعد زندہ کیا اور ہواؤں کے بدل کر لانے میں عقل مندوں کے لیے نشانیاں ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxix{یہ الله کی آیات ہیں جو ہم آپ کو بالکل سچی پڑھ کر سناتے ہیں پس الله اور اس کی آیات کے بعد وہ کس بات پر ایمان لائیں گے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxx{ہر سخت جھوٹے گناہگار کے لیے تباہی ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxi{جو آیات الہیٰ سنتا ہے جو اس پر پڑھی جاتی ہیں پھر نا حق تکبر کی وجہ سے اصرار کرتا ہے گویاکہ اس نے سنا ہی نہیں پس اسے دردناک عذاب کی خوشخبری دے دو\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxii{اورجب ہماری آیتوں میں سے کسی کو سن لیتاہے تو اس کی ہنسی اڑاتا ہے ایسوں کے لیے ذلت کا عذاب ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxiii{ان کے سامنے جہنم ہے اور جو کچھ انہوں نے کمایا تھا ان کے کچھ بھی کام نہ آئے گا اور نہ وہ معبود کام آئيں گے جنہیں الله کے سوا حمایتی بنا رکھا تھا اور ان کے لیے بڑاعذاب ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxiv{یہ (قرآن) تو ہدایت ہے اور جو اپنے رب کی آیتوں کے منکر ہیں ان کے لیے سخت دردناک عذاب ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxv{الله ہی ہے جس نے تمہارے لیے سمندر کو تابع کر دیا تاکہ ا س میں اس کے حکم سے جہاز چلیں اورتاکہ تم اس کا فضل تلاش کرو اور تاکہ تم اس کا شکر کرو\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxvi{اور اس نے آسمانوں اور زمین کی سب چیزوں کو اپنے فضل سے تمہارے کام پر لگا دیا ہے بے شک اس میں فکر کرنے والوں کے لیے نشانیاں ہیں\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxvii{ان سے کہہ دو جو ایمان لائے کہ انہیں معاف کر دیں ایام الہیٰ (عذاب) کی امید نہیں رکھتے تاکہ وہ ایک قوم کو بدلہ دے اس کا جو وہ کرتے رہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxviii{جو کوئی نیک کام کرتا ہے وہ اپنے ہی لیے کرتا ہے اورجو کوئی برائی کرتا ہے تو اپنے سر پر وبال لیتا ہے پھر تم اپنے رب کی طرف لوٹائے جاؤ گے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxix{اور بے شک ہم نے بنی اسرائیل کو کتاب اورحکومت اور نبوت دی تھی اور ہم نے پاکیزہ چیزوں سے روزی دی اور ہم نے انہیں جہان والوں پر بزرگی دی\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxc{اور انہیں دین کے کھلے کھلے احکام بھی دیے پھر انہوں نے اختلاف کیا تو علم آنے کے بعد صرف آپس کی ضد سے بے شک آپ کا رب قیامت کے دن ان میں فیصلہ کرے گا جس چیز میں وہ باہم اختلاف کیا کرتے تھے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxci{پھر ہم نے آپ کو دین کے ایک طریقہ پر مقرر کر دیا پس آپ اسی کی پیروی کیجیئے اور ان کی خواہشوں کی پیروی نہ کیجیئے جو علم نہیں رکھتے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxcii{کیوں کہ وہ الله کے سامنے آپ کے کچھ بھی کام نہ آئیں گے اور بے شک ظالم ایک دوسرے کے دوست ہیں اور الله ہی پرہیز گاروں کا دوست ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxciii{یہ قرآن لوگوں کے لیے بصیرت اورہدایت ہے اور یقین کرنے والو ں کے لیے رحمت ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxciv{کیا گناہ کرنے والوں نے یہ سمجھ لیا ہے کہ ہم ان کو ایمانداروں نیک کام کرنے والوں کے برابر کر دیں گے ان کا جینا اور مرنا برابر ہے وہ بہت ہی برا فیصلہ کرتے ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxcv{اور الله نے آسمانوں اور زمین کو جسے چاہئیں بنایا ہے اور تاکہ ہر نفس کو اس کا بدلہ دیا جائے جو اس نے کمایا ہے اور ان پر کوئی ظلم نہ ہوگا\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxcvi{بھلا آپ نے اس کو بھی دیکھا جو اپنی خواہش کا بندہ بن گیا اور الله نے باوجود سمجھ کے اسے گمراہ کر دیا اور اس کے کان اور دل پر مہر کر دی اور اس کی آنکھوں پر پردہ ڈال دیا پھر الله کے بعد اسے کون ہدایت کر سکتا ہے پھر تم کیوں نہیں سمجھتے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxcvii{اور کہتے ہیں ہمارا یہی دنیا کا جینا ہے ہم مرتے ہیں اور جیتے ہیں اور زمانہ ہی ہمیں ہلاک کرتا ہے حالانکہ انہیں اس کی کچھ بھی حقیقت معلوم نہیں محض اٹکلیں دوڑاتے ہیں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxcviii{اور جب انہیں ہماری واضح آیتیں پڑھ کر سنائی جاتی ہیں تو سوائے اس کے ان کی اور کوئی دلیل نہیں ہوتی کہتے ہیں ہمارے باپ دادا کو لے آؤ اگر تم سچے ہو\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxcix{کہہ دو الله ہی تمہیں زندہ کرتا ہے پھر تمہیں مارتا ہے پھر وہی تم سب کو قیامت میں جمع کرے گا جس میں کوئی شک نہیں لیکن اکثر آدمی نہیں جانتے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmd{اور آسمانوں اور زمین کی بادشاہی الله ہی کی ہے اور جس دن قیامت قائم ہو گی اس دن جھٹلانے والے نقصان اٹھائیں گے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmdi{اور آپ ہر ایک جماعت کو گھٹنے ٹیکے ہوئے دیکھیں گے ہر ایک جماعت اپنے نامہٴ اعمال کی طرف بلائی جائے گی (کہا جائے گا) آج تمہیں تمہارے اعمال کا بدلہ دیا جائے گا\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmdii{یہ ہمارا دفتر تم پر سچ سچ بول رہا ہے کیونکہ جو کچھ تم کیا کرتے تھے اسے ہم لکھ لیا کرتے تھے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmdiii{پس جو لوگ ایمان لائے اورانہوں نے نیک کام کیے انہیں ان کا پروردگار اپنی رحمت میں داخل کرے گا یہ صریح کامیابی ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmdiv{اور جنہوں نے کفر کیا (انہیں کہا جائے گا) کیا تمہیں ہماری آیتیں نہیں سنائی جاتی تھیں پھر تم نے غرور کیا اور تم نافرمان لوگ تھے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmdv{اور جب کہا جاتا تھا کہ الله کا وعدہ سچا ہے اور قیامت میں کوئی شک نہیں تو تم کہتے تھے ہم نہیں جانتے قیامت کیا چیز ہے ہم تو اس کو محض خیالی بات جانتے ہیں اور ہمیں یقین نہیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmdvi{اور ان پر ان کےاعمال کی برائی ظاہر ہو جائے گی اور ان پر وہ آفت آ پڑے گی جس سے وہ ٹھٹھا کرتے تھے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmdvii{اور کہا جائے گا آج ہم تمہیں فراموش کر دیں گے جیسا تم نے اپنے اس دن کے ملنے کو فراموش کر دیا تھا اور تمہارا ٹھکانہ دوزخ ہے اور تمہارا کوئی مددگارنہیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmdviii{یہ اس لیے کہ تم الله کی آیتوں کی ہنسی اڑایا کرتے تھے اور تمہیں دنیا کی زندگی نے دھوکے میں ڈال دیا تھا پس آج وہ اس سے نہ نکالے جائیں گے اور نہ ان سے توبہ طلب کی جائے گی\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmdix{پس سب تعریف الله ہی کے لیے ہے جو آسمانوں کا رب اور زمین کا رب سارے جہانوں کا رب ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmdx{اور آسمانوں اور زمین میں اسی کی عزت ہے اور وہی زبردست حکمت والا ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmdxi{\basmalahur حمۤ\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmdxii{یہ کتاب الله کی طرف سے اتاری گئی ہے جو غالب حکمت والا ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmdxiii{ہم نے آسمانوں اور زمین کو اور جو ان کے درمیان ہے کسی مصلحت ہی سے اور ایک خاص وقت تک کے لیے پیدا کیا ہے اورکافروں کو جس چیز سے ڈرایا جاتا ہے اس سے منہ پھیر لیتے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmdxiv{کہہ دو بھلا بتاؤ تو سہی جنہیں تم الله کے سوا پکارتے ہو مجھے دکھاؤ کہ انہوں نے زمین میں کون سی چیز پیدا کی ہے یا آسمانوں میں ان کا کوئی حصہ ہے میرے پاس اس سے پہلے کی کوئی کتاب لاؤ یا کوئی علم چلا آتا ہو وہ لاؤ اگر تم سچے ہو\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmdxv{اور اس سے بڑھ کر کون گمراہ ہے جو الله کےسوا اسےپکارتا ہے جو قیامت تک اس کے پکارنے کا جواب نہ دے سکے اور انہیں ان کے پکارنے کی خبر بھی نہ ہو\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmdxvi{او ر جب لوگ جمع کئےجائیں گے تو وہ ان کے دشمن ہو جائیں گے اور ان کی عبادت کے منکر ہوں گے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmdxvii{اور جب ان پر ہماری واضح آیتیں پڑھی جاتی ہیں تو کافر حق کو کہتے ہیں جب وہ ان کے پاس آچکا کہ یہ تو کھلم کھلاجادوہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmdxviii{کیا وہ کہتے ہیں آپ نے اسے خود بنا لیا ہے کہہ دو اگر میں نے اسے خود بنا لیا ہے تو تم مجھے الله سے بچانے کی کچھ بھی طاقت نہیں رکھتے وہی بہتر جانتا ہے جو باتیں تم اس میں بناتے ہو میرے اور تمہارے درمیان وہی گواہ کافی ہے اور وہ بخشنے والا نہایت رحم والا ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmdxix{کہہ دو میں کوئی انوکھا رسول نہیں ہوں اور میں نہیں جانتا کہ میرے ساتھ کیا کیا جائے گا اور نہ تمہارے ساتھ میں نہیں پیروی کرتا مگر اس کی جو میری طرف وحی کیا جاتا ہے سوائے اس کے نہیں کہ میں کھلم کھلا ڈرانے والا ہوں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmdxx{کہہ دو بتاؤ تو سہی اگر یہ کتاب الله کی طرف سے ہو اور تم اس کے منکر ہو اور بنی اسرائیل کا ایک گواہ ایک ایسی کتاب پر گواہی دے کر ایمان بھی لے آیا اور تم اکڑے ہی رہے بے شک الله ظالموں کو ہدایت نہیں کرتا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxi{اور کافروں نے ایمانداروں سے کہا اگر یہ دین بہتر ہوتا تو یہ اس پر ہم سے پہلے نہ دوڑ کر جاتے اورجب انہوں نے اس کے ذریعے سے ہدایت نہیں پائی تو کہیں گے یہ تو پرانا جھوٹ ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxii{اور اس سے پہلے موسیٰ کی کتاب ہے جو رہنما اور رحمت تھی او ریہ کتاب ہے جو اسے سچا کرتی ہے عربی زبان میں ظالموں کو ڈرانے کے لیے اور نیکوں کو خوشخبری دینے کے لیے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxiii{بے شک جنہوں نے کہا کہ ہمارا رب الله ہے پھر اسی پر جمے رہے پس ان پر کوئی خوف نہیں اور نہ وہ غمگین ہوں گے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxiv{یہی بہشتی ہیں اس میں ہمیشہ رہیں گے بدلےان کاموں کے جو وہ کیا کرتے تھے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxv{اور ہم نے انسان کو اپنے والدین کے ساتھ نیکی کرنے کی تاکید کی کہ اسے اس کی ماں نے تکلیف سے اٹھائے رکھا اور اسے تکلیف سے جنا اوراس کا حمل اور دودھ کا چھڑانا تیس مہینے ہیں یہاں تک کہ جب وہ اپنی جوانی کو پہنچا اور چالیں سال کی عمر کو پہنچا تو اس نے کہا اے میرے رب مجھے توفیق دے کہ میں تیری نعمت کا شکر ادا کروں جو تو نے مجھ پر انعام کی اور میرے والدین پر اور میں نیک عمل کروں جسے تو پسند کرے اور میرے لیے میری اولاد میں اصلاح کر بے شک میں تیری طرف رجوع کرتا ہوں اور بے شک میں فرمانبردار میں ہوں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxvi{یہی وہ لوگ ہیں جن سے ہم وہ نیک عمل قبول کرتے ہیں جو انہوں نے کیے اور بہشتیوں میں شامل کر کے ان کے گناہوں سے درگزر کرتے ہیں یہ اس سچے وعدے کے مطابق ہے جو ان سے کیا گیا تھا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxvii{اور جس نے اپنے ماں باپ سے کہا کہ تم پر تف ہے کیاتم مجھے یہ وعدہ دیتے ہو کہ میں قبر سے نکالا جاؤں گا حالانکہ مجھ سے پہلے بہت سی امتیں گزر گئیں اور وہ دونوں الله سے فریاد کر رہے ہیں کہ ارے تیرا ناس ہو ایمان لا بے شک الله کاوعدہ سچا ہے پھر وہ کہتا ہے یہ ہے کیا مگر پہلوں کے افسانے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxviii{یہ وہ لوگ ہیں کہ ان کے حق میں بھی ان لوگوں کے ساتھ الله کا قول پورا ہو کر رہا جو ان سے پہلے جن اور انسان ہوگزرے ہیں بے شک وہی خسارہ اٹھانے والے ہیں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxix{اور ہر ایک کے لیے اپنے اپنے اعمال کے مطابق درجے ہیں تاکہ الله ان کے اعمال کا انہیں پورا عوض دے اور ان پر کچھ بھی ظلم نہ ہوگا\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxx{اور جس دن کافر آگ کے روبرو لائے جائیں گے ان سے (کہا جائے گا) تم (اپنا حصہ) پاک چیزو ں میں سے اپنی دنیا کی زندگی میں لے چکے اور تم ان سے فائدہ اٹھا چکے پس آج تمہیں ذلت کا عذاب دیا جائے گا بدلے اس کے جو تم زمین میں ناحق اکڑا کرتے تھے اوربدلے اس کے جو تم نافرمانی کیاکرتے تھے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxi{اور قوم عاد کے بھائی کا ذکر کر جب اس نے اپنی قوم کو (وادی) احقاف میں ڈرایا اور اس سے پہلے اورپیچھے کئی ڈرانے والے گزرے کہ سوائے الله کے کسی کی عبادت نہ کرو بے شک میں تم پر ایک بڑے دن کے عذاب سے ڈرتا ہوں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxii{انہوں نے کہا کیا تو ہمارے پاس اس لیے آیا ہے کہ تو ہمیں ہمارے معبودوں سے بہکا دے پس ہم پردہ (عذاب) لے آ جس کا تو ہم سے وعدہ کرتا ہے اگر تو سچا ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxiii{اس نے کہا اس کا علم تو الله کے پاس ہے اورمیں تمہیں وہ (پیغام) پہنچاتا ہوں جو میں دے کر بھیجا گیا ہوں لیکن میں تمہیں دیکھ رہا ہوں تم ایک جاہل قوم ہو\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxiv{پھر جب انہوں نے اسے دیکھا کہ وہ ایک ابر ہے جو ان کے میدانوں کی طرف بڑھا چلا آ رہا ہے کہنے لگے کہ یہ تو ابر ہے جو ہم پر برسے گا (نہیں) بلکہ یہ وہی ہے جسے تم جلدی چاہتے تھے یعنی آندھی جس میں دردناک عذاب ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxv{وہ اپنے رب کے حکم سے ہر ایک چیز کو برباد کر دے گی پس وہ صبح کو ایسے ہو گئے کہ سوائے ان کے گھروں کے کچھ نظر نہ آتا تھا ہم اسی طرح مجرم لوگوں کو سزا دیا کرتے ہیں\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxvi{اور ہم نے ان لوگوں کو ان باتوں میں قدرت دی تھی کہ تمہیں ان باتوں میں قدرت نہیں دی اور ہم نے انہیں کان اور آنکھیں اور دل دیئے تھے پھر نہ تو ان کے کان ہی کام آئے اور نہ ان کی آنکھیں ہی کام آئیں او رنہ ان کے دل ہی کچھ کام آئے کیوں کہ وہ الله کی آیتوں کو انکار ہی کرتے رہے اور جس عذاب کا وہ ٹھٹھا اڑیا کرتے تھے ان پر آن پڑا\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxvii{اور ہم ہلاک کر چکے ہیں جو تمہارے آس پاس بستیاں ہیں اور طرح طرح کے اپنے نشان قدرت بھی دکھائے تاکہ وہ باز آجائيں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxviii{پھر ان معبودوں نے کیوں نہ مدد کی جن کو انہوں نے الله کے سوا مرتبہ حاصل کرنے کے لیے معبود بنا رکھا تھا بلکہ وہ تو ان سے کھو ئےگئے تھے اور یہ ان کا جھوٹ تھا اور جو کچھ وہ ڈھکوسلے بنایا کرتےتھے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxix{اورجب ہم نے آپ کی طرف چند ایک جنوں کو پھیر دیا جو قرآن سن رہے تھے پس جب وہ آپ کے پاس حاصر ہوئے تو کہنے لگے چپ رہو پھر جب ختم ہوا تو اپنی قوم کی طرف واپس لوٹے ایسے حال میں کہ وہ ڈرانے والے تھے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmdxl{کہنے لگے اےہماری قوم بیشک ہم نے ایک کتاب سنی ہے جو موسیٰ کے بعد نازل ہوئی ہے ان کی تصدیق کرنے والی ہے جو اس سے پہلے ہو چکیں حق کی طرف ا ور سیدھے راستہ کی طرف رہنمائی کرتی ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmdxli{اے ہماری قوم الله کی طرف بلانے والے کو مان لو اور اس پر ایمان لے آؤ وہ تمہارے لیے تمہارے گناہ بخش دے گا اور تمہیں دردناک عذاب سے بچا لے گا\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmdxlii{اور جو الله کی طرف بلانے والے کو نہ مانے گا تو وہ زمین میں اسے عاجر نہیں کر سکے گا اور الله کے سوا اس کا کوئی مددگار نہ ہوگا یہی لوگ صریح گمراہی میں ہیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmdxliii{کیا انہوں نے نہیں دیکھا جس الله نے آسمانوں اور زمین کو پیدا کرنے میں نہیں تھکا اس پر قاد رہے کہ مردوں کو زندہ کردے کیوں نہیں وہ تو ہر ایک چیز پر قادر ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmdxliv{اور جس دن کافر آگ کے سامنے لائے جائیں گے (ان سے کہا جائے گا) کیا یہ امر واقعی نہیں ہے کہیں گے ہمیں اپنے رب کی قسم ضرور امر واقعی ہے ارشاد ہو گا تواپنے کفر کے بدلہ میں اس کا عذاب چکھو\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmdxlv{پھر صبرکر جیسا کہ عالی ہمت رسولوں نے کیا ہے اور ان کے لیے جلدی نہ کر گویا کہ وہ جس دن عذاب دیکھیں گے جس کا ان سے وعدہ کیا جاتا ہے (تو انہیں ایسا معلوم ہو گا) کہ ایک دن میں سے ایک گھڑی بھر رہے تھے آپ کا کام پہنچا دینا تھا سو کیا نافرمان لوگوں کے سوا اور کوئی ہلاک ہوگا\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmdxlvi{\basmalahur وہ لوگ جو منکر ہوئے اورانہوں نے لوگوں کو بھی الله کے راستہ سے روکا تو الله نے ان کے اعمال برباد کر دیئے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmdxlvii{اوروہ جو ایمان لائے اور انہوں نے اچھے کام کیے اورجو کچھ محمد پر نازل کیا گیا اسپر بھی ایمان لائے اور انہوں نے اچھے کام بھی کیے اور جو کچھ محمد پر نازل کیا گیا اس پر بھی ایمان لائے حالانکہ وہ ان کے رب کی طرف سے برحق بھی ہے تو الله ان کی برائیوں کو مٹا دے گا اور ان کا حال درست کرے گا\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmdxlviii{یہ اس لیے کہ جولوگ منکر ہیں انہوں نے جھوٹ کی پیروی کی اور جو لوگ ایمان لائے انہوں نے اپنے رب کی طرف سے حق کی پیروی کی اسی طرح اللہ لوگوں کے لیے ان کی مثالیں بیان کرتا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmdxlix{پس جب تم ان کے مقابل ہو جو کافر ہیں تو ان کی گردنیں مارو یہاں تک کہ جب تم ان کو خوب مغلوب کر لو تو ان کی مشکیں کس لو پھر یا تو اس کے بعد احسان کرو یا تاوان لے لو یہاں تک کہ لڑائی اپنے ہتھیار ڈال دے یہی (حکم) ہے اور اگر الله چاہتا تو ان سے خود ہی بدلہ لے لیتا لیکن وہ تمہارا ایک دوسرے کے ساتھ امتحان کرنا چاہتا ہے اور جو الله کی راہ میں مارے گئے ہیں الله ان کے اعمال برباد نہیں کرے گا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmdl{جلدی انہیں راہ دکھائے گا اور ان کاحال درست کر دے گا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmdli{اور انہیں بہشت میں داخل کرے گا جس کی حقیقت انہیں بتا دی ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmdlii{اے ایمان والو اگر تم الله کی مدد کرو گے وہ تمہاری مدد کرے گا اور تمہارے قدم جمائے رکھے گا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmdliii{اور جو منکر ہیں سو ان کے لیے تباہی ہے اور وہ ان کے اعمال اکارت کر دے گا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmdliv{یہ اس لیے کہ انہیں نے ناپسند کیا جو الله نے اتارا ہے سو اس نے ان کے اعمال ضائع کر دیے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmdlv{کیا انہوں نے زمین میں سیر نہیں کی وہ دیکھتے ان کا انجام کیسا ہوا جو ان سے پہلے تھے الله نے انہیں ہلاک کر دیا اور منکروں کے لیے ایسی ہی (سزائیں) ہیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmdlvi{یہ اس لیے کہ اللهان کا حامی ہے جو ایمان لائے اور کفار کا کوئی بھی حامی نہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmdlvii{بے شک الله انہیں داخل کرے گا جو ایمان لائے اور نیک کام کیے بہشتوں میں جن کے نبیچے نہریں بہتی ہو ں گی اور جو کافر ہیں وہ عیش کر رہے ہیں اور اس طرح کھاتے ہیں جس طرح چار پائے کھاتے ہیں اور دوزخ ان کا ٹھکانہ ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmdlviii{اور کتنی ہی بستیاں تھی جو آپ کی اس بستی سے طاقت میں بڑھ کر تھیں جس کے رہنے والوں نے آپ کو نکال دیا ہے ہم نے انہیں ہلاک کر دیا تو ان کا کوئی بھی مددگار نہ ہوا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmdlix{پس کیا وہ شخص جو اپنے رب کی طرف سے واضح دلیل پر ہو وہ اس جیسا ہو سکتا ہے جسے اس کے برے عمل اچھے کر کے دکھائے گئے ہوں اور انہوں نے اپنی ہی خواہشوں کی پیروی کی ہو\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmdlx{اس جنت کی کیفیت جس کا پرہیزگاروں سے وعدہ کیا جاتا ہے (یہ ہے) کہ اس میں ایسے پانی کی نہریں ہو گی جو بگڑنے والا نہیں اور کچھ دودھ کی نہریں جن کا مزہ کبھی نہیں بدلے گا اور کچھ نہریں ایسے شراب کی جو پینے والوں کے لیے خوش ذائقہ ہو گا اور کچھ نہریں صاف شہد کی اور ان کے لیے وہاں ہر قسم کے میوے ہوں اوراپنے رب کی بخشش (کیا وہ) ان جیسے ہو سکتے ہیں جو ہمیشہ دوزخ میں رہیں گے اور انہیں کھولتا ہوا پانی پلایا جائے گا سو وہ ان کی آنتوں کے ٹکڑے ٹکڑے کر ڈالے گا\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxi{اور ان میں سے بعض وہ ہیں جو آپ کی بات سنتے ہیں یہاں تک کہ جب آپ کے ہاں سے نکل جاتے ہیں تو ان سے کہتے ہیں جنہیں علم دیا گیا ہے اس نے ابھی ابھی کیا کہا یہی لوگ ہیں کہ الله نے ان کے دلوں پر مہر کر دی ہے اور انہوں نے اپنی خواہشوں کی پیروی کی ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxii{اور جو راستہ پر آگئے ہیں الله انہیں اور زیادہ ہدایت دیتا اور انہیں پرہیزگاری عطا کرتا ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxiii{پھر کیا وہ اس گھڑی کا انتظار کرتے ہیں کہ ان پر ناگہان آئے پس تحقیق اس کی علامتیں تو ظاہر ہو چکیں ہیں پھر جب وہ آگئی تو ان کا سمجھنا کیا فائدہ دے گا\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxiv{پس جان لو کہ سوائے الله کے کوئی معبود نہیں اور اپنے اور مسلمان مردوں اور مسلمان عورتوں کے گناہوں کی معافی مانگیئے اور الله ہی تمہارے لوٹنے اور آرام کرنے کی جگہ کو جانتا ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxv{اور کہتے ہیں وہ لوگ جو ایمان لائے کوئی سورت کیوں نہیں نازل ہوئی سو جس وقت کوئی صاف (مضمون) کی سورت نازل ہوتی ہے اور اس میں جہاد کا بھی ذکر ہوتا ہے تو جن لوگو ں کے دلوں میں بیماری (نفاق) ہے آپ ان لوگو ں کو دیکھتے ہیں کہ وہ آپ کی طرف اس طرح دیکھتے ہیں جیسے کسی پر موت کی بیہوشی طاری ہو پس ایسے لوگوں کے لیے تباہی ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxvi{حکم ماننا اور نیک بات کہنا (لازم ہے) پس جب بات قرار پا جائے تو اگر وہ الله کے سچے رہے تو ان کے لیے بہتر ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxvii{پھر تم سے یہ بھی توقع ہے اگرتم ملک کے حاکم ہو جاؤ تو ملک میں فساد مچانے اور قطع رحمی کرنے لگو\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxviii{یہی وہ لوگ ہیں جن پر الله نے لعنت کی ہے پھرانہیں بہرا اوراندھا بھی کر دیا ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxix{پھر کیوں قرآن پر غور نہیں کرتے کیا ان کے دلوں پر قفل پڑے ہوئے ہیں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxx{بے شک جو لوگ پیچھے کی طرف الٹے پھر گئے بعد اس کے کہ ان پر سیدھا راستہ ظاہر ہو چکا شیطان نے ان کے سامنے برے کامو ں کو بھلا کر دکھایا اور انہیں آرزو دلائی\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxi{یہ اس لیے کہ وہ ان لوگوں سے کہنے لگے جنہوں نے اسے ناپسند کیا اس کو جو الله نے نازل کیا ہے کہ بعض باتوں میں ہم تمہاراکہا مانیں گے اور الله ان کی رازداری کو جانتا ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxii{پھر کیا حال ہوگا جب ان کی روحیں فرشتے قبض کریں گے ان کے مونہوں اور پیٹھوں پر مار رہے ہوں گے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxiii{یہ اس لیے کہ یہ اس پر چلے جس پر الله ناراض ہے اور انہوں نے الله کی رضا مندی کو برا جانا پھر اس نے بھی ان کے اعمال اکارت کر دیئے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxiv{کیا وہ لوگ کہ جن کے دلوں میں مرض (نفاق) ہے یہ سمجھے ہوئے ہیں کہ الله ان کی دبی دشمنی ظاہر نہ کرے گا\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxv{اور اگر ہم چاہتے تو آپ کو وہ لوگ دکھا دیتے پس آپ اچھی طرح سے انہیں ان کے نشان سےپہچان لیتے اور آپ انہیں طرز کلام سے پہچان لیں گے اور الله تمہارے اعمال کو جانتا ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxvi{اور ہم تمہیں آزمائیں گے یہاں تک کہ ہم تم میں سے جہاد کرنے والوں کو اور صبر کرنے والوں کو معلوم کر لیں اور تمہارے حالات کو جانچ لیں\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxvii{بے شک جنہوں نے انکار کر دیا اور الله کی راہ سے روکا اور رسول کی مخالفت کی بعد اس کے کہ ان پر سیدھا راستہ صاضح ہو چکا وہ الله کا کچھ بھی نہیں بگاڑ سکیں گے اور ان کے اعمال کو اکارت کر دے گا\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxviii{اے ایمان والو الله کا حکم مانو اوراس کے رسول کا حکم مانو اور اپنے اعمال کو ضائع نہ کرو\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxix{بےشک جنہوں نے انکار کیا اور الله کی راہ سے روکا پھر مر گئے درآنحالیکہ وہ کافر تھے سو الله ان کو ہرگز نہیں بخشے گا\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxx{پس تم سست نہ ہو اور نہ صلح کی طرف بلاؤ اور تم ہی غالب رہو گے اور الله تمہارے ساتھ ہے اور وہ ہر گز تمہارےاعمال میں نقصان نہیں دیگا\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxi{بلاشبہ دنیا کی زندگی تو کھیل اور تماشا ہے اور اگر تم ایمان لاؤ اور پرہیزگاری اختیار کرو تو تمہیں تمہارے اجر دے گا اور تم سے تمہارے مال نہیں مانگے گا\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxii{اور اگر تم سے وہ (مال) مانگے پھر تمہیں تنگ کرے تو تم بخل کرنے لگو اور تمہارے دلی کینے ظاہر کر دے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxiii{خبردار تم وہ لوگ ہو کہ الله کی راہ میں خرچ کرنے کو بلائے جاتے ہو تو کوئی تم میں سے وہ ہے جو بخل کرتا ہے اورجو بخل کرتا ہے سو وہ اپنی ہی ذات سے بخل کرتا ہے اور الله بے پرواہ ہے اور تم ہی محتاج ہو اور اگر تم نہ مانو گے تو وہ اور قوم سوائے تمہارے بدل دے گا پھر وہ تمہاری طرح نہ ہوں گے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxiv{\basmalahur بے شک ہم نے آپ کو کھلم کھلا فتح دی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxv{تاکہ آپ کے اگلے اور پچھلے گناہ معاف کر دے اور اپنی نعمت آپ پر تمام کر دے اور تاکہ آپ کو سیدھے راستہ پر چلائے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxvi{اور تاکہ الله آپ کی زبردست مدد کرے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxvii{وہی تو ہے جس نے ایمانداروں کے دلو ں میں اطمینان اتارا تاکہ ان کا ایمان اور زیادہ ہو جائے اور آسمانوں اور زمین کے لشکر سب الله ہی کے ہیں اور الله خبردار حکمت والا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxviii{تاکہ ایمان والے مردوں اور عورتوں کو بہشتوں میں داخل کرے جن کے نیچے نہریں بہہ رہی ہوں گی ان میں ہمیشہ رہیں گے اور ان پر سے ان کے گناہ دور کر دے گا اور الله کے ہاں یہ بڑی کامیابی ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxix{اور تاکہ منافق مردوں اور عورتوں کواور مشرک مردوں اور عورتوں کو عذاب دے جو الله کے بارے میں براگمان رکھتے ہیں انہیں پر بری گردش ہے اور الله نے ان پر غضب نازل کیا اور ان پر لعنت کی اوران کے لیے دوزخ تیار کر رکھا ہےاور وہ برا ٹھکانہ ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmdxc{اور الله ہی کے سب لشکر آسمانوں اور زمین میں ہیں اور الله بڑا غالب حکمت والا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmdxci{بے شک ہم نے آپ کو گواہ بناکر بھیجا اور خوشخبری دینے والا اور ڈرانے والا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmdxcii{تاکہ تم الله پر اور اس کے رسول پر ایمان لاؤ اور اس کی مدد کرو اور اس کی عزت کرو اور صبح اور شام اس کی پاکی بیان کرو\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmdxciii{بے شک جو لوگ آپ سے بیعت کر رہے ہیں وہ الله ہی سے بیعت کر رہے ہیں ان کے ہاتھوں پر الله کا ہاتھ ہے پس جو اس عہد کو) تو ڑ دے گا سو توڑنے کا وبال خود اسی پر ہو گا اور جو وہ عہد پورا کرے گا جو اس نے الله سے کیا ہے سو عقریب وہ اسے بہت بڑا اجر دے گا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmdxciv{عنقریب آ پ سے وہ لوگ کہیں گے جو بدویوں میں سے پیچھے رہ گئے تھے کہ ہمیں ہمارے اور اہل و عیال نے مشغول رکھا ہے آپ ہمارے لیے مغفرت مانگیئے وہ اپنی زبانوں سے وہ بات کہتے ہیں جو ان کے دلوں میں نہیں ہے کہدو وہ کون ہے جو الله کے سامنے تمہارے لیے کسی چیز کا (کچھ بھی) اختیار رکھتا ہوگا اگر الله تمہیں کوئی نقصان یا کوئی نفع پہنچانا چاہے بلکہ الله تمہارے سب اعمال پر خبردار ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmdxcv{بلکہ تم نے خیال کیا تھا کہ رسول الله اور مسلمان اپنے گھر والوں کی طرف کبھی بھی واپس نہ لوٹیں گے اور تمہارے دلوں میں یہ بات اچھی معلوم ہوئی اور تم نے بہت برا گمان کیا اور تم ہلاک ہونے والے لوگ تھے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmdxcvi{اورجو لوگ الله اور اس کے رسول پر ایمان نہیں لائے سو ہم نے ایسے کافروں کے لیے بھڑکتی ہوئی آگ تیار کر رکھی ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmdxcvii{اور آسمانوں اور زمین کی حکومت الله ہی کے لیے ہے وہ جسے چاہے بخشے اورجسے چاہے عذاب دے اور الله بخشنے والا بڑا مہربان ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmdxcviii{عنقریب کہیں گے وہ لوگ جو پیچھے رہ گئے تھے جب تم غنیمتوں کی طرف ان کے لینے کے لیے جانے لگو گے کہ ہمیں چھوڑو ہم تمہارے ساتھ چلیں وہ چاہتے ہیں کہ الله کا حکم بدل دیں کہہ دو کہ تم ہرگز ہمارے ساتھ نہ چلو گے الله نے اس سے پہلے ہی ایسا فرما دیا ہے پس وہ کہیں گے کہ (نہیں) بلکہ تم ہم سے حسد کرتے ہو بلکہ وہ لوگ بات ہی کم سمجھتے ہیں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmdxcix{ان پیچھے رہ جکانے والے بدوؤں سے کہہ دو کہ بہت جلد تمہیں ایک سخت جنگجو قوم سے لڑنے کے لیے بلایا جائے گا تم ان سے لڑو گے یا وہ اطاعت قبول کر لے گی پھر اگر تم نے حکم مان لیا تو الله تمہیں بہت ہی اچھا انعام دے گا اور اگر تم پھر گئے جیسا کہ پہلے پھر گئے تھے تو تمہیں سخت عذاب دے گا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmdc{نہ اندھے پر کچھ گناہ ہے اور نہ لنگڑے ہی پرکچھ گناہ ہے اور نہ بیمار ی پرکچھ گناہے ہے اور جوکوئی الله اور اس کے رسول کی اطاعت کرے گا تو اسے ایسے باغوں میں داخل کرے گا جن کے نیچے نہریں بہتی ہوں گی اور جو نافرمانی کرے گا اسے سخت سزا دے گا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmdci{بے شک الله مسلمانوں سے راضی ہوا جب وہ آپ سے درخت کے نیچے بیعت کر رہے تھے پھر اس نے جان لیا جو کچھ ان کے دلو ں میں تھا پس اس نے ان پر اطمینان نازل کر دیا اور انہیں جلد ہی فتح دے دی\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmdcii{اوربہت سی غنیمتیں بھی دے گا جنہیں وہ لیں گے اور الله زبردست حکمت والا ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmdciii{الله نے تم سے بہت سی غنیمتوں کا وعدہ کیا ہے جنہیں تم حاصل کرو گے پھر تمہیں اس نے یہ جلدی دےدی اوراس نےتم سے لوگوں کے ہاتھ روک دیئے اور تاکہ ایمان لانے والوں کے لیے یہ ایک نشان ہو اور تاکہ تم سیدھے راستہ پر چلائے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmdciv{اور بھی فتوحات ہیں کہ جو (اب تک) تمہارے بس میں نہیں آئیں البتہ الله کے بس میں ہیں اور الله ہر چیز پر قادر ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmdcv{اور اگر کافر تم سے لڑتے تو پیٹھ پھیر کر بھاگ پڑتے پھر نہ کوئی حمایتی پاتے نہ کوئی مددگار\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmdcvi{الله کا قدیم دستور پہلے سے یونہی چلا آتا ہے اور تو اس کے دستور کو بدلا ہوا نہ پائے گا\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmdcvii{اوروہی ہے جس نے وادی مکہ میں ان کے ہاتھ تم سے اور تمہارے ہاتھ ان سے روک دیے اس کے بعد اس نے تمہیں ان پر غالب کر دیا تھا اور الله ان سب باتوں کو جو تم کر رہے تھے دیکھ رہا تھا\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmdcviii{وہ تو وہی ہیں جنہوں نے انکار کیا اور تمہیں مسجد حرام سے روکا اور قربانی کے جانوروں کو روکے رکھا اس سے کہ وہ اپنی قربان گاہ تک پہنچیں اور اگر کچھ مرد ایمان والے اور عورتیں ایمان والی نہ ہوتیں جنہیں تم نہیں جانتے تھے کہ تم انہیں پامال کر دیتے پھر ان کی طرف سے تم پر نادانستگی سے الزام آتا (تو تمہیں لڑنے سے نہ روکا جاتا) تاکہ الله اپنی رحمت میں جسے چاہے داخل کرے اگر وہ ٹل گئے ہوتے تو ہم ان میں سے جو کافر ہیں انہیں دردناک عذاب دیتے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmdcix{جب کہ کافروں نے اپنے دل میں سخت جوش پیدا کیا تھا جہالت کا جوش تھا پھر الله نے بھی اپنی تسکین اپنے رسول اور ایمان والوں پر نازل کر دی اور ان کو پرہیزگاری کی بات پر قائم رکھا اور وہ اسی کے لائق اور قابل بھی تھے اور الله ہر چیز کو جانتا ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmdcx{بے شک الله نے اپنے رسول کا خواب سچا کر دکھایا کہ اگر الله نے چاہا تو تم امن کے ساتھ مسجد حرام میں ضرور داخل ہو گے اپنے سر منڈاتے ہوئے اور بال کتراتے ہوئے بے خوف و خطر ہوں گے پس جس بات کو تم نہ جانتے تھے اس نے اسے جان لیا تھا پھر اس نے اس سے پہلےہی ایک فتح بہت جلدی کر دی\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxi{وہی تو ہے جس نے اپنے رسول کو ہدایت اور سچا دین دے کر بھیجا تاکہ اسے ہر ایک دین پر غالب کرے اور الله کی شہادت کافی ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxii{محمد الله کے رسول ہیں اور جو لوگ آپ کے ساتھ ہیں کفار پر سخت ہیں آپس میں رحم دل ہیں تو انہیں دیکھے گا کہ رکوع و سجود کر رہے ہیں الله کا فضل اوراس کی خوشنودی تلاش کرتے ہیں ان کی شناخت ان کے چہرو ں میں سجدہ کا نشان ہے یہی وصف ان کا تو رات میں ہے اور انجیل میں ان کا وصف ہے مثل اس کھیتی کے جس نے اپنی سوئی نکالی پھر اسے قوی کر دیا پھر موٹی ہوگئی پھر اپنے تنہ پر کھڑی ہوگئی کسانوں کو خوش کرنے لگی تاکہ الله ان کی وجہ سے کفار کو غصہ دلائے الله ان میں سے ایمان داروں اورنیک کام کرنے والوں کے لیے بخشش اور اجر عظیم کا وعدہ کیا ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxiii{\basmalahur اے ایمان والو الله اور اس کے رسول کے سامنے پہل نہ کرو الله سے ڈرتے رہو بے شک الله سب کچھ سننے والا جاننے والا ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxiv{اے ایمان والو اپنی آوازیں نبی کی آواز سے بلند نہ کیا کرو اور نہ بلندآواز سے رسول سے بات کیا کرو جیسا کہ تم ایک دوسرے سے کیا کرتے ہو کہیں تمہارے اعمال برباد نہ ہوجائیں اور تمہیں خبر بھی نہ ہو\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxv{بے شک جو لوگ اپنی آوازیں رسول الله کے حضور دھیمی کر لیتے ہیں یہی لوگ ہیں کہ الله نے ان کے دلوں کو پرہیزگاری کے لیے جانچ لیا ہےان کے لیے بخشش اور بڑا اجر ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxvi{بے شک جو لوگ آپ کو حجروں کے باہر سے پکارتے ہیں اکثر ان میں سے عقل نہیں رکھتے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxvii{اور اگر وہ صبر کرتے یہاں تک کہ آپ ان کے پاس سے نکل کر آتے تو ان کے لیے بہتر ہوتا اور الله بخشنے والا نہایت رحم والا ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxviii{اے ایمان والو اگر کوئی فاسق تمہاے پاس کوئی سی خبر لائے تو اس کی تحقیق کیا کرو کہیں کسی قوم پر بے خبری سے نہ جا پڑو پھر اپنے کیے پر پشیمان ہونے لگو\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxix{اور جان لو کہ تم میں الله کا رسول موجود ہے اگر وہ بہت سی باتوں میں تمہارا کہا مانے تو تم پر مشکل پڑ جائے لیکن الله نے تمہارے دلوں میں ایمان کی محبت ڈال دی ہے اوراس کو تمہارے دلوں میں اچھاکردکھایا ہے اور تمہارے دل میں کفر اور گناہ اور نافرمانی کی نفرت ڈال دی ہے یہی لوگ ہدایت یافتہ ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxx{الله کے فضل اور احسان سے اور الله جاننے والا حکمت والا ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxi{اور اگر مسلمانوں کے دو گروہ آپس میں لڑ پڑیں تو ان کے درمیان صلح کرا دو پس اگر ایک ان میں دوسرے پر ظلم کرے تو اس سے لڑو جو زیادتی کرتا ہے یہاں تک کہ وہ الله کے حکم کی طرف رجوع کرے پھر اگر وہ رجوع کرے تو ان دونوں میں انصاف سے صلح کرادو اورانصاف کرو بے شک الله انصاف کرنے والوں کو دوست رکھتا ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxii{بے شک مسلمان آپس میں بھائی بھائی ہیں سواپنے بھائیوں میں صلح کرادو اور الله سے ڈرو تاکہ تم پر رحم کیا جائے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxiii{اے ایمان والو ایک قوم دوسری قوم سے ٹھٹھا نہ کرے عجب نہیں کہ وہ ان سے بہتر ہوں اور نہ عورتیں دوسری عورتوں سے ٹھٹھا کریں کچھ بعید نہیں کہ وہ ان سے بہتر ہوں اور ایک دوسرے کو طعنے نہ دو اور نہ ایک دوسرے کے نام دھرو فسق کے نام لینے ایمان لانے کے بعد بہت برے ہیں اور جو باز نہ آئیں سووہی ظالم ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxiv{اے ایمان والو بہت سی بدگمانیوں سے بچتے رہو کیوں کہ بعض گمان تو گناہ ہیں اور ٹٹول بھی نہ کیا کرو اور نہ کوئی کسی سے غیبت کیا کرے کیا تم میں سے کوئی پسند کرتا ہے کہ اپنے مردہ بھائی کا گوشت کھائے سواس کو توتم ناپسند کرتے ہو اور الله سے ڈرو بے شک الله بڑا توبہ قبول کرنے والا نہایت رحم والا ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxv{ا ے لوگو ہم نے تمہیں ایک ہی مرد اور عورت سے پیدا کیا ہے اور تمہارے خاندان اور قومیں جو بنائی ہیں تاکہ تمہیں آپس میں پہچان ہو بے شک زیادہ عزت والا تم میں سے الله کے نزدیک وہ ہے جو تم میں سے زیادہ پرہیزگار ہے بے شک الله سب کچھ جاننے والا خبردار ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxvi{بدویوں نے کہا ہم ایمان لے آئے ہیں کہہ دو تم ایمان نہیں لائے لیکن تم کہو کہ ہم مسلمان ہو گئے ہیں اورابھی تک ایمان تمہارے دلوں میں داخل نہیں ہوا اور اگر تم الله اور اس کے رسول کا حکم مانو تو تمہارے اعمال میں سے کچھ بھی کم نہیں کرے گا بے شک الله بخشنے والا نہایت رحم والا ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxvii{بے شک سچے مسلمان تو وہی ہیں جو الله اور اس کے رسول پر ایمان لائے پھر انہوں نے شک نہ کیا اور اپنے مالوں اور اپنی جانوں سے الله کی راہ میں جہاد کیا وہی سچے (مسلمان) ہیں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxviii{کہہ دوکیا تم الله کو اپنی دین داری جتاتے ہو اور الله جانتا ہے جو کچھ آسمانوں میں اور زمین میں ہے اور الله ہر چیز کو جاننے والا ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxix{آپ پر اپنے اسلام لانے کا احسان جتاتے ہیں کہہ دو مجھ پراپنے اسلام لانے کا احسان نہ جتلاؤ بلکہ الله تم پر احسان رکھتا ہے کہ اس نے ایمان کی طرف تمہاری رہنمائی کی اگر تم سچے ہو\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxx{بے شک الله آسمانوں اور زمین کی سب مخفی چیزیں جانتا ہےاوردیکھ رہاہےجوتم کررہےہو\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxi{\basmalahur قۤ۔ اس قرآن کی قسم جو بڑا شان والا ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxii{بلکہ وہ تعجب کرتے ہیں کہ ان کے پاس انہیں میں سے ایک ڈرانے والا آیا پس کافرو ں نے کہا کہ یہ تو ایک عجیب بات ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxiii{کیا جب ہم مرجائیں گے اورمٹی ہو جائیں گے یہ دوبارہ زندگی بعید از قیاس ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxiv{ہمیں معلوم ہے جو زمین ان میں سے کم کرتی ہے اور ہمارے پاس ایک کتاب ہے جس میں سب کھچ محفوظ ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxv{بلکہ انہوں نے حق کو جھٹلایا جب کہ وہ ان کے پاس آیا پس وہ ایک الجھی ہوئی بات میں پڑے ہوئے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxvi{پس کیا انہوں نے غور سے اپنے اوپر آسمان کو نہیں دیکھا کہ ہم نے کس طرح اسے بنایا اور آراستہ کیا ہے اور اس میں کوئی بھی شگاف نہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxvii{اور ہم نے زمین کو بچھا دیا اوراس میں مضبوط ڈال دیے اور اس میں ہر قسم کی خوشنما چیزیں اگائیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxviii{ہر رجوع کرے والے بندے کے لیے بصیرت اور نصیحت ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxix{اور ہم نے آسمان سے برکت والا پانی اتارا پھر ہم پھر ہم نے اس کے ذریعے سے باغ اگائے اور اناج جن کے کھیت کاٹے جاتے ہیں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxl{او رلمبی لمبی کھجوریں جن کے خوشے تہہ بہ تہہ ہیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxli{بندوں کے لیے روزی اورہم نے اس سے ایک مردہ بستی کو زندہ کیا دوبارہ نکلنا اس طرح ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxlii{ان سے پہلے قوم نوح اور کنوئیں والوں نے اور قوم ثمود نے جھٹلایا\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxliii{اور قوم عاد اور فرعون اور قوم لوط نے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxliv{اور بن والو ں اور قوم تبعّ نے ہر ایک نےرسولوں کو جھٹلایا تو ہمارا وعدہ عذاب ثابت ہوا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxlv{کی ہم پہلی بار پیدا کرنے میں تھک گئے ہیں (نہیں) بلکہ وہ از سرِ نو پیدا کرنے کے متعلق شک میں ہیں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxlvi{اور بے شک ہم نے انسان کو پیدا کیا اور ہم جانتے ہیں جو وسوسہ اس کے دل میں گزرتا ہے اور ہم اس سے اس کی رگ گلو سے بھی زیادہ قریب ہیں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxlvii{جب کہ ضبط کرنے والے دایں اوربائیں بیٹھیں ہوئے ضبط کرتے جاتے ہیں\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxlviii{وہ منہ سے کوئی بات نہیں نکالتا مگراس کے پاس ایک ہوشیار محافظ ہوتا ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxlix{اور موت کی بے ہوشی تو ضرور آ کر رہے گی یہی ہے وہ جس سے تو گریز کرتا تھا\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmdcl{اور صور میں پھونکا جائے گا وعدہ عذاب کا دن یہی ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmdcli{اور ہر ایک شخص آئے گا اس کے ساتھ ایک ہانکنے والا اورایک گواہی دینے والا ہوگا\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmdclii{بے شک تو تو اس دن سے غفلت میں رہا پس ہم نے تجھ سے تیرا پردہ دور کر دیا پس تیری نگاہ آج بڑی تیز ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmdcliii{اور اس کا ساتھی کہے گا یہ ہے جو میرے پاس تیار ہے (حکم ہوگ)\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmdcliv{تم دونوں ہر کافر سرکش کو دوزخ میں ڈال دو\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmdclv{جو نیکی سےروکنے والا حد سےبڑھنے والا شک کرنے والا ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmdclvi{جس نے الله کے ساتھ کوئی دوسرا معبود ٹھیرایا پس اسے سخت عذاب میں ڈال دو\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmdclvii{اس کا ہم نشین کہے گا اے ہمارے رب میں نے اسے گمراہ نہیں کیا تھا بلکہ وہ خود ہی بڑی گمراہی میں پڑا ہوا تھا\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmdclviii{فرمائے گا تم میرے پاس مت جھگڑو اور میں تو پہلے تمہاری طرف اپنے عذاب کا وعدہ بھیج چکا تھا\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmdclix{میرے ہاں کی بات بدلی نہیں جاتی اور نہ ہی بندو ں کے لیے ظالم ہوں\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmdclx{جس دن ہم جہنم سے کہیں گے کیا تو بھر چکی اوروہ کہے گی کیا کچھ اوربھی ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxi{اوربہشت پرہیزگاروں کے لیے قریب لائی جائے گی کہ کچھ فاصلہ نہ ہوگا\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxii{یہی ہے جس کا تم سے وعدہ کیا جاتا تھا ہر رجوع کرنے والے اور حفاظت کرنے والے کے لیے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxiii{جو کوئی الله سے بن دیکھے ڈرا اور رجوع کرنے والا دل لے کر آیا\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxiv{اس میں سلامتی سے داخل ہو جاؤ ہمیشہ رہنے کا دن یہی ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxv{انہیں جو کچھ وہ چاہیں گے وہاں ملے گا اور ہمارے پاس اوربھی زیادہ ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxvi{اور ہم نے ان سے پہلے کتنی قومیں ہلاک کر دیں جو قوت میں ان سے بڑھ کر تھیں پھر (عذاب کے وقت) شہرو ں میں دوڑتے پھرنے لگے کہ کوئی پناہ کی جگہ بھی ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxvii{بے شک اس میں شخص کے لیے بڑی عبرت ہے جس کے پاس (فہیم) دل ہو یا وہ متوجہ ہو کر (بات کی طرف) کان ہی لگا دیتا ہو\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxviii{اور بے شک ہم نےآسمانوں اور زمین کو پیدا کیا اورجو کچھ ان کے درمیان میں ہے چھ دن میں اور ہمیں کچھ بھی تکان نہ ہوئی\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxix{پس ان باتوں پر صبر کر جو وہ کہتے ہیں اور اپنے رب کی پاکیزگی بیان کر تعریف کے ساتھ دن نکلنے سے پہلے اور دن چھپنے سے پہلے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxx{اورکچھ رات میں بھی اس کی تسبیح کر اور نماز کے بعد بھی\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxi{اور توجہ سے سنیئے جس دن پکارنے والا پاس سے پکارے گا\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxii{جس دن وہ ایک چیخ کو بخوبی سنیں گے یہ دن قبروں سے نکلنے کا ہوگا\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxiii{بے شک ہم ہی زندہ کرتے اورمارتے ہیں اورہماری طرف ہی لوٹ کر آنا ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxiv{جس دن ان پر سے زمین پھٹ جائے گی لوگ دوڑتے ہوئے نکل آئيں گے یہ لوگو ں کا جمع کرنا ہمیں بہت آسان ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxv{ہم جانتے ہیں جو کچھ وہ کہتے ہیں اور آپ ا ن پر کچھ زبردستی کرنے والے نہیں پھر آپ قرآن سے اس کو نصیحت کیجیئے جو میرے عذاب سے ڈرتا ہو\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxvi{\basmalahur قسم ہے ان ہواؤں کی جو (غبار وغیرہ) اڑانے والی ہیں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxvii{پھر ا ن بادلوں کی جو بوجھ (بارش کا) اٹھانے والے ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxviii{پھر ان کشتیوں کی جو نرمی سے چلنے والی ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxix{پھر ان فرشتوں کی جو حکم کے موافق چیزیں تقسیم کرنے واے ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxx{بے شک جس قیامت کا تم سے وعدہ کیا جاتا ہےوہ سچ ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxi{اور بے شک اعمال کی جزا ضرور ہونے والی ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxii{آسمان جالی دار کی قسم ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxiii{البتہ تم پیچیدہ بات میں پڑے ہوئے ہو\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxiv{قرآن سے وہی روکا جاتا ہےجوازل سے گمراہ ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxv{اٹکل پچو باتیں بنانے والے غارت ہوں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxvi{وہ جو غفلت میں بھولے ہوئے ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxvii{پوچھتے ہیں فیصلے کا دن کب ہوگا\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxviii{جس دن وہ آگ پر عذاب دیے جائیں گے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxix{اپنی شرارت کا مزہ چکہو یہی ہے وہ (عذاب) جس کی تم جلدی کرتے تھے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxc{بے شک پرہیزگار باغات اور چشموں میں ہوں گے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxci{لے رہے ہوں گے جو کچھ انہیں ان کا رب عطا کرے گا بے شک وہ اس سے پہلے نیکو کار تھے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxcii{وہ رات کے وقت تھوڑا عرصہ سویا کرتے تھے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxciii{اور آخر رات میں مغفرت مانگا کرتے تھے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxciv{اور ان کے مالوں میں سوال کرنے والے اور محتاج کا حق ہوتا تھا\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxcv{اور زمین میں یقین کرنے والوں کے لیے نشانیاں ہیں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxcvi{اور خود تمہاری نفسوں میں بھی پس کیا تم غور سے نہیں دیکھتے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxcvii{اور تمہاری روزی آسمان میں ہے اور جو تم سے وعدہ کیا جاتا ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxcviii{پس آسمان اور زمین کے مالک کی قسم ہے بے شک یہ (قرآن) برحق ہے جیسا تم باتیں کرتے ہو\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxcix{کیا آپ کو ابراھیم کے معزز مہمانوں کی بات پہنچی ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmdcc{جب کہ وہ اس پر داخل ہوئے پھر انہوں نے سلام کیا ابراھیم نے سوال کا جواب دیا (خیال کیا) کچھ اجنبی سے لوگ ہیں\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmdcci{پس چپکے سے اپنے گھر والوں کے پاس گیا اور ایک موٹا بچھڑا (تلا ہوا) لایا\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmdccii{پھر ان کے سامنے لا رکھا فرمایا کیا تم کھاتے نہیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmdcciii{پھر ان سے خوف محسوس کیا انہوں نے کہا تم ڈرو نہیں اور انہوں نے اسے ایک دانشمند لڑکے کی خوشخبری دی\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmdcciv{پھر ان کی بیوی شور مچاتی ہوئی آگے بڑھی اور اپنا ماتھا پیٹ کر کہنے لگی کیا بڑھیا بانجھ جنے گی\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmdccv{انہوں نے کہا تیرے رب نے یونہی فرمایا ہے بے شک وہ حکمت والا دانا ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmdccvi{فرمایا اے رسولو! تمہارا کیا مطلب ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmdccvii{انہوں نے کہا ہم ایک مجرم قوم کی طرف بھیجے گئے ہیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmdccviii{تاکہ ہم ان پر مٹی کے پتھر برسائیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmdccix{وہ آپ کے رب کی طرف حدسے بڑھنے والوں کے لیے مقرر ہو چکے ہیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmdccx{پھر ہم نے نکال لیا جو بھی وہا ں ایمان دار تھا\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxi{پھر ہم نے وہاں سوائے مسلمانوں کے ایک گھر کے نہ پایا\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxii{اورہم نے اس واقعہ میں ایسے لوگو ں کے لیے ایک عبرت رہنے دی جو دردناک عذاب سے ڈرتے ہیں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxiii{اور موسیٰ کے قصہ میں بھی عبرت ہے جب کہ ہم نے فرعون کے پا س ایک کھلی دلیل دے کر بھیجا\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxiv{سو اس نے مع اپنے ارکانِ سلطنت کے سرتابی کی اور کہا یہ جادوگر یا دیوانہ ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxv{پھر ہم نے اسے اور اس کے لشکروں کو پکڑ لیا پھر ہم نے انہیں سمند رمیں پھینک دیا اور اس نے کام ہی ملامت کا کیا تھا\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxvi{اور قوم عاد میں بھی (عبرت ہے) جب ہم نے ان پر سخت آندھی بھیجی\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxvii{جو کسی چیز کو نہ چھوڑتی جس پر سے وہ گزرتی مگر اسے بوسیدہ ہڈیوں کی طرح کر دیتی\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxviii{اور قوم ثمود میں بھی (عبرت ہے) جب ہ ان سے کہا گیا ایک وقت معین تک کا فائدہ اٹھاؤ\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxix{پھر انہوں نے اپنے رب کے حکم سے سرتابی کی تو ان کو بجلی نے آ پکڑا اوروہ دیکھ رہے تھے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxx{پھر نہ تو وہ اٹھ ہی سکے اور نہ وہ بدلہ ہی لے سکے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxi{اور قوم نوح کو اس سے پہلے (ہلاک کر دیا) بے شک وہ نافرمان لوگ تھے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxii{اور ہم نے آسمان کو قدرت سے بنایا اور ہم وسیع قدرت رہنے والے ہیں\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxiii{اورہم نے ہی زمین کو بچھایا پھر ہم کیا خوب بچھانے والے ہیں\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxiv{اور ہم نے ہی ہر چیز کا جوڑا پیدا کیا تاکہ تم غور کرو\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxv{پھر الله کی طرف دوڑو بے شک میں تمہارے لیے الله کی طرف سے کھلم کھلا ڈرانے والا ہوں\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxvi{اور اللہ کے ساتھ کوئی دوسرا معبود نہ ٹھراؤ بےشک میں تمہارے لئے اس کی طرف سے کھلم کھلا ڈرانے والا ہوں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxvii{اسی طرح ان سے پہلوں کے پا س بھی جب کوئی رسول آیا تو انہوں نے یہی کہا کہ یہ جادوگر یا دیوانہ ہے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxviii{کیا ایک دوسرے سے یہی کہ مرے تھے نہیں بلکہ وہ خود ہی سرکش ہیں\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxix{پس آپ ان کی پرواہ نہ کیجیئے آپ پر کوئی الزام نہیں\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxx{اور نصیحت کرتے رہیئے بے شک ایمان والوں کو نصیحت نفع دیتی ہے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxi{اور میں نے جن اور انسان کو بنایا ہے تو صرف اپنی بندگی کے لیے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxii{میں ان سے کوئی روزی نہیں چاہتا ہوں اور نہ ہی چاہتا ہوں کہ وہ مجھے کھلائیں\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxiii{بے شک الله ہی بڑا روزی دینے والا زبردست طاقت والا ہے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxiv{پس بے شک ان کے لیے جو ظالم ہیں حصہ ہے جیسا کہ ان کے ساتھیوں کا حصہ تھا تو وہ مجھ سے جلدی کا مطالبہ نہ کریں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxv{پس ہلاکت ہے ان کے لیے جو کافر ہیں اس دن جس کا ان سے وعدہ کیا جاتا ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxvi{\basmalahur قسم ہے طور کی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxvii{اور اس کتاب کی جو لکھی گئی ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxviii{کشادہ ورقوں میں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxix{اور آباد گھر کی قسم ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxl{اور اونچی چھت کی\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxli{اور جوش مارتے ہوئے سمندر کی\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxlii{بے شک آپ کے رب کا عذاب واقع ہوکر رہے گا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxliii{اسے کوئی ٹالنے والا نہیں ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxliv{جس دن آسمان تھرتھرا کر لرزنے لگے گا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxlv{اور پہاڑ تیزی سے چلنے لگیں گے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxlvi{پس اس دن جھٹلانے والوں کے لیے ہلاکت ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxlvii{جو جھوٹی باتوں میں لگے ہوئے کھیل رہے ہیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxlviii{جس دن وہ دوزخ کی آگ کی طرف بری طرح سے دھکیلے جائیں گے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxlix{یہی وہ آگ ہے جسے تم دنیا میں جھٹلاتے تھے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmdccl{پس کیایہ جادو ہے یا تم دیکھتے نہیں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmdccli{اس میں داخل ہو جاؤ پس تم صبر کرو یا نہ کرو تم پر برابر ہے تمہیں تو ویسا ہی بدلہ دیا جائے گا جیسا تم کرتے تھے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclii{بے شک پرہیز گار باغوں اور نعمتوں میں ہوں گے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmdccliii{محظوظ ہو رہے ہوں گے اس سے جو انہیں ان کے رب نے عطا کی ہے اور ان کو ان کے رب نے عذاب دوزخ سے بچا دیا ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmdccliv{مزے سے کھاؤ اور پیو بدلے ان (اعمال) کے جو تم کیا کرتے تھے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclv{تختوں پر تکیہ لگائے ہوئے جو قطاروں میں بچھے ہوئے ہیں اور ہم ان کا نکاح بڑی بڑی آنکھوں والی حوروں سے کر دیں گے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclvi{اور جو لوگ ایمان لائے اور ان کی اولاد نے ایمان میں ان کی پیروی کی ہم ان کے ساتھ ان کی اولاد کو بھی (جنت) میں ملا دیں گے اور ان کے عمل میں سے کچھ بھی کم نہ کریں گے ہر شخص اپنے عمل کے ساتھ وابستہ ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclvii{اور ہم انہیں اور زیادہ میوے دیں گے اور گوشت جو وہ چاہیں گے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclviii{وہاں ایک دوسرے سے شراب کا پیالہ لیں گے جس میں نہ بکواس ہو گی نہ گناہ کا کام\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclix{اور ان کے پاس لڑکے ان کی خدمت کے لیے پھر رہے ہوں گے گویا وہ غلافوں میں رکھے ہوئے موتی ہیں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclx{اورایک دوسرے کی طرف متوجہ ہو کر آپس میں پوچھیں گے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxi{کہیں گے ہم تو اس سے پہلے اپنے گھروں میں ڈرا کرتے تھے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxii{پس الله نے ہم پر احسان کیا اور ہمیں لُو کے عذاب سے بچا لیا\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxiii{بے شک ہم اس سے پہلے اسے پکارا کرتے تھے بے شک وہ بڑا ہی احسان کرنے والا نہایت رحم والا ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxiv{پس نصیحت کرتے رہئے آپ اپنے رب کے فضل سے نہ کاہن ہیں نہ دیوانہ ہیں\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxv{کیا وہ کہتے ہیں کہ وہ شاعر ہے ہم اس پر گردشِ زمانہ کا انتظار کر رہے ہیں\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxvi{کہہ دو تم انتظار کرتے رہو بے شک میں بھی تمہارے ساتھ منتظر ہوں\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxvii{کیا ان کی عقلیں انہیں اس بات کا حکم دیتی ہیں یا وہ خود ہی سرکش ہیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxviii{یا وہ کہتے ہیں کہ اس نے اسے خود بنا لیا ہے بلکہ وہ ایمان ہی نہیں لاتے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxix{پس کوئی کلام اس جیسا لے آئيں اگر وہ سچے ہیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxx{کیا وہ بغیر کسی خالق کے پیدا ہو گئے ہیں یا وہ خود خالق ہیں\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxi{یا انہوں نے آسمانوں اور زمین کوبنایا ہے نہیں بلکہ وہ یقین ہی نہیں کرتے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxii{کیا ان کے پاس آپ کے رب کے خزانے ہیں یا وہ داروغہ ہیں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxiii{کیا ان کے پاس کوئی سیڑھی ہے کہ وہ اس پر چڑھ کر سن آتے ہیں تو لے آئے ان میں سے سننے والا کوئی دلیل واضح\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxiv{کیا اس کے لیے توبیٹیاں ہیں اور تمہارے لیے بیٹے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxv{کیا آپ ان سے کوئی صلہ مانگتے ہیں کہ وہ تاوان سے دبے جا رہے ہیں\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxvi{یا ان کے پاس علم غیب ہے کہ وہ اسے لکھتے رہتے ہیں\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxvii{کیا وہ کوئی داؤ کرنا چاہتے ہیں پس جو منکر ہیں وہی داؤ میں آئے ہوئے ہیں\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxviii{کیا سوائے الله کے ان کا کوئی اور معبود ہے الله اس سےپاک ہے جو وہ شریک ٹھہراتے ہیں\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxix{اگر وہ ایک ٹکڑا آسمان سے گرتا ہوا دیکھ لیں تو کہہ دیں کہ تہ بہ تہ جما ہوا بادل ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxx{پس آپ انہیں چھوڑ دیجیئے یہاں تک کہ وہ اپنا وہ دن دیکھ لیں جس میں وہ بے ہوش ہو کر گر پڑیں گے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxi{جس دن ان کا داؤ ان کے کچھ بھی کام نہ آئے گا اور نہ انہیں مدد دی جائے گی\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxii{اوربے شک ان ظالموں کو علاوہ اس کے ایک عذاب (دنیا میں) ہوگا لیکن اکثر ان میں سے نہیں جانتے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxiii{اور اپنے رب کا حکم آنے تک صبر کر کیوں کہ بےشک آپ ہماری آنکھوں کے سامنے ہیں اور اپنے رب کی حمد کے ساتھ تسبیح کیجیئے جب آپ اٹھا کریں\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxiv{اور (کچھ حصہ رات میں بھی) اس کی تسبیح کیا کیجیئے اور ستاروں کے غروب ہونے کے بعد بھی\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxv{\basmalahur ستارے کی قسم ہے جب وہ ڈوبنے لگے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxvi{تمہارا رفیق نہ گمراہ ہوا ہے اورنہ بہکا ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxvii{اور نہ وہ اپنی خواہش سے کچھ کہتا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxviii{یہ تو وحی ہے جو اس پر آتی ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxix{بڑے طاقتور (جبرائیل) نے اسے سکھایا ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxc{جو بڑا زور آور ہے پس وہ قائم ہوا (اصلی صورت میں)\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxci{اور وہ (آسمان کے) اونچے کنارے پر تھا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxcii{پھر نزدیک ہوا پھر اور بھی قریب ہوا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxciii{پھر فاصلہ دو کمان کے برابر تھا یا اس سے بھی کم\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxciv{پھر اس نے الله کےبندے کے دل میں القا کیا جو کچھ القا کیا دل نے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxcv{جھوٹ نہیں کہا تھا جو دیکھا تھا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxcvi{پھر جو کچھ اس نے دیکھا تم اس میں جھگڑتے ہو\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxcvii{اور اس نے اس کو ایک بار اور بھی دیکھا ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxcviii{سدرة المنتہیٰ کے پاس\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxcix{جس کے پاس جنت الماویٰ ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmdccc{جب کہ اس سدرة پر چھا رہا تھا جو چھا رہا تھا (یعنی نور)\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmdccci{نہ تو نظر بہکی نہ حد سے بڑھی\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccii{بے شک اس نے اپنے رب کی بڑی بڑی نشانیاں دیکھیں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmdccciii{پھر کیا تم نے لات اور عزیٰ کو بھی دیکھاہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmdccciv{اور تیسرے منات گھٹیا کو (دیکھا ہے)\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccv{کیا تمہارے لیے بیٹے اور اس کے لیے بیٹیاں ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccvi{تب تو یہ بہت ہی بری تقسیم ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccvii{یہ تو صرف نام ہی نام ہیں جو تم نے اور تمہارے باپ دادا نے گھڑ لیے ہیں جن پر خدا نے کوئی سندبھی نہیں اتاری وہ محض وہم اور اپنی خواہش کی پیروی کرتے ہیں حالانکہ ان کے پاس ان کے رب کے ہاں سے ہدایت آ چکی ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccviii{پھر کیا انسان کو وہی مل جاتا ہے جس کی تمنا کرتا ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccix{پس آخرت اور دنیا الله ہی کے اختیار میں ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccx{اور بہت سے فرشتے آسمان میں ہیں کہ جن کی شفاعت کسی کے کچھ بھی کام نہیں آتی مگر اس کے بعدکہ الله جس کے لیے چاہے اجازت دے اور پسند کرے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxi{بے شک جو لوگ آخرت پر ایمان نہیں لاتے وہ فرشتوں کے عورتوں کے سے نام رکھتے ہیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxii{اور اس بات کو کچھ بھی نہیں جانتے محص وہم پر چلتے ہیں اوروہم حق بات کی جگہ کچھ بھی کام نہیں آتا\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxiii{پھر تم اس کی پرواہ نہ کرو جس نے ہماری یاد سے منہ پھیر لیا ہے اور صرف دنیا ہی کی زندگی چاہتا ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxiv{ان کی سمجھ کی یہیں تک رسائی ہے بے شک آپ کا رب اس کو خوب جانتا ہے جو اس کے راستہ سے بہکا اور اس کو بھی خوب جانتا ہے جو راہ پر آیا\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxv{اور الله ہی کا ہے جو کچھ آسمانوں اور زمین میں ہے تاکہ براکرنے والوں کو ان کے بدلہ دے اور نیکی کرنے والوں کو نیک بدلہ دے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxvi{وہ جو بڑے گناہوں اور بے حیائی کی باتوں سے بچتے ہیں مگر صغیرہ گناہوں سے بے شک آپ کا رب بڑی وسیع بخشش والا ہے وہ تمہیں خوب جانتا ہے جب کہ تمہیں زمین سے پیدا کیا تھا اور جب کہ تم اپنی ماں کے پیٹ میں بچے تھے پس اپنے آپ کو پاک نہ سمجھو وہ پرہیزگار کو خوب جانتا ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxvii{بھلا آپ نے اس شخص کو دیکھا جس نے منہ پھیر لیا\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxviii{اور تھوڑا سا دیا اور سخت دل ہو گیا\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxix{کیا اس کے پاس غیب کا علم ہے کہ وہ دیکھ رہا ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxx{کیا اسے ان باتوں کی خبر نہیں پہنچی جو موسیٰ کے صحیفوں میں ہیں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxi{اورابراھیم کے جس نے (اپنا عہد) پورا کیا\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxii{وہ یہ کہ کوئی کسی کا بوجھ نہیں اٹھائے گا\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxiii{اور یہ کہ انسان کو وہی ملتا ہے جو کرتا ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxiv{اور یہ کہ اس کی کوشش جلد دیکھی جائے گی\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxv{پھر اسے پورا بدلہ دیا جائے گا\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxvi{اوریہ کہ سب کو آپ کے رب ہی کی طرف پہنچتا ہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxvii{اور یہ کہ وہی ہنساتا ہے اوررلاتا ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxviii{اور یہ کہ وہی مارتا ہے اور زندہ کرتا ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxix{اور یہ کہ اسی نے جوڑا نر اور مادہ کا پیدا کیا ہے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxx{ایک بوند سے جب کہ وہ ٹپکائی جائے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxi{اور یہ کہ دوسری بارزندہ کر کے اٹھانا اسی کے ذمہ ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxii{اور یہ کہ وہی غنی اور سرمایہ دار کرتا ہے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxiii{اور یہ کہ وہی شعریٰ کا رب ہے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxiv{اور یہ کہ اسی نے عاد اولیٰ کو ہلاک کیا تھا\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxv{اور ثمود کو پس اسے باقی نہ چھوڑا\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxvi{اور اس سے پہلے نوح کی قوم کو بے شک وہ زیادہ ظالم اور زيادہ سرکش تھے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxvii{اور الٹی بستی کو اس نے دے ٹپکا\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxviii{پس اس پر وہ (تباہی) چھا گئی جوچھا گئی\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxix{پس اپنے رب کی کون کون سی نعمت میں تو شک کرے گا\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxl{یہ بھی ایک ڈرانے والا ہے پہلے ڈرانے والوں میں سے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxli{آنے والی قریب آ پہنچی\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxlii{سوائے الله کے اسے کوئی ہٹانے والا نہیں\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxliii{پس کیا اس بات سے تم تعجب کرتے ہو\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxliv{اور ہنستے ہو اور روتے نہیں\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxlv{اور تم کھیل رہے ہو\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxlvi{پس الله کے آگے سجدہ کرو اور اس کی عبادت کرو\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxlvii{\basmalahur قیامت قریب آ گئی اور چاند پھٹ گیا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxlviii{اور اگر وہ کوئی معجزہ دیکھ لیں تو اس سے منہ موڑ لیں اور کہیں یہ تو ہمیشہ سے چلا آتا جادو ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxlix{اور انہوں نے جھٹلایا اور اپنی خواہشوں کی پیروی کی اور ہر بات کے لیے ایک وقت مقرر ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccl{اور ان کے پاس وہ خبریں آ چکی ہیں جن میں کافی تنبیہ ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccli{اورپوری دانائی بھی ہے پر ان کو ڈرانے والوں سے فائدہ نہیں پہنچا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclii{پس ان سے منہ موڑ لے جس دن پکارنے والا ایک نا پسند چیز کے لیے پکارے گا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccliii{اپنی آنکھیں نیچے کیے ہوئے قبروں سے نکل پڑیں گے جیسے ٹڈیاں پھیل پڑی ہوں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccliv{بلانے والے کی طرف بھاگے جا رہے ہوں گے یہ کافر کہہ رہے ہوں گے یہ تو بڑا ہی سخت دن ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclv{ان سے پہلے قوم نوح نے بھی جھٹلایا تھا پس انہوں نے ہمارے بندے کو جھٹلایا اور کہا دیوانہ ہے اور اسے جھڑک دیا گیا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclvi{پھر نوح نے اپنے رب کو پکارا کہ میں تو مغلوب ہو گیا تو میری مدد کر\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclvii{پھر ہم نے موسلا دھار پانی سے آسمان کے دروازے کھول دیے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclviii{اور ہم نے زمین سے چشمے جاری کر دیے پھر جہاں تک پانی کا چڑھاؤ چڑھنا ٹھہر چکا تھاچڑھ آیا\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclix{اور ہم نے نوح کو تختوں اور کیلوں والی کشتی پر سوار کیا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclx{جو ہماری عنایت سے چلتی تھی یہ اس کا بدلہ تھا جس کا انکار کیا گیا تھا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxi{اور ہم نے اس کو ایک نشان بنا کر چھوڑ دیا پس کیا کوئی نصیحت پکڑنے والا ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxii{پھر (دیکھا) ہمارا عذاب اور ڈرانا کیسا تھا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxiii{اور البتہ ہم نے تو سمجھنے کے لیے قرآن کو آسان کر دیا پھر کوئی ہے کہ سمجھے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxiv{قوم عاد نے بھی جھٹلایا تھا پھر (دیکھا) ہمارا عذاب اور ڈرانا کیسا تھا\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxv{بے شک ہم نے ایک دن سخت آندھی بھیجی تھی جس کی نحوست دائمی تھی\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxvi{جو لوگوں کو ایسا پھینک رہی تھی کہ گویا وہ کھجور کے جڑ سے اکھڑے ہوئے پیڑ ہیں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxvii{پھر (دیکھا) ہمارا عذاب اور ڈرانا کیسا تھا\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxviii{اور البتہ ہم نے قرآن کو سمجھنے کے لیے آسان کر دیا ہے پھر ہے کوئی کہ سمجھے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxix{قوم ثمود نے بھی ڈرانے والوں کو جھٹلایا تھا\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxx{پس کہا کیا ہم اپنے میں سے ایک آدمی کے کہنے پر چلیں گے تب تو ہم ضرور گمراہی اور دیوانگی میں جا پڑیں گے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxi{کیا ہم میں سے اسی پر وحی بھیجی گئی بلکہ وہ بڑا جھوٹا (اور) شیخی خورہ ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxii{عنقریب انہیں معلوم ہو جائے گا کون بڑا جھوٹا (اور) شیخی خورہ ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxiii{بے شک ہم ان کی آزمائش کے لیے اونٹنی بھیجنے والے ہیں پس (اے صالح) ان کا انتظار کر اور صبر کر\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxiv{اور ان سے کہہ دو کہ پانی ان میں بٹ گیا ہے ہر ایک اپنی باری سے پانی پلایا کرے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxv{پھر انہوں نے اپنے رفیق کو بلایا تب اس نے ہاتھ بڑھایا اور (اس کی) کانچیں کاٹ ڈالیں\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxvi{پھر (دیکھا) ہمارا عذاب اور ڈرانا کیسا تھا\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxvii{بے شک ہم نے ان پر ایک زور کی چیخ کا عذاب بھیجا پھر وہ ایسے ہو گئے جیسا کانٹو ں کی باڑ کا چورا\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxviii{اور البتہ ہم نے قرآن کو سمجھنے کے لیے آسان کر دیا ہے پھر ہے کوئی سمجھنے والا\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxix{قوم لوط نے بھی ڈرانے والوں کو جھٹلایا تھا\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxx{بے شک ہم نے ان پر پتھر برسائے سوائے لوط کے گھر والوں کے ہم نے انہیں پچھلی رات نجات دی\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxi{یہ ہماری طرف سے فضل ہے جو شکر کرتا ہے ہم اسے ایسا ہی بدلہ دیا کرتے ہیں\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxii{اور وہ انہیں ہماری پکڑ سے ڈرا چکا تھا پس وہ ڈرانے میں شک کرنے لگے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxiii{اور البتہ اس سے اس کے مہمانوں کا مطالبہ کرنے لگے تو ہم نے ان کی آنکھیں مٹا دیں پس (کہا) میرے عذاب اور میرے ڈرانے کا مزہ چکھو\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxiv{اور بے شک صبح کو ان پر ایک عذاب نہ ٹلنے والا آ پڑا\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxv{پس میرے عذاب اور میرے ڈرانے کا مزہ چکھو\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxvi{اور البتہ ہم نے سمجھنے کے لیے قرآن کو آسان کر دیا ہے پھر ہے کوئی سمجھنے والا\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxvii{اور البتہ فرعون کے خاندان کے پاس بھی ڈرانے والے آئے تھے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxviii{انہوں نے ہماری سب نشانیوں کو جھٹلایا پھر ہم نے انہیں بڑی زبردست پکڑ سے پکڑا\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxix{کیا تمہارے منکر ان لوگوں سے اچھے ہیں یا تمہارے لیے کتابوں میں نجات لکھی ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxc{کیا وہ یہ کہتے ہیں کہ ہم زبردست جماعت ہیں\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxci{عنقریب یہ جماعت بھی شکست کھائے گی اور پیٹھ پھیر کر بھاگیں گے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxcii{بلکہ قیامت ان کے وعدے کا وقت ہے اور قیامت زیادہ دہشت ناک اور تلخ تر ہے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxciii{بے شک مجرم گمراہی اور جنون میں ہیں\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxciv{جس دن اپنے منہ کے بل دوزخ میں گھسیٹے جائیں گے (کہا جائے گا) آگ لگنے کا مزہ چکھو\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxcv{بے شک ہم نے ہر چیز اندازے سے بنائی ہے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxcvi{اور ہمارا حکم تو ایک ہی بات ہوتی ہے جیسا کہ پلک جھپکنا\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxcvii{اور البتہ ہم تمہارے جیسوں کو غارت کر چکے ہیں پھر کیا کوئی سمجھنے والا ہے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxcviii{اور پھر جو کچھ بھی انہوں نے کیا ہے وہ اعمال ناموں میں موجود ہے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxcix{اور ہر چھوٹا اور بڑا کام لکھا ہوا ہے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmcm{بے شک پرہیزگار باغوں اور نہروں میں ہوں گے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmcmi{عزت کے مقام میں قادر مطلق بادشاہ کے حضور میں\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmcmii{\basmalahur رحمنٰ ہی نے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmcmiii{قرآن سکھایا\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmcmiv{اس نے انسان کو پیدا کیا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmcmv{اسے بولنا سکھایا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmcmvi{سورج اور چاند ایک حساب سے چل رہے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmcmvii{اوربیلیں اور درخت سجدہ کر رہے ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmcmviii{اور آسمان کو اسی نے بلند کر دیا اور ترازو قائم کی\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmcmix{تاکہ تم تولنے میں زیادتی نہ کرو\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmcmx{اور انصاف سے تولو اور تول نہ گھٹاؤ\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxi{اور اس نے خلقت کے لیے زمین کو بچھا دیا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxii{اس میں میوے اور غلافوں والی کھجوریں ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxiii{اور بھوسے دار اناج اور پھول خوشبو دار ہیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxiv{پھر تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxv{اس نے انسان کو ٹھیکری کی طرح بجتی ہوئی مٹی سے پیدا کیا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxvi{اور اس نے جنوں کو آگ کے شعلے سے پیدا کیا\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxvii{پھر تم (اے جن و انس) اپنے رب کی کس کس نعمت کو جھٹلاؤ گے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxviii{وہ دونوں مشرقوں اور مغربوں کا مالک ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxix{پھر تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxx{اس نے دو سمندر ملا دیئے جو باہم ملتے ہیں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxi{ان دونوں میں پردہ ہے کہ وہ حد سے تجاوز نہیں کرسکتے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxii{پھر تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxiii{ان دونوں میں سے موتی اور مونگا نکلتا ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxiv{پھر تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxv{اور سمند ر میں پہا ڑوں جیسے کھڑے ہوئے جہاز اسی کے ہیں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxvi{پھر تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxvii{جو کوئی زمین پر ہے فنا ہوجانے والا ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxviii{اور آپ کے پروردگار کی ذات باقی رہے گی جو بڑی شان اور عظمت والا ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxix{پھر تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxx{اس سے مانگتے ہیں جو آسمانوں اور زمین میں ہیں ہر روز وہ ایک کام میں ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxi{پھر تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxii{اے جن و انس ہم تمہارے لیے جلد ہی فارغ ہو جائیں گے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxiii{پھر تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxiv{اے جنوں اور انسانوں کے گروہ اگر تم آسمانوں اور زمین کی حدود سے باہر نکل سکتے ہو تو نکل جاؤ تم بغیر زور کے نہ نکل سکو گے (اور وہ ہے نہیں)\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxv{پھر تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxvi{تم پر آگے کے شعلے اور دھواں چھوڑا جائے گا پھر تم بچ نہ سکو گے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxvii{پھر تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxviii{پھر جب آسمان پھٹ جائے گا اور پھٹ کر گلابی تیل کی طرح سرخ ہو جائے گا\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxix{پھر تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxl{پس اس دن اپنے گناہ کی بات نہ کوئی انسان اور نہ کوئی جن پوچھا جائے گا\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxli{پھر تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxlii{مجرم اپنے چہرے کے نشان سے پہچانے جائیں گے پس پیشانی کے بالوں اور پاؤں سے پکڑے جائیں گے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxliii{پھر تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxliv{یہی وہ دوزخ ہے جسے مجرم جھٹلاتے تھے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxlv{گناہ گار جہنم میں اور کھولتے ہوئے پانی میں تڑپتے پھریں گے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxlvi{پھر تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxlvii{اوراس کے لیے جو اپنے رب کے سامنے کھڑا ہونے سے ڈرتا ہے دو باغ ہوں گے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxlviii{پھر تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxlix{جن میں بہت سی شاخیں ہوں گی\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmcml{پھر تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmcmli{ان دونوں میں دو چشمے جاری ہوں گے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlii{پھر تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmcmliii{ان دونوں میں ہر میوہ کی دو قسمیں ہوں گی\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmcmliv{پھر تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlv{ایسے فرشتو ں پر تکیہ لگائے بیٹھے ہوں گے کہ جن کا استر مخملی ہوگا اور دونوں باغوں کا میوہ جھک رہا ہوگا\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlvi{پھر تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlvii{ان میں نیچی نگاہوں والی عورتیں ہوں گی نہ تو انہیں ان سے پہلے کسی انسان نے اور نہ کسی جن نے چھوا ہوگا\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlviii{پھر تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlix{گویا کہ وہ یاقوت اور مونگا ہیں\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlx{پھر تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxi{نیکی کا بدلہ نیکی کے سوا اور کیا ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxii{پھر تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxiii{اور ان دو کے علاوہ اور دو باغ ہوں گے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxiv{پھر تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxv{وہ دونوں بہت ہی سبز ہوں گے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxvi{پھر تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxvii{ان دونوں میں دو چشمے ابلتےہوئے ہوں گے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxviii{پھر تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxix{ان دونوں میں میوے اور کھجوریں اور انار ہوں گے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxx{پھر تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxi{ان میں نیک خوبصورت عورتیں ہوں گی\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxii{پھر تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxiii{وہ حوریں جو خیموں میں بند ہوں گی\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxiv{پھر تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxv{نہ انہیں ان سےپہلے کسی انسان نے اور نہ کسی جن نے چھوا ہوگا\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxvi{پھر تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxvii{قالینوں پر تکیہ لگائے ہوئے ہوں گے جو سبز اور نہایت قیمتی نفیس ہوں گے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxviii{پھر تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxix{آپ کے رب کا نام با برکت ہے جو بڑی شان اور عظمت والا ہے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxx{\basmalahur جب واقع ہونے والی واقع ہو گی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxi{جس کے واقع ہونے میں کچھ بھی جھوٹ نہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxii{پست کرنے والی اور بلند کرنے والی\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxiii{جب کہ زمین بڑے زور سے ہلائی جائے گی\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxiv{اور پہاڑ ٹکڑے ٹکڑے ہو کر چورا ہو جائیں گے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxv{سو و ہ غبار ہو کر اڑتے پھریں گے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxvi{اور (اس وقت) تمہاری تین جماعتیں ہو جائیں گی\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxvii{پھر داہنے والے کیا خوب ہی ہیں داہنے والے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxviii{اوربائیں والے کیسے برے ہیں بائیں والے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxix{اور سب سے اول ایمان لانے والے سب سے اول داخل ہونے والے ہیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxc{وہ الله کے ساتھ خاص قرب رکھنے والے ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxci{نعمت کے باغات ہوں گے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxcii{پہلوں میں سے بہت سے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxciii{اور پچھلوں میں سے تھوڑے سے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxciv{تختوں پر جو جڑاؤ ہوں گے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxcv{آمنے سامنے تکیہ لگائے ہوئےبیٹھے ہوں گے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxcvi{ان کے پاس ایسے لڑکے جو ہمیشہ لڑکے ہی رہیں گے آمد و رفت کیا کریں گے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxcvii{آبخورے اور آفتابے اور ایسا جام شراب لے کر جو بہتی ہوئی شراب سے بھرا جائے گا\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxcviii{نہ اس سے ان کو دردِ سر ہوگا اور نہ اس سے عقل میں فتور آئے گا\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxcix{اور میوے جنہیں وہ پسند کریں گے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmm{اور پرندوں کا گوشت جو ان کو مرغوب ہو گا\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmi{اوربڑی بڑی آنکھوں والی حوریں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmii{جیسے موتی کئی تہو ں میں رکھےہوئے ہوں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmiii{بدلے اس کے جو وہ کیا کرتے تھے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmiv{وہ وہاں کوئی لغو اور گناہ کی بات نہیں سنیں گے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmv{مگر سلام سلام کہنا\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmvi{اور داہنے والے کیسے اچھے ہوں گے داہنے والے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmvii{وہ بے کانٹوں کی بیریوں میں ہوں گے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmviii{اور گتھے ہوئے کیلو ں میں\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmix{اورلمبے سایوں میں\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmx{اور پانی کی آبشاروں میں\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmxi{اور باافراط میوں میں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmxii{جونہ کبھی منقطع ہوں گے اور نہ ان میں روک ٹوک ہو گی\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmxiii{اور اونچے فرشتوں میں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmxiv{بے شک ہم نے انہیں (حوروں کو) ایک عجیب انداز سے پیدا کیا ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmxv{پس ہم نے انہیں کنواریاں بنا دیا ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmxvi{دل لبھانے والی ہم عمر بنایا ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmxvii{داہنے والوں کے لیے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmxviii{بہت سے پہلوں میں سے ہوں گے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmxix{اور بہت سے پچھلوں میں سے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmxx{اوربائیں والے کیسے برے ہیں بائیں والے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxi{وہ لووں اور کھولتے ہوئے پانی میں ہوں گے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxii{اور سیاہ دھوئیں کے سائے میں\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxiii{جو نہ ٹھنڈا ہوگا اور نہ راحت بخش\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxiv{بے شک وہ اس سے پہلے خوش حال تھے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxv{اور بڑے گناہ (شرک) پر اصرار کیا کرتے تھے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxvi{اور کہا کرتے تھے کیا جب ہم مر جائیں گے اور مٹی اور ہڈیاں ہو جائیں گے تو کیا ہم پھر اٹھاے جائیں گے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxvii{اور کیا ہمارے اگلے باپ دادا بھی\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxviii{کہہ دو بے شک پہلے بھی اور پچھلے بھی\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxix{ایک معین تاریخ کے وقت پر جمع کیے جاویں گے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxx{پھر بے شک تمہیں اے گمراہو جھٹلانے والو\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxi{البتہ تھوہر کا درخت کھانا ہوگا\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxii{پھر اس سے پیٹ بھرنے ہوں گے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxiii{پھر اس پر کھولتا ہوا پانی پینا ہوگا\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxiv{پھر پینا ہو گا پیاسے اونٹوں کا سا پینا\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxv{قیامت کے دن یہ ان کی مہمانی ہو گی\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxvi{ہم نے ہی تمہیں پیدا کیا ہے پس کیوں تم تصدیق نہیں کرتے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxvii{بھلا دیکھو (تو) (منی) جو تم ٹپکاتے ہو\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxviii{کیا تم اسے پیدا کرتے ہو یا ہم ہی پیدا کرنے والے ہیں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxix{ہم نے ہی تمہارے درمیان موت مقرر کر دی ہے اور ہم عاجز نہیں ہیں\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmmmxl{اس بات سے کہ ہم تم جیسے لوگ بدل لائیں اور تمہیں ایسی صورت میں بنا کھڑا کریں جو تم نہیں جانتے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmmmxli{اور تم پہلی پیدائش کو جان چکے ہو پھر کیوں تم غور نہیں کرتے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmmmxlii{بھلا دیکھو جو کچھ تم بولتے ہو\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmmmxliii{کیا تم اسے اگاتے ہو یا ہم اگانے والے ہیں\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmmmxliv{اگر ہم چاہیں تو اسے چورا چورا کر دیں پھر تم تعجب کرتے رہ جاؤ\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmmmxlv{کہ بے شک ہم پر تو تاوان پڑ گیا\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmmmxlvi{بلکہ ہم بے نصیب ہو گئے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmmmxlvii{بھلا دیکھو تو سہی وہ پانی جو تم پیتے ہو\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmmmxlviii{کیا تم نے اسے بادل سے اتارا ہے یا ہم اتارنے والے ہیں\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmmmxlix{اگر ہم چاہیں تو اسے کھاری کر دیں پس کیوں تم شکر نہیں کرتے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmmml{بھلا دیکھو تو سہی وہ آگ جو تم سلگاتے ہو\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmmmli{کیا تم نے اس کا درخت پیدا کیا ہے یا ہم پیدا کرنے والے ہیں\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmmmlii{ہم نے اسے یادگار اور مسافروں کے لیے فائدہ کی چیز بنا دیا ہے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmmmliii{پس اپنے رب کے نام کی تسبیح کر جو بڑا عظمت والا ہے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmmmliv{پھر میں تاروں کے ڈوبنے کی قسم کھاتا ہوں\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmmmlv{اور بے شک اگر سمجھو تو یہ بڑی قسم ہے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmmmlvi{کہ بے شک یہ قرآن بڑی شان والا ہے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmmmlvii{ایک پوشیدہ کتاب میں لکھا ہوا ہے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmmmlviii{جسے بغیر پاکو ں کے اور کوئی نہیں چھوتا\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmmmmlix{پروردگار عالم کی طرف سے نازل ہوا ہے\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmmmmlx{سو کیا تم اس کلام کو سرسری بات سمجھتے ہو\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxi{اور اپنا حصہ تم یہی لیتے ہو کہ اسے جھٹلاتے ہو\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxii{پھر کس لیے روح کو روک نہیں لیتے جب کہ وہ گلے تک آ جاتی ہے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxiii{اورتم اس وقت دیکھا کرتے ہو\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxiv{اور تم سے زیادہ ہم اس کے قرب ہوتے ہیں لیکن تم نہیں دیکھتے\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxv{پس اگر تمہارا حساب کتاب ہونے والا نہیں ہے\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxvi{تو تم اس روح کو کیوں نہیں لوٹا دیتے اگر تم سچے ہو\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxvii{پھر (جب قیامت آئے گی) اگر وہ مقربین میں سے ہے\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxviii{تو (اس کے لیے) راحت اور خوشبو میں اور عیش کی باغ ہیں\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxix{اور اگر وہ داہنے والوں میں سے ہے\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxx{تو اے شخص تو جو داہنے والوں میں سے ہے تجھ پر سلام ہو\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxi{اور اگر وہ جھٹلانے والے گمراہوں میں سے ہے\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxii{تو کھولتا ہوا پانی مہمانی ہے\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxiii{اور دوزخ میں داخل ہونا ہے\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxiv{بے شک یہ تحقیقی یقینی بات ہے\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxv{پس اپنے رب کی نام تسبیح کر جو بڑا عظمت والا ہے\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxvi{\basmalahur الله کی پاکیزگی بیان کرتے ہیں وہ جو آسمانوں اور زمین میں ہیں اور وہ زبردست حکمت والا ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxvii{آسمانوں اور زمین کی بادشاہت اسی کے یے ہے وہ زندہ کرتا ہے اور مارتا ہے اور وہ ہر چیز پر قادر ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxviii{وہی سب سے پہلا اور سب سے پچھلا اور ظاہر اور پوشیدہ ہے اور وہی ہر چیز کو جاننے والا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxix{وہی ہے جس نے آسمانوں اور زمین کو چھ دن میں بنایا پھر وہ عرش پر قائم ہوا وہ جانتا ہے جو چیز زمین میں داخل ہوتی ہے اور جو اس سے نکلتی ہے اور جو آسمان سے اترتی ہے اور جو اس میں اوپر چڑھتی ہے اور وہ تمہارے ساتھ ہے جہاں کہیں تم ہو اور الله اس کو جو تم کرتے ہو دیکھتا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxx{آسمانوں اورزمین کی حکومت اسی کے لیے ہے اور سب امور الله ہی کی طرف لوٹائے جاتے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxi{وہ رات کو دن میں داخل کرتا ہے اور دن کو رات میں داخل کرتا ہے اوروہ سینوں کے بھید خوب جانتا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxii{الله اور اس کے رسول پر ایمان لاؤ اور اس میں سے خرچ کرو جس میں اس نے تمہیں پہلوں کا جانشین بنایا ہے پس جو لوگ تم میں سے ایمان لائے اور انہوں نے خرچ کیا ان کے لیے بڑا اجر ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxiii{اور تمہیں کیا ہوا جو الله پر ایمان نہیں لاتے اور رسول تمہیں تمہارے رب پرایمان لانے کے لیے بلا رہا ہے اور تم سے عہد بھی لے چکا ہے اگر تم ایمان لانے والے ہو\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxiv{وہی ہے جو اپنے بندے پر کھلی کھلی آیتیں نازل کر رہا ہے تاکہ تمہیں اندھیروں میں سے نکال کر روشنی میں لائے اور بے شک الله تم پر بڑا مہربان نہایت رحم والا ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxv{اور تمہیں کیا ہوگیا جو الله کی راہ میں خرچ نہیں کرتے حالانکہ آسمانوں اور زمین کا ورثہ تو الله ہی کے لیے ہے تم میں سے اور کوئی اس کے برابر ہو نہیں سکتا جس نے فتح مکہ سے پہلے خرچ کیا اور جہاد کیا یہ ہیں کہ الله کے نزدیک جن کا بڑا درجہ ہے ان لوگو ں پر ہے جنہوں نے بعد میں خرچ کیا اور جہاد کیا اور الله نے ہر ایک سے نیک جزا کا وعدہ کیا ہے اور الله تمہارے کاموں سے خبردار ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxvi{ایسا کون ہے جو الله کو اچھا قرض دے پھر وہ اس کو ا سکے لیے دگنا کر دے اوراس کے لیے عمدہ بدلہ ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxvii{جس دن آپ ایماندار مردوں اور عورتوں کو دیکھیں گے کہ ان کا نور ان کے سامنے اور ان کے داہنے دوڑ رہا ہوگا تمہیں آج ایسے باغوں کی خوشخبری ہے کہ ان کے نیچے نہریں چلتی ہیں وہ ان میں ہمیشہ رہیں گے یہی وہ بڑی کامیابی ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxviii{جس دن منافق مرد اورمنافق عورتیں ان سے کہیں گے جو ایمان لائے ہیں کہ ہمارا انتظار کرو کہ ہم بھی تمہارے نور سے روشنی لے لیں کہا جائے گا اپنے پیچھے لوٹ جاؤ پھر روشنی تلاش کرو پس ان کے درمیان ایک دیوار کھڑی کر دی جائے گی جس میں ایک دروازہ ہو گا اس کے اندر تو رحمت ہو گی اور اس کے باہر کی طرف عذاب ہو گا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxix{وہ انہیں پکاریں گے کیا ہم تمہارے ساتھ نہ تھے وہ کہیں گے کیوں نہیں لیکن تم نے اپنے آپ کو فتنہ میں ڈالا اور راہ دیکھتے اور شک کرتے رہے اور تمہیں آرزوؤں نے دھوکہ دیا یہاں تک کہ الله کا حکم آ پہنچا اور تمہیں الله کے بارے میں شیطان نے دھوکہ دیا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmxc{پس آج نہ تم سے کوئی تاوان لیا جائے گا اور نہ ان سے جنہوں نے انکار کیا تھا تمہارا سب کا ٹھکانا دوزخ ہے وہی تمہارا رفیق ہے اوربہت ہی بری جگہ ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmxci{کیا ایمان والوں کے لیے اس بات کا وقت نہیں آیا کہ ان کے دل الله کی نصیحت اور جو دین حق نازل ہوا ہے اس کے سامنے جھک جائیں اور ان لوگوں کی طرح نہ ہوجائیں جنہیں ان سے پہلے کتاب (آسمانی) ملی تھی پھر ان پر مدت لمبی ہو گئی تو ان کے دل سخت ہو گئے اور ان میں سے بہت سے نافرمان ہیں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmxcii{اور جان لو کہ الله ہی زمین کو اس کے مرنے پیچھے زندہ کرتا ہے ہم نے تو تمہارے لیے کھول کھول کر نشانیاں بیان کر دی ہیں تاکہ تم سمجھو\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmxciii{بے شک خیرات کرنے والے مرد اور خیرات کرنے والی عورتیں اور جنہوں نے الله کو اچھا قرض دیا ان کے لیے دگنا کیا جائے گا اور انہیں عمدہ بدلہ ملے گا\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmxciv{اور جو لوگ الله اور اس کے رسولوں پر ایمان لائے وہی لوگ اپنے رب کے نزدیک صدیق اور شہید ہیں ان کے لیے ان کا اجر اور ان کی روشنی ملے گی اور جنہوں نے کفر کیا اورہماری آیتوں کو جھٹلایا یہی لوگ دوزخی ہیں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmxcv{جان لو کہ یہ دنیا کی زندگی محض کھیل اور تماشا اور زیبائش اور ایک دوسرے پر آپس میں فخر کرنا اور ایک دوسرے پر مال اور اولاد میں زیادتی چاہنا ہے جیسے بارش کی حالت کہ اس کی سبزی نے کسانوں کو خوش کر دیا پھر وہ خشک ہو جاتی ہے تو تو اسے زرد شدہ دیکھتا ہے پھر وہ چورا چورا ہو جاتی ہے اور آخرت میں سخت عذاب ہے اور الله کی مغفرت اور اس کی خوشنودی ہے اور دنیاکی زندگی سوائے دھوکے کے اسباب کے اور کیا ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmxcvi{اپنے رب کی مغفرت کی طرف دوڑو اور جنت کی طرف جس کا عرض آسمان اور زمین کے عرض کے برابر ہے ان کے لیے تیار کی گئی ہے جو الله اور اس کے رسولوں پر ایمان لائے یہ الله کا فضل ہے وہ جسے چاہتا ہے دیتا ہے اور الله بڑے فضل والا ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmxcvii{جو کوئی مصیبت زمین پر یاخودتم پر پڑتی ہے وہ اس سے پیشتر کہ ہم اسے پیدا کریں کتاب میں لکھی ہوتی ہے بے شک یہ الله کے نزدیک آسان بات ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmxcviii{تاکہ جو چیز تمہارے ہاتھ سے جاتی رہے اس پر رنج نہ کرو اور جو تمہیں دے اس پر اتراؤ نہیں اور الله کسی اترانے والے شیخی خورے کو پسند نہیں کرتا\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmxcix{جو خود بھی بخل کرتے ہیں اور لوگوں کو بھی بخل کا حکم دیتے ہیں اور جو کوئی منہ موڑے تو الله بھی بے پرواہ خوبیوں والا ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmc{البتہ ہم نے اپنے رسولوں کو نشانیاں دے کر بھیجا اور ان کے ہمراہ ہم نے کتاب اور ترازوئے (عدل) بھی بھیجی تاکہ لوگ انصاف کو قائم رکھیں اور ہم نے لوہا بھی اتارا جس میں سخت جنگ کے سامان اورلوگوں کے فائدے بھی ہیں اور تاکہ الله معلوم کرے کہ کون اس کی اور اس کے رسولوں کی غائبانہ مدد کرتا ہے بے شک الله بڑا زور آور غالب ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmci{اور ہم نے نوح اور ابراھیم کو بھیجا تھا اور ہم نے ان دونوں کیاولاد میں نبوت اور کتاب رکھی تھی پس بعض تو ان میں راہِ راست پر رہے اور بہت سے ان میں سے نافرمان ہیں\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmcii{پھر اس کے بعد ہم نے اپنے اور رسول بھیجے اور عیسیٰ ابن مریم کو بعد میں بھیجا اور اسے ہم نے انجیل دی اور اس کے ماننے والوں کے دلوں میں ہم نے نرمی اور مہربانی رکھ دی اور ترک دنیا جو انہوں نے خود ایجاد کی ہم نے وہ ان پرفرض نہیں کی تھی مگر انہوں نے رضائے الہیٰ حاصل کرنے کے لیے ایسا کیا پس اسے نباہ نہ سکے جیسے نباہنا چاہیئے تھا تو ہم نے انہیں جو ان میں سے ایمان لائے ان کا اجر دے دیا اور بہت سے تو ان میں بدکار ہی ہیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmciii{اے ایمان والو الله سے ڈرو اور اس کے رسول پر ایمان لاؤ وہ تمہیں اپنی رحمت سے دوہرا حصہ دے گا اور تمہیں ایسا نورعطا کرے گا تم اس کے ذریعہ سے چلو اور تمہیں معاف کر دے گا اور الله بخشنے والا نہایت رحم ولا ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmciv{تاکہ اہلِ کتاب یہ نہ سمجھیں کہ (مسلمان) الله کے فضل میں سے کچھ بھی حاصل نہیں کر سکتے اوریہ کہ فضل تو الله ہی کے ہاتھ میں ہے جس کو چاہے دے اور الله بڑا فضل کرنے والا ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmcv{\basmalahur بے شک الله نے اس عورت کی بات سن لی ہے جو آپ سے اپنے خاوند کے بارے میں جھگڑتی تھی اور الله کی جناب میں شکایت کرتی تھی اور الله تم دونوں کی گفتگو سن رہا تھا بے شک الله سب کچھ سننے والا دیکھنے والا ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcvi{جو لوگ تم میں سے اپنی عورتوں سے ظہار کرتے ہیں وہ ان کی مائیں نہیں ہو جاتیں ان کی مائیں تو وہی ہیں جنہوں نے انہیں جنا ہے اور بےشک انہوں نے ایک بیہودہ اور جھوٹی بات منہ سے نکالی ہے اور بے شک الله معاف کرنے والا بخشنے والا ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcvii{اور جو لوگ اپنی بیویوں سے اظہار کرتے ہیں پھر اس کہی ہوئی بات سے پھرنا چاہیں تو ایک غلام ایک دوسرے کو ہاتھ لگانے سے پہلے آزاد کر دیں یہ اس کے لیے اس سے تمہیں نصیحت ہو اور الله جو کچھ تم کرتے ہو اس کی خبر رکھتا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcviii{پس جو شخص نہ پائے تو دو مہینے کے لگاتار روزے رکھے اس سے پہلےکہ ایک دوسرے کو چھوئیں پس جو کوئی ایسا نہ کر سکے تو ساٹھ مسکینوں کو کھانا کھلائے یہ ا س لیے کہ تم الله اور اس کے رسول پر ایمان لاؤ اور یہ الله کی حدیں ہیں اورمنکروں کے لیے دردناک عذاب ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcix{بے شک جو لوگ الله اور اس کے رسول کی مخالفت کرتے ہیں وہ ذلیل کیے جائیں گے جس طرح ذلیل کیے گئے وہ لوگ جو ان سے پہلے تھے اور ہم نے تو صاف صاف آیتیں نازل کر دی ہیں اور منکروں کے لیے ذلت کا عذاب ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcx{جس دن ان سب کو الله قبروں سے اٹھائے گا پھر ان کو بتائے گا کہ وہ کیا کرتے تھے جس کو الله نے یاد رکھا ہے اور وہ بھول گئے ہیں اور الله کے سامنے ہر چیز موجود ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxi{کیا آپ نے نہیں دیکھا الله جانتا ہے جو کچھ آسمانوں اور زمین میں ہے (یہاں تک) کہ جو کوئی مشورہ تین آدمیوں میں ہوتا ہے تو وہ چوتھا ہوتا ہے اور جو پانچ میں ہوتا ہے تو وہ چھٹا ہوتا ہے اور خواہ اس سے کم کی سرگوشی ہو یا زیادہ کی مگر وہ ہر جگہ ان کے ساتھ ہوتا ہے پھر انہیں قیامت کے دن بتائے گا کہ وہ کیا کرتے تھے بے شک الله ہر چیز کو جاننے والا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxii{کیا آپ نے ان کو نہیں دیکھا جو سرگوشی کرنے سے روکے گئے تھے پھر وہ اسی بات کی طرف لوٹتے ہیں جس سے انہیں روکا گیا تھا اور گناہ اور سرکشی اور رسول کی نافرمانی کی سرگوشی کرتے ہیں اور جب وہ آپ کے پاس آتے ہیں تو آپ کو ایسے لفظوں سے سلام کرتے ہیں جن سے الله نے آپ کو سلام نہیں دیا اور اپنے دلوں میں کہتے ہیں کہ ہمیں الله اس پر کیوں عذاب نہیں دیتا جو ہم کہہ رہے ہیں ان کے لیے دوزخ کافی ہے وہ اس میں داخل ہوں گے پس وہ کیا ہی برا ٹھکانہ ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxiii{اے ایمان والو جب تم آپس میں سرگوشی کرو تو گناہ اور سرکشی اور رسول کی نافرمانی کی سرگوشی نہ کرو اورنیکی اور پرہیز گاری کی سرگوشی کرو اور الله سے ڈرو جس کی طرف تم جمع کیے جاؤ گے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxiv{(یہ) سرگوشی تو صرف شیطانی بات ہے تاکہ ایمان داروں کو غمناک کر دے حالانکہ بغیر حکم الله کے کچھ بھی ضرر نہیں دے سکتی اور ایمان والے تو الله ہی پربھروسہ رکھتے ہیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxv{اے ایمان والو جب تمہیں مجلسوں میں کھل کر بیٹھنے کو کہا جائے تو کھل کر بیٹھو الله تمیں فراخی دے گا اور جب کہا جائے کہ اٹھ جاؤ تو اٹھ جاؤ تم میں سے الله ایمان داروں کے اور ان کے جنہیں علم دیا گیا ہے درجے بلند کرے گا اور جو کچھ تم کرتے ہواللہ اس سے خبردار ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxvi{اے ایمان والو جب تم رسول سے سرگوشی کرو تو اپنی سرگوشی سے پہلے صدقہ دے لیا کرو یہ تمہارے لیے بہتر اور زیادہ پاکیزہ بات ہے پس اگر نہ پاؤ تو الله بخشنے والا نہایت رحم والا ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxvii{کیا تم اپنی سرگوشی سے پہلے صدقہ دینے سے ڈر گئے پھر جب تم نے نہ کیا اور الله نے تمہیں معاف بھی کردیا تو (بس) نماز ادا کرو اور زکواة دو اور الله اور اس کے رسول کی اطاعت کرو اور جو کچھ تم کرتے ہو الله اس سے خبردار ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxviii{کیا آپ نے ان کو نہیں دیکھا جنہوں نے اس قوم سے دوستی رکھی ہے جن پر الله کا غضب ہے نہ وہ تم میں سے ہیں اور نہ ان میں سے اوروہ جان بوجھ کر جھوٹ پر قسمیں کھاتے ہیں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxix{الله نے ان کے لیے سخت عذاب تیار کر رکھا ہے بے شک وہ بہت ہی برا ہے جو کچھ وہ کرتے ہیں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxx{انہوں نے اپنی قسموں کو ڈھال بنا لیا ہے پس وہ (لوگوں کو) الله کی راہ سے روکتے ہیں تو ان کے لیے ذلیل کرنے والاعذآب ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxi{الله کے مقابلہ میں نہ تو ان کے مال ہی کچھ کام آئیں گے اور نہ ان کی اولاد کچھ کام آئے گی یہ دوزخی لوگ ہیں وہ اس میں ہمیشہ رہنے والے ہیں\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxii{جس دن الله ان سب کو قبروں سے اٹھائے گا تو اس کے سامنے بھی ایسی ہی قسمیں کھائیں گے جیسی کہ تمہارے سامنے کھاتے ہیں اور سمھجھ رہے ہیں کہ ہم رستے پر ہیں خبردار بے شک وہی جھوٹے ہیں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxiii{ان پر شیطان نے غلبہ پا لیا ہے پس اس نے انہیں الله کا ذکر بھلا دیا ہے یہی شیطان کا گروہ ہے خبردار بے شک شیطان کا گروہ ہی نقصان اٹھانے والا ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxiv{بے شک جو لوگ الله اورا سکے رسول کی مخالفت کرتے ہیں یہی لوگ ذلیلوں میں ہیں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxv{الله نے لکھ دیا ہے کہ میں اور میرے رسول ہی غالب رہیں گے بے شک الله زور آور زبردست ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxvi{آپ ایسی کوئی قوم نہ پائیں گے جو الله اور قیامت کے دن پر ایمان رکھتی ہو اور ان لوگو ں سے بھی دوستی رکھتے ہوں جو الله اور اس کے رسول کی مخالفت کرتے ہیں گو وہ ان کے باپ یا بیٹے یا بھائی یا کنبے کے لوگ ہی کیوں نہ ہوں یہی وہ لوگ ہیں جن کے دلوں میں اللہ نے ایمان لکھ دیا ہے اور ان کو اپنے فیض سے قوت دی ہے اور وہ انہیں بہشتوں میں داخل کرے گا جن کے نیچے نہریں بہہ رہی ہوں گی وہ ان میں ہمیشہ رہیں گے الله ان سے راضی ہوا اور وہ اس سے راضی ہوئے یہی الله کا گروہ ہے خبردار بے شک الله کا گروہ ہی کامیاب ہونے والا ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxvii{\basmalahur جو مخلوقات آسمانوں میں ہے اور جو زمین میں ہے الله کی تسبیح کرتی ہے اور وہی غالب حکمت والا ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxviii{وہی ہے جس نے اہلِ کتاب کے کافروں کو ان کے گھروں سے پہلا لشکر جمع کرنے کے وقت نکال دیا حالانکہ تمہیں ان کے نکلنے کا گمان بھی نہ تھا اور وہ یہی سمجھ رہے تھے کہ ان کے قلعے انہیں الله سے بچا لیں گے پھر الله کا عذاب ان پر وہاں سے آیا کہ جہاں کا ان کو گمان بھی نہ تھا اوران کے دلوں میں ہیبت ڈال دی کہ اپنے گھر وں کو اپنے اورمسلمانوں کے ہاتھوں سے آپ اجاڑنے لگے پس اے آنکھوں والو عبرت حاصل کرو\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxix{اوراگر الله نے ان کے لیے دیس نکالا نہ لکھ دیا ہوتا تو انہیں دنیا ہی میں سزا دیتا اور آخرت میں تو ان کے لیے آگ کا عذاب ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxx{یہ ا سلیے کہ انہوں نے الله اوراس کے رسول کی مخالفت کی اور جو الله کی مخالفت کرے تو بے شک الله سخت عذاب دینے والا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxi{مسلمانوں تم نے جو کھجور کا پیڑ کاٹ ڈالا یا اس کو اس کی جڑوں پر کھڑا رہنے دیا یہ سب الله کے حکم سے ہوا اور تاکہ وہ نافرمانوں کو ذلیل کرے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxii{اور جوکچھ الله نے اپنے رسول کو ان سے مفت دلا دیا سو تم نے اس پر گھوڑے نہیں دوڑائے اور نہ اونٹ لیکن الله اپنے رسولوں کو غالب کر دیتا ہے جس پر چاہے اور الله ہر چیز پر قادر ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxiii{جو مال الله نے اپنےرسول کو دیہات والوں سے مفت دلایا سو وہ الله اور رسول اور قرابت والوں اور یتمیموں اور مسکینوں اور مسافروں کے لیے ہے تاکہ وہ تمہارے دولتمندوں میں نہ پھرتا رہے اور جو کچھ تمہیں رسول دے اسے لے لو اور جس سے منع کرے اس سے باز رہو اور الله سے ڈرو بیشک الله سخت عذاب دینے والا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxiv{وہ مال وطن چھوڑنے والے مفلسوں کے لیے بھی ہے جو اپنے گھروں اور مالوں سے نکالے گئے الله کا فضل اس کی رضا مندی چاہتے ہیں اوروہ الله اور اس کے رسول کی مدد کرتے ہیں یہی سچے (مسلمان) ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxv{اور وہ (مال) ان کے لیے بھی ہے کہ جنہوں نے ان سے پہلے (مدینہ میں) گھر اور ایمان حاصل کر رکھا ہے جو ان کے پاس وطن چھوڑ کرآتا ہے اس سے محبت کرتے ہیں اور اپنے سینوں میں اس کی نسبت کوئی خلش نہیں پاتے جو مہاجرین کو دیا جائے اور وہ اپنی جانوں پر ترجیح دیتے ہیں اگرچہ ان پر فاقہ ہو اور جو اپنے نفس کے لالچ سے بچایا جائے پس وہی لوگ کامیاب ہیں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxvi{اور ان کے لیے بھی جو مہاجرین کے بعد آئے (اور) دعا مانگا کرتے ہیں کہ اے ہمارے رب ہمیں اور ہمارےان بھائیوں کو بخش دے جو ہم سے پہلے ایمان لائے ہیں اور ہمارے دلوں میں ایمانداروں کی طرف سے کینہ قائم نہ ہونے پائے اے ہمارے رب بے شک تو بڑا مہربان نہایت رحم والا ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxvii{کیا آپ نے منافقوں کو نہیں دیکھا جواپنے اہل کتاب کے کافر بھائیوں سے کہتے ہیں کہ اگر تم نکالے گئے تو ضرور ہم بھی تمہارے ساتھ نکلیں گے اور تمہارے معاملہ میں کبھی کسی کی بات نہ مانیں گے اور اگر تم سے لڑائی ہو گی تو ہم تمہاری مدد کریں گے اور الله گواہی دیتا ہے کہ وہ سراسر جھوٹے ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxviii{اگر وہ نکالے گئے تو یہ ان کے ساتھ نہ نکلیں گے اور اگر ان سے لڑائی ہوئی تو یہ ان کی مدد بھی نہ کریں گے اور اگر ان کی مدد کریں گے تو پیٹھ پھیر کر بھاگیں گے پھر ان کو مدد نہ دی جائے گی\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxix{البتہ تمہارا خوف ان کے دلوں میں الله (کے خوف) سے زیادہ ہے یہ اس لیے کہ وہ لوگ سمجھتے نہیں\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxl{وہ تم سے سب ملکر بھی نہیں لڑ سکتے مگر محفوظ بستیوں میں یا دیواروں کی آڑ میں ان کی لڑائی تو آپس میں سخت ہے آپ ان کو متفق سمجھتے ہیں حالانکہ ان کے دل الگ الگ ہیں یہ اس لیے کہ وہ لوگ عقل نہیں رکھتے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxli{ان کا حال تو پہلوں جیسا ہے کہ جنہوں نے ابھی اپنے کام کی سزا پائی ہے اور ان کے لیے (آخرت میں) دردناک عذاب ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxlii{(اور) مشال شیطان کی سی ہے کہ وہ آدمی سے کہتا ہے کہ تو منکر ہو جا پھر جب وہ منکر ہو جاتا ہے تو کہتا ہے بے شک میں تم سے بری ہوں کیوں کہ میں الله سے ڈرتا ہوں جو سارے جہاں کا رب ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxliii{پس ان دونوں کا انجام یہ ہوتا ہے کہ وہ دونوں دوزخ میں ہوں گے اس میں ہمیشہ رہیں گے اور ظالموں کی یہی سزا ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxliv{اے ایمان والو الله سے ڈرو اور ہر شخص کو دیکھنا چاہیئے کہ اس نے کل کے لئے کیا آگے بھیجا ہے اور الله سے ڈرو کیوں کہ الله تمہارے کاموں سے خبردار ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxlv{اور ان کی طرح نہ ہوں جنہوں نے الله کو بھلا دیاپھر الله نے بھی ان کو (ایسا کر دیا) کہ وہ اپنے آپ ہی کو بھول گئے یہی لوگ نافرمان ہیں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxlvi{دوزخی اور جنتی برابر نہیں ہو سکتے جنتّی ہی بامراد ہیں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxlvii{اگر ہم اس قرآن کو کسی پہاڑ پرنازل کرتے تو آپ اسے دیکھتے کہ الله کے خوف سے جھک کر پھٹ جاتا اور ہم یہ مثالیں لوگوں کے لیے بیان کرتے ہیں تاکہ وہ غور کریں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxlviii{وہی الله ہے کہ اس کے سوا کوئی معبود نہیں سب چھپی اور کھلی باتوں کا جاننے والا ہے وہ بڑا مہربان نہایت رحم والا ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxlix{وہی الله ہے کہ اس کے سوا کوئی معبود نہیں وہ بادشاہ پاک ذات سلامتی دینے والا امن دینے والا نگہبان زبردست خرابی کا درست کرنے والا بڑی عظمت والا ہے الله پاک ہے اس سے جو اس کے شریک ٹھیراتے ہیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmcl{وہی الله ہے پیدا کرنے والا ٹھیک ٹھیک بنانے والا صورت دینے والا اس کے اچھے اچھے نام ہیں سب چیزیں اسی کی تسبیح کرتی ہیں جو آسمانوں میں اور زمین میں ہیں اور وہی زبردست حکمت والا ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmcli{\basmalahur اے ایمان والو میرے دشمنوں اور اپنے دشمنوں کو دوست نہ بناؤ کہ ان کے پاس دوستی کے پیغام بھیجتے ہو حالانکہ تمہارے پاس جو سچا دین آیا ہے اس کے یہ منکر ہو چکے ہیں رسول کو اور تمہیں ا س بات پر نکالتے ہیں کہ تم الله اپنے رب پر ایمان لائے ہو اگر تم جہاد کے لیے میری راہ میں اور میری رضا جوئی کے لیے نکلے ہوتو ان کو دوست نہ بناؤ تم ان کے پاس پوشیدہ دوستی کے پیغام بھیجتے ہو حالانکہ میں خوب جانتا ہوں جو کچھ تم مخفی اور ظاہر کرتے ہو اور جس نے تم میں سے یہ کام کیا تو وہ سیدھے راستہ سے بہک گیا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmclii{اگر وہ تم پر قابو پائیں تو تمہارے دشمن ہو جائیں اور تم پر اپنے ہاتھ اور اپنی زبانیں برائی سے دراز کریں اور چاہتے ہیں کہ کہیں تم کافر ہو جاؤ\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcliii{نہ تمہیں تمہارے رشتے ناطے اور نہ تمہاری اولاد قیامت کے دن نفع دیں گے وہ تمہارے درمیان فیصلہ کرے گا اور جو تم کرتے ہو الله اسے خوب دیکھتا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcliv{بے شک تمہارے لیے ابراہیم میں اچھا نمونہ ہے اوران لوگوں میں جو اس کے ہمراہ تھے جب کہ انہوں نے اپنی قوم سے کہا تھا بے شک ہم تم سے بیزار ہیں اور ان سے جنہیں تم الله کے سوا پوجتے ہو ہم نے تمہارا انکار کر دیا اور ہمارے او رتمہارے درمیان دشمنی اور بیَر ہمیشہ کے لیے ظاہر ہو گیا یہاں تک کہ تم ایک الله پر ایمان لاؤ مگر ابراھیم کا اپنے باپ سے کہنا کہ میں تمہارے لیے معافی مانگوں گا اور میں الله کی طرف سے تمہارے لیے کسی بات کا مالک بھی نہیں ہوں اے ہمارے رب ہم نے تجھ ہی پر بھروسہ کیا اور تیری ہی طرف ہم رجوع ہوئے اور تیری ہی طرف لوٹنا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmclv{اے ہمارے رب ہمیں ان کا تختہ مشق نہ بنا جو کافر ہیں اور اے ہمارے رب ہمیں معاف کر بے شک تو ہی غالب حکمت والا ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmclvi{البتہ تمہارے لیے ان میں ایک نیک نمونہ ہے اس کے لیے جو الله اور قیامت کے دن کی امید رکھتا ہو اور جو کوئی منہ موڑے تو بے شک الله بھی بے پرواہ خوبیوں والا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmclvii{شاید کہ الله تم میں اور ان میں کہ جن سے تمہیں دشمنی ہے دوستی قائم کر دے اور الله قادر ہے اور الله بخشنے والا نہایت رحم والا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmclviii{الله تمہیں ان لوگو ں سے منع نہیں کرتا جو تم سے دین کے بارے میں نہیں لڑتے اورنہ انہوں نے تمہیں تمہارے گھروں سے نکالا ہے اس بات سے کہ تم ان سے بھلائی کرو اور ان کے حق میں انصاف کرو بیشک الله انصاف کرنے والوں کو پسند کرتا ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmclix{تمہیں الله انہیں سے منع کرتا ہے کہ جو دین میں تم سے لڑے اورانہوں نے تمہیں تمہارے گھروں سے نکال دیا اور تمہارے نکالنے پر (لوگوں کی) مدد بھی کی کہ ان سے دوستی کرو اورجس نے ان سے دوستی کی تو پھر وہی ظالم بھی ہیں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmclx{اے ایمان والو جب تمہارے پاس مومن عورتیں ہجرت کر کے آئيں تو ان کی جانچ کر لو الله ہی ان کے ایمان کو خوب جانتا ہے پس اگر تم انہیں مومن معلوم کر لو تو انہیں کفار کی طرف نہ لوٹاؤ نہ وہ (عورتیں) ان کے لیے حلال ہیں اور نہ وہ (کافر) ان کے لیے حلال ہیں اور ان کفار کو دے دو جو کچھ انہوں نے خرچ کیا اور تم پر گناہ نہیں کہ تم ان سے نکاح کر لو جب تم انہیں ان کے مہر دے دو اور کافر عورتوں کے ناموس کو قبضہ میں نہ رکھو اور جو تم نےان عورتوں پر خرچ کیا تھا مانگ لو اور جو انہوں نے خرچ کیا کہ وہ مانگ لیں الله کا یہی حکم ہے جو تمہارے لیے صاد رفرمایا اور الله سب کچھ جاننے والا حکمت والا ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxi{اور اگرکوئی عورت تمہاری عورتوں میں سے کفار کے پاس نکل گئی ہے پھر تمہاری باری آجائے تو ان مسلمانو ں کو دے دو جن کی بیویاں چلی گئی ہیں جتنا کہ انہوں نے دیا تھا اوراس الله سے ڈرو کہ جس پر تم ایمان لائے ہو\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxii{اے نبی جب آپ کے پاس ایمان والی عورتیں اس بات پر بیعت کرنے کو آئیں کہ الله کے ساتھ کسی کو شریک نہ کرینگی اور نہ چوری کریں گی اور نہ زنا کریں گی اور نہ اپنی اولاد کو قتل کریں گی اور نہ بہتان کی اولاد لائیں گی جسے اپنے ہاتھوں اور پاؤں کے درمیان (نطفہٴ شوہر سے جنی ہوئی) بنا لیں اور نہ کسی نیک بات میں آپ کی نافرمانی کریں گی تو ان کی بیعت قبول کر اور ان کے لیے الله سے بخشش مانگ بے شک الله بخشنے والا نہایت رحم والا ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxiii{اے ایمان والو اس قوم سے دوستی نہ کرو جن پر الله کا غضب ہوا وہ تو آخرت سے ایسے نا امید ہو گئے کہ جیسے کافر اہلِ قبور سے نا امید ہو گئے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxiv{\basmalahur جو مخلوقات آسمانو ں میں اور جو زمین میں ہے الله کی تسبیح کرتی ہے اور وہی غالب حکمت والا ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxv{اے ایمان والو کیو ں کہتے ہو جو تم کرتے نہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxvi{الله کے نزدیک بڑی ناپسند بات ہے جو کہو اس کو کرو نہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxvii{بے شک الله تو ان کو پسند کرتا ہے جو اس کی راہ میں صف باندھ کر لڑتے ہیں گویا وہ سیسہ پلائی ہوئی دیوار ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxviii{اور جب موسیٰ نے اپنی قوم سے کہا کہ اے میری قوم مجھےکیوں ستاتے ہو حالانکہ تم جانتے ہو کہ میں تمہاری طرف الله کا رسول ہوں پس جب وہ پھر گئے تو الله نے ان کے دل پھیر دیئے اور الله نافرمان لوگو ں کو ہدایت نہیں کرتا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxix{اور جب عیسیٰ بن مریم نے کہا اے بنی اسرائیل بے شک میں الله کا تمہاری طرف سے رسول ہوں تورات جو مجھ سے پہلے ہے اس کی تصدیق کرنے والا ہوں اور ایک رسول کی خوشخبری دینے والا ہوں جو میرے بعد آئے گا اس کا نام احمد ہو گا پس جب وہ واضح دلیلیں لے کر ان کے پاس آ گیا تو کہنے لگے یہ تو صریح جادو ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxx{اور اس سے زیادہ کون ظالم ہے جو الله پر جھوٹ باندھے حالانکہ اسلام کی طرف اسے بلایا جارہا ہو اور ظالم لوگوں کو ہدایت نہیں کرتا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxi{وہ چاہتے ہیں کہ الله کا نور اپنے مونہوں سے بجھا دیں اور الله اپنا نور پورا کر کے رہے گا اگرچہ کافر برا مانیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxii{وہی تو ہے جس نے اپنا رسول ہدایت اور سچا دین دے کر بھیجا تاکہ اس کو سب دینوں پر غالب کرے اگرچہ مشرک نا پسند کریں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxiii{اے ایمان والو کیا میں تمہیں ایسی تجارت بتاؤں جو تمہیں دردناک عذاب سے نجات دے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxiv{تم الله اور اس کے رسول پر ایمان لاؤ اور تم الله کی راہ میں اپنے مالوں اور اپنی جانوں سے جہاد کرو یہی تمہارے لیے بہتر ہے اگر تم جانتے ہو\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxv{وہ تمہارے لیے تمہارے گناہ بخش دے گا اور تمہیں بہشتوں میں داخل کر ے گا جن کے نیچے نہریں بہہ رہی ہوں گی اور پاکیزہ مکانوں میں ہمیشہ رہنے کے باغو ں میں یہ بڑی کامیابی ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxvi{اور دوسری بات جو تم پسند کرتے ہو الله کی طرف سے مدد ہے اور جلدی فتح اور ایمان والوں کو خوشخبری دے دے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxvii{ایمان والو الله کے مددگار ہو جاؤ جیسا کہ ابن مریم نے حواریوں سے کہا تھا کہ الله کی راہ میں میرا مددگار کون ہے حواریو ں نے کہا ہم الله کے مددگار ہیں پھر ایک گروہ بنی اسرائیل کا ایمان لایا اور ایک گروہ کافر ہو گیا پھر ہم نے ایمان داروں کو ان کے دشمنوں پر غالب کر دیا پھر تو وہی غالب ہو کر رہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxviii{\basmalahur جو مخلوقات آسمانوں اور زمین میں ہے الله کی تسبیح کرتی ہے وہ بادشاہ پاک ذات غالب حکمت والا ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxix{وہی ہے جس نے ان پڑھوں میں ایک رسول انہیں میں سے مبعوث فرمایا جو ان پر اس کی آیتیں پڑھتا ہے اور انہیں پاک کرتا ہے اور انہیں کتاب اور حکمت سکھاتا ہے اور بے شک وہ اس سے پہلے صریح گمراہی میں تھے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxx{اور دوسروں کے لیے بھی جو ابھی ان سے نہیں ملے اور وہ زبردست حکمت والا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxi{یہ الله کا فضل ہے جسے چاہے دے اور الله بڑا فضل کرنے والا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxii{ان لوگو ں کی مثال جنہیں تورات اٹھوائی گئی پھر انہوں نے اسے نہ اٹھایا گدھے کی سی مثال ہے جو کتابیں اٹھاتا ہے ان لوگوں کی بہت بری مثال ہے جنہوں نے الله کی آیتو ں کو جھٹلایا اور الله ظالم لوگوں کو ہدایت نہیں کرتا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxiii{کہہ دو اے لوگو جو یہودی ہو اگر تم خیال کرتے ہو کہ تم ہی الله کے دوست ہو سوائے دوسرے لوگوں کے تو موت کی آرزو کرو اگر تم سچے ہو\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxiv{اور وہ لوگ اس کی کبھی بھی تمنا نہ کریں گے بسبب ان (عملوں) کے جو ان کے ہاتھوں نے آگے بھیجے اور الله ظالموں کو خوب جانتا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxv{کہہ دو بے شک وہ موت جس سے تم بھاگتے ہو سو وہ تو ضرور تمہیں ملنے والی ہے پھر تم اس کی طرف لوٹائے جاؤ گے جو ہر چھپی اور کھلی بات کا جاننے والا ہے پھر وہ تمہیں بتائے گا جو کچھ تم کیا کرتے تھے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxvi{اے ایمان والو جب جمعہ کے دن نماز کے لیے اذان دی جائے تو ذکر الہیٰ کی طرف لپکو اور خرید و فروخت چھوڑ دو تمہارے لیے یہی بات بہتر ہے اگر تم علم رکھتے ہو\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxvii{پس جب نماز ادا ہو چکے تو زمین میں چلو پھرو اور الله کا فضل تلاش کرو اور الله کو بہت یاد کرو تاکہ تم فلاح پاؤ\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxviii{اور جب وہ لوگ تجارت یاتماشہ دیکھتے ہیں تو اس پر ٹوٹ پڑتے ہیں اور آپ کو کھڑا ہوا چھوڑ جاتے ہیں کہہ دو جو الله کے پاس ہے وہ تماشا اور تجارت سے کہیں بہتر ہے اور الله بہتر روزی دینے والا ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxix{\basmalahur جب آپ کے پاس منافق آتے ہیں تو کہتے ہیں ہم گواہی دیتے ہیں کہ بے شک آپ الله کے رسول ہیں اور الله جانتا ہے کہ بے شک آپ اس کے رسول ہیں اور الله گواہی دیتا ہے کہ بے شک منافق جھوٹے ہیں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxc{انہوں نے اپنی قسموں کو ڈھال بنا کر رکھا ہے پھر (لوگوں کو) الله کی راہ سے روکتے ہیں بے شک کیسا برا کام ہے جو وہ کر رہے ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxci{یہ اس لیے کہ وہ ایمان لائے پھر منکر ہو گئے پس ان کے دلوں پر مہر کر دی گئی ہے پس وہ نہیں سمجھتے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxcii{اور جب آپ ان کو دیکھیں تو اپ کو ان کے ڈیل ڈول اچھے لگیں اور اگر وہ بات کریں تو آپ انکی بات سن لیں گویا کہ وہ دیوار سے لگی ہوئی لکڑیاں ہیں وہ ہر آواز کو اپنے ہی اُوپر خیال کرتے ہیں وہی دشمن ہیں پس ان سے ہوشیار رہيے الله انہیں غارت کرے کہاں وہ بہکے جا رہے ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxciii{اور جب ان سے کہا جائے کہ آؤ تمہارے لیے رسول الله مغفرت طلب کریں تو اپنے سر پھیر لیتے ہیں اور آپ انہیں دیکھیں گے کہ وہ رکتے ہیں ایسے حال میں کہ وہ تکبر کرنے والے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxciv{برابر ہے خواہ وہ آپ ان کے لیے معافی مانگیں یا نہ مانگیں اللهانہیں ہر گز نہیں بخشے گا بے شک الله بدکار قوم کو ہدایت نہیں کرتا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxcv{وہی لوگ ہیں جوکہتے ہیں کہ ان پر خرچ نہ کرو جو رسول الله کے پاس ہیں یہاں تک کہ وہ تتر بتر ہو جائیں اور آسمانوں اور زمین کے خزانے الله ہی کے لیے ہیں لیکن منافق نہیں سمجھتے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxcvi{وہ کہتے ہیں کہ اگر ہم مدینہ کی طرف لوٹ کر گئے تو اس میں سے عزت والا ذلیل کو ضرور نکال دے گا اور عزت تو الله اوراس کے رسول اور مومنین ہی کے لیے ہے لیکن منافق نہیں جانتے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxcvii{اے ایمان والو تمہیں تمہارے مال اور تمہاری اولاد الله کے ذکر سے غافل نہ کر دیں اور جو کوئی ایسا کرے گا سووہی نقصان اٹھانے والے ہیں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxcviii{اوراس میں سے خرچ کرو جو ہم نے تمہیں روزی دی ہے اس سے پہلے کہ کسی کو تم میں سے موت آجائے تو کہے اے میرے رب تو نے مجھے تھوڑی مدت کے لیے ڈھیل کیوں نہ دی کہ میں خیرات کرتا اور نیک لوگو ں میں ہو جاتا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxcix{اور الله کسی نفس کو ہرگز مہلت نہیں دے گا جب اس کی اجل آجائے گی اور الله اس سے خبردار ہے جو تم کرتے ہو\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcc{\basmalahur جو مخلوقات آسمانوں میں اور جو زمین میں ہے الله کی تسبیح کرتی ہے اسی کی حکومت ہے اور اس کی تعریف ہے اوروہ ہر چیز پر قادر ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcci{اسی نے تو تمہیں پیدا کیا ہے پھر کوئی تم میں سے کافر ہے اور کوئی مومن اورجو کچھ تم کر رہے ہو الله دیکھ رہا ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmccii{اسی نے آسمانوں اور زمین کو ٹھیک طور پر بنایا ہے اور تمہاری صورت بنائی پھر تمہاری صورتیں اچھی بنائیں اور اسی کی طرف لوٹ کر جانا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcciii{وہ جانتا ہے جو کچھ آسمانوں اور زمین میں ہے اور وہ جانتاہے جو تم چھپاتے ہو اور جو تم ظاہر کرتے ہو اور الله ہی سینوں کے بھید جانتا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcciv{کیا تمہارے ہاں ان کی خبر نہیں پہنچی جو اس ے پہلے منکر ہوئے پس انہوں نے اپنے کام کا وبال چکھا اوران کے لیے دردناک عذاب ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmccv{یہ اس لیے کہ ان کے پاس ان کے رسول واضح دلیلیں لے کر آتے تھے تووہ کہا کرتے تھے کہ کیا آدمی ہم کو راہ دکھائیں گے پس انہوں نے انکار کیا اورمنہ موڑ لیا اور الله نے پروا نہ کی اور الله بے نیاز تعریف کیا ہوا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmccvi{کافروں نے سمجھ لیا کہ قبروں سے اٹھائے نہ جائیں گے کہہ دوکیوں نہیں مجھے اپنے رب کی قسم ہے ضرور اٹھائے جاؤ گے پھر تمہیں بتلایا جائے گا جو کچھ تم نے کیا تھا اور یہ بات الله پر آسان ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmccvii{پس الله اوراس کے رسول پر ایمان لاؤ اور اس نور پر جو ہم نے نازل کیا ہے اور الله اس سے جو تم کرتے ہو خبردار ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmccviii{جس دن تمہیں جمع ہونے کے دن جمع کرے گا وہ دن ہار جیت کا ہے اور جو کوئی الله پر ایمان لائے اور نیک عمل کرے الله اس سے اس کی برائیاں دور کر دے گا اور اسے بہشتوں میں داخل کرے گا جن کے نیچے نہریں بہہ رہی ہوں گی ان میں ہمیشہ رہیں گے یہی بڑی کامیابی ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmccix{اورجنہوں نے انکار کیا اور ہماری آیتوں کو جھٹلایا یہی لوگ دوزخی ہیں اس میں ہمیشہ رہیں گے اوروہ بری جگہ ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmccx{الله کے حکم کے بغیر کوئی مصیبت بھی نہیں آتی اور جو الله پر ایمان رکھتا ہے وہ اس کے دل کو ہدایت دیتا ہے اور الله ہر چیز جاننے والا ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxi{اور الله اور اس کے رسول کی فرمانبرداری کرو پھر اگر تم نے منہ موڑ لیا تو ہمارے رسول پر بھی صرف کھول کر ہی پہنچا دینا ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxii{الله ہی ہے اس کے سوا کوئی معبود نہیں اور الله ہی پر ایمانداروں کو بھروسہ رکھنا چاہیئے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxiii{اے ایمان والو بے شک تمہاری بیویوں اور اولاد میں سے بعض تمہارے دشمن بھی ہیں سو ان سے بچتے رہو اور اگرتم معاف کرو اور درگزر کرو ارو بخش دو تو الله بھی بخشنے واا نہایت رحم والا ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxiv{تمہارے مال اور اولاد تمہارے لیے محض آزمائش ہیں اور الله کے پاس تو بڑا اجر ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxv{پس جہاں تک تم سے ہو سکے الله سے ڈرو اور سنو اور حکم مانو اور اپنے بھلے کے لیے خرچ کرو اورجو شخص اپنے دل کے لالچ سے محفوظ رکھا گیا سووہی فلاح بھی پانے والے ہیں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxvi{اگر تم الله کو نیک قرض دو تو وہ اسے تمہارے لیے دگنا کر دے گا اور تمہیں بخش دے گا اور الله بڑا قدردان حلم والا ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxvii{سب چھپی اورکھلی کا جاننے والا غالب حکمت والا ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxviii{\basmalahur اے نبی جب تم عورتوں کو طلاق دو تو ان کی عدت کے موقع پر طلاق دو اور عدت گنتے رہو اور الله سے ڈرتے رہو جو تمہارا رب ہے نہ تم ہی ان کو ان کے گھروں سے نکالو اور نہ وہ خود ہی نکلیں مگر جب کھلم کھلا کوئی بے حیائی کا کام کریں اور یہ الله کی حدیں ہیں اور جو الله کی حدوں سے بڑھاا تو اس نے اپنے نفس پر ظلم کیا آپ کو کیا معلوم کہ شاید الله اس کے بعد اور کوئی نئی بات پیدا کر دے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxix{پس جب وہ اپنی عدت کو پہنچ جائیں تو انہیں دستور سے رکھ لو یا انہیں دستور سے چھوڑ دو اور دو معتبر آدمی اپنے میں سے گواہ کر لو اور الله کے لیے گواہی پوری دو یہ نصیحت کی باتیں انہیں سمجھائی جاتی ہیں جو الله اور قیامت پر ایمان رکھتے ہیں اور جو الله سے ڈرتا ہے الله اس کے لیے نجات کی صورت نکال دیتا ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxx{اور اسے رزق دیتا ہے جہاں سے اسے گمان بھی نہ ہو اور جو الله پر بھروسہ کرتا ہے سو وہی اس کو کافی ہے بے شک الله اپنا حکم پورا کرنے والا ہے الله نے ہر چیز کے لیے ایک اندازہ مقرر کر دیا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxi{اور تمہاری عورتوں میں سے جن کو حیض کی امید نہیں رہی ہے اگر تمہیں شبہ ہو تو ان کی عدت تین مہینے ہیں اور ان کی بھی جنہیں ابھی حیض نہیں آیا اور حمل والیوں کی عدت ان کے بچہ جننے تک ہے اور جو الله سے ڈرتا ہے وہ اس کے کام آسان کر دیتا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxii{یہ الله کا حکم ہے جو اس نے تمہاری طرف نازل کیا ہے اور جو الله سے ڈرتا ہے وہ اس سے اس کی برائیاں دور کر دیتا ہے اور اسے بڑااجر بھی دیتا ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxiii{طلاق دی ہوئی عورتوں کو وہیں رکھو جہاں تم اپنے مقدور کے موافق رہتے ہو اورانہیں ایذا نہ دو انہیں تنگ کرنے کے لیے اور اگر وہ حاملہ ہوں تو انہیں نان ونفقہ دو جب تک وہ وضع حمل کریں پس اگر پلائيں دودھ تمہارے لیے تو دو ان کو ان کی اجرت دو اور آپس میں دستور کے مطابق مشورہ کر لو اور اگر تم آپس میں تنگی کرو تو اس کے لیے دوسری عورت دودھ پلائے گی\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxiv{مقدور والا اپنے مقدور کے موافق خرچ کرے اور اگر تنگ دست ہو تو جو کچھ الله نے اسے دیا ہے اس میں سے خرچ کرے الله کسی کو تکلیف نہیں دیتا مگر اسی قدر جو اسے دے رکھا ہے عنقریب الله تنگی کے بعد آسانی کر دے گا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxv{اور کتنی ہی بستیاں اپنے رب اوراس کے رسولوں کے حکم سے سر کش ہوگئیں پھر ہم نے بھی ان سے سخت حساب لیا اور ان کو بری سزا دی\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxvi{پس ان بستیوں نے اپنے کام کا وبال چکھا اور ان کا انجام کار بربادی ہوئی\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxvii{الله نے ان کے لیے سخت عذاب تیار کر رکھا ہے پھر اے عقل والو الله سے ڈرتے رہو جو ایمان لا چکے ہو بے شک الله نے تمہاری طرف نصیحت نازل کی ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxviii{یعنی ایک رسول جو تمہیں الله کی واضح آیتیں پڑھ کر سناتا ہے تاکہ جو ایمان لائے اورانہوں نے نیک کام بھی کیے انہیں اندھیروں سے نکال کر روشنی میں لے جائے اورجو الله پر ایمان لائے اور اس نے نیک کام بھی کیے تو اسے ایسے باغوں میں داخل کرے گا جن کے نیچے نہریں بہتی ہوں گی وہ ان میں سدا رہیں گے الله نے اس کو بہت اچھی روزی دی ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxix{الله ہی ہے جس نے سات آسمان پیدا کیے اور زمینیں بھی اتنی ہی ان میں حکم نازل ہوا کرتا ہے تاکہ تم جان لو کہ الله ہر چیز پر قادر ہے اور الله نے ہر چیز کو علم سے احاطہ کر رکھا ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxx{\basmalahur اے نبی آپ کیوں حرام کرتے ہیں جو الله نے آپ کے لیے حلال کیا ہے آپ اپنی بیویوں کی خوشنودی چاہتے ہیں اور الله بخشنے والا نہایت رحم والا ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxi{الله نے تمہارے لیے اپنی قسموں کا توڑ دینا فرض کر دیا ہے اور الله ہی تمہارا مالک ہے اوروہی سب کا جاننے والا حکمت والا ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxii{اور جب نبی نے چھپا کر اپنی کسی بیوی سے ایک بات کہہ دی اور پھر جب اس بیوی نے وہ بات بتا دی اور الله نے اس کو نبی پر ظاہر کر دیا تو نبی نے اس میں سے کچھ بات جتلا دی اور کچھ ٹال دی پس جب پیغمبر نے اس کو وہ بات جتلا دی تو بولی آپ کو کس نے یہ بات بتا دی آپ نے فرمایا مجھے خدائے علیم و خبیر نے یہ بات بتلائی\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxiii{اگر تم دونوں الله کی جناب میں توبہ کرو تو (بہتر) ورنہ تمہارے دل تو مائل ہو ہی چکے ہیں اوراگر تم آپ کے خلاف ایک دوسرے کی مدد کرو گی تو بے شک اللهآپ کا مددگار ہے اور جبرائیل اور نیک بخت ایمان والے بھی اور سب فرشتے اس کے بعد آپ کے حامی ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxiv{اگر نبی تمیں طلاق دے دے تو بہت جلد اس کا رب اس کے بدلے میں تم سے اچھی بیویاں دے دے گا فرمانبردار ایمان والیاں نمازی توبہ کرنے والی عبادت گزار روزہ دار بیوائیں اور کنواریاں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxv{اے ایمان والو اپنے آپ کو اور اپنے گھر والوں کو دوزخ سے بچاؤ جس کا ایندھن آدمی اور پتھر ہیں اس پر فرشتے سخت دل قوی ہیکل مقرر ہیں وہ الله کی نافرمانی نہیں کرتے جو وہ انہیں حکم دے اور وہی کرتے ہیں جو انہیں حکم دیا جاتا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxvi{اے کافرو آج بہانے نہ بناؤ تمہیں وہی بدلہ دیا جائے گا جو تم کیا کرتے تھے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxvii{اے ایمان والو الله کے سامنے خالص توبہ کرو کچھ بعید نہیں کہ تمہارا رب تم سے تمہارے گناہ دور کر دے اور تمہیں بہشتوں میں داخل کرے جن کے نیچے نہریں بہتی ہوں گی جس دن الله اپنے نبی کو اور ان کو جو اس کے ساتھ ایمان لائے رسوا نہیں کرے گا ان کا نور ان کے آگے اور ان کے دائیں دوڑ رہا ہوگا وہ کہہ رہے ہوں گے اے ہمارے رب ہمارے لیے ہمارا نور پورا کر اور ہمیں بخش دے بے شک تو ہر چیز پر قادر ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxviii{اے نبی کافروں اور منافقوں سے جہاد کر اور ان پر سختی کر اور انکا ٹھکانا دوزخ ہے اور وہ بہت ہی بری جگہ ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxix{الله کافرو ں کے لیے ایک مثال بیان کرتا ہے نوح اور لوط کی بیوی کی وہ ہمارے دو نیک بندوں کے نکاح میں تھیں پھر ان دونوں نے ان کی خیانت کی سو وہ الله کے غضب سے بچانے میں ان کے کچھ بھی کام نہ آئے اور کہا جائے گا دونوں دوزخ میں داخل ہونے والوں کے ساتھ داخل ہو جاؤ\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxl{اور الله ایمان داروں کے لیے فرعون کی بیوی کی مثال بیان کرتا ہے جب اس نے کہاکہ اے میرے رب میرے لیے اپنے پاس جنت میں ایک گھر بنا اور مجھے فرعون اور اس کے کام سے نجات دے اور مجھے ظالموں کی قوم سے نجات دے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxli{اور مریم عمران کی بیٹی (کی مثال بیان کرتا ہے) جس نے اپنی عصمت کو محفوظ رکھا پھر ہم نے اس میں اپنی طرف سے روح پھونکی اور اس نے اپنے رب کی باتوں کو اور اس کی کتابوں کو سچ جانا اوروہ عبادت کرنے والو ں میں سے تھی\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxlii{\basmalahur وہ ذات با برکت ہے جس کے ہاتھ میں سب حکومت ہے اور وہ ہر چیز پر قادر ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxliii{جس نے موت اور زندگی کو پیدا کیا تاکہ تمہیں آزمائيں کہ تم میں کس کے کام اچھے ہیں اور وہ غالب بخشنے والا ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxliv{جس نے سات آسمان اوپر تلے بنائے تو رحمان کی اس صنعت میں کوئی خلل نہ دیکھے گا تو پھر نگاہ دوڑا کیا تجھے کوئی شگاف دکھائی دیتا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxlv{پھر دوبارہ نگاہ کر تیری طرف نگاہ ناکام لوٹ آئے گی اور وہ تھکی ہوئی ہو گی\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxlvi{اور ہم نے دنیا کے آسمان کو چراغوں سے آراستہ کیا ہے اور ہم نے انہیں شیطانوں کو مارنے کے لیے آلہ بنا دیا ہے اور ہم نے ان کے لیے بھڑکتی آگ کا عذاب تیار کر رکھا ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxlvii{اور جنہوں نے اپنے رب کا انکار کیا ہے ان کے لیے جہنم کا عذاب ہے اور وہ بہت ہی بری جگہ ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxlviii{جب اس میں ڈالے جائیں گے تو اس کے شور کی آواز سنیں گے اور وہ جوش مارتی ہوگی\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxlix{ایسا معلوم ہو گا کہ جوش کی وجہ سے ابھی پھٹ پڑے گی جب اس میں ایک گروہ ڈالا جائے گا تو ان سے دوزخ کے داروغہ پوچھیں گے کیاتمہارے پاس کوئی ڈرانے والا نہیں آیا تھا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmccl{وہ کہیں گے ہاں بے شک ہمارے پاس ڈرنے والا آیا تھا پر ہم نے جھٹلا دیا اور کہہ دیا کہ الله نے کچھ بھی نازل نہیں کیا تم خود بڑی گمراہی میں پڑے ہوئے ہو\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmccli{اور کہیں گے کہ اگر ہم نے سنا یا سمجھا ہوتا تو ہم دوزخیوں میں نہ ہوتے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclii{پھر وہ اپنے گناہ کا اقرار کریں گے سو دوزخيوں پر پھٹکار ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmccliii{بے شک جو لوگ اپنے رب سے بن دیکھے ڈرتے ہیں ان کے لیے بخشش اور بڑا اجر ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmccliv{اور تم اپنی بات کو چھپاؤ یا ظاہر کرو بے شک وہ سینوں کے بھید خوب جانتا ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclv{بھلا وہ نہیں جانتا جس نے (سب کو) پیدا کیا وہ بڑا باریک بین خبردار ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclvi{وہی تو ہے جس نے تمہارے لیے زمین کو نرم کر دیا سو تم اس کے راستوں میں چلو پھر اور الله کے رزق میں سے کھاؤ اور اسی کے پاس پھر کر جانا ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclvii{کیا تم اس سے ڈرتے نہیں جو آسمان میں ہے کہ وہ تمہیں زمین میں دھنسا دے پس یکایک وہ لرزنے لگے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclviii{کیا تم اس سے نڈر ہو گئے ہو جو آسمان میں ہے وہ تم پر پتھر برسا دے پھر تمہیں معلوم ہو جائے گا کہ میرا ڈرانا کیسا ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclix{اور ان سے پہلے لوگ بھی جھٹلا چکے ہیں پھر ہماری ناراضگی کاکیا نتیجہ ہوا\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclx{اور کیا انہوں نے اپنے اوپر پرندوں کو پر کھولتے اور سکیڑتے ہوئے نہیں دیکھا جنہیں رحمان کے سوا کوئی نہیں تھام رہا بے شک وہ ہر چیز کو دیکھ رہاہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxi{بھلا وہ تمہارا کون سا لشکر ہے جو رحمنٰ کے مقابلہ میں تمہاری مدد کرے گا کچھ نہیں کافر تو دھوکے میں پڑے ہوئے ہیں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxii{بھلا وہ کون ہے جو تم کو روزی دے گا اگر وہ اپنی روزی بند کر لے کچھ نہیں بلکہ وہ سرکشی اور نفرت میں اڑے بیٹھے ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxiii{پس کیا وہ شخص جو اپنے منہ کے بل اوندھا چلتا ہے وہ زیادہ راہِ راست پر ہے یا وہ جو سیدھے راستے پر سیدھا چلا جاتا ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxiv{کہہ دو اسی نے تم کو پیدا کیا ہے اور تمہارے لیے کان اور آنکھ اور دل بھی بنائے ہیں (مگر) تم بہت ہی کم شکر کرتے ہو\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxv{کہہ دو اسی نے تمہیں زمین میں پھیلایا ہے اور اسی کے پاس جمع کر کے لائے جاؤ گے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxvi{اور وہ کہتے ہیں کہ یہ وعدہ کب ہو گا اگر تم سچے ہو\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxvii{کہہ دو اس کی خبر تو الله ہی کو ہے اور میں تو صاف صاف ڈرانے والا ہوں\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxviii{پھر جب وہ اسے قریب دیکھیں گے تو ان کی صورتیں بگڑ جائیں گی جو کافر ہیں اور کہا جائے گا یہ وہی ہے جسے تم دنیا میں مانگا کرتے تھے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxix{کہہ دو بھلادیکھو تو سہی اگر الله مجھے اور میرے ساتھ والوں کو ہلاک کرے یا ہم پر رحم کرے پھر وہ کون ہے جو منکروں کو دردناک عذاب سے بچا سکے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxx{کہہ دو وہی رحمنٰ ہے ہم اس پر ایمان لائے اور اسی پر ہم نے بھروسہ بھی کررکھا پس عنقریب تم جان لو گے کون صریح گمراہی میں ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxi{کہہ دو بھلا دیکھو تو سہی اگر تمہارا پانی خشک ہو جائے تو وہ کون ہے جو تمہارے پاس صاف پانی لے آئے گا\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxii{\basmalahur نۤ قلم کی قسم ہے اور اس کی جو اس سے لکھتے ہیں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxiii{آپ الله کے فضل سے دیوانہ نہیں ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxiv{اور آپ کے لیے تو بے شمار اجر ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxv{اور بے شک آپ تو بڑے ہی خوش خلق ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxvi{پس عنقریب آپ بھی دیکھ لیں گے اور وہ بھی دیکھ لیں گے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxvii{کہ تم میں سے کون دیوانہ ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxviii{بے شک آپ کا رب ہی خوب جانتا ہے کہ کون اس کی راہ سے بہکا ہے اور وہ ہدایت پانے والوں کو بھی خوب جانتا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxix{پس آپ جھٹلانےوالوں کا کہا نہ مانیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxx{وہ تو چاہتے ہیں کہ کہیں آپ نرمی کریں تو وہ بھی نرمی کریں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxi{اور ہر قسمیں کھانے والے ذلیل کا کہا نہ مان\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxii{جو طعنے دینے والا چغلی کھانے والا ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxiii{نیکی سے روکنے والا حد سے بڑھاہوا گناہگار ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxiv{بڑا اجڈ اس کے بعد بد اصل بھی ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxv{اس لئے کہ وہ مال اور اولاد والا ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxvi{جب اس پر ہماری آیتیں پڑھی جاتی ہیں تو کہتا ہے پہلوں کی کہانیاں ہیں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxvii{عنقریب ہم اس کی ناک پر داغ لگائیں گے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxviii{بے شک ہم نے ان کو آزمایا ہے جیسا کہ ہم نے باغ والوں کو آزمایا تھا جب انہوں نے قسم کھائی تھی کہ وہ ضرور صبح ہوتے ہی اس کا پھل توڑ لیں گے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxix{اور انشاالله بھی نہ کہا تھا\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxc{پھر تو اس پر رات ہی میں آپ کے رب کی طرف سے ایک جھونکا چل گیا درآنحالیکہ وہ سونے والے تھے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxci{پھر وہ کٹی ہوئی کھیتی کی طرح ہو گیا\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxcii{پھر وہ صبح کو پکارنے لگے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxciii{کہ اپنے کھیت پر سویرے چلو اگر تم نے پھل توڑنا ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxciv{پھر وہ آپس میں چپکے چپکے یہ کہتے ہوئے چلے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxcv{کہ تمہارے باغ میں آج کوئی محتاج نہ آنے پائے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxcvi{اور وہ سویرے ہی بڑے اہتمام سے پھل توڑنے کی قدرت کا خیال کر کے چل پڑے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxcvii{پس جب انہوں نے اسے دیکھا تو کہنے لگےکہ ہم تو راہ بھول گئے ہیں\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxcviii{بلکہ ہم تو بدنصیب ہیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxcix{پھر ان میں سے اچھے آدمی نے کہا کیامیں نے تمہیں نہیں کہا تھا کہ تم کس لیے تسبیح نہیں کرتے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmccc{انہوں نے کہا ہمارا رب پاک ہے بے شک ہم ظالم تھے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmccci{پھر ایک دوسرے کی طرف متوجہ ہو کر آپس میں ملامت کرنے لگے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccii{انہوں نے کہا ہائے افسوس بے شک ہم سرکش تھے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmccciii{شاید ہمارا رب ہمارے لیے اس سے بہتر باغ بدل دے بے شک ہم اپنے رب کی طرف رجوع کرنے والے ہیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmccciv{عذاب یونہی ہوا کرتا ہے اور البتہ آخرت کا عذاب تو کہیں بڑھ کر ہے کاش وہ جانتے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccv{بے شک پرہیزگاروں کے لیے ان کے رب کے ہاں نعمت کے باغ ہیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccvi{پس کیا ہم فرمانبرداروں کو مجرموں کی طرح کر دیں گے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccvii{تمہیں کیا ہوگیا کیسا فیصلہ کر رہے ہو\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccviii{کیا تمہارے پاس کوئی کتاب ہے جس میں تم پڑھتے ہو\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccix{کہ بے شک تمہیں آخرت میں ملے گا جو تم پسند کرتے ہو\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccx{کیا تمہارے لیے ہم نے قسمیں کھا لی ہیں جو قیامت تک چلی جائيں گی کہ بے شک تمہیں وہی ملے گا جو تم حکم کرو گے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxi{ان سے پوچھیئے کون سا ان میں اس بات کا ذمہ دار ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxii{کیا ان کے معبود ہیں پھر اپنے معبودوں کو لے آئيں اگر وہ سچے ہیں\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxiii{جس دن پنڈلی کھولی جائے گی اور وہ سجدہ کرنے کو بلائے جائیں گے تو وہ نہ کر سکیں گے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxiv{ان کی آنکھیں جھکی ہوں گی ان پر ذلت چھا رہی ہو گی اوروہ پہلے (دنیا میں) سجدہ کے لیے بلائے جاتے تھے حالانکہ وہ صحیح سالم ہوتے تھے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxv{پس مجھے اور اس کلام کے جھٹلانے والوں کو چھوڑ دو ہم انہیں بتدریج (جہنم کی طرف) لے جائے گے اس طور پر کہ انہیں خبر بھی نہیں ہو گی\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxvi{اور ہم انکو ڈھیل دیتے ہیں بے شک ہماری تدبیر زبردست ہے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxvii{کیا آپ ان سے کچھ اجرت مانگتے ہیں کہ جس کا تاوان کا ان پر بوجھ پڑ رہا ہے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxviii{یا ان کے پاس غیب کی خبر ہے کہ وہ اسے لکھ لیتے ہیں\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxix{پھر آپ اپنے رب کے حکم کا انتظار کریں اور مچھلی والے جیسے نہ ہوجائیں جب کہ اس نے اپنے رب کو پکارا اور وہ بہت ہی غمگین تھا\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxx{اگر اس کے رب کی رحمت اسے نہ سنبھال لیتی تو وہ برے حال سے چٹیل میدان میں پھینکا جاتا\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxi{پس اسے اس کے رب نے نوازا پھر اسے نیک بختو ں میں کر دیا\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxii{اور بالکل قریب تھا کہ کافر آپ کو اپنی تیز نگاہوں سے پھسلا دیں جب کہ انہوں نے قرآن سنا اور کہتے ہیں کہ یہ تو دیوانہ ہے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxiii{اور حالانکہ یہ قرآن تمام دنیا کے لیے صرف نصیحت ہے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxiv{\basmalahur قیامت\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxv{قیامت کیا چیز ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxvi{اور تمہیں کس چیز نے بتایا کہ قیامت کیا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxvii{ثمود اور عاد نے قیامت کو جھٹلایا تھا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxviii{سو ثمود تو سخت ہیبت ناک چیخ سے ہلاک کیے گئے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxix{اور لیکن قوم عاد سو وہ ایک سخت آندھی سے ہلاک کیے گئے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxx{وہ ان پر سات راتیں اور آٹھ دن لگاتار چلتی رہی (اگر تو موجود ہوتا) اس قوم کو اس طرح گرا ہوا دیکھتا کہ گویا کہ گھری ہوئی کھجوروں کے تنے ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxi{سو کیا تمہیں ان کا کوئی بچا ہوا نظر آتا ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxii{اور فرعون اس سے پہلے کے لوگ اور الٹی ہوئی بستیوں والے گناہ کے مرتکب ہوئے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxiii{پس انہوں نے اپنے رب کے رسول کی نافرمانی کی تو الله نے انہیں سخت پکڑ لیا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxiv{بے شک ہم نے جب پانی حد سے گزر گیا تھا تو تمہیں کشتی میں سوار کر لیا تھا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxv{تاکہ ہم اسے تمہارے لیے ایک یادگار بنائیں اور اس کو کان یا د رکھنے والے یاد رکھیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxvi{پھر جب صور میں پھونکا جائے گا ایک بار پھونکا جانا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxvii{اور زمین اور پہاڑ اٹھائے جائیں گے پس وہ دونوں ریزہ ریزہ کر دیئے جائیں گے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxviii{پس اس دن قیامت ہو گی\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxix{اور آسمان پھٹ جائے گا اوروہ اس دن بودا ہوگا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxl{اور اس کے کنارے پر فرشتے ہوں گے اور عرشِ الہیٰ کو اپنے اوپر اس دن آٹھ فرشتے اٹھائیں گے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxli{اس دن تم پیش کیے جاؤ گے تمہارا کوئی راز مخفی نہ رہے گا\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxlii{جس کو اس کا اعمال نامہ اس کے داہنے ہاتھ میں دیا جائے گا سو وہ کہے گا لو میرا اعمال نامہ پڑھو\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxliii{بے شک میں سمجھتا تھا کہ میں اپنا حساب دیکھوں گا\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxliv{سووہ دل پسند عیش میں ہو گا\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxlv{بلند بہشت میں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxlvi{جس کے میوے جھکے ہوں گے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxlvii{کھاؤ اور پیئو ان کاموں کے بدلے میں جو تم نے گزشتہ دنوں میں آگے بھیجے تھے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxlviii{اور جس کا اعمال نامہ اس کے بائیں ہاتھ میں دیا گیا تو کہے گا اے کاش میرا اعمال نامہ نہ ملتا\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxlix{اور میں نہ جانتا کہ میرا حساب کیا ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccl{کاش وہ (موت) خاتمہ کرنے والی ہوتی\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccli{میرا مال میرے کچھ کام نہ آیا\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclii{مجھ سے میری حکومت بھی جاتی رہی\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccliii{اسے پکڑو اسے طوق پہنا دو\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccliv{پھر اسے دوزخ میں ڈال دو\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclv{پھر ایک زنجیر میں جس کا طول ستر گز ہے اسے جکڑ دو\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclvi{بے شک وہ الله پر یقین نہیں رکھتا تھا جو عظمت والا ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclvii{اور نہ وہ مسکین کے کھانا کھلانے کی رغبت دیتا تھا\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclviii{سو آج اس کا یہاں کوئی دوست نہیں\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclix{اور نہ کھانا ہے مگر زخموں کا دھون\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclx{اسے سوائے گناہگاروں کے کوئی نہیں کھائے گا\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxi{سو میں ان چیزوں کی قسم کھاتا ہوں جو تم دیکھتے ہو\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxii{اوران کی جو تم نہیں دیکھتے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxiii{کہ بے شک یہ (قرآن) رسول کریم کی زبان سے نکلا ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxiv{اور وہ کسی شاعر کا قول نہیں (مگر) تم بہت ہی کم یقین کرتے ہو\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxv{اور نہ ہی کسی جادوگر کا قول ہے تم بہت ہی کم غور کرتے ہو\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxvi{وہ پرودگار عالم کا نازل کیا ہوا ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxvii{اور اگر وہ کوئی بناوٹی بات ہمارے ذمہ لگاتا\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxviii{تو ہم اس کا داہنا ہاتھ پکڑ لیتے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxix{پھر ہم اس کی رگِ گردن کاٹ ڈالتے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxx{پھر تم میں سے کوئی بھی اس سے روکنے والا نہ ہوتا\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxi{اور بے شک وہ تو پرہیزگاروں کے لیے ایک نصیحت ہے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxii{اور بے شک ہم جانتے ہیں کہ بعض تم میں سے جھٹلانے والے ہیں\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxiii{اور بے شک وہ کفار پر باعث حسرت ہے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxiv{اور بے شک وہ یقین کرنے کے قابل ہے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxv{پس اپنے رب کے نام کی تسبیح کر جو بڑا عظمت والا ہے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxvi{\basmalahur ایک سوال کرنے والے نے اس عذاب کا سوال کیا جو واقع ہونے والا ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxvii{کافرو ں کے لیے کہ اس کا کوئی ٹالنے والا نہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxviii{جس الله کی طرف سے واقع ہو گا جو سیڑھیوں کا (یعنی آسمانوں کا) مالک ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxix{(جن سیڑھیوں سے) فرشتے اور اہلِ ایمان کی روحیں اس کے پاس چڑھ کر جاتی ہیں (اور وہ عذاب) اس دن ہو گا جس کی مقدار پچاس ہزار سال کی ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxx{آپ اچھی طرح سے صبر کیے رہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxi{بے شک وہ اسے دور دیکھتے ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxii{اور ہم اسے قریب دیکھتے ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxiii{جس دن آسمان پگھلے ہوئے تانبے کی مانند ہوگا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxiv{اور پہاڑ دھنی ہوئی رنگداراؤن کی طرح ہوں گے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxv{اور کوئی دوست کسی دوست کو نہیں پوچھے گا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxvi{وہ انہیں کھائیں جائیں گے مجرم چاہے گا کہ کاش اس دن کے عذاب کے بدلے میں اپنے بیٹوں کو دے دے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxvii{اوراپنی بیوی اور اپنے بھائی کو\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxviii{اور اپنے اس کنبہ کو جو اسے پناہ دیتا تھا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxix{اوران سب کو جو زمین میں ہیں پھر اپنے آپ کو بچا لے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxc{ہرگز نہیں بے شک وہ تو ایک آگ ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxci{کھالوں کو اتارنے والی\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxcii{اس کو بلائے گی جس نے پیٹھ پھیری اورمنہ موڑا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxciii{اور مال جمع کیا اورگن گن کر رکھا\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxciv{بے شک انسان کم ہمت پیدا ہوا ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxcv{جب اسے تکلیف پہنچتی ہے تو چلا اٹھتا ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxcvi{اور جب اسے مال ملتا ہے تو بڑا بخیل ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxcvii{مگر وہ نمازی\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxcviii{جو اپنی نماز پر ہمیشہ سے قائم ہیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxcix{اوروہ جن کے مالو ں میں حصہ معین ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmcd{سائل اور غیر سائل کے لیے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdi{اوروہ جو قیامت کے دن کا یقین رکھتے ہیں\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdii{اور وہ جو اپنے رب کے عذاب سے ڈرنے والے ہیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdiii{بے شک ان کے رب کے عذاب کا خطرہ لگا ہوا ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdiv{اوروہ جو اپنی شرم گاہوں کی حفاظت کرتے ہیں\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdv{مگر اپنی بیویوں یا اپنی لونڈیوں سے سو بے شک انہیں کوئی ملامت نہیں\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdvi{پس جو کوئی اس کے سوا چاہے سو وہی لوگ حد سے بڑھنے والے ہیں\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdvii{اور وہ جواپنی امانتوں اور عہدوں کی رعایت رکھتے ہیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdviii{اور وہ جو اپنی گواہیوں پر قائم رہتے ہیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdix{اور وہ جو اپنی نمازوں کی حفاظت کرتے ہیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdx{وہی لوگ باغوں میں عزت سے رہیں گے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxi{پس کافروں کو کیا ہوگیا کہ آپ کی طرف دوڑے آ رہے ہیں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxii{دائیں اور بائیں سے ٹولیاں بنا کر\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxiii{کیا ہر ایک ان میں سے طمع رکھتا ہے کہ وہ نعمت کے باغ میں داخل کیا جاوے گا\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxiv{ہرگز نہیں بے شک ہم نے انہیں اس چیز سے پیدا کیا ہے جسے وہ بھی جانتے ہیں\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxv{پس میں مشرقوں اور مغربوں کے پروردگار کی قسم کھاتا ہوں (یعنی اپنی ذات کی) کہ ہم ضرور قادر ہیں\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxvi{اس بات پر کہ ہم ان سے بہتر لوگ بدل کر لا سکتے ہیں اور ہم عاجز بھی نہیں ہیں\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxvii{پھر انہیں چھوڑ دو کہ وہ بیہودہ باتوں اور کھیل میں لگے رہیں یہاں تک کہ وہ دن دیکھ لیں جس کا ان سے وعدہ کیا جاتا ہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxviii{جس دن وہ دوڑتے ہوئے قبروں سے نکل پڑیں گے گویا کہ وہ ایک نشان کی طرف دوڑے چلے جارہے ہیں\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxix{ان کی نگاہیں جھکی ہوں گی ان پر ذلت چھا رہی ہو گی یہی وہ دن ہے جس کا ان سے وعدہ کیا جاتا تھا\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxx{\basmalahur بے شک ہم نے نوح کو اس کی قوم کی طرف بھیجا تھا کہ اپنی قوم کو ڈرا اس سے پہلے کہ ان پر دردناک عذاب آ پڑے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxi{اس نے کہا کہ اے میری قوم بے شک میں تمہارے لیے کھلم کھلا ڈرانے والا ہوں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxii{کہ الله کی عبادت کرو اور اس سے ڈرو اور میرا کہا مانو\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxiii{وہ تمہارے لیے تمہارے گناہ بخش دے گا اور تمہیں ایک وقت مقرر تک مہلت دے گا بے شک الله کا وقت ٹھیرایا ہوا ہے جب آجائے گا تو اس میں تاخیر نہ ہوگی کا ش تم جانتے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxiv{کہا اے میرے رب میں نے اپنی قوم کو رات اور دن بلایا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxv{پھر وہ میرے بلانے سے اوربھی زيادہ بھاگتے رہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxvi{اور بے شک جب کبھی میں نے انہیں بلایا تاکہ تو انہیں معاف کر دے تو انہوں نے اپنی انگلیاں اپنے کانوں میں رکھ لیں اور انہوں نے اپنے کپڑے اوڑھ لیے اور ضد کی اوربہت بڑا تکبر کیا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxvii{پھر میں نے انہیں کھلم کھلا بھی بلایا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxviii{پھر میں نے انہیں علانیہ بھی کہا اور مخفی طور پر بھی کہا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxix{پس میں نے کہا اپنے رب سے بخشش مانگو بے شک وہ بڑا بخشنے والا ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxx{وہ آسمان سے تم پر (موسلا داھار) مینہ برسائے گا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxi{اور مال اور اولاد سے تمہاری مدد کرے گا اور تمہارے لیے باغ بنادے گا اور تمہارے لیے نہریں بنا دے گا\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxii{تمہیں کیا ہو گیا تم الله کی عظمت کا خیال نہیں رکھتے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxiii{حالانکہ اس نے تمہیں کئی طرح سے بنا یا ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxiv{کیا تم نہیں دیکھتے کہ الله نے سات آسمان اوپر تلے (کیسے) بنائے ہیں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxv{اوران میں چاند کو چمکتا ہوا بنایا اور آفتاب کو چراغ بنا دیا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxvi{اور الله ہی نے تمہیں زمین میں سے ایک خاص طور پر پیدا کیا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxvii{پھر وہ تمہیں اسی میں لوٹائے گا اور اسی میں سے (پھر) باہر نکالے گا\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxviii{اور الله ہی نے تمہارے لیے زمین کو فرش بنایا ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxix{تاکہ تم اس کے کھلے راستوں میں چلو\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxl{نوح نے کہا اے میرے رب بے شک انہوں نے میرا کہنا نہ مانا اور اس کو مانا جس کو اس کے مال اور اولاد نے نقصان کے سوا کچھ بھی فائد نہں دیا\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxli{اور انہوں نے بڑی زبردست چال چلی\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxlii{اور کہا تم اپنے معبودوں کوہرگز نہ چھوڑو اور نہ ودّ اور سواع اور یغوث اور یعوق اورنسرکو چھوڑو\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxliii{اور انہوں نے بہتوں کو گمراہ کر دیا اور (اب آپ) ان ظالموں کی گمراہی اور بڑھا دیجیئے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxliv{وہ اپنے گناہوں کے سبب سے غرق کر دیئے گئے پھر دوزخ میں داخل کیے گئے پس انہوں نے اپنے لیے سوائے الله کے کوئی مددگار نہ پایا\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxlv{اور نوح نے کہا اے میرے رب زمین پر کافروں میں سے کوئی رہنے والا نہ چھوڑ\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxlvi{اگر تو نے ان کو چھوڑ دیا تو تیرے بندوں کو گمراہ کریں گے اور نسل بھی جو ہو گی تو فاجر اور کافر ہی ہو گی\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxlvii{اے میرے رب مجھے اور میرے ماں باپ کو بخش دے اور اس کی جو میرے گھر میں ایماندار ہو کر داخل ہوجائے اور ایماندار مردوں اور عورتوں کو اور ظالموں کو تو بربادی کے سوا اور کچھ زیادہ نہ کر\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxlviii{\basmalahur کہہ دو کہ مجھے اس بات کی وحی آئی ہے کہ کچھ جن (مجھ سے قرآن پڑھتے) سن گئے ہیں پھر انہوں نے (اپنی قوم سے) جا کر کہہ دیا کہ ہم نے عجیب قرآن سنا ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxlix{جو نیکی کی طرف رہنمائی کرتا ہے سو ہم اس پر ایمان لائے ہیں اور ہم اپنے رب کا کسی کو شریک نہ ٹھیرائیں گے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdl{اورہمارے رب کی شان بلند ہے نہ اس کی کوئی بیوی ہے اور نہ بیٹا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdli{اور ہم میں سے بعض بے وقوف ہیں جو الله پر جھوٹی باتیں بنایا کرتے تھے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlii{اور ہمیں خیال تھا کہ انسان اور جن الله پر ہرگز چھوٹ نہ بولیں گے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdliii{اورکچھ آدمی جنوں کے مردوں سے پناہ لیاکرتے تھے سو انہوں نے ان کی سرکشی اور بڑھا دی\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdliv{اور وہ بھی سمجھے ہوئے تھے جیسا کہ تم نے سمجھ رکھا ہے کہ الله ہر گز کسی کو (رسول بنا کر) نہ بھیجحے گا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlv{اور ہم نے آسمان کو ٹٹولا تو ہم نے اسے سخت پہروں اور شعلوں سے بھرا ہو ا پایا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlvi{اورہم نے اس کے ٹھکانوں میں سننے کے لیے بیٹھا کرتے تھے پس جو کوئی اب کان دھرتا ہے تو وہ اپنے لیے ایک انگارہ تاک لگانے ہوئے پاتا ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlvii{اورہم نہیں جانتے کہ زمین والوں کے ساتھ نقصان کا ارادہ کیا گیا ہےیا ان کی نسبت ان کے رب نےراہ راست پر لانے کا ارادہ کیا ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlviii{اور کچھ تو ہم میں سے نیک ہیں اور کچھ اور طرح کے ہم بھی مختلف طریقوں پر تھے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlix{اور بے شک ہم نے سمجھ لیا ہے کہ ہم الله کو زمین میں کبھی عاجز نہ کر سکیں گے اور نہ ہی ہم بھاگ کر عاجز کر سکیں گے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlx{اور جب ہم نے ہدایت کی بات سنی تو ہم اس پر ایمان لے آئے پھر جو اپنے رب پر ایمان لے لآیا تو نہ اسے نقصان کا ڈر رہے گا اور نہ ظلم کا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxi{اور کچھ تو ہم میں سے فرمانبردار ہیں اور کچھ نافرمان پس جوکوئی فرمانبردار ہو گیا سو ایسے لوگوں نے سیدھا راستہ تلاش کر لیا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxii{اور لیکن جو ظالم ہیں سو وہ دوزح کا ایندھن ہوں گے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxiii{اور اگر (مکہ والے) سیدھے راستے پر قائم رہتے تو ہم ان کو با افراط پانی سے سیراب کرتے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxiv{تاکہ اس (ارزانی) میں ان کا امتحان کریں اورجس نے اپنے رب کی یاد سے منہ موڑا تو وہ اسے سخت عذاب میں ڈالے گا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxv{اوربے شک مسجدیں الله کے لیے ہیں پس تم الله کے ساتھ کسی کو نہ پکارو\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxvi{اورجب الله کا بندہ (نبی) اس کو پکارنے کھڑا ہوتا ہے تو لوگ اس پر جھمگٹا کرنے لگتے ہیں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxvii{کہہ دو میں تو اپنے رب ہی کو پکارتا ہوں اور اس کے ساتھ کسی کوبھی شریک نہیں کرتا\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxviii{کہہ دو میں نہ تمہارے کسی ضرر کا اختیار رکھتا ہوں اورنہ کسی بھلائی کا\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxix{کہہ دو مجھے الله سے کوئی نہیں بچا سکے گا اور نہ مجھے اس کے سوا پناہ ملے گی\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxx{مگر الله کا پیغام اور اس کا حکم پہنچانا ہے اور جو کوئی الله اوراس کے رسول کی نافرمانی کرے گا تو اس کے لیے دوزخ کی آگ ہے جس میں وہ سدا رہے گا\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxi{یہاں تک کہ جب وہ (عذاب) دیکھیں گے جس کا ان سے وعدہ کیا جاتا ہے تو وہ جان لیں گے کہ کس کے مددگار کمزور اور شمار میں کم ہیں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxii{کہہ دو مجھے خبر نہیں جس کا تم سے وعدہ کیا گیا ہے وہ قریب ہے یا اس کے لیے میرا رب کوئی مدت ٹھیراتا ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxiii{وہ غیب جاننے والا ہے اپنے غائب کی باتوں پر کسی کو واقف نہیں کرتا\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxiv{مگر اپنے پسندیدہ رسول کو پھراس کے آگے اور پیچھے محافظ مقرر کر دیتا ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxv{تاکہ وہ بظاہر جان لے کہ انہوں نے اپنے رب کے پیغامات پہنچا دیے اور الله نے تمام کاموں کو اپنے قبضے میں کر رکھا ہے ارواس نے ہر چیز کی گنتی شمار کر رکھی ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxvi{\basmalahur اے چادر اوڑھنے والے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxvii{رات کو قیام کر مگر تھوڑا ساحصہ\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxviii{آدھی رات یا اس میں سے تھوڑا ساحصہ کم کر دے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxix{یا اس پر زیادہ کر دو اور قرآن کو ٹھہر ٹھہر کر پڑھا کرو\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxx{ہم عنقریب آپ پر ایک بھاری بات کا (بوجھ) ڈالنے والے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxi{بےشک رات کا اٹھنا نفس کو خوب زیر کرتا ہے اور بات بھی صحیح نکلتی ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxii{بے شک دن میں آپ کے لیے بڑا کام ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxiii{اور اپنے رب کا نام لیا کرو اور سب سے الگ ہو کر اسی کی طرف آ جاؤ\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxiv{وہ مشرق اور مغرب کا مالک ہے اس کے سوا اور کوئی معبود نہیں پس اسی کو کارساز بنا لو\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxv{اور کافروں کی باتوں پر صبر کرو اور انہیں عمدگی سے چھوڑ دو\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxvi{اورمجھے اور جھٹلانے والے دولت مندوں کو چھوڑ دو اور انہیں تھوڑی سی مدت و مہلت دو\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxvii{بے شک ہمارے پاس بیڑیاں اور جہنم ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxviii{اور گلے میں اٹکنے والا کھانا اور دردناک عذاب\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxix{جس دن زمین اور پہاڑ لرزیں گے اور پہاڑ ریگ رواں کے تودے ہو جائیں گے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxc{ہم نے تمہاری طرف تم پر گواہی دینے والا ایک رسول بھیجا ہے کہ جس طرح فرعون کی طرف ایک رسول بھیجا تھا\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxci{پھر فرعون نے اس رسول کی نافرمانی کی تو ہم نے اسے سخت پکڑ سے پکڑ لیا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxcii{پھر تم کس طرح بچو گے اگر تم نے بھی انکار کیا اس دن جو لڑکوں کو بوڑھا کر دے گا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxciii{اس دن آسمان پھٹ جائے گا اس کا وعدہ ہو کر رہے گا\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxciv{بے شک یہ (قرآن) ایک نصیحت ہے پھر جو چاہے اپنے رب کی طرف آنے کا راستہ بنا لے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxcv{بے شک آپ کا رب جانتا ہے کہ آپ اور جو لوگ آپ کے ساتھ ہیں (کبھی) دو تہائی رات کے قریب اور (کبھی) آدھی رات اور (کبھی) تہائی رات سے (نماز تہجد) میں کھڑے ہوتے ہیں اور الله ہی رات اور دن کا اندازہ کرتا ہے اسے معلوم ہے کہ تم اس کو نباہ نہیں سکتے سو اس نے تم پر رحم کیا پس پڑھو جتنا قرآن میں سے آسان ہو اسے علم ہے کہ تم میں سے کچھ بیمار ہوں گے اور کچھ اور لوگ بھی جو الله کا فضل تلاش کرتے ہوئے زمین پر سفر کریں گے اورکچھ اور لوگ ہوں گے جو الله کی راہ میں جہاد کریں گے پس پڑھو جو اس میں سےآسان ہو اور نماز قائم کرو اور زکوةٰ دو اور الله کو اچھی طرح (یعنی اخلاص سے) قرض دو اورجو کچھ نیکی آگے بھیجوگے اپنے واسطے تو اس کو الله کے ہاں بہتر اور بڑے اجر کی چیز پاؤ گے اور الله سے بخشش مانگو بے شک الله بخشنے والا نہایت رحم والا ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxcvi{\basmalahur اے کپڑے میں لپٹنے والے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxcvii{اٹھو پھر (کافروں کو) ڈراؤ\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxcviii{اور اپنے رب کی بڑائی بیان کرو\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxcix{اور اپنے کپڑے پاک رکھو\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmd{اورمیل کچیل دور کرو\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdi{اوربدلہ پانے کی غرض سے احسان نہ کرو\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdii{اوراپنے رب کے لیے صبر کرو\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdiii{پھر جب صور میں پھونکا جائے گا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdiv{پس وہ اس دن بڑا کٹھن دن ہو گا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdv{کافروں پر وہ آسان نہ ہو گا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdvi{مجھے اور اس کو چھوڑ دو کہ جس کو میں نے اکیلا پیدا کیا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdvii{اوراس کوبڑھنے والا مال دیا\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdviii{اور حاضر رہنے والے بیٹے دیئے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdix{اور اس کے لیے ہر طرح کا سامان تیار کر دیا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdx{پھر وہ طمع کرتا ہے کہ میں اور بڑھا دوں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxi{ہرگز نہیں بےشک وہ ہماری آیات کا سخت مخالف ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxii{عنقریب میں اسے اونچی گھاٹی پر چڑھاؤں گا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxiii{بے شک اس نے سوچا اور اندازہ لگایا\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxiv{پھر اسے الله کی مار اس نے کیسا اندازہ لگایا\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxv{پھر اسے الله کی مار اس نے کیسا اندازہ لگایا\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxvi{پھر اس نے دیکھا\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxvii{پھر اس نے تیوری چڑھائی اور منہ بنایا\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxviii{پھر پیٹھ پھیر لی اور تکبر کیا\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxix{پھر کہا یہ تو ایک جادو ہے جو چلا آتا ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxx{یہ تو ہو نہ ہو آدمی کا کلام ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxi{عنقریب اس کو دوزخ میں ڈالوں گا\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxii{اور آپ کو کیا خبر کہ دوزخ کیا ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxiii{نہ باقی رکھے اور نہ چھوڑے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxiv{آدمی کو جھلس دے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxv{اس پر انیس (فرشتے) مقرر ہیں\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxvi{اور ہم نے دوزخ پر فرشتے ہی رکھے ہیں اور ان کی تعداد کافروں کے لیے آزمائش بنائی ہے تاکہ جن کو کتاب دی گئی ہے وہ یقین کر لیں اور ایمان داروں کا ایمان بڑھے اورتاکہ اہلِ کتاب اور ایمان دار شک نہ کریں اور تاکہ جن کے دلوں میں (نفاق کی) بیماری ہے اورکافر یہ کہیں کہ الله کی اس بیان سے کیاغرض ہے اور الله اس طرح سے جسے چاہتاہے گمراہ کر تا ہے اور جسے چاہتا ہے ہدایت کرتا ہے اور آپ کے رب کے لشکروں کو اس کے سوا اور کوئی نہیں جانتا اور دوزخ (کا حال بیان کرنا) صرف آدمیوں کی نصیحت کے لیے ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxvii{نہیں نہیں قسم ہے چاند کی\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxviii{اور رات کی جب وہ ڈھلے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxix{اور صبح کی جب وہ روشن ہوجائے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxx{کہ وہ (دوزخ) بڑی بڑی مصیبتوں میں سے ایک ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxi{انسان کو ڈرانے والی ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxii{تم میں سے ہر ایک کے لیے خواہ کوئی اس کے آگے آئے یا پیچھے ہٹے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxiii{ہر شخص اپنے اعمال کے سبب گروی ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxiv{مگر داہنے والے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxv{باغوں میں ہو ں گے ایک دوسرے سے پوچھیں گے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxvi{گناہگارو ں کی نسبت\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxvii{کس چیز نے تمہیں دوزخ میں ڈالا\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxviii{وہ کہیں گے کہ ہم نمازی نہ تھے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxix{اور نہ ہم مسکینوں کو کھانا کھلاتے تھے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxl{اور ہم بکواس کرنے والوں کے ساتھ بکواس کیاکرتے تھے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxli{اور ہم انصاف کے دن کو جھٹلایا کرتے تھے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxlii{یہاں تک کہ ہمیں موت آ پہنچی\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxliii{پس ان کو سفارش کرنے والوں کی سفارش نفع نہ دے گی\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxliv{پسانہیں کیا ہو گیا کہ وہ نصیحت سے منہ موڑرہے ہیں\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxlv{گویا کہ وہ بدکنے والے گدھے ہیں\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxlvi{جو شیر سے بھاگے ہیں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxlvii{بلکہ ہر ایک آدمی ان میں سے چاہتا ہے کہ اسے کھلے ہوئے صحیفے دیئے جائیں\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxlviii{ہرگز نہیں بلکہ وہ آخرت سے نہیں ڈرتے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxlix{ہرگز نہیں بے شک یہ (قرآن) ایک نصیحت ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmmdl{(پس جو چاہے اس کو یاد کر لے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmmdli{اور کوئی بھی یاد نہیں کر سکتا مگر جبکہ الله ہی چاہے وہی جس سے ڈرنا چاہیے اوروہی بخشنے والا ہے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlii{\basmalahur قیامت کے دن کی قسم ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdliii{اور پشیمان ہونے والے شخص کی قسم ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdliv{کیا انسان سمجھتا ہے کہ ہم اس کی ہڈیاں جمع نہ کریں گے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlv{ہاں ہم تو اس پر قادر ہیں کہ اس کی پور پور درست کر دیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlvi{بلکہ انسان تو چاہتا ہے کہ آئندہ بھی نافرمانی کرتا رہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlvii{پوچھتا ہےکہ قیامت کا دن کب ہو گا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlviii{پس جب آنکھیں چندھیا جائیں گی\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlix{اور چاند بے نور ہو جائے گا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlx{اور سورج اور چاند اکھٹے کیے جائیں گے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxi{اس دن انسان کہے گا کہ بھاگنے کی جگہ کہاں ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxii{ہر گز نہیں کہیں پناہ نہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxiii{اس دن آپ کے رب ہی کی طرف ٹھکانہ ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxiv{اس دن انسان کو بتا دیا جائے گا کہ وہ کیا لایا اور کیا چھوڑ آیا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxv{بلکہ انسان اپنے اوپر خود شاہد ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxvi{گو وہ کتنے ہی بہانے پیش کرے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxvii{آپ (وحی ختم ہونے سے پہلے) قرآن پراپنی زبان نہ ہلایا کیجیئے تاکہ آپ اسے جلدی جلدی لیں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxviii{بے شک اس کا جمع کرنا اور پڑھا دینا ہمارے ذمہ ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxix{پھر جب ہم ا سکی قرأت کر چکیں تو اس کی قرأت کا اتباع کیجیئے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxx{پھر بے شک اس کا کھول کر بیان کرنا ہمارے ذمہ ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxi{ہر گز نہیں بلکہ تم تو دنیا کو چاہتے ہو\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxii{اور آخرت کو چھوڑتے ہو\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxiii{کئی چہرے اس دن تر و تازہ ہو ں گے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxiv{اپنے رب کی طرف دیکھتے ہوں گے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxv{اور کتنے چہرے اس دن اداس ہو ں گے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxvi{خیال کر رہے ہوں گے کہ ان کے ساتھ کمر توڑ دینے والی سختی کی جائے گی\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxvii{نہیں نہیں جب کہ جان گلے تک پہنچ جائے گی\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxviii{اورلوگ کہیں گے کوئی جھاڑنے والا ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxix{اور وہ خیال کرے گا کہ یہ وقت جدائی کا ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxx{اور ایک پنڈلی دوسری پنڈلی سے لپٹ جائے گی\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxi{تیرے رب کی طرف اس دن چلنا ہوگا\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxii{پھر نہ تو اس نے تصدیق کی اور نہ نماز پڑھی\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxiii{بلکہ جھٹلایا اورمنہ موڑا\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxiv{پھر اپنے گھر والوں کی طرف اکڑتا ہوا چلا گیا\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxv{(اے انسان) تیرے لیے افسوس پرافسوس ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxvi{پھر تیرے لیے افسوس پر افسوس ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxvii{کیاانسان یہ سمجھ رہا ہے کہ وہ یونہی چھوڑ دیا جائے گا\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxviii{کیا وہ ٹپکتی منی کی ایک بوند نہ تھا\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxix{پھر وہ لوتھڑا بنا پھر الله نے اسے بنا کر ٹھیک کیا\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxc{پھر اس نے مرد و عورت کا جوڑا بنایا\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxci{پھر کیا وہ الله مردے زندہ کردینے پر قادر نہیں\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxcii{\basmalahur انسان پر ضرور ایک ایسا زمانہ بھی آیا ہے کہ اس کا کہیں کچھ بھی ذکر نہ تھا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxciii{بے شک ہم نے انسان کو ایک مرکب بوند سے پیدا کیا ہم اس کی آزمائش کرنا چاہتے تھے پس ہم نے اسے سننے والا دیکھنے والا بنا دیا\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxciv{بے شک ہم نے اسے راستہ دکھا دیا یا تو وہ شکر گزار ہے اور یا ناشکرا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxcv{بے شک ہم نے کافروں کے لیے زنجیریں اور طوق اور دھکتی آگ تیار کر رکھی ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxcvi{بے شک نیک ایسی شراب کے پیالے پئیں گے جس میں چشمہ کافور کی آمیزش ہو گی\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxcvii{وہ ایک چشمہ ہو گا جس میں سے الله کے بندے پئیں گے اس کو آسانی سے بہا کر لے جائیں گے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxcviii{وہ اپنی منتیں پوری کرتے ہیں اور اس دن سے ڈرتے رہتے ہیں جس کی مصیبت ہر جگہ پھیلی ہوئی ہوگی\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxcix{اور وہ اس کی محبت پرمسکین اور یتیم اور قیدی کو کھانا کھلاتے ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdc{ہم جو تمہیں کھلاتے ہیں تو خاص الله کے لیے نہ ہمیں تم سے بدلہ لینا مقصود ہے اور نہ شکرگزاری\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdci{ہم تو اپنے رب سے ایک اداس (اور) ہولناک دن سے ڈرتے ہیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcii{پس الله اس دن کی مصیبت سے انہیں بچا لے گا اور ان کے سامنے تازگی اور خوشی لائے گا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdciii{اوران کے صبر کے بدلے ان کو جنت اور ریشمی پوشاکیں دے گا\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdciv{اس میں تختوں پر تکیہ لگائے ہوئے ہوں گے نہ وہاں دھوپ دیکھیں گے اور نہ سردی\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcv{اور ان پر اس کے سائے جھک رہے ہوں گے اور پھلوں کے گوشے بہت ہی قریب لٹک رہے ہوں گے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcvi{اوران پر چاندی کے برتن اور شیشے کے آبخوروں کا دور چل رہا ہوگا\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcvii{شینیے بھی چاندی کے شیشے جو ایک خاص اناز پر ڈھالے گئے ہوں گے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcviii{اورانہیں وہاں ایسی شراب کا پیالہ پلایا جائے گا جس میں سونٹھ کی آمیزش ہو گی\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcix{وہ وہاں ایک چشمہ ہے جس کا نام سلسبیل ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcx{اوران کے پاس سدا رہنے والے لڑکے (خادم) گھومتے ہوں گے جو تو ا ن کو دیکھےگا تو خیال کرے گا کہ وہ بکھرے ہوئے موتی ہیں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxi{اورجب تو وہاں دیکھے گا تو نعمت اور بڑی سلطنت دیکھے گا\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxii{ان پرباریک سبز اور موٹے ریشم کے لباس ہوں گے اور انہیں چاندی کے کنگن پہنائے جائیں گے اور انہیں ان کا رب پاک شراب پلائے گا\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxiii{بے شک یہ تمہارے (نیک اعمال کا) بدلہ ہے اور تمہاری کوشش مقبول ہوئی\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxiv{بےشک ہم نےہی آپ پر یہ قرآن تھوڑا تھوڑا اتارا ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxv{پھر آپ اپنے رب کے حکم کا انتظار کیاکر یں اوران میں سے کسی بدکار یا ناشکرے کا کہا نہ مانا کریں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxvi{اوراپنے رب کا نام صبح اور شام یاد کیا کریں\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxvii{اورکچھ حصہ رات میں بھی اس کو سجدہ کیجیئے اوررات میں دیر تک اس کی تسبیح کیجیئے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxviii{بے شک یہ لوگ دنیا کو چاہتے ہیں اور اپنے پیچھے ایک بھاری دن کو چھوڑتے ہیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxix{ہم ہی نے انہیں پیدا کیااور ان کے جوڑ مضبوط کر دیئے اورجب ہم چاہیں ان جیسےان کے بدلے اور لا سکتے ہیں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxx{بے شک یہ ایک نصیحت ہے پس جو کوئی چاہے اپنے رب کی طرف راستہ اختیار کرے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxi{اور تم جب ہی چاہو گے جب الله چاہے گا بے شک الله سب کچھ جاننے والا حکمت والا ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxii{جس کو چاہتا ہے اپنی رحمت میں داخل کرتا ہے اورظالموں کے لیے تو اس نے دردناک عذاب تیار کر رکھا ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxiii{\basmalahur ان ہواؤں کی قسم ہے جو نفع پہنچانے کے لیے بھیجی جاتی ہیں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxiv{پھر ان ہواؤں کی جو تندی سے چلتی ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxv{اوران ہواؤں کی جو بادلوں کو اٹھا کر پھیلاتی ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxvi{پھر ان ہواؤں کی جو بادلوں کو متفرق کر دیتی ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxvii{پھر ان ہواؤں کی جو (دل میں) الله کی یاد کا القا کرتی ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxviii{الزام اتارنے یا ڈرانے کے لیے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxix{جن کا تم سے وعدہ کیا جاتا ہے وہ ضرور ہونے والی ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxx{پس جب ستارے مٹا دیئے جائیں گے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxi{اورجب آسمان پھٹ جائیں گے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxii{اورجب پہاڑ اڑائے جائیں گے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxiii{اور جب رسول وقت معین پرجمع کیے جائیں گے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxiv{کس دن کے لیے تاخیر کی گئی تھی\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxv{فیصلہ کے دن کے لیے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxvi{اور آپکو کیا معلوم کہ فیصلہ کا دن کیا ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxvii{اس دن جھٹلانے والوں کے لیے تباہی ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxviii{کیا ہم نے پہلوں کو ہلاک نہیں کر ڈالا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxix{پھر ہم ان کے پیچھے دوسروں کو چلائیں گے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxl{مجرموں کے ساتھ ہم ایسا ہی برتاؤ کرتے ہیں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxli{اس دن جھٹلانے والوں کے لیے تباہی ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxlii{کیا ہم نے تمہیں ایک ذلیل پانی سے نہیں پیدا کیا\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxliii{پھر ہم نے اس کو ایک محفوظ ٹھکانے میں رکھ دیا\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxliv{ایک معین اندازے تک\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxlv{پھر ہم نے اندازہ لگایا تو ہم تو کیسے اچھے اندازہ لگانے والے ہیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxlvi{اس دن جھٹلانے والوں کے لیےتباہی ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxlvii{کیا ہم نے زمین کو جمع کرنے والی نہیں بنایا\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxlviii{زندوں اور مردوں کو\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxlix{اور ہم نے اس میں مضبوط اونچے اونچے پہاڑ رکھ دیئے اور ہم نے تمہیں میٹھا پانی پلایا\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcl{اس دن جھٹلانے والوں کے لیے تباہی ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcli{اس (دوزخ) کی طرف چلو جسے تم جھٹلایا کرتےتھے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclii{ایک سائبان کی طرف چلو جسکے تین حصے ہیں\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcliii{نہ وہ سایہ کرے اور نہ تپش سے بچائے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcliv{بے شک وہ محل جیسے انگارے پھینکے گی\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclv{گویا کہ وہ زرد اونٹ ہیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclvi{اس دن جھٹلانے والوں کے لیے تباہی ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclvii{یہ وہ دن ہے جس میں بات بھی نہ کر سکیں گے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclviii{اور نہ انہیں عذر کرنے کی اجازت ہو گی\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclix{اس دن جھٹلانے والوں کے لیے تباہی ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclx{یہ فیصلہ کا دن ہے ہم تمہیں اور پہلوں کو جمع کریں گے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxi{پس اگر تمہارے پاس کوئی تدبیر ہے تو مجھ پر کر دیکھو\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxii{اس دن جھٹلانے والوں کے لیے تباہی ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxiii{بے شک پرہیزگار ٹھنڈی چھاؤں اور چشموں میں ہوں گے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxiv{اور میووں میں جو وہ چاہیں گے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxv{مزے سے کھاؤ اور پیئو ان کاموں کے بدلے جو تم کرتے رہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxvi{بے شک ہم اسی طرح نیکو کاروں کو بدلہ دیتے ہیں\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxvii{اس دن جھٹلانے والوں کے لیے تباہی ہے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxviii{کھاؤ اور چند روز فائدہ اٹھاؤ بے شک تم مجرم ہو\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxix{اس دن جھٹلانے والوں کے لیے تباہی ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxx{اورجب ان سے کہا جاتا تھا کہ رکوع کرو تورکوع نہ کرتے تھے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxi{اس دن جھٹلانے والوں کے لیے تباہی ہے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxii{پس اس کے بعد کس بات پر ایمان لائیں گے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxiii{\basmalahur کس چیز کی بابت وہ آپس میں سوال کرتے ہیں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxiv{اس بڑی خبر کے متعلق\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxv{جس میں وہ اختلاف کر رہے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxvi{ہرگز ایسا نہیں عنقریب وہ جان لیں گے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxvii{پھر ہر گز ایسا نہیں عنقریب وہ جان لیں گے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxviii{کیا ہم نے زمین کو فرش نہیں بنایا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxix{اور پہاڑوں کو میخیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxx{اور ہم نے تمہیں جوڑے جوڑے پیدا کیا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxi{اور تمہاری نیند کو راحت کا باعث بنایا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxii{اور رات کو پردہ پوش بنایا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxiii{اور دن کو روزی کمانے کے لیے بنایا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxiv{اور ہم نے تمہارے اوپر سات سخت (آسمان) بنائے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxv{اور ایک جگمگاتا ہوا چراغ بنایا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxvi{اور ہم نے بادلوں سے زور کا پانی اتارا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxvii{تاکہ ہم اس سے اناج اور گھاس اگائیں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxviii{اور گھنے باغ اگائیں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxix{بے شک فیصلہ کا دن معین ہو چکا ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxc{جس دن صور میں پھونکا جائے گا پھر تم گروہ درگروہ چلے آؤ گے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxci{اور آسمان کھولا جائے گا تو (اس میں) دروازے ہوجائیں گے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxcii{اور پہاڑ اڑائے جائیں گے توریت ہو جائیں گے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxciii{بے شک دوزخ گھات میں لگی ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxciv{سرشکوں کے لیے ٹھکانہ ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxcv{کہ وہ اس میں ہمیشہ پڑے رہیں گے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxcvi{نہ وہاں کسی ٹھنڈک کا مزہ چکھیں گے اور نہ کسی پینے کی چیز کا\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxcvii{مگر گرم پانی اور بہتی پیپ\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxcviii{پوراپورا بدلہ ملے گا\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxcix{بے شک وہ حساب کی امید نہ رکھتے تھے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcc{اور ہماری آیتوں کوبہت جھٹلایا کرتے تھے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcci{اور ہم نے ہر چیز کو کتاب میں شمار کر رکھا ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccii{پس چکھو سو ہم تمہارے لیے عذاب ہی زیادہ کرتے رہیں گے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcciii{بے شک پرہیزگاروں کے لیے کامیابی ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcciv{باغ اور انگور\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccv{اور نوجوان ہم عمر عورتیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccvi{اور پیالے چھلکتے ہوئے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccvii{نہ وہاں بیہودہ باتیں سنیں گے اور نہ جھوٹ\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccviii{آپ کے رب کی طرف سے حسب اعمال بدلہ عطا ہوگا\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccix{جو آسمانوں اور زمین کا رب ہے اور جو کچھ ان کے درمیان ہے بڑامہربان کہ وہ اس سے بات نہیں کر سکیں گے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccx{جس دن جبرائیل اور سب فرشتے صف باندھ کر کھڑے ہوں گےکوئی نہیں بولے گا مگر وہ جس کو رحمنٰ اجازت دے گا اور وہ بات ٹھیک کہے گا\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxi{یہ یقینی دن ہے پس جو چاہے اپنے رب کے پاس ٹھکانا بنا لے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxii{بے شک ہم نے تمہیں ایک عنقریب آنے والے عذاب سے ڈرایا ہے جس دن آدمی دیکھے گا جو کچھ اس کے ہاتھوں نے آگے بھیجا تھا اور کافر کہے گا اے کاش میں مٹی ہو گیا ہوتا\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxiii{\basmalahur جورڑوں میں گھس کر نکالنے والوں کی قسم ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxiv{اور بند کھولنے والوں کی\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxv{اورتیزی سے تیرنے والوں کی\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxvi{پھر دوڑ کر آگے بڑھ جانے والوں کی\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxvii{پھر ہر امر کی تدبیر کرنے والوں کی\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxviii{جس دن کانپنے والی کانپے گی\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxix{اس کے پیچھے آنے والی پیچھے آئے گی\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxx{کئی دل اس دن دھڑک رہے ہوں گے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxi{ان کی آنکھیں جھکی ہوئی ہوں گی\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxii{وہ کہتے ہیں کیا ہم پہلی حالت میں لوٹائے جائیں گے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxiii{کیا جب ہم بوسیدہ ہڈیاں ہوجائیں گے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxiv{کہتے ہیں کہ یہ تو اس وقت خسارہ کا لوٹنا ہوگا\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxv{پھر وہ واقعہ صرف ایک ہی ہیبت ناک آواز ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxvi{پس وہ اسی وقت میدان میں آ موجود ہوں گے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxvii{کیا آپ کو موسیٰ کا حال معلوم ہوا ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxviii{جب کہ مقدس وادی طویٰ میں اس کے رب نے اسےپکارا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxix{فرعون کے پاس جاؤ کیونکہ اس نے سرکشی کی ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxx{پس کہو کیا تیری خواہش ہے کہ تو پاک ہو\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxi{اور میں تجھے تیرے رب کی طرف راہ بتاؤں کہ تو ڈرے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxii{پس اس نے اس کو بڑی نشانی دکھائی\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxiii{تو اس نے جھٹلایا اور نافرمانی کی\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxiv{پھر کوشش کرتا ہوا واپس لوٹا\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxv{پھر اس نے سب کو جمع کیا پھر پکارا\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxvi{پھر کہا کہ میں تمہارا سب سے برتر رب ہوں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxvii{پھر الله نے اس کو آخرت اور دنیا کے عذاب میں پکڑ لیا\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxviii{بے شک اس میں اس کے لیے عبرت ہے جو ڈرتا ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxix{کیا تمہارا بنانا بڑی بات ہے یا آسمان کا جس کو ہم نے بنایا ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxl{ا سکی چھت بلند کی پھر اس کو سنوارا\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxli{اور اس کی رات اندھیری کی اور اس کے دن کو ظاہر کیا\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxlii{اور اس کے بعد زمین کو بچھا دیا\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxliii{اس سے اس کا پانی اور اس کا چارا نکالا\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxliv{او رپہاڑوں کو خوب جما دیا\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxlv{تمہارے لیے اور تمہارے چار پایوں کے لیے سامان حیات ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxlvi{پس جب وہ بڑا حادثہ آئے گا\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxlvii{جس دن انسان اپنے کیے کو یاد کرے گا\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxlviii{اور ہر دیکھنے والے کے لیے دوزخ سامنے لائی جائے گی\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxlix{سو جس نے سرکشی کی\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccl{اور دنیا کی زندگی کو ترجیح دی\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccli{سو بے شک اس کا ٹھکانا دوزخ ہی ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclii{اور لیکن جو اپنے رب کے سامنے کھڑا ہونے سے ڈرتارہا اور اس نے اپنے نفس کو بری خواہش سے روکا\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccliii{سو بے شک اس کا ٹھکانا بہشت ہی ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccliv{آپ سے قیامت کی بابت پوچھتے ہیں کہ اس کا قیام کب ہوگا\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclv{آپ کو اس کےذکر سے کیا واسطہ\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclvi{اس کے علم کی انتہا آپ کے رب ہی کی طرف ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclvii{بے شک آپ تو صرف اس کو ڈرانے والے ہیں جو اس سے ڈرتا ہے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclviii{جس دن اسے دیکھ لیں گے (تو یہی سمجھیں گے کہ دنیا میں) گویا ہم ایک شام یا اس کی صبح تک ٹھیرے تھے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclix{\basmalahur پیغمبر چین بجیں ہوئے اور منہ موڑ لیا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclx{کہ ان کے پاس ایک اندھا آیا\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxi{اور آپ کو کیا معلوم کہ شاید وہ پاک ہوجائے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxii{یا وہ نصیحت پکڑ لے تو اس کو نصیحت نفع دے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxiii{لیکن وہ جو پروا نہیں کرتا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxiv{سو آپ کے لیے توجہ کرتے ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxv{حالانکہ آپ پر اس کےنہ سدھرنے کا کوئی الزام نہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxvi{اور لیکن جو آپ کے پاس دوڑتا ہوا آیا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxvii{اور وہ ڈر رہا ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxviii{تو آپ اس سے بے پروائی کرتے ہیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxix{ایسا نہیں چاہیئے بے شک یہ تو ایک نصیحت ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxx{پس جو چاہے اس کو یاد کرے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxi{وہ عزت والے صحیفوں میں ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxii{جو بلند مرتبہ اور پاک ہیں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxiii{ان لکھنے والوں کے ہاتھوں میں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxiv{جو بڑے بزرگ نیکو کار ہیں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxv{انسان پر خدا کی مار وہ کیسا ناشکرا ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxvi{اس نے کس چیز سے اس کو بنایا\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxvii{ایک بوند سے اس کوبنایا پھر اس کا اندزہ ٹھیرایا\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxviii{پھراس پر راستہ آسان کر دیا\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxix{پھر اس کو موت دی پھر اس کو قبر میں رکھوایا\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxx{پھر جب چاہے گا اٹھا کر کھڑا کرے گا\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxi{ایسا نہیں چاہیئے اس نے تعمیل نہیں کی جو اس کو حکم دیا تھا\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxii{پس انسان کو اپنے کھانے کی طرف غور کرنا چاہیئے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxiii{کہ ہم نے اوپر سے مینہ برسایا\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxiv{پھر ہم نے زمین کو چیر کر پھاڑا\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxv{پھر ہم نے اس میں اناج ا گایا\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxvi{اورانگور اور ترکاریاں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxvii{اور زیتون اور کھجور\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxviii{اور گھنے باغ\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxix{اور میوے اور گھاس\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxc{تمہارے لیے اور تمہارے چار پایوں کے لیے سامان حیات\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxci{پھر جس وقت کانوں کا بہرا کرنے والا شور برپا ہوگا\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxcii{جس دن آدمی اپنے بھائی سے بھاگے گا\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxciii{اور اپنی ماں اور باپ سے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxciv{اور اپنی بیوی اوراپنے بیٹوں سے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxcv{ہر شخص کی ایسی حالت ہوگی جو اس کو اوروں کی طرف سے بے پروا کر دے گی\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxcvi{اورکچھ چہرے اس دن چمک رہے ہوں گے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxcvii{ہنستے ہوئے خوش و خرم\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxcviii{اور کچھ چہرے اس دن ایسے ہوں گے کہ ان پر گرد پڑی ہو گی\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxcix{ان پر سیاہی چھا رہی ہو گی\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccc{یہی لوگ ہیں منکر نافرمان\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccci{\basmalahur جب سورج کی روشنی لپیٹی جائے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccii{اور جب ستارے گر جائیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccciii{اور جب پہاڑ چلائے جائیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccciv{اور جب دس مہینے کی گابھن اونٹنیاں چھوڑ دی جائیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccv{اور جب جنگلی جانور اکھٹے ہوجائیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccvi{اور جب سمندر جوش دیئے جائیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccvii{اور جب جانیں جسموں سے ملائی جائیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccviii{اور جب زندہ درگور لڑکی سے پوچھا جائے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccix{کہ کس گناہ پر ماری گئی تھی\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccx{اور جب اعمال نامے کھل جائیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxi{اور آسمان کا پوست اتارا جائے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxii{اورجب دوزخ دھکائی جائے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxiii{اورجب جنت قریب لائی جائے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxiv{تو ہر شخص جان لے گا کہ وہ کیا لے کر آیا ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxv{پس میں قسم کھاتا ہوں پیچھے ہٹنے والے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxvi{سیدھے چلنے والے غیب ہو جانے والے ستارو ں کی\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxvii{اور قسم ہے رات کی جب وہ جانے لگے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxviii{اور قسم ہے صبح کی جب وہ آنے لگے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxix{بے شک یہ قرآن ایک معزز رسول کا لایا ہوا ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxx{جو بڑا طاقتور ہے عرش کے مالک کے نزدیک بڑے رتبہ والا ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxi{وہاں کا سردار امانت دار ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxii{اور تمہارا رفیق کوئی دیوانہ نہیں ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxiii{اور اس نے اس کو کُھلے کنارے پر دیکھا بھی ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxiv{اور وہ غیب کی باتوں پر بخیل نہیں ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxv{اور وہ کسی شیطان مردود کا قول نہیں ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxvi{پس تم کہاں چلے جا رہے ہو\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxvii{یہ تو جہان بھرکے لیے نصیحت ہی نصیحت ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxviii{اس کے لیے جو تم میں سے سیدھا چلنا چاہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxix{اور تم توجب ہی چاہو گے کہ جب الله چاہے گا جو تمام جہان کا رب ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxx{\basmalahur جب آسمان پھٹ جائے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxi{اورجب ستارے جھڑ جائیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxii{اور جب سمندر ابل پڑیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxiii{اور جب قبریں اکھاڑ دی جائیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxiv{تب ہر شخص جان لے گا کہ کیا آگے بھیجا اور کیا پیچھے چھوڑ آیا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxv{اے انسان تجھے اپنے رب کریم کے بارے میں کس چیز نے مغرور کر دیا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxvi{جس نے تجھے پیدا کیا پھر تجھے ٹھیک کیا پھر تجھے برابر کیا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxvii{جس صورت میں چاہا تیرے اعضا کو جوڑ دیا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxviii{نہیں نہیں بلکہ تم جزا کو نہیں مانتے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxix{اور بے شک تم پر محافظ ہیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxl{عزت والے اعمال لکھنے والے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxli{وہ جانتے ہیں جو تم کرتے ہو\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxlii{بےشک نیک لوگ نعمت میں ہوں گے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxliii{اور بے شک نافرمان دوزخ میں ہوں گے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxliv{انصاف کے دن اس میں داخل ہوں گے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxlv{اور وہ اس سے کہیں جانے نہ پائیں گے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxlvi{اورتجھے کیا معلوم انصاف کا دن کیا ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxlvii{پھر تجھے کیا خبر کہ انصاف کا دن کیا ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxlviii{جس دن کوئی کسی کے لیے کچھ بھی نہ کر سکے گااور اس دن الله ہی کا حکم ہوگا\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxlix{\basmalahur کم تولنے والوں کے لیے تباہی ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccl{وہ لوگ کہ جب لوگوں سے ماپ کر لیں تو پورا کریں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccli{اور جب ان کو ماپ کر یا تول کردیں توگھٹا کر دیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclii{کیا وہ خیال نہیں کرتے کہ وہ اٹھائے جائیں گے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccliii{اس بڑے دن کے لیے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccliv{جس دن سب لوگ رب العالمین کے سامنے کھڑے ہو ں گے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclv{ہر گز ایسا نہیں چاہیے بے شک نافرمانوں کے اعمال نامے سجین میں ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclvi{اور آپ کو کیا خبر کہ سجین کیا ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclvii{ایک دفتر ہے جس میں لکھا جاتا ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclviii{اس دن جھٹلانے والوں کے لئے تباہی ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclix{وہ جو انصاف کے دن کو جھٹلاتے ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclx{اور اس کو وہی جھٹلاتا ہے جو حد سے بڑھا ہوا گناہگار ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxi{جب اس پر ہماری آیتیں پڑھی جاتی ہیں تو کہتا ہے پہلوں کی کہانیاں ہیں\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxii{ہر گز نہیں بلکہ ان کے (بڑے) کاموں سے ان کے دلو ں پر زنگ لگ گیا ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxiii{ہر گز نہیں بے شک وہ اپنے رب سے اس دن روک دیئے جائیں گے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxiv{پھر بے شک وہ دوزخ میں گرنے والے ہیں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxv{پھر کہا جائے گا کہ یہی ہے وہ جسے تم جھٹلاتے تھے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxvi{ہر گز نہیں بےشک نیکوں کے اعمال نامے علییں میں ہیں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxvii{اور آپ کو کیا خبر کہ علیّین کیا ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxviii{ایک دفتر ہے جس میں لکھا جاتا ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxix{اسے مقرب فرشتے دیکھتے ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxx{بے شک نیکو کار جنت میں ہوں گے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxi{تختوں پر بیٹھے دیکھ رہے ہوں گے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxii{آپ ان کے چہروں میں نعمت کی تازگی معلوم کریں گے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxiii{ان کو خالص شراب مہر لگی ہوئی پلائی جائے گی\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxiv{اس کی مہر مشک کی ہو گی اور رغبت کرنے والوں کو اس کی رغبت کرنی چاہیئے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxv{اور اس میں تسنیم ملی ہو گی\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxvi{وہ ایک چشمہ ہے اس میں سےمقرب پئیں گے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxvii{بے شک نافرمان (دنیا میں) ایمان داروں سے ہنسی کیا کرتے تھے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxviii{اور جب ان کے پاس سے گزرتے تو آپس میں آنکھ سے اشارے کرتے تھے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxix{اور جب اپنے گھر والوں کے پاس لوٹ کر جاتے تو ہنستے ہوئے جاتے تھے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxx{اور جب ان کو دیکھتے تو کہتے بے شک یہی گمراہ ہیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxi{حالانکہ وہ ان پر نگہبان بنا کر نہیں بھیجے گئے تھے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxii{پس آج وہ لوگ جو ایمان لائے کفار سے ہنس رہے ہوں گے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxiii{تختوں پر بیٹھے دیکھ رہے ہوں گے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxiv{آیا کافروں کو بدلہ دیا گیا ہے ان اعمال کا جو وہ کیا کرتے تھے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxv{\basmalahur جب آسمان پھٹ جائے گا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxvi{اور اپنے رب کا حکم سن لے گا اور وہ اسی لائق ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxvii{اور جب زمین پھیلا دی جائے گی\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxviii{اور جو کچھ اس میں ہے ڈال دے گی اور خالی ہو جائے گی\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxix{اور اپنے رب کا حکم سن لے گی اور وہ اسی لائق ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxc{اے انسان تو اپنے رب کے پاس پہنچنے تک کام میں کوشش کر رہا ہے پھر اس سے جا ملے گا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxci{پھر جس کا اعمال نامہ اس کے دائیں ہاتھ میں دیا گیا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxcii{تو اس سے آسانی کے ساتھ حساب لیا جائے گا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxciii{اور وہ اپنے اہل و عیال میں خوش واپس آئے گا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxciv{اور لیکن جس کو نامہٴ اعمال پیٹھ پیچھے سے دیا گیا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxcv{تو وہ موت کو پکارے گا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxcvi{اور دوزخ میں داخل ہوگا\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxcvii{بے شک وہ اپنے اہل و عیال میں بڑا خوش و خرم تھا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxcviii{بے شک اس نے سمجھ لیا تھا کہ ہر گز نہ لوٹ کر جائے گا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxcix{کیوں نہیں بے شک اس کا رب تو اس کو دیکھ رہا تھا\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcm{پس شام کی سرخی کی قسم ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmi{اور رات کی اور جو کچھ اس نے سمیٹا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmii{اور چاند کی جب کہ وہ پورا ہوجائے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmiii{کہ تمہیں ایک منزل سے دوسری منزل پر چڑھنا ہوگا\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmiv{پھر انہیں کیا ہو گیا کہ ایمان نہیں لاتے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmv{اور جب ان پر قرآن پڑھا جائے تو سجدہ نہیں کرتے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmvi{بلکہ جو لوگ منکر ہیں جھٹلاتے ہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmvii{اور الله خوب جانتا ہے وہ جو (دل میں) محفوظ رکھتے ہیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmviii{پس انہیں دردناک عذاب کی خوشخبری دے دو\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmix{مگر جو لوگ ایمان لائے اورانہوں نے نیک عمل کیے ان کے لیے بے انتہا اجر ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmx{\basmalahur آسمان کی قسم ہے جس میں برج ہیں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxi{اوراس دن کی جس کا وعدہ کیا گیا ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxii{اور اس دن کی جو حاضر ہوتا ہے اور اس کی جس کے پاس حاضر ہوتے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxiii{خندقوں والے ہلاک ہوئے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxiv{جس میں آگ تھی بہت ایندھن والی\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxv{جب کہ وہ اس کے کنارو ں پر بیٹھے ہوئے تھے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxvi{اور وہ ایمانداروں سے جو کچھ کر رہے تھے اس کو دیکھ رہے تھے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxvii{اور ان سے اسی کا توبدلہ لے رہے تھے کہ وہ الله زبردست خوبیوں والے پر ایمان لائے تھے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxviii{وہ کہ جس کے قبضہ میں آسمان اور زمین ہیں اور الله ہر چیز پر شاہد ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxix{بے شک جنہوں نے ایمان دار مردوں اور ایمان دار عورتوں کو ستایا پھر توبہ نہ کی تو ان کے لیے جہنم کا عذاب ہے اور ان کے لیے جلانے والا عذاب ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxx{بے شک جو لوگ ایمان لائے اور انہوں نے نیک کام بھی کیے ان کے لیے باغ ہیں جن کے نیچے نہریں بہتی ہوں گی یہی بڑی کامیابی ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxi{بے شک تیرے رب کی پکڑ بھی سخت ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxii{بے شک وہی پہلے پیدا کرتا ہے اور دوبارہ پیدا کرے گا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxiii{اور وہی ہے بخشنے والا محبت کرنے والا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxiv{عرش کا مالک بڑی شان والا\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxv{جو چاہے کرنے والا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxvi{کیا آپ کے پاس لشکروں کا حال پہنچا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxvii{فرعون اور ثمود کے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxviii{بلکہ منکر تو جھٹلانے میں لگے ہوئے ہیں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxix{اور الله ہر طرف سے ان کو گھیرے ہوئے ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxx{بلکہ وہ قرآن ہے بڑی شان والا\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxi{لوح محفوظ میں (لکھا ہوا ہے)\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxii{\basmalahur آسمان کی قسم ہے اور رات کو آنے والے کی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxiii{اور آپ کو کیا معلوم رات کو آنے والا کیا ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxiv{وہ چمکتا ہوا ستارہ ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxv{ایسی کوئی بھی جان نہیں کہ جس پر ایک محافظ مقرر نہ ہو\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxvi{پس انسان کو دیکھنا چاہیے کہ وہ کس چیز سے پیدا کیا گیا ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxvii{ایک اچھلتے ہوئے پانی سے پیدا کیا گیا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxviii{جو پیٹھ اور سینے کی ہڈیوں کے درمیان سے نکلتا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxix{بے شک وہ اس کے لوٹانے پر قادر ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxl{جس دن بھید ظاہر کیے جائیں گے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxli{تو اس کے لیے نہ کوئی طاقت ہو گی اور نہ کوئی مددگار\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxlii{آسمان اور بارش والے کی قسم ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxliii{اور زمین کی جو پھٹ جاتی ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxliv{بے شک قرآن قطعی بات ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxlv{اوروہ ہنسی کی بات نہیں ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxlvi{بے شک وہ ایک تدبیر کر رہے ہیں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxlvii{اور میں بھی ایک تدبیر کر رہا ہوں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxlviii{پس کافرو ں کو تھوڑے دنوں کی مہلت دے دو\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxlix{\basmalahur اپنے رب کے نام کی تسبیح کیا کر جو سب سے اعلیٰ ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcml{وہ جس نے پیدا کیا پھر ٹھیک بنایا\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmli{اور جس نے اندازہ ٹھہرایا پھر راہ دکھائی\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlii{اور وہ جس نے چارہ نکالا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmliii{پھر اس کو خشک چورا سیاہ کر دیا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmliv{البتہ ہم آپ کو پڑھائیں گے پھر آپ نہ بھولیں گے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlv{مگر جو الله چاہے بے شک وہ ہرظاہر اور چھپی بات کو جانتا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlvi{اور ہم آپ کو آسان شریعت کے سمجھنے کی توفیق دیں گے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlvii{پس آپ نصیحت کیجیئے اگر نصیحت فائدہ دے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlviii{جو الله سے ڈرتا ہے وہ جلدی سمجھ جائے گا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlix{اور اس سے بڑا بدنصیب الگ رہے گا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlx{جو سخت آگ میں داخل ہوگا\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxi{پھر اس میں نہ تو مرے گا اور نہ جیئے گا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxii{بے شک وہ کامیاب ہوا جو پاک ہو گیا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxiii{اور اپنے رب کا نام یاد کیا پھر نماز پڑھی\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxiv{بلکہ تم تودنیا کی زندگی کو ترجیح دیتے ہو\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxv{حالانکہ آخرت بہتر اور زیادہ پائدار ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxvi{بے شک یہی پہلے صحیفوں میں ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxvii{(یعنی) ابراھیم اور موسیٰ کے صحیفوں میں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxviii{\basmalahur کیا آپ کے پاس سب پرچھا جانے والی (قیامت) کا حال پہنچا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxix{کئی چہرو ں پر اس دن ذلت برس رہی ہوگی\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxx{محنت کرنے والے تھکنے والے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxi{دھکتی ہوئی آگ میں کریں گے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxii{انہیں ابلتے ہوئے چشمے سے پلایا جائے گا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxiii{ان کے لیے کوئی کھانا سوائے کانٹے دار جھاڑی کے نہ ہوگا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxiv{جو نہ فربہ کرتی ہے اور نہ بھوک کود ور کرتی ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxv{کئی منہ اس دن ہشاش بشاش ہوں گے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxvi{اپنی کوشش سے خوش ہوں گے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxvii{اونچے باغ میں ہوں گے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxviii{وہاں کوئی لغو بات نہیں سنیں گے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxix{وہاں ایک چشمہ جاری ہوگا\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxx{وہاں اونچے اونچے تخت ہوں گے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxi{اور آبخورے سامنے چنے ہوئے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxii{اورگاؤ تکیے قطار سے لگے ہوئے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxiii{اور مخملی فرش بچھے ہوئے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxiv{پھر کیا وہ اونٹوں کی طرف نہیں دیکھتے کہ کیسے بنائے گئے ہیں\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxv{اور آسمان کی طرف کہ کیسے بلند کیے گئے ہیں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxvi{اور پہاڑوں کی طرف کہ کیسے کھڑے کیے گئے ہیں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxvii{اور زمین کی طرف کہ کیسے بچھائی گئی ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxviii{پس آپ نصیحت کیجئے بے شک آپ تو نصیحت کرنے والے ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxix{آپ ان پر کوئی داروغہ نہیں ہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxc{مگر جس نے منہ موڑا اورانکار کیا\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxci{سو اسے الله بہت بڑا عذاب دے گا\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxcii{بےشک ہماری طرف ہی ان کو لوٹ کر آنا ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxciii{پھر ہمارےہی ذمہ ان کا حساب لینا ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxciv{\basmalahur فجر کی قسم ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxcv{اور دس راتوں کی\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxcvi{اور جفت اور طاق کی\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxcvii{اور رات کی جب وہ گزر جائے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxcviii{ان چیزو ں کی قسم عقلمندوں کے واسطے معتبر ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxcix{کیا آپ نے نہیں دیکھا کہ آپ کے رب نے عاد کے ساتھ کیا سلوک کیا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmm{جو نسل ارم سے ستونوں والے تھے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmi{کہ ان جیسا شہرو ں میں پیدا نہیں کیا گیا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmii{اور ثمود کے ساتھ جنہوں نے پتھروں کو وادی میں تراشا تھا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmmiii{اور فرعون میخوں والوں کے ساتھ\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmmiv{ان سب نے ملک میں سرکشی کی\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmmv{پھر انہوں نے بہت فساد پھیلایا\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmmvi{پھر ان پر تیرے رب نے عذاب کا کوڑا پھینکا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmmvii{بے شک آپ کا رب تاک میں ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmmviii{لیکن انسان تو ایسا ہے کہ جب اسے اس کا رب آزماتا ہے پھر اسے عزت اور نعمت دیتا ہے تو کہتا ہے کہ میرے رب نے مجھے عزت بخشی ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmmix{لیکن جب اسے آزماتا ہے پھر اس پر اس کی روزی تنگ کر تا ہے تو کہتا ہے میرے رب نے مجھے ذلیل کر دیا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmmx{ہرگز نہیں بلکہ تم یتیم کی عزت نہیں کرتے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxi{اور نہ مسکین کو کھانا کھلانے کی ترغیب دیتے ہو\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxii{اور میت کا ترکہ سب سمیٹ کر کھا جاتے ہو\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxiii{اور مال سے بہت زیادہ محبت رکھتے ہو\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxiv{ہرگز نہیں جب زمین کوٹ کوٹ کر ریزہ ریزہ کر دی جائے گی\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxv{اور آپ کے رب کا (تخت) آجائے گا اور فرشتے بھی صف بستہ چلے آئيں گے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxvi{اوراس دن دوزخ لائی جائے گی اس دن انسان سمجھے گا اور اس وقت اس کو سمجھنا کیا فائدہ دے گا\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxvii{کہے گا اے کاش میں اپنی زندگی کے لیے کچھ آگے بھیجتا\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxviii{پس اس دن اس کا ساعذاب کوئی بھی نہ دے گا\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxix{اور نہ اس کے جکڑنے کے برابر کوئی جکڑنے والا ہو گا\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxx{(ارشاد ہوگا) اے اطمینان والی روح\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxi{اپنے رب کی طرف لوٹ چل تو اس سے راضی وہ تجھ سے راضی\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxii{پس میرے بندو ں میں شامل ہو\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxiii{اور میری جنت میں داخل ہو\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxiv{\basmalahur ا س شہر کی قسم ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxv{حالانکہ آپ اس شہر میں مقیم ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxvi{اورباپ کی اور اس کی اولاد کی قسم ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxvii{کہ بےشک ہم نے انسان کو مصیبت میں پیدا کیا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxviii{کیا وہ خیال کرتا ہےکہ اس پر کوئی بھی ہرگز قابو نہ پا سکے گا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxix{کہتا ہے کہ میں نے مال برباد کر ڈالا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxx{کیا وہ خیال کرتا ہے کہ اسے کسی نے بھی نہیں دیکھا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxi{کیا ہم نے اس کے لیے دو آنکھیں نہیں بنائیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxii{اور زبان اور دو ہونٹ\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxiii{اور ہم نے اسے دونوں راستے دکھائے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxiv{پس وہ (دین کی) گھاٹی میں سے نہ ہو کر نکلا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxv{اور آپ کو کیا معلوم کہ وہ گھاٹی کیا ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxvi{گردن کا چھوڑانا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxvii{یا بھوک کے دن میں کھلانا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxviii{کسی رشتہ دار یتیم کو\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxix{یا کسی خاک نشین مسکین کو\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxl{پھر وہ ان میں سے ہو جو ایمان لائے اور انہوں نے ایک دوسرے کو صبر کی وصیت کی اور رحم کرنے کی وصیت کی\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxli{یہی لوگ دائیں والے ہیں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxlii{اور جنہوں نے ہماری آیتوں سے انکار کیا وہی بائیں والے ہیں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxliii{انہیں پر چاروں طرف سے بند کی ہوئی آگ ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxliv{\basmalahur سورج کی اور اس کی دھوپ کی قسم ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxlv{اور چاند کی جب وہ اس کے پیچھے آئے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxlvi{اور دن کی جب وہ اس کو روشن کر دے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxlvii{اور رات کی جب وہ اس کو ڈھانپ لے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxlviii{اور آسمان کی اور اس کی جس نے اس کو بنایا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxlix{اور زمین اور اس کی جس نے اس کو بچھایا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmml{اور جان کی اور اس کی جس نے اس کو درست کیا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmli{پھر اس کو اس کی بدی اور نیکی سمجھائی\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlii{بے شک وہ کامیاب ہوا جس نے اپنی روح کو پاک کر لیا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmmliii{اوربے شک وہ غارت ہوا جس نے اس کو آلودہ کر لیا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmmliv{ثمود نے اپنی سرکشی سے (صالح کو) جھٹلایا تھا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlv{جب کہ ان کا بڑا بدبخت اٹھا\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlvi{پس ان سے الله کے رسول نے کہا کہ الله کی اونٹنی اور اس کے پانی پینے کی باری سے بچو\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlvii{پس انہوں نے اس کو جھٹلایا اور اونٹنی کی کونچیں کاٹ ڈالیں پھر ان پر ان کے رب نےان کےگناہوں کے بدلے ہلاکت نازل کی پھر ان کو برابر کر دیا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlviii{اوراس نے اس کےانجام کی پروا نہ کی\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlix{\basmalahur رات کی قسم ہے جب کہ وہ چھاجائے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlx{اور دن کی جبکہ وہ روشن ہو\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxi{اوراس کی قسم کہ جس نے نر و مادہ کوبنایا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxii{بے شک تمہاری کوشش مختلف ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxiii{پھر جس نے دیا اور پرہیز گاری کی\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxiv{اورنیک بات کی تصدیق کی\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxv{تو ہم اس کے لیے جنت کی راہیں آسان کر دیں گے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxvi{اورلیکن جس نے بخل کیا اوربے پرواہ رہا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxvii{اور نیک بات کو جھٹلایا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxviii{تو ہم اس کے لیے جہنم کی راہیں آسان کر دیں گے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxix{اوراس کا مال اس کے کچھ بھی کام نہ آئے گا جب کہ وہ گھڑے میں گرے گا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxx{بے شک ہمارے ذمے راہ دکھانا ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxi{اور بے شک ہمارے ہی ہاتھ میں آخرت بھی اور دنیا بھی ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxii{پس میں نے تمہیں بڑھکتی ہوئی آگ سے ڈرایا ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxiii{جس میں صرف وہی بد بخت داخل ہوگا\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxiv{جس نے جھٹلایا اورمنہ موڑا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxv{اوراس آگ سے وہ بڑا پرہیز گار دور رہے گا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxvi{جو اپنا مال دیتا ہے تاکہ وہ پاک ہو جائے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxvii{اور اس پر کسی کا کوئی احسان نہیں کہ جس کا بدلہ دیا جائے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxviii{وہ تو صرف اپنے سب سے برتر رب کی رضا مندی کے لیے دیتا ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxix{اوروہ عنقریب خوش ہو جائے گا\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxx{\basmalahur دن کی روشنی کی قسم ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxi{اور رات کی جب وہ چھا جائے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxii{آپ کے رب نے نہ آپ کو چھوڑا ہے اور نہ بیزار ہوا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxiii{اور البتہ آخرت آپ کے لیے دنیا سے بہتر ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxiv{اور آپ کا رب آپ کو (اتنا) دے گا کہ آپ خوش ہو جائیں گے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxv{کیا اس نے آپ کو یتیم نہیں پایا تھا پھر جگہ دی\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxvi{اور آپ کو (شریعت سے) بے خبر پایا پھر (شریعت کا) راستہ بتایا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxvii{اوراس نے آپ کو تنگدست پایا پھر غنی کر دیا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxviii{پھر یتیم کو دبایا نہ کرو\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxix{اورسائل کو جھڑکا نہ کرو\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxc{اورہر حال میں اپنے رب کے احسان کا ذکر کیا کرو\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxci{\basmalahur کیا ہم نے آپ کا سینہ نہیں کھول دیا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxcii{اور کیا آپ سے آپ کا وہ بوجھ نہیں اتار دیا\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxciii{جس نے آپ کی کمر جھکا دی تھی\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxciv{اور ہم نے آپ کا ذکر بلند کر دیا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxcv{پس بے شک ہر مشکل کے ساتھ آسانی ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxcvi{بے شک ہر مشکل کے ساتھ آسانی ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxcvii{پس جب آپ (تبلیغ احکام سے) فارغ ہوں تو ریاضت کیجئے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxcviii{اور اپنے رب کی طرف دل لگائیے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxcix{\basmalahur انجیر اور زیتون کی قسم ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmc{اور طور سینا کی\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmci{اور اس شہر (مکہ) کی جو امن والا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcii{بے شک ہم نے انسان کو بڑے عمدہ انداز میں پیدا کیا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmciii{پھر ہم نے اسے سب سے نیچے پھینک دیا ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmciv{مگر جو ایمان لائے اور نیک کام کئے سو ان کے لیے تو بے انتہا بدلہ ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcv{پھر اس کے بعد آپ کو قیامت کے معاملہ میں کون جھٹلا سکتا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcvi{کیا الله سب حاکموں سے بڑا حاکم نہیں (ضرور ہے)\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcvii{\basmalahur اپنے رب کے نام سے پڑھیئے جس نے سب کو پیدا کیا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcviii{انسان کو خون بستہ سے پیدا کیا\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcix{پڑھیئے اور آپ کا رب سب سے بڑھ کر کرم والا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcx{جس نے قلم سے سکھایا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxi{انسان کو سکھایا جو وہ نہ جانتا تھا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxii{ہرگز نہیں بے شک آدمی سرکش ہو جاتا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxiii{جب کہ اپنے آپ کو غنی پاتا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxiv{بے شک آپ کے رب ہی کی طرف لوٹ کر جانا ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxv{کیا آپ نے اس کو دیکھا جو منع کرتا ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxvi{ایک بندے کو جب کہ وہ نماز پڑھتا ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxvii{بھلا دیکھو تو سہی اگر وہ راہ پر ہوتا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxviii{یا پرہیز گاری سکھاتا\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxix{بھلا دیکھو تو سہی اگر اس نے جھٹلایا اور منہ موڑ لیا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxx{تو کیا وہ نہیں جانتا کہ الله دیکھ رہا ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxi{ہرگزایسا نہیں چاہیئے اگر وہ باز نہ آیا تو ہم پیشانی کے بال پکڑ کر گھسیٹیں گے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxii{پیشانی جھوٹی خطا کار\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxiii{پس وہ اپنے مجلس والوں کو بلا لے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxiv{ہم بھی مؤکلین دوزخ کو بلا لیں گے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxv{ہر گز ایسا نہیں چاہیئے آپ اس کا کہانہ مانیے اور سجدہ کیجیئے اور قرب حاصل کیجیئے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxvi{\basmalahur بے شک ہم نے اس (قرآن) کو شب قدر میں اتارا ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxvii{اور آپ کو کیا معلوم کہ شب قدر کیا ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxviii{شب قدر ہزار مہینوں سے بہتر ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxix{اس میں فرشتے اور روح نازل ہوتے ہیں اپنے رب کے حکم سے ہر کام پر\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxx{وہ صبح روشن ہونے تک سلامتی کی رات ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxi{\basmalahur اہلِ کتاب میں سے کافر اور مشرک لوگ باز آنے والے نہیں تھے یہاں تک کہ ان کے پاس کھلی دلیل آئے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxii{یعنی ایک رسول الله کی طرف سے آئے جو پاک صحیفے پڑھ کر سنائے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxiii{جن میں درست مضامین لکھے ہوں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxiv{اور اہلِ کتاب نے جو اختلاف کیا تو واضح دلیل آنے کے بعد\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxv{اور انہیں صرف یہی حکم دیا گیا تھا کہ الله کی عبادت کریں ایک رخ ہو کر خالص اسی کی اطاعت کی نیت سے اورنماز قائم کریں اور زکواة دیں اور یہی محکم دین ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxvi{بے شک جو لوگ اہلِ کتاب میں سے منکر ہوئے اور مشرکین وہ دوزخ کی آگ میں ہوں گے اس میں ہمیشہ رہیں گے یہی لوگ بدترین مخلوقات ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxvii{بے شک جولوگ ایمان لائے اورنیک کام کیے یہی لوگ بہترین مخلوقات ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxviii{ان کا بدلہ ان کے رب کے ہاں ہمیشہ رہنے کے بہشت ہیں ان کے نیچے نہریں بہتی ہوں گی وہ ان میں ہمیشہ ہمیشہ رہیں گے الله ان سے راضی ہوا اور وہ اس سے راضی ہوئے یہ اس کے لئےہے جو اپنے رب سے ڈرتا ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxix{\basmalahur جب زمین بڑے زور سے ہلا دی جائے گی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxl{اور زمین اپنے بوجھ نکال پھینکے گی\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxli{اور انسان کہے گا کہ اس کو کیا ہوگیا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxlii{اس دن وہ اپنی خبریں بیا ن کرے گی\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxliii{اس لئے کہ آپ کا رب اس کو حکم دے گا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxliv{اس دن لوگ مختلف حالتوں میں لوٹیں گے تاکہ انہیں ان کے اعمال دکھائے جائیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxlv{پھر جس نے ذرہ بھر نیکی کی ہے وہ اس کو دیکھ لے گا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxlvi{اورجس نے ذرہ بھر برائی کی ہے وہ اس کو دیکھ لے گا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxlvii{\basmalahur ان گھوڑوں کی قسم جو ہانپتے ہوئے دوڑتے ہیں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxlviii{پھر (پتھر پر) ٹاپ مار کر آگ جھاڑتے ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxlix{پھر صبح کے وقت دھاوا کرتے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcl{پھر اس وقت غبار اُڑاتے ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcli{پھر اس وقت دشمنوں کی جماعت میں جا گھستے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclii{بے شک انسان اپنے رب کا بڑا ناشکرا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcliii{اوربے شک وہ اس بات پر خود شاہد ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcliv{اوربے شک وہ مال کی محبت میں بڑا سخت ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclv{پس کیا وہ نہیں جانتا جب اکھاڑا جائے گا جو کچھ قبروں میں ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclvi{اورجو دلوں میں ہے وہ ظاہر کیا جائے گا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclvii{بے شک ان کا رب ان سے اس دن خوب خبردار ہو گا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclviii{\basmalahur کھڑکھڑانے والی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclix{وہ کھڑکھڑانے والی کیا ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclx{اور آپ کو کیا خبر کہ وہ کھڑکھڑانے والی کیا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxi{جس دن لو گ بکھرے ہوئے پروانوں کی طرح ہوں گے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxii{اور پہاڑ رنگی ہوئی دھنی ہوئی اُون کی طرح ہوں گے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxiii{تو جس کے اعمال (نیک) تول میں زیادہ ہوں گے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxiv{تو وہ خاطر خواہ عیش میں ہوگا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxv{اور جس کے اعمال (نیک) تول میں کم ہوں گے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxvi{تواس کا ٹھکانا ہاویہ ہوگا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxvii{اور آپ کو کیا معلوم کہ وہ کیا چیز ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxviii{وہ دھکتی ہوئی آگ ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxix{\basmalahur تمہیں حرص نے غافل کر دیا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxx{یہاں تک کہ قبریں جا دیکھیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxi{ایسا نہیں آئندہ تم جان لو گے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxii{پھر ایسا نہیں چاہیئے آئندہ تم جان لو گے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxiii{ایسا نہیں چاہیئے کاش تم یقینی طور پر جانتے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxiv{البتہ تم ضرور دوزخ کو دیکھو گے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxv{پھر تم اسے ضرور بالکل یقینی طور پر دیکھو گے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxvi{پھر اس دن تم سے نعمتوں کے متعلق پوچھا جائے گا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxvii{\basmalahur زمانہ کی قسم ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxviii{بے شک انسان گھاٹے میں ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxix{مگر جو لوگ ایمان لائے اور نیک کام کیے اور حق پر قائم رہنے کی اور صبر کرنے کی آپس میں وصیت کرتے رہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxx{\basmalahur ہر غیبت کرنے والے طعنہ دینے والے کے لیے ہلاکت ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxi{جو مال کو جمع کرتا ہے اور اسے گنتا رہتا ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxii{وہ خیال کرتا ہے کہ اس کا مال اسے سدا رکھے گا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxiii{ہرگز نہیں وہ ضرور حطمہ میں پھینکا جائے گا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxiv{اور آپ کو کیا معلوم حطمہ کیا ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxv{وہ الله کی بھڑکائی ہوئی آگ ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxvi{جو دلوں تک جا پہنچتی ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxvii{بے شک وہ ان پر چاروں طرف سے بند کر دی جائے گی\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxviii{لمبے لمبے ستونوں میں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxix{\basmalahur کیا آپ نے نہیں دیکھا کہ آپ کے رب نے ہاتھی والوں سے کیا برتاؤ کیا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxc{کیا اس نے ان کی تدبیر کوبے کار نہیں بنا دیا تھا\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxci{اور اس نے ان پر غول کے غول پرندے بھیجے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxcii{جہاں پر پتھر کنکر کی قسم کے پھینکتے تھے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxciii{پھر انہیں کھائے ہوئے بھس کی طرح کر ڈالا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxciv{\basmalahur اس لیے کہ قریش کو مانوس کر دیا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxcv{ان کو جاڑے اور گرمی کے سفر سے مانوس کرنے کے باعث\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxcvi{ان کو اس گھرکے مالک کی عبادت کرنی چاہیئے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxcvii{جس نے ان کو بھوک میں کھلایا اور ان کو خوف سے امن دیا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxcviii{\basmalahur کیا آپ نے اس کو دیکھا جو روزِ جرا کو جھٹلاتا ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxcix{پس وہ وہی ہے جو یتیم کو دھکے دیتا ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcc{اور مسکین کو کھانا کھلانے کی ترغیب نہیں دیتا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcci{پس ان نمازیوں کے لیے ہلاکت ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccii{جو اپنی نماز سے غافل ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcciii{جو دکھلاوا کرتے ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcciv{اور برتنے کی چیز تک روکتے ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccv{\basmalahur بے شک ہم نے آپ کو کوثر دی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccvi{پس اپنے رب کے لیے نماز پڑھیئے اور قربانی کیجیئے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccvii{بے شک آپ کا دشمن ہی بے نام و نشان ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccviii{\basmalahur کہہ دو اے کافرو\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccix{نہ تومیں تمہارے معبودوں کی عبادت کرتا ہوں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccx{اور نہ تم ہی میرے معبود کی عبادت کرتے ہو\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxi{اور نہ میں تمہارے معبودوں کی عبادت کروں گا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxii{اور نہ تم میرے معبود کی عبادت کرو گے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxiii{تمہارے لیے تمہارا دین ہے اور میرے لیے میرا دین\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxiv{\basmalahur جب الله کی مدد اور فتح آ چکی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxv{اورآپ نے لوگوں کو الله کے دین میں جوق در جوق داخل ہوتے دیکھ لیا\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxvi{تو اپنے رب کی حمد کے ساتھ تسبیح کیجیئے اور اس سے معافی مانگیئے بےشک وہ بڑا توبہ قبول کرنے والا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxvii{\basmalahur ابو لہب کے دونوں ہاتھ ٹوٹ گئے اوروہ ہلاک ہو گیا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxviii{اس کا مال اورجو کچھ اس نے کمایا اس کے کام نہ آیا\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxix{وہ بھڑکتی ہوئی آگ میں پڑے گا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxx{اور اس کی عورت بھی جو ایندھن اٹھائے پھرتی تھی\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxi{اس کی گردن میں موُنج کی رسیّ ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxii{\basmalahur کہہ دووہ الله ایک ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxiii{اللہ بے نیاز ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxiv{نہ اس کی کوئی اولاد ہے اور نہ وہ کسی کی اولاد ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxv{اور اس کے برابر کا کوئی نہیں ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxvi{\basmalahur کہہ دو صبح کے پیدا کرنے والے کی پناہ مانگتا ہوں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxvii{اس کی مخلوقات کے شر سے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxviii{اور اندھیری رات کے شر سے جب وہ چھا جائے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxix{اورگرہوں میں پھونکنے والیوں کے شر سے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxx{اور حسد کرنے والے کے شر سے جب وہ حسد کرے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxxi{\basmalahur کہہ دو میں لوگوں کے رب کی پناہ میں آیا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxxii{لوگوں کے بادشاہ کی\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxxiii{لوگوں کے معبود کی\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxxiv{اس شیطان کے شر سے جووسوسہ ڈال کر چھپ جاتا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxxv{جو لوگوں کے سینوں میں وسوسہ ڈالتا ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxxvi{جنوں اور انسانوں میں سے\qt@no{(6)}}%
%% End of file `qurantext-uri.translation.def'.
