\qt@newcmd\qurantrans@bn@i{আল্লাহর নাম নিয়ে (আরম্ভ করছি), (যিনি) রহমান (--পরম করুণাময়, যিনি অসীম করুণা ও দয়া বশতঃ বিশ্বজগতের সমস্ত সৃষ্টির সহাবস্থানের প্রয়োজনীয় সব ব্যবস্থা অগ্রিম করে রেখেছেন), (যিনি) রহীম (--অফুরন্ত ফলদাতা, যাঁর অপার করুণা ও দয়ার ফলে প্রত্যেকের ক্ষুদ্রতম শুভ-প্রচেষ্টাও বিপুলভাবে সাফল্যমণ্ডিত ও পুরস্কৃত হয়ে থাকে)।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@ii{সমস্ত প্রশংসা আল্লাহ্‌র প্রাপ্য, সমুদয় সৃষ্ট-জগতের রব্ব।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@iii{রহমান, রহীম।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@iv{বিচারকালের মালিক।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@v{“তোমারই আমরা এবাদত করি, এবং তোমারই কাছে আমরা সাহায্য প্রার্থনা করি।”\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@vi{“আমাদের তুমি সহজ-সঠিক পথে পরিচালিত করো, --”\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@vii{“তাদের পথে যাদের প্রতি তুমি নিয়ামত অর্পণ করেছ, তাদের ব্যতীত যাদের প্রতি গযব এসেছে, এবং তাদেরও নয় যারা পথভ্রষ্ট।”\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@viii{\basmalahbn আলিফ, লাম, মীম।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@ix{ঐ গ্রন্থ, এতে কোনো সন্দেহ নেই, মুত্তকীদের জন্য পথপ্রদর্শক --\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@x{যারা গায়েবে ঈমান আনে, আর নামায কায়েম করে, আর আমরা যে রিযেক তাদের দিয়েছি তা থেকে তারা খরচ করে থাকে।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@xi{আর তোমার কাছে যা-কিছু অবতীর্ণ হয়েছে তা’তে যারা ঈমান আনে, আর তোমার পূর্ববর্তীদের কাছে যা অবতীর্ণ হয়েছে তাতেও, আর আখেরাত সন্বন্ধে যারা দৃঢ়বিশ্বাস রাখে।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@xii{এরাই আছে তাদের প্রভুর তরফ থেকে হেদায়তের উপরে, আর এরা নিজেরাই হচ্ছে সফলকাম।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@xiii{অবশ্যই যারা অবিশ্বাস পোষণ করে, তাদের তুমি সতর্ক কর বা তাদের সতর্ক নাই কর তাদের কাছে সবই সমান, ওরা ঈমান আনবে না।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@xiv{আল্লাহ্ তাদের হৃদয়ে সীল মেরে দিয়েছেন, এবং তাদের কানেও, আর তাদের চোখের উপরে পর্দা। আর তাদের জন্য আছে কঠোর শাস্তি।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@xv{আর মানুষের মাঝে কেউ-কেউ বলে থাকে -- “আমরা আল্লাহ্‌র প্রতি এবং আখেরাতের প্রতি ঈমান এনেছি”, অথচ তারা মুমিনদের মধ্যে নয়।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@xvi{এরা চায় আল্লাহ্ ও যারা ঈমান এনেছে তারা যেন প্রতারিত হন। কিন্তু তারা প্রতারণা করছে নিজেদের ছাড়া আর কাউকে নয়, অথচ তারা বুঝতে পারছে না।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@xvii{তাদের অন্তরে ব্যারাম, তাই আল্লাহ্ তাদের জন্য ব্যারাম বাড়িয়ে দিয়েছেন, আর তাদের জন্য ব্যথাদায়ক শাস্তি, যেহেতু তারা মিথ্যা বলে চলেছে।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@xviii{আর যখন তাদের বলা হলো -- “দুনিয়াতে তোমরা গন্ডগোল সৃষ্টি কর না”, তারা বলে -- “না তো, আমরা শান্তিকামী।”\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@xix{তারা নিজেরাই কি নিশ্চয়ই গন্ডগোল সৃষ্টিকারী নয়? কিন্তু তারা বোঝে না।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@xx{আর যখন তাদের বলা হলো -- “তোমরাও ঈমান আনো যেমন লোকেরা ঈমান এনেছে”, তারা বললে -- “আমরা কি বিশ্বাস করব যেমন মূর্খরা বিশ্বাস করছে?” তারা নিজেরাই কি নিঃসন্দেহে মূর্খ নয়? কিন্তু তারা জানে না।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@xxi{আর যারা ঈমান এনেছে তাদের সাথে তারা যখন মিলিত হয় তখন বলে -- “আমরা ঈমান এনেছি” । আবার যখন তারা তাদের শয়তানদের সঙ্গে নিরিবিলি হয় তখন বলে -- “আমরা নিশ্চয়ই তোমাদের সাথে, আমরা শুধু মস্করা করছিলাম।”\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@xxii{আল্লাহ্ তাদের প্রতি মস্করা ঘুরিয়ে পাঠান, এবং তাদের অন্যায় ক্রিয়া-কলাপের মধ্যে ঘুরপাক খেতে তাদের ছেড়ে দেন।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@xxiii{এরাই তারা যারা পথনির্দেশের বদলে পথভ্রষ্টতার কেনাকাটা করে, তাই তাদের ব্যবসা মুনাফা আনে না, আর তারা সৎপথপ্রাপ্ত হয় না।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@xxiv{তাদের উপমা একজনের উদাহরণের মতো যিনি প্রদীপ জ্বালালেন, কিন্তু যখন এর চার পাশের সব-কিছু এ আলোকিত করল তখন আল্লাহ্ তাদের দীপ্তি নিয়ে নিলেন ও তাদের ফেলে রাখলেন ঘোর অন্ধকারে, তাই তারা পথঘাট দেখতে পায় না।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@xxv{কালা, বোবা, অন্ধত্ব, গতিকে তারা ফিরতে পারে না।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@xxvi{অথবা আকাশ থেকে আসা ঝড় বৃষ্টির মতো -- তার মাঝে আছে গাঢ় অন্ধকার এবং বজ্রপাত ও বিদ্যুতের ঝলকানি। তারা তাদের গোটা আঙ্গুলগুলো চেপে ধরে তাদের কানের ভেতরে বজ্রের শব্দে মরার ভয়ে। কিন্তু আল্লাহ্ অবিশ্বাসীদের ঘিরে ফেলেন।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@xxvii{বিদ্যুতের ঝলকানি তাদের দৃষ্টি প্রায় ছিনিয়ে নিচ্ছিল। যতবার এ তাদের জন্য ঝিলিক দেয়, তারা এর মধ্যে হেটে চলে, আর যখনি তাদের উপরে অন্ধকার নেমে আসে, তারা দাঁড়িয়ে পড়ে। অথচ আল্লাহ্ যদি ইচ্ছা করতেন তিনি নিশ্চয়ই তাদের শ্রবণশক্তি ও তাদের দৃষ্টিশক্তি নিয়ে নিতে পারতেন। নিশ্চয়ই আল্লাহ্ সব-কিছুতে সর্বশক্তিমান।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@xxviii{ওহে মানবজাতি! তোমাদের প্রভুর উপাসনা করো, যিনি তোমাদের সৃষ্টি করেছেন এবং তোমাদের পূর্ববর্তীদেরও, যাতে তোমরা ধর্মপরায়ণতা অবলন্বন করো।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@xxix{যিনি তোমাদের জন্য পৃথিবীকে ফরাশ বানিয়েছেন, আর আকাশকে চাঁদোয়া, আর তিনি আকাশ থেকে পাঠান বৃষ্টি, তা’ দিয়ে তারপর ফলফসল উৎপাদন করেন তোমাদের জন্য রিযেক হিসেবে। অতএব আল্লাহ্‌র সাথে প্রতিদ্বন্ধী খাড়া করো না, অধিকন্তু তোমরা জানো।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@xxx{আর যদি তোমরা সন্দেহের মাঝে থাকো এর সন্বন্ধে যা আমাদের বান্দার কাছে অবতারণ করেছি তা হলে এর মতো একটিমাত্র সূরা নিয়ে এস এবং আল্লাহ্ ছাড়া তোমাদের সাহায্যকারীদের ডাকো, যদি তোমরা সত্যবাদী হয়ে থাকো।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@xxxi{কিন্তু যদি তোমরা না করো -- আর তোমরা কখনো পারবে না -- তাহলে আগুনকে ভয় কর যার জ্বালানি হচ্ছে মানুষ এবং পাথরগুলো, -- তৈরি হয়েছে অবিশ্বাসীদের জন্য।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@xxxii{আর খুশখবর দাও তাদের যারা ঈমান এনেছে আর সৎকর্ম করে, তাদের জন্য আছে জান্নাত, যাদের নিচ দিয়ে বয়ে চলেছে ঝরনারাজি! যতবার এ থেকে ফলফসল তাদের খেতে দেয়া হয় তারা বলে -- “এ সেই যা এর আগে আমাদের খাওয়ানো হয়েছিল”, কারণ তাদের এ দেয়া হয় অনুকরণে। আর তাদের জন্য এর মধ্যে আছে পবিত্র সঙ্গিসাথী আর এতে তারা থাকবে চিরকাল।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@xxxiii{অবশ্যই আল্লাহ্ উপমা ছুড়ঁতে লজ্জিত হন না, যথা মশার অথবা তার চাইতে উপরের কিছুর। সুতরাং যারা ঈমান এনেছে তারা জানে যে এ নিশ্চয়ই তাদের প্রভুর কাছ থেকে সত্য। আর যারা অবিশ্বাস পোষণ করে তারা বলে -- “আল্লাহ্ এমন একটি উপমাদ্বারা কী চান?” এর দ্বারা তিনি অনেককে বিপথে চলতে দেন এবং অনেককে এর সাহায্যে সৎপথগামী করেন। তিনি কিন্তু ভ্রষ্টাচারী ভিন্ন কাউকেও এর মাধ্যমে বিপথে চলতে দেন না।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@xxxiv{যারা আল্লাহ্‌র চুক্তি ভঙ্গ করে এর সুদৃঢ়ীকরণ হবার পরেও, আর কেটে দেয় যা এর দ্বারা বহাল রাখার জন্য আল্লাহ্ আদেশ করেছিলেন, আর পৃথিবীতে ফসাদ সৃষ্টি করে। তারা নিজেরাই ক্ষতিগ্রস্ত হয়।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@xxxv{তোমরা কেমন করে আল্লাহ্‌র প্রতি অবিশ্বাস পোষণ করো যেহেতু তোমরা নিস্প্রাণ ছিলে, তখন তোমাদের তিনি জীবন দান করেছেন? তারপর তিনি তোমাদের মৃত্যু ঘটাবেন ও আবার তোমাদের পুনর্জীবিত করবেন, তখন তাঁরই দরবারে তোমাদের ফিরিয়ে নেয়া হবে।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@xxxvi{তিনিই সেইজন যিনি ঘূর্ণায়মান-পৃথিবীতে যা-কিছু আছে সবই তোমাদের জন্য সৃষ্টি করেছেন, তাছাড়া তিনি মহাকাশের প্রতি খেয়াল করলেন, তাই তাদের তিনি সাত আসমানে পরিপূর্ণ করলেন। আর তিনি সব-কিছু সন্বন্ধে সর্বজ্ঞাতা।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@xxxvii{আর স্মরণ কর, -- তোমার প্রভু ফিরিশ্‌তাদের বললেন, “আমি অবশ্যই পৃথিবীতে খলিফা বসাতে যাচ্ছি।” তারা বলল -- “তুমি কি উহাতে এমন কাউকে বসাচ্ছ যে তার মধ্যে ফসাদ সৃষ্টি করবে ও রক্তপাত করবে, অথচ আমরা তোমার স্তুতির গুণগান করছি ও তোমারই পবিত্রতার জয়গান গাইছি।” তিনি বললেন -- “আমি নিঃসন্দেহে তা জানি যা তোমরা জানো না।”\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@xxxviii{তখন তিনি আদমকে নামাবলী -- তাদের সব-কিছু শিখিয়ে দিলেন, তারপর তিনি ফিরিশ্‌তাদের কাছে তাদের স্থাপন করলেন ও বললেন, -- “আমাকে এই সমস্তের নামাবলী বর্ণনা কর, যদি তোমরা সঠিক হয়ে থাকো।”\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@xxxix{তারা বলল -- “তোমারই সব মহিমা! আমাদের যা শিখিয়েছ তা ছাড়া আমাদের জ্ঞান নেই! নিঃসন্দেহ তুমি নিজেই সর্বজ্ঞাতা, পরমজ্ঞানী।”\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@xl{তিনি বললেন -- “হে আদম! এ-সবের নামাবলী এদের কাছে বর্ণনা কর।” তাই সে যখন তাদের কাছে এ-সবের নামাবলী বর্ণনা করল, তিনি বললেন -- “আমি কি তোমাদের বলি নি যে আমি নিশ্চয়ই মহাকাশমন্ডলী ও পৃথিবীর রহস্যসব জানি? আর আমি জানি যা তোমরা প্রকাশ করেছ, আর যা তোমরা লুকিয়ে রেখে চলেছ।”\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@xli{আর স্মরণ করো! আমরা ফিরিশ্‌তাদের বললাম -- “আদমের প্রতি সিজদা করো।” সুতরাং তারা সিজদা করল, কিন্তু ইবলিস করলনা, কারণ সে ছিল কাফিরদের অন্তর্ভুক্ত।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@xlii{আর আমরা বললাম, -- “হে আদম! তুমি ও তোমার সঙ্গিনী এই বাগানে অবস্থান কর, আর সেখান থেকে যখন-যেখানে ইচ্ছা কর ভরপুরভাবে পানাহার কর, কিন্তু এই বৃক্ষের ধারেকাছেও যেও না, নতুবা তোমরা দুরাচারদের অন্তর্ভুক্ত হয়ে যাবে।”\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@xliii{কিন্তু শয়তান তাদের সেখান থেকে পদস্খলিত করল, আর যেখানে তারা থাকত সেখান থেকে তাদের বের করে দিল। তখন আমরা বললাম -- “তোমরা অধঃপাতে যাও, তোমাদের কেউ কেউ একে অন্যের শত্রু। আর তোমাদের জন্য পৃথিবীতে আছে জিরানোর স্থান ও কিছু সময়ের সংস্থান।”\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@xliv{তখন আদম তার প্রভুর কাছ থেকে কিছু কথা শিখে নিলে, তাই তিনি তার দিকে ফিরলেন। নিঃসন্দেহ তিনি নিজেই সদা ফেরেন, অফুরন্ত ফলদাতা।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@xlv{আমরা বললাম -- “তোমরা সব্বাই মিলে এখান থেকে নেমে পড়ো। কিন্তু যদি তোমাদের কাছে আমার তরফ থেকে হেদায়ত আসে, তবে যারা আমার পথনির্দেশ মেনে চলবে তাদের উপর কিন্তু কোনো ভয় নেই, আর তারা নিজেরা অনুতাপও করবে না।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@xlvi{“কিন্তু যারা অবিশ্বাস পোষণ করে ও আমাদের আয়াতসমূহে মিথ্যারোপ করে, তারাই হচ্ছে আগুনের বাসিন্দা, তারা তার মধ্যে থাকবে দীর্ঘকাল।”\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@xlvii{হে ইসরাইলের বংশধরগণ! আমার নিয়ামত স্মরণ করো, যা আমি তোমাদের প্রদান করেছিলাম, আর আমার সাথের চুক্তি তোমরা বহাল রাখো, আমিও তোমাদের সাথের চুক্তি বহাল রাখব। আর আমাকে, শুধু আমাকে, তোমরা ভয় করবে।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@xlviii{আর আমি যা অবতারণ করেছি তাতে তোমরা ঈমান আনো, -- তোমাদের কাছে যা রয়েছে তার সত্য-সমর্থনরূপে, এমতাবস্থায় তোমরা এতে অবিশ্বাসকারীদের পুরোভাগে থেকো না, আর আমার প্রত্যাদেশের বিনিময়ে তুচ্ছ বস্তু কামাতে যেও না, আর আমাকে, শুধু আমাকে, তোমরা ভয়-শ্রদ্ধা করবে।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@xlix{আর সত্যকে তোমরা মিথ্যার পোশাক পরিয়ো না বা সত্যকে গোপন কর না, অথচ তোমরা জানো।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@l{আর তোমরা নামায কায়েম করো ও যাকাত আদায় করো, আর রুকুকারীদের সাথে রুকু করো।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@li{তোমরা কি লোকজনকে ধার্মিকতা করতে আদেশ কর আর নিজের বেলায় স্রেফ ভুলে যাও, অথচ তোমরা ধর্মগ্রন্থ পড়ে থাক? তোমাদের কি কান্ডজ্ঞান নেই?\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@lii{আর তোমরা ধৈর্য ধরে ও নামায পড়ে সাহায্য কামনা করো। আর এটি নিশ্চয়ই বড় কঠিন, শুধু বিনয়ীদের ছাড়া, --\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@liii{যারা স্মরণ রাখে যে তারা নিশ্চয়ই তাদের প্রভুর সাথে মোলাকাত করতে যাচ্ছে, আর তারা অবশ্যই তাঁর কাছে প্রত্যাবর্তনকারী।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@liv{হে ইসরাইলের বংশধরগণ! আমার নিয়ামত স্মরণ করো যা আমি তোমাদের প্রদান করেছিলাম ও কিভাবে মানবগোষ্ঠীর উপর তোমাদের মর্যাদা দিয়েছিলাম।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@lv{আর সতর্কতা অবলন্বন করো এমন এক দিনের একজন অন্যজনের কাছ থেকে কোনো প্রকার সাহায্য পাবে না, আর তার থেকে কোনো সুপারিশ কবুল করা হবে না বা তার থেকে কোনো খেসারতও নেওয়া হবে না, আর তাদের সাহায্য দেয়া হবে না।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@lvi{আর স্মরণ করো! তোমাদের আমরা ফিরআউনের লোকদের থেকে মুক্ত করেছিলাম, যারা তোমাদের নির্যাতন করেছিল কঠোর যন্ত্রণায়, তারা হত্যা করত তোমাদের পুত্র সন্তানদের ও বাঁচতে দিত তোমাদের নারীদের। আর এতে তোমাদের জন্যে তোমাদের প্রভুর কাছ থেকে ছিল কঠোর পরীক্ষা।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@lvii{আর স্মরণ করো! আমরা তোমাদের জন্যে সাগরকে করেছিলাম বিভক্ত, তাতে উদ্ধার করেছিলাম তোমাদের, আর আমরা ডুবিয়েছিলাম ফিরআউনের লোকদের, আর তোমরা চেয়ে দেখেছিলে।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@lviii{আর স্মরণ করো! আমরা মূসার সঙ্গে চল্লিশ রাত্রি নির্ধারিত করেছিলাম, তখন তোমরা বাছুরকে তাঁর অনুপস্থিতিতে গ্রহণ করলে, আর তোমরা হলে অন্যায়কারী।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@lix{শেষে এর পরেও আমরা তোমাদের ক্ষমা করেছিলাম যাতে তোমরা কৃতজ্ঞতা জ্ঞাপন কর।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@lx{আর স্মরণ করো! আমরা মূসাকে দিয়েছিলাম ধর্মগ্রন্থ তথা ফুরকান যাতে তোমরা সুপথগামী হতে পার।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@lxi{আর স্মরণ করো! মূসা তাঁর লোকদের বলেছিলেন, -- “হে আমার অনুচরবর্গ, তোমরা নিশ্চয়ই তোমাদের প্রতি অন্যায় করেছ বাছুরকে গ্রহণ ক’রে, অতএব তোমাদের সৃষ্টিকর্তার দিকে ফেরো ও নিজেদের সংহার করো। ইহা তোমাদের সৃষ্টিকর্তার সমীপে তোমাদের জন্য মঙ্গলময়।” তাই তিনি তোমাদের দিকে ফিরলেন। নিঃসন্দেহ তিনি নিজেই সদা ফেরেন, অফুরন্ত ফলদাতা।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@lxii{আর স্মরণ করো! তোমরা বললে -- “হে মূসা, আমরা তোমার প্রতি কখনো ঈমান আনব না যে পর্যন্ত না আমরা প্রকাশ্যভাবে আল্লাহ্‌কে দেখতে পাই।” তাই বজ্রাঘাত তোমাদের পাকড়ালো, আর তোমরা তাকিয়ে থাকলে।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@lxiii{তারপর তোমাদের জাগিয়ে তুললাম তোমাদের মৃতবৎ হবার পরে, যাতে তোমরা কৃতজ্ঞতা জ্ঞাপন করতে পার।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@lxiv{আর তোমাদের উপরে আমরা মেঘ দিয়ে আচ্ছাদন করেছিলাম, আর তোমাদের কাছে পাঠিয়েছিলাম 'মান্না’ ও 'সালওয়া’। “তোমাদের যে-সব ভাল ভাল রিযেক দিয়েছি তা খেয়ে যাও।” কিন্তু তারা আমাদের কোনো অনিষ্ট করে নি, বরং তারা নিজেদেরই প্রতি অনিষ্ট করছিল।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@lxv{আর স্মরণ করো! আমরা বললাম -- “এই শহরে প্রবেশ কর, আর সেখান থেকে যখন-যেখানে ইচ্ছা কর ভরপুরভাবে পানাহার করো, আর সদর-দরজা দিয়ে নতশিরে প্রবেশ করো ও বলো 'হিৎতাতুন’, যাতে তোমাদের দোষত্রুটিগুলো আমরা তোমাদের জন্য ক্ষমা করে দিতে পারি, আর বাড়িয়ে দিতে পারি শুভকর্মীদের জন্য।”\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@lxvi{কিন্তু যারা অন্যায় করে তারা যা বলা হয়েছিল তার বিপরীত কথায় তা বদলে দিল। তাই যারা অন্যায় করেছিল তাদের উপরে আকাশ থেকে আমরা মহামারী পাঠিয়েছিলাম, কারণ তারা পাপাচার করছিল।\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@lxvii{আর স্মরণ করো! মূসা তাঁর লোকদের জন্য পানি চাইলেন, তাই আমরা বললাম, -- “তোমার লাঠি দিয়ে পাথরে আঘাত করো।” তখন তা থেকে বারোটি প্রস্রবন বেরিয়ে পড়লো। প্রত্যেক উপদল নিজ জলপান-স্থান চিনে নিলো। “আল্লাহ্‌র রিযেক থেকে খাও ও পান করো, আর ফসাদী হয়ে দুনিয়াতে অন্যায়াচরণ করো না।”\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@lxviii{আর স্মরণ করো! তোমরা বলেছিলে -- “হে মূসা! আমরা একই খাবারে সন্তষ্ট থাকতে পারছি না, তাই তোমার প্রভুর কাছে আমাদের জন্য প্রার্থনা করো যাতে তিনি আমাদের জন্য উৎপন্ন করেন মাটি যা উৎপাদিত করে, যেমন তার সবজি ও তার শস্য ও তার মসূর ও তার পেয়াঁজ।” তিনি বললেন -- “তোমরা কি বদল করে নিতে চাও যা নিকৃষ্ট তার সঙ্গে যা উৎকৃষ্ট? নেমে যাও কোনো মিশরে, তাহলে তোমরা যা চাও তাই পাবে।” আর ওরা নিজেদের উপরে লাঞ্ছনা ও দুর্দশা ঘটালো, আর তারা আল্লাহ্‌র রোষ টেনে আনল তাই হলো, কারণ তারা আল্লাহ্‌র আয়াতসমূহে অবিশ্বাস করছিল, আর নবীদের অন্যায়ভাবে হত্যা করতে যাচ্ছিল। তাই হলো, কেননা তারা অবাধ্য হয়েছিল ও সীমালঙ্ঘন করেছিল।\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@lxix{নিঃসন্দেহ যারা ঈমান এনেছে, আর যারা ইহুদীয় মত পোষণ করে ও খ্রীস্টান ও সাবেঈন -- যারাই আল্লাহ্‌র প্রতি তাঁর একত্বে ও আনুগত্যে ঈমান এনেছে ও আখেরাতের দিনের প্রতি, আর সৎকর্ম করে, তাদের জন্য নিজ নিজ পুরস্কার রয়েছে তাদের প্রভুর দরবারে, আর তাদের উপরে কোনো ভয় নেই, আর তারা নিজেরা অনুতাপও করবে না।\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@lxx{আর স্মরণ করো! আমরা তোমাদের অঙ্গীকার গ্রহণ করেছিলাম ও তোমাদের উপরে পর্বত উত্তোলন করেছিলাম। “তোমাদের আমরা যা দিয়েছি তা দৃঢ়ভাবে গ্রহণ করো, আর এতে যা আছে তা স্মরণ রাখো, যাতে তোমরা ধর্মপরায়ণতা অবলন্বন করতে পার।”\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@lxxi{তারপর তোমরা এর পরেও ফিরে গেলে, কাজেই আল্লাহ্‌র প্রসন্নতা ও তাঁর করুণা যদি তোমাদের উপরে না থাকত তবে তোমরা অবশ্যই হতে ক্ষতিগ্রস্তদের অন্তর্ভুক্ত।\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@lxxii{তদুপরি তোমাদের মধ্যে যারা সাব্বাথের নিয়ম লঙঘন করেছিল তাদের কথা নিশ্চয়ই জানা আছে, তাই আমরা তাদের বলেছিলাম -- “তোমরা ঘৃণ্য বানর হয়ে যাও।”\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@lxxiii{এইভাবে আমরা এটিকে একটি দৃষ্টান্ত বানিয়েছিলাম যারা ওদের সমসাময়িক ছিল তাদের জন্য ও যারা ওদের পরবর্তীকালে এসেছিল, আর ধর্মভীরুদের জন্য উপদেশ বিশেষ।\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@lxxiv{আর স্মরণ করো! মূসা তাঁর লোকদের বললেন -- “নিঃসন্দেহ, আল্লাহ্ তোমাদের হুকুম করেছেন তোমরা যেন একটি বক্‌না-বাছুর যবেহ্ করো।” তারা বললে -- “তুমি কি আমাদের নিয়ে ঠাট্টা করছ?” তিনি বললেন -- “আল্লাহ্‌র কাছে আশ্রয় চাইছি যেন আমি জাহিলদের অন্তর্ভুক্ত না হই।”\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@lxxv{তারা বললো -- “তোমার প্রভুর কাছে আমাদের জন্য প্রার্থনা করো যেন তিনি আমাদের পরিস্কার করে দেন সেটি কি রকমের।” তিনি বললেন -- “নিঃসন্দেহ তিনি বলেছেন, সেটি অবশ্যই একটি বক্‌না-বাছুর যেটি বুড়ো নয় ও বাচ্চাও নয়, এদের মাঝামাঝি মধ্য-বয়সী। অতএব তোমাদের যা আদেশ দেয়া হয়েছে তাই করো।”\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@lxxvi{তারা বললো -- “আমাদের জন্য তোমার প্রভুর কাছে প্রার্থনা করো তিনি আমাদের খোলাখুলি বলে দিন তার রঙ কেমন।” তিনি বললেন -- “তিনি অবশ্যই বলেছেন, সেটি নিঃসন্দেহ হলুদ রঙের বাছুর, তার রঙ অতি উজ্জ্বল -- দর্শকদের কাছে মনোরম।”\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@lxxvii{তারা বললে -- “তোমার প্রভুর কাছে আমাদের জন্য প্রার্থনা করো আমাদের তিনি স্পষ্ট জানিয়ে দিন সেটি কেমন, কারণ সব বাছুর আমাদের কাছে একাকার লাগে, আর আল্লাহ্ যদি ইচ্ছা করেন, আমরা নিশ্চয় ঠিক পথে চালিত হব।”\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@lxxviii{তিনি বললেন, “নিঃসন্দেহ তিনি বলছেন, সেটি নিশ্চয়ই এমন বাছুর যাকে জোয়ালে জোতা হয় নি জমি চাষ করতে, বা ক্ষেতে পানিও দেয় না, সহি-সালামত, যার মধ্যে কোন খুতঁ নেই।” তারা বললে -- “এবার তুমি পুরোপুরি সত্য নিয়ে এসেছো।” সুতরাং তারা তাকে কুরবানি করল, আর দেখালো না যে তারা করল।\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@lxxix{আর স্মরণ করো! তোমরা একজনকে কাতল করতে যাচ্ছিলে, তারপর তোমরা এ ব্যাপারে দোষাদোষি করছিলে। আর আল্লাহ্ প্রকাশ করছিলেন যা তোমরা লুকোতে চাইছিলে।\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@lxxx{সুতরাং আমরা বললাম -- “তুলনা করো তাঁকে এর কিছু অংশের সাথে।” এইভাবে আল্লাহ্ মৃতবৎকে জীবন দান করেন। আর তিনি তোমাদের দেখাচ্ছেন তাঁর নিদর্শন সমূহ যাতে তোমরা বুঝতে পার।\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@lxxxi{তারপর তোমাদের হৃদয় এর পরেও কঠিন হলো, পাথরের মতো হয়ে গেল, বরং আরও কঠিন। আর অবশ্য পাথরের মধ্যে এমনও আছে যার মধ্য থেকে বেরিয়ে আসে ঝরনা। আবার তাদের কিছু যখন চৌচির হয় তখন তা থেকে পানি বেরোয়। আবার তাদের মধ্যে কতক আল্লাহ্‌র ভয়ে ভেঙ্গে পড়ে। আর তোমরা যা করছো আল্লাহ্ সে বিষয়ে অজ্ঞাত নন।\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@lxxxii{এরপর কি তোমরা আশা কর যে তারা তোমাদের প্রতি বিশ্বাস করবে? ইতিপূর্বে তাদের একটি দল আল্লাহ্‌র বাণী শুনত, তারপর তা পাল্টে দিত উহা বুঝবার পরেও, আর তারা জানে।\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@lxxxiii{আর যারা ঈমান এনেছে তাদের সাথে যখন তারা মোলাকাত করে তখন বলে -- “আমরা ঈমান এনেছি।” আর যখন তাদের লোকেরা একে অন্যের সাথে নিরিবিলি হয় তখন বলে -- “আল্লাহ্ তোমাদের কাছে যা প্রকাশ করেছেন তা কি তোমরা ওদের জানিয়ে দিচ্ছ, যাতে ওরা এ-সবের সাহায্যে তোমাদের প্রভুর সামনে তোমাদের সাথে বিতর্ক করে? তোমরা কি তবে বুঝতে পারছ না?”\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@lxxxiv{আর তারা কি জানে না যে নিঃসন্দেহ আল্লাহ্ জানেন যা তারা লুকিয়ে রাখছে ও যা প্রকাশ করছে?\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@lxxxv{আর তাদের মধ্যে হচ্ছে নিরক্ষর যারা ধর্মগ্রন্থ সন্বন্ধে উপকথার বেশী জানে না, আর তারা শুধু আন্দাজের উপর চলে!\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@lxxxvi{হায়, কি অভাগা তারা যারা নিজ হাতে গ্রন্থ লেখে, তারপর বলে -- “ইহা আল্লাহ্‌র দরবার থেকে” -- যাতে এর জন্য তারা স্বল্পমূল্য কামাতে পারে। অতএব ধিক্ তাদের প্রতি তাদের হাত যা লিখেছে সেজন্য, আর ধিক্ তাদের প্রতি যা তারা কামাই করে সেজন্য!\qt@no{(79)}}
\qt@newcmd\qurantrans@bn@lxxxvii{আর তারা বলে -- “আগুন আমাদের গুনতির কয়েকদিন ছাড়া কদাচ স্পর্শ করবে না।” তুমি বলো -- “তোমরা কি আল্লাহ্‌র কাছ থেকে কোনো প্রতি‌শ্রুতি নিয়েছ? তাহলে আল্লাহ্ তাঁর ওয়াদার কখনো খেলাফ করেন না, অথবা তোমরা কি আল্লাহ্ সন্বন্ধে যা জান না তাই বলছ?”\qt@no{(80)}}
\qt@newcmd\qurantrans@bn@lxxxviii{হাঁ, যে কেউ মন্দ অর্জন করে, আর তার পাপ তাকে ঘেরাও করে ফেলে, এরাই হচ্ছে আগুনের বাসিন্দা, তাতে তারা থাকবে দীর্ঘকাল।\qt@no{(81)}}
\qt@newcmd\qurantrans@bn@lxxxix{আর যারা ঈমান এনেছে ও সৎকর্ম করছে, তারাই হচ্ছে বেহেশতের বাসিন্দা, তাতে থাকবে তারা চিরকাল।\qt@no{(82)}}
\qt@newcmd\qurantrans@bn@xc{আর স্মরণ করো! আমরা ইসরাইলের বংশধরদের থেকে চুক্তি গ্রহণ করেছিলাম -- “তোমরা আল্লাহ্ ছাড়া আর কারো উপাসনা করবে না, আর মাতাপিতার প্রতি ভালো ব্যবহার করবে, এবং আ‌ত্মীয়স্বজনদের প্রতি, আর এতিমদের প্রতি, আর মিসকিনদের প্রতি, আর লোকদের সাথে ভালোভাবে কথা বলবে, আর নামায কায়েম করবে ও যাকাত আদায় করবে।” তারপর তোমরা তোমাদের অল্প কয়েকজন ছাড়া ফিরে গেলে, আর তোমরা ফিরে যাবার দলের।\qt@no{(83)}}
\qt@newcmd\qurantrans@bn@xci{আর স্মরণ করো! আমরা তোমাদের অঙ্গীকার গ্রহণ করেছিলাম -- “তোমরা তোমাদের রক্তপাত করবে না আর তোমাদের লোকদের তোমাদের বাড়িঘর থেকে বের করে দেবে না।” তখন তোমরা প্রতিজ্ঞা করেছিলে, আর তোমারা সাক্ষ্য দিয়েছিলে।\qt@no{(84)}}
\qt@newcmd\qurantrans@bn@xcii{তারপর তোমরাই সেই যারা তোমাদের নিজেদের মধ্যে খুন-খারাবি করো, আর তোমাদেরই এক দলকে তাদের বাড়িঘর থেকে তোমরা তাড়িয়ে দাও তাদের বিরুদ্ধে পাপ ও নিষ্ঠুরতায় পৃষ্ঠপোষকতা ক’রে। অথচ যদি তারা তোমাদের কাছে বন্দীরূপে আসে তবে তাদের মুক্তিপণ দাও, যদিও তাদের তাড়িয়ে দেওয়াটা তোমাদের উপরে অবৈধ ছিল। তাহলে তোমরা কি ধর্মগ্রন্থের অংশবিশেষে বিশ্বাস কর ও অন্য অংশে অবিশ্বাস পোষণ কর? অতএব তোমাদের মধ্যের যারা এরকম করে তাদের ইহজীবনে লাঞ্ছনা ছাড়া আর কী পুরস্কার আছে? আর কিয়ামতের দিনে তাদের ফেরত পাঠানো হবে কঠোরতম শাস্তিতে। আর তোমরা যা করছো আল্লাহ্ সে-বিষয়ে অজ্ঞাত নন।\qt@no{(85)}}
\qt@newcmd\qurantrans@bn@xciii{এরাই তারা যারা আখেরাতের বদলে ইহজীবন খরিদ করেছে। তাই তাদের উপর থেকে শাস্তি লাঘব করা হবে না, আর তাদের সাহায্যও দেয়া হবে না।\qt@no{(86)}}
\qt@newcmd\qurantrans@bn@xciv{আর অবশ্যই আমরা মূসাকে ধর্মগ্রন্থ দিয়েছিলাম, আর তাঁর পরে পর্যায়ক্রমে বহু রসূল পাঠিয়েছিলাম, আর আমরা মরিয়মের পুত্র ঈসাকে দিয়েছিলাম স্পষ্ট-প্রমাণাবলী, আর আমরা তাঁকে বলীয়ান করি রূহুল ক্কুদুস দিয়ে। তাহলে কি যখনই তোমাদের কাছে একজন রসূল আসেন এমন কিছু নিয়ে যা তোমাদের মন চায় না, তখনই তোমরা অহংকার দেখাও? গতিকে, কাউকে তোমরা মিথ্যারোপ করো ও কাউকে কাতল করতে যাও।\qt@no{(87)}}
\qt@newcmd\qurantrans@bn@xcv{আর তারা বলে -- “আমাদের হৃদয় হলো গেলাফ!” না, আল্লাহ্ তাদের বঞ্চিত করেছেন তাদের অবিশ্বাসের জন্য। তাই যৎসামান্যই যা তারা বিশ্বাস করে।\qt@no{(88)}}
\qt@newcmd\qurantrans@bn@xcvi{আর যখন তাদের কাছে আল্লাহ্‌র তরফ থেকে একখানা ধর্মগ্রন্থ এল যাতে সমর্থন রয়েছে যা তাদের কাছে আছে -- যদিও ইতিপূর্বে তারা প্রার্থনা করতো যারা অবিশ্বাস পোষণ করে তাদের উপরে বিজয়ী হবার জন্যে, -- কিন্তু যখন তাদের কাছে এলেন যাঁকে তারা চিনতে পারল তারা তাঁকে অবিশ্বাস করে বসলো। সুতরাং আল্লাহ্‌র নারাজি অবিশ্বাসীদের উপরে।\qt@no{(89)}}
\qt@newcmd\qurantrans@bn@xcvii{গর্হিত তা যা দিয়ে তারা নিজেদের আ‌ত্মা বিনিময় করেছে যে জন্য আল্লাহ্ যা অবতারণ করেছেন তা তারা অবিশ্বাস করে বিদ্বেষের বশে -- যে আল্লাহ্ তাঁর কৃপাবশতঃ উহা অবতীর্ণ করবেন তাঁর দাসদের মধ্যে যাকে ইচ্ছা করেন তার কাছে! তাই তারা রোষের উপর রোষ টেনে আনলো। আর অবিশ্বাসীদের জন্য রয়েছে লাঞ্ছনাদায়ক শাস্তি।\qt@no{(90)}}
\qt@newcmd\qurantrans@bn@xcviii{আর যখন তাদের বলা হয় -- “ঈমান আনো আল্লাহ্ যা নাযিল করেছেন তাতে,” তারা বলে -- “আমরা বিশ্বাস করি যা আমাদের কাছে নাযিল হয়েছিল।” অথচ তারা অবিশ্বাস করে যা তার পরে এসেছে, যদিও উহা হলো ধ্রুব সত্য, সমর্থন করছে যা তাদের কাছে রয়েছে তার। বলো -- “তাহলে তোমরা কেন আল্লাহ্‌র নবীদের এর আগে হত্যা করতে যাচ্ছিলে? যদি তোমরা বিশ্বাসী হয়ে থাকো।”\qt@no{(91)}}
\qt@newcmd\qurantrans@bn@xcix{আর নিশ্চয়ই মূসা তোমাদের কাছে এসেছিলেন স্পষ্ট প্রমাণ নিয়ে, কিন্তু তোমরা বাছুরকে গ্রহণ করলে তাঁর, আর তোমরা হলে অন্যায়কারী।\qt@no{(92)}}
\qt@newcmd\qurantrans@bn@c{আর স্মরণ করো! আমরা তোমাদের অঙ্গীকার গ্রহণ করেছিলাম ও তোমাদের উপরে পর্বত খাড়া করেছিলাম। -- “তোমাদের আমরা যা দিয়েছি তা শক্ত করে পাকড়ে ধরো, আর শুনো।” তারা বলল -- “আমরা শুনলাম আর অমান্য করলাম!” আর তাদের হৃদয়ের ভেতরে পান করানো হয়েছে বাছুর তাদের অস্বীকার করার দরুন। বলো -- “তোমাদের ধর্মবিশ্বাস তোমাদের যা নির্দেশ দিচ্ছে তা দূষণীয়, যদি তোমরা ঈমানদার হও।”\qt@no{(93)}}
\qt@newcmd\qurantrans@bn@ci{বলো -- “যদি আল্লাহ্‌র আখেরাতের ঘর অপর লোককে বাদ দিয়ে খাস ক’রে তোমাদের জন্য হয়ে থাকে তবে মৃত্যু কামনা করো, যদি তোমরা সত্যবাদী হও।”\qt@no{(94)}}
\qt@newcmd\qurantrans@bn@cii{কিন্তু তারা কখনো তা চাইবে না তাদের দুই হাত যা পাঠিয়েছে। আর আল্লাহ্ অন্যায়কারীদের সম্পর্কে সর্বজ্ঞাতা।\qt@no{(95)}}
\qt@newcmd\qurantrans@bn@ciii{আর তুমি তাদের পাবে জীবন সন্বন্ধে সবচাইতে লোভী মানুষ, যারা শরিক করে তাদের চাইতেও। তাদের এক একজন কামনা করে তাকে যেন হাজার বছরের পরমায়ু দেয়া হয়। কিন্তু তাকে দীর্ঘজীবন দেয়া হলেও শাস্তি থেকে সে স্থানাস্তরিত হবে না। আর তারা যা করছে আল্লাহ্ তার দর্শক।\qt@no{(96)}}
\qt@newcmd\qurantrans@bn@civ{বলো -- “যে কেউ জিব্রীলের শত্রু” -- কারণ নিঃসন্দেহ সে-ই আল্লাহ্‌র আদেশে উহা তোমার হৃদয়ে অবতীর্ণ করেছে, এর আগে যা এসেছিল তার সত্য-সমর্থনরূপে, এবং মুমিনদের জন্য পথপ্রদর্শক ও সুসংবাদদাতারূপে, --\qt@no{(97)}}
\qt@newcmd\qurantrans@bn@cv{“যে কেউ আল্লাহ্‌র ও তাঁর ফিরিশ্‌তাদের ও তাঁর রসূলদের ও জিব্রীলের ও মিকালের শত্রু, নিঃসন্দেহ আল্লাহ্ তখন অবিশ্বাসীদের শত্রু।”\qt@no{(98)}}
\qt@newcmd\qurantrans@bn@cvi{আর নিশ্চয়ই আমরা তোমার কাছে নাযিল করেছি সুস্পষ্ট আয়াত -- সমূহ, আর কেউ এতে অবিশ্বাস করে না দুর্বৃত্তরা ছাড়া।\qt@no{(99)}}
\qt@newcmd\qurantrans@bn@cvii{কি ব্যাপার! যখনই তারা কোনো ওয়াদাতে অঙ্গীকার করেছে, তাদের একদল তা প্রত্যাখ্যান করেছে? না, তাদের অধিকাংশই বিশ্বাস করে না।\qt@no{(100)}}
\qt@newcmd\qurantrans@bn@cviii{আর যখনই তাদের কাছে আল্লাহ্‌র তরফ থেকে কোনো রসূল আসেন তাদের কাছে যা আছে তার সমর্থন ক’রে, যাদের গ্রন্থ দেয়া হয়েছিল তাদের একদল আল্লাহ্‌র গ্রন্থকে তাদের পশ্চাদ্দেশে ফেলে রাখে, যেন তারা জানে না।\qt@no{(101)}}
\qt@newcmd\qurantrans@bn@cix{আর তারা তার অনুসরণ করে যা শয়তানরা সুলাইমানের রাজত্বে চালু করেছিল, আর সুলাইমান অবিশ্বাস পোষণ করেন নি, বরং শয়তান অবিশ্বাস করেছিল, তারা লোকজনকে জাদুবিদ্যা শেখাতো, আর তা বাবেলে হারূত ও মারূত এই দুই ফিরিশ্‌তার কাছে নাযিল হয় নি, আর এই দুইজন কাউকে শেখায়ও নি যাতে তাদের বলতে হয় -- “আমরা এক পরীক্ষা মাত্র, অতএব অবিশ্বাস করো না।” সুতরাং এই দুইয়ের থেকে তারা শিখেছে যার দ্বারা স্বামী ও তার স্ত্রীর মধ্যে বিচ্ছেদ ঘটে। কিন্তু তারা এর দ্বারা কারো ক্ষতি করতে পারে না আল্লাহ্‌র অনুমতি ব্যতীত। আর তারা তাই শেখে যা তাদের ক্ষতিসাধন করে, এবং তাদের উপকার করে না। আর অবশ্যই তারা জানে যে এটা যে কিনে নেয় তার জন্য পরকালে কোনো লাভের অংশ থাকবে না। আর আফসোস, এটা মন্দ যার বিনিময়ে তারা নিজেদের আ‌ত্মা বিক্রয় করেছে, -- যদি তারা জানতো!\qt@no{(102)}}
\qt@newcmd\qurantrans@bn@cx{আর যদি তারা ঈমান আনতো ও ধর্মভীরুতা অবলন্বন করতো তাহলে আল্লাহ্‌র কাছ থেকে পুরস্কার নিশ্চয়ই বহু ভালো হতো, -- যদি তারা জানতো!\qt@no{(103)}}
\qt@newcmd\qurantrans@bn@cxi{ওহে যারা ঈমান এনেছো! তোমরা বলো না “রা-'ইনা-”, বরং বলো “উনযুরনা-”, আর শুনুন। আর অবিশ্বাসীদের জন্য রয়েছে মর্মন্তদ শাস্তি।\qt@no{(104)}}
\qt@newcmd\qurantrans@bn@cxii{গ্রন্থপ্রাপ্তদের মধ্যে যারা অবিশ্বাস পোষণ করে তারা এবং মুশরিকরা চায় না যে তোমাদের প্রভুর কাছ থেকে কোনো কল্যাণ তোমাদের প্রতি নাযিল হোক। কিন্তু আল্লাহ্ তাঁর করুণার জন্য যাকে ইচ্ছা করেন মনোনীত করেন। আর আল্লাহ্ অপার কল্যাণের অধিকারী।\qt@no{(105)}}
\qt@newcmd\qurantrans@bn@cxiii{যে-সব আয়াত আমরা মনসুখ করি অথবা উহা ভুলিয়ে দিই, আমরা তার চাইতে ভালো অথবা তার অনুরূপ নিয়ে আসি। তুমি কি জান না যে আল্লাহ্ নিঃসন্দেহ সব-কিছুর উপরে সর্বশক্তিমান?\qt@no{(106)}}
\qt@newcmd\qurantrans@bn@cxiv{তুমি কি জানো না নিঃসন্দেহ আল্লাহ্‌, -- মহাকাশমন্ডলের ও পৃথিবীর রাজত্ব তাঁরই। আর তোমাদের জন্য আল্লাহ্ ছাড়া কোনো মুরব্বী অথবা সাহায্যকারী নেই।\qt@no{(107)}}
\qt@newcmd\qurantrans@bn@cxv{তোমরা কি তোমাদের রসূলকে প্রশ্ন করতে চাও যেমন মূসাকে এর আগে প্রশ্ন করা হয়েছিল? আর যে বিশ্বাসের জায়গায় অবিশ্বাস বদলে নেয় সে-ই নিশ্চয়ই সরল পথের দিশা হারায়।\qt@no{(108)}}
\qt@newcmd\qurantrans@bn@cxvi{গ্রন্থপ্রাপ্ত লোকের অনেকে কামনা করে যে তোমাদের ঈমান আনার পরে তোমাদের অবিশ্বাসে ফিরিয়ে নিতে, তাদের তরফ থেকে বিদ্বেষের ফলে তাদের কাছে সত্য পরিস্কার হবার পরেও। তাই ক্ষমা করো ও উপেক্ষা করো যে পর্যন্ত না আল্লাহ্ তাঁর অনুশাসন নিয়ে আসেন। নিঃসন্দেহ আল্লাহ্ সবকিছুর উপরে সর্বশক্তিমান।\qt@no{(109)}}
\qt@newcmd\qurantrans@bn@cxvii{আর নামায কায়েম করো ও যাকাত আদায় করো। আর তোমাদের আ‌ত্মার জন্য যা কিছু কল্যাণ আগবাড়াও তা আল্লাহ্‌র দরবারে পাবে। নিশ্চয়ই তোমরা যা করছো আল্লাহ্ তার দর্শক।\qt@no{(110)}}
\qt@newcmd\qurantrans@bn@cxviii{আর তারা বলে -- “যে ইহুদী বা খ্রীষ্টান সে ছাড়া কেউ কখনও বেহেশতে দাখিল হতে পারবে না।” এসব তাদের বৃথা আকাঙ্খা। বলো -- “তোমাদের প্রমাণ নিয়ে এসো, যদি তোমরা সত্যবাদী হও।”\qt@no{(111)}}
\qt@newcmd\qurantrans@bn@cxix{না, যে কেউ আল্লাহ্‌র তরফে নিজের মুখ পূর্ণ-সমর্পণ করেছে ও সে সৎকর্মী, তার জন্য তার পুরস্কার আছে তার প্রভুর দরবারে, আর তাদের উপরে কোনো ভয় নেই, আর তারা অনুতাপও করবে না।\qt@no{(112)}}
\qt@newcmd\qurantrans@bn@cxx{আর ইহুদীরা বলে -- “খ্রীষ্টানরা কিছুরই উপর নয়”, আর খ্রীষ্টানরা বলে -- “ইহুদীরা কিছুরই উপর নয়।” অথচ তারা সবাই গ্রন্থ পড়ে। এমনিভাবে তাদের কথার মতো কথা বলে এরা যারা জানে না। তাই আল্লাহ্ কিয়ামতের দিনে তাদের মধ্যে রায় দেবেন যে বিষয়ে তারা মতবিরোধ করতো।\qt@no{(113)}}
\qt@newcmd\qurantrans@bn@cxxi{আর তার চাইতে কে বেশী অন্যায়কারী যে আল্লাহ্‌র মসজিদসমূহে বাধা দেয় এইজন্য যে সে-সবে তাঁর নাম স্মরণ করা হবে, আর চেষ্টা করে সে-সবের অনিষ্ট সাধনে? এদের ক্ষেত্রে, তাদের জন্য নয় যে তারা এ-সবে দাখিল হয় ভয়াতুর না হয়ে। তাদের জন্য এই দুনিয়াতে আছে অপমান, আর পরকালে তাদের জন্য কঠোর শাস্তি।\qt@no{(114)}}
\qt@newcmd\qurantrans@bn@cxxii{আর আল্লাহ্‌রই পূর্বাঞ্চল ও পশ্চিমাঞ্চল। অতএব যেদিকে তোমরা ফেরো সে-দিকেই আল্লাহ্‌র মুখ। নিঃসন্দেহে আল্লাহ্ সর্বব্যাপক, সর্বজ্ঞাতা।\qt@no{(115)}}
\qt@newcmd\qurantrans@bn@cxxiii{আর তারা বলে -- “আল্লাহ্ একটি ছেলে গ্রহণ করেছেন” । তাঁরই মহিমা হোক! বরং মহাকাশমন্ডলে ও পৃথিবীতে যা-কিছু আছে সে-সব তাঁরই, সবাই তাঁর আজ্ঞা পালনকারী।\qt@no{(116)}}
\qt@newcmd\qurantrans@bn@cxxiv{মহাকাশমন্ডলী ও পৃথিবীর আদি-স্রষ্টা! আর যখনই তিনি কোনো বিষয় বির্ধারিত করেন তিনি সে-সন্বন্ধে তখন শুধু বলেন -- “হও”, আর তা হয়ে যায়।\qt@no{(117)}}
\qt@newcmd\qurantrans@bn@cxxv{আর যারা জানে না তারা বলে -- “আল্লাহ্ কেন আমাদের সাথে কথা বলেন না, অথবা একটি নিদর্শন আমাদের কাছে আসুক?” এমনভাবে এদের আগে যারা ছিল তারা এদের কথার অনুরূপ কথা বলেছিল। তাদের হৃদয় একই রকমের। আমরা আয়াতসমূহ সুস্পষ্ট করে রেখেছি সেই লোকদের কাছে যারা দৃঢ়প্রত্যয় রাখে।\qt@no{(118)}}
\qt@newcmd\qurantrans@bn@cxxvi{নিঃসন্দেহ আমরা তোমাকে সত্য দিয়ে পাঠিয়েছি, সুসংবাদদাতারূপে ও সতর্ককারীরূপে, আর তোমাকে জবাব দিহি করতে হবে না ভয়ঙ্কর আগুনের বাসিন্দাদের সম্পর্কে।\qt@no{(119)}}
\qt@newcmd\qurantrans@bn@cxxvii{আর ইহুদীরা কখনো তোমার উপরে সন্তষ্ট হবে না, খ্রীষ্টানরাও নয়, যতক্ষণ না তুমি তাদের ধর্মমত অনুসরণ কর। তাদের বলো -- “নিশ্চয়ই আল্লাহ্‌র যা হেদায়ত তাই-ই হেদায়ত। আর তুমি যদি তাদের ইচ্ছার অনুসরণ কর তোমার কাছে জ্ঞানের যা এসেছে তার পরে, তাহলে আল্লাহর কাছ থেকে তুমি পাবে না কোনো বন্ধু-বান্ধব, না কোনো সাহায্যকারী।\qt@no{(120)}}
\qt@newcmd\qurantrans@bn@cxxviii{যাদের আমরা গ্রন্থ দিয়েছি তারা উহার তিলাওতের ন্যায্যতা মোতাবেক উহা অধ্যয়ন করে। তারাই এতে ঈমান এনেছে। আর যারা এতে অবিশ্বাস পোষণ করে তারা নিজেরাই হয় ক্ষতিগ্রস্ত।\qt@no{(121)}}
\qt@newcmd\qurantrans@bn@cxxix{হে ইসরাইলের বংশধরগণ! আমার নিয়ামত স্মরণ করো যা আমি তোমাদের প্রদান করেছিলাম ও কিভাবে মানবগোষ্ঠীর উপরে তোমাদের মর্যাদা দিয়েছিলাম।\qt@no{(122)}}
\qt@newcmd\qurantrans@bn@cxxx{আর হুশিয়াঁর হও এমন এক দিনের যখন এক সত্তা অন্য আ‌ত্মা থেকে কোনো প্রকার সাহায্য পাবে না, আর তার কাছ থেকে কোনো খেসারত কবুল করা হবে না, আর সুপারিশেও তার কোনো ফায়দা হবে না, আর তাদের সাহায্য করা হবে না।\qt@no{(123)}}
\qt@newcmd\qurantrans@bn@cxxxi{আর স্মরণ করো! ইব্রাহীমকে তাঁর প্রভু কয়েকটি নির্দেশ দ্বারা পরীক্ষা করলেন, আর তিনি সেগুলো সম্পাদন করলেন। তিনি বললেন -- “আমি নিশ্চয়ই তোমাকে মানবজাতির জন্য ইমাম করতে যাচ্ছি।” তিনি বললেন -- “আর আমার বংশধরগণ থেকে?” তিনি বললেন -- “আমার অঙ্গীকার অন্যায়কারীদের উপরে বর্তায় না।”\qt@no{(124)}}
\qt@newcmd\qurantrans@bn@cxxxii{আর চেয়ে দেখো! আমরা গৃহকে মানুষের জন্য সম্মেলনস্থল ও নিরাপত্তা-স্থান বানিয়েছিলাম। আর “মক্কাম-ই-ইব্রাহীমকে উপাসনা-ভূমি করো।” আর আমরা ইব্রাহীম ও ইসমাইলের প্রতি নির্দেশ দিয়েছিলাম -- “আমার গৃহ পবিত্র করে রেখো তওয়াফকারীদের ও ই’তিকাফকারীদের ও রুকু-সিজদাকারীদের জন্য।”\qt@no{(125)}}
\qt@newcmd\qurantrans@bn@cxxxiii{আর স্মরণ করো! ইব্রাহীম বললেন -- “আমার প্রভু! এটিকে তুমি নিরাপদ নগর বানাও, আর এর লোকদের ফলফসল দিয়ে জীবিকা দান করো -- তাদের যারা আল্লাহ্‌তে ও আখেরাতের দিনে ঈমান এনেছে।” তিনি বললেন -- “আর যে অবিশ্বাস পোষণ করবে তাকে আমি ক্ষণেকের জন্য ভোগ করতে দেব, তারপর তাড়িয়ে নেব আগুনের শাস্তির দিকে, আর নিকৃষ্ট গন্তব্যস্থল।”\qt@no{(126)}}
\qt@newcmd\qurantrans@bn@cxxxiv{আর স্মরণ করো! ইব্রাহীম গৃহের ভিত্তি গেথেঁ তুললেন, আর ইসমাইল। “আমাদের প্রভু! আমাদের থেকে তুমি গ্রহণ করো। নিঃসন্দেহ তুমি নিজেই সর্বশ্রোতা, সর্বজ্ঞাতা।\qt@no{(127)}}
\qt@newcmd\qurantrans@bn@cxxxv{“আমাদের প্রভু! আর তোমার প্রতি আমাদের মুসলিম করে রেখো, আর আমাদের সন্তানসন্ততিদের থেকে তোমার প্রতি মুসলিম উম্মৎ, আর আমাদের উপাসনা-প্রণালী আমাদের দেখিয়ে দাও, আর আমাদের তওবা কবুল করো, নিঃসন্দেহ তুমি নিজেই তওবা কবুলকারী, অফুরন্ত ফলদাতা।\qt@no{(128)}}
\qt@newcmd\qurantrans@bn@cxxxvi{“আমাদের প্রভু! তাদের মাঝে তাদের থেকে রসূল উত্থাপন করো যিনি তোমার প্রত্যাদেশসমূহ তাদের কাছে পড়ে শোনাবেন, আর তাদের শেখাবেন ধর্মগ্রন্থ ও জ্ঞান-বিজ্ঞান, আর তাদের পবিত্র করবেন। নিশ্চয়ই তুমি নিজেই মহাশক্তিশালী, পরমজ্ঞানী।”\qt@no{(129)}}
\qt@newcmd\qurantrans@bn@cxxxvii{আর যে ইব্রাহীমের ধর্মমত থেকে অপসৃত হয় সে ছাড়া আর কে নিজেকে নির্বোধ বানায়? আর অবশ্যই আমরা তাঁকে এই দুনিয়াতে মনোনীত করেছিলাম, আর নিঃসন্দেহে তিনি আখেরাতে হবেন ধার্মিকদের অন্যতম।\qt@no{(130)}}
\qt@newcmd\qurantrans@bn@cxxxviii{স্মরণ করো! তাঁর প্রভু তাঁকে বললেন -- “ইসলাম গ্রহণ করো!” তিনি বললেন -- “আমি সমস্ত সৃষ্টজগতের প্রভুর কাছে আ‌ত্মসমর্পণ করছি।”\qt@no{(131)}}
\qt@newcmd\qurantrans@bn@cxxxix{আর ইব্রাহীম তাঁর সন্তানদের এইটির ভারার্পণ করেছিলেন, আর ইয়াকুব। “হে আমার সন্তানসন্ততি! নিশ্চয় আল্লাহ্ তোমাদের জন্য এই ধর্ম মনোনীত করেছেন, অতএব তোমরা প্রাণত্যাগ করো না তোমরা মুসলিম না হয়ে।”\qt@no{(132)}}
\qt@newcmd\qurantrans@bn@cxl{অথবা তোমরা কি প্রত্যক্ষদর্শী ছিলে যখন ইয়াকুবের মৃত্যু এসেছিল, যখন তিনি তাঁর সন্তানদের বলেছিলেন -- “তোমরা আমার পরে কার এবাদত করবে?” ওরা বলেছিল -- “আমরা এবাদত করব তোমার উপাস্যের ও তোমার পিতৃপুরুষ ইব্রাহীম ও ইসমাইল ও ইসহাকের উপাস্যের -- একক উপাস্যের, আর তাঁর কাছে আমরা মুসলিম।”\qt@no{(133)}}
\qt@newcmd\qurantrans@bn@cxli{এরা ঐসব লোক যারা গত হয়ে গেছে। তাদের জন্য আছে যা তারা অর্জন করেছিল আর তোমাদের জন্য যা তোমরা অর্জন করছ, আর তোমাদের জবাবদিহি করতে হবে না ওরা যা করছিল সে সন্বন্ধে।\qt@no{(134)}}
\qt@newcmd\qurantrans@bn@cxlii{আর তারা বলে -- “ইহুদীয় বা খ্রীষ্টান হও, তোমরা হেদায়ত পাবে।” তুমি বলো -- “বরং অনন্যচিত্ত ইব্রাহীমের ধর্মমত। আর তিনি মুশরিকদের অন্তর্ভুক্ত ছিলেন না?”\qt@no{(135)}}
\qt@newcmd\qurantrans@bn@cxliii{তোমরা বলো -- “আমরা আল্লাহ্‌তে ঈমান এনেছি, আর তা’তে যা আমাদের জন্য নাযিল হয়েছে, আর যা নাযিল হয়েছিল ইব্রাহীমের কাছে, আর ইসমাইল ও ইসহাক, আর ইয়াকুব এবং বিভিন্ন গোত্রের কাছে, আর যা দেয়া হয়েছিল মূসাকে এবং ঈসাকে, আর যা সকল নবীদের তাঁদের প্রভুর কাছ থেকে দেয়া হয়েছিল। আমরা তাঁদের কোনো একজনের মধ্যেও পার্থক্য করি না। আর আমরা তাঁরই কাছে মুসলিম হচ্ছি।”\qt@no{(136)}}
\qt@newcmd\qurantrans@bn@cxliv{এবার যদি তারা ঈমান আনত যেভাবে তোমরা তাঁর প্রতি ঈমান আনছো, তাহলে নিঃসন্দেহ তারা হেদায়ত পেতো, আর যদি তারা ফিরে যায় তাহলে অবশ্যই তারা বিরোধিতাতে নিমগ্ন। অতএব আল্লাহই তাদের বিরুদ্ধে তোমার জন্য যথেষ্ট, কারণ তিনিই সর্বশ্রোতা, সর্বজ্ঞাতা।\qt@no{(137)}}
\qt@newcmd\qurantrans@bn@cxlv{“আল্লাহ্‌র রঙ। আর রঙের ক্ষেত্রে আল্লাহ্‌র চাইতে কে বেশী সুন্দর? আর আমরা তাঁরই উপাসনাকারী।”\qt@no{(138)}}
\qt@newcmd\qurantrans@bn@cxlvi{বলো -- “তোমরা কি আমাদের সঙ্গে আল্লাহ্‌র সন্বন্ধে হুজ্জত করছ অথচ তিনি আমাদের প্রভু, তোমাদেরও প্রভু? আর আমাদের কাজ আমাদের হবে, ও তোমাদের কাজ তোমাদের হবে। আর আমরা তাঁরই প্রতি একান্ত অনুরক্ত।”\qt@no{(139)}}
\qt@newcmd\qurantrans@bn@cxlvii{অথবা তোমরা কি বলো যে ইব্রাহীম ও ইসমাইল ও ইসহাক ও ইয়াকুব এবং বিভিন্ন গোত্রেরা ইহুদী অথবা খ্রীষ্টান ছিলেন? বলো -- “তোমরা কি বেশি জানো, না আল্লাহ্‌? আর তাঁর চাইতে কে বেশি অন্যায় করছে যে গোপন করছে সেই সাক্ষ্য যা আল্লাহ্‌র কাছ থেকে সে পেয়েছে? আর তোমরা যা করছ সে সন্বন্ধে আল্লাহ্ বেখেয়াল নন।\qt@no{(140)}}
\qt@newcmd\qurantrans@bn@cxlviii{এরা ঐসব লোক যারা গত হয়ে গেছে। তাদের জন্য আছে যা তারা অর্জন করেছিল, আর তোমাদের জন্য যা তোমরা অর্জন করছ, আর তোমাদের জবাবদিহি করতে হবে না ওরা যা করছিল সে-সন্বন্ধে।\qt@no{(141)}}
\qt@newcmd\qurantrans@bn@cxlix{লোকদের মধ্যের নির্বোধরা শীঘ্রই বলবে -- “তাদের যে কিবলাহ্‌তে তারা তাদের বদলালো কিসে?” তুমি বলো -- “পূর্ব ও পশ্চিমের মালিক আল্লাহ্‌, তিনি যাকে ইচ্ছা করেন তাকে সহজ-সঠিক পথের দিকে পরিচালিত করেন।”\qt@no{(142)}}
\qt@newcmd\qurantrans@bn@cl{আর এইভাবে তোমাদের আমরা বানিয়েছি একটি সুসামঞ্জস্যরক্ষাকারী সমাজ, যাতে তোমরা মানবজাতির জন্য সাক্ষী হতে পারো, আর রসূল তোমাদের জন্য সাক্ষী হতে পারেন। আর আমরা তাকে কিবলাহ্ বানাতাম না যার উপরে তুমি ছিলে, যদি না আমরা যাচাই করতাম যে কে রসূলকে অনুসরণ করে আর কে তার মোড় ফিরিয়ে ঘুরে যায়। আর নিঃসন্দেহ এটি কঠিন ছিল তাদের ক্ষেত্রে ছাড়া যাদের আল্লাহ্ হেদায়ত করেছেন। আর আল্লাহ্ তোমাদের ঈমান কখনও নিষ্ফল হতে দেবেন না। নিঃসন্দেহ আল্লাহ্ মানুষের প্রতি পরম স্নেহময়, অফুরন্ত ফলদাতা।\qt@no{(143)}}
\qt@newcmd\qurantrans@bn@cli{আমরা নিশ্চয়ই দেখেছি আকাশের দিকে তুমি মুখ তোলে রয়েছ, তাই আমরা নিঃসন্দেহ তোমাকে কর্তৃত্ব দেবো কিবলাহ্‌র যা তুমি পছন্দ কর। কাজেই হারাম মসজিদের দিকে তোমার মুখ ফেরাও। আর যেখানেই তোমরা থাক তোমাদের মুখ এর দিকেই ফেরাবে। আর যাদের কিতাব দেয়া হয়েছে তারা অবশ্যই জানে যে নিঃসন্দেহ এটি তাদের প্রভুর কাছ থেকে আসা ধ্রুব-সত্য। আর তারা যা করছে আল্লাহ্ সে-সন্বন্ধে বেখেয়াল নন।\qt@no{(144)}}
\qt@newcmd\qurantrans@bn@clii{আর যদিও তুমি যাদের কিতাব দেয়া হয়েছে তাদের কাছে সবক’টি নিদর্শন নিয়ে আস তবুও তারা তোমার কিবলাহ্ মেনে চলবে না। আর তুমি তাদের কিবলাহ্‌র অনুবর্তী হতে পারো না, আবার তাদের কেউ-কেউ পরস্পরের কিবলাহ্‌র অনুবর্তী নয়। আর তুমি যদি তাদের হীন মনোবৃত্তির অনুসরণ কর তোমার কাছে জ্ঞানের যা এসেছে তার পরেও, তাহলে নিঃসন্দেহ তুমিও হবে অন্যায়কারীদের অন্যতম।\qt@no{(145)}}
\qt@newcmd\qurantrans@bn@cliii{যাদের আমরা কিতাব দিয়েছি তারা তাঁকে চিনতে পারছে যেমন তারা চিনতে পারে তাদের সন্তানদের। কিন্তু তাদের মধ্যের একদল নিশ্চয়ই সত্য কথা গোপন করছে, আর তারা জানে।\qt@no{(146)}}
\qt@newcmd\qurantrans@bn@cliv{এই সত্য এসেছে তোমার প্রভুর কাছ থেকে অতএব তোমারা সন্দেহপরায়ণদের অন্তর্ভুক্ত হয়ো না।\qt@no{(147)}}
\qt@newcmd\qurantrans@bn@clv{আর প্রত্যেকের জন্য একটি কেন্দ্রস্থল আছে যে-দিকে সে ফেরে, কাজেই সৎকর্মে একে অন্যের সাথে তোমরা প্রতিযোগিতা করো। যেখানেই তোমরা থাকো না কেন, আল্লাহ্ তোমাদের সবাইকে একত্রিত করবেন। নিঃসন্দেহ আল্লাহ্ সব-কি ছুর উপরে সর্বশক্তিমান।\qt@no{(148)}}
\qt@newcmd\qurantrans@bn@clvi{আর যেখান থেকেই তুমি আস, তোমার মুখ পবিত্র মসজিদের দিকে ফেরাও। নিঃসন্দেহ এটি তোমার প্রভুর কাছ থেকে সত্য। আর অবশ্যই আল্লাহ্ বেখেয়াল নন তোমরা যা করো সে-সন্বন্ধে।\qt@no{(149)}}
\qt@newcmd\qurantrans@bn@clvii{আর যেখান থেকেই তুমি আস, তোমার মুখ পবিত্র মসজিদের দিকে ফেরাবে। আর যেখানেই তোমরা থাকো, তোমাদের মুখ সেই দিকেই ফেরাবে। যাতে তোমাদের বিরুদ্ধে লোকজনদের কোনো হুজ্জত না থাকে -- তাদের মাঝে যারা অন্যায় করে তারা ব্যতীত। অতএব তাদের ভয় করো না, বরং ভয় করো আমাকে। আর যাতে আমি তোমাদের উপরে আমার নিয়ামত সম্পূর্ণ করতে পারি, আর যাতে তোমরা সুপথগামী হতে পারো, --\qt@no{(150)}}
\qt@newcmd\qurantrans@bn@clviii{যেমন, আমরা তোমাদের কাছে তোমাদের মধ্যে থেকে একজন রসূল পাঠিয়েছি, যিনি আমাদের বাণী তোমাদের কাছে তিলাওত করছেন, আর তোমাদের পবিত্র করছেন, আর তোমাদের ধর্মগ্রন্থ ও জ্ঞানবিজ্ঞান শিক্ষা দিচ্ছেন, আর তোমাদের শেখাচ্ছেন যা তোমরা জানতে না।\qt@no{(151)}}
\qt@newcmd\qurantrans@bn@clix{অতএব আমাকে স্মরণ করো, আমিও তোমাদের স্মরণ করবো, আর আমার প্রতি কৃতজ্ঞ হও, আর আমাকে অস্বীকার করো না।\qt@no{(152)}}
\qt@newcmd\qurantrans@bn@clx{ওহে যারা ঈমান এনেছ! সাহায্য কামনা করো ধৈর্য ধরে ও নামায পড়ে! নিঃসন্দেহ আল্লাহ্ সবুরকারীদের সাথে আছেন।\qt@no{(153)}}
\qt@newcmd\qurantrans@bn@clxi{আর যারা আল্লাহ্‌র পথে নিহত হয় তাদের বলো না -- “মৃত,” বরং জীবন্ত, যদিও তোমরা বুঝতে পারছ না।\qt@no{(154)}}
\qt@newcmd\qurantrans@bn@clxii{আর আমরা নিশ্চয়ই তোমাদের পরীক্ষা করবো কিছু ভয়, আর ক্ষুধা দিয়ে, আর মাল-আসবাবের, আর লোকজনের আর ফল- ফসলের লোকসান ক’রে। আর সুসংবাদ দাও ধৈর্যশীলদের --\qt@no{(155)}}
\qt@newcmd\qurantrans@bn@clxiii{যারা তাদের উপরে কোনো আপদ-বিপদ ঘটলে বলে -- “নিঃসন্দেহ আমরা আল্লাহ্‌র জন্যে, আর অবশ্যই আমরা তাঁরই কাছে প্রত্যাবর্তনকারী।”\qt@no{(156)}}
\qt@newcmd\qurantrans@bn@clxiv{এইসব -- তাদের উপরে তাদের প্রভুর কাছ থেকে রয়েছে আশবাদ ও করুণা, আর এরা নিজেরাই সুপথগামী।\qt@no{(157)}}
\qt@newcmd\qurantrans@bn@clxv{নিঃসন্দেহ সাফা ও মারওয়াহ্ আল্লাহ্‌র নিদর্শনসমূহের অন্যতম। তাই যে কেউ গৃহে হজ করে বা উমরাহ করে তার জন্য অপরাধ হবে না যদি সে এ দুইয়ের মাঝে তওয়াফ করে। আর যে কেউ স্বতঃপ্রণোদিতভাবে সৎকর্ম করে, আল্লাহ্ নিশ্চয়ই অতি দানশীল, সর্বজ্ঞাতা।\qt@no{(158)}}
\qt@newcmd\qurantrans@bn@clxvi{নিঃসন্দেহ যারা গোপন করে রাখে পরিস্কার প্রমাণাবলী ও পথনির্দেশের যে-সব আমরা অবতারণ করেছিলাম এগুলো জণগণের জন্য ধর্মগন্থে সুস্পষ্টভাবে বিবৃত করার পরেও, তারাই! -- যাদের আল্লাহ্ লানৎ দেন, আর তাদের বঞ্চিত করে লানৎকারীরা --\qt@no{(159)}}
\qt@newcmd\qurantrans@bn@clxvii{তারা ছাড়া যারা তওবা করে ও সংশোধন করে, আর প্রকাশ করে, তাহলে তারাই! -- তাদের প্রতি আমি ফিরি আর আমি বারবার ফিরি, অফুরন্ত ফলদাতা।\qt@no{(160)}}
\qt@newcmd\qurantrans@bn@clxviii{অবশ্য যারা অবিশ্বাস পোষণ করে আর মারা যায় তারা অবিশ্বাসী থাকা অবস্থায়, তাদের ক্ষেত্রে -- তাদের উপরে ধিক্কার হোক আল্লাহ্‌র, ও ফিরিশ্‌তাদের ও জনগণের সম্মিলিতভাবে, --\qt@no{(161)}}
\qt@newcmd\qurantrans@bn@clxix{এতে তারা অবস্থান করবে। তাদের উপর থেকে যাতনা লাঘব করা হবে না, আর তারা বিরামও পাবে না।\qt@no{(162)}}
\qt@newcmd\qurantrans@bn@clxx{আর তোমাদের উপাস্য একক খোদা, তিনি ছাড়া কোনো উপাস্য নেই, রহমান, রহীম।\qt@no{(163)}}
\qt@newcmd\qurantrans@bn@clxxi{নিঃসন্দেহ মহাকাশমন্ডল ও পৃথিবীর সৃষ্টির মধ্যে, আর রাত ও দিনের বিবর্তনে, আর জাহাজে -- যা সাগরের মাঝে চলাচল করে যার দ্বারা মানুষের মুনাফা হয় তার মধ্যে, আর আল্লাহ্ আকাশ থেকে বৃষ্টির যা-কিছু পাঠান তাতে, তারপর তার দ্বারা মাটিকে তার মরণের পরে প্রাণসঞ্চার করেন, আর তাতে ছড়িয়ে দেন হরেক রকমের জীবজন্ত, আর আকাশ ও পৃথিবীর মাঝে নিয়ন্ত্রিত বাতাস ও মেঘের গতিবেগে বিশেষ নিদর্শন রয়েছে বিচার-বুদ্ধি থাকা লোকের জন্য।\qt@no{(164)}}
\qt@newcmd\qurantrans@bn@clxxii{আর মানুষের মাঝে কেউ-কেউ আল্লাহ্‌কে ছেড়ে অন্যকে মুরব্বী বলে গ্রহণ করে, তারা তাদের ভালোবাসে আল্লাহ্‌কে ভালোবাসার ন্যায়। তবে যারা ঈমান এনেছে আল্লাহ্‌র প্রতি তাদের ভালোবাসা প্রবলতর। আফসোস! যারা অন্যায় করে তারা যদি দেখতো -- যখন শাস্তি তারা দেখতে পায়, তখন সমস্ত ক্ষমতা পুরোপুরিভাবে আল্লাহ্‌র, আর আল্লাহ্ নিঃসন্দেহ শাস্তি দিতে কঠোর।\qt@no{(165)}}
\qt@newcmd\qurantrans@bn@clxxiii{চেয়ে দেখো! যাদের অনুসরণ করা হতো তারা যারা অনুসরণ করেছিল তাদের অস্বীকার করবে, আর তারা দেখতে পাবে শাস্তি, আর তাদের মধ্যেকার সম্পর্ক ছিন্ন হয়ে যাবে।\qt@no{(166)}}
\qt@newcmd\qurantrans@bn@clxxiv{আর যারা অনুসরণ করেছিল তারা বলবে -- ''হায়, আমরা যদি ফেরত পালা পেতাম তাহলে আমরা তাদের থেকে বিচ্ছিন্ন করতাম, যেমন তারা আমাদের থেকে বিচ্ছিন্ন করেছে।’’ এইভাবে আল্লাহ্ তাদের ক্রিয়াকলাপ তাদের দেখান তাদের জন্য তীব্র আক্ষেপরূপে। আর তারা আগুন থেকে বহিষ্কৃত হবে না।\qt@no{(167)}}
\qt@newcmd\qurantrans@bn@clxxv{ওহে মানবজাতি! পৃথিবীতে যা-কিছু হালাল ও পবিত্র আছে তা থেকে পানাহার করো, আর শয়তানের পদচিহ্ন অনুসরণ করো না। নিঃসন্দেহ সে তোমাদের জন্য প্রকাশ্য শত্রু।\qt@no{(168)}}
\qt@newcmd\qurantrans@bn@clxxvi{সে তোমাদের কেবল প্ররোচনা দেয় মন্দ ও অশালীনতার প্রতি, আর আল্লাহ্‌র বিরুদ্ধে তাই বলতে যা তোমরা জানো না।\qt@no{(169)}}
\qt@newcmd\qurantrans@bn@clxxvii{আর যখন তাদের বলা হয় -- ''অনুসরণ করো যা প্রত্যাদেশ আল্লাহ্ অবতারণ করেছেন’’, তারা বলে -- ''না, আমরা অনুসরণ করি তার যার উপরে আমাদের পিতৃপুরুষদের দেখেছি।’’ কি! যদিও তাদের পিতৃপুরুষদের বুদ্ধিবিবেচনা কিছুই ছিল না, আর তারা পথনির্দেশ গ্রহণ করে নি?\qt@no{(170)}}
\qt@newcmd\qurantrans@bn@clxxviii{আর যারা অবিশ্বাস পোষণ করে তাদের উপমা হচ্ছে তার দৃষ্টান্তের মতো যে ডাক দেয় এমন কতককে যে আওয়াজ ও চেচাঁমেচি ছাড়া আর কিছু শোনে না। বধিরতা, বোবা, অন্ধত্ব, কাজেই তারা বুঝে না।\qt@no{(171)}}
\qt@newcmd\qurantrans@bn@clxxix{ওহে যারা ঈমান এনেছ! পবিত্র জিনিস থেকে পানাহার করো যা তোমাদের খেতে দিয়েছি, আর আল্লাহ্‌কে ধন্যবাদ দাও, যদি তোমরা তাঁরই এবাদত করো।\qt@no{(172)}}
\qt@newcmd\qurantrans@bn@clxxx{তিনি তোমাদের কারণে নিষেধ করেছেন কেবল যা নিজে মারা গেছে, আর রক্ত, আর শূকরের মাংস, আর যার উপরে আল্লাহ্ ছাড়া অন্য নাম উচ্চারিত হয়েছে। কিন্তু যে চাপে পড়েছে, অবাধ্য হয় নি বা মাত্রা ছাড়ায় নি, তার উপরে কোনো পাপ হবে না। নিঃসন্দেহ আল্লাহ্ ত্রাণকর্তা, অফুরন্ত ফলদাতা!\qt@no{(173)}}
\qt@newcmd\qurantrans@bn@clxxxi{অবশ্যই যারা ধর্মগ্রন্থের মধ্যে থেকে আল্লাহ্ যা নাযিল করেছেন তা লুকিয়ে রাখে আর এর দ্বারা তুচ্ছ বস্তু কিনে নেয়, -- এরাই তাদের পেটে আগুন ছাড়া আর কিছু গেলে না, আর কিয়ামতের দিন আল্লাহ্ তাদের সাথে কথাবার্তা বলবেন না, বা তাদের শুদ্ধও করবেন না, আর তাদের জন্য রয়েছে ব্যথাদায়ক শাস্তি।\qt@no{(174)}}
\qt@newcmd\qurantrans@bn@clxxxii{এরাই তারা যারা কিনে নেয় হেদায়তের বিনিময়ে ভ্রান্তপথ ও পরিত্রাণের পরিবর্তে শাস্তি। কাজেই কতো তাদের ধৈর্য আগুনের প্রতি!\qt@no{(175)}}
\qt@newcmd\qurantrans@bn@clxxxiii{তা-ই! কারণ আল্লাহ্ গ্রন্থখানা নাযিল করেছেন সত্যের সাথে। আর যারা গ্রন্থখানার মতবিরোধ করে তারা নিঃসন্দেহ একগুঁয়েমিতে বহুদূর পৌঁছেছে\qt@no{(176)}}
\qt@newcmd\qurantrans@bn@clxxxiv{ধার্মিকতা তাতে নয় যে তোমাদের মুখ পূব বা পশ্চিম দিকে ফেরাও, তবে ধর্মনিষ্ঠা হচ্ছে যে আল্লাহর প্রতি ঈমান আনে, আর আখেরাতের দিনের প্রতি, আর ফিরিশ্‌তাদের প্রতি, আর গ্রন্থখানিতে, আর নবীদের প্রতি; আর যে তাঁর প্রতি মহব্বত বশতঃ ধন দান করে আ‌ত্মীয়-স্বজনদের, আর এতীমদের, আর মিসকিনদের, আর পথচারীদের, আর ভিখারীদের, আর দাসদের মুক্তিপণ বাবদ, আর যে নামায কায়েম করে ও যাকাত আদায় করেচ আর যারা প্রতিজ্ঞা করার পরে তাদের ওয়াদা রক্ষা করে, আর অভাব-অনটনে ও আপৎকালে ও আতঙ্কের সময়ে ধৈর্যশীলদের। এরাই তারা যারা সত্যনিষ্ঠ, আর এরা নিজেরাই ধর্মপরায়ণ।\qt@no{(177)}}
\qt@newcmd\qurantrans@bn@clxxxv{ওহে যারা ঈমান এনেছ! তোমাদের প্রতি হত্যার ক্ষেত্রে প্রতিশোধের বিধান দেয়া হয়েছে। স্বাধীন ব্যক্তির উপরে স্বাধীন ব্যক্তির ক্ষেত্রে, আর দাসের উপরে দাসের ক্ষেত্রে, আর নারীর উপরে নারীর ক্ষেত্রে। তবে যাকে কিছুটা রেহাই দেয়া হয় তার ভাইয়ের তরফ হতে, তাহলে বিচার হবে ন্যায্যভাবে, আর তার প্রতি ক্ষতিপূরণ দিতে হবে উদারভাবে। -- এটি তোমাদের প্রভুর কাছ থেকে লঘু-ব্যবস্থা ও করুণা। কাজেই এরপরে যে সীমালঙ্ঘন করবে তার জন্য রয়েছে ব্যথাদায়ক শাস্তি।\qt@no{(178)}}
\qt@newcmd\qurantrans@bn@clxxxvi{আর তোমাদের জন্য প্রতিশোধের বিধানে রয়েছে জীবন, হে জ্ঞানবান ব্যক্তিগণ! যাতে তোমরা ধর্মপরায়ণতা অবলন্বন করো।\qt@no{(179)}}
\qt@newcmd\qurantrans@bn@clxxxvii{তোমাদের জন্য বিধিবদ্ধ করা গেল যে যখন তোমাদের কারোর কাছে মৃত্যু হাজির হয় সে ধন ছেড়ে যাচ্ছে, তবে যেন ওসিয়ৎ করা হয় মাতাপিতা ও নিকটা‌ত্মীয়দের জন্য ন্যায়সঙ্গত-ভাবে; এটা মুত্তকীদের উপরে একটি কর্তব্য।\qt@no{(180)}}
\qt@newcmd\qurantrans@bn@clxxxviii{আর যে কেউ এটি বদলে ফেলে তা শোনার পরেও, তা হলে তার পাপ বর্তাবে তাদের উপরে যারা এটি বদলাবে। নিঃসন্দেহ আল্লাহ্ সর্বশ্রোতা, সর্বজ্ঞাতা।\qt@no{(181)}}
\qt@newcmd\qurantrans@bn@clxxxix{কিন্তু যদি কেউ আশংকা করে যে ওসিয়ৎকারীর তরফ থেকে ভুল বা অন্যায় হচ্ছে, কাজেই তাদের মধ্যে বোঝাপড়া করে, তাহলে তার উপরে কোনো দোষ হবে না। নিঃসন্দেহ আল্লাহ্ ত্রাণকর্তা, অফুরন্ত ফলদাতা।\qt@no{(182)}}
\qt@newcmd\qurantrans@bn@cxc{ওহে যারা ঈমান এনেছ! তোমাদের উপরে রোযা বিধিবদ্ধ করা গেল যেমন বিধান করা হয়েছিল যারা তোমাদের আগে এসেছে তাদের উপরে, যাতে তোমরা ধর্মভীরুতা অবলন্বন করো, --\qt@no{(183)}}
\qt@newcmd\qurantrans@bn@cxci{নির্দিষ্টসংখ্যক দিনের জন্য। কিন্তু তোমাদের মধ্যে যে কেউ অসুস্থ অথবা সফরে আছে সে সেই সংখ্যক অন্য দিন-গুলোতে। আর যারা এ অতি কষ্টসাধ্য বোধ করে -- প্রতিবিধান হল একজন মিসকিনকে খাওয়ানো। কিন্তু যে কেউ স্বতঃপ্রবৃত্ত হয়ে ভালো কাজ করে, সেটি তার জন্য ভালো। আর যদি তোমরা রোযা রাখো তবে তোমাদের জন্য অতি উত্তম, -- যদি তোমরা জানতে।\qt@no{(184)}}
\qt@newcmd\qurantrans@bn@cxcii{রমযান মাস এইটি যাতে কুরাআন নাযিল হয়েছিল, -- মানবগোষ্ঠীর জন্য পথপ্রদর্শক হিসেবে, আর পথনির্দেশের স্পষ্টপ্রমানরূপে, আর ফুরকান। কাজেই তোমাদের মধ্যে যে কেউ মাসটির দেখা পাবে সে যেন এতে রোযা রাখে। আর যে অসুস্থ বা সফরে আছে যে সেই সংখ্যক অন্য দিনগুলোতে। আল্লাহ্ তোমাদের জন্য সুবিধা চান, আর তিনি তোমাদের জন্য কষ্টকর অবস্থা চান না, আর তোমরা যেন এই সংখ্যা সম্পূর্ণ করো, আর যাতে আল্লাহ্‌র মহিমা কীর্তন করো তোমাদের যে পথনির্দেশ তিনি দিয়েছেন সেইজন্য, আর তোমরা যেন কৃতজ্ঞতা জ্ঞাপন করো।\qt@no{(185)}}
\qt@newcmd\qurantrans@bn@cxciii{আর যখন আমার বান্দারা আমার সন্বন্ধে তোমাকে জিজ্ঞাসা করে, তখন -- ''দেখো! আমি নিঃসন্দেহ অতি নিকটে।’’ আমি প্রার্থনাকারীর প্রার্থনার জবাব দিই যখনি সে আমাকে আহ্বান করে। কাজেই তারা আমার প্রতি সাড়া দিক আর আমাতে ঈমান আনুক, -- যাতে তারা সুপথে চলতে পারে।\qt@no{(186)}}
\qt@newcmd\qurantrans@bn@cxciv{রোযার রাত্রে তোমাদের স্ত্রীদের কাছে গমন তোমাদের জন্য বৈধ করা গেল। তারা তোমাদের জন্য পোশাক আর তোমরা তাদের জন্য পোশাক। আল্লাহ্ জানেন যে তোমরা তোমাদের নিজেদের প্রবঞ্চনা করছিলে, তাই তিনি তোমাদের উপরে ফিরেছেন ও তোমাদের ভুলকে উপেক্ষা করেছেন। সুতরাং এখন তাদের সাহচর্য ভোগ করো, আর আল্লাহ্ তোমাদের জন্য যা নির্ধারিত করেছেন তা অনুসরণ করে চল। আর আহার করো ও পান করো যতক্ষণ না তোমাদের কাছে স্পষ্ট হয়ে ওঠে ভোরবেলাতে সাদা কিরণ কালো ছায়া থেকে, তারপর রোযা সম্পূর্ণ করো রাত্রি সমাগম পর্যন্ত। আর তাদের স্পর্শ করো না যখন তোমরা মসজিদে ই'তিকাফ করো। এ হচ্ছে আল্লাহ্‌র সীমা, কাজেই সে-সবের নিকটে যেয়ো না। এইভাবে আল্লাহ্ তাঁর আয়াতসমূহ মানুষের জন্য সুস্পষ্ট করে দিয়েছেন যাতে তারা ধর্মপরায়ণতা অবলন্বন করে।\qt@no{(187)}}
\qt@newcmd\qurantrans@bn@cxcv{আর তোমাদের সম্পত্তি পরস্পরের মধ্যে জালিয়াতি করে গ্রাস করো না, আর এগুলো বিচারকদের কাছে পেশ করো না যাতে লোকের সম্পত্তির কিছুটা অন্যায়ভাবে গিলে ফেলতে পারো, তাও তোমরা জেনেবুঝে।\qt@no{(188)}}
\qt@newcmd\qurantrans@bn@cxcvi{তারা তোমাকে নতুন চাঁদ সন্বন্ধে জিজ্ঞাসা করছে। তুমি বলো -- ''এসব হচ্ছে নির্দিষ্ট সময় জনসাধারণের জন্য ও হজের জন্য।’’ আর ধার্মিকতা এ নয় যে তোমরা বাড়িতে প্রবেশ করবে তাদের পেছন দিক দিয়ে, বরং ধার্মিকতা হচ্ছে যে ধর্মভীরুতা অবলন্বন করে। তাই বাড়ীতে ঢোকো তাদের দরজা দিয়ে, আর আল্লাহ্‌তে ভয়-শ্রদ্ধা করো যেন তোমরা সফলকাম হতে পার।\qt@no{(189)}}
\qt@newcmd\qurantrans@bn@cxcvii{আর আল্লাহ্‌র পথে তোমরা যুদ্ধ করো তাদের বিরুদ্ধে যারা অন্যায়ভাবে তোমাদের সঙ্গে যুদ্ধ করে, আর সীমালংঘন করো না। নিঃসন্দেহ আল্লাহ্ সীমালংঘনকারীদের ভালোবাসেন না।\qt@no{(190)}}
\qt@newcmd\qurantrans@bn@cxcviii{আর তাদের হত্যা করো যেখানেই তোমারা তাদের দেখা পাও, আর তাদের তাড়িয়ে দাও যেখান থেকে তারা তোমাদের তাড়িয়ে দিয়েছিল, আর উৎপীড়ন যুদ্ধের চেয়ে নিকৃষ্টতর। কিন্তু তাদের হত্যা করো না পবিত্র-মসজিদের আশেপাশে যে পর্যন্ত না তারা সেখানে তোমাদের সঙ্গে যুদ্ধ করে, কাজেই তারা যদি তোমাদের সঙ্গে যুদ্ধ করে তবে তোমরাও তাদের সাথে লড়বে। এই হচ্ছে অবিশ্বাসীদের প্রাপ্য।\qt@no{(191)}}
\qt@newcmd\qurantrans@bn@cxcix{কিন্তু তারা যদি ক্ষান্ত হয় তবে আল্লাহ্ নিঃসন্দেহ ত্রাণকর্তা, অফুরন্ত ফলদাতা।\qt@no{(192)}}
\qt@newcmd\qurantrans@bn@cc{আর তাদের সাথে লড়বে যে পর্যন্ত না উৎপীড়ন বন্ধ হয়, আর ধর্ম হচ্ছে আল্লাহ্‌র জন্য। সুতরাং তারা যদি ক্ষান্ত হয় তবে যুদ্ধ-বিগ্রহ চলবে না শুধু অত্যাচারীদের সাথে ছাড়া।\qt@no{(193)}}
\qt@newcmd\qurantrans@bn@cci{পবিত্র মাস পবিত্র মাসের খাতিরে, আর সব নিষিদ্ধ ব্যাপারে প্রতিশোধ নিতে হবে। কাজেই যে কেউ তোমাদের উপরে আক্রমণ চালায়, তোমরাও তবে তাদের উপরে আঘাত হানবে সেইভাবে যেমনটা তারা তোমাদের উপরে আঘাত করেছিল। আর আল্লাহ্‌কে ভয়-শ্রদ্ধা করবে, আর জেনে রেখো নিঃসন্দেহ আল্লাহ্ ধর্মভীরুদের সাথে আছেন।\qt@no{(194)}}
\qt@newcmd\qurantrans@bn@ccii{আর আল্লাহ্‌র রাস্তায় খরচ করো, আর তোমাদের নিজহাতে তোমাদের ধ্বংসের মধ্যে ফেলো না, বরং ভালো করো, নিঃসন্দেহ আল্লাহ্ মঙ্গলকারীদের ভালোবাসেন।\qt@no{(195)}}
\qt@newcmd\qurantrans@bn@cciii{আর আল্লাহ্‌র জন্য সম্পূর্ণ করো হজ এবং উমরাহ। কিন্তু যদি বাধা পাও, তবে কুরবানির যা-কিছু পাওয়া যায় তাই, আর তোমাদের মাথা কামাবে না যতক্ষণ না কুরবানি তার গন্তব্যস্থানে পৌঁছেছে কিন্তু তোমাদের মধ্যে যদি কেউ অসুস্থ হয় অথবা তার মাথায় রোগ থাকে, তবে প্রতিবিধান হচ্ছে রোযা রেখে বা সদকা দিয়ে বা কুরবানি ক’রে। কিন্তু যখন তোমরা নিরাপদ বোধ করবে তখন যে উমরাহ্‌কে হজের সঙ্গে সংযোজন ক’রে লাভবান হতে চায়, সে যেন কুরবানির যা-কিছু পায় তাই। কিন্তু যে পায় না, রোযা হচ্ছে হজের সময়ে তিনদিন আর তোমরা যখন ফিরে এস তখন সাত, -- এই হলো পুরো দশ। এটা তার জন্য যার পরিবার পবিত্র- মজজিদে হাজির থাকে না। আর আল্লাহ্‌কে ভয়-ভক্তি করো, আর জেনে রেখো যে নিঃসন্দেহ আল্লাহ্ প্রতিফলদানে কঠোর।\qt@no{(196)}}
\qt@newcmd\qurantrans@bn@cciv{হজ হয় কয়েকটি সুবিখ্যাত মাসে, কাজেই যে কেউ এই সময়ে হজ করার সংকল্প করে তার জন্য এ-সবের মধ্যে স্ত্রী-গমন বা দুষ্টামি থাকবে না, বা হজের মধ্যে তর্কাতর্কি চলবে না। আর ভালো যা-কিছু তোমরা কর, আল্লাহ্ তা জানেন। আর পাথেয় সংগ্রহ করো, নিঃসন্দেহ শ্রেষ্ঠ পাথেয় হচ্ছে ধর্মপরায়ণতা। অতএব আমাকে ভয়-শ্রদ্ধা করো, হে জ্ঞানের অধিকারীসব!\qt@no{(197)}}
\qt@newcmd\qurantrans@bn@ccv{তোমাদের উপরে কোনো অপরাধ হবে না যদি বা তোমরা তোমাদের প্রভুর কাছে দৌলত কামানোর চেষ্টা করো। তারপর তোমরা যখন আরাফাত থেকে জোট বেধে ফিঁরবে তখন মাশ'আরিল-হারাম এর নিকটে আল্লাহ্‌কে স্মরণ করো; আর তাঁকে স্মরণ করো যেমন তিনি তোমাদের পথনির্দেশ দিয়েছেন, যদিও এর আগে নিঃসন্দেহ তোমরা ছিলে পথভ্রষ্টদের অন্তর্ভুক্ত।\qt@no{(198)}}
\qt@newcmd\qurantrans@bn@ccvi{তারপর তোমরা তাড়াতাড়ি চল যেখান থেকে জনতা এগিয়ে চলে, আর আল্লাহ্‌র কাছে পরিত্রাণ খোঁজো, নিঃসন্দেহ আল্লাহ্ ত্রাণকর্তা, অফুরন্ত ফলদাতা।\qt@no{(199)}}
\qt@newcmd\qurantrans@bn@ccvii{তারপর যখন তোমাদের পুণ্যানুষ্ঠান শেষ কর তখন আল্লাহ্‌র গুণগান করো, যেমন তোমরা তোমাদের পূর্বপুরুষদের জয়গান গাইতে, -- বরং তার চাইতেও বেশী গুণকীর্তন করো। কিন্তু মানুষের মাঝে এমনও লোক আছে যে বলে -- ''আমাদের প্রভু! এই দুনিয়াতে আমাদের দাও।’’ অতএব আখেরাতে তাদের জন্য কোনো ভাগ থাকবে না।\qt@no{(200)}}
\qt@newcmd\qurantrans@bn@ccviii{আর তাদের মধ্যে এমনও আছে যে বলে -- ''আমাদের প্রভু! এই দুনিয়াতে আমাদের ভালো জিনিস অর্পণ করো, এবং আখেরাতেও ভালো জিনিস, আর আমাদের রক্ষা করো আগুনের শাস্তি থেকে।’’\qt@no{(201)}}
\qt@newcmd\qurantrans@bn@ccix{এরাই -- তাদের জন্য আছে ভাগ যা তারা অর্জন করেছে তা থেকে। আর আল্লাহ্ হিসেব-নিকেশে তৎপর।\qt@no{(202)}}
\qt@newcmd\qurantrans@bn@ccx{আর আল্লাহ্‌কে স্মরণ করো নির্ধারিত দিনগুলোতে। কিন্তু যে দু’দিনে তাড়াতাড়ি করে, তাতে তার অপরাধ হবে না, আর যে দেরী করে তার উপরেও কোনো অপরাধ হবে না, -- যে ভয়-ভক্তি করে। আর তোমরা আল্লাহ্‌কে ভয়-ভক্তি করো, আর জেনে রেখো নিঃসন্দেহ তোমরা তাঁরই কাছে একত্রিত হবে।\qt@no{(203)}}
\qt@newcmd\qurantrans@bn@ccxi{আর মানুষের মধ্যে এমনও আছে যার দুনিয়াদারির কথাবার্তা তোমাকে তাজ্জব করে দেয়, আর সে আল্লাহ্‌কে সাক্ষী মানে তার অন্তরে যা আছে সে-সন্বন্ধে, অথচ সে-ই হচ্ছে প্রতিদ্বন্দ্বীদের মধ্যে সবচেয়ে মারা‌ত্মক।\qt@no{(204)}}
\qt@newcmd\qurantrans@bn@ccxii{আর সে যখন ফিরে যায় তখন সে দেশের মধ্যে দৌড়াদৌড়ি করে তাতে ফসাদ বাঁধাতে এবং ফসল ও পশুপাল বিনষ্ট করতে। আর আল্লাহ্ ফসাদ পছন্দ করেন না।\qt@no{(205)}}
\qt@newcmd\qurantrans@bn@ccxiii{আর যখন তাকে বলা হয় -- ''আল্লাহ্‌কে ভয়-ভক্তি করো,’’ অহংকার তাকে নিয়ে চলে পাপের মধ্যে, কাজেই জাহান্নাম হচ্ছে তার হিসেব-নিকেশ, -- আর নিশ্চয়ই মন্দ সেই বিশ্রাম-স্থান।\qt@no{(206)}}
\qt@newcmd\qurantrans@bn@ccxiv{আর মানুষের মাঝে এমনও আছে যে নিজের সত্তাকে বিক্রি করে দিয়েছে আল্লাহ্‌র সন্তষ্টি কামনা ক’রে। আর আল্লাহ্ পরম স্নেহময় বান্দাদের প্রতি।\qt@no{(207)}}
\qt@newcmd\qurantrans@bn@ccxv{ওহে যারা ঈমান এনেছ! সম্পূর্ণরূপে আ‌ত্মসমর্পণে দাখিল হও, আর শয়তানের পদচিহ্ন অনুসরণ করো না। নিঃসন্দেহ সে তোমাদের জন্য প্রকাশ্য শত্রু।\qt@no{(208)}}
\qt@newcmd\qurantrans@bn@ccxvi{কিন্তু যদি তোমরা পিছলে পড় তোমাদের কাছে স্পষ্ট প্রমাণাবলী আসবার পরেও, তবে জেনে রেখো -- নিঃসন্দেহ আল্লাহ মহাশক্তিশালী, পরমজ্ঞানী।\qt@no{(209)}}
\qt@newcmd\qurantrans@bn@ccxvii{তারা এছাড়া আর কিসের প্রতীক্ষা করে যে তাদের কাছে আল্লাহ্ আসবেন মেঘের ছায়ায়, আর ফিরিশ্‌তারাও, আর বিষয়টির নিস্পত্তি হয়ে গেছে? আর আল্লাহ্‌র কাছেই সব ব্যাপার ফিরে যায়।\qt@no{(210)}}
\qt@newcmd\qurantrans@bn@ccxviii{ইসরাইলের বংশধরদের জিজ্ঞাসা করো -- স্পষ্ট নিদর্শন-গুলো থেকে কতো না আমরা তাদের দিয়েছিলাম! আর যে কেউ আল্লাহ্‌র নিয়ামত বদল করে তা তার কাছে আসার পরে, তা হলে নিঃসন্দেহ আল্লাহ্ প্রতিফল দিতে কঠোর!\qt@no{(211)}}
\qt@newcmd\qurantrans@bn@ccxix{যারা অবিশ্বাস পোষণ করে তাদের কাছে এই দুনিয়ার জীবন মনোরম ঠেকে, আর তারা মস্করা করে যারা ঈমান এনেছে তাদের। আর যারা ধর্মপরায়ণতা অবলন্বন করে তারা কিয়ামতের দিন ওদের উপরে থাকবে। আর আল্লাহ্ যাকে ইচ্ছে করেন বে-হিসাব রিযেক দান করেন।\qt@no{(212)}}
\qt@newcmd\qurantrans@bn@ccxx{মানবগোষ্ঠী হচ্ছে একই জাতি। কাজেই আল্লাহ্ উত্থাপন করলেন নবীদের সুসংবাদদাতারূপে এবং সতর্ককারীরূপে, আর তাঁদের সঙ্গে তিনি অবতারণ করেছিলেন কিতাব সত্যতার সাথে যাতে তা মীমাংসা করতে পারে লোকদের মধ্যে যে-বিষয়ে তারা মতবিরোধ করত। আর কেউ এতে মতবিরোধ করে না তারা ছাড়া যাদের এ দেয়া হয়েছিল তাদের কাছে স্পষ্ট প্রমাণ আসার পরেও তাদের পরস্পরের মধ্যে বিদ্রোহাচরণ বশতঃ। তাই যারা ঈমান এনেছে, আল্লাহ্ তাদের হেদায়ত করলেন আপন এখতিয়ারে সেই সত্যতে যে বিষয়ে তারা মতবিরোধ করছিল। আর আল্লাহ্ যাকে ইচ্ছে করেন তাকে সহজ-সঠিক পথের দিকে পরিচালিত করেন।\qt@no{(213)}}
\qt@newcmd\qurantrans@bn@ccxxi{অথবা তোমরা কি বিবেচনা করো যে তোমরা বেহেশতে দাখিল হতে পারবে যতক্ষণ না তোমাদের উপরেও তোমাদের আগে যারা গত হয়েছে তাদের ন্যায় না বর্তায়? তাদের আক্রমণ করেছিল দারুণ বিপর্যয় এবং চরম দুর্দশা, আর তারা কেঁপেছিল, শেষ পর্যন্ত রসূল ও তাঁর সঙ্গে যারা ঈমান এনেছিল তারা বললে -- ''আল্লাহ্‌র সাহায্য কখন?’’ আল্লাহ্‌র সাহায্য অবশ্যই নিকটবর্তী নয় কি?\qt@no{(214)}}
\qt@newcmd\qurantrans@bn@ccxxii{তারা তোমায় জিজ্ঞেস করছে কি তারা খরচ করবে। বলো -- ''ভালো জিনিস যা-কিছু তোমরা খরচ করো তা মাতাপিতার জন্য ও নিকট-আ‌ত্মীয়দের ও এতিমদের ও মিসকিনদের ও পথচারীদের জন্য। আর ভালো কাজ যা-কিছু কর, নিঃসন্দেহ আল্লাহ্ সে-সন্বন্ধে সর্বজ্ঞাতা।\qt@no{(215)}}
\qt@newcmd\qurantrans@bn@ccxxiii{তোমাদের জন্য যুদ্ধ বিধিবদ্ধ করা হলো, অথচ তোমাদের জন্য তা অপ্রীতিকর। আর হতে পারে তোমরা কোনো-কিছু অপছন্দ করলে, অথচ তা তোমাদের জন্য মঙ্গলজনক, আবার হতে পারে তোমরা কোনো-কিছু ভালোবাসলে, অথচ তা তোমাদের জন্য মন্দ। আর আল্লাহ জানেন, যদিও তোমরা জানো না।\qt@no{(216)}}
\qt@newcmd\qurantrans@bn@ccxxiv{তারা তোমাকে পবিত্র মাস সম্পর্কে প্রশ্ন করছে -- তাতে যুদ্ধ করার ব্যাপারে। বলো -- ''এতে যুদ্ধ করা গুরুতর, কিন্তু আল্লাহ্‌র রাস্তা থেকে ফিরিয়ে রাখা, আর তাঁর প্রতি ও পবিত্র মসজিদের প্রতি অবিশ্বাস পোষণ করা, এবং তার বাসিন্দাদের সেখান থেকে বের করে দেয়া আল্লাহ্‌র কাছে আরও গুরুতর! আর উৎপীড়ন হত্যার চেয়ে গুরুতর। আর তারা তোমাদের সাথে যুদ্ধ করা থামাবে না যতক্ষণ না তারা তোমাদের ধর্ম থেকে তোমাদের ফিরিয়ে নিতে পারে, -- যদি তারা পারে। আর তোমাদের মধ্যে থেকে যে তার ধর্ম থেকে ফিরে যায় ও মারা যায় অবিশ্বাসী থাকা অবস্থায়, তা হলে এরাই -- এদের সব কাজ এই দুনিয়াতে ও আখেরাতে বৃথা যাবে। আর তারাই হচ্ছে আগুনের অধিবাসী, তারা এতে থাকবে দীর্ঘকাল।\qt@no{(217)}}
\qt@newcmd\qurantrans@bn@ccxxv{নিঃসন্দেহ যারা ঈমান এনেছিল ও যারা হিজরত করেছিল, এবং আল্লাহ্‌র রাস্তায় কঠোর সংগ্রাম করেছিল, -- এরাই আশা রাখে আল্লাহ্‌র করুণার। আর আল্লাহ্ ত্রাণকর্তা, অফুরন্ত ফলদাতা।\qt@no{(218)}}
\qt@newcmd\qurantrans@bn@ccxxvi{তারা তোমাকে নেশা ও জুয়া সন্বন্ধে জিজ্ঞাসা করছে। বলো -- ''এই দুয়েতেই আছে মহাপাপ ও মানুষের জন্য মুনাফা, কিন্তু তাদের পাপ তাদের মুনাফার চাইতে গুরুতর। আর তারা তোমায় সওয়াল করে কী তারা খরচ করবে। বলো -- ''যা বাড়তি থাকে।’’ এইভাবে আল্লাহ্ তোমাদের জন্য বাণীসমূহ স্পষ্ট করেন যাতে তোমরা ভেবে দেখতে পার, --\qt@no{(219)}}
\qt@newcmd\qurantrans@bn@ccxxvii{এই দুনিয়া ও আখেরাতের সন্বন্ধে। আর তারা তোমায় এতিমদের সম্পর্কে প্রশ্ন করছে। বলো -- ''তাদের জন্য সুব্যবস্থা করা উত্তম।’’ আর তোমরা যদি তাদের সঙ্গে অংশীদার হও তবে তারা তোমাদের ভাই। আর আল্লাহ্ হিতকারীদের থেকে ফেসাদকারীদের জানেন । আর আল্লাহ্ যদি ইচ্ছা করতেন তবে নিশ্চয়ই তোমাদের বিপন্ন করতে পারতেন। নিঃসন্দেহ আল্লাহ্ মহাশক্তিশালী, পরমজ্ঞানী।\qt@no{(220)}}
\qt@newcmd\qurantrans@bn@ccxxviii{আর মুশরিক নারীদের বিয়ে করো না যে পর্যন্ত না তারা ঈমান আনে । আর নিঃসন্দেহ একজন মুমিন দাসীও একজন মুশরিক নারীর চেয়ে ভালো, যদিও বা সে তোমাদের মোহিত করে দেয়। আর বিয়ে দিয়ো না মুশরিকদের সাথে যে পর্যন্ত না তারা ঈমান আনে, কেননা নিঃসন্দেহ একজন মুমিন গোলামও একজন মুশরিকের চেয়ে উত্তম, যদিও সে তোমাদের তাজ্জব করে দেয়। এই সব আমন্ত্রণ করে আগুনের প্রতি, আর আল্লাহ্ আহ্বান করেন বেহেশতের দিকে এবং পরিত্রাণের দিকে তাঁর নিজ ইচ্ছায়, আর তিনি মানুষের জন্য তাঁর নির্দেশাবলী সুস্পষ্ট করে দেন যেন তারা মনোযোগ দেয়।\qt@no{(221)}}
\qt@newcmd\qurantrans@bn@ccxxix{তারা তোমাকে ঋতুস্রাব সন্বন্ধে জিজ্ঞাসা করছে। বলো -- ''ইহা অনিষ্টকর, কাজেই ঋতুকালে স্ত্রীদের থেকে আলাদা থাকবে, এবং তাদের নিকটবর্তী হয়ো না যে পর্যন্ত না তারা পরিস্কার হয়ে যায়। তারপর যখন তারা নিজেদের পরিস্কার করে নেয় তখন তাদের সঙ্গে মিলিত হও যেভাবে আল্লাহ্ তোমাদের আদেশ দিয়েছেন।’’ নিঃসন্দেহ আল্লাহ্ ভালোবাসেন তাদের যারা তাঁর দিকে ফেরে, আর তিনি ভালবাসেন পরিচ্ছন্নতা রক্ষাকারীদের।\qt@no{(222)}}
\qt@newcmd\qurantrans@bn@ccxxx{তোমাদের স্ত্রীরা তোমাদের জন্য এক ক্ষেতখামার। সুতরাং তোমরা যখন-যেমন ইচ্ছে কর তোমাদের ক্ষেতখামারে গমন করো। আর তোমাদের নিজেদের জন্যে অগ্রিম ব্যবস্থা অবলন্বন করো। আর আল্লাহ্‌কে ভয়-ভক্তি করবে, আর জেনে রেখো -- নিশ্চয় তাঁর সঙ্গে তোমাদের মোলাকাত হবে। আর সুসংবাদ দাও মুমিনদের।\qt@no{(223)}}
\qt@newcmd\qurantrans@bn@ccxxxi{আর আল্লাহ্‌কে প্রতিবন্ধক বানিয়ো না তোমাদের শপথের দ্বারা তোমাদের ভালো কাজ করার বেলা ও ভয়ভক্তি দেখাতে, ও লোকদের মধ্যে শান্তি প্রতিষ্ঠার ক্ষেত্রে। আর আল্লাহ্ সর্বশ্রোতা, সর্বজ্ঞাতা।\qt@no{(224)}}
\qt@newcmd\qurantrans@bn@ccxxxii{আল্লাহ্ তোমাদের পাকড়াবেন না তোমাদের শপথগুলোর মধ্যে যা খেলো, কিন্তু তিনি তোমাদের পাকড়াও করবেন যা তোমাদের হৃদয় অর্জন করেছে। আর আল্লাহ্ ত্রাণকর্তা, পরম সহিষ্ণু।\qt@no{(225)}}
\qt@newcmd\qurantrans@bn@ccxxxiii{যারা তাদের স্ত্রীদের থেকে ''ইলা’’ করে, চার মাসকাল অপেক্ষা করতে হবে, কিন্তু তারা যদি ফিরে যায়, তা হলে আল্লাহ্ নিশ্চয় ত্রাণকর্তা, অফুরন্ত ফলদাতা।\qt@no{(226)}}
\qt@newcmd\qurantrans@bn@ccxxxiv{আর যদি তারা সিদ্ধান্ত নিয়ে থাকে তালাকের, তবে নিঃসন্দেহ আল্লাহ্ সর্বশ্রোতা, সর্বজ্ঞাতা।\qt@no{(227)}}
\qt@newcmd\qurantrans@bn@ccxxxv{আর তালাকপ্রাপ্তা নারীরা নিজেদের প্রতীক্ষায় রাখবে তিন ঋতুকাল। আর তাদের জন্য বৈধ হবে না লুকিয়ে রাখা যা আল্লাহ্ তাদের গর্ভে সৃষ্টি করেছেন, যদি তারা আল্লাহ্‌তে ও শেষ দিনে ঈমান আনে। আর তাদের স্বামীদের অধিকতর হক্ আছে তাদের ইতিমধ্যে ফিরিয়ে নেবার, যদি তারা মিটমাট করতে চায়। আর স্ত্রীদের তেমন অধিকার আছে যেমন আছে তাদের উপরে ন্যায়সঙ্গতভাবে। অবশ্য পুরুষদের অবস্থান তাদের কিছুটা উপরে। আর আল্লাহ্ মহাশক্তিশালী, পরমজ্ঞানী!\qt@no{(228)}}
\qt@newcmd\qurantrans@bn@ccxxxvi{তালাক দুইবার, তারপর পুরোদস্তুর রক্ষণ নয়ত সুন্দরভাবে বিদায় দান। আর তোমাদের জন্য বৈধ নয় তাদের যা দিয়েছ তা থেকে কিছু ফিরিয়ে নেয়া, যদি না দুজনেই আশঙ্কা করে যে আল্লাহ্‌র নির্দেশিত সীমা কায়েম রাখা তাদের পক্ষে সম্ভবপর নয়। কিন্তু তোমরা যদি আশঙ্কা কর যে তারা আল্লাহ্‌র গন্ডির ভেতরে কায়েম থাকতে পারবে না, তা হলে তাদের জন্যে অপরাধ হবে না যার বিনিময়ে সে মুক্ত হতে চায়। এইসব হচ্ছে আল্লাহ্‌র নির্দেশিত গন্ডি, অতএব এ-সব লঙ্ঘন করো না, আর যারা আল্লাহ্‌র গন্ডি লঙ্ঘন করে তারা নিজেরাই হচ্ছে অন্যায়কারী।\qt@no{(229)}}
\qt@newcmd\qurantrans@bn@ccxxxvii{তারপর যদি সে তাকে তালাক দেয় তবে এরপর সে তার জন্য বৈধ হবে না যে পর্যন্ত না সে অন্য স্বামীকে বিবাহ করে। এখন যদি সেও তাকে তালাক দিয়ে দেয় তাহলে তাদের উভয়ের অপরাধ হবে না যদি তারা পরস্পরের কাছে ফিরে আসে, -- যদি তারা বিবেচনা করে যে তারা আল্লাহ্‌র গন্ডির মধ্যে থাকতে পারবে। আর এগুলো হচ্ছে আল্লাহ্‌র নির্দেশিত সীমা, -- তিনি তা সুস্পষ্ট করে দেন সেই লোকদের জন্য যারা জানে।\qt@no{(230)}}
\qt@newcmd\qurantrans@bn@ccxxxviii{আর যখন স্ত্রীদের তালাক দাও, আর তারা তাদের ইদ্দত পূর্ণ করে, তারপর হয় তাদের রাখবে সদয়ভাবে, নয় তাদের মুক্তি দেবে সদয়ভাবে। আর তাদের আটকে রেখো না ক্ষতি করার জন্যে, -- যার ফলে তোমরা সীমা লঙ্ঘন করবে, আর যে তাই করে সে নিশ্চয় তার নিজের প্রতি অন্যায় করে। আর আল্লাহ্‌র প্রত্যাদেশকে তামাশার বস্তু করে নিয়ো না, আর স্মরণ করো তোমাদের উপরে আল্লাহ্‌র নিয়ামত ও তোমাদের কাছে যা তিনি অবতারণ করেছেন কিতাব ও হিক্‌মত, যার দ্বারা তিনি তোমাদের উপদেশ দিচ্ছেন। আর আল্লাহ্‌কে ভয়ভক্তি করবে, আর জেনে রেখো -- নিশ্চয় আল্লাহ্ সব-কিছু সম্পর্কে সর্বজ্ঞাতা।\qt@no{(231)}}
\qt@newcmd\qurantrans@bn@ccxxxix{আর যখন তোমরা স্ত্রীদের তালাক দাও, আর তারা তাদের ইদ্দত পূর্ণ করে, তখন তাদের বাধা দিয়ো না তাদের স্বামীদের বিয়ে করতে, যদি তারা নিজেদের মধ্যে রাজী হয় সঙ্গতভাবে। এইভাবে এরদ্বারা উপদেশ দেয়া হচ্ছে তোমাদের মধ্যে তাকে যে আল্লাহ্‌তে ও শেষ দিনে ঈমান আনে। এইটি তোমাদের জন্য অধিকতর পরিচ্ছন্ন ও পবিত্রতর। আর আল্লাহ্ জানেন অথচ তোমরা জানো না।\qt@no{(232)}}
\qt@newcmd\qurantrans@bn@ccxl{আর মায়েরা নিজ সন্তানদের পুরো দু’বছর স্তন্য খেতে দেবে, -- যে চায় স্তন্যদান পুরো করতে। তার পিতার উপরে দায়িত্ব তাদের খাওয়ানো ও পরানো ন্যায়সঙ্গতরূপে। কোনো লোকেরই উচিত নয় এমন দায়িত্ব আরোপ করা যা তার ক্ষমতার অতিরিক্ত। মাতাকেও যেন সন্তানের জন্য ক্ষতিগ্রস্ত হতে না হয়, আর যার রসে সন্তান জন্মেছে তাকেও যেন নিজের সন্তানের দরুন, আর উত্তরাধিকারীর উপরে দায়িত্ব তার অনুরূপ করা। কিন্তু যদি দুজনেই ইচ্ছা করে মাই ছাড়াতে, উভয়ের মধ্যে সম্মতিক্রমে এবং পরামর্শক্রমে, তবে তাদের কোনো অপরাধ হবে না। আর যদি তোমরা চাও তোমাদের সন্তানদের জন্য ধাইমা নিযুক্ত করতে, তাতেও তোমাদের কোনো অপরাধ হবে না যে পর্যন্ত তোমরা রাজী থাকো যা তোমরা পুরোদস্তুর প্রদান করবে। আর আল্লাহ্‌কে ভয়ভক্তি করবে, আর জেনে রেখো -- নিঃসন্দেহ তোমরা যা করো আল্লাহ্ তার দর্শক।\qt@no{(233)}}
\qt@newcmd\qurantrans@bn@ccxli{আর তোমাদের মধ্যে যারা মারা যায় ও রেখে যায় স্ত্রীদের, তারা নিজেদের অপেক্ষায় রাখবে চার মাস ও দশ। তারপর তারা যখন তাদের সময়ের মোড়ে পৌঁছে যায় তখন তোমাদের কোনো অপরাধ হবে না যা তারা নিজেদের জন্য করে ন্যায়সঙ্গতভাবে। আর তোমরা যা কর সে-সন্বন্ধে আল্লাহ্ ওয়াকিবহাল।\qt@no{(234)}}
\qt@newcmd\qurantrans@bn@ccxlii{আর তোমাদের উপরে অপরাধ হবে না তোমরা নারীদের বিবাহের প্রস্তাবে যা আভাসে ইঙ্গিতে প্রকাশ কর, অথবা গোপন রাখো তোমাদের অন্তরে। আল্লাহ্ জানেন যে তোমরা তাদের স্মরণ করবে, কিন্তু ভদ্রভাবে কথাবার্তা বলা ছাড়া গোপনে তাদের সাথে ওয়াদা করো না, আর বিবাহবন্ধন পাকাপাকি করো না যে পর্যন্ত না তাদের নির্ধারিত সময়সীমা পেছোঁয়! আর জেনে রেখো -- আল্লাহ্ নিশ্চয়ই জানেন যা তোমাদের অন্তরে আছে, অতএব তাঁর সম্পর্কে সতর্ক হও, আর জেনে রেখো যে নিঃসন্দেহ আল্লাহ্ ত্রানকর্তা, পরম সহিষ্ণু।\qt@no{(235)}}
\qt@newcmd\qurantrans@bn@ccxliii{তোমাদের অপরাধ হবে না যদি তোমরা তালাক দাও স্ত্রীদের যাদের এখনও তোমরা স্পর্শ করো নি বা দেয় যাদের জন্য ধার্য করো নি। আর তাদের জন্য ব্যবস্থা করো, ধনবানের ক্ষেত্রে তার সামর্থ্য অনুসারে ও অভাবীর ক্ষেত্রে তার সামর্থ্য অনুসারে, ব্যবস্থা হবে পুরোদস্তুরভাবে। সৎকর্মীদের জন্য একটি কর্তব্য।\qt@no{(236)}}
\qt@newcmd\qurantrans@bn@ccxliv{কিন্তু যদি তোমরা তাদের তালাক দাও তাদের স্পর্শ করার আগে এবং ইতিমধ্যে দেয় তাদের জন্য ধার্য করে ফেলেছ, যা ধার্য করেছ তার অর্ধেক, যদি না তারা মাফ করে দেয় অথবা তারা মাফ করে দেয় যাদের হাতে রয়েছে বিবাহ-গ্রন্থি। আর যদি তোমরা দাবি ছেড়ে দাও তবে তা ধর্মপরায়ণতার অধিকতর নিকটবর্তী। আর তোমাদের পরস্পরের মধ্যে সদয়তা ভুলে যেয়ো না। নিঃসন্দেহ তোমরা যা করো আল্লাহ্ তার দর্শক।\qt@no{(237)}}
\qt@newcmd\qurantrans@bn@ccxlv{হেফাজত করো নামাযগুলোর, বিশেষ করে সর্বোৎকৃষ্ট নামায, আর তোমরা খাড়া থেকো আল্লাহ্‌র উদ্দেশ্যে পরম বিনয়ে।\qt@no{(238)}}
\qt@newcmd\qurantrans@bn@ccxlvi{কিন্তু যদি তোমরা আশঙ্কা কর তবে পায়ে চলে বা ঘোড়ায় চড়ে, কিন্তু যখন তোমরা নিরাপত্তা বোধ কর তখন আল্লাহ্‌কে স্মরণ করো যে ভাবে তিনি তোমাদের শিখিয়েছেন -- যা তোমরা ইতিপূর্বে জানতে না।\qt@no{(239)}}
\qt@newcmd\qurantrans@bn@ccxlvii{আর তোমাদের মধ্যে যারা মারা যায় এবং রেখে যায় স্ত্রীদের, তাদের স্ত্রীদের জন্য এক বছরের ভরণ-পোষণের ওসিয়ৎ হওয়া চাই, তাদের বহিস্কার না ক’রে, কিন্তু তারা যদি চলে যায় তবে তোমাদের উপরে অপরাধ হবে না যা তারা নিজেদের ব্যাপারে সুসঙ্গতভাবে করে। আর আল্লাহ্ মহাশক্তিশালী, পরমজ্ঞানী।\qt@no{(240)}}
\qt@newcmd\qurantrans@bn@ccxlviii{আর তালাক দেয়া নারীদের জন্যে ব্যবস্থা চাই পুরোদস্তুর মতে, ধর্মপরায়ণদের জন্য একটি কর্তব্য।\qt@no{(241)}}
\qt@newcmd\qurantrans@bn@ccxlix{এইভাবে আল্লাহ্ তোমাদের জন্য তাঁর বাণীসমূহ সুস্পষ্ট করে দিয়েছেন যেন তোমরা বুঝতে পার।\qt@no{(242)}}
\qt@newcmd\qurantrans@bn@ccl{তুমি কি তাদের বিষয়ে ভাব নি যারা তাদের বাড়িঘর থেকে বেরিয়ে এসেছিল মৃত্যুর ভয়ে, আর তারা হাজারে হাজারে ছিল? তারপর আল্লাহ্ তাদের বললেন -- ''তোমরা মরো’’ এরপর তিনি তাদের জীবনদান করলেন। নিঃসন্দেহ আল্লাহ্ অবশ্যই মানুষের প্রতি অশেষ করুণাময়, কিন্তু অধিকাংশ লোকেই শুকুরানা আদায় করে না।\qt@no{(243)}}
\qt@newcmd\qurantrans@bn@ccli{আর আল্লাহ্‌র রাস্তায় সংগ্রাম করো, আর জেনে রেখো -- নিঃসন্দেহ আল্লাহ্ সর্বশ্রোতা, সর্বজ্ঞাতা।\qt@no{(244)}}
\qt@newcmd\qurantrans@bn@cclii{কে আছে যে আল্লাহ্‌কে কর্জ দেবে সর্বাঙ্গসুন্দর ঋণ? তিনি তখন তা বাড়িয়ে দেবেন তার জন্য বহুগুণিত করে। আর আল্লাহ্ গ্রহণ করেন ও তিনি সম্প্রসারণ করেন আর তাঁরই কাছে তোমাদের ফিরিয়ে নেয়া হবে।\qt@no{(245)}}
\qt@newcmd\qurantrans@bn@ccliii{তুমি কি মূসার পরবর্তীকালে ইসরাইলের বংশধরদের প্রধানদের বিষয়ে ভেবে দেখ নি, যখন তারা তাদের নবীকে বলেছিল -- ''আমাদের জন্য একজন রাজা উত্থাপন করো যেন আমরা আল্লাহ্‌র পথে লড়তে পারি’’? তিনি বলেছিলেন -- ''এমনটা কি তোমাদের হবে যে তোমাদের জন্য যুদ্ধ বিধিবদ্ধ করা হলে তোমরা যুদ্ধ করবে না?’’ তারা বলেছিল -- ''আমাদের কী হয়েছে যে আমরা আল্লাহ্‌র পথে যুদ্ধ করবো না যখন আমরা আমাদের বাড়িঘর ও সন্তান-সন্ততি থেকে বিতাড়িত হয়েছি?’’ কিন্তু যখন তাদের জন্য যুদ্ধ বিধিবদ্ধ করা হলো, তারা ফিরে দাঁড়াল তাদের মধ্যের অল্প কয়েকজন ছাড়া। আর আল্লাহ্ অন্যায়কারীদের সন্বন্ধে সর্বজ্ঞাতা।\qt@no{(246)}}
\qt@newcmd\qurantrans@bn@ccliv{আর তাদের নবী তাদের বলেছিলেন -- ''নিশ্চয়ই আল্লাহ্ এখন তোমাদের জন্য তালুতকে রাজা করেছেন।’’ তারা বললে -- ''সে কেমন ক’রে আমাদের উপরে রাজত্ব পেতে পারে যখন রাজত্বে তার চাইতে আমাদেরই বেশী দাবী, আর তাকে ধনদৌলতের প্রাচুর্যও প্রদান করা হয় নি? তিনি বললেন -- ''নিশ্চয় আল্লাহ্ তাকে মনোনীত করেছেন তোমাদের উপরে, আর তিনি তাকে অগাধভাবে প্রাচুর্যও দিয়েছেন জ্ঞানে ও দেহে। আর আল্লাহ্ তাঁর রাজত্ব দেন যাকে ইচ্ছে করেন, কারণ আল্লাহ্ সর্বব্যাপ্ত, সর্বজ্ঞাতা।’’\qt@no{(247)}}
\qt@newcmd\qurantrans@bn@cclv{আর তাদের নবী তাদের বলেছিলেন -- ''নিঃসন্দেহ তার রাজত্বের লক্ষণ এই যে তোমাদের কাছে আসবে 'তাবুত’ যাতে আছে তোমাদের প্রভুর তরফ থেকে প্রশান্তি, এবং মূসার বংশধরেরা ও হারূনের অনুগামীরা যা ছেড়ে গেছেন তার শ্রেষ্ঠাংশ, -- তা বহন করছে ফিরিশ্‌তারা। নিঃসন্দেহ এতে আছে তোমাদের জন্য নিদর্শন যদি তোমরা বিশ্বাসী হয়ে থাকো।\qt@no{(248)}}
\qt@newcmd\qurantrans@bn@cclvi{তারপর তালুত যখন সৈন্যদল নিয়ে অভিযান করলেন তখন বললেন -- ''নিশ্চয় আল্লাহ্ তোমাদের পরীক্ষা করবেন একটি নদী দিয়ে; তাই যে কেউ তার থেকে পান করবে সে আমার নয়, আর যে এর স্বাদ গ্রহণ করবে না সে নিঃসন্দেহ আমার, শুধু সে ছাড়া যে তার হাতে কোষ-পরিমাণ পান করে।’’ কিন্তু তাদের অল্প কয়েকজন ছাড়া তারা তা থেকে পান করেছিল। তারপর তিনি যখন উহা পার হয়ে গেলেন, তিনি ও যারা তাঁর সাথে ঈমান এনেছে, তারা বললে -- ''আজ আমাদের শক্তি নেই জালুত এবং তার সৈন্যদলের বিরুদ্ধে।’’ যারা নিশ্চিত ছিল যে তারা অবশ্যই আল্লাহ্‌র সাথে মুলাকাত করতে যাচ্ছে, তারা বললে -- ''কতবার ছোট দল আল্লাহ্‌র হুকুমে বড় দলকে পরাজিত করেছে, আর আল্লাহ্ অধ্যবসায়ীদের সাথে আছেন’’।\qt@no{(249)}}
\qt@newcmd\qurantrans@bn@cclvii{আর যখন তারা জালুতের ও তার সৈন্যদলের মুখোমুখি হলো, তারা বললে -- ''আমাদের প্রভু! আমাদের প্রতি অধ্যবসায় বর্ষণ করো, আর আমাদের পদক্ষেপ মজবুত করো, আর অবিশ্বাসী দলের বিরুদ্ধে সাহায্য করো।’’\qt@no{(250)}}
\qt@newcmd\qurantrans@bn@cclviii{অতএব আল্লাহ্‌র হুকুমে তারা তাদের পরাজিত করল, আর দাউদ হত্যা করলেন জালুতকে, আর আল্লাহ্ তাঁকে রাজত্ব ও জ্ঞান দিলেন, আর তাঁকে শেখালেন যা তিনি ইচ্ছা করলেন। আব মানুষদের যদি আল্লাহ্‌র প্রতিহতকরণ না হতো -- তাদের এক দলকে অন্য দলের দ্বারা -- তবে পৃথিবী নিঃসন্দেহ অরাজকতাপূর্ণ হতো। কিন্তু আল্লাহ্ সমস্ত সৃষ্টজগতের প্রতি অশেষ কৃপাময়।\qt@no{(251)}}
\qt@newcmd\qurantrans@bn@cclix{এইসব হচ্ছে আল্লাহ্‌র বাণী, আমরা তোমার কাছে তা পাঠ করছি যথাযথভাবে, আর নিঃসন্দেহ তুমি রসূলদের অন্যতম।\qt@no{(252)}}
\qt@newcmd\qurantrans@bn@cclx{এইসব রসূল -- তাঁদের কাউকে আমরা অপর কারোর উপরে শ্রেষ্ঠত্ব দিয়েছি। তাঁদের মধ্যে কারোর সাথে আল্লাহ্ কথা বলছেন এবং তাঁদের কাউকে তিনি বহুস্তর উন্নত করেছেন। আর আমরা মরিয়মের পুত্র ঈসাকে দিয়েছিলাম স্পষ্ট প্রমাণাবলী, আর আমরা তাঁকে বলীয়ান করি রূহুল ক্কুদুস্ দিয়ে। আর আল্লাহ্ যদি ইচ্ছা করতেন তবে তাঁদের পরবর্তীরা পরস্পর বিবাদ করতো না তাদের কাছে স্পষ্ট প্রমাণাবলী আসার পরেও, কিন্তু তারা মতবিরোধ করলো, কাজেই তাদের মধ্যে কেউ ঈমান আনলো ও তাদের কেউ অবিশ্বাস পোষণ করলো। কিন্তু আল্লাহ্ যদি ইচ্ছা করতেন তবে তারা পরস্পর লড়াই করতো না, কিন্তু আল্লাহ্ যা ইচ্ছা করেন তাই করে থাকেন।\qt@no{(253)}}
\qt@newcmd\qurantrans@bn@cclxi{ওহে যারা ঈমান এনেছ! আমরা তোমাদের যা রিযেক দিয়েছি তা থেকে তোমরা খরচ করো সেই দিন আসবার আগে যে দিন দরদস্তুর করা চলবে না, বা বন্ধুত্ব থাকবে না বা সুপারিশ টিকবে না। আর অবিশ্বাসীরা -- তারাই অন্যায়কারী।\qt@no{(254)}}
\qt@newcmd\qurantrans@bn@cclxii{আল্লাহ্ -- তিনি ছাড়া অন্য উপাস্য নেই, -- চিরজীবন্ত, সদা-বিদ্যমান, তন্দ্রা তাঁকে অভিভূত করতে পারে না, নিদ্রাও নয়। তাঁরই হচ্ছে যা-কিছু আছে মহাকাশমন্ডলে এবং যা-কিছু পৃথিবীতে। কে আছে যে তাঁর দরবারে সুপারিশ করতে পারে তার অনুমতি ছাড়া? তিনি জানেন কি আছে তাদের সামনে এবং কি আছে তাদের পেছনে; আর তাঁর জ্ঞানের কিছুই তারা ধারণা করতে পারে না তিনি যা ইচ্ছা করেন তা ব্যতীত। তাঁর মহাসিংহাসন মহাকাশমন্ডলী ও পৃথিবীতে ব্যাপ্ত; এদের উভয়ের হেফাজত তাঁকে ক্লান্ত করে না, আর তিনি সর্বোচ্চে অধিষ্ঠিত, মহামহিম।\qt@no{(255)}}
\qt@newcmd\qurantrans@bn@cclxiii{ধর্মে জবরদস্তি নেই, নিঃসন্দেহ সত্যপথ ভ্রান্তপথ থেকে সুস্পষ্ট করা হয়ে গেছে। অতএব যে তাগুতকে অস্বীকার করে এবং আল্লাহ্‌তে ঈমান আনে সেই তবে ধরেছে একটি শক্ত হাতল, -- তা কখনো ভাঙবার নয়। আর আল্লাহ্ সর্বশ্রোতা, সর্বজ্ঞাতা।\qt@no{(256)}}
\qt@newcmd\qurantrans@bn@cclxiv{আল্লাহ্ তাদের পৃষ্ঠপোষক যারা ঈমান এনেছে, তিনি অন্ধকার থেকে তাদের আলোতে বের করে আনেন। আর যারা অবিশ্বাস পোষণ করে তাদের পৃষ্ঠপোষক হচ্ছে তাগুত, তারা আলোক থেকে তাদের বের করে অন্ধকারের দিকে নিয়ে যায়। তারাই হচ্ছে আগুনের বাসিন্দা, তারা তাতে থাকবে দীর্ঘকাল।\qt@no{(257)}}
\qt@newcmd\qurantrans@bn@cclxv{তুমি কি তার কথা ভেবে দেখো নি যে ইব্রাহীমের সাথে তাঁর প্রভুর সন্বন্ধে ঝগড়া করছিল যেহেতু আল্লাহ্ তাঁকে রাজত্ব দিয়েছিলেন? স্মরণ করো! ইব্রাহীম বলেছিলেন -- ''আমার প্রভু তিনি যিনি জীবনদান করেন এবং মৃত্যু ঘটান।’’ সে বলল -- ''আমি জীবন দিয়ে রাখতে পারি এবং মৃত্যু ঘটাতে পারি।’’ ইব্রাহীম বলেছিলেন -- ''আল্লাহ্ কিন্তু সূর্যকে পূর্বদিক থেকে নিয়ে আসেন তুমি তাহলে তাকে পশ্চিমদিক থেকে নিয়ে এস।’’ এইভাবে সে হেরে গেল যে অবিশ্বাস পোষণ করেছিল। আর আল্লাহ্ জুলুমকারী জাতিকে হেদায়ত করেন না।\qt@no{(258)}}
\qt@newcmd\qurantrans@bn@cclxvi{অথবা, তাঁর কথা যিনি যাচ্ছিলেন এক শহরের পাশ দিয়ে, আর তা ভেঙ্গে পড়েছিল তার ছাদ সহ? তিনি বলেছিলেন -- ''কেমন ক’রে আল্লাহ্ একে পুনরুজ্জীবিত করবেন তার মৃত্যুর পরে?’’ এরপর আল্লাহ্ তাঁকে শতবৎসরকাল মৃতবৎ করে রাখলেন, তারপর তিনি তাঁকে পুনরুত্থিত করলেন। তিনি বললেন -- ''কত সময় তুমি কাটিয়েছ?’’ তিনি বললেন -- ''আমি কাটিয়েছি একটি দিন, বা এক দিনের কিছু অংশ।’’ তিনি বললেন -- ''না, তুমি কাটিয়েছ একশত বছর, কাজেই তোমার খাদ্য ও তোমার পানীয়ের দিকে তাকাও, বয়স উহাকে বয়স্ক করে নি, আর তোমার গাধার দিকে তাকাও, আর যেন তোমাকে মানবগোষ্ঠীর জন্য নিদর্শন করতে পারি, আর এই হাড়গুলোর দিকে তাকাও, কেমন ক’রে আমরা সে-সব গুছিয়েছি ও সেগুলোকে মাংস দিয়ে ঢেকেছি।’’ আর যখন তাঁর কাছে পরিস্কার হলো তিনি বললেন -- ''আমি এখন জানি যে আল্লাহ্ সব-কিছুর উপরে সর্বশক্তিমান।’’\qt@no{(259)}}
\qt@newcmd\qurantrans@bn@cclxvii{আর স্মরণ করো! ইব্রাহীন বললেন -- ''আমার প্রভু! আমাকে দেখাও কেমন করে তুমি মৃতকে জীবিত করো।’’ তিনি বললেন -- ''তুমি কি বিশ্বাস করো না?’’ তিনি বললেন,''না, তবে যাতে আমার হৃদয় শান্ত হয়।’’ তিনি বললেন -- ''তা হলে পাখীদের চারটি তুমি নাও ও তাদের তোমার প্রতি অনুগত করো, তারপর প্রতিটি পাহাড়ে তাদের এক একটি অংশ স্থাপন করো, তারপর তাদের ডাক দাও, তারা ছুটে আসবে তোমার কাছে। আর জেনে রেখো, নিঃসন্দেহ আল্লাহ্ মহাশক্তিশালী, পরমজ্ঞানী।’’\qt@no{(260)}}
\qt@newcmd\qurantrans@bn@cclxviii{যারা তাদের ধনসম্পত্তি আল্লাহ্‌র পথে খরচ করে তাদের উপমা হচ্ছে একটি শস্যবীজের উপমার ন্যায়, তা উৎপাদন করে সাতটি শিষ, প্রতিটি শিষে থাকে একশত শস্য। আর আল্লাহ্ বহুগুণিত করেন যার জন্য ইচ্ছা করেন, কারণ আল্লাহ্‌, মহাদানশীল সর্বজ্ঞাতা।\qt@no{(261)}}
\qt@newcmd\qurantrans@bn@cclxix{যারা তাদের ধনসম্পত্তি আল্লাহ্‌র পথে খরচ ক’রে, তারপর যা তারা খরচ করেছে তারা তার পশ্চাদ্ধাবন করে না কৃতজ্ঞতাপাশে আবদ্ধ করতে বা আঘাত হানতে, তাদের জন্য পুরস্কার আছে তাদের প্রভুর দরবারে, কাজেই তাদের উপরে কোনো ভয় নেই, আর তারা নিজেরা অনুতাপও করবে না।\qt@no{(262)}}
\qt@newcmd\qurantrans@bn@cclxx{সদয় আলাপ এবং ক্ষমা করা বহু ভালো সেই দানের চেয়ে যাকে অনুসরণ করা হয় উৎপীড়ন দিয়ে। আর আল্লাহ্ স্বয়ং-সমৃদ্ধ, ধৈর্যশীল।\qt@no{(263)}}
\qt@newcmd\qurantrans@bn@cclxxi{ওহে যারা ঈমান এনেছ! তোমাদের দানখয়রাতকে ব্যর্থ করে দিয়ো না কৃতজ্ঞতাপাশে আবদ্ধ করে ও আঘাত হেনে, তার মতো যে তার ধনসম্পত্তি খরচ করে লোকদের দেখানোর জন্যে এবং যে ঈমান আনে না আল্লাহ্‌র প্রতি ও আখেরাতের দিনে। কাজেই তার উদাহরণ হচ্ছে মসৃণ পাথরের উপমার মতো, যার উপরে আছে ধুলোমাটি, তখন তার উপরে নামে ঝড়বৃষ্টি, গতিকে তাকে ফেলে রাখে খালি করে! তারা যা অর্জন করেছে তার কোনো-কিছুর উপরেও তাদের কর্তৃত্ব থকে না। আর আল্লাহ্ অবিশ্বাসী লোকদের হেদায়ত করেন না।\qt@no{(264)}}
\qt@newcmd\qurantrans@bn@cclxxii{আর যারা তাদের ধনদৌলত খরচ করে আল্লাহ্‌র সন্তষ্টি কামনা ক’রে এবং তাদের আ‌ত্মার দৃঢ়প্রত্যয় জন্মাবার জন্যে, তাদের উদাহরণ হচ্ছে টিলার উপরের বাগানের উপমার মতো, যার উপরে নামে বৃষ্টিধারা, তাতে তার ফল দ্বিগুণ হয়ে আসে, আর যদি তাতে বৃষ্টিধারা নাও নামে তবে শিশিরপাত। আর তারা যা করে আল্লাহ্ তার দর্শক।\qt@no{(265)}}
\qt@newcmd\qurantrans@bn@cclxxiii{তোমাদের মধ্যে কি কেউ আশা করে যে তার খেজুর ও আঙ্গুরের বাগান হোক, যার নিচে দিয়ে বয়ে চলে ঝরনারাজি, অথচ তার সন্তানরা দুর্বল, এমতাবস্থায় তাকে পাকড়ালো ঘুর্ণিঝড়ে, যাতে রয়েছে আগুনের হলকা, ফলে তা পুড়ে গেল! এইভাবে আল্লাহ্ তোমাদের জন্য তাঁর বাণীসমূহ সুস্পষ্ট করে থাকেন যেন তোমরা চিন্তা করতে পার।\qt@no{(266)}}
\qt@newcmd\qurantrans@bn@cclxxiv{ওহে যারা ঈমান এনেছ! খরচ করো ভালো বিষয়বস্তু যা তোমরা উপার্জন কর, আর যা আমরা তোমাদের জন্য মাটি থেকে উৎপাদন করে থাকি তা থেকে, আর যা নিকৃষ্ট তা থেকে খরচ করতে সংকল্প করো না যখন তোমরা নিজেরা তার গ্রহণকারী হও না, এর প্রতি উপেক্ষা করা ছাড়া। আর জেনে রেখো, নিঃসন্দেহ আল্লাহ্ স্বয়ংসমৃদ্ধ, পরম প্রশংসিত।\qt@no{(267)}}
\qt@newcmd\qurantrans@bn@cclxxv{শয়তান তোমাদের দরিদ্রতার ধমক দেয়, আর তোমাদের তাড়া করে গর্হিত কাজে, অথচ আল্লাহ্ তোমাদের প্রতি‌শ্রুতি দেন তাঁর কাছ থেকে পরিত্রাণের এবং প্রাচুর্যের। আর আল্লাহ্‌, মহাবদান্য, সর্বজ্ঞাতা।\qt@no{(268)}}
\qt@newcmd\qurantrans@bn@cclxxvi{তিনি জ্ঞানদান করেন যাকে ইছে করেন, আর যাকে জ্ঞান দেওয়া হয় তাকে অবশ্যই অপার কল্যাণ দেওয়া হয়েছে। আর বোধশক্তির অধিকারী ছাড়া অন্য কেউ বুঝতে পারে না।\qt@no{(269)}}
\qt@newcmd\qurantrans@bn@cclxxvii{আর দানের জন্য যা-কিছু তোমরা খরচ কর, অথবা ব্রতের মধ্যে যাই তোমরা সংকল্প কর, নিঃসন্দেহ আল্লাহ্ তা জানেন। আর অন্যায়কারীদের জন্য কোনো সাহায্যকারী নেই।\qt@no{(270)}}
\qt@newcmd\qurantrans@bn@cclxxviii{তোমরা যদি দানখয়রাত প্রকাশ কর তবে তা কতো ভালো! আর যদি তা গোপন রেখে দরিদ্রদের দান কর তা হলে তোমাদের জন্য তা আরও মঙ্গলময়! আর তোমাদের গর্হিত ক্রিয়াকর্ম হতে তোমাদের এতে প্রায়শ্চিত হবে। আর তোমরা যা করছো আল্লাহ্ তার ওয়াকিফহাল।\qt@no{(271)}}
\qt@newcmd\qurantrans@bn@cclxxix{তাদের হেদায়ত করার দায়িত্ব তোমার উপরে নয়, কিন্তু আল্লাহ্ হেদায়ত করেন যাদের তিনি ইচ্ছা করেন। আর ভালো জিনিসের যা-কিছু তোমরা খরচ কর তা তোমাদের নিজেদের জন্য, আর তোমরা আল্লাহ্‌র সন্তষ্টি লাভের উদ্দেশ্যে ছাড়া খরচ করো না। আর ভালো যা-কিছু তোমরা খরচ কর তা তোমাদের পুরোপুরি প্রদান করা হবে, আর তোমাদের প্রতি অন্যায় করা হবে না।\qt@no{(272)}}
\qt@newcmd\qurantrans@bn@cclxxx{দরিদ্রদের জন্য যারা আল্লাহ্‌র পথে আটকা পড়ে রয়েছে, -- তারা পৃথিবীতে চলাফেরা করতে অপারগ। অজানা লোকে তাদের ধনী বলে ভাবে তাদের বিরত থাকার দরুন। তুমি তাদের চিনতে পারবে তাদের চেহারাতে। তারা লোকের কাছে ধরনা দিয়ে ভিক্ষা করে না। আর ভালো জিনিসের যা-কিছু তোমরা খরচ করো সে-সন্বন্ধে আল্লাহ্ নিশ্চয় সর্বজ্ঞাতা।\qt@no{(273)}}
\qt@newcmd\qurantrans@bn@cclxxxi{যারা তাদের ধনদৌলত দিবারাত্রি গোপনে ও প্রকাশ্যভাবে খরচ করে থাকে, তাদের জন্যে নিজ নিজ পুরস্কার রয়েছে তাদের প্রভুর দরবারে, আর তাদের উপরে কোনো ভয় নেই, আর তারা নিজেরা অনুতাপও করবে না।\qt@no{(274)}}
\qt@newcmd\qurantrans@bn@cclxxxii{যারা সুদ খায় তারা দাঁড়াতে পারে না তার মতো দাঁড়ানো ছাড়া যাকে শয়তান তার স্পর্শের দ্বারা পাতিত করেছে। এমন হবে কেননা তারা বলে -- ''ব্যবসা-বাণিজ্য তো সুদী-কারবারের মতোই।’’ কিন্তু আল্লাহ্ বৈধ করেছেন ব্যবসা-বাণিজ্য, অথচ নিষিদ্ধ করেছেন সুদখুরি। অতএব যার কাছে তারা প্রভুর তরফ থেকে এই নির্দেশ এসেছে এবং সে বিরত হয়েছে তার জন্যে যা গত হয়ে গেছে, আর তার ব্যাপার রইল আল্লাহ্‌র কাছে। আর যে ফিরে যায় তারাই হচ্ছে আগুনের বাসিন্দা, এতে তারা থাকবে দীর্ঘকাল।\qt@no{(275)}}
\qt@newcmd\qurantrans@bn@cclxxxiii{আল্লাহ্ সুদখুরিকে নিষ্ফল করেছেন, এবং দান-খয়রাতকে অগ্রগামী করেছেন। আর আল্লাহ্ সকল অবিশ্বাসী পাপীকে ভালোবাসেন না।\qt@no{(276)}}
\qt@newcmd\qurantrans@bn@cclxxxiv{নিঃসন্দেহ যারা ঈমান এনেছে এবং সৎকাজ করে, আর নামায কায়েম করে ও যাকাত দেয়, তাদের জন্যে নিজ নিজ পুরস্কার রয়েছে তাদের প্রভুর দরবারে, আর তাদের উপরে কোনো ভয় নেই, এবং তারা নিজেরা অনুতাপও করবে না।\qt@no{(277)}}
\qt@newcmd\qurantrans@bn@cclxxxv{ওহে যারা ঈমান এনেছ! আল্লাহ্‌কে ভয়-শ্রদ্ধা করো, আর সুদের বাবদ বকেয়া যা আছে তা ছেড়ে দাও, যদি তোমরা ঈমানদার হও।\qt@no{(278)}}
\qt@newcmd\qurantrans@bn@cclxxxvi{কিন্তু যদি তোমরা না করো তবে আল্লাহ্ ও তাঁর রসূলের তরফ থেকে সংগ্রামের ঘোষণা জেনে রেখো। আর যদি তোমরা ফেরো তবে তোমাদের জন্য রইল তোমাদের ধনসম্পত্তির আসলভাগ। অত্যাচার করো না এবং অত্যাচারিতও হয়ো না।\qt@no{(279)}}
\qt@newcmd\qurantrans@bn@cclxxxvii{আর যদি সে অসচ্ছল অবস্থায় থাকে তবে মূলতবি রাখো যতক্ষণ না সচ্ছলতা আসে। আর যদি দান করে দাও তবে তা তোমাদের জন্য আরো উত্তম, -- যদি তোমরা জানতে।\qt@no{(280)}}
\qt@newcmd\qurantrans@bn@cclxxxviii{আর হুশিয়াঁর হও সেই দিন সন্বন্ধে যেদিন তোমাদের ফিরিয়ে আনা হবে আল্লাহ্‌র তরফে, তখন প্রত্যেক লোককে পুরোপুরি প্রতিদান দেয়া হবে যা সে অর্জন করেছে, আর তাদের অন্যায় করা হবে না।\qt@no{(281)}}
\qt@newcmd\qurantrans@bn@cclxxxix{ওহে যারা ঈমান এনেছ! তোমরা যখন কোনো লেনদেন নির্দিষ্ট সময়ের জন্য পরস্পরের মধ্যে সম্পাদিত কর তখন তা লিখে রাখো, এবং লেখকজন যেন তোমাদের মধ্যে লিখে রাখুক ন্যাসঙ্গতভাবে, আর লেখক যেন লিখতে অস্বীকার না করে, কেননা আল্লাহ্ তাকে শিখিয়েছেন, কাজেই সে লিখুক। আর যার উপরে দেনার দায় সে বলে যাবে, আর সে তার প্রভু আল্লাহ্‌কে যেন ভয়-ভক্তি করে, এবং তা’ থেকে কোনো কিছু যেন কম না করে। কিন্তু যার উপরে দেনার দায় সে যদি অল্পবুদ্ধি বা জরাগ্রস্ত হয়, অথবা তা বলে যেতে অপারগ হয় তবে তার অভিভাবক বলে যাক ন্যায়সঙ্গতভাবে। আর তোমাদের পুরুষদের মধ্যে থেকে দুইজন সাক্ষীকে সাক্ষী মনোনীত করো। কিন্তু যদি দুইজন পুরুষকে পাওয়া না যায় তবে একজন পুরুষ ও দু’জন মহিলাকে -- তাদের মধ্যে থেকে যাদের তোমরা সাক্ষী মনোনীত কর, যাতে তাদের দুজনের একজন যদি ভুল করে তবে তাদের অন্য একজন মনে করিয়ে দেবে। আর সাক্ষীরা যেন অস্বীকার না করে যখন তাদের ডাকা হয়। আর এটা লিখে নিতে অমনোযোগী হয়ো না -- ছোট হোক বা বড় হোক -- তার মেয়াদ সমেত। এ আল্লাহ্‌র কাছে বেশী ন্যায়সঙ্গত ও সাক্ষ্যের জন্য বেশী নির্ভরযোগ্য, এবং তোমরা যাতে সন্দেহ না করো সেজন্যেও এ সব চাইতে ভালো, তবে হাতের কাছের পণ্যসামগ্রী হলে তোমাদের মধ্যে তার বিনিময়ের ক্ষেত্র ব্যতীত, তখন তোমাদের অপরাধ হবে না যদি তোমরা তা লেখাপড়া না করো। আর সাক্ষী রাখো যখন তোমরা একে অন্যের কাছে বিক্রি করো। আর লেখকজন যেন ক্ষতিগ্রস্ত না হয়, আর সাক্ষীও যেন না হয়। কিন্তু যদি তোমরা কর তবে তা নিশ্চয়ই তোমাদের পক্ষে দুস্কার্য হবে। আর আল্লাহ্‌কে ভয়-ভক্তি করো, কারণ আল্লাহ্ তোমাদের শিখিয়েছেন। আর আল্লাহ্ সব-কিছু সন্বন্দে সর্বজ্ঞাতা।\qt@no{(282)}}
\qt@newcmd\qurantrans@bn@ccxc{আর যদি তোমরা সফরে থাক এবং লেখক না পাও তবে বন্ধক নিতে পার। কিন্তু তোমাদের কেউ যদি অন্যের কাছে বিশ্বাসস্থাপন করে তবে যাকে বিশ্বাস করা হল সে তার আমানত ফেরত দিক, আর তার প্রভু আল্লাহ্‌কে ভয়-ভক্তি করুক। আর সাক্ষ্য গোপন করবে না, কারণ যে তা গোপন করে তার হৃদয় নিঃসন্দেহ পাপপূর্ণ। আর তোমরা যা করো আল্লাহ্ সে-সন্বন্ধে স র্বজ্ঞাতা।\qt@no{(283)}}
\qt@newcmd\qurantrans@bn@ccxci{আল্লাহ্‌রই যা-কিছু আছে মহাকাশমন্ডলে ও যা-কিছু আছে পৃথিবীতে। আর তোমাদের অন্তরে যা আছে তা প্রকাশ করো, বা তা লুকিয়ে রাখো, আল্লাহ্ তার জন্য তোমাদের হিসেব-নিকেশ নেবেন। কাজেই যাকে তিনি ইচ্ছা করবেন পরিত্রাণ করবেন এবং যাকে ইচ্ছা করবেন শাস্তিও দেবেন। আর আল্লাহ্ সব-কিছুর উপরে সর্বশক্তিমান।\qt@no{(284)}}
\qt@newcmd\qurantrans@bn@ccxcii{রসূল ঈমান এনেছেন যা তাঁর প্রভুর কাছ থেকে তাঁর কাছে অবতীর্ণ হয়েছে, আর বিশ্বাসীরাও। তারা সবাই ঈমান এনেছে আল্লাহ্‌তে, আর তাঁর ফিরিশ্‌তাগণে, আর তাঁর কিতাবসমূহে, আর তাঁর রসূলগণে, -- ''আমরা তাঁর রসূলদের কোনোজনের মধ্যে কোনো পার্থক্য করি না।’’ তারা আরও বলে -- ''আমরা শুনি আর আমরা পালন করি, হে আমাদের প্রভু! তোমার পরিত্রাণ, আর তোমারই কাছে গন্তব্যপথ।’’\qt@no{(285)}}
\qt@newcmd\qurantrans@bn@ccxciii{আল্লাহ্ কোনো সত্তার উপরে তার ক্ষমতার অতিরিক্ত দায়িত্ব চাপিয়ে দেন না। তার অনুকূলে রয়েছে সে যা-কিছু অর্জন করেছে, আর তার প্রতিকূলে রয়েছে যা-কিছু সে কামিয়েছে। ''আমাদের প্রভু, আমাদের পাকড়াও করো না যদি আমরা ভুলে যাই অথবা ভুল করি, হে আমাদের প্রভু! আর আমাদের উপরে তেমন বোঝা চাপিও না যেমন তুমি তা চাপিয়েছিলে তাদের উপরে যারা ছিল আমাদের পূর্ববর্তী, আমাদের প্রভু! আর আমাদের উপরে তেমন ভার তুলে দিয়ো না যার সামর্থ্য আমাদের নেই। অতএব তুমি আমাদের ক্ষমা করে দাও, আর আমাদের তুমি রক্ষা করে রাখো, আর আমাদের প্রতি তুমি করুণা বর্ষণ করো। তুমিই আমাদের পৃষ্ঠপোষক, অতএব অবিশ্বাসিগোষ্ঠীর বিরুদ্ধে আমাদের তুমি সাহায্য করো।’’\qt@no{(286)}}
\qt@newcmd\qurantrans@bn@ccxciv{\basmalahbn আলিফ, লাম, মীম।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@ccxcv{আল্লাহ্‌! তিনি ছাড়া অন্য উপাস্য নেই, -- চিরজীবন্ত, সদা-বিদ্যমান।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@ccxcvi{তিনি তোমার কাছে এই কিতাব অবতারণ করেছেন সত্যের সাথে, -- এর আগে যা এসেছিল তার সত্যসমর্থনরূপে আর তিনি তওরাত ও ইনজীল অবতারণ করেছিলেন --\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@ccxcvii{-- এর আগে, মানুষের জন্য এক একটি পথনির্দেশ হিসেবে, আর তিনি অবতারণ করেছেন এই ফুরকান। নিঃসন্দেহ যারা অবিশ্বাস করে আল্লাহ্‌র বাণীসমূহে, তাদের জন্য রয়েছে ভয়ঙ্কর শাস্তি। আর আল্লাহ্ মহাশক্তিশালী, প্রতিফল দান সুসমর্থ।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@ccxcviii{নিঃসন্দেহ আল্লাহ্ সম্পর্কে, -- তাঁর কাছে কিছুই লুকানো নেই পৃথিবীতে, আর মহাকাশেও নেই।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@ccxcix{তিনিই সেইজন যিনি তোমাদের গড়ে তোলেন জঠরের ভেতরে যেমন তিনি চান। তিনি ছাড়া কোনো উপাস্য নেই, -- মহাশক্তিশালী, পরমজ্ঞানী।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@ccc{তিনি সেইজন যিনি তোমার কাছে নাযিল করেছেন এই কিতাব, তার মধ্যে কতকগুলো আয়াত নির্দেশা‌ত্মক -- সেইসব হচ্ছে গ্রন্থের ভিত্তি, আর অপরগুলো রূপক। তবে তাদের বেলা যাদের অন্তরে আছে কুটিলতা তারা অনুসরণ করে এর মধ্যের যেগুলো রূপক, বিরোধ সৃষ্টির কামনায় এবং এর ব্যাখ্যা দেবার প্রচেষ্টায়। আর এর ব্যাখ্যা আর কেউ জানে না আল্লাহ্ ছাড়া। আর যারা জ্ঞানে দৃঢ়প্রতিষ্ঠিত তারা বলে -- ''আমরা এতে বিশ্বাস করি, এ-সবই আমাদের প্রভুর কাছ থেকে।’’ আর কেউ মনোযোগ দেয় না কেবল জ্ঞানবান ছাড়া।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@ccci{''আমাদের প্রভু! আমাদের অন্তরকে বিপথগামী করো না আমাদের হেদায়ত করার পরে, আর তোমার নিকট থেকে আমাদের করুণা প্রদান করো। নিঃসন্দেহ তুমি নিজেই পরম বদান্য।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@cccii{''আমাদের প্রভু! অবশ্যই তুমি লোকজনকে সমবেত করতে যাচ্ছো এমন এক দিনের প্রতি যার সন্বন্ধে কোনোও সন্দেহ নেই।’’ নিঃসন্দেহ আল্লাহ্ ধার্য স্থান-কালের কখনো খেলাফ করেন না।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@ccciii{যারা অবিশ্বাস পোষণ করে, নিঃসন্দেহ আর তারা নিজেরাই হচ্ছে আগুনের ইন্ধন --\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@ccciv{ফিরআউনের দলের সংগ্রামের মতো, এবং যারা তাদের পূর্ববর্তীদের অন্তর্ভুক্ত ছিল। তারা আমাদের প্রত্যাদেশসমূহে মিথ্যারোপ করেছিল, তাই আল্লাহ্ তাদের পাকড়াও করেছিলেন তাদের অপরাধের জন্য। আর আল্লাহ্ প্রতিফল দানে কঠোর।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@cccv{যারা অবিশ্বাস পোষণ করে তাদের বলো -- ''তোমরা শীঘ্রই পরাভূত হবে, আর তোমাদের তাড়িয়ে নেয়া হবে জাহান্নামের দিকে, আর মন্দ সেই বিশ্রামস্থান।’’\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@cccvi{ইতিপূর্বে তোমাদের জন্য একটি নিদর্শন এসেছিল দুই সৈন্যদলের মুখোমুখি হওয়ায় -- একদল যুদ্ধ করছিল আল্লাহ্‌র পথে, আর অন্য দল অবিশ্বাসী, এরা চোখের দেখায় তাদের দেখেছিল নিজেদের দ্বিগুণ। আর আল্লাহ্ তাঁর সাহায্য দিয়ে মদদ করেন যাকে তিনি ইচ্ছে করেন। নিঃসন্দেহ এতে শিক্ষণীয় বিষয় আছে দৃষ্টিবানদের জন্য।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@cccvii{মানুষের পক্ষে মনোরম ঠেকে নারীদের সাহচর্যের প্রতি আকর্ষণ, ও সন্তানসন্ততির, ও সোনারূপার জমানো ভান্ডারের, ও সুশিক্ষিত ঘোড়া ও গবাদি-পশুর ও ক্ষেতখামারের। এসব এই দুনিয়ার জীবনের উপকরণ, অথচ আল্লাহ্‌, -- তাঁর কাছে রয়েছে উত্তম নিভৃতে বিশ্রাম।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@cccviii{বলো -- ''তোমাদের কি এ-সবের চাইতে ভালো জিনিসের খবর দেব? যারা সুপথে চলে তাদের জন্য তাদের প্রভুর কাছে রয়েছ বাগানসমূহ, যাদের নীচে দিয়ে বয়ে যাচ্ছে ঝরনারাজি, সেখানে তারা থাকবে চিরকাল, আর পবিত্র সঙ্গিসাথী, আর আল্লাহ্‌র সন্তষ্টি। আর আল্লাহ্ বান্দাদের পর্যবেক্ষক --\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@cccix{''যারা বলে -- 'আমাদের প্রভু! আমরা নিশ্চয়ই ঈমান এনেছি, অতএব আমাদের অপরাধ থেকে তুমি আমাদের ত্রাণ করো, আর আগুনের যাতনা থেকে আমাদের রক্ষা করো’।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@cccx{''ধৈর্যশীল, আর সত্যপরায়ণ আর অনুগত, আর দানশীল, আর প্রাতে পরিত্রাণ প্রার্থী।’’\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@cccxi{আল্লাহ্ সাক্ষ্য দিচ্ছেন যে তিনি ছাড়া আর কোনো উপাস্য নেই, আর ফিরিশ্‌তারাও, আর জ্ঞানের অধিকারীরা ন্যায়ে অধিষ্ঠিত হয়ে। তিনি ছাড়া কোনো উপাস্য নেই, মহাশক্তিশালী, পরমজ্ঞানী।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@cccxii{নিঃসন্দেহ আল্লাহ্‌র কাছে ধর্ম হচ্ছে ইসলাম। আর যাদের কিতাব দেয়া হয়েছিল তারা মতভেদ করে নি, শুধু তারা ব্যতীত যাদের কাছে জ্ঞানের বিষয় আসার পরেও নিজেদের মধ্যে ঈর্ষাবিদ্বেষ করেছিল, আর যে কেউ আল্লাহ্‌র নির্দেশের প্রতি অবিশ্বাস পোষণ করে -- নিঃসন্দেহ আল্লাহ্ হিসেব-নিকেশে তৎপর।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@cccxiii{কিন্তু যদি তারা তোমার সাথে হুজ্জত করে, তবে বলো -- ''আমি সম্পূর্ণরূপে আল্লাহ্‌র দিকে আমার মুখ রুজু করেছি, আর যারা আমায় অনুসরণ করে।’’ আর তাদের বলো যাদের কিতাব দেয়া হয়েছে আর নিরক্ষরদের, ''তোমরা কি আ‌ত্মসমর্পণ করেছ?’’ অতএব যদি তারা আ‌ত্মসমর্পণ করে তবে অবশ্যই তারা হেদায়তপ্রাপ্ত হবে, আর যদি তারা ফিরে যায় তবে নিঃসন্দেহ তোমার উপরে হচ্ছে পৌঁছে দেয়া। আর আল্লাহ্ বান্দাদের দর্শক।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@cccxiv{নিঃসন্দেহ যারা আল্লাহ্‌র নির্দেশাবলীতে অবিশ্বাস পোষণ করে, আর নবীদের অন্যায়ভাবে হত্যা করতে যায়, আর মানুষদের মধ্যে যারা ন্যায় প্রতিষ্ঠার নির্দেশ দেয় তাদের হত্যা করতে যায়, -- তাদের তুমি সংবাদ দাও ব্যথাময় যাতনার।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@cccxv{এরাই তারা যাদের সব কাজ বৃথা হবে এই দুনিয়াতে ও আখেরাতে, আর তাদের জন্য সাহায্যকারীদের কেউ থাকবে না।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@cccxvi{তুমি কি তাদের দিকে চেয়ে দেখো নি যাদের কিতাবের কিছু অংশ দেয়া হয়েছে? তাদের আহ্বান করা হচ্ছে আল্লাহ্‌র কিতাবের দিকে, যেন ইহা তাদের মধ্যে মীমাংসা করতে পারে। তারপর তাদের মধ্যের একটি দল ফিরে গেল, ফলে তারা হল অগ্রাহ্যকারী।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@cccxvii{এমন ছিল, কারণ তারা বলে -- ''আগুন আমাদের কদাচ স্পর্শ করবে না গুনতির কয়েকটি দিন ছাড়া।’’ আর তাদের ধর্মমতে তারা নিজেদের প্রতারণা করছে তারা যা জালিয়াতি করে চলেছে তার দ্বারা।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@cccxviii{কাজেই কেমন হবে, যখন আমরা তাদের জমা করবো এমন এক দিনে যার সন্বন্ধে নেই কোনো সন্দেহ, এবং প্রত্যেক সত্ত্বাকে পুরোপুরি প্রতিদান করা হবে যা সে অর্জন করেছে, আর তাদের প্রতি অন্যায় করা হবে না?\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@cccxix{বলো -- ''হে আল্লাহ্‌! সাম্রাজ্যের মালিক! তুমি যাকে ইচ্ছা কর তাকে সাম্রাজ্য প্রদান করো, আবার যার কাছ থেকে ইচ্ছা কর রাজত্ব ছিনিয়ে নাও, আর যাকে খুশী সম্মানিত করো, আবার যাকে খুশী অপমানিত করো, -- তোমার হাতেই রয়েছে কল্যাণ। নিঃসন্দেহ তুমি সব-কিছুর উপরে সর্বশক্তিমান।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@cccxx{''তুমি রাতকে প্রবেশ করাও দিনে, আবার দিনকে প্রবেশ করাও রাতে, আর প্রাণবানদের উদগত করো মৃত থেকে, আবার মৃতকে উদগত করো জীবন্ত থেকে, আর যাকে ইচ্ছা কর বেহিসাব রিযেক দান করো।’’\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@cccxxi{বিশ্বাসীরা যেন বিশ্বাসীদের বাদ দিয়ে অবিশ্বাসীদের বন্ধুরূপে গ্রহণ না করে। আর যে এমন করবে আল্লাহ্‌র কাছ থেকে কোনো কিছুই থাকবে না, তবে যদি তোমরা তাদের থেকে সতর্কতা স্বরূপ হুশিয়াঁর হতে চাও। আর আল্লাহ্ তোমাদের তাঁর সন্বন্ধে সাবধান করেছেন, আর আল্লাহ্‌র দিকেই শেষ গতি।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@cccxxii{বলো -- ''তোমাদের অন্তরে যা আছে তা লুকিয়ে রাখো, অথবা তা প্রকাশ করো, আল্লাহ্ তা জানেন। আর তিনি জানেন যা-কিছু আছে মহাকাশে ও যা-কিছু পৃথিবীতে। আর আল্লাহ্ সব-কিছুর উপরে সর্বশক্তিমান।’’\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@cccxxiii{সেদিন প্রত্যেক সত্ত্বা দেখতে পাবে ভালো যা সে করেছে তা হাজির করা হয়েছে, আর মন্দ যা সে করেছে তাও, সে চাইবে -- তার মধ্যে আর ওর মধ্যে যদি সুদীর্ঘ ব্যবধান থাকতো! কিন্তু আল্লাহ্ তোমাদের সাবধান করছেন তাঁর সন্বন্ধে। আর আল্লাহ্ স্নেহময়।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@cccxxiv{বলো -- ''তোমরা যদি আল্লাহ্‌কে ভালোবাস তবে তোমরা আমায় অনুসরণ করো, তা হলে আল্লাহ্ তোমাদের ভালবাসবেন, আর তোমাদের পরিত্রাণ করবেন তোমাদের অপরাধ থেকে। কেননা আল্লাহ্ পরিত্রাণকারী, অফুরন্ত ফলদাতা।’’\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@cccxxv{বলো -- ''আল্লাহ্‌র আজ্ঞানুবর্তী হও আর রসূলেরও।’’ কিন্তু যদি তারা ফিরে যায়, তবে নিঃসন্দেহ আল্লাহ্ অবিশ্বাসকারীদের ভালোবাসেন না।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@cccxxvi{আল্লাহ্ নিশ্চয়ই আদম ও নূহ্ ও ইব্রাহীমের বংশধর, আর ইমরানের পরিবারকে মানবগোষ্ঠীর মধ্যে উচ্চ মর্যাদা দিয়েছিলেন,\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@cccxxvii{এক বংশ পরম্পরা -- একের থেকে তাদের অন্যরা। আর আল্লাহ্ সর্বশ্রোতা, সর্বজ্ঞাতা।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@cccxxviii{স্মরণ করো! ইমরান বংশের একজন স্ত্রীলোক বললে -- ''আমার প্রভু! আমার গর্ভে যে আছে তাকে আমি তোমার জন্য মানত করলাম একান্তভাবে, অতএব আমার থেকে কবুল করো, নিঃসন্দেহ তুমি নিজেই সর্বশ্রোতা, সর্বজ্ঞাতা।’’\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@cccxxix{তারপর যখন সে তাকে প্রসব করলো, সে বললে -- ''প্রভু! আমি কিন্তু তাকে প্রসব করলাম একটি কন্যা!’’ আর আল্লাহ্ ভালো জানেন কি সে প্রসব করলো। আর, বেটাছেলে মেয়েছেলের মতো নয়। ''আর আমি তার নাম রাখলাম মরিয়ম, আর আমি অবশ্যই তোমার আশ্রয়ে তাকে রাখছি, আর তার সন্তানসন্ততিকেও, ভ্রষ্ট শয়তানের থেকে।’’\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@cccxxx{অতএব তার প্রভু তাকে কবুল করলেন সুন্দর স্বীকৃতির সাথে, ফলে তাকে বর্ধিত করলেন সুন্দর বর্ধনে, আর তাকে সমর্পণ করলেন যাকারিয়ার অভিভাকত্বে। যখন যাকারিয়া তাকে দেখতে উপাসনাস্থলে প্রবেশ করতেন তিনি তার কাছে দেখতে পেতেন রিযেক। তিনি বললেন -- ''হে মরিয়ম! এ তোমার কাছে কোথা থেকে?’’ সে বললে -- ''এ আল্লাহ্‌র দরবার থেকে।’’ নিঃসন্দেহ আল্লাহ্ যাকে ইচ্ছে করেন তাকে বেহিসাব রিযেক দান করেন।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@cccxxxi{সঙ্গে-সঙ্গে সেইখানেই যাকারিয়া তাঁর প্রভুর কাছে প্রার্থনা করলেন, তিনি বললেন -- ''আমার প্রভু! তোমার নিকট থেকে আমাকে একটি উত্তম সন্তান দাও। নিঃসন্দেহ তুমি প্রার্থনার শ্রোতা।’’\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@cccxxxii{ফিরিশ্‌তারা তাঁকে ডেকে বললে আর তিনি তখন উপাসনাস্থলে নামাযে দাঁড়িয়েছিলেন -- ''আল্লাহ্ নিশ্চয়ই আপনাকে সুসংবাদ দিচ্ছেন ইয়াহ্‌য়ার, আল্লাহ্‌র বাণীর সত্যতা প্রতিপন্ন করতে, আর সম্মানিত ও চরিত্রবান, আর সাধুপুরুষদের মধ্য থেকে একজন নবী।’’\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@cccxxxiii{তিনি বললেন -- ''আমার প্রভু! কোথা থেকে আমার ছেলে হতে পারে, যখন ইতিপূর্বেই আমার কাছে বার্ধক্য এসে হাজির হয়েছে, আর আমার স্ত্রী বন্ধ্যা?’’ তিনি বললেন -- ''এইভাবেই, -- আল্লাহ্ তাই করেন যা তিনি চান।’’\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@cccxxxiv{তিনি বললেন -- ''আমার প্রভু! আমার জন্য একটি নিদর্শন নির্ধারিত করো।’’ তিনি বললেন -- ''তোমার নিদর্শন হচ্ছে এই যে তুমি লোকজনের সাথে তিনদিন কথা বলবে না শুধু ইশারাতে ছাড়া, আর তোমার প্রভুকে খুব করে স্মরণ করো নিশাসমাগমে ও ভোরবেলা।’’\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@cccxxxv{আর স্মরণ করো! ফিরিশ্‌তারা বললেন -- ''হে মরিয়ম! নিশ্চয়ই আল্লাহ্ তোমাকে নির্বাচন করেছেন, আর তোমায় পবিত্র করেছেন, আর বিশ্বজগতের সব নারীর উপরে তোমায় নির্বাচন করেছেন।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@cccxxxvi{''হে মরিয়ম! তোমার প্রভুর অনুগত হয়ে থেকো, আর সিজদা করো ও রুকু করো রুকুকারীদের সাথে।’’\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@cccxxxvii{এ হচ্ছে অদৃশ্য বার্তাসমূহের থেকে যে-সব তোমার কাছে আমরা প্রত্যাদিষ্ট করছি। আর তুমি তাদের কাছে ছিলে না যখন তারা তাদের কলম নিক্ষেপ করছিল তাদের মধ্যে কে মরিয়মের ভার নেবে সে সম্পর্কে, আর তুমি তাদের নিকটে ছিলে না যখন তারা পরস্পর বচসা করছিল।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@cccxxxviii{স্মরণ করো! ফিরিশ্‌তারা বললে -- ''হে মরিয়ম, নিঃসন্দেহ আল্লাহ্ তোমাকে সুসংবাদ দিচ্ছেন তাঁর তরফ থেকে একটি বাণী দ্বারা -- তাঁর নাম হচ্ছে মসীহ্‌, মরিয়ম-পুত্র ঈসা, ইহকালে ও পরকালে সম্মানের যোগ্য, আর নৈকট্যে আনীতদের অন্তর্গত।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@cccxxxix{''আর তিনি লোকদের সাথে কথা বলবেন দোলনায় এবং বার্ধক্যকালে, আর তিনি সুকর্মীদের অন্যতম।’’\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@cccxl{তিনি বললেন -- ''আমার প্রভু! কোথা থেকে আমার ছেলে হবে যখন পুরুষমানুষ আমায় স্পর্শ করে নি?’’ তিনি বললেন -- ''এইভাবেই, -- আল্লাহ্ তাই সৃষ্টি করেন যা তিনি চান। তিনি যখন কোনো বিষয়ে সিদ্ধান্ত করেন, তিনি তখন সে সন্বন্ধে শুধু বলেন -- ''হও’’ আর তা হয়ে যায়।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@cccxli{''আর তিনি তাঁকে শেখাবেন কিতাব ও জ্ঞানভান্ডার, আর তওরাত ও ইনজীল।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@cccxlii{''আর ইসরাইল বংশীয়দের জন্য রসূল। 'নিঃসন্দেহ আমি তোমাদের কাছে আসছি তোমাদের প্রভুর কাছ থেকে একটি নিদর্শন নিয়ে, আমি অবশ্যই তোমাদের জন্য মাটি থেকে তৈরি করি পাখির মতো মূর্তি, তারপর তাতে আমি ফুৎকার দিই, তখন সেটি পাখি হয়ে যায় আল্লাহ্‌র ইচ্ছায়। আর আমি আরোগ্য করি অন্ধকে ও কুষ্ঠ রুগীকে, আর আমি জীবন দিই মৃতকে আল্লাহ্‌র ইচ্ছায়। আর আমি তোমাদের খবর দিই যেসব তোমরা খাবে আর যা তোমরা নিজেদের বাড়িতে মজুত রাখো। নিঃসন্দেহ এতে বিশেষ নিদর্শন আছে তোমাদের জন্য যদি তোমরা বিশ্বাসী হও।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@cccxliii{''আর তওরাতের যা-কিছু আমার কাছে ছিল আমি তার প্রতিপাদক, আর আমি যাতে তোমাদের জন্য বৈধ করতে পারি কোনো কোনো বিষয় যা তোমাদের জন্য নিষিদ্ধ হয়েছিল, আর আমি তোমাদের কাছে এসেছি তোমাদের প্রভুর কাছ থেকে একটি বাণী নিয়ে, অতএব আল্লাহ্‌কে ভয়-শ্রদ্ধা করো ও আমার অনুগত হও।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@cccxliv{''নিঃসন্দেহ আল্লাহ্ আমার প্রভু ও তোমাদেরও প্রভু, অতএব তাঁরই উপাসনা করো, -- এই হচ্ছে সহজ-সঠিক পথ।’’\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@cccxlv{কিন্তু যখন ঈসা তাদের মধ্যে অবিশ্বাস বোধ করলেন, তিনি বললেন -- ''কারা আল্লাহ্‌র পথে আমার সাহায্যকারী হবে?’’ হাওয়ারীরা বললে -- ''আমরা আল্লাহ্‌র সাহায্যকারী হব, আমরা আল্লাহ্‌তে বিশ্বাস করি, আর তুমি সাক্ষ্য দাও যে আমরা হচ্ছি আ‌ত্মসমর্পণকারী।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@cccxlvi{''আমাদের প্রভু! আমরা ঈমান এনেছি তাতে যা তুমি অবতারণ করেছ, আর আমরা রসূলকে অনুসরণ করি, অতএব আমাদের লিখে রাখ সাক্ষ্যদাতাদের সাথে।’’\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@cccxlvii{আর তারা চক্রান্ত করেছিল, আর আল্লাহ্‌ও পরিকল্পনা করেছিলেন। আর আল্লাহ্ পরিকল্পনাকারীদের মধ্যে সর্বোত্তম।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@cccxlviii{স্মরণ করো! আল্লাহ্ বললেন -- ''হে ঈসা, আমি নিশ্চয়ই তোমার মৃত্যু ঘটাব, এবং আমি তোমাকে আমার দিকে উন্নীত করবো, আর তোমাকে পরিশোধিত করবো যারা অবিশ্বাস পোষণ করে তাদের থেকে, আর যারা তোমায় অনুসরণ করবে তাদের আমি স্থান দেবো যারা অবিশ্বাস পোষণ করে তাদের উপরে কিয়ামতের দিন পর্যন্ত, এরপর আমারই কাছে তোমাদের প্রত্যাবর্তন স্থান, আর আমি তোমাদের মধ্যে বিচার করবো যে-বিষয়ে তোমরা মতভেদ করছিলে সেই বিষয়ে।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@cccxlix{অতএব যারা অবিশ্বাস পোষণ করে আমি তাদের শাস্তি দেবো কঠোর শাস্তিতে এই দুনিয়াতে ও পরলোকে, আর তাদের জন্য সাহায্যকারীদের কেউ থাকবে না।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@cccl{আর যারা ঈমান এনেছে ও সুকর্ম করেছে, তিনি তাদের প্রাপ্য পুরোপরি তাদের দেবেন। আর অন্যায়কারীদের আল্লাহ্ ভালোবাসেন না।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@cccli{এটিই যা আমি তোমার কাছে বর্ণনা করছি নির্দেশবাণী ও জ্ঞানময় স্মারক থেকে।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@ccclii{নিঃসন্দেহ ঈসার দৃষ্টান্ত হচ্ছে আল্লাহ্‌র কাছে আদমের দৃষ্টান্তের মতো। তিনি তাঁকে সৃষ্টি করেছিলেন মাটি থেকে; তারপর তাঁকে বলেছিলেন -- ''হও’’ আর তিনি হয়ে গেলেন।\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@cccliii{তোমার প্রভুর কাছ থেকে আসা ধ্রুবসত্য, কাজেই সংশয়ীদের দলভুক্ত হয়ো না।\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@cccliv{অতএব যারা তোমার সাথে এ-বিষয়ে তর্ক করে তোমার কাছে জ্ঞানের যা এসেছে তার পরেও, তাহলে বলো -- ''এসো, আমরা ডেকে আনি আমাদের সন্তানদের ও তোমাদের সন্তানদের, আর আমাদের স্ত্রীলোকদের ও তোমাদের স্ত্রীলোকদের, আর আমাদের লোকজনকে ও তোমাদের লোকজনকে, তারপর কাতর প্রার্থনা করি যেন আল্লাহ্‌র অভিশাপ পড়ে মিথ্যাবাদীদের উপরে।’’\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@ccclv{নিঃসন্দেহ এই হচ্ছে যথার্থ সত্য বিবৃতি, আর আল্লাহ্ ছাড়া কোনো উপাস্য নেই। আর নিঃসন্দেহ আল্লাহ্‌, অবশ্যই তিনি মহাশক্তিশালী, পরমজ্ঞানী।\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@ccclvi{কিন্তু তারা যদি ফিরে যায়, তাহলে আল্লাহ্ ফসাদকারীদের সম্যক জ্ঞাতা।\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@ccclvii{বলো -- ''হে গ্রন্থপ্রাপ্ত লোকেরা, আমাদের মধ্যে ও তোমাদের মধ্যে পরস্পর সমঝোথার মাঝে এসো, যেন আমরা আল্লাহ্ ছাড়া আর কারো এবাদত করবো না, আর তাঁর সাথে অন্য কিছুকে শরীক করবো না, আর আমরা কেউ আল্লাহ্ ছাড়া অন্য কাউকে মনিব বলে গ্রহণ করবো না।’’ কিন্তু তারা যদি ফিরে যায় তবে বলো -- ''সাক্ষী থাকো, আমরা কিন্তু মুসলিম।’’\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@ccclviii{হে গ্রন্থধারিগণ! তোমরা কেন ইব্রাহীম সন্বন্ধে হুজ্জত করো, অথচ তওরাত ও ইনজীল তাঁর পরে ছাড়া অবতীর্ণ হয় নি? তোমরা কি তাহলে বুঝো না?\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@ccclix{দেখো! তোমরাই তারা যারা তর্ক করেছ যে-বিষয়ে তোমাদের জ্ঞান ছিল, তবে কেন তোমরা হুজ্জত করছো যে বিষয়ে তোমাদের সম্যক জ্ঞান নেই? আর আল্লাহ্ জানেন, অথচ তোমরা জানো না।\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@ccclx{ইব্রাহীম ইহুদী ছিলেন না, খ্রীষ্টানও নহেন, বরং তিনি ছিলেন ঋজু স্বভাব, মুসলিম, আর তিনি মুশরিকদের অন্তর্ভুক্ত ছিলেন না।\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@ccclxi{নিঃসন্দেহ ইব্রাহীমের নিকটতম লোক ছিলেন যাঁরা তাঁকে অনুসরণ করে চলতেন, আর এই নবী, আর যারা ঈমান এনেছে। আর আল্লাহ্ বিশ্বাসীদের রক্ষাকারী বন্ধু।\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@ccclxii{গ্রন্থপ্রাপ্তদের একদল চায় তোমাদের বিপথগামী করতে, আর তারা বিপথে নেয় না নিজেদের ছাড়া অন্য কাউকে, আর তারা উপলব্ধি করতে পারছে না।\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@ccclxiii{হে গ্রন্থধারিগণ! কেন তোমরা আল্লাহ্‌র নির্দেশে অবিশ্বাস পোষণ করো, যখন তোমরা প্রত্যক্ষদর্শী?\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@ccclxiv{হে গ্রন্থধারিগণ! কেন তোমরা সত্যকে মিথ্যার পোশাক পরিয়ে দিচ্ছ, আর তোমরা জেনেশুনে সত্যকে লুকোচ্ছ?\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@ccclxv{আর গ্রন্থপ্রাপ্তদের একদল বলে -- ''যারা ঈমান এনেছে তাদের কাছে যা নাযিল হয়েছে তাতে তোমরাও বিশ্বাস করো দিনের আগবেলায়, আর তার অপরাহে প্রত্যাখ্যান করো, যাতে তারাও ফিরে যায়।\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@ccclxvi{''তা ছাড়া যে তোমাদের ধর্ম অনুসরণ করে তাকে ছাড়া ঈমান এনো না।’’ তুমি বলো -- ''নিঃসন্দেহ হেদায়ত হচ্ছে আল্লাহ্‌র হেদায়ত, কাজেই তোমাদের যা দেয়া হয়েছিল তার মতো অন্যকে দেয়া হয়েছে, অথবা তারা তোমাদের প্রভুর সামনে তোমাদের উপরে প্রভাব বিস্তার করতে পারে।’’ বলো -- ''নিঃসন্দেহ মহত্ত্ব আল্লাহ্‌র হাতে ন্যস্ত, তিনি তা দান করেন যাকে পছন্দ ক রেন। আর আল্লাহ্ মহাবদান্য, সর্বজ্ঞাতা।’’\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@ccclxvii{তিনি তাঁর করুণাবশতঃ নির্বাচিত করেন যাকে পছন্দ করেন, আর আল্লাহ্ বিপুল মহিমার অধিকারী।\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@ccclxviii{আর গ্রন্থপ্রাপ্তদের মধ্যে এমন লোক আছে যার কাছে তুমি যদি একগাদা আমানত রাখো সে তোমাকে তা ফিরিয়ে দেবে, আর তাদের মধ্যে এমনও আছে যার কাছে যদি তুমি একটি দিনার গচ্ছিত রাখো সে তোমাকে তা ফিরিয়ে দেবে না, যদি না তুমি তার কাছে দাঁড়িয়ে থাকো। এইরূপ কারণ তারা বলে -- ''অক্ষরজ্ঞানহীনদের ব্যাপারে আমাদের কোনো পথ ধরে চলার দায়িত্ব নেই।’’ আর তারা আল্লাহ্ সন্বন্ধে মিথ্যারোপ করে, যদিও তারা জানে।\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@ccclxix{হাঁ, যে কেউ তার অঙ্গীকার পালন করে ও ভয়-ভক্তি বজায় রেখে চলে, নিঃসন্দেহ তখন আল্লাহ্ মুত্তাকীদের ভালোবাসেন।\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@ccclxx{নিঃসন্দেহ যারা আল্লাহ্‌র অঙ্গীকার ও তাদের প্রতি‌শ্রুতি স্বল্পমূল্যে বিক্রী করে দেয়, তারা -- পরকালে তাদের জন্য কোনো ভাগ থাকবে না, আর আল্লাহ্ তাদের সঙ্গে কথাও বলবেন না বা তাদের দিকে তাকাবেন না কিয়ামতের দিনে, আর তিনি তাদের শুদ্ধও করবেন না, আর তাদের জন্য থাকছে কঠোর যাতনা।\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@ccclxxi{আর নিশ্চয়ই তাদের মধ্যের একদল গ্রন্থপাঠে তাদের জিহ্বাকে পাকিয়ে-বাঁকিয়ে তোলে যেন তোমরা ভাবতে পারো তা গ্রন্থ থেকেই, অথচ তা গ্রন্থ থেকে নয়। আর তারা বলে -- ''ইহা আল্লাহ্‌র কাছ থেকে’’ যদিও উহা আল্লাহ্ থেকে নয়। আর তারা আল্লাহ্ সন্বন্ধে মিথ্যাকথা বলে, যদিও তারা জানে।\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@ccclxxii{কোনো মানবের জন্য এটি উচিত নয় যে আল্লাহ্ তাকে কিতাব, নির্দেশনামা ও নবুওৎ দেবেন, তারপর সে লোকদের বলবে -- “তোমরা আল্লাহ্‌কে ছেড়ে আমার উপাসনাকারী হও”, বরং -- ''তোমরা রব্বানী হও, কেননা তোমরা কিতাব শিক্ষা দিয়ে যাচ্ছিলে ও অনুশীলন করে চলছিলে।’’\qt@no{(79)}}
\qt@newcmd\qurantrans@bn@ccclxxiii{আর সে তোমাদের আদেশ করবে না যে তোমরা ফিরিশ্‌তাদের ও নবীদের প্রভুরূপে গ্রহণ করবে। সে কি তোমাদের আদেশ করবে অবিশ্বাসের দিকে, তোমরা মুসলিম হবার পরে?\qt@no{(80)}}
\qt@newcmd\qurantrans@bn@ccclxxiv{আর স্মরণ করো! আল্লাহ্ নবীদের মাধ্যমে অঙ্গীকার করেছিলেন -- ''নিঃসন্দেহ আমি তোমাদের কিতাব ও জ্ঞান ভান্ডার থেকে প্রদান করেছি, তারপর তোমাদের কাছে একজন রসূল আসবেন তোমাদের কাছে যা আছে তা প্রতিপাদন করেচ তোমরা নিশ্চয়ই তাঁর প্রতি ঈমান আনবে আর নিশ্চয় তাঁকে সাহায্য করবে।’’ তিনি বলেছিলেন -- ''তোমরা কি স্বীকার করলে ও এই ব্যাপারে আমার শর্ত গ্রহণ করলে?’’ তারা বলেছিল -- ''আমরা স্বীকার করলাম।’’ তিনি বললেন -- ''তবে তোমরা সাক্ষী থেকো, আর আমিও তোমাদের সাথে সাক্ষ্যদাতাদের অন্যতম।’’\qt@no{(81)}}
\qt@newcmd\qurantrans@bn@ccclxxv{অতএব যে কেউ এরপর ফিরে যায়, তা হলে তারা নিজেরাই হচ্ছে পাপাচারী।\qt@no{(82)}}
\qt@newcmd\qurantrans@bn@ccclxxvi{তারা কি তবে আল্লাহ্‌র ধর্ম ছাড়া আর কিছু খুজঁছে? আর তাঁর প্রতি আ‌ত্মসমর্পণ করছে যে কেউ আছে মহাকাশমন্ডলে ও পৃথিবীতে -- স্বেচ্ছায় অথবা অনিচ্ছায়; আর তাঁর কাছেই তাদের ফিরিয়ে আনা হবে।\qt@no{(83)}}
\qt@newcmd\qurantrans@bn@ccclxxvii{তুমি বলো -- ''আমরা বিশ্বাস করি আল্লাহ্‌তে আর যা আমাদের কাছে অবতীর্ণ হয়েছে, আর যা নাযিল হয়েছিল ইব্রাহীম ও ইসমাইল ও ইসহাক ও ইয়াকুব ও গোত্রদের কাছে, আর যা দেওয়া হয়েছিল মূসাকে ও ঈসাকে ও নবীদের তাঁদের প্রভুর তরফ থেকে। আমরা তাঁদের কোনো একজনের মধ্যেও পার্থক্য করি না, আর তাঁরই কাছে আমরা আ‌ত্মসমর্পণকারী।’’\qt@no{(84)}}
\qt@newcmd\qurantrans@bn@ccclxxviii{আর যে কেউ ইসলাম পরিত্যাগ করে অন্য কোনো ধর্ম অনুসরণ করে তা হলে তার কাছ থেকে কখনো তা কবুল করা হবে না। আর আখেরে সে হবে ক্ষতিগ্রস্তদের অন্তর্ভুক্ত।\qt@no{(85)}}
\qt@newcmd\qurantrans@bn@ccclxxix{আল্লাহ কেমন করে হেদায়ত করবেন সেই লোকদের যারা অবিশ্বাস পোষণ করে তাদের বিশ্বাস স্থাপনের পরেও, আর এই সাক্ষ্য দেবার পরেও যে এই রসূল সত্য, আর স্পষ্ট প্রমাণাবলী তাদের কাছে আসবার পরেও? আর অন্যায়কারী দলকে আল্লাহ্ হেদায়ত করেন না।\qt@no{(86)}}
\qt@newcmd\qurantrans@bn@ccclxxx{এরাই -- এদের প্রাপ্য এই যে এদের উপরে লানৎ হোক আল্লাহ্‌র ও ফিরিশ্‌তাদের ও মানুষের সম্মিলিতভাবে।\qt@no{(87)}}
\qt@newcmd\qurantrans@bn@ccclxxxi{এতে তারা অবস্থান করবে। তাদের উপর থেকে যাতনা লাঘব করা হবে না, আর তারা বিরামও পাবে না।\qt@no{(88)}}
\qt@newcmd\qurantrans@bn@ccclxxxii{তারা ছাড়া যারা এরপর তওবা করে ও সংশোধন করে, কাজেই আল্লাহ্ নিঃসন্দেহ পরিত্রাণকারী, অফুরন্ত ফলদাতা।\qt@no{(89)}}
\qt@newcmd\qurantrans@bn@ccclxxxiii{নিঃসন্দেহ যারা অবিশ্বাস পোষণ করে তাদের বিশ্বাস স্থাপনের পরে, তারপর অবিশ্বাস বাড়িয়ে নিয়ে যায়, তাদের তওবা কখনো কবুল করা হবে না; আর এরা নিজেরাই হচ্ছে পথভ্রষ্ট।\qt@no{(90)}}
\qt@newcmd\qurantrans@bn@ccclxxxiv{নিঃসন্দেহ যারা অবিশ্বাস পোষণ করে আর মারা যায় তারা অবিশ্বাসী থাকা অবস্থায়, তা হলে তাদের কোনো একজনের কাছ থেকে পৃথিবী ভরা সোনাও গ্রহণ করা হবে না, যদি সে তাই দিয়ে মুক্তি পেতে চায়। এরাই -- এদের জন্য ব্যথাদায়ক শাস্তি, আর এদের থাকবে না কোনো সাহায্যকারী।\qt@no{(91)}}
\qt@newcmd\qurantrans@bn@ccclxxxv{তোমরা কখনো ধর্মনিষ্ঠ হতে পারবে না যে পর্যন্ত না তোমরা ব্যয় করো যা তোমরা ভালোবাস তা থেকে। আর তোমরা যে বস্তুই খরচ করবে, নিঃসন্দেহ আল্লাহ্ সে-সন্বন্ধে সর্বজ্ঞাতা।\qt@no{(92)}}
\qt@newcmd\qurantrans@bn@ccclxxxvi{সব রকম খাদ্য বৈধ ছিল ইসরাইলের বংশধরদের জন্যেও, -- সে-সব ছাড়া যা তওরাত অবতীর্ণ হবার আগে ইসরাইল নিজের জন্য নিষিদ্ধ করেছিল। বলো -- ''তা হলে তওরাত নিয়ে এস আর তা পড়ো, যদি তোমরা সত্যবাদী হও।’’\qt@no{(93)}}
\qt@newcmd\qurantrans@bn@ccclxxxvii{অতএব যে কেউ এরপর আল্লাহ্‌র বিরুদ্ধে মিথ্যারোপ করে, তাহলে তারা নিজেরাই হচ্ছে অন্যায়কারী।\qt@no{(94)}}
\qt@newcmd\qurantrans@bn@ccclxxxviii{বলো -- ''আল্লাহ্ সত্যকথা বলেন, কাজেই ঋজুস্বভাব ইব্রাহীমের ধর্ম অনুসরণ করো, আর তিনি বহুখোদাবাদীদের অন্তর্ভুক্ত ছিলেন না।’’\qt@no{(95)}}
\qt@newcmd\qurantrans@bn@ccclxxxix{নিঃসন্দেহ মানবজাতির জন্য প্রথম যে ভোজনালয় প্রতিষ্ঠা হয়েছিল তা হচ্ছে বাক্কাতে, -- অশেষ কল্যাণময়, আর সব মানবগোষ্ঠীর জন্য পথপ্রদর্শক।\qt@no{(96)}}
\qt@newcmd\qurantrans@bn@cccxc{এতে আছে সুস্পষ্ট নিদর্শনাবলী -- মক্কামে ইব্রাহীম; আর যে কেউ এখানে প্রবেশ করবে সে হচ্ছে নিরাপদ, আর আল্লাহ্‌র উদ্দেশ্যে এই গৃহে হজ করা মানবগোষ্ঠীর জন্য আবশ্যিক -- যারই সেখানকার পাথেয় অর্জনের ক্ষমতা আছে। আর যে অবিশ্বাস পোষণ করে -- তাহলে নিঃসন্দেহ আল্লাহ্ সমস্ত সৃষ্ট জগতের থেকে স্বয়ং-সম্পূর্ণ।\qt@no{(97)}}
\qt@newcmd\qurantrans@bn@cccxci{বলো -- ''হে গ্রন্থপ্রাপ্ত লোকেরা! কেন তোমরা আল্লাহ্‌র নির্দেশাবলীতে অবিশ্বাস পোষণ করো, অথচ আল্লাহ্ সাক্ষী রয়েছেন তোমরা যা করো তার?’’\qt@no{(98)}}
\qt@newcmd\qurantrans@bn@cccxcii{বলো -- ''হে গ্রন্থধারিগণ! কেন তোমরা যারা ঈমান এনেছে তাদের আল্লাহ্‌র পথ থেকে প্রতিরোধ করো, তোমরা তার বক্রতা খোঁজো, অথচ তোমরা সাক্ষী রয়েছ?’’ আর আল্লাহ্ গাফিল নন তোমরা যা করো সে-সন্বন্ধে মুসলিমদের বিরুদ্ধাচরণ করার কারসাজি আল্লাহ্‌র অগোচর থাকছে না।\qt@no{(99)}}
\qt@newcmd\qurantrans@bn@cccxciii{ওহে যারা ঈমান এনেছ! যাদের কিতাব দেয়া হয়েছে তাদের কোনো এক দলের অনুবর্তী যদি তোমরা হও, তারা তোমাদের ফিরিয়ে নেবে অবিশ্বাসীদের দলে তোমাদের ঈমান আনার পরেও।\qt@no{(100)}}
\qt@newcmd\qurantrans@bn@cccxciv{কিন্তু কেমন করে তোমরা অবিশ্বাস পোষণ করো যখন তোমাদেরই কাছে আল্লাহ্‌র বাণীসমূহ পাঠ করা হচ্ছে, আর তোমাদের কাছে আছেন তাঁর রসূল? আর যে আল্লাহ্‌কে দৃঢ়ভাবে ধরে থাকে, নিশ্চয় সে তাহলে চালিত হয়েছে সহজ-সঠিক পথে।\qt@no{(101)}}
\qt@newcmd\qurantrans@bn@cccxcv{ওহে যারা ঈমান এনেছ! আল্লাহ্‌কে ভয়-শ্রদ্ধা করো যেমন তাঁকে ভয়ভক্তি করা উচিত, আর তোমরা প্রাণত্যাগ করো না আ‌ত্মসমর্পিত না হয়ে।\qt@no{(102)}}
\qt@newcmd\qurantrans@bn@cccxcvi{আর তোমরা সবে মিলে আল্লাহ্‌র রশি দৃঢ়ভাবে আঁকড়ে ধরো, আর বিচ্ছিন্ন হয়ো না, আর স্মরণ করো তোমাদের উপরে আল্লাহ্‌র অনুগ্রহ, -- যথা তোমরা ছিলে পরস্পর শত্রু, তারপর তিনি তোমাদের হৃদয়ে সম্প্রীতি ঘটালেন, কাজেই তাঁর অনুগ্রহে তোমরা হলে ভাই-ভাই। আর তোমরা ছিলে এক আগুনের গর্তের কিনারে, তারপর তিনি তোমাদের তা থেকে বাঁচালেন। এইভাবে আল্লাহ্ তোমাদের জন্য তাঁর নির্দেশাবলী সুস্পষ্ট করেন যেন তোমরা পথের দিশা পাও।\qt@no{(103)}}
\qt@newcmd\qurantrans@bn@cccxcvii{আর তোমাদের মধ্যে এমন একটি লোকদল হওয়া চাই যারা আহ্বান করবে কল্যাণের প্রতি, আর নির্দেশ দেবে ন্যায়পথের, আর নিষেধ করবে অন্যায় থেকে। আর এরা নিজেরাই হচ্ছে সফলকাম।\qt@no{(104)}}
\qt@newcmd\qurantrans@bn@cccxcviii{আর তাদের মতো হয়ো না যারা বিচ্ছিন্ন হয়েছিল আর মতভেদ করেছিল তাদের কাছে সুস্পষ্ট নির্দেশাবলী আসার পরেও। আর এরা -- এদের জন্য আছে কঠোর যন্ত্রণা, --\qt@no{(105)}}
\qt@newcmd\qurantrans@bn@cccxcix{যেদিন কতকগুলো চেহারা হবে ঝক্‌ঝকে আর কতকগুলো চেহারা হবে মিসমিসে, তারপর যাদের চেহারা কালো হবে তাদের ক্ষেত্রে -- ''তোমরা কি অবিশ্বাস পোষণ করেছিলে তোমাদের ঈমান আনার পরে? অতএব যন্ত্রণার আস্বাদ গ্রহণ করো যেহেতু তোমরা অবিশ্বাস পোষণ করছিলে।’’\qt@no{(106)}}
\qt@newcmd\qurantrans@bn@cd{আর যাদের চেহারা ঝক্‌মকে হবে তাদের ক্ষেত্রে -- তারা থাকবে আল্লাহ্‌র করুণাসিন্ধুতে, এতে তারা থাকবে চিরকাল।\qt@no{(107)}}
\qt@newcmd\qurantrans@bn@cdi{এইসব হছে আল্লাহ্‌র নির্দেশাবলী যা আমরা তোমার কাছে পাঠ করছি সত্যের সাথে। আর আল্লাহ্ কোনো প্রাণীর প্রতি অবিচার চান না।\qt@no{(108)}}
\qt@newcmd\qurantrans@bn@cdii{আর যা-কিছু আছে মহাকাশমন্ডলে ও যা-কিছু পৃথিবীতে সে-সবই আল্লাহ্‌র। আর আল্লাহ্‌র কাছেই সব ব্যাপার ফিরে যায়।\qt@no{(109)}}
\qt@newcmd\qurantrans@bn@cdiii{তোমরা মানবগোষ্ঠীর জন্য এক শ্রেষ্ঠ সমাজরূপে উত্থিত হয়েছ, -- তোমরা ন্যায়ের পথে নির্দেশ দাও ও অন্যায় থেকে নিষেধ করো, আর আল্লাহ্‌তে বিশ্বাস রাখো। আর গ্রন্থপ্রাপ্তরাও যদি ঈমান আনতো তবে তাদের জন্য ভালো হতো! তাদের মধ্যে কেউ কেউ বিশ্বাসী, কিন্তু তাদের বেশির ভাগ দুষ্টলোক।\qt@no{(110)}}
\qt@newcmd\qurantrans@bn@cdiv{তারা কখনো তোমাদের ক্ষতি করতে পারবে না কিঞ্চিৎ জ্বালাতন ছাড়া, আর যদি তারা তোমাদের সাথে যুদ্ধ বাধায় তবে তারা তোমাদের দিকে পিঠ ফেরাবে, তারপর তাদের আর সাহায্য করা হবে না।\qt@no{(111)}}
\qt@newcmd\qurantrans@bn@cdv{তাদের উপরে লাঞ্ছনা হানা দেবে যেখানেই তারা থাকুক না কেন, যদি না আল্লাহ্‌-থেকে-আসা রশি দ্বারা বা মানুষ-থেকে- পাওয়া রশি, আর তারা আল্লাহ্‌র রোষ অর্জন করেছে, আর তাদের উপরে দুর্দশা হানা দেবে। তাই হয়েছে -- কেননা তারা আল্লাহ্‌র নির্দেশাবলী অমান্য করে চলেছিল, আর নবীগণকে অন্যায়ভাবে হত্যা করতে যাচ্ছিল। তাই হয়, কারণ তারা অবাধ্য হয়েছিল আর তারা সীমা-লঙ্ঘন করেছিল।\qt@no{(112)}}
\qt@newcmd\qurantrans@bn@cdvi{তারা সবাই এক রকমের নয়। গ্রন্থপ্রাপ্তদের মধ্যে একদল আছে নিষ্ঠাবান, তারা আল্লাহ্‌র নির্দেশাবলী রাত্রিকালে পাঠ করে, আর তারা সিজদা করে।\qt@no{(113)}}
\qt@newcmd\qurantrans@bn@cdvii{তারা আল্লাহ্‌র প্রতি ও আখেরাতের দিনের প্রতি বিশ্বাস করে, আর তারা ন্যায়ের পথে নির্দেশ দেয় ও অন্যায় থেকে নিষেধ করে, আর তারা শুভকাজে পরস্পরের মধ্যে প্রতিযোগিতা করে, আর এরা সাধুপুরুষদের অন্তর্ভুক্ত।\qt@no{(114)}}
\qt@newcmd\qurantrans@bn@cdviii{আর তারা ভালোকাজের যা-কিছু করে তার সন্বন্ধে তাদের কখনো অস্বীকার করা হবে না। আর আল্লাহ্ ধর্মপরায়ণদের সন্বন্ধে ওয়াকিফহাল।\qt@no{(115)}}
\qt@newcmd\qurantrans@bn@cdix{নিঃসন্দেহ যারা অবিশ্বাস পোষণ করে, তাদের ধনসম্পত্তি ও তাদের সন্তানসন্ততি আল্লাহ্‌র বিরুদ্ধে কোনোভাবেই তাদের কখনো লাভবান করবে না। আর এরাই হচ্ছে আগুনের বাসিন্দা, তারা সেখানে থাকবে দীর্ঘকাল।\qt@no{(116)}}
\qt@newcmd\qurantrans@bn@cdx{দুনিয়ার এই জীবনে তারা যা খরচ করে তার দৃষ্টান্ত হচ্ছে বাতাসের দৃষ্টান্তের মতো যাতে রয়েছে কনকনে ঠান্ডা, এ ঝাপটা দিল সেই লোকদের ফসলে যারা নিজেদের প্রতি অন্যায় করেছে, কাজেই এ ধ্বংস করে দিল তা। আর আল্লাহ্ তাদের প্রতি অন্যায় করেন নি, বরং তারা তাদের নিজেদের প্রতি অন্যায় করেছে।\qt@no{(117)}}
\qt@newcmd\qurantrans@bn@cdxi{ওহে যারা ঈমান এনেছ! তোমাদের নিজেদের লোক ছাড়া অন্যদের অন্তরঙ্গরূপে গ্রহণ করো না; তারা অনিষ্ট সাধন করতে তোমাদের থেকে পশ্চাৎপদ হয় না। তোমাদের যা ক্লেশ দেয় তারা তা ভালোবাসে, তাদের মুখ থেকে ঘোর বিদ্বেষ ইতিমধ্যে নির্গত হচ্ছে। আর তাদের অন্তরে যা লুকোনো আছে তা আরও গুরুতর। তোমাদের জন্য নির্দেশাবলী সুস্পষ্ট করলাম, যদি তোমরা বুঝতে পারো।\qt@no{(118)}}
\qt@newcmd\qurantrans@bn@cdxii{তোমরাই বটে! তোমরা ঐ ওদের ভালোবাস, অথচ তারা তোমাদের ভালোবাসে না, তোমরা কিন্তু ধর্মগ্রন্থে বিশ্বাস করো, তার সবটাতে। আর যখন তারা তোমাদের সাথে দেখা করে তারা বলে -- ''আমরা ঈমান এনেছি’’; আর যখন তারা নিরিবিলি হয়, তোমাদের প্রতি আক্রোশে তারা আঙ্গুল কামড়ায়। তুমি বলো -- ''তোমাদের আক্রোশে মরে যাও। নিঃসন্দেহ বুকের মধ্যে কি আছে সে-সন্বন্ধে আল্লাহ্ সর্বজ্ঞাতা।\qt@no{(119)}}
\qt@newcmd\qurantrans@bn@cdxiii{যদি শুভ কিছু তোমাদের জন্য ঘটে তবে সেটা তাদের দুঃখ দেয়, আর যদি মন্দ কিছু তোমাদের পাকড়াও তবে তাতে তারা হয় পরমানন্দিত। আর যদি তোমরা ধৈর্যশীল ও ধর্মপরায়ণ হও তবে তাদের ষড়যন্ত্র তোমাদের এতটুকু ক্ষতি করবে না। নিঃসন্দেহ তারা যা করছে তা আল্লাহ্ ঘিরে রয়েছেন।\qt@no{(120)}}
\qt@newcmd\qurantrans@bn@cdxiv{আর স্মরণ করো তুমি ভোরে তোমার পরিজনদের কাছ থেকে যাত্রা করলে যুদ্ধের জন্য বিশ্বাসীদের অবস্থান নির্দ্ধারণ করতে। আর আল্লাহ্ সর্বশ্রোতা, সর্বজ্ঞাতা।\qt@no{(121)}}
\qt@newcmd\qurantrans@bn@cdxv{স্মরণ করো! তোমাদের মধ্যে থেকে দুইটি দল ভীরুতা দেখাবার মনস্থ করেছিল, আর আল্লাহ্ ছিলেন তাদের উভয়ের অভিভাবক, আর আল্লাহ্‌র উপরেই তাহলে বিশ্বাসীদের নির্ভর করা উচিত।\qt@no{(122)}}
\qt@newcmd\qurantrans@bn@cdxvi{আর আল্লাহ্ ইতিপূর্বে তোমাদের সাহায্য করেছিলেন বদরে যখন তোমরা ছিলে দুর্দশাগ্রস্ত; অতএব আল্লাহ্‌র প্রতি ভয়-শ্রদ্ধা করো যেন তোমরা ধন্যবাদ দিতে পারো।\qt@no{(123)}}
\qt@newcmd\qurantrans@bn@cdxvii{স্মরণ করো! তুমি বিশ্বাসীদের বলেছিলে -- ''এইটি কি তোমাদের জন্য যথেষ্ট নয় যে তোমাদের প্রভু তোমাদের সাহায্য করুন নেমে আসা ফিরিশ্‌তাদের তিন হাজার দিয়ে?\qt@no{(124)}}
\qt@newcmd\qurantrans@bn@cdxviii{''যথার্থ! যদি তোমরা ধৈর্যশীল ও ধর্মপরায়ণ হও, আর তারা তোমাদের উপরে এসে পড়ে প্রবল বেগে, -- তোমাদের প্রভু তোমাদের সাহায্য করেছিলেন প্রচন্ড আঘাতকারী পাঁচ হাজার ফিরিশ্‌তাদের দিয়ে।’’\qt@no{(125)}}
\qt@newcmd\qurantrans@bn@cdxix{আর আল্লাহ্ এটি করেন নি তোমাদের জন্য সুসংবাদ ব্যতীত, আর যাতে তোমাদের হৃদয় ইহাদ্বারা সান্তনা পায়। আর সাহায্য আসেনা শুধু আল্লাহ্‌র দরবার থেকে ছাড়া, মহাশক্তিশালী, পরমজ্ঞানী --\qt@no{(126)}}
\qt@newcmd\qurantrans@bn@cdxx{যেন তিনি যারা অবিশ্বাস পোষণ করে তাদের এক দলকে সংহার করতে পারেন, অথবা তাদের পরাভূত করতে পারেন, যেন তারা বিফলমনোরথ হয়ে ফিরে যায়।\qt@no{(127)}}
\qt@newcmd\qurantrans@bn@cdxxi{এই ব্যাপারে তোমার আদৌ কোনো সংস্রব নেই যে তিনি তাদের প্রতি ফিরবেন, অথবা তাদের শাস্তি দেবেন, যদিও তারা নিঃসন্দেহ অন্যায়কারী।\qt@no{(128)}}
\qt@newcmd\qurantrans@bn@cdxxii{আর মহাকাশমন্ডলে যা-কিছু আছে ও যা-কিছু আছে পৃথিবীতে সে-সবই আল্লাহ্‌র। তিনি যাকে ইচ্ছা করবেন পরিত্রাণ করবেন এবং যাকে ইচ্ছা করবেন শাস্তিও দেবেন। আর আল্লাহ্ পরিত্রাণকারী, অফুরন্ত ফলদাতা।\qt@no{(129)}}
\qt@newcmd\qurantrans@bn@cdxxiii{ওহে যারা ঈমান এনেছ! সুদ গলাধঃকরণ করো না তাকে দ্বিগুণ ও বহুগুণিত করে; আর আল্লাহ্‌কে ভয়-শ্রদ্ধা করো যাতে তোমরা সফলকাম হতে পারো।\qt@no{(130)}}
\qt@newcmd\qurantrans@bn@cdxxiv{আর সতর্কতা অবলন্বন করো সেই আগুন সন্বন্ধে যা তৈরি করা হয়েছে অবিশ্বাসীদের জন্য।\qt@no{(131)}}
\qt@newcmd\qurantrans@bn@cdxxv{আর আল্লাহ্ ও রসূলের প্রতি অনুগত হও, যেন তোমাদের করুণা দেখানো হয়।\qt@no{(132)}}
\qt@newcmd\qurantrans@bn@cdxxvi{আর তৎপর হও তোমাদের প্রভুর কাছ থেকে পরিত্রাণ লাভের জন্য এবং স্বর্গোদ্যানের জন্য যার বিস্তার হচ্ছে মহাকাশমন্ডল ও পৃথিবী জুড়ে -- তৈরী হয়েছে ধর্মপরায়ণদের জন্য --\qt@no{(133)}}
\qt@newcmd\qurantrans@bn@cdxxvii{যারা খরচ করে সচ্ছল অবস্থায় ও অসচ্ছল অবস্থায়, আর যারা ক্রোধ সংবরণকারী, আর যারা লোকজনের প্রতি ক্ষমাশীল। আর আল্লাহ্ সৎকর্মীদের ভালোবাসেন, --\qt@no{(134)}}
\qt@newcmd\qurantrans@bn@cdxxviii{আর যারা, যখন কোনো গর্হিত কাজ করে বা নিজেদের প্রতি অন্যায় করে, তখন আল্লাহ্‌কে স্মরণ করে ও তাদের অপরধের জন্য পরিত্রাণ চায়, -- বস্তুতঃ আল্লাহ্ ছাড়া আর কে অপরাধ ক্ষমা করে? আর তারা যা করেছিল তাতে জেনেশুনে আঁকড়ে ধরে থাকে না।\qt@no{(135)}}
\qt@newcmd\qurantrans@bn@cdxxix{এরা? -- এদের পুরস্কার হচ্ছে এদের প্রভুর কাছ থেকে পরিত্রাণ ও স্বর্গোদ্যানসমূহ যাদের নিচে দিয়ে বয়ে চলে ঝরনারাজি, সেখানে তারা থাকবে স্থায়ীভাবে, আর কর্মীবৃন্দের পুরস্কার কী চমৎকার!\qt@no{(136)}}
\qt@newcmd\qurantrans@bn@cdxxx{নিশ্চয়ই তোমাদের পূর্বে বহু জীবনধারা গত হয়ে গেছে। অতএব পৃথিবীতে ভ্রমণ করো ও দেখো কেমন হয়েছিল মিথ্যারোপকারীদের পরিণাম।\qt@no{(137)}}
\qt@newcmd\qurantrans@bn@cdxxxi{এই হচ্ছে মানব জাতির জন্য সুস্পষ্ট ঘোষণা ও পথনির্দেশ ও উপদেশ -- ধর্মপরায়ণদের জন্য।\qt@no{(138)}}
\qt@newcmd\qurantrans@bn@cdxxxii{অতএব দুর্বলচিত্ত হয়ো না ও অনুশোচনা করো না, কারণ তোমরাই হবে উচ্চপদস্থ যদি তোমরা বিশ্বাসী হও।\qt@no{(139)}}
\qt@newcmd\qurantrans@bn@cdxxxiii{যদি কোনো আঘাত তোমাদের পীড়া দিয়ে থাকে তবে তার সমান আঘাত পীড়া দিয়েছে দলকে। আর এইসব দিনগুলো আমরা লোকদের কাছে পালাক্রমে এনে থাকি যাতে আল্লাহ্ অবধারণ করতে পারেন তাদের যারা ঈমান এনেছে, আর যাতে তোমাদের মধ্যে থেকে সাক্ষী মনোনীত করতে পারেন। আর আল্লাহ্ অন্যায়কারীদের ভালোবাসেন না, --\qt@no{(140)}}
\qt@newcmd\qurantrans@bn@cdxxxiv{আর যেন আল্লাহ্ বিমুক্ত করতে পারেন যারা ঈমান এনেছে তাদের, আর নিষ্ফল করতে পারেন অবিশ্বাসীদের।\qt@no{(141)}}
\qt@newcmd\qurantrans@bn@cdxxxv{তোমরা কি বিবেচনা করছো যে তোমরা বেহেশতে প্রবেশ করবে, অথচ আল্লাহ্ এখনো অবধারণ করেন নি তোমাদের মধ্যে কারা সংগ্রাম করেছে, আর যাচাই করেন নি কারা ধৈর্যশীল?\qt@no{(142)}}
\qt@newcmd\qurantrans@bn@cdxxxvi{আর নিঃসন্দেহ তোমরা চেয়েছিলে মৃত্যুবরণ করতে -- তার সঙ্গে দেখা হবার আগে, এখন কিন্তু তোমরা তা দেখেছ, আর তোমরা দেখতে থাকো!\qt@no{(143)}}
\qt@newcmd\qurantrans@bn@cdxxxvii{আর মুহাম্মদ একজন রসূল বৈ তো নন। নিঃসন্দেহ তাঁর পূর্বে রসূলগণ গত হয়ে গেছেন। অতএব তিনি যদি মারা যান অথবা তাঁকে কাতল করা হয় তাহলে কি তোমরা তোমাদের গোড়ালির উপরে মোড় ফেরাবে? আর যে কেউ তার গোড়ালির উপরে মোড় ফেরে সে কিন্তু, আর আল্লাহ্ অচিরেই পুরস্কার দেবেন কৃতজ্ঞদের।\qt@no{(144)}}
\qt@newcmd\qurantrans@bn@cdxxxviii{আর কোনো লোকের পক্ষে তার মরে যাওয়া চলে না আল্লাহ্‌র অনুমতি ব্যতীত, লিপিবদ্ধ থাকা নির্ধারিত সময় অনুসারে। আর যে কেউ ইহজীবনের পুরস্কার কামনা করে আমরা তাকে তা’ থেকে আদায় করি, আর যে কেউ চায় পরলোকের পুরস্কার আমরা তাকেও তা থেকে প্রদান করি। আর আমরা অচিরেই পুরস্কৃত করবো কৃতজ্ঞদের।\qt@no{(145)}}
\qt@newcmd\qurantrans@bn@cdxxxix{আর আরো কত নবী যুদ্ধ করেছেন, তাঁদের সঙ্গে ছিল প্রভুর অনুগত বহু লোক, আর আল্লাহ্‌র পথে তাদের উপরে যা বর্তেছিল তার জন্য তারা অবসাদগ্রস্ত হয় নি, আর তারা দুর্বলও হয় নি, আর তারা নিজেদের হীনও করে নি। আর আল্লাহ্ ভালোবাসেন ধৈর্যশীলদের।\qt@no{(146)}}
\qt@newcmd\qurantrans@bn@cdxl{আর তাদের বক্তব্য এই বলা ছাড়া অন্য কিছু ছিল না -- ''আমাদের প্রভু! ক্ষমা করো আমাদের সব অপরাধ ও আমাদের কাজকর্মে আমাদের সমস্ত অমিতাচার, আর দৃঢ় করো আমাদের পদক্ষেপ, আর আমাদের সাহায্য করো অবিশ্বাসী দলের বিরুদ্ধে।’’\qt@no{(147)}}
\qt@newcmd\qurantrans@bn@cdxli{কাজেই আল্লাহ্ তাদের দিয়েছিলেন ইহজীবনের পুরস্কার, আর পরলোকের পুরস্কার আরো চমৎকার! আর আল্লাহ্ ভালোবাসেন সৎকর্মীদের।\qt@no{(148)}}
\qt@newcmd\qurantrans@bn@cdxlii{ওহে যারা ঈমান এনেছ! যারা অবিশ্বাস পোষণ করে তোমরা যদি তাদের অনুগত হও তবে তারা তোমাদের গোড়ালির উপরে তোমাদের মোড় ফিরিয়ে দেবে, ফলে তোমরা ক্ষতিগ্রস্ত হয়ে ফিরবে।\qt@no{(149)}}
\qt@newcmd\qurantrans@bn@cdxliii{না, আল্লাহ্ তোমাদের রক্ষাকারী বন্ধু, আর তিনি সাহায্যকারীদের মধ্যে সর্বোত্তম।\qt@no{(150)}}
\qt@newcmd\qurantrans@bn@cdxliv{যারা অবিশ্বাস পোষণ করে তাদের হৃদয়ে আমরা অচিরেই ভীতি নিক্ষেপ করবো, কেননা তারা আল্লাহ্‌র সাথে শরীক করেছিল যার জন্য তিনি কোনো বিধান অবতারণ করেন নি, ফলে তাদের বাসস্থান হচ্ছে আগুন, আর অন্যায়কারীদের বাসস্থান মন্দ বটে!\qt@no{(151)}}
\qt@newcmd\qurantrans@bn@cdxlv{আর নিঃসন্দেহ আল্লাহ্ ইতিপূর্বে তোমাদের কাছে তাঁর অঙ্গীকার পালন করেছিলেন যখন তোমরা তাঁর ইচ্ছায় তাদের টুকরো- টুকরো করছিলে, যতক্ষণ না তোমরা দুর্বলচিত্ত হয়ে পড়লে, আর তোমরা আদেশ সন্বন্ধে বিরোধ করলে ও অবাধ্য হলে যা তোমরা ভালোবাস তা তোমাদের দেখাবার পরে। তোমাদের মধ্যে কেউ ছিল যারা এই দুনিয়া চাচ্ছিল, আর তোমাদের মধ্যে কেউ ছিল যারা পরকাল চাচ্ছিল, তারপর তিনি তোমাদের তাদের থেকে পলায়নপর করলেন যেন তিনি তোমাদের শাসন করতে পারেন। আর তিনি নিঃসন্দেহ তোমাদের অপরাধ মার্জনা করলেন। আর আল্লাহ্ বিশ্বাসীদের প্রতি অশেষ কৃপাময়।\qt@no{(152)}}
\qt@newcmd\qurantrans@bn@cdxlvi{স্মরণ করো! তোমরা পাহাড়ে উঠছিলে আর কারো দিকে ভ্রক্ষেপ করছিলে না, আর রসূল তোমাদের পিছন থেকে তোমাদের ডাকছিলেন, কাজেই তিনি তোমাদের এক বিষাদের উপরে আরেক বিষাদ উপহার দিলেন, যেন তোমরা অনুশোচনা না করো যা তোমাদের থেকে ফসকে গেছে, আর যা তোমাদের উপরে বর্তেছে তার জন্যেও না। আর তোমরা যা করো সে- সন্বন্ধে আল্লাহ্ চির-ওয়াকিফহাল।\qt@no{(153)}}
\qt@newcmd\qurantrans@bn@cdxlvii{তারপর বিষাদের পরে তিনি তোমাদের উপরে বর্ষণ করলেন নিরাপত্তা, তোমাদের একদলের উপরে নেমে এল প্রশান্তি, আর অন্য এক দলের নিজেদের মন তাদের উৎকতি করেছিল, তারা আল্লাহ্ সন্বন্ধে অজ্ঞানতাকালীন সন্দেহপ্রবণতায় সন্দিহান হয়েছিল অসঙ্গতভাবে। তারা বলছিল -- ''এই ব্যাপারে আমাদের কি কোনো কিছু আছে?’’ বলো -- ''নিঃসন্দেহ ব্যাপারটি সর্বতোভাবে আল্লাহ্‌র।’’ তারা তাদের নিজেদের মধ্যে যা লুকিয়ে রেখেছে তা তোমার কাছে প্রকাশ করছে না, তারা বলছিল -- ''এই ব্যাপারে যদি আমাদের কিছু থাকতো তবে এখানে আমাদের কাতল করা হতো না।’’ তুমি বলো -- ''তোমরা যদি তোমাদের বাড়ির ভিতরেও থাকতে তথাপি যাদের জন্য প্রাণঘাত লিখিত হয়েছে তারা নিশ্চয়ই তাদের নির্ধারিত-স্থলে গিয়ে হাজির হতো।’’ আর আল্লাহ্ যেন যাচাই করতে পারেন কি আছে তোমাদের বুকের ভেতরে, আর যেন নিংড়ে বের করে দিতে পারেন যা আছে তোমাদের অন্তরে। আর বুকের ভেতরে যা আছে সে-সন্বন্ধে আল্লাহ্ সর্বজ্ঞাতা।\qt@no{(154)}}
\qt@newcmd\qurantrans@bn@cdxlviii{নিঃসন্দেহ যেদিন দুই সৈন্যদল পরস্পর সম্মুখীন হয়েছিল সেদিন তোমাদের মধ্যে যারা পলায়নপর হলে, তাদের পদস্খলন করেছিল শয়তান যেহেতু তারা কিছু কামিয়েছিল, আর অবশ্য আল্লাহ্ তাদের মার্জনা করলেন। নিঃসন্দেহ আল্লাহ্ পরিত্রাণকারী, অতি অমায়িক।\qt@no{(155)}}
\qt@newcmd\qurantrans@bn@cdxlix{ওহে যারা ঈমান এনেছ! তাদের মতো হয়ো না যারা অবিশ্বাস পোষণ করেছে, আর যারা তাদের ভাইদের বলে যখন তারা দেশে পরিভ্রমণ করে অথবা অভিযানে লিপ্ত হয় -- ''তারা যদি আমাদের সাথে থাকতো তবে তারা মারা পড়তো না বা তাদের কাতল করা হতো না।’’ পরিণামে আল্লাহ্ এটি তাদের অন্তরে আক্ষেপের বিষয় করেছেন। আর আল্লাহ্ জীবনদান করেন ও মৃত্যু ঘটান। আর তোমরা যা করছো আল্লাহ্ তার দর্শক।\qt@no{(156)}}
\qt@newcmd\qurantrans@bn@cdl{আর যদি আল্লাহ্‌র পথে তোমাদের হত্যা করা হয় অথবা তোমরা মারা যাও, -- নিঃসন্দেহ আল্লাহ্‌র কাছ থেকে পরিত্রাণলাভ ও করুণাপ্রাপ্তি তারা যা জমা করে তার চাইতে উৎকৃষ্টতর।\qt@no{(157)}}
\qt@newcmd\qurantrans@bn@cdli{আর যদি তোমরা মারাই যাও বা তোমাদের কাতল করা হয়, নিঃসন্দেহ আল্লাহ্‌র কাছে তোমাদের একত্রিত করা হবে।\qt@no{(158)}}
\qt@newcmd\qurantrans@bn@cdlii{তারপর আল্লাহ্‌র করুণার ফলেই তুমি তাদের প্রতি কোমল হয়েছিলে। আর তুমি যদি রুক্ষ ও কঠোর-হৃদয় হতে তবে নিঃসন্দেহ তারা তোমার চারপাশ থেকে বিচ্ছিন্ন হয়ে যেতো। অতএব তাদের অপরাধ মার্জনা করো, আর তাদের জন্য ক্ষমা প্রার্থনা করো, আর তাদের সঙ্গে কাজেকর্মে পরামর্শ করো। আর যখন সংকল্প গ্রহণ করেছ তখন আল্লাহ্‌র উপরে নির্ভর করো। নিঃসন্দেহ আল্লাহ্ ভালোবাসেন নির্ভরশীলদের।\qt@no{(159)}}
\qt@newcmd\qurantrans@bn@cdliii{যদি আল্লাহ্ তোমাদের সাহায্য করেন তবে কেউ তোমাদের পরাভূত করতে পারবে না, আর যদি তিনি তোমাদের পরিত্যাগ করেন তবে তাঁর পরে আর কে আছে যে তোমাদের সাহায্য করতে পারে? আর আল্লাহ্‌র উপরেই তাহলে বিশ্বাসীদের নির্ভর করা উচিত।\qt@no{(160)}}
\qt@newcmd\qurantrans@bn@cdliv{আর কোনো নবীর পক্ষে এটি নয় যে তিনি প্রতারণা করবেন। আর যে কেউ প্রতারণা করে সে যা-কিছু প্রতারণা করেছে তা কিয়ামতের দিনে নিয়ে আসবে। তারপর প্রত্যেক সত্ত্বাকে পুরোপুরি দেয়া হবে যা সে অর্জন করেছে, আর তাদের অন্যায় করা হবে না।\qt@no{(161)}}
\qt@newcmd\qurantrans@bn@cdlv{কি! যে আল্লাহ্‌র সন্তষ্টির অনুবর্তী সে কি তার মতো যে আল্লাহ্‌র কাছ থেকে অসন্তোষ আনয়ন করেছে ও যার ঠাঁই হচ্ছে জাহান্নাম? আর জঘন্য সেই গন্তব্যস্থল!\qt@no{(162)}}
\qt@newcmd\qurantrans@bn@cdlvi{আল্লাহ্‌র কাছে তাদের স্তরভেদ আছে। আর তারা যা করছে আল্লাহ্ তার দর্শক।\qt@no{(163)}}
\qt@newcmd\qurantrans@bn@cdlvii{নিঃসন্দেহ আল্লাহ্ বিশ্বাসীদের প্রতি অনুগ্রহ করেছিলেন যখন তিনি তাদের কাছে তাদের মধ্য থেকে দাঁড় করালেন একজন রসূল যিনি তাঁর নির্দেশাবলী তাদের কাছে পাঠ করেন ও তাদের পরিশোধিত করেন ও তাদের কিতাব ও জ্ঞান-বিজ্ঞান শিক্ষা দেন; যদিও এর আগে নিঃসন্দেহ তারা ছিল স্পষ্ট ভুলের মধ্যে।\qt@no{(164)}}
\qt@newcmd\qurantrans@bn@cdlviii{কি! যখন কোনো দুর্যোগ তোমাদের উপরে ঘটলো, ইতিপূর্বে তোমরা আঘাত করেছিলে এর দ্বিগুণ পরিমাণ, তোমরা বলতে থাকলে -- ''এ কোথা থেকে?’’ বলো -- ''এসব তোমাদের নিজেদের থেকে।’’ নিশ্চয় আল্লাহ্ সব-কিছুর উপরে সর্বশক্তিমান।\qt@no{(165)}}
\qt@newcmd\qurantrans@bn@cdlix{আর যেদিন দুই সৈন্যদল মুখোমুখি হয়েছিল সেদিন যা তোমাদের উপরে ঘটেছিল তা আল্লাহ্‌র জ্ঞাতসারে, আব যেন তিনি বিশ্বাসীদের জানতে পারেন,\qt@no{(166)}}
\qt@newcmd\qurantrans@bn@cdlx{আর যেন তিনি জানতে পারেন তাদের যারা কপটতা করে, আর তাদের বলা হয়েছিল -- ''এসো, আল্লাহ্‌র পথে যুদ্ধ করো, অথবা আ‌ত্মরক্ষা করো।’’ তারা বলেছিল -- ''আমরা যদি যুদ্ধ করতে জানতাম তবে আমরা নিঃসন্দেহ তোমাদের অনুসরণ করতাম।’’ সেদিন তারা ঈমানের চাইতে অবিশ্বাসের নিকটতর হয়েছিল। তারা তাদের মুখ দিয়ে বলছিল যা তাদের অন্তরে ছিল না, আর আল্লাহ্ ভালো জানেন যা তারা লুকোচ্ছে।\qt@no{(167)}}
\qt@newcmd\qurantrans@bn@cdlxi{তারা বাড়িতে বসে থেকে তাদের ভাইদের সন্বন্ধে বলেছিল -- ''তারা যদি আমাদের কথা শুনতো তবে তাদের কাতল করা হতো না।’’ বলো -- ''তাহলে নিজেদের থেকে তোমরা মৃত্যুকে ঠেকাও, যদি তোমরা সত্যবাদী হও।’’\qt@no{(168)}}
\qt@newcmd\qurantrans@bn@cdlxii{আর যাদের আল্লাহ্‌র পথে হত্যা করা হয়েছে তাদের মৃত ভেবো না, বরং তাদের প্রভুর দরবারে জীবন্ত, তাদের রিযেক দেওয়া হবে,\qt@no{(169)}}
\qt@newcmd\qurantrans@bn@cdlxiii{আল্লাহ্ তাঁর করুণাভান্ডার থেকে তাদের যা দিয়েছেন সেজন্যে খুশিতে ডগমগ, আর তারা আনন্দ করবে তাদের জন্য যারা তাদের সঙ্গে মিলিত হয়নি তাদের পশ্চাদভাগ থেকে, কেননা তাদের উপরে কোনো ভয় নেই আর তারা অনুতাপও করবে না।\qt@no{(170)}}
\qt@newcmd\qurantrans@bn@cdlxiv{তারা আনন্দ করবে আল্লাহ্‌র কাছ থেকে অনুগ্রহের জন্য এবং করুণাভান্ডারের জন্য, আর নিঃসন্দেহ আল্লাহ্ বিশ্বাসীদের প্রাপ্য বিফল করেন না।\qt@no{(171)}}
\qt@newcmd\qurantrans@bn@cdlxv{যারা আল্লাহ্ ও রসূলের আহ্বানে সাড়া দিয়েছিল তাদের উপরে দুর্যোগ ঘটার পরে, -- তাদের মধ্যে যারা সৎকর্ম করে ও ভয়শ্রদ্ধা করে তাদের জন্য আছে বিরাট পুরস্কার।\qt@no{(172)}}
\qt@newcmd\qurantrans@bn@cdlxvi{লোকেরা যাদের বলেছিল -- ''নিঃসন্দেহ তোমাদের বিরুদ্ধে লোক জমায়েৎ হয়েছে, অতএব তাদের ভয় করো।’’ কিন্তু তাদের ঈমান বেড়ে গেল, আর তারা বললে -- ''আল্লাহ্ আমাদের জন্য যথেষ্ট ও তিনি অতি উত্তম রক্ষাকর্তা।’’\qt@no{(173)}}
\qt@newcmd\qurantrans@bn@cdlxvii{সুতরাং তারা ফিরে এল আল্লাহ্‌র কাছ থেকে নিয়ামত ও করুণাভান্ডার নিয়ে, কোনো অনিষ্ট তাদের স্পর্শ করে নি, বস্তুতঃ তারা আল্লাহ্‌র প্রসন্নতার অনুগমন করেছিল। আর আল্লাহ্ অফুরন্ত করুণাভান্ডারের মালিক।\qt@no{(174)}}
\qt@newcmd\qurantrans@bn@cdlxviii{নিঃসন্দেহ তোমাদের সেই শয়তানই ভয় দেখায় তার বন্ধুবান্ধবকে, কিন্তু তোমরা তাদের ভয় করো না, বরং আমাকে ভয় করো, -- যদি তোমরা ঈমানদার হও।\qt@no{(175)}}
\qt@newcmd\qurantrans@bn@cdlxix{আর যারা অবিশ্বাসের প্রতি ধাবিত হয় তারা যেন তোমাকে দুঃখিত না করে, নিঃসন্দেহ তারা আল্লাহ্‌র কোনো ক্ষতি করতে পারে না। আল্লাহ্ চান যে আখেরাতে তাদের জন্য লাভের কিছুই থাকুক না, আর তাদের জন্য রয়েছে কঠোর শাস্তি।\qt@no{(176)}}
\qt@newcmd\qurantrans@bn@cdlxx{নিঃসন্দেহ যারা ঈমানের বিনিময়ে অবিশ্বাস কিনেছে তারা আল্লাহ্‌র কোনো ক্ষতি করতে পারবে না; আর তাদের জন্য রয়েছে ন্তন্ত শাস্তি।\qt@no{(177)}}
\qt@newcmd\qurantrans@bn@cdlxxi{আর যারা অবিশ্বাস পোষণ করে তারা যেন না ভাবে যে আমরা তাদের যে বিরাম দিয়েছি তা তাদের নিজেদের ভালোর জন্য। নিঃসন্দেহ আমরা তাদের অবকাশ দিই যেন তারা পাপের মাত্রা বাড়িয়ে তুলে, আর তাদের জন্য রয়েছে লাঞ্ছনাদায়ক শাস্তি।\qt@no{(178)}}
\qt@newcmd\qurantrans@bn@cdlxxii{তোমরা যে অবস্থায় আছ সে অবস্থায় আল্লাহ্ কোনোক্রমেই বিশ্বাসীদের ফেলে রাখবেন না, যে পর্যন্ত না তিনি ভালোদের থেকে মন্দদের পৃথক করেন। আর আল্লাহ্ অদৃশ্য সন্বন্ধে তোমাদের কাছে গোচরীভূত করবেন না, তবে আল্লাহ্ তাঁর রসূলদের মধ্যে থেকে যাঁকে ইচ্ছা করেন নির্বাচিত করেন। অতএব আল্লাহ্‌তে ও তাঁর রসূলগণে ঈমান আনো। আর যদি তোমরা বিশ্বাস করো ও ভয়শ্রদ্ধা করো তবে তোমাদের জন্য রয়েছে বিরাট পুরস্কার।\qt@no{(179)}}
\qt@newcmd\qurantrans@bn@cdlxxiii{আর আল্লাহ্ তাঁর করুণাভান্ডার থেকে তাদের যা দান করেছেন সে-বিষয়ে যারা কৃপণতা করে তারা যেন না ভাবে যে তা তাদের জন্য ভালো। না, তা তাদের জন্য মন্দ। যে বিষয়ে তারা কঞ্জুসি করে তা কিয়ামতের দিনে তাদের গলায় ঝুলানো থাকবে। আর মহাকাশমন্ডল ও পৃথিবীর উত্তরাধিকার আল্লাহ্‌র। আর যা তোমরা করো আল্লাহ্ তার পূর্ণ ওয়াকিফহাল।\qt@no{(180)}}
\qt@newcmd\qurantrans@bn@cdlxxiv{আল্লাহ্ অবশ্যই শুনেছেন তাদের কথা যারা বলেছিল -- ''নিশ্চয় আল্লাহ্ গরিব, আর আমরা ধনী।’’ কাজেই আমরা লিখে রাখবো তারা যা বলে ও তাদের অন্যায়ভাবে নবীদের হত্যা করতে যাওয়া; আর আমরা বলবো -- ''পোড়ার যন্ত্রণার স্বাদ গ্রহণ করো।\qt@no{(181)}}
\qt@newcmd\qurantrans@bn@cdlxxv{''এ তার জন্য যা তোমাদের নিজ হাত আগ বাড়িয়েছে, আর যেহেতু আল্লাহ্ বান্দাদের প্রতি জালিম নন।’’\qt@no{(182)}}
\qt@newcmd\qurantrans@bn@cdlxxvi{যারা বলেছিল -- ''নিঃসন্দেহ আল্লাহ্ আমাদের কাছে অঙ্গীকার করেছেন যে আমরা কোনো রসূলের প্রতি ঈমান আনবো না যে পর্যন্ত না তিনি আমাদের কাছে এমন কুরবানি আনেন যাকে আগুন পুড়িয়ে থাকে।’’ তুমি বলো -- ''নিশ্চয়ই আমার আগে তোমাদের কাছে রসূলগণ এসেছিলেন স্পষ্ট প্রমাণাবলী নিয়ে আর তোমরা যার কথা বলছো তা নিয়ে, তবে কেন তোমরা তাঁদের হত্যা করতে যাচ্ছিলে, যদি তোমরা সত্যবাদী হও।’’\qt@no{(183)}}
\qt@newcmd\qurantrans@bn@cdlxxvii{অতএব যদি তারা তোমাকে অস্বীকার করে তোমার আগের রসূলগণও এমনিভাবে অস্বীকৃত হয়েছিলেন, যাঁরা এসেছিলেন সঙ্গে নিয়ে স্পষ্ট প্রমাণাবলী ও যবূর ও উজ্জ্বল কিতাব।\qt@no{(184)}}
\qt@newcmd\qurantrans@bn@cdlxxviii{প্রত্যেক সত্ত্বাকে মৃত্যু আস্বাদন করতে হবে। আর নিশ্চয়ই কিয়ামতের দিনে তোমাদের প্রাপ্য পুরোপুরি তোমাদের আদায় করা হবে। কাজেই যাকে আগুন থেকে বহুদূরে রাখা হবে ও স্বর্গোদ্যানে প্রবিষ্ট করা হবে, নিঃসন্দেহ সে হ’ল সফলকাম। আর এই দুনিয়ার জীবন ধোকার সন্বল ছাড়া কিছুই নয়।\qt@no{(185)}}
\qt@newcmd\qurantrans@bn@cdlxxix{নিশ্চয়ই তোমাদের পরীক্ষা করা হবে তোমাদের ধনসম্পত্তি ও তোমাদের লোকজনের মাধ্যমে, আর নিঃসন্দেহ তোমরা শুনতে পাবে তোমাদের আগে যাদের গ্রন্থ দেয়া হয়েছে তাদের থেকে এবং যারা শরিক করে তাদের থেকে অনেক গালিগালাজ। আর যদি তোমরা ধৈর্য ধারণ করো ও ভয়ভক্তি করো তবে নিশ্চয় সেটি হবে সৎসাহসের কাজ।\qt@no{(186)}}
\qt@newcmd\qurantrans@bn@cdlxxx{আর স্মরণ করো! যাদের কিতাব দেওয়া হয়েছিল তাদের থেকে আল্লাহ্ অঙ্গীকার গ্রহণ করেছিলেন -- ''তোমরা নিশ্চয় এর কথা লোকেদের কাছে প্রকাশ করবে, আর তা লুকিয়ে রাখবে না।’’ কিন্তু তারা এটি তাদের পিঠের পেছনে ফেলে রেখে দিয়েছিল, আর এর জন্য তারা বিনিময়ে স্বল্পমূল্য গ্রহণ করেছিল। অতএব মন্দ তারা যা কেনে।\qt@no{(187)}}
\qt@newcmd\qurantrans@bn@cdlxxxi{তুমি মনে করো না যারা উল্লসিত হয় যা তাদের দেয়া হয়েছে সেজন্য, আর প্রশংসা পেতে ভালোবাসে যা করে নি তার জন্যেও, -- কাজেই তুমি তাদের ভেবো না যে তারা শাস্তি থেকে নিরাপদ, আর তাদের জন্য রয়েছে ব্যথাদায়ক শাস্তি।\qt@no{(188)}}
\qt@newcmd\qurantrans@bn@cdlxxxii{আর আল্লাহ্‌রই মহাকাশমন্ডল ও পৃথিবী রাজত্ব। আর আল্লাহ্ সব-কিছুর উপরে সর্বশক্তিমান।\qt@no{(189)}}
\qt@newcmd\qurantrans@bn@cdlxxxiii{নিঃসন্দেহ মহাকাশমন্ডলী ও পৃথিবীর সৃষ্টিতে এবং রাত ও দিনের আবর্তনে বিশেষ নিদর্শন রয়েছে জ্ঞানবান লোকদের জন্য --\qt@no{(190)}}
\qt@newcmd\qurantrans@bn@cdlxxxiv{যারা আল্লাহ্‌কে স্মরণ করে দাঁড়ানো ও বসা ও তাদের পার্শ্বের উপরে শায়িত অবস্থায় আর গভীর চিন্তা করে মহাকাশমন্ডল ও পৃথিবীর সৃষ্টির বিষয়ে। ''আমাদের প্রভু! এসব তুমি বৃথা সৃষ্টি করো নি, তোমারই সব মহিমা। কাজেই আমাদের রক্ষা করো আগুনের শাস্তি থেকে।\qt@no{(191)}}
\qt@newcmd\qurantrans@bn@cdlxxxv{''আমাদের প্রভু! নিশ্চয়ই যাকে তুমি আগুনে প্রবিষ্ট করাও, তাকে তবে প্রকৃতই তুমি লাঞ্ছিত করেছ। আর অন্যায়কারীদের জন্য সাহায্যকারীদের কেউ থাকবে না।\qt@no{(192)}}
\qt@newcmd\qurantrans@bn@cdlxxxvi{''আমাদের প্রভু! নিঃসন্দেহ আমরা শুনেছি একজন ঘোষণাকারীকে ঈমানের প্রতি আহ্বান করতে এই বলে -- 'তোমাদের প্রভুরপ্রতি ঈমান আনো’, কাজেই আমরা ঈমান এনেছি। আমাদের প্রভু! অতএব আমাদের অপরাধ থেকে আমাদের পরিত্রাণ করো, আর আমাদের দোষত্রুটি আমাদের থেকে মুছে দাও, আর আমাদের প্রাণত্যাগ করতে দাও সজ্জনদের সঙ্গে।\qt@no{(193)}}
\qt@newcmd\qurantrans@bn@cdlxxxvii{''আমাদের প্রভু! আর আমাদের প্রদান করো যা তুমি আমাদের কাছে ওয়াদা করেছ তোমার রসূলদের মাধ্যমে, আর আমাদের লাঞ্ছিত করো না কিয়ামতের দিনে। নিঃসন্দেহ তুমি ওয়াদার খেলাফ করো না।’’\qt@no{(194)}}
\qt@newcmd\qurantrans@bn@cdlxxxviii{তাদের প্রভু তখন তাদের আহ্বানে সাড়া দিলেন -- ''আমি নিশ্চয়ই বিফল করবো না তোমাদের মধ্যের কর্মীদের কোনো কাজ -- পুরুষ হও বা নারী -- তোমাদের একজন অন্যজন থেকে, সুতরাং যারা হিজরত করেছে ও তাদের ঘরবাড়ি থেকে যারা বহিষ্কৃত হয়েছে, ও আমার পথে যারা নির্যাতিত হয়েছে, আর যারা যুদ্ধ করেছে ও নিহত হয়েছে -- নিঃসন্দেহ তাদের দোষত্রুটি তাদের থেকে অবশ্যই মুছে দেব আর নিঃসন্দেহ তাদের অবশ্যই প্রবিষ্ট করাব স্বর্গোদ্যানসমূহে যাদের নিচে দিয়ে বয়ে চলে ঝরনারাজি -- একটি পুরস্কার আল্লাহ্‌র দরবার থেকে। আর আল্লাহ্ -- তাঁর কাছে রয়েছে আরো উত্তম পুরস্কার।’’\qt@no{(195)}}
\qt@newcmd\qurantrans@bn@cdlxxxix{যারা অবিশ্বাস পোষণ করে শহরে-নগরে তাদের চলাফেরা তোমাকে যেন ধোকা না দেয়।\qt@no{(196)}}
\qt@newcmd\qurantrans@bn@cdxc{তুচ্ছ ভোগ! তারপর তাদের বাসস্থান হচ্ছে জাহান্নাম, আর জঘন্য এই বিশ্রামস্থল।\qt@no{(197)}}
\qt@newcmd\qurantrans@bn@cdxci{কিন্তু যারা তাদের প্রভুকে ভয়-শ্রদ্ধা করে তাদের জন্য স্বর্গোদ্যানসমূহ, যাদের নিচে দিয়ে বয়ে চলে ঝরনারাজি, তাতে তারা থাকবে চিরকাল -- আল্লাহ্‌র তরফ থেকে আপ্যায়ন। আর আল্লাহ্‌র কাছে যা রয়েছে তা পুণ্যা‌ত্মাদের জন্য আরো উত্তম।\qt@no{(198)}}
\qt@newcmd\qurantrans@bn@cdxcii{আর নিঃসন্দেহ গ্রন্থপ্রাপ্তদের মধ্যে যারা ঈমান আনে আল্লাহ্‌তে আর যা তোমাদের কাছে অবতীর্ণ হয়েছে আর যা তা দের কাছে নাযিল হয়েছিল তাতে, আল্লাহ্‌র কাছে বিনীত, তারা আল্লাহ্‌র বাণীসমূহের জন্য স্বল্পমূল্য কামাতে যায় না। এরাই, -- এদের জন্য এদের পুরস্কার রয়েছে এদের প্রভুর কাছে। নিঃসন্দেহ আল্লাহ্ হিসেব-নিকেশে তৎপর।\qt@no{(199)}}
\qt@newcmd\qurantrans@bn@cdxciii{ওহে যারা ঈমান এনেছ! ধৈর্যধারণ করো আর ধৈর্যধারণে অগ্রণী হও, আর অবিচল থেকো, আর আল্লাহ্‌কে ভয়শ্রদ্ধা করো, যেন তোমরা সফলকাম হতে পারো।\qt@no{(200)}}
\qt@newcmd\qurantrans@bn@cdxciv{\basmalahbn ওহে মানবগোষ্ঠি! তোমাদের প্রভুকে ভয়ভক্তি করো যিনি তোমাদের সৃষ্টি করেছেন একই নফস থেকে, আর তার জোড়াও সৃষ্টি করেছেন তার থেকে, আর এই উভয় থেকে ছড়িয়ে দিয়েছেন বহু নর ও নারী। অতএব ভয়শ্রদ্ধা করো আল্লাহ্‌কে যাঁর দ্বারা তোমরা পরস্পরের ও মাতৃজঠরের সওয়াল-জবাব করো। নিঃসন্দেহ আল্লাহ্ তোমাদের উপরে সদা প্রহরী।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@cdxcv{আর তাদের ধন-সম্পত্তি এতীমদের দিয়ে দাও, আর উৎকৃষ্ট বস্তুর সঙ্গে নিকৃষ্ট বস্তু বদলে নিও না। আর তাদের সম্পত্তি তোমাদের সম্পত্তির সঙ্গে গ্রাস করো না। নিঃসন্দেহ এটি গুরুতর অপরাধ।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@cdxcvi{আর যদি তোমরা আশঙ্কা করো যে তোমরা এতীমদের প্রতি ন্যায়পরায়ণ হতে পারছ না, তা হলে স্ত্রীলোকদের মধ্যের যাকে তোমাদের ভালো লাগে তাকে বিয়ে করতে পার -- দুই বা তিন বা চার। কিন্তু যদি তোমরা আশঙ্কা করো যে তোমরা সমব্যবহার করতে পারবে না, তা হলে একজনকেই, অথবা তোমাদের ডান হাত যাদের ধরে রেখেছে। এইটিই বেশী সঙ্গত যেন তোমরা সরে না যাও।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@cdxcvii{আর স্ত্রীলোকদের তাদের মহরানা আদায় করবে নিঃস্বার্থভাবে। কিন্তু যদি তারা নিজেরা এর কোনো অংশ তোমাদের দিতে খুশি হয় তবে তা ভোগ করো সানন্দে ও তৃপ্তির সাথে।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@cdxcviii{আর অবোধদের দিয়ে দিও না তোমাদের সম্পত্তি যা আল্লাহ্ তোমাদের জন্য অবলন্বনস্বরূপ করেছেন। আর তা থেকে তাদের খাওয়াও ও তাদের পরাও, আর তাদের বলো ভালোভালো কথা।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@cdxcix{আর এতীমদের পরীক্ষা করে দেখবে যে পর্যন্ত না তারা বিবাহ-বয়সে উপনীত হয়, তারপর যদি তাদের মধ্যে বিচার-বুদ্ধি দেখতে পাও তবে তাদের ধনসম্পত্তি তাদের হস্তার্পণ করবে, আর তা মাত্রাতিরিক্তভাবে ও তাড়াহুড়ো করে খেয়ে ফেলো না পাছে তারা বড় হয়ে যাবে। আর যে অবস্থাপন্ন সে যেন নিবৃত্ত থাকে, আর যে গরীব সে ন্যায়সঙ্গতভাবে খাক। তারপর যখন তোমরা তাদের সম্পত্তি তাদের ফিরিয়ে দাও তখন তাদের সামনে সাক্ষী ডাকো। আর হিসাব-রক্ষকরূপে আল্লাহ্ যথেষ্ট।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@d{পিতামাতা ও নিকট-আ‌ত্মীয়রা যা রেখে যায় তার একটি অংশ পুরুষদের জন্য, আর স্ত্রীলোকদের জন্যেও থাকবে একটি অংশ যা পিতামাতা ও নিকট-আ‌ত্মীয়রা রেখে যায় তার, -- তা কমই হোক বা বেশি, -- একটি নির্দিষ্ট অংশ।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@di{আর ভাগাভাগির সময়ে যখন উপস্থিত থাকে আ‌ত্মীয়-স্বজন ও এতীমরা ও গরীবরা, তখন তা থেকে তাদের দান করো, আর তাদের সঙ্গে ভালোভাবে কথাবার্তা বলো।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@dii{আর তারা তেমনি ভয় করুক যেমন তারা যদি তাদের পেছনে অসহায় ছেলেপিলে ফেলে রাখত তবে তাদের জন্য আশঙ্কা করতো। কাজেই তারা আল্লাহ্‌কে ভয়শ্রদ্ধা করুক এবং সততার সাথে কথাবার্তা বলুক।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@diii{নিঃসন্দেহ যারা এতীমদের ধনসম্পত্তি অন্যায়ভাবে গ্রাস করে তারা নিশ্চয়ই তাদের পেটে আগুন গিলে। আর তারা শীঘ্রই প্রবেশ করবে জ্বলন্ত আগুনে।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@div{আল্লাহ্ তোমাদের নির্দেশ দিচ্ছেন তোমাদের সন্তানসন্ততি সম্পর্কে, -- এক বেটাছেলের জন্য দুই মেয়েছেলের সমান অংশ। তবে যদি তারা সব মেয়ে হয়, দুই মেয়ের উর্ধ্বে, তবে তাদের জন্য সে যা রেখে গেছে তার দুই-তৃতীয়াংশ, আর যদি সে একমাত্র মেয়ে হয় তবে তার জন্য অর্ধেক । আর তার পিতামাতার জন্য -- তাদের দুজনের প্রত্যেকের জন্য সে যা রেখে গেছে তার ছয় ভাগের একভাগ, যদি তার সন্তান থাকে, কিন্তু তার যদি সন্তান না থাকে ও তার ওয়ারিশ হয় পিতামাতা, তবে তার মাতার জন্য এক-তৃতীয়াংশ, কিন্তু যদি তার ভাইরা থাকে তবে তার মায়ের জন্য ছয় ভাগের একভাগ, কোনো ওছিয়ৎনামাতে উইল করে থাকলে বা দেনা থাকলে তা আদায়ের পরে। তোমাদের পিতামাতা ও তোমাদের সন্তানসন্ততি -- তোমরা জানো না এদের কে তোমাদের কাছে ফায়দার দিক দিয়ে বেশি নিকটতর। এ আল্লাহ্‌র তরফ থেকে বিধান। নিঃসন্দেহ আল্লাহ্ হচ্ছেন সর্বজ্ঞাতা, পরমজ্ঞানী।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@dv{আর তোমাদের স্ত্রীরা যা রেখে যায় তার অর্ধেক তোমাদের জন্য যদি তাদের কোনো ছেলেপিলে না থাকে, কিন্তু যদি তাদের সন্তান থাকে তবে তোমাদের জন্য তারা যা রেখে গেছে তার এক-চতুর্থাংশ, -- কোনো ওছিয়ৎনামায় তারা উইল করে থাকলে বা দেনা থাকলে তা আদায়ের পরে। আর তাদের জন্য যা তোমরা রেখে যাও তার এক-চতুর্থাংশ যদি তোমাদের কোনো সন্তান না থাকে, কিন্তু যদি তোমাদের ছেলেপিলে থাকে তবে তাদের জন্য যা তোমরা রেখে গেছ তার আট ভাগের একভাগ, -- কোনো ওছিয়ৎনামায় তোমরা উইল করে থাকলে বা দেনা থাকলে তা আদায়ের পরে। আর যদি কোনো পুরুষ বা স্ত্রীলোককে নিঃসন্তান-ভাবে উত্তরাধিকার করতে হয় ও তার এক ভাই বা এক বোন থাকে তবে তাদের উভয়ের প্রত্যেকের জন্য ছয় ভাগের এক ভাগ, কিন্তু যদি তারা এর চেয়ে বেশী হয় তবে তারা হবে এক তৃতীয়াংশের অংশীদার, -- কোনো ওছিয়ৎনামায় তারা উইল করে থাকলে বা দেনা থাকলে তা আদায়ের পরে, -- কোনো ক্ষতি না করে, এ হচ্ছে আল্লাহ্‌র তরফ থেকে বিধান। আর আল্লাহ্ হচ্ছেন সর্বজ্ঞাতা, অতি অমায়িক।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@dvi{এইসব হচ্ছে আল্লাহ্‌র সীমা। আর যে কেউ আল্লাহ্ ও তাঁর রসূলের অনুবর্তী হয় তাকে তিনি প্রবেশ করাবেন স্বর্গোউদ্যানসমূহে যাদের নিচে দিয়ে বয়ে চলে ঝরনারাজী, সেখানে সে থাকবে স্থায়ীভাবে আর তাই হচ্ছে মহা সাফল্য।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@dvii{আর যে কেউ আল্লাহ্ ও তাঁর রসূলের অবাধ্য হয় আর তাঁর সীমা লঙ্ঘন করে, তাকে তিনি প্রবেশ করাবেন আগুনে, সেখানে থাকবার জন্য দীর্ঘকাল, আর তার জন্য রয়েছে লাঞ্ঝনাদায়ক শাস্তি।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@dviii{আর তোমাদের নারীদের মধ্যে যারা অশ্লীল আচরণ করে তাদের বিরুদ্ধে তোমাদের মধ্যে থেকে চারজন সাক্ষী ডাকো, তারা যদি সাক্ষ্য দেয় তবে তাদের ঘরের ভেতরে আটক করে রাখো যে পর্যন্ত না মৃত্যু তাদের উপরে ঘনিয়ে আসে, অথবা আল্লাহ্ তাদের জন্য পথ করে দেন।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@dix{আর তোমাদের মধ্যে দুজন যদি ঐ আচরণ করে তবে তাদের উভয়কেই অল্প শাস্তি দাও। তারপর যদি তারা তওবা করে ও শোধরায় তবে তাদের থেকে ফিরিয়ে নাও। নিঃসন্দেহ আল্লাহ বারবার ফেরেন, অফুরন্ত ফলদাতা।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@dx{নিঃসন্দেহ আল্লাহ্‌র পক্ষে ফেরা সব তাদের প্রতি যারা কুকর্ম করে অজ্ঞানতা বশতঃ, তারপর অবিলন্বে তওবা ক রে, অতএব এরাই -- আল্লাহ্ এদের প্রতি ফেরেন, আর আল্লাহ্ হচ্ছেন সর্বজ্ঞাতা, পরমজ্ঞানী।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@dxi{আর তওবা তাদের জন্য নয় যারা কুকর্ম করেই চলে, যে পর্যন্ত না মৃত্যু তাদের কোনো একের কাছে হাজির হলে সে বলে -- ''আমি অবশ্যই এখন তওবা করছি’’, তাদের জন্যও যারা মারা যায় অথচ তারা অবিশ্বাসী থাকে। তারাই -- তাদের জন্য আমরা তৈরি করেছি ব্যথাদায়ক শাস্তি।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@dxii{ওহে যারা ঈমান এনেছ! তোমাদের জন্য বৈধ নয় যে তোমরা স্ত্রীদের জবরদস্তি উত্তরাধিকার-সূত্রে গ্রহণ করবে। আর তাদের উপরে জোরজুলুম করো না তোমরা যা তাদের দিয়েছ তার অংশ বিশেষ ফিরে পাবার জন্য, যদি না তারা জাজ্জ্বল্যমান অশ্লীল আচরণে লিপ্ত হয়। আর তাদের প্রতি সদয় ব্যবহার করো। অবশ্য যদি তোমরা তাদের ঘৃণা করো তবে হতে পারে তোমরা এমন একটা কিছু অপছন্দ করলে অথচ আল্লাহ্ তার মধ্যে প্রচুর কল্যাণ নিহিত রেখেছেন।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@dxiii{আর তোমরা যদি এক স্ত্রীর স্থলে আরেক স্ত্রী বদলে নিতে চাও, আর যদি এদের একজনকে একস্তূপ দিয়ে থাকো, তবে তা থেকে কিছুই নিও না। তোমরা কি তা নেবে কুৎসা রটিয়ে এবং ডাহা অন্যায় করে?\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@dxiv{আর কেমন করে তোমরা তা নিতে পারো যখন তোমাদের একে অন্যতে গমন করেছ আর তারা তোমাদের থেকে দৃঢ় অঙ্গীকার গ্রহণ করেছে?\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@dxv{আর তোমাদের পিতারা যাদের বিয়ে করেছিল সে-সব স্ত্রীলোকদের বিয়ে করো না, -- অবশ্য যা ইতিমধ্যে ঘটে গেছে তা ব্যতীত। নিঃসন্দেহ এটি হচ্ছে একটি অশ্লীল আচরণ ও ঘৃণ্য কর্ম, আর জঘন্য পন্থা!\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@dxvi{তোমাদের জন্য অবৈধ হচ্ছে -- তোমাদের মায়েরা আর তোমাদের মেয়েরা আর তোমাদের বোনেরা আর তোমাদের ফুফুরা আর তোমাদের মাসীরা, আর ভাইয়ের মেয়েরা ও বোনের মেয়েরা, আর তোমাদের মায়েরা যারা তোমাদের স্তন্যদান করেছে, আর দুধ- মায়ের দিক থেকে তোমাদের বোনেরা, আর তোমাদের স্ত্রীদের মায়েরা, আর তোমাদের সৎ-মেয়েরা যারা তোমাদের অভিভাবকত্বে আছে -- তোমাদের তেমন স্ত্রীদের থেকে যাদের সাথে সহবাস করেছ, কিন্তু যদি তাদের সাথে সহবাস করে না থাক তবে তোমাদের অপরাধ হবে না, আর যারা তোমাদের ঔরস থেকে তোমাদের তেমন ছেলেদের স্ত্রীরা; আর যেন তোমরা দুই বোনের মধ্যে জমায়েৎ করো -- অবশ্য যা ইতিমধ্যে ঘটে গেছে তা ব্যতীত। অবশ্য আল্লাহ্ হচ্ছেন পরিত্রাণকারী, অফুরন্ত ফলদাতা।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@dxvii{আর স্ত্রীলোকদের মধ্যের সধবা যারা, তবে তোমাদের ডান হাত যাদের ধরে রেখেছে তাদের ব্যতীত, তোমাদের প্রতি আল্লাহ্‌র বিধান। আর এদের বাইরে তোমাদের জন্য বৈধ করা গেল যদি তোমরা চাও তোমাদের ধনদৌলত দিয়ে বিবাহ -বন্ধনের মাধ্যম, ব্যভিচারের জন্য নয়। অতএব তাদের মধ্যের যাদের থেকে তোমরা সুফল পেতে চাও তাদের নির্ধারিত মহরানা তাদের প্রদান করো। আর তোমাদের জন্য দূষণীয় হবে না নির্ধারিত হবার পরে তোমরা যাতে পরস্পর সম্মত হও। নিঃসন্দেহ আল্লাহ্ সর্বজ্ঞাতা, পরমজ্ঞানী।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@dxviii{আর তোমাদের মধ্যে যার আর্থিক সংগতি নেই যে বিশ্বাসিনী স্বাধীন নারীকে বিয়ে করতে পারে, সে তবে তোমাদের ডান হাতে ধরে রাখা বিশ্বাসিনী কুমারীদের মধ্য থেকে। আর আল্লাহ্ ভালো জানেন তোমাদের ধর্মবিশ্বাস সন্বন্ধে, তোমরা একে অন্য থেকে কাজেই তাদের বিয়ে করো তাদের মনিবের অনুমতি নিয়ে, আর তাদের মহরানা তাদের দাও সুষ্ঠুভাবে, -- বিবাহ-বন্ধনের মাধ্যমে, ব্যভিচারের জন্যে নয় আর রক্ষিতারূপে গ্রহণ করেও নয়। অতএব যখন তাদের বিবাহ-বন্ধনে আনা হয়, তারপর যদি তারা অশ্লীল আচরণ করে তবে তাদের জন্য হচ্ছে স্বাধীন নারীদের জন্যে নির্ধারিত শাস্তির অর্ধেক। এ হচ্ছে তোমাদের মধ্যে তার জন্য যে পাপে পড়ার ভয় করে। আর যদি তোমরা ধৈর্য ধরো, তবে সেটি তোমাদের জন্য বেশী ভালো। আর আল্লাহ্ ত্রাণকর্তা, অফুরন্ত ফলদাতা।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@dxix{আল্লাহ্ চান তোমাদের পূর্ববর্তী যারা ছিল তাদের দৃষ্টান্তেরদ্বারা তোমাদের কাছে সুস্পষ্ট করতে ও তোমাদের হেদায়ত করতে, আর তোমাদের দিকে ফিরতে। আর আল্লাহ্ সর্বজ্ঞাতা, পরমজ্ঞানী।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@dxx{আর আল্লাহ্ চান যে তিনি তোমাদের দিকে সর্বদা ফেরেন, কিন্তু যারা কাম-লালসার অনুসরণ করে তারা চায় তোমরাও যেন গহীন বিপথে পথ হারাও।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@dxxi{আল্লাহ্ চান যে তিনি তোমাদের বোঝা হাল্কা করেন, আর মানুষকে দুর্বল ক’রে সৃষ্টি করা হয়েছে ।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@dxxii{ওহে যারা ঈমান এনেছ! তোমাদের সম্পত্তি জুচ্চুরি করে নিজেদের মধ্যে গ্রাস করো না, তবে যদি তোমাদের পরস্পর সম্মতিক্রমে ব্যবসা-বাণিজ্যের দ্বারা এ হয়ে থাকে, আর নিজেদের লোকদের হত্যা করো না, যেহেতু আল্লাহ্ নিঃসন্দেহ তোমাদের প্রতি অফুরন্ত ফলদাতা।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@dxxiii{আর যে কেউ তা করে উল্লঙ্ঘন ক’রে ও অত্যাচার ক’রে, আমরা অচিরেই তাকে ফেলবো আগুনে। আর এ আল্লাহ্‌র জন্য সহজ ব্যাপার।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@dxxiv{যদি তোমরা বিরত থাকো বড়গুলো থেকে যা তোমাদের জন্য নিষিদ্ধ করা হয়েছে, তবে তোমাদের থেকে আমরা তোমাদের দোষত্রুটি মূছে দেব, আর তোমাদের প্রবেশ করাবো এক গৌরবময় প্রবেশদ্বারে।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@dxxv{আর ঈর্ষা করো না যে বিষয়দ্বারা আল্লাহ্ তোমাদের কাউকে অপরের উপরে শ্রেষ্ঠতা দিয়েছেন। পুরুষদের জন্য ভাগ রয়েছে যা তারা অর্জন করে, আর নারীদের জন্যেও ভাগ রয়েছে যা তারা অর্জন করে। কাজেই আল্লাহ্‌র কাছে চাও তাঁর করুণাভান্ডার থেকে। নিঃসন্দেহ আল্লাহ্ সব-কিছু সন্বন্ধে সর্বজ্ঞাতা।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@dxxvi{আর প্রত্যেকের জন্য আমরা উত্তরাধিকার নির্ধারিত করেছি যা পিতামাতা ও নিকট-আ‌ত্মীয়রা রেখে যায়। আর যাদের সঙ্গে তোমাদের ডান হাতের দ্বারা অঙ্গীকার করেছ তাদের ভাগ তা হলে প্রদান করো। আল্লাহ্ নিঃসন্দেহ সব-কিছু তেই সাক্ষ্যদাতা।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@dxxvii{পুরুষরা নারীদের অবলন্বন, যেহেতু আল্লাহ্ তাদের এক শ্রেণীকে অন্য শ্রেণীর উপরে শ্রেষ্ঠত্ব দিয়েছেন, এবং যেহেতু তারা তাদের সম্পত্তি থেকে খরচ করে। কাজেই সতীসাধবী নারীরা অনুগতা, গোপনীয়তার রক্ষয়িত্রী, যেমন আল্লাহ্ রক্ষা করেছেন। আর যে নারীদের ক্ষেত্রে তাদের অবাধ্যতা আশঙ্কা করো, তাদের উপদেশ দাও, আর শয্যায় তাদের একা ফেলে রাখো, আর তাদের প্রহার করো। তারপর যদি তারা তোমাদের অনুগতা হয় তবে তাদের বিরুদ্ধে অন্য পথ খুজোঁ না। নিঃসন্দেহ আল্লাহ্ সর্বজ্ঞাতা, মহামহিম।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@dxxviii{আর যদি তোমরা দু’জনের মধ্যে বিচ্ছেদ আশঙ্কা করো, তবে তার লোকদের থেকে একজন মধ্যস্থ নিয়োগ করো এবং ওর লোকদের থেকেও একজন মধ্যস্থ, যদি তারা দু’জনই মিটমাট চায় তবে আল্লাহ্ তাদের মধ্যে মিলন ঘটাবেন। নিঃসন্দেহ আল্লাহ্ সর্বজ্ঞাতা, ওয়াকিফহাল।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@dxxix{আর আল্লাহ্‌র এবাদত করো, আর তাঁর সাথে অন্য কিছু শরিক করো না, আর পিতামাতার প্রতি সদয় আচরণ করো, আর নিকটা‌ত্মীয়দের প্রতি, আর এতীমদের আর মিসকিনদের, আর নিকট সম্পর্কের প্রতিবেশীর, আর পরকীয় প্রতিবেশীর, আর পার্শ্ববর্তী সাথীর, আর পথচারীর, আর যাকে তোমাদের ডান হাত ধরে রেখেছে। নিঃসন্দেহ আল্লাহ্ ভালোবাসেন না তাকে যে দাম্ভিক, গর্বিত, --\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@dxxx{যে কার্পণ্য করে আর লোকদের কৃপণতার নির্দেশ দেয়, আর লুকিয়ে রাখে আল্লাহ্ যা তাদের দিয়েছেন তাঁর করুনাভান্ডার থেকে। আর অবিশ্বাসীদের জন্যে আমরা তৈরি করেছি লাঞ্ঝনাদায়ক শাস্তি, --\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@dxxxi{আর যারা তাদের ধনসম্পত্তি খরচ করে লোকদের দেখাবার জন্য, অথচ তারা বিশ্বাস করে না আল্লাহ্‌তে, আর আখেরাতের দিনেও না। আর যার জন্য সঙ্গী হয়েছে শয়তান, -- সে তবে মন্দ সাথী।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@dxxxii{আর এতে তাদের কি বা হতো যদি তারা আল্লাহ্‌তে ও আখেরাতের দিনে ঈমান আনতো, আর খরচ করতো আল্লাহ্ তাদের যা রিযেক দিয়েছেন তা থেকে? আর আল্লাহ্ তাদের ব্যাপারে সর্বজ্ঞাতা।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@dxxxiii{নিঃসন্দেহ আল্লাহ্ অনুপরিমাণেও অবিচার করেন না; আর যদি এটা শুভ কাজ হয় তিনি তা বহুগুণিত করেন, আর তাঁর নিজের তরফ থেকে দেন মহান পুরস্কার।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@dxxxiv{কাজেকাজেই তখন কেমন হবে যখন প্রত্যেক জাতি থেকে আমরা এক একজন সাক্ষী আনবো, আর তোমাকে আনবো তাদের সমক্ষে সাক্ষীরূপে?\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@dxxxv{সেইদিন তারা চাইবে যারা অবিশ্বাস করে ও রসূলকে অমান্য করে, -- তাদের নিয়ে পৃথিবীটা যদি সমতল হয়ে যেত। আর তারা আল্লাহ্ থেকে কোনো কথা লুকোতে পারবে না।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@dxxxvi{ওহে যারা ঈমান এনেছ! নামাযের ধারে-কাছে যেয়ো না যখন তোমরা নেশায় চুর হয়ে থাকো, যে পর্যন্ত না তোমরা বুঝো কি তোমরা বলছো, অথবা যৌন-সম্ভোগ করার পরবর্তী অবস্থায়, -- তবে শুধু অতিক্রম করা ছাড়া -- যতক্ষণ না গোসল করেছ। আর যদি তোমরা অসুস্থ হও, অথবা সফরে থাকো, অথবা তোমাদের কেউ পায়খানা থেকে এসেছ, অথবা স্ত্রীদের স্পর্শ করেছ, আর যদি পানি না পাও তবে তৈয়ম্মুম করো বিশুদ্ধ মাটি নিয়ে, আর তোমাদের মুখমন্ডল ও তোমাদের হাত মুসেহ্ করো। নিঃসন্দেহ আল্লাহ্ মার্জনাকারী, পরিত্রাণকারী।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@dxxxvii{তুমি কি তাদের কথা ভেবে দেখো নি যাদের গ্রন্থের কিছু অংশ দেওয়া হয়েছিল, -- তারা ভুলভ্রান্তি কিনে নেয়, আর চায় যে তোমরাও পথ থেকে পথভ্রষ্ট হও?\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@dxxxviii{আর আল্লাহ্ ভালো জানেন তোমাদের শত্রুদের। আর আল্লাহ্‌ই মূরব্বীরূপে যথেষ্ট, আর আল্লাহ্‌ই যথেষ্ট সহায়করূপে।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@dxxxix{যারা ইহুদী মত পোষণ করে তাদের মাঝে কেউ কেউ কালামগুলো তাদের স্থান থেকে সরিয়ে দেয় আর বলে -- 'আমরা শুনেছি’, আর 'আমরা অমান্য করি’; আর 'শোনো’ -- 'তার মতো যে শোনে না’; আর ''রা'ইর্না" -- তাদের জিহবারদ্বারা বিকৃত ক’রে; আর ধর্ম নিয়ে বিদ্রূপ করে। আর যদি তারা বলতো -- ''আমরা শুনেছি ও আমরা মান্য করি, আর শুনুন ও 'উনযুরনর্া’ তবে তা তাদের জন্য বেশী ভালো হতো ও বেশী ন্যায়সঙ্গত। কিন্তু আল্লাহ্ তাদের ধিক্কার দিয়েছেন তাদের অবিশ্বাসের জন্য, কাজেই তারা ঈমান আনে না অল্প ছাড়া।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@dxl{ওহে যাদের কিতাব দেয়া হয়েছে! তোমরা ঈমান আনো তাতে যা আমরা নাযিল করেছি তোমাদের কাছে যা আছে তার সত্য- সমর্থনরূপে, মূখপাত্রদের বিধবস্ত করবার ও তাদের পেছনের দিকে ফিরিয়ে দেবার, অথবা তাদের বঞ্চিত করবার পূর্বে যেমন আমরা ধিক্কার দিয়েছিলাম সাব্বাত অনুসরণকারীদের। আর আল্লাহ্‌র হুকুম অবশ্য কার্যকর হবে।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@dxli{নিশ্চয়ই আল্লাহ্ ক্ষমা করবেন না যে, তাঁর সাথে কাউকে শরিক করা হোক, আর তা ছাড়া আর সব তিনি ক্ষমা করেন যার জন্য তিনি ইচ্ছা করেন। আর যে কেউ আল্লাহ্‌র সাথে শরিক করে সে তাহলে উদ্ভাবন করেছে বিরাট পাপ।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@dxlii{তুমি কি তাদের দিকে চেয়ে দেখো নি যারা নিজেদের প্রতি পবিত্রতা আরোপ করে? না, আল্লাহ্ পবিত্র করেন যাদের তিনি পছন্দ করেন। আর তাদের অন্যায় করা হবে না খেজুর-বিচির-পাতলা-আবরণ পরিমাণেও।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@dxliii{দেখো, কেমন ক’রে তারা আল্লাহ্‌র বিরুদ্ধে মিথ্যা রচনা ক’রে! আর স্পষ্ট পাপ হিসেবে এটিই যথেষ্ট।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@dxliv{তুমি কি তাদের কথা ভেবে দেখো নি যাদের কিতাবের কিছু অংশ দেওয়া হয়েছিল, যারা বিশ্বাস করে তন্ত্রমন্ত্রে ও তাগুতে, আর যারা অবিশ্বাস পোষণ করে তাদের সন্বন্ধে যারা বলে -- ''যারা ঈমান এনেছে তাদের চাইতে এরাই পথে অধিকতর সুপথগামী?’’\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@dxlv{এরাই সেইসব যাদের আল্লাহ্ ধিক্কার দিয়েছেন। আর যাকে আল্লাহ্ বঞ্চিত করেন তার জন্য তুমি কোনো সাহায্যকারী পাবে না।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@dxlvi{অথবা, তাদের কি কোনো ভাগ আছে সাম্রাজ্যে? তবে কিন্তু তারা লোকজনকে দিত না খেজুর বিচির খোসাটুকুও।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@dxlvii{অথবা তারা কি লোকদের ঈর্ষা করে আল্লাহ্ তাঁর করুণাভান্ডার থেকে তাদের যা দিয়েছেন সেজন্য? তবে আমরা নিশ্চয়ই ইব্রাহীমের বংশধরদের দিয়েছি কিতাব ও জ্ঞানবিজ্ঞান, আর আমরা তাদের দিয়েছি এক বিশাল রাজত্ব।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@dxlviii{অতএব তাদের মধ্যে আছে সে যে তাঁর প্রতি ঈমান এনেছে, আবার তাদের মধ্যে সেও আছে যে তাঁর থেকে ফিরে যায়। আর জ্বলন্ত আগুনরূপে জাহান্নামই যথেষ্ট।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@dxlix{যারা আমাদের নির্দেশাবলীতে অবিশ্বাস পোষণ করে, নিশ্চয়ই তাদের আমরা অচিরে আগুনে প্রবেশ করাবো। যতবার তাদের চামড়া পুরোপুরি পুড়ে যাবে ততবার আমরা সেগুলো বদলে দেবো তার পরিবর্তে অন্য চামড়া দিয়ে যাতে তারা শাস্তি আস্বাদন করে। নিঃসন্দেহ আল্লাহ্ হচ্ছেন মহাশক্তিশালী, পরমজ্ঞানী।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@dl{আর যারা ঈমান আনে ও সৎকাজে করে তাদের আমরা শীঘ্রই প্রবেশ করাবো স্বর্গোউদ্যানসমূহে, যাদের নিচে দিয়ে বয়ে চলে ঝরনারাজি, তাতে তারা থাকবে চিরকাল। তাদের জন্য এর মধ্যে থাকবে পবিত্র সঙ্গিসাথী, আর তাদের আমরা প্রবেশ করাবো গহন ছায়ায়।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@dli{আল্লাহ্ নিশ্চয়ই তোমাদের আদেশ করছেন যেন তোমরা আমানত তাদের বাসিন্দাদের সমর্পণ করো, আর যখন তো মরা লোকদের মধ্যে বিচার-আচার করো তখন যেন ন্যায়পরায়ণতার সাথে বিচার করো। নিঃসন্দেহ আল্লাহ্ কি উত্তম উপদেশ তোমাদের দিয়ে থাকেন! নিঃসন্দেহ আল্লাহ্ হচ্ছেন সর্বশ্রোতা, সর্বদর্শী।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@dlii{ওহে যারা ঈমান এনেছ! আল্লাহ্‌কে অনুসরণ করো, ও রসূলের অনুগমন করো, আর তোমাদের মধ্যে যাদের হুকুম দেবার ভার আছে। তারপর যদি কোনো বিষয়ে তোমরা মতভেদ করো তবে তা পেশ করো আল্লাহ্ ও রসূলের কাছে, যদি তোমরা আল্লাহ্‌তে ও আখেরাতের দিনে বিশ্বাস করে থাকো। এটিই হচ্ছে শ্রেষ্ঠ ও সর্বাঙ্গ সুন্দর সমাপ্তিকরণ।\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@dliii{তুমি কি তাদের দিকে চেয়ে দেখো নি যারা ভাণ করে যে তারা বিশ্বাস করে যা তোমার কাছে অবতীর্ণ হয়েছে ও যা তোমার পূর্ববর্তীদের কাছে অবতীর্ণ হয়েছে, তারা বিচার খুজঁতে চায় তাগুত থেকে, যদিও নিশ্চয়ই তাদের নির্দেশ দেয়া হয়েছিল তাকে অস্বীকার করতে? আর শয়তান চায় তাদের সুদূর বিপথে পথহারা করতে।\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@dliv{আর যখন তাদের বলা হয় -- ''আল্লাহ যা নাযিল করেছেন তার দিকে এবং রসূলের দিকে এসো’’, তুমি দেখতে পাবে মুনাফিকরা তোমার কাছ থেকে ফিরে যাচ্ছে বিতৃষ্ণার সাথে।\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@dlv{কিন্তু কেমন হবে যখন তাদের উপরে কোনো মূছিবত এসে পড়বে যা তাদের হাত আগ-বাড়িয়েছে সে জন্য? তখন তারা তোমার কাছে আসবে আল্লাহ্‌র নামে হলফ করে -- ''আমরা কিন্তু চেয়েছি কল্যাণ ও সদ্ভাব ছাড়া অন্য কিছু নয়।’’\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@dlvi{এরাই তারা যাদের সন্বন্ধে আল্লাহ জানেন কি আছে তাদের অন্তরে। অতএব তাদের থেকে ঘুরে দাঁড়াও, তবে তাদের উপদেশ দাও, এবং তাদের নিজেদের সন্বন্ধে তাদের বলো মর্মস্পশী কথা।\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@dlvii{আর আমরা কোনো রসূল পাঠাই নি আল্লাহ্‌র হুকুমে তাঁদের অনুসরণ করার জন্যে ছাড়া। আর তারা যদি, যখন তারা নিজেদের প্রতি অন্যায় করেছিল, তখন তোমার কাছে আসতো ও আল্লাহ্‌র কাছে ক্ষমা প্রার্থনা করতো, আর রসূলও যদি তাদের জন্যে ক্ষমা চাইতেন, তবে তারা আল্লাহ্‌কে পেতো বারবার প্রত্যাবর্তনকারী, অফুরন্ত ফলদাতা।\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@dlviii{কিন্তু না, তোমার খোদার কসম! তারা ঈমান আনে না যে পর্যন্ত না তারা তোমাকে বিচারক মনোনীত করে সেই বিষয়ে যাতে তারা পরস্পরের মধ্যে মতবিরোধ করে, তারপর নিজেদের অন্তরে কোনো বিরূপতা পায় না তুমি যা মীমাংসা করো সে-সন্বন্ধে, আর তারা আ‌ত্মসমর্পণ করে পূর্ণ সমর্পণের সাথে।\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@dlix{আর আমরা যদি তাদের জন্য বিধান করতাম, যথা -- ''তোমাদের প্রাণ বিসর্জন করো’’, অথবা ''তোমাদের বাড়িঘর থেকে বেরিয়ে পড়ো’’, তারা তা করতো না তাদের মধ্যের অল্প কয়েকজন ছাড়া। আর যদি তারা তাই করতো যে ব্যাপারে তাদের উপদেশ দেয়া হয়েছিল তবে তাদের জন্য তা হতো বহু ভালো ও আরো বেশী শক্তিদায়ক;\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@dlx{আর তাহলে নিঃসন্দেহ আমাদের তরফ থেকে আমরা তাদের দিতাম বিরাট পুরস্কার;\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@dlxi{আর আমরা নিশ্চয়ই তাদের পরিচালিত করতাম সহজ-সঠিক পথে। আর যে কেউ আল্লাহ্‌র ও রসূলের আজ্ঞাপালন করে, -- এরাই তবে রয়েছে তাঁদের সঙ্গে যাঁদের উপরে আল্লাহ্ নিয়ামত প্রদান করেছেন -- নবীগণের মধ্য থেকে, ও সত্যপরায়ণদের ও সাক্ষ্যদাতাদের এবং সৎকর্মীদের, -- আর এরঁা হচ্ছেন সর্বাঙ্গসুন্দর বন্ধুবর্গ।\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@dlxii{এই হচ্ছে আল্লাহ্ থেকে অপার করুণা। আর সর্বজ্ঞাতারূপে আল্লাহ্‌ই যথেষ্ট।\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@dlxiii{ওহে যারা ঈমান এনেছ! নিজেদের সতর্কতামূলক সাজ-সরাম নাও, তারপর ভিন্ন ভিন্ন দল হয়ে বেরিয়ে পড়ো অথবা এগিয়ে চলো দলবদ্ধভাবে।\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@dlxiv{আর নিঃসন্দেহ তোমাদের মধ্যে এমন লোক আছে যে পেছনে পড়ে থাকে, তারপর তোমাদের উপরে যদি কোনো দু র্ঘটনা ঘটে যায় সে বলে -- ''আল্লাহ্ নিশ্চয়ই আমার উপরে অনুগ্রহ করেছেন যে আমি তাদের সঙ্গে চাক্ষুষকারী ছিলুম না।’’\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@dlxv{আর যদি আল্লাহ্‌র তরফ থেকে তোমাদের কাছে করুণাভান্ডার এসে পড়ে তখন, যেন তোমাদের মধ্যে ও তার মধ্যে কোনো বন্ধুত্বই ছিল না এমনিভাবে সে বলে উঠে -- ''আফসোস! আমি যদি তাদের সঙ্গে থাকতাম তবে বিরাট সাফল্যে সফলকাম হতে পারতাম।’’\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@dlxvi{কাজেই ওরাই আল্লাহ্‌র পথে যুদ্ধ করুক যারা এই দুনিয়ার জীবন পরকালের জন্য বিক্রয় করে দেয়। আর যে কেউ আল্লাহ্‌র পথে যুদ্ধ করে, সে নিহত হোক বা বিজয়ী হোক শীঘ্রই তাকে আমরা দেব মহাপুরস্কার।\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@dlxvii{আর তোমাদের কী আছে যে তোমরা আল্লাহ্‌র পথে যুদ্ধ করবে না, অথচ পুরুষদের মধ্যের দুর্বল লোকেরা আর স্ত্রীলোকেরা আর ছেলেমেয়েরা যারা বলছে -- ''আমাদের প্রভূ! আমাদের বাইরে নিয়ে যাও এই বসতি থেকে যার অধিবাসীরা অত্যাচারী, আর তোমার কাছ থেকে আমাদের জন্য একজন রক্ষাকারী-বন্ধু দাও, আর তোমার কাছ থেকে আমাদের দাও একজন সাহায্যকারী।’’\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@dlxviii{যারা ঈমান এনেছে তারা যুদ্ধ করে আল্লাহ্‌র পথে, আর যারা অবিশ্বাস পোষণ করে তারা তাগুতের পথে যুদ্ধ করে, অতএব শয়তানের সাঙ্গোপাঙ্গদের বিরুদ্ধে যুদ্ধ করো। নিঃসন্দেহ শয়তানের চক্রান্ত চির-দুর্বল।\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@dlxix{তুমি কি তাদের দিকে চেয়ে দেখো নি যাদের বলা হয়েছিল -- ''তোমাদের হাত গুটিয়ে রাখো, এবং নামায কায়েম করো, আর যাকাত আদায় করো।’’ কিন্তু যখন তাদের জন্য যুদ্ধের বিধান দেয়া হলো তখন, আশ্চর্য! তাদের একটি দল মানুষকে ভয় করতে লাগলো যেমন উচিত আল্লাহ্‌কে ভয় করা, -- অথবা তার চাইতেও বেশী ভয়, আর বললে -- ''আমাদের প্রভূ! কেন তুমি আমাদের জন্য যুদ্ধের বিধান করলে? কেন তুমি আমাদের অল্পকালের জন্য বিরাম দিলে না?’’ তুমি বলো -- ''এই দুনিয়ার আয়োজন অল্পক্ষণের জন্য, আর পরকাল হচ্ছে যে ভয় করে তার জন্য উৎকৃষ্টতর। আর তোমাদের অন্যায় করা হবে না খেজুর-বিচির-পাতলা পরত পরিমাণেও!\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@dlxx{''যেখানেই তোমরা থাকো মৃত্যু তোমাদের ধরবেই, যদিও তোমরা উঁচু দুর্গে অবস্থান করো।’’ আর যদি ভালো কিছু তাদের জন্য ঘটে তারা বলে, ''এ আল্লাহ্‌র তরফ থেকে।’’ আর যদি খারাপ কিছু তাদের জন্য ঘটে তারা বলে, ''এ তোমার কাছ থেকে।’’ তুমি বলো, ''সবই আল্লাহ্‌র কাছ থেকে।’’ কিন্তু কি হয়েছে এই লোকদের, এরা একথা বুঝবার কোনো চেষ্টা করে না?\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@dlxxi{ভালো যা কিছু তোমার ঘটে তা কিন্তু আল্লাহর কাছ থেকে, আর মন্দ বিষয় থেকে যা কিছু তোমার ঘটে তা কিন্তু তোমার নিজের থেকে। আর আমরা তোমাকে মানবগোষ্ঠীর জন্য রসূলরূপে পাঠিয়েছি। আর সাক্ষীরূপে আল্লাহ্‌ই যথেষ্ট।\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@dlxxii{যে কেউ রসূলের আজ্ঞাপালন করে সে অবশ্যই আল্লাহ্‌র আজ্ঞাপালন করে। আর যে কেউ ফিরে যায় -- আমরা তোমাকে তাদের উপরে রক্ষাকর্ত্তারূপে পাঠাই নি।\qt@no{(79)}}
\qt@newcmd\qurantrans@bn@dlxxiii{আর তারা বলে বেড়ায় -- ``আজ্ঞানুবর্তিতা", কিন্তু যখন তারা তোমার সামনে থেকে চলে যায়, তাদের একদল রাত্রিযাপন করে তুমি যা বলেছ তার উল্টোভাবে। আর আল্লাহ্ রেকর্ড করে রাখেন যা তারা নিশাকালে নিশানা করে, অতএব তাদের থেকে ফিরে দাঁড়াও আর আল্লাহ্‌র উপরে ভরসা করো। আর রক্ষাকারীরূপে আল্লাহ্‌ই যথেষ্ট।\qt@no{(80)}}
\qt@newcmd\qurantrans@bn@dlxxiv{কি! তারা কি তবে কুরআন সন্বন্ধে ভাববে না? বস্তুত তা যদি আল্লাহ্ ছাড়া অন্য কারো কাছ থেকে হতো তবে তাতে নিশ্চয়ই তারা পেতো প্রচুর গরমিল।\qt@no{(81)}}
\qt@newcmd\qurantrans@bn@dlxxv{আর যখন তাদের কাছে নিরাপত্তার অথবা ভয়ের কোনো বিষয় আসে, তারা তা ছড়িয়ে দেয়। আর যদি তারা তা রসূলের ও তাদের মধ্যেকার কর্তৃপক্ষের গোচরে আনতো তবে তাঁদের মধ্যের যাঁদের এ তদন্ত করার কথা তাঁরা তা জানতে পারতেন। আর যদি আল্লাহ্‌র কল্যাণ ও তাঁর রহ্‌মত তোমাদের উপরে না থাকতো তাহলে তোমরা অবশ্যই শয়তানের তাবেদারি করতে -- অল্প ছাড়া।\qt@no{(82)}}
\qt@newcmd\qurantrans@bn@dlxxvi{অতএব যুদ্ধ করো আল্লাহ্‌র পথে, তোমার উপরে তোমার নিজের ছাড়া চাপানো হয় নি, আর বিশ্বাসীদের উদ্বুদ্ধ করো। হতে পারে যারা অবিশ্বাস পোষণ করে তাদের হিংস্রতা আল্লাহ্ বন্ধ করবেন। আর আল্লাহ্ বিক্রমে কঠোরতর, আর লক্ষণীয় শাস্তিদানে আরো কঠোর।\qt@no{(83)}}
\qt@newcmd\qurantrans@bn@dlxxvii{যে কেউ সুপারিশ করে সুন্দর ওকালতিতে, তার জন্য ভাগ থাকবে তা থেকে, আর যে কেউ সুপারিশ করে মন্দ ওকালতিতে, তার জন্য বোঝা থাকবে তা থেকে। আর আল্লাহ্ হচ্ছেন সব বিষয়ের নিয়ন্ত্রণকারী।\qt@no{(84)}}
\qt@newcmd\qurantrans@bn@dlxxviii{আর যখন তোমাদের প্রীতি- সম্ভাষণ সম্ভাষিত করা হয় তখন তার চেয়েও ভালো সম্ভাষণ করো, অথবা তা ফিরিয়ে দাও। নিঃসন্দেহ আল্লাহ্ হচ্ছেন সব-কিছুর হিসাব রক্ষক।\qt@no{(85)}}
\qt@newcmd\qurantrans@bn@dlxxix{আল্লাহ্ -- তিনি ছাড়া কোনো উপাস্য নেই। তিনি নিশ্চয়ই তোমাদের সমবেত করবেন কিয়ামতের দিনে -- কোনো সন্দেহ নেই তাতে। আর কথা রাখার বেলা আল্লাহ্‌র চাইতে কে বেশী সত্যনিষ্ঠ?\qt@no{(86)}}
\qt@newcmd\qurantrans@bn@dlxxx{তোমাদের তাহলে কি হয়েছে যে মূনাফিকদের সন্বন্ধে তোমরা দুই দল হয়েছ, অথচ আল্লাহ্ তাদের ফিরিয়ে দিয়েছেন তারা যা অর্জন করেছে সেজন্য? তোমরা কি তাকে পথ দেখাতে চাও যাকে আল্লাহ্ পথভ্রষ্ট হতে দিয়েছেন? আর যাকে আল্লাহ্ পথভ্রষ্ট হতে দেন তার জন্য তুমি কিছুতেই পথ পাবে না।\qt@no{(87)}}
\qt@newcmd\qurantrans@bn@dlxxxi{তারা চায় যে তোমরা যেন অবিশ্বাস পোষণ করো যেমন তারা অবিশ্বাস করে, যাতে তোমরা সবাই এক রকমের হতে পারো। কাজেই তাদের মধ্যে থেকে কাউকে বন্ধু হিসেবে নিও না যে পর্যন্ত না তারা আল্লাহ্‌র পথে গৃহত্যাগ করে। কিন্তু তারা যদি ফিরে যায় তবে তাদের ধরো আর তাদের বধ করো যেখানেই তাদের পাও, আর তাদের থেকে কাউকেও বন্ধুরূপে নিও না এবং সাহায্যকারীরূপেও নয়, --\qt@no{(88)}}
\qt@newcmd\qurantrans@bn@dlxxxii{তারা ব্যতীত যারা এমন লোকদের সাথে যোগ-সাজশ করে যাদের মধ্যে ও তোমাদের মধ্যে অঙ্গীকার রয়েছে, অথবা যারা তোমাদের কাছে আসে যাদের হৃদয় সংকুচিত হয়েছে তোমাদের সঙ্গে যুদ্ধ করতে অথবা তাদের লোকদের সঙ্গে লড়াই করতে। আর যদি আল্লাহ্ ইচ্ছা করতেন তবে তিনি তোমাদের উপরে তাদের বলীয়ান করতেন, তার ফলে তারা নিশ্চয়ই তোমাদের সঙ্গে যুদ্ধ করতো। কাজেই যদি তারা তোমাদের থেকে সরে যায় ও তোমাদের সঙ্গে যুদ্ধ না করে, বরঞ্চ তোমাদের প্রতি শান্তি চুক্তি পেশ করে তাহলে তাদের বিরুদ্ধে কোনো পথ ধরবার জন্য আল্লাহ্ তোমাদের নিযুক্ত করেন নি।\qt@no{(89)}}
\qt@newcmd\qurantrans@bn@dlxxxiii{তোমরা অন্যদেরও পাবে যারা চায় তোমাদের থেকে নিরাপদে থাকতে ও তাদের লোকদের থেকেও নিরাপদে থাকতে। যতবার বিরুদ্ধাচরণ করতে তাদের ফেরত ডাকা হয় তারা তাতে মগ্ন হয়, কাজেই তারা যদি তোমাদের থেকে সরে না যায় বা তোমাদের প্রতি শান্তি-চুক্তি পেশ না করে, বা তাদের হাত গুটিয়ে না নেয়, তবে তাদের ধরো আর তাদের কাতল করো যেখানেই তাদের পাও। আর এরাই -- এদের বিরুদ্ধে তোমাদের আমরা স্পষ্ট কর্তৃত্ব দিয়েছি।\qt@no{(90)}}
\qt@newcmd\qurantrans@bn@dlxxxiv{আর একজন মূমিনের জন্য সঙ্গত নয় যে ভ্রমক্রমে ভিন্ন অন্য একজন মূমিনকে সে হত্যা করবে, আর যে কেউ একজন মূমিনকে ভুল করে কাতল করবে, তাহলে একজন মূমিন দাসকে মুক্ত করতে হবে আর তার লোকদের হত্যার খেসারত আদায় করবে যদি না তারা দানরূপে মাফ করে দেয়। কিন্তু যদি সে তোমাদের শত্রুপক্ষীয় দল থেকে হয় আর সে মুমিন হয়, তবে একজন মুমিন দাসকে মূক্ত করতে হবে। আর যদি সে এমন দলের লোক হয় যে তোমাদের মধ্যে ও তাদের মধ্যে অঙ্গীকার রয়েছে তাহলে তার লোকদের হত্যার খেসারত আদায় করতে হবে এবং মুক্ত করতে হবে একজন মূমিন দাসকে, কিন্তু যে পায় না তবে পরপর দুই মাস রোযা, -- আল্লাহ্‌র কাছ থেকে প্রায়শ্চিত্ত। আর আল্লাহ্ হচ্ছেন সর্বজ্ঞাতা, পরমজ্ঞানী।\qt@no{(91)}}
\qt@newcmd\qurantrans@bn@dlxxxv{আর যে কেউ ইচ্ছাকৃতভাবে একজন মূমিনকে হত্যা করে, তার তবে পরিণতি হচ্ছে জাহান্নাম, তাতে সে থাকবে দীর্ঘকাল, আর তার উপরে আসবে আল্লাহ্‌র গযব ও তাঁর লানৎ।\qt@no{(92)}}
\qt@newcmd\qurantrans@bn@dlxxxvi{ওহে যারা ঈমান এনেছ! তোমরা যখন আল্লাহ্‌র পথে যাত্রা করো, তখন পরিষ্কার করে নাও; আর যে তোমাদের প্রতি 'সালাম’ জানায় তাকে বলো না -- ''তুমি মূমিন নও।’’ তোমরা বুঝি এই দুনিয়ার জীবনের সম্পদ চাচ্ছ? কিন্তু আল্লাহ্‌র কাছে রয়েছে প্রচুর ধনদৌলত। ইতিপূর্বে তোমরাও এমন ছিলে, কিন্তু আল্লাহ্ তোমাদের হিতসাধন করেছেন; কাজেই পরিষ্কার করে নাও। নিঃসন্দেহ তোমরা যা করো আল্লাহ্ তার খবরদার।\qt@no{(93)}}
\qt@newcmd\qurantrans@bn@dlxxxvii{সমতুল্য নয় মূমিনদের মধ্যেকার যারা বসে থাকা লোক -- কোনো চোটজখম না থাকাতেও, আর যারা আল্লাহ্‌র পথে তাদের ধনসম্পত্তি ও তাদের জানপ্রাণ দিয়ে জিহাদকারী। নিজ নিজ ধনসম্পত্তি ও আপন জানপ্রাণ দিয়ে জিহাদকারীদের আল্লাহ্ মাহা‌ত্ম্য দিয়েছেন বসে-থাকা-লোকদের উপরে পদমর্যাদায়। আর আল্লাহ্ সবাইকে কল্যাণদানের ওয়াদা করেছেন। আর মূজাহিদদের আল্লাহ্ মাহা‌ত্ম্য দিয়েছেন বসে-থাকা-লোকদের চাইতে বিরাট পুরস্কার দানে --\qt@no{(94)}}
\qt@newcmd\qurantrans@bn@dlxxxviii{তাঁর কাছ থেকে বহু পদমর্যাদায় আর পরিত্রাণে এবং করুণাধারায়। আর আল্লাহ্ হচ্ছেন পরিত্রাণকারী, অফুরন্ত ফলদাতা।\qt@no{(95)}}
\qt@newcmd\qurantrans@bn@dlxxxix{নিঃসন্দেহ ফিরিশ্‌তারা যাদের মৃত্যু আনয়ন করে যারা ছিল নিজেদের প্রতি অন্যায়কারী, তারা বলবে -- ''তোমরা কি অবস্থায় পড়ে রয়েছিলে?’’ তারা বলবে -- ''আমরা দুনিয়াতে দুর্বল ছিলাম।’’ তারা বলবে -- ''আল্লাহ্‌র পৃথিবী কি প্রশস্ত ছিল না যার ফলে তাতে তোমরা হিজরত করতে পারতে?’’ কাজেই এরা -- এদের বাসস্থান জাহান্নাম, আর মন্দ সেই আশ্রয়স্থল\qt@no{(96)}}
\qt@newcmd\qurantrans@bn@dxc{তবে পুরুষদের ও স্ত্রীলোকদের ও ছেলেপিলেদের মধ্যে দুর্বল লোকেরা ব্যতীত, যাদের সামর্থ্য আয়ত্তের মধ্যে নেই ও যারা পথ খুঁজে পাচ্ছে না।\qt@no{(97)}}
\qt@newcmd\qurantrans@bn@dxci{অতএব এদের ক্ষেত্রে -- আশা হচ্ছে যে আল্লাহ্ তাদের ক্ষমা করবেন। আর আল্লাহ্ হচ্ছেন ক্ষমাশীল, পরিত্রাণকারী।\qt@no{(98)}}
\qt@newcmd\qurantrans@bn@dxcii{আর যে আল্লাহ্‌র পথে হিজরত করবে সে পৃথিবীতে পাবে বহু আশ্রয়স্থল ও প্রাচুর্য! আর যে কেউ তার বাড়িঘর থেকে আল্লাহ্ ও তাঁর রসূলের দিকে হিজরত ক’রে বের হয়ে আসে, তারপর মৃত্যু তাকে পাকড়াও করে, তাহলে তার প্রতিদান নিশ্চয়ই আল্লাহ্‌র কাছে মওজুদ রয়েছে! আর আল্লাহ্ হচ্ছেন পরিত্রাণকারী, অফুরন্ত ফলদাতা।\qt@no{(99)}}
\qt@newcmd\qurantrans@bn@dxciii{আর যখন তোমরা পৃথিবীতে বেরোও তখন তোমাদের উপরে কোনো অপরাধ হবে না যদি তোমরা নামাযে 'কছর’ করো, যদি তোমরা আশঙ্কা করো যে যারা অবিশ্বাস পোষণ করে তারা তোমাদের ঝামেলা করবে। নিঃসন্দেহ অবিশ্বাসীরা হচ্ছে তোমাদের প্রতি প্রকাশ্য শত্রু।\qt@no{(100)}}
\qt@newcmd\qurantrans@bn@dxciv{আর যখন তুমি তাদের মধ্যে অবস্থান করো আর তাদের জন্য নামাযে খাড়া হও, তখন তাদের মধ্যের একদল তোমার সঙ্গে দাঁড়াক এবং তাদের অস্ত্রধারণ করুক, কিন্তু যখন তারা সিজদা দিয়েছে তখন তারা তোমাদের পেছন থেকে সরে যাক, আর অন্যদল যারা নামায পড়ে নি তারা এগিয়ে আসুক ও তোমার সঙ্গে নামায পড়ুক, আর তারা তাদের সতর্কতামূলক ব্যবস্থা ও তাদের অস্ত্রগ্রহণ করুক, কেননা যারা অবিশ্বাস পোষণ করে তারা চায় যে যদি তোমরা তোমাদের অস্ত্রশস্ত্র ও তোমাদের মাল-আসবাব সন্বন্ধে অসাবধান হও তবে তারা তোমাদের উপরে এক ঝাঁপে ঝাঁপিয়ে পড়তে পারে। আর তোমাদের উপরে অপরাধ হবে না যদি তোমরা বৃষ্টিতে বিব্রত হও অথবা তোমরা অসুস্থ হও, ফলে তোমাদের অস্ত্র রেখে দাও, কিন্তু তোমাদের সতর্কতামূলক ব্যবস্থা গ্রহণ করো। নিঃসন্দেহ অবিশ্বাসীদের জন্য আল্লাহ্ তৈরি করেছেন লাঞ্ঝনাদায়ক শাস্তি।\qt@no{(101)}}
\qt@newcmd\qurantrans@bn@dxcv{তবে যখন তোমরা নামায আদায় করো তখনো আল্লাহ্‌কে স্মরণ করবে দাঁড়ানো অবস্থায় ও বসে থেকে, ও তোমাদের পাশে কাত হয়ে। কিন্তু যখন তোমরা নিরাপত্তা বোধ করো তখন নামায কায়েম করো। নিঃসন্দেহ নামায হচ্ছে মূমিনদের জন্য নির্দিষ্ট সময়ে পালনীয় বিধান।\qt@no{(102)}}
\qt@newcmd\qurantrans@bn@dxcvi{আর লোকের অনুসন্ধানে শিথিল হয়ো না। যদি তোমরা ব্যথা পেয়ে থাকো তবে তারাও নিশ্চয়ই ব্যথা পেয়েছে যেমন তোমরা ব্যথা পেয়েছ, আর তোমরা আল্লাহ্‌র কাছ থেকে যা আশা করো তারা তা আশা করে না। আর আল্লাহ্ হচ্ছেন সর্বজ্ঞাতা, পরমজ্ঞানী।\qt@no{(103)}}
\qt@newcmd\qurantrans@bn@dxcvii{নিঃসন্দেহ আমরা তোমার কাছে এই কিতাব অবতারণ করেছি সত্যের সাথে, যেন তুমি লোকজনের মধ্যে বিচার করতে পারো আল্লাহ্ যা তোমাকে দেখিয়েছেন তার সাহায্যে। আর বিশ্বাসভঙ্গকারীদের পক্ষ-সমর্থনকারী হয়ো না।\qt@no{(104)}}
\qt@newcmd\qurantrans@bn@dxcviii{আর আল্লাহ্‌র কাছে পরিত্রাণ খোঁজো। নিঃসন্দেহ আল্লাহ্ হচ্ছেন পরিত্রাণকারী, অফুরন্ত ফলদাতা।\qt@no{(105)}}
\qt@newcmd\qurantrans@bn@dxcix{আর যারা নিজেদের আ‌ত্মাকে ফাঁকি দেয় তাদের পক্ষে বিতর্ক করো না। নিঃসন্দেহ আল্লাহ্ ভালোবাসেন না তাকে যে বিশ্বাসঘাতক, পাপাচারী।\qt@no{(106)}}
\qt@newcmd\qurantrans@bn@dc{তারা লুকোয় মানুষদের থেকে, কিন্তু তারা লুকোতে পারে না আল্লাহ্‌র থেকে, কারণ তিনি তাদের সঙ্গে থাকেন যখন তারা রাত্রে আলোচনা করে সেইসব কথা যা তাঁকে খুশী করে না। আর তারা যা করে আল্লাহ্ তার ঘেরাওকারী।\qt@no{(107)}}
\qt@newcmd\qurantrans@bn@dci{আহা রে! তোমরাই তারা যারা তাদের পক্ষে এই দুনিয়ার জীবনে বিতর্ক করছ, কিন্তু কে আল্লাহ্‌র কাছে তাদের পক্ষে বিতর্ক করবে কিয়ামতের দিনে? অথবা কে হবে তাদের পক্ষে উকিল?\qt@no{(108)}}
\qt@newcmd\qurantrans@bn@dcii{আর যে কেউ কুকর্ম করে অথবা নিজের আ‌ত্মার প্রতি জুলুম করে, তারপর আল্লাহ্‌র কাছে ক্ষমা প্রার্থনা করে, সে আল্লাহ্‌কে পাবে পরিত্রাণকারী, অফুরন্ত ফলদাতা।\qt@no{(109)}}
\qt@newcmd\qurantrans@bn@dciii{আর যে কেউ পাপ অর্জন করে, সে তবে নিঃসন্দেহ তা অর্জন করে নিজের আ‌ত্মার বিরুদ্ধে। আর আল্লাহ্ হচ্ছেন সর্বজ্ঞাতা, পরমজ্ঞানী।\qt@no{(110)}}
\qt@newcmd\qurantrans@bn@dciv{আর যে কেউ কোনো ত্রুটি বা পাপ অর্জন করে, তারপর এর দ্বারা দোষারোপ করে নির্দোষকে, সে তাহলে নিশ্চয়ই বহন করছে কলঙ্কারোপের ও স্পষ্ট পাপের বোঝা।\qt@no{(111)}}
\qt@newcmd\qurantrans@bn@dcv{আর যদি তোমার উপরে আল্লাহ্‌র কৃপা ও তাঁর করুণা না থাকতো তাহলে তাদের একদল নিশ্চয়ই সংকল্প করেছিল তোমাকে পথভ্রান্ত করতে। কিন্তু তারা নিজেদের ছাড়া কাউকে পথভ্রান্ত করে না, আর তারা তোমার কিছুই ক্ষতি করতে পারবে না। আর আল্লাহ্ তোমার কাছে নাযিল করেছেন কিতাব ও জ্ঞানবিজ্ঞান, আর তোমাকে শিখিয়েছেন যা তুমি জানতে না। আর তোমার উপরে আল্লাহ্‌র কৃপা হচ্ছে অসীম।\qt@no{(112)}}
\qt@newcmd\qurantrans@bn@dcvi{তাদের বেশির ভাগ গোপন পরামর্শে ভালো কিছু নেই তার ক্ষেত্রে ছাড়া যে নির্দেশ দেয় দানখয়রাতের অথবা শুভকাজের অথবা মানুষের মাঝে শান্তি প্রতিষ্ঠার। আর যে কেউ এরকম করে আল্লাহ্‌র সন্তষ্টি কামনা ক’রে, তাহলে তাকে আমরা দেবো বিরাট পুরস্কার।\qt@no{(113)}}
\qt@newcmd\qurantrans@bn@dcvii{আর যে কেউ রসূলের বিরুদ্ধাচরণ করে পথনির্দেশ তার কাছে সুস্পষ্ট হবার পরে, আর অনুসরণ করে মূমিনদের পথ থেকে ভিন্ন, আমরা তাকে ফেরাবো সেই দিকে যে দিকে সে ফিরেছে, আর তাকে প্রবেশ করাবো জাহান্নামে, আর মন্দ সেই গন্তব্যস্থান!\qt@no{(114)}}
\qt@newcmd\qurantrans@bn@dcviii{নিঃসন্দেহ আল্লাহ্ ক্ষমা করেন না তাঁর সঙ্গে শরিক করা হোক, আর তা ছাড়া সব-কিছু তিনি ক্ষমা করেন যার জন্য তিনি ইচ্ছে করেন। আর যে কেউ আল্লাহ্‌র সঙ্গে অংশীদার করে সে নিশ্চয়ই বিপথগামী হয় সুদূর বিপথে।\qt@no{(115)}}
\qt@newcmd\qurantrans@bn@dcix{তারা তো আহ্বান করে তাঁর পরিবর্তে শুধু নারী- মূর্তিদের, আর তারা তো আহ্বান করে শুধু বিদ্রোহী শয়তানকে, --\qt@no{(116)}}
\qt@newcmd\qurantrans@bn@dcx{তাকে আল্লাহ্ ধিক্কার দিয়েছেন। আর সে বলেছিল -- ''আমি নিশ্চয় তোমার বান্দাদের একটি নির্ধারিত অংশ গ্রহণ করবো” ।\qt@no{(117)}}
\qt@newcmd\qurantrans@bn@dcxi{''আর আমি নিশ্চয়ই তাদের পথভ্রান্ত করবো, আর তাদের মধ্যে জাগাবো ব্যর্থ-কামনা, আর তাদের নির্দেশ দেবো -- ফলে তারা গবাদি-পশুর কর্ণচ্ছেদ করবে, আর আমি তাদের আদেশ করবো -- ফলে তারা আল্লাহ্‌র সৃষ্টি পাল্টে দেবে।’’ আর যে কেউ আল্লাহ্‌র পরিবর্তে শয়তানকে মূরব্বীরূপে গ্রহণ করে সে নিশ্চয়ই ডাহা লোকসানে ক্ষতিগ্রস্ত হবে।\qt@no{(118)}}
\qt@newcmd\qurantrans@bn@dcxii{সে তাদের প্রতি‌শ্রুতি দেয় আর তাদের মধ্যে জাগায় ব্যর্থ-কামনা। আর শয়তান কেবল প্রবঞ্চনা করা ছাড়া তাদের অন্য প্রতি‌শ্রুতি দেয় না।\qt@no{(119)}}
\qt@newcmd\qurantrans@bn@dcxiii{এরাই, -- এদের বাসস্থান জাহান্নাম, আর সেখান থেকে তারা কোনো নিষ্কৃতি পাবে না।\qt@no{(120)}}
\qt@newcmd\qurantrans@bn@dcxiv{আর যারা ঈমান এনেছে ও সৎকাজ করছে তাদের আমরা শীঘ্রই প্রবেশ করাবো স্বর্গোউদ্যানসমূহে, যাদের নিচে দিয়ে বয়ে চলে ঝরনারাজি, তারা সেখানে থাকবে অনন্তকাল; -- আল্লাহ্‌র এ ওয়াদা ধ্রুবসত্য। আর কে বেশী সত্যবাদী আল্লাহ্‌র চেয়ে কথা রাখার ক্ষেত্রে?\qt@no{(121)}}
\qt@newcmd\qurantrans@bn@dcxv{এ হবে না তোমাদের চাওয়া অনুসারে, আর গ্রন্থপ্রাপ্তদের চাওয়া অনুসারেও নয়। যে কেউ কুকর্ম করে তাই দিয়ে তাকে প্রতিফল দেয়া হবে, আর তার জন্য সে আল্লাহ্‌কে ছাড়া পাবে না কোনো বন্ধু, না কোনো সহায়।\qt@no{(122)}}
\qt@newcmd\qurantrans@bn@dcxvi{আর যে কেউ ভালো ভালো কাজ করে, পুরুষ হোক বা নারী, আর সে মূমিন হয়, -- এরাই তবে বেহেশতে প্রবেশ করবে, আর তাদের অন্যায় করা হবে না খেজুর-বিচির-খোসা-পরিমাণে।\qt@no{(123)}}
\qt@newcmd\qurantrans@bn@dcxvii{আর তাঁর চাইতে কে বেশী ধর্মপরায়ণ যে আল্লাহ্‌র দিকে আপন মূখমন্ডল সমর্পণ করেছে আর সে সৎকর্মী, আর যে সরল স্বভাব ইব্রাহীমের ধর্মমত অনুসরণ করে? আর আল্লাহ্ ইব্রাহীমকে গ্রহণ করেছিলেন বন্ধুরূপে।\qt@no{(124)}}
\qt@newcmd\qurantrans@bn@dcxviii{আর আল্লাহ্‌রই যা-কিছু আছে মহাকাশমন্ডলে ও যা-কিছু পৃথিবীতে। আর আল্লাহ্ হচ্ছেন সব-কিছুরই বেষ্টনকারী।\qt@no{(125)}}
\qt@newcmd\qurantrans@bn@dcxix{আর নারীদের সন্বন্ধে তারা তোমার কাছে সিদ্ধান্ত চায়। বলো -- ''আল্লাহ্ তাদের সন্বন্ধে তোমাদের কাছে সিদ্ধান্ত দিয়েছেন, আর যা তোমাদের কাছে কিতাবখানিতে বর্ণনা করা হয়েছে নারীদের এতীম সন্তানদের সন্বন্ধে, যাদের তোমরা দিতে চাও না তাদের জন্য নির্ধারিত প্রাপ্য, অথচ তোমরা ইচ্ছা করো যে তাদের তোমরা বিয়ে করবে, আর সন্তানসন্ততিদের মধ্যের দুর্বলদের সন্বন্ধে, আর যেন এতীমদের প্রতি ন্যায়বিচার করা তোমরা কায়েম করো।’’ আর ভালো বিষয়ের যা-কিছু তোমরা করো, নিঃসন্দেহ আল্লাহ্ সে- সন্বন্ধে হচ্ছেন সর্বজ্ঞাতা।\qt@no{(126)}}
\qt@newcmd\qurantrans@bn@dcxx{আর যদি কোনো নারী তার স্বামীর কাছ থেকে আশঙ্কা করে দুর্ব্যবহার অথবা বর্জন, তবে তাদের উভয়ের দোষ হবে না যদি তারা উভয়ের মধ্যে বুঝাপড়া ক’রে পুনর্মিলন ঘটাতে পারে। আর আপোস-মীমাংসা কল্যাণকর। আর মনের মধ্যে বর্তমান থাকে লালসা। আর যদি তোমরা ভালো করো ও ভয়শ্রদ্ধা করো, তবে নিঃসন্দেহ তোমরা যা করো সে সন্বন্ধে আল্লাহ্ হচ্ছেন চির ওয়াকিফহাল।\qt@no{(127)}}
\qt@newcmd\qurantrans@bn@dcxxi{আর তোমাদের সাধ্য নেই যে তোমরা স্ত্রীদের মধ্যে সমব্যবহার করবে, যদিও তোমরা আকাঙক্ষা করো। কিন্তু বীতরাগ হয়ো না পুরোপুরি বিরাগভাজনে, যার ফলে তাকে ফেলে রাখো যেন ঝুলন্ত অবস্থায়। আর যদি তোমরা সমঝোথা করো এবং, তবে নিঃসন্দেহ আল্লাহ্ হচ্ছেন পরিত্রাণকারী, অফুরন্ত ফলদাতা।\qt@no{(128)}}
\qt@newcmd\qurantrans@bn@dcxxii{আর যদি তারা বিচ্ছিন্ন হয়, আল্লাহ তাদের উভয়কে সমৃদ্ধ করবেন তাঁর প্রাচুর্য থেকে। আর আল্লাহ্ হচ্ছেন অশেষ দাতা, পরমজ্ঞানী।\qt@no{(129)}}
\qt@newcmd\qurantrans@bn@dcxxiii{আর যা-কিছু আছে মহাকাশমন্ডলে এবং যা-কিছু পৃথিবীতে সে-সবই আল্লাহ্‌র। আর আমরা নিশ্চয়ই নির্দেশ দিয়ছিলাম তোমাদের আগে যাদের কিতাব দেয়া হয়েছিল তাদের এবং তোমাদেরও যেন তোমরা আল্লাহ্‌কে ভয়-শ্রদ্ধা করবে। কিন্তু যদি তোমরা অবিশ্বাস পোষণ করো তবে নিঃসন্দেহ আল্লাহ্‌রই যা-কিছু আছে মহাকাশমন্ডলে ও যা-কিছু পৃথিবীতে। আর আল্লাহ্ হচ্ছেন মহাধনবান, পরম প্রশংসিত।\qt@no{(130)}}
\qt@newcmd\qurantrans@bn@dcxxiv{আর আল্লাহ্‌রই যা-কিছু আছে মহাকাশমন্ডলে ও যা-কিছু আছে পৃথিবীতে। আর রক্ষাকারীরূপে আল্লাহ্‌ই যথেষ্ট।\qt@no{(131)}}
\qt@newcmd\qurantrans@bn@dcxxv{হে লোকগণ! যদি তিনি ইচ্ছা করেন তবে তিনি তোমাদের সরিয়ে দিতে পারেন, আর অন্যদের নিয়ে আসতে পারেন। আর আল্লাহ্ এই ব্যাপরে হচ্ছেন অসীম ক্ষমতাশালী।\qt@no{(132)}}
\qt@newcmd\qurantrans@bn@dcxxvi{যে কেউ এই দুনিয়ার পুরস্কার কামনা করে আল্লাহ্‌র কাছে তবে রয়েছে ইহজগতের ও পরকালের পুরস্কার। আর আল্লাহ্ হচ্ছেন সর্বশ্রোতা, সর্বদ্রষ্টা।\qt@no{(133)}}
\qt@newcmd\qurantrans@bn@dcxxvii{ওহে যারা ঈমান এনেছ! তোমরা ন্যায়বিচারের দৃঢ় প্রতিষ্ঠাতা হও, আল্লাহ্‌র উদ্দেশ্যে সাক্ষ্যদাতা হও, যদিও তা তোমাদের নিজেদের বিরুদ্ধে যায় অথবা পিতা-মাতার ও নিকট-আ‌ত্মীয়ের, সে ধনী হোক অথবা গরীব, -- কেননা আল্লাহ্ তাদের উভয়ের বেশি নিকটবর্তী। কাজেই কামনার অনুবর্তী হয়ো না পাছে তোমরা ভ্রষ্ট হও। আর যদি তোমরা বিকৃত করো অথবা ফিরে যাও, তবে নিঃসন্দেহ তোমরা যা করো আল্লাহ্ হচ্ছেন তার পূর্ণ ওয়াকিফহাল।\qt@no{(134)}}
\qt@newcmd\qurantrans@bn@dcxxviii{ওহে যারা ঈমান এনেছ! বিশ্বাস স্থাপন করো আল্লাহ্‌তে ও তাঁর রসূলে, ও কিতাবে যা তিনি নাযিল করেছেন তাঁর রসূলের কাছে, আর যে গ্রন্থ তিনি অবতারণ করেছিলেন এর আগে। আর যে কেউ অবিশ্বাস করে আল্লাহ্‌তে ও তাঁর ফিরিশ্‌তাগণে, ও তাঁর কিতাবসমূহে, ও তাঁর রসূলগণে, ও আখেরাতের দিনে, -- সে তাহলে নিশ্চয়ই চলে গেছে সুদূর বিপথে।\qt@no{(135)}}
\qt@newcmd\qurantrans@bn@dcxxix{নিঃসন্দেহ যারা ঈমান আনে তারপর অবিশ্বাস পোষণ করে, পুনরায় ঈমান আনে ও আবার অবিশ্বাস করে, তারপর অবিশ্বাস বাড়িয়ে নিয়ে যায়, -- তাদের পরিত্রাণ করার জন্য আল্লাহ্ নন, আর নন তাদের সুপথে পরিচালিত করার জন্যেও।\qt@no{(136)}}
\qt@newcmd\qurantrans@bn@dcxxx{মূনাফিকদের সুসংবাদ দাও যে তাদের জন্য নিশ্চয়ই রয়েছে ব্যথাদায়ক শাস্তি --\qt@no{(137)}}
\qt@newcmd\qurantrans@bn@dcxxxi{যারা অবিশ্বাসীদের বন্ধুরূপে গ্রহণ করে বিশ্বাসীদের ছেড়ে দিয়ে। তারা কি তাদের কাছে মান-সম্মান খোঁজে? তবে নিঃসন্দেহ সম্মান-প্রতিপত্তি সমস্তই আল্লাহ্‌র।\qt@no{(138)}}
\qt@newcmd\qurantrans@bn@dcxxxii{আর নিশ্চয়ই তোমাদের কাছে তিনি কিতাবে নাযিল করেছেন যে যখন তোমরা শোনো আল্লাহ্‌র আয়াতসমূহ অবিশ্বাস করা হচ্ছে ও সেগুলোকে বিদ্রূপ করা হচ্ছে তখন তাদের সঙ্গে বসে থেকো না যে পর্যন্ত না তারা অন্য কোনো প্রসঙ্গে প্রবেশ করে, নিঃসন্দেহ তাহলে তোমরাও তাদের মতো হবে। নিঃসন্দেহ আল্লাহ্ মূনাফিকদের ও অবিশ্বাসীদের সম্মিলিতভাবে একত্রিত করতে যাচ্ছেন জাহান্নামে, --\qt@no{(139)}}
\qt@newcmd\qurantrans@bn@dcxxxiii{যারা প্রতীক্ষায় থাকে তোমাদের জন্য, তারপর যদি আল্লাহ্‌র কাছ থেকে তোমাদের বিজয় লাভ হয় তবে তারা বলে -- ''আমরা কি তোমাদের সঙ্গে ছিলাম না?’’ আর যদি অবিশ্বাসীদের জন্য ভাগ পড়ে তবে তারা বলে -- ''আমরা কি তোমাদের উপরে আধিপত্য রাখি নি এবং মূমিনদের থেকে তোমাদের রক্ষা করি নি?’’ সেজন্য আল্লাহ্ কিয়ামতের দিন তোমাদের মধ্যে বিচার করবেন। আর আল্লাহ্ কখনো অবিশ্বাসীদের মূমিনদের উপরে পথ করে দেবেন না।\qt@no{(140)}}
\qt@newcmd\qurantrans@bn@dcxxxiv{নিঃসন্দেহ মূনাফিকরা চায় আল্লাহ্‌কে ফাঁকি দিতে, কিন্তু তিনিই তাদের ফাঁকি প্রতিদানকারী। আর যখন তারা নামাযে দাঁড়ায়, তারা দাঁড়ায় অমনোযোগের সাথে, লোককে তারা দেখাতে যায়; আর তারা আল্লাহ্‌কে স্মরণ করে না অল্প পরিমাণে ছাড়া,\qt@no{(141)}}
\qt@newcmd\qurantrans@bn@dcxxxv{তারা দোল খাচ্ছে এর মাঝখানে -- এদিকেও তারা নয়, ওদিকেও তারা নয়। আর যাকে আল্লাহ্ বিপথে চলতে দেন, তুমি তার জন্যে কখনো পথ পাবে না।\qt@no{(142)}}
\qt@newcmd\qurantrans@bn@dcxxxvi{ওহে যারা ঈমান এনেছ! মুমিনদের বাদ দিয়ে অবিশ্বাসীদের বন্ধুরূপে গ্রহণ করো না, তোমরা কি চাও যে তোমরা আল্লাহ্‌র কাছে তোমাদের বিরুদ্ধে স্পষ্ট কর্তৃত্ব দেবে?\qt@no{(143)}}
\qt@newcmd\qurantrans@bn@dcxxxvii{নিঃসন্দেহ মুনাফিকরা আগুনের নিন্মতম গহবরে থাকবে, আর তুমি তাদের জন্য কখনো পাবে না কোনো সহায় --\qt@no{(144)}}
\qt@newcmd\qurantrans@bn@dcxxxviii{তারা ব্যতীত যারা তওবা করে ও শোধরায়, আর আল্লাহ্‌কে দৃঢ়ভাবে আঁকড়ে ধরে, আর তাদের ধর্মকে আল্লাহ্‌র জন্য বিশুদ্ধ করে, -- তারা তবে মুমিনদের সাথে, আর শীঘ্রই আল্লাহ্ মুমিনদের দিচ্ছেন এক বিরাট পুরস্কার।\qt@no{(145)}}
\qt@newcmd\qurantrans@bn@dcxxxix{তোমাদের শাস্তিতে আল্লাহ্ কি করবেন, যদি তোমরা কৃতজ্ঞ হও ও বিশ্বাস স্থাপন করো। আর আল্লাহ্ হচ্ছেন বিপুল পুরস্কার দাতা, সর্বজ্ঞাতা।\qt@no{(146)}}
\qt@newcmd\qurantrans@bn@dcxl{আল্লাহ্ ভালোবাসেন না প্রকাশ্যে মন্দ বাক্যালাপ, তবে যাকে জুলুম করা হয়েছে সে ছাড়া। আর আল্লাহ্ হচ্ছেন সর্বশ্রোতা, সর্বজ্ঞাতা।\qt@no{(147)}}
\qt@newcmd\qurantrans@bn@dcxli{যদি তোমরা ভলো কিছু প্রকাশ্যভাবে করো, অথবা তা গোপন রাখো, অথবা ক্ষমা করে দাও মন্দ কিছু, তাহলে নিঃসন্দেহ আল্লাহ্ হচ্ছেন সদা ক্ষমাশীল, পরম শক্তিমান।\qt@no{(148)}}
\qt@newcmd\qurantrans@bn@dcxlii{নিঃসন্দেহ যারা অবিশ্বাস পোষণ করে আল্লাহ্‌তে ও তাঁর রসূলগণে, আর যারা আল্লাহ্ ও তাঁর রসূলদের মধ্যে পার্থক্য করতে চায়, আর তারা বলে -- ''আমরা ঈমান আনি কয়েকজনের প্রতি আর অস্বীকার করি কয়েকজনকে”, আর যারা চায় ওর মধ্যে একটি পথ নিতে, --\qt@no{(149)}}
\qt@newcmd\qurantrans@bn@dcxliii{এরা নিজেরাই হচ্ছে প্রকৃত অবিশ্বাসী, আর আমরা অবিশ্বাসীদের জন্য তৈরি করেছি লাঞ্ঝনাদায়ক শাস্তি।\qt@no{(150)}}
\qt@newcmd\qurantrans@bn@dcxliv{আর যারা ঈমান আনে আল্লাহ্‌তে ও তাঁর রসূলগণে, আর তাঁদের কোনো একজনের মধ্যেও পার্থক্য করে না; এরাই -- এদের পুরস্কার শীঘ্রই এদের দেয়া হবে। আর আল্লাহ্ হচ্ছেন পরিত্রাণকারী, অফুরন্ত ফলদাতা।\qt@no{(151)}}
\qt@newcmd\qurantrans@bn@dcxlv{গ্রন্থপ্রাপ্তরা তোমাকে প্রশ্ন করে তুমি আকাশ থেকে তাদের কাছে কিতাব অবতারণ করো; এমনিভাবে তারা মূসার কাছে সওয়াল করেছিল এর চাইতেও বড় কিছু, যখন তারা বলেছিল -- ''আল্লাহ্‌কে আমাদের দেখাও প্রকাশ্যভাবে।’’ তাই বজ্রধবনি তাদের পাকড়ালো তাদের অন্যায়ের জন্য। তারপর তারা গোবৎসকে গ্রহণ করেছিল তাদের কাছে স্পষ্ট নিদর্শনাবলী আসার পরেও; কিন্তু আমরা তাও মাফ করলাম। আর আমরা মূসাকে দিয়েছিলাম স্পষ্ট কর্তৃত্ব।\qt@no{(152)}}
\qt@newcmd\qurantrans@bn@dcxlvi{আর আমরা তাদের উপরে তুলেছিলাম পর্বত তাদের অঙ্গীকারের সময়ে, আর তাদের বলেছিলাম -- ''দরজা দিয়ে প্রবেশ করো নত মস্তকে।’’ আর তাদের বলেছিলাম -- ''সাব্বাথের নিয়ম লঙঘন করো না।’’ আর তাদের থেকে আমরা গ্রহণ করেছিলাম সুদৃঢ় অঙ্গীকার।\qt@no{(153)}}
\qt@newcmd\qurantrans@bn@dcxlvii{কিন্তু তাদের অঙ্গীকার তাদের ভেঙ্গে দেবার ফলে, আর আল্লাহ্‌র নির্দেশের প্রতি তাদের অবিশ্বাসের জন্যে, আর নবীগণকে না- হক্‌ভাবে তাদের হত্যা করতে যাবার জন্যে, আর তাদের বলার জন্য -- ''আমাদের হৃদয় হ’ল গেলাফ।’’ না, আল্লাহ্ তাদের উপরে সীল মেরে দিয়েছেন তাদের অবিশ্বাসের জন্যেচ তাই তারা ঈমান আনে না অল্প ছাড়া, --\qt@no{(154)}}
\qt@newcmd\qurantrans@bn@dcxlviii{আর তাদের অবিশ্বাসের জন্যে, আর মরিয়মের বিরুদ্ধে তাদের জঘন্য কুৎসা রটনার জন্যে;\qt@no{(155)}}
\qt@newcmd\qurantrans@bn@dcxlix{আর তাদের বলার জন্য -- ''আমরা নিশ্চয়ই কাতল করেছি মসীহ্‌কে, -- মরিয়ম-পুত্র ঈসাকে” আল্লাহ্‌র রসূল, আর তারা তাঁকে কাতল করে নি, আর তারা তাঁকে ত্রুশে বধও করে নি, কিন্তু তাদের কাছে তাঁকে তেমন প্রতীয়মান করা হয়েছিল। আর নিঃসন্দেহ যারা এ বিষয়ে ভিন্ন মত পোষণ করছিল, তারা অবশ্য তাঁর সন্বন্ধে সন্দেহের মধ্যে ছিল। এ বিষয়ে তাদের কোনো জ্ঞান নেই অনুমানের অনুসরণ ছাড়া। আর এ সুনিশ্চিত যে তারা তাঁকে হত্যা করে নি।\qt@no{(156)}}
\qt@newcmd\qurantrans@bn@dcl{পক্ষান্তরে আল্লাহ্ তাঁকে তাঁর দিকে উন্নীত করেছেন। আর আল্লাহ্ হচ্ছেন মহাশক্তিশালী, পরমজ্ঞানী।\qt@no{(157)}}
\qt@newcmd\qurantrans@bn@dcli{আর গ্রন্থপ্রাপ্তদের মধ্যে এমন কেউ নেই যে এতে বিশ্বাস করবে না তার মৃত্যুর পূর্বে। আর কিয়ামতের দিনে তিনি হবেন তাদের বিরুদ্ধে সাক্ষ্যদাতা।\qt@no{(158)}}
\qt@newcmd\qurantrans@bn@dclii{তারপর যারা ইহুদী মত পোষণ করে তাদের অন্যায় আচরণের ফলে আমরা তাদের জন্য হারাম করলাম কিছু পবিত্র বস্তু যা তাদের জন্য হালাল ছিল, আর তাদের প্রতিরোধ করার জন্যে বহু লোককে আল্লাহ্‌র পথ থেকে, --\qt@no{(159)}}
\qt@newcmd\qurantrans@bn@dcliii{আর তাদের সুদ নেবার জন্যে, যদিও তাদের তা নিষেধ করা হয়েছিল, আর লোকের সম্পত্তি অন্যায়ভাবে তাদের গ্রাস করার জন্যে। আর তাদের মধ্যের অবিশ্বাসীদের জন্য আমরা তৈরি করেছি ব্যথাদায়ক শাস্তি।\qt@no{(160)}}
\qt@newcmd\qurantrans@bn@dcliv{কিন্তু তাদের মধ্যে যারা জ্ঞানে দৃঢ়প্রতিষ্ঠিত আর মুমিনগণ, তারা বিশ্বাস করে তোমার কাছে যা নাযিল হয়েছে ও যা তোমার আগে নাযিল হয়েছিল তাতে, আর যারা নামায কায়েম করে ও যাকাত আদায় করে, আর যারা আল্লাহ্‌র প্রতি ও আখেরাতের দিনে বিশ্বাস স্থাপন করে, -- এরাই, এদের আমরা শীঘ্রই দেবো বিরাট পুরস্কার।\qt@no{(161)}}
\qt@newcmd\qurantrans@bn@dclv{নিঃসন্দেহ আমরা তোমার কাছে প্রত্যাদেশ পাঠিয়েছি যেমন আমরা প্রত্যাদেশ দিয়েছিলাম নূহকে ও তাঁর পরবর্তী নবীদের, আর আমরা প্রত্যাদেশ পাঠিয়েছি ইব্রাহীমকে, আর ইসমাইল ও ইসহাক ও ইয়াকুবকে, আর গোত্রদের, আর ঈসা ও আইয়ুব ও ইউনুসকে, আর হারূন ও সুলাইমানকে, আর আমরা দাউদকে দিয়েছিলাম যবূর --\qt@no{(162)}}
\qt@newcmd\qurantrans@bn@dclvi{আর রসূলগণকে যাঁদের কথা ইতিপূর্বে তোমার কাছে বর্ণনা করেছি, আর রসূলগণকে যাঁদের বিষয়ে তোমার কাছে উল্লেখ করি নি; আর আল্লাহ্ মূসার সঙ্গে বলেছিলেন কথাবার্তা, --\qt@no{(163)}}
\qt@newcmd\qurantrans@bn@dclvii{রসূলগণকে সুসংবাদদাতারূপে, আর সাবধানকারীরূপে, যেন আল্লাহ্‌র বিরুদ্ধে লোকদের কোনো অজুহাত না থাকতে পারে রসূলগণের পরে। আর আল্লাহ্ হচ্ছেন মহাশক্তিশালী, পরমজ্ঞানী।\qt@no{(164)}}
\qt@newcmd\qurantrans@bn@dclviii{কিন্তু আল্লাহ্ সাক্ষ্য দিচ্ছেন যা তোমার কাছে অবতীর্ণ করেছেন তার দ্বারা যে তিনি তা নাযিল করেছেন তাঁর জ্ঞানের সঙ্গে, আর ফিরিশ্‌তারাও সাক্ষ্য দিচ্ছে। আর সাক্ষীরূপে আল্লাহ্ যথেষ্ট।\qt@no{(165)}}
\qt@newcmd\qurantrans@bn@dclix{নিঃসন্দেহ যারা অবিশ্বাস পোষণ করে এবং আল্লাহ্‌র পথ থেকে সরিয়ে রাখে, তারা নিশ্চয়ই পথ হারিয়ে গেছে সুদূর বিপথে।\qt@no{(166)}}
\qt@newcmd\qurantrans@bn@dclx{নিঃসন্দেহ যারা অবিশ্বাস পোষণ করে আর অন্যায় করে, তাদের পরিত্রাণের জন্য আল্লাহ্ দায় নিচ্ছেন না, আর তাদের কোনো গতিপথে পরিচালিত করার জন্যেও না, --\qt@no{(167)}}
\qt@newcmd\qurantrans@bn@dclxi{শুধু জাহান্নামের পথে ছাড়া, তারা সেখানে থাকবে সুদীর্ঘকাল। আর আল্লাহ্‌র পক্ষে এটা হচ্ছে সহজ।\qt@no{(168)}}
\qt@newcmd\qurantrans@bn@dclxii{ওহে মানবগোষ্ঠি! নিশ্চয়ই রসূল তোমাদের কাছে এসেছেন তোমাদের প্রভুর কাছ থেকে সত্যসহ, অতএব ঈমান আনো, তোমাদের জন্য তা মঙ্গলজনক। কিন্তু যদি তোমরা অবিশ্বাস পোষণ করো তবে নিঃসন্দেহ আল্লাহ্‌রই যা-কিছু আছে মহাকাশ-মন্ডলে ও যা-কিছু পৃথিবীতে। আর আল্লাহ্ হচ্ছেন সর্বজ্ঞাতা, পরমজ্ঞানী।\qt@no{(169)}}
\qt@newcmd\qurantrans@bn@dclxiii{হে গ্রন্থপ্রাপ্ত লোকেরা! তোমাদের ধর্মে বাড়াবাড়ি করো না, আর আল্লাহ্ সম্পর্কে সত্য ছাড়া অন্য কথা বলো না। নিঃসন্দেহ মসীহ্ -- মরিয়মের পুত্র ঈসা হচ্ছেন আল্লাহ্‌র একজন রসূল, আর তাঁর কলিমাহ্‌, যা তিনি মরিয়মের কাছে পাঠিয়েছিলেন, আর তাঁর কাছ থেকে আসা রূহ্‌, কাজেই ঈমান আনো আল্লাহ্‌র প্রতি ও তাঁর রসূলগণের প্রতি, আর বলো না -- ''তিনজন’’, থামো -- তোমাদের জন্য মঙ্গলময়। নিঃসন্দেহ আল্লাহ্ হচ্ছেন একক উপাস্য, সমস্ত মহিমা তাঁরই, যে তাঁর কোনো পুত্র থাকবে! যা-কিছু আছে মহাকাশমন্ডলে ও যা-কিছু আছে পৃথিবীতে সে-সব তাঁর। আর রক্ষাকারীরূপে আল্লাহ্‌ই যথেষ্ট।\qt@no{(170)}}
\qt@newcmd\qurantrans@bn@dclxiv{মসীহ্ কখনো কুণ্ঠাবোধ করেন না আল্লাহ্‌র বান্দা বনতে, আর সান্নিধ্যে থাকা ফিরিশ্‌তারাও করে না। আর যে কেউ তাঁর সেবায় কুণ্ঠাবোধ করে ও অহংকার করে, তিনি তাহলে তাঁর দিকে তাদের একত্রিত করবেন একজোটে।\qt@no{(171)}}
\qt@newcmd\qurantrans@bn@dclxv{কজেই যারা ঈমান আনে ও ভালো কাজ করে তিনি তাহলে তাদের প্রাপ্য তাদের পুরোপুরি দেবেন এবং তাঁর করুণাভান্ডার থেকে তাদের বাড়িয়ে দেবেন। কিন্তু যারা কুণ্ঠাবোধ করে ও অহংকার করে, তিনি তাহলে তাদের শাস্তি দেবেন ব্যথাদায়ক শাস্তিতে, --\qt@no{(172)}}
\qt@newcmd\qurantrans@bn@dclxvi{আর তারা আল্লাহ্ ছাড়া তাদের জন্য পাবে না কোনো মুরব্বী, না কোনো সহায়।\qt@no{(173)}}
\qt@newcmd\qurantrans@bn@dclxvii{ওহে জনগণ! তোমাদের কাছে নিশ্চয়ই তোমাদের প্রভুর কাছ থেকে এসেছে স্পষ্ট প্রমাণ, আর তোমাদের কাছে আমরা পাঠিয়েছি এক উজ্জ্বল জ্যোতি।\qt@no{(174)}}
\qt@newcmd\qurantrans@bn@dclxviii{অতএব যারা আল্লাহ্‌র প্রতি ঈমান এনেছে ও তাঁকে দৃঢ়ভাবে আঁকড়ে ধরে, তিনি তবে তাদের শীঘ্রই প্রবেশ করাবেন তাঁর থেকে করুণাধারায় ও প্রাচুর্যে, আর তাদের পরিচালিত করবেন তাঁর দিকে সহজ-সঠিক পথে।\qt@no{(175)}}
\qt@newcmd\qurantrans@bn@dclxix{তারা তোমাকে জিজ্ঞাসা করছে একটি বিধান সম্পর্কে। বলো -- ''আল্লাহ্ তোমাদের বিধান দিচ্ছেন মাতাপিতৃহীন তথা সন্তানসন্ততিহীনদের সন্বন্ধে।’’ যদি কোনো লোক মারা যায় -- তার কোনো সন্তান নাই কিন্তু এক বোন আছে -- তার জন্য তবে সে যা ছেড়ে যায় তার অর্ধেক, আর সে হচ্ছে তার ওয়ারিস যদি তার কোনো সন্তান না থাকে। আর যদি তারা দুজন হয় তবে তাদের দুজনের জন্য সে যা ছেড়ে যায় তার দুই-তৃতীয়াংশ। আর যদি তারা হয় ভ্রাতৃবর্গ -- পুরুষ ও স্ত্রীলোক তবে পুরুষের জন্য হচ্ছে দুইজন স্ত্রীলোকের সমান অংশ। আল্লাহ্ তোমাদের জন্য সুস্পষ্ট করে দিচ্ছেন পাছে তোমরা পথভ্রষ্ট হও। আর আল্লাহ্ সব-কিছু সন্বন্ধে সর্বজ্ঞাতা।\qt@no{(176)}}
\qt@newcmd\qurantrans@bn@dclxx{\basmalahbn ওহে যারা ঈমান এনেছ! তোমাদের অঙ্গীকারসমূহ প্রতিপালন করো। তোমাদের জন্য বৈধ করা গেল গবাদি পশু -- তোমাদের কাছে যা বর্ণনা করা হয়েছে তা ব্যতীত, শিকার বিধিসংগত নয় যখন তোমরা হারামে থাকো। নিঃসন্দেহ আল্লাহ্ হুকুম করেন যা তিনি মনস্থ করেন।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@dclxxi{ওহে যারা ঈমান এনেছ! আল্লাহ্‌র নিদর্শনসমূহ লঙ্ঘন করো না, আর পবিত্র মাসেরও না, আর উৎসর্গকৃত পশুদেরও না, আর মালা পরানো উটদেরও না, আর পবিত্র গৃহে আশ্রয় গ্রহণকারীদেরও না যারা তাদের প্রভুর কাছ থেকে কৃপা ও সন্তোষ কামনা করছে। কিন্তু যখন তোমরা মুক্ত হয়ে যাও তখন শিকার করো। আর কোনো লোকের প্রতি বিদ্বেষ, যেহেতু তারা হারাম-মসজিদে তোমাদের যেতে বাধা দিয়েছিল, তোমাদের যেন সীমালঙ্ঘনে প্ররোচিত না করে। আর পরস্পরকে সাহায্য করো সৎকাজে ও ভয়-ভক্তিতে, আর পাপাচারে ও উল্লঙ্ঘনে সহায়তা করো না, আর আল্লাহ্‌কে ভয়-ভক্তি করো। নিঃসন্দেহ আল্লাহ্ প্রতিফলদানে কঠোর।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@dclxxii{তোমাদের জন্য অবৈধ হচ্ছে -- যা নিজে মারা গেছে, আর রক্ত, আর শূকরের মাংস, আর যা যবেহ্ করা হয়েছে আল্লাহ্ ছাড়া অন্য নাম নিয়ে, আর যা গলাটিপে মারা হয়েছে, আর যা ধাঁধা লাগিয়ে মারা হয়েছে, আর পড়ে গিয়ে যে মরেছে, আর যা শিঙের আঘাতে মরেছে -- তোমরা যা বৈধ করেছ তা ব্যতীত, আর যা প্রস্তরবেদীতে বলি দেয়া হয়েছে, আর যা তোমরা ভাগাভাগি করেছ তীরের লটারি খেলেচ এ সমস্তই পাপাচার। যারা অবিশ্বাস পোষণ করে তারা আজকের দিনে তোমাদের ধর্ম সন্বন্ধে হতাশ্বাস হয়েছে, কাজেই তাদের ভয় করো না, বরং ভয় করো আমাকে। আজ আমি তোমাদের জন্য তোমাদের ধর্মব্যবস্থা পূর্ণাঙ্গ করলাম, আর তোমাদের উপরে আমার নিয়ামত সম্পূর্ণ করলাম, আর তোমাদের জন্য ধর্মরূপে মনোনীত করলাম ইসলাম। অতএব যে কেউ ক্ষুধার তাড়নায় বাধ্য হয়, -- পাপের দিকে ঝোঁকে পড়ে নয়, -- তবে নিঃসন্দেহ আল্লাহ্ হচ্ছেন পরিত্রাণকারী, অফুরন্ত ফলদাতা।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@dclxxiii{তারা তোমাকে জিজ্ঞাসা করছে কি তাদের জন্য হালাল হয়েছে। বলো -- ''ভালো বস্তু তোমাদের জন্য বৈধ হয়েছে । আর শিকারী পশুপক্ষীদের শিকার করতে যা শিখিয়েছ -- তাদের তোমরা শিখিয়েছ যা আল্লাহ্ তোমাদের শিখিয়েছেন, কাজেই তারা তোমাদের কাছে যা ধরে আনে তা থেকে তোমরা খাও, তবে তার উপরে আল্লাহ্‌র নাম উল্লেখ করো। আর আল্লাহ্‌কে ভয়-ভক্তি করো। নিঃসন্দেহ আল্লাহ্ হিসেব-নিকেশে তৎপর।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@dclxxiv{আজ ভালো বস্তু তোমাদের জন্য হালাল করা হলো। আর যাদের গ্রন্থ দেয়া হয়েছে তাদের খাদ্য তোমাদের জন্য হালাল, এবং তোমাদের খাদ্যও তাদের জন্য বৈধ। আর মুমিনদের মধ্যের সতী-সাধ্বী নারী, আর তোমাদের আগে যাদের গ্রন্থ দেয়া হয়েছে তাদের মধ্যের সতী-সাধ্বী নারীও, যখন তোমরা তাদের মহরানা আদায় করেছ, সচ্চরিত্রভাবে, ব্যভিচারের জন্য নয় ও রক্ষিতারূপে গ্রহণ করেও নয়। আর যে কেউ ঈমান অস্বীকার করে সে তাহলে তার আচরণ ব্যর্থ করেছে, আর সে পরকালে হবে ক্ষতিগ্রস্তদের মধ্যেকার।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@dclxxv{ওহে যারা ঈমান এনেছ! যখন তোমরা নামাযে খাড়া হও তখন তোমাদের মুখমন্ডল ও কনুই পর্যন্ত তোমাদের হাত ধোও, আর তোমাদের মাথা ও গোড়ালি পর্যন্ত তোমাদের পা মূসেহ্ করো। আর যদি তোমরা যৌন সম্ভোগের পরবর্তী অবস্থায় থাকো তবে ধৌত করো। আর যদি তোমরা অসুস্থ হও, অথবা সফরে থাকো, অথবা তোমাদের কেউ পায়খানা থেকে এসেছ, অথবা স্ত্রীদের স্পর্শ করেছ, আর যদি পানি না পাও তবে তৈয়ম্মুম করো বিশুদ্ধ মাটি নিয়ে, আর তা দিয়ে তোমাদের মুখমন্ডল ও তোমাদের হাত মূসেহ্ করো। আল্লাহ্ চান না তোমাদের উপরে কষ্টের কিছু আরোপ করতে, কিন্তু তিনি চান তোমাদের পবিত্র করতে, আর যাতে তাঁর নিয়ামত তোমাদের উপরে পরিপূর্ণ করেন, যেন তোমরা ধন্যবাদ দিতে পারো।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@dclxxvi{আর স্মরণ করো তোমাদের উপরে আল্লাহ্‌র নিয়ামত আর তাঁর অঙ্গীকার যার দ্বারা তিনি তোমাদের অঙ্গীকারবদ্ধ করেছিলেন, যখন তোমরা বলেছিলে -- ''আমরা শুনেছি আর আমরা আজ্ঞাপালন করছি।’’ আর আল্লাহ্‌কে ভয়-ভক্তি করো। নিঃসন্দেহ বুকের ভিতরে যা আছে আল্লাহ্ সে-সন্বন্ধে সর্বজ্ঞাতা।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@dclxxvii{ওহে যারা ঈমান এনেছ! আল্লাহ্‌র জন্য দৃঢ়-প্রতিষ্ঠাতা হও, ন্যায়-বিচারে সাক্ষ্যদাতা হও, আর কোনো লোকদলের প্রতি বিদ্বেষ তোমাদের যেন ন্যায়াচরণ না করতে তোমাদের প্ররোচিত না করে। ন্যায়াচরণ করো, এটিই হচ্ছে ধর্মভীরুতার নিকটতর। আর আল্লাহ্‌কে ভয়-শ্রদ্ধা করো। নিঃসন্দেহ তোমরা যা করছো আল্লাহ্ তার পূর্ণ-ওয়াকিফহাল।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@dclxxviii{আল্লাহ্ ওয়াদা করছেন -- যারা ঈমান আনে ও সৎকাজ করে, তাদের জন্য রয়েছে পরিত্রাণ আর বিরাট পুরস্কার।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@dclxxix{আর যারা অবিশ্বাস পোষণ করে আর আমাদের নিদর্শনসমূহে মিথ্যারোপ করে, -- এরা হচ্ছে জ্বলন্ত আগুনের বাসিন্দা।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@dclxxx{ওহে যারা ঈমান এনেছ! তোমাদের উপরে আল্লাহ্‌র নিয়ামত স্মরণ করো -- যখন একটি দল দৃঢ়সঙ্কল্প করেছিল তোমাদের দিকে তাদের হাত বাড়াতে, কিন্তু তিনি তোমাদের বিরুদ্ধে তাদের হাত ঠেকিয়ে রেখেছিলেন, কাজেই আল্লাহ্‌কে ভয়-শ্রদ্ধা করো। আর আল্লাহ্‌র উপরেই তবে নির্ভর করুক মুমিন সব।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@dclxxxi{আর আল্লাহ্ অবশ্যই ইসরাইলের বংশধর থেকে অঙ্গীকার গ্রহণ করেছিলেন, আর আমরা তাদের মধ্যে থেকে বারো জন দলপতি দাঁড় করিয়েছিলাম। আর আল্লাহ্ বলেছিলেন -- ''নিঃসন্দেহ আমি তোমাদের সঙ্গে রয়েছি। যদি তোমরা নামায কায়েম করো ও যাকাত আদায় করো, আর আমার রসূলদের প্রতি ঈমান আনো ও তাঁদের সমর্থন করো, আর আল্লাহ্‌কে ধার দাও পর্যাপ্ত-সুন্দর ঋণ, তবে আমি নিশ্চয়ই তোমাদের থেকে তোমাদের সব পাপ মোছে দেব ও তোমাদের প্রবেশ করাবো উদ্যানসমূহে যাদের নীচ দিয়ে বয়ে চলেছে ঝরনারাজি। কিন্তু এর পরে তোমাদের মধ্যের যে কেউ অবিশ্বাস পোষণ করবে সে-ই তবে নিশ্চয়ই সরল পথের দিশা হারিয়েছে।’’\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@dclxxxii{তারপর নিজেদের অঙ্গীকার তাদের ভঙ্গ করার দরুন আমরা তাদের বঞ্চিত করলাম আর তাদের অন্তরকে কঠিন হতে দিলাম। তারা কালামগুলো তাদের স্থান থেকে সরিয়ে দেয়, আর তাদের যে-সব নির্দেশ দেয়া হয়েছিল তার অংশবিশেষ ভুলে যায়, আর তাদের লোকদের মধ্যে বিশ্বাসঘাতকতা আবিস্কার করার অবসান তোমার থাকবে না তাদের অল্প ছাড়া, সেজন্য তাদের ক্ষমা করো ও উপেক্ষা করো। নিঃসন্দেহ আল্লাহ্ ভালোবাসেন সৎকর্মীদের।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@dclxxxiii{আর যারা বলে -- 'নিঃসন্দেহ আমরা খ্রীষ্টান’, তাদের থেকে আমরা তাদের অঙ্গীকার গ্রহণ করেছিলাম, তারাও ভু লে গেল তাদের যে-সব নির্দেশ দেওয়া হয়েছিল তার অংশবিশেষ, কাজেই আমরা তাদের মধ্যে শত্রুতা ও বিদ্বেষ জাগিয়ে রাখলাম কিয়ামতের দিন পর্যন্ত। আর অচিরেই আল্লাহ্ তাদের জানিয়ে দেবেন তারা কি করে যাচ্ছিল।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@dclxxxiv{হে গ্রন্থপ্রাপ্ত লোকেরা! আমাদের রসূল তোমাদের কাছে ইতিমধ্যে এসে গেছেন, ধর্মগ্রন্থের যা তোমরা লুকোচ্ছিলে তার বহুলাংশ তিনি তোমাদের জন্য সুস্পষ্ট করেছেন, এবং অনেকটা তিনি উপেক্ষা করেছেন। আল্লাহ্‌র কাছ থেকে তোমাদের কাছে নিশ্চয়ই এসেছে এক জ্যোতি আর উজ্জ্বল কিতাব, --\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@dclxxxv{এর দ্বারা আল্লাহ্ তাকে হেদায়ত করেন যে তাঁর সন্তষ্টি অনুসরণ করে শান্তির পথে, আর তাদের বের করে আনেন অন্ধকার থেকে আলোর দিকে তাঁর ইচ্ছায়, আর তাদের পরিচালিত করেন সহজ-সঠিক পথের দিকে।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@dclxxxvi{তারা নিশ্চয়ই অবিশ্বাস পোষণ করে যারা বলে -- ''নিঃসন্দেহ আল্লাহ্‌, তিনিই মসীহ্‌, মরিয়মের পুত্র।’’ তুমি বলো -- ''কার তাহলে বিন্দুমাত্র ক্ষমতা আছে আল্লাহ্‌র বিরুদ্ধে যখন তিনি চেয়েছিলেন মরিয়ম-পুত্র মসীহ্‌কে বিনাশ করতে, আর তাঁব মাতাকে, আর পৃথিবীতে যারা ছিল তাদের সবাইকে?’’ বস্তুতঃ আল্লাহ্‌রই মহাকাশমন্ডল ও পৃথিবীর রাজত্ব আর এই দুইয়ের মধ্যে যা আছে। তিনি সৃষ্টি করেন যা তিনি ইচ্ছে করেন। আর আল্লাহ্ সব-কিছুর উপরে সর্বশক্তিমান।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@dclxxxvii{আর ইহুদী ও খ্রীষ্টানরা বলে -- ''আমরা আল্লাহ্‌র সন্তান ও তাঁর প্রিয়পাত্র।’’ তুমি বলো -- ''তবে কেন তোমাদের অপরাধের জন্য তিনি তোমাদের শাস্তি দেন? না, যাদের তিনি সৃষ্টি করেছেন তোমরা তাদের মধ্যেকার মানুষ। তিনি যাকে ইচ্ছে করেন পরিত্রাণ করেন এবং যাকে ইচ্ছে করেন শাস্তি দেন।’’ আর আল্লাহ্‌রই মহাকাশমন্ডল ও পৃথিবীর সাম্রাজ্য এবং এই দুইয়ের মধ্যে যা আছে, আর তাঁরই দিকে প্রত্যাবর্তন।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@dclxxxviii{হে গ্রন্থপ্রাপ্ত লোকেরা! তোমাদের কাছে নিশ্চয়ই আমাদের রসূল এসেছেন তোমাদের কাছে সুস্পষ্ট করতে, রসূলদের এক বিরতির পরে, পাছে তোমরা বলো -- 'আমাদের কাছে সুসংবাদদাতাদের কেউ আসেন নি এবং সতর্ককারীও না।’ এখন তোমাদের কাছে নিশ্চয়ই এসেছেন একজন সুসংবাদদাতা ও সতর্ককারী। আর আল্লাহ্ সব-কিছুর উপরে সর্বশক্তিমান।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@dclxxxix{আর স্মরণ করো! মূসা তাঁর লোকদের বলেছিলেন -- ''হে আমার লোকদল! তোমাদের প্রতি আল্লাহ্‌র নিয়ামত স্মরণ করো যখন তিনি তোমাদের মধ্যে নবীদের নিযুক্ত করেছিলেন এবং তোমাদের বানিয়েছিলেন রাজা-রাজড়া, আর তোমাদের দিয়েছিলেন যা তিনি মানবগোষ্ঠীর মধ্যে অপর কাউকেও দেন নি।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@dcxc{''হে আমার লোকদল! সেই পুণ্য ভূমিতে প্রবেশ করো যা আল্লাহ্ তোমাদের জন্য বিধান করেছেন, আর তোমাদের পেছন দিকে ফিরে যাবে না, কেননা তোমরা তাহলে মোড় ফেরাবে ক্ষতিগ্রস্তভাবে।’’\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@dcxci{তারা বললে -- ''হে মূসা! নিঃসন্দেহ ওতে রয়েছে বিশালকায় লোকেরা, আর আমরা কখনো ওতে প্রবেশ করবো না যে পর্যন্ত না তারা ওখান থেকে বেরিয়ে যায়। কাজেই তারা যদি ওখান থেকে বেরিয়ে যায় তবে আমরা অবশ্যই প্রবেশ করবো।’’\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@dcxcii{যারা ভয় করতো তাদের মধ্যের দুজন লোক -- যাদের উপরে আল্লাহ্ অনুগ্রহ করেছিলেন, তারা বললে -- ''তাদের উপরে ঢুকে পড়ো দরজা দিয়ে, কাজেই যখন তোমরা তাতে প্রবেশ করবে তোমরা তখন নিশ্চয়ই বিজয়ী হবে, আর আল্লাহ্‌র উপরে তবে তোমরা নির্ভর করো, যদি তোমরা মুমিন হও।’’\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@dcxciii{তারা বললে -- ''হে মূসা! আমরা নিশ্চয়ই কখনো এতে ঢুকবো না যতক্ষণ তারা ওর মধ্যে অবস্থান করছে। কাজেই তুমি ও তোমার প্রভু এগিয়ে যাও এবং তোমরা দুজনে যুদ্ধ করো, আমরা নিশ্চয়ই এখানে বসে পড়লাম।’’\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@dcxciv{তিনি বললেন, ''আমার প্রভু! নিশ্চয়ই আমি আমার নিজের ও আমার ভাইয়ের উপরে ছাড়া কর্তৃত্ব রাখি না, অতএব আমাদের ও দুষ্কৃতিপরায়ণ লোকদের মধ্যে ছাড়াছাড়ি ঘটিয়ে দাও।’’\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@dcxcv{তিনি বললেন -- ''তবে নিঃসন্দেহ এটি তাদের জন্য হারাম থাকবে চল্লিশ বৎসর কাল, তারা পৃথিবীতে ঘুরে বেড়াবে। অতএব দুঃখ করো না এই দুষ্কৃতিপরায়ণ জাতির জন্য।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@dcxcvi{আর তাদের কাছে সঠিকভাবে বর্ণনা করো দুই আদম-সন্তানের কাহিনী, কেমন ক’রে তারা উভয়ে কুরবানি করেছিল, কিন্তু তা কবুল হল তাদের একজনের কাছ থেকে আর অপরজনের কাছ থেকে তা গৃহীত হল না। সে বললে -- ''নিশ্চয় আমি তোমাকে খুন করবো।’’ সে বললে -- ''আল্লাহ্ কবুল করেন শুধু ধর্মভীরুদের থেকে।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@dcxcvii{''তুমি যদি আমার দিকে তোমার হাত বাড়াও আমাকে হত্যা করতে, আমি কিন্তু তোমার দিকে আমার হাত প্রসারণকারী হবো না তোমাকে হত্যা করতে। নিঃসন্দেহ আমি ভয় করি আল্লাহ্‌কে -- সমগ্র বিশ্বজগতের প্রভু।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@dcxcviii{''নিঃসন্দেহ আমি চাই যে তুমি আমার বিরুদ্ধে পাপ ও তোমার পাপ বহন করো, ফলে আগুনের বাসিন্দাদের দলভুক্ত হও, আর এই-ই অন্যায়কারীদের প্রতিফল।’’\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@dcxcix{কিন্তু তার মন তাকে প্রবুদ্ধ করলো তার ভাইকে হত্যা করতে, তাই সে তাকে খুন করলো, কাজেই পরমূহূর্তে সে হলো ক্ষতিগ্রস্তদের দলের।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@dcc{তারপর আল্লাহ্ একটি কাককে নিযুক্ত করলেন মাটি আচঁড়াতে যেন তাকে দেখানো যায় কেমন ক’রে সে তার ভাইয়ের মৃতদেহ ঢাকবে। সে বললে -- ''হায় দুর্ভাগ্য! আমি কি এই কাকের মতো হবার জন্য এতই দুর্বল হয়ে গেছি, কাজেই আমি যেন আমার ভাইয়ের শব ঢাকতে পারি?’’ সেজন্য পরমুহূর্তে সে হলো অনুতপ্তদের দলের\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@dcci{এই কারণ বশতঃ আমরা বিধিবদ্ধ করেছিলাম ইসরাইল-বংশীয়দের জন্যে -- যে, যে কেউ হত্যা করে একজন মানুষকে আরেকজনকে ব্যতীত, অথবা দেশে ফসাদ সৃষ্টি, তাহলে সে যেন লোকজনকে সর্বসাকল্যে হত্যা করলে। আবার যে কেউ তাকে বাঁচিয়ে রাখে, সে যেন তাহলে সমস্ত লোকজনকে বাঁচালে। আর নিশ্চয়ই তাদের কাছে আমাদের রসূলগণ এসেছিলেন স্পষ্ট প্রমাণাবলী নিয়ে, কিন্তু তাদের মধ্যের অনেকেই এর পরেও পৃথিবীতে সীমা ছাড়িয়ে চলে।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@dccii{যারা আল্লাহ্‌র ও তাঁর রসূলের বিরুদ্ধে যুদ্ধ ঘোষণা করে আর দেশে গন্ডগোল বাঁধাতে তৎপর হয় তাদের একমাত্র প্রাপ্য হচ্ছে -- তাদের কাতল করো, অথবা শূলে চড়াও, অথবা তাদের হাত ও তাদের পা বিপরীত দিকে কেটে ফেলো, অথবা তাদের দেশ থেকে নির্বাসিত করো। এটি হচ্ছে তাদের জন্য ইহলোকে লাঞ্ছনা, আর তাদের জন্য পরকালে রয়েছে কঠোর শাস্তি, --\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@dcciii{তারা ব্যতীত যারা তওবা করে তোমরা তাদের উপরে ক্ষমতাসীন হবার পূর্বে, তাহলে জেনে রেখো যে নিঃসন্দেহ আল্লাহ্ পরিত্রাণকারী, অফুরন্ত ফলদাতা।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@dcciv{ওহে যারা ঈমান এনেছ! আল্লাহ্‌কে ভয়-শ্রদ্ধা করো, আর তাঁর দিকে অছিলা অন্বেষণ করো, আর তাঁর পথে জিহাদ করো, যাতে তোমরা সফলকাম হতে পারো।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@dccv{নিঃসন্দেহ যারা অবিশ্বাস পোষণ করে -- পৃথিবীতে যা আছে সে-সমস্তই যদি তাদের হতো এবং তার সাথে সেই পরিমাণে, যার বিনিময়ে তারা মুক্তি কামনা করতো কিয়ামতের দিনের শাস্তি থেকে, তাদের কাছ থেকে তা কবুল হতো না, আর তাদের জন্য রয়েছে ব্যথাদায়ক শাস্তি।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@dccvi{তারা চাইবে যেন সেই আগুন থেকে তারা বেরিয়ে যেতে পারে, কিন্তু তা থেকে তারা বেরিয়ে যাবার নয়, আর তাদের জন্যে রয়েছে দীর্ঘস্থায়ী শাস্তি।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@dccvii{আর চোরা পুরুষ ও চোরা স্ত্রীলোক -- দুইয়েরই তবে হাত কেটে ফেলো, -- তারা যা করেছে তার প্রতিফলস্বরূপ, -- এটি আল্লাহ্‌র তরফ থেকে একটি দৃষ্টান্ত-স্থাপনকারী শাস্তি। আর আল্লাহ্ মহাশক্তিশালী, পরমজ্ঞানী।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@dccviii{কিন্তু যে কেউ তওবা করে তার অন্যায়াচরণের পরে আর সংশোধন কবে, তাহলে নিঃসন্দেহ আল্লাহ্ তার দিকে ফিরবেন। নিঃসেন্দহ আল্লাহ্ পরিত্রাণকারী, অফুরন্ত ফলদাতা।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@dccix{তুমি কি জানো না যে আল্লাহ -- মহাকাশমন্ডল ও পৃথিবীর রাজত্ব তাঁরই? তিনি শাস্তি দেন যাকে ইচ্ছে করেন আর ক্ষমাও করেন যাকে ইচ্ছে করেন। আর আল্লাহ্ সব-কিছুর উপরে সর্বশক্তিমান।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@dccx{হে প্রিয় রসূল! যারা অবিশ্বাসের অভিমুখে ধাওয়া করেছে তারা যেন তোমাকে দুঃখিত না করে, যারা তাদের মুখে বলে -- 'আমরা ঈমান এনেছি’, কিন্তু তাদের হৃদয় ঈমান আনে নি, আর যারা ইহুদীয় মত পোষণ করে, -- মিথ্যার জন্যে শ্রবণকারী, শ্রবণকারী অন্য লোকদের জন্যে যারা তোমার কাছে আসে না। তারা কথাগুলো সরিয়ে দেয় সেগুলোকে যথাস্থানে স্থাপনের পরে, তারা বলে -- ''তোমাদের যদি এই দেওয়া হয় তবে তা গ্রহণ করো, আর যদি তোমাদের এই দেয়া না হয় তবে সাবধান হও।’’ আর যাকে তার প্রলোভনের মধ্যে আল্লাহ্ চান, তার জন্য আল্লাহ্‌র কাছ থেকে কিছু করার ক্ষমতা তোমার নেই। এরাই তারা যাদের সন্বন্ধে আল্লাহ্ চান না যে তাদের হৃদয় বিশুদ্ধ হোক। এদের জন্য এই দুনিয়াতে রয়েছে দুর্গতি, আর পরকালে এদের জন্য কঠোর শাস্তি।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@dccxi{তারা মিথ্যার জন্যে শ্রবণকারী, নিষিদ্ধের ভক্ষণকারী। অতএব তারা যদি তোমার কাছে আসে তবে তাদের মধ্যে বিচার করো, অথবা তাদের থেকে গুটিয়ে নাও, আর যদি তুমি তাদের থেকে গুটিয়ে নাও তবে তারা কখনো তোমার মোটেই ক্ষতি করতে পারবে না। আর যদি তুমি বিচার করো তবে তাদের মধ্যে বিচার করো ন্যায়পরায়ণতার সাথে। নিঃসন্দেহ আল্লাহ্ ভালোবাসেন ভারসাম্যরক্ষাকারীদের।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@dccxii{আর কেমন ক’রে তারা তোমাকে বিচারক করে, আর তাদের কাছে রয়েছে তওরাত যাতে আছে আল্লাহ্‌র বিধান? তবুও তারা ফিরে যায় এ-সবের পরেও! আর এমন লোকেরা মুমিন নয়।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@dccxiii{নিঃসন্দেহ আমরা অবতীর্ণ করেছি তওরাত, যাতে রয়েছে হেদায়ত ও দীপ্তি। তার দ্বারা নবীগণ, যাঁরা ইসলামী ধর্মমত পোষণ করেন, বিধান দিয়েছিলেন তাদের যারা ইহুদীয় মত পোষণ করে, আর রব্বিসব ও পুরোহিতরা আল্লাহ্‌র কিতাবের যা তারা সংরক্ষণ করতো তারদ্বারা, আর তারা সে-সবের সাক্ষী ছিল। সেজন্য তোমরা লোকজনকে ভয় করো না, বরং ভয় করো আমাকে, আর আমার বাণীসমূহের জন্য স্বল্পমূল্য কামাতে যেয়ো না। আর যারা বিচার করে না আল্লাহ্ যা নাযিল করেছেন তার দ্বারা, তারা তবে নিজেরাই অবিশ্বাসী।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@dccxiv{আর আমরা তাদের জন্য তাতে বিধান করেছিলাম -- প্রাণের বদলে প্রাণ, আর চোখের বদলে চোখ, আর নাকের বদলে নাক, আর কানের বদলে কান, আর দাঁতের বদলে দাঁত, আর জখমেরও বদলাই। আর যে কেউ এটি দিয়ে দান করে দেয়, সেটি তা হলে তার জন্য হবে প্রায়শ্চিত্ত। আর যে বিচার করে না আল্লাহ্ যা অবতীর্ণ করেছেন তার দ্বারা, তাহলে তারা নিজেরাই হচ্ছে অন্যায়কারী।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@dccxv{আর তাদের পশ্চাতে আমরা পাঠিয়েছিলাম মরিয়ম-পুত্র ঈসাকে, তাঁর পূর্বে তওরাতে যা ছিল তার প্রতিপাদকরূপে, আর তাঁকে আমরা দিয়েছিলাম ইনজীল যাতে রয়েছে পথপ্রদর্শন ও দীপ্তি, এর পূর্বে তওরাতে যা ছিল তার সত্য-সমর্থনরূপে, আর পথপ্রদর্শন ও উপদেশ ধর্মপরায়ণদের জন্য।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@dccxvi{আর ইনজীলের অনুবর্তীদের উচিত তারা যেন বিচার করে আল্লাহ্ তাতে যা অবতারণ করেছেন তার দ্বারা। আর যে বিচার করে না আল্লাহ্ যা অবতারণ করেছেন তার দ্বারা, তারা তবে নিজেরাই হচ্ছে দুষ্কৃতিপরায়ণ।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@dccxvii{আর তোমার কাছে আমরা অবতারণ করেছি এই কিতাব সত্যের সাথে, এবং পূর্ববর্তী ধর্মগ্রন্থে যা আছে তার সত্য-সমর্থনরূপে, আর তার উপরে প্রহরীরূপে, সেজন্য তাদের মধ্যে বিচার করো যা আল্লাহ্ নাযিল করেছেন তার দ্বারা, আর তাদের হীন-বাসনার অনুসরণ করো না তোমার প্রতি সত্যের যা এসেছে তার প্রতি বিমুখ হয়ে। তোমাদের মধ্যের প্রত্যেকের জন্য আমরা নির্ধারণ করেছিলাম এক-একটি শরিয়ৎ ও এক-একটি পথ। আর যদি আল্লাহ্ ইচ্ছে করতেন তবে তিনি তোমাদের বানাতেন একই জাতি, কিন্তু তিনি যেন তোমাদের যাচাই করতে পারেন তোমাদের যা তিনি দিয়েছেন তার দ্বারা, কাজেই ভালোকাজে পরস্পরের সঙ্গে প্রতিযোগিতা করো। আল্লাহ্‌র কাছে তোমাদের সকলের প্রত্যাবর্তন, তখন তিনি তোমাদের অবহিত করবেন সেইসব বিষয়ে যাতে তোমরা মতভেদ করছিলে।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@dccxviii{আর তুমি যেন তাদের মধ্যে বিচার করো আল্লাহ্ যা অবতারণ করেছেন তার দ্বারা আর তাদের হীন-বাসনার অনুসরণ করো না, আর তাদের সম্পর্কে সাবধান হও পাছে তারা তোমাকে ভ্রান্তিতে ফেলে দেয় আল্লাহ্ তোমার কাছে যা অবতারণ করেছেন তার কোনো অংশ থেকে। তারা যদি তবে ফিরে যায় তাহলে জেনে রেখো যে আল্লাহ্ নিশ্চয়ই তাদের পাকড়াও করতে চান তাদের কতকগুলো অপরাধের জন্য। আর নিঃসন্দেহ লোকদের অধিকাংশই দুষ্কৃতিপরায়ণ।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@dccxix{তবে কি তারা অজ্ঞতার যুগের বিচার ব্যবস্থা চায়? আর আল্লাহ্‌র চাইতে কে বেশি ভালো বিচার ব্যবস্থায় সেই সম্প্রদায়ের জন্যে যারা সুনিশ্চিত?\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@dccxx{ওহে যারা ঈমান এনেছ! ইহুদী ও খ্রীষ্টানদের বন্ধুরূপে গ্রহণ করো না, তাদের একদল অন্যদের বন্ধু। আর তোমাদের মধ্যের যে তাদের মুরব্বী বানায় সে তবে নিশ্চয় তাদেরই মধ্যেকার। নিঃসন্দেহ আল্লাহ্ পথ দেখান না অন্যায়কারী সম্প্রদায়কে।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@dccxxi{কাজেই যাদের অন্তরে ব্যারাম রয়েছে তাদের তুমি দেখতে পাবে তাদের দিকে ছুটে যেতে এই বলে -- ''আমরা আশঙ্কা করছি কোনো দুর্যোগ আমাদের উপরে ঘটে যায়।’’ কিন্তু হতে পারে যে আল্লাহ্ এনে দেবেন বিজয় অথবা তাঁর কাছ থেকে চুড়ান্ত নিস্পত্তি, তাই তাদের অন্তরে তারা যা পোষণ করছিল তার জন্য পরমুহূর্তেই তারা হলো অনুতাপী।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@dccxxii{আর যারা ঈমান এনেছে তারা বলবে -- ''এরাই কি তারা যারা আল্লাহ্‌র নামে তাদের জোরালো আস্থার সাথে শপথ গ্রহণ করেছিল যে তারা সুনিশ্চিত তোমাদের সঙ্গে?’’ তাদের ক্রিয়াকলাপ বৃথা গেল, কাজেই পরমুহূর্তে তারা হলো ক্ষতিগ্রস্ত।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@dccxxiii{ওহে যারা ঈমান এনেছ! তোমাদের মধ্যে থেকে যে কেউ তার ধর্ম থেকে ফিরে যায়, আল্লাহ্ তবে শীঘ্রই নিয়ে আসবেন একটি সম্প্রদায় -- তাদের তিনি ভালোবাসবেন ও তারা তাঁকে ভালোবাসবে, মুমিনদের প্রতি বিনীত, অবিশ্বাসীদের প্রতি কঠোর, তারা আল্লাহ্‌র পথে জিহাদ করবে, আর ভয় করবে না কোনো নিন্দুকের নিন্দা। এই হচ্ছে আল্লাহ্‌র এক আশিস -- তিনি তা প্রদান করেন যাকে তিনি ইচ্ছে করেন। আর আল্লাহ্ পরম বদান্য, সর্বজ্ঞাতা।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@dccxxiv{নিঃসন্দেহ তোমাদের ওলী হচ্ছেন কেবলমাত্র আল্লাহ্ এবং তাঁর রসূল, আর যারা ঈমান এনেছে, আর যারা নামায কায়েম করে, আর যাকাত আদায় করে, আর তারা রুকুকারী।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@dccxxv{আর যে কেউ বন্ধুরূপে গ্রহণ করে আল্লাহ্‌কে, ও তাঁর রসূলকে, আর যারা ঈমান এনেছে তাদের, তাহলে আল্লাহ্‌র দল, তারাই হবে বিজয়ী।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@dccxxvi{ওহে যারা ঈমান এনেছ! যারা তোমাদের ধর্মকে উপহাসের ও খেলার সামগ্রীরূপে গ্রহণ করেছে -- তোমাদের পূর্বে যাদের গ্রন্থ দেয়া হয়েছে ও অবিশ্বাসকারীরা, -- তাদের বন্ধুরূপে গ্রহণ করো না। আর আল্লাহ্‌কে ভয়-শ্রদ্ধা করো যদি তোমরা মুমিন হও।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@dccxxvii{আর যখন তোমরা নামাযের জন্য আহ্বান করো, তারা তাকে বিদ্রূপের ও খেলার জিনিসরূপে গ্রহণ করে। সেটি এই জন্য যে তারা এমন একটি দল যারা বুঝে না।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@dccxxviii{তুমি বলো -- ''হে গ্রন্থপ্রাপ্ত লোকেরা! তোমরা কি আমাদের কোনো দোষ ধরো এ ব্যতীত যে আমরা ঈমান এনেছি আল্লাহ্‌তে, আর যা আমাদের কাছে নাযিল হয়েছে, আর যা পূর্বে নাযিল হয়েছিল? আর নিশ্চয় তোমাদের অধিকাংশই দুষ্কৃতিপরায়ণ।’’\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@dccxxix{বলো -- ''তোমাদের কি জানাবো এর চেয়েও খারাপদের কথা, আল্লাহ্‌র কাছে প্রতিফল পাওয়া সন্বন্ধে? যাকে আল্লাহ্ ধিক্কার দিয়েছেন, আর যার উপরে তিনি ক্রোধ বর্ষণ করেছেন, আর তাদের মধ্যের কাউকে তিনি বানালেন বানর, আর শূকর, আর যে উপাসনা করত তাগুতকে। এরা আছে অতি মন্দ অবস্থায়, আর সরল পথ থেকে সুদূর পথভ্রষ্ট।\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@dccxxx{আর যখন তারা তোমাদের কাছে আসে তারা বলে -- 'আমরা ঈমান এনেছি’, কিন্তু আসলে তারা ভরতি হয়েছিল অবিশ্বাস নিয়ে আর এখন বেরিয়েও গেছে তাতেই। আর আল্লাহ্ ভালো জানেন কি তারা লুকোচ্ছে।\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@dccxxxi{আর তুমি দেখতে পাবে তাদের অনেকেই ছুটে চলেছে পাপের দিকে ও উল্লঙ্ঘনে, আর তাদের গলাধঃকরণে অবৈধভাবে লব্ধ বস্তু। নিশ্চয়ই গর্হিত যা তারা করে চলেছে।\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@dccxxxii{রব্বিগণ ও পুরোহিতরা কেন তাদের নিষেধ করে না তাদের পাপপূর্ণ কথাবার্তা বলাতে আর তাদের গ্রাস-করণে অবৈধভাবে লব্ধ বস্তু। অবশ্যই গর্হিত যা তারা করে যাচ্ছে।\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@dccxxxiii{আর ইহুদীরা বলে -- ''আল্লাহ্‌র হাত বাঁধা রয়েছে।’’ তাদের হাত রয়েছে বাঁধা, আর তারা ধিক্কারপ্রাপ্ত যা তারা বলে সেজন্য। না, তাঁর দুই হাতই পূর্ণ-প্রসারিত, -- তিনি বিতরণ করেন যেমন তিনি চান। আর তোমার প্রভুর কাছ থেকে তোমার কাছে যা নাযিল হয়েছে তা নিশ্চয়ই বাড়িয়ে দেয় তাদের মধ্যের অনেকের অবাধ্যতা ও অবিশ্বাস। আর আমরা তাদের মধ্যে ছুঁড়ে দিয়েছি শত্রুতা ও বিদ্বেষ কিয়ামতের দিন পর্যন্ত। যতবার তারা যুদ্ধের আগুন জ্বালিয়ে তুলে, আল্লাহ্ তা নিভিয়ে দেন, কিন্তু তারা দেশে গন্ডগোল করার চেষ্টা চালাতেই থাকে। আর আল্লাহ্ ভালোবাসেন না গন্ডগোল সৃষ্টিকারীদের।\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@dccxxxiv{আর যদি গ্রন্থপ্রাপ্ত লোকেরা ঈমান আনতো এবং ভয়-শ্রদ্ধা করতো, তবে নিশ্চয়ই আমরা তাদের দোষ-ত্রুটি তাদের থেকে মুছে দিতাম, আর তাদের অবশ্যই প্রবেশ করাতাম আনন্দময় স্বর্গোদ্যানে।\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@dccxxxv{আর যদি তারা প্রতিষ্ঠিত রাখতো তওরাত ও ইনজীল, আর তাদের কাছে যা অবতীর্ণ হয়েছিল তাদের প্রভুর কাছ থেকে তবে তারা নিশ্চয়ই আহার করতো তাদের উপর থেকে আর তাদের পায়ের নিচে থেকে। তাদের মধ্যেও একটি নরমপন্থী দল রয়েছে, কিন্তু তাদের অনেকের ক্ষেত্রেই -- তারা যা করে তা হচ্ছে গর্হিত।\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@dccxxxvi{হে প্রিয় রসূল! তোমার প্রভুর কাছ থেকে যা তোমার কাছে অবতীর্ণ হয়েছে তা প্রচার করো। আর যদি তুমি তা না করো তবে তাঁর বাণী তুমি প্রচার করলে না। আর আল্লাহ্ লোকদের থেকে তোমাকে রক্ষা করবেন। নিঃসন্দেহ আল্লাহ্ অবিশ্বাসী লোকদের পথপ্রদর্শন করেন না।\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@dccxxxvii{বলো -- ''হে গ্রন্থপ্রাপ্ত লোকেরা! তোমরা কোনো কিছুর উপরে নও যে পর্যন্ত না তোমরা প্রতিষ্ঠিত রাখো তওরাত ও ইনজীল আর যা তোমাদের কাছে অবতীর্ণ হয়েছে তোমাদের প্রভুর কাছ থেকে।’’ আর তোমার কাছে তোমার প্রভুর কাছ থেকে যা অবতীর্ণ হয়েছে তা নিশ্চয়ই বাড়িয়ে দেয় তাদের মধ্যের অনেকের অবাধ্যতা ও অবিশ্বাস। সেজন্য দুঃখ করো না অবিশ্বাসী লোকদের জন্য।\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@dccxxxviii{নিঃসন্দেহ যারা ঈমান এনেছে ও যারা ইহুদী মত পোষণ করে, আর সাবেঈন ও খ্রীষ্টান, -- যারাই আল্লাহ্‌র প্রতি ঈমান এনেছে ও আখেরাতের দিনের প্রতি, আর সৎকর্ম করে, তাদের উপরে তা হলে কোনো ভয় নেই, আর তারা নিজেরা অনুতাপও করবে না।\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@dccxxxix{আমরা নিশ্চয়ই ইসরাইলের বংশধরদের থেকে অঙ্গীকার গ্রহণ করেছিলাম আর তাদের কাছে পাঠিয়েছিলাম রসূলগণ। যখনই তাদের কাছে কোনো রসূল এসেছেন তা নিয়ে যা তাদের মন চায় না, কিছুসংখ্যককে তারা মিথ্যারোপ করেছে আর কাউকে করতে গেছে হত্যা।\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@dccxl{আর তারা ভেবেছিল যে কোনো পরীক্ষা-নিরীক্ষা হবে না, সেজন্য তারা হলো অন্ধ আর বধির, এরপর আল্লাহ্ তাদের দিকে ফিরলেন। তারপরেও তাদের অনেকে অন্ধ ও বধির হলো। আর তারা যা করে আল্লাহ্ তার দর্শক।\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@dccxli{নিশ্চয়ই তারা অবিশ্বাস পোষণ করে থাকে যারা বলে -- ''নিঃসন্দেহ আল্লাহ্‌, তিনিই মসীহ্‌, মরিয়মের পুত্র।’’ অথচ মসীহ্ বলেছেন -- ''হে ইসরাইলের বংশধরগণ! আল্লাহ্‌র এবাদত করো যিনি আমার প্রভু ও তোমাদেরও প্রভু।’’ নিঃসন্দেহ যে আল্লাহ্‌র সঙ্গে অংশীদার নিরূপণ করে, আল্লাহ্ নিশ্চয়ই তার জন্য নিষিদ্ধ করেছেন স্বর্গোদ্যান, আর তার আবাসস্থল হচ্ছে আগুন। আর অন্যায়কারীদের জন্য থাকবে না কোনো সাহায্যকারী।\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@dccxlii{তারা নিশ্চয়ই অবিশ্বাস পোষণ করে যারা বলে -- ''নিঃসন্দেহ আল্লাহ্ হচ্ছেন তিনজনের তৃতীয়জন।’’ বস্তুতঃ একক খোদা ছাড়া অন্য কোনো উপাস্য নেই। আর যা তারা বলছে তা থেকে যদি তারা না থামে, তবে তাদের মধ্যের যারা অবিশ্বাস পোষণ করে তাদের পাকড়াবে ব্যথাদায়ক শাস্তি।\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@dccxliii{তবে কি তারা আল্লাহ্‌র দিকে ফিরবে না, আর তারা তাঁর ক্ষমা-প্রার্থনা করবে কি? আর আল্লাহ্ পরিত্রাণকারী, অফুরন্ত ফলদাতা।\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@dccxliv{মরিয়ম-পুত্র মসীহ্ রসূল বৈ নন। তাঁর পূর্বে রসূলগণ নিশ্চয়ই গত হয়ে গেছেন। আর তাঁর মাতা ছিলেন একজন সত্যপরায়ণা নারী। তাঁরা উভয়ে খাদ্য খেতেন। দেখো, কিভাবে আমরা তাদের জন্য আমার বাণী সুস্পষ্ট করি, তারপর দেখো, কেমন করে তারা ঘুরে যায়।\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@dccxlv{বলো -- ''তোমরা আল্লাহ্‌কে ছেড়ে দিয়ে কি তার এবাদত করো যার কোনো ক্ষমতা নেই তোমাদের জন্য অপকারের, না কোনো উপকারের? আর আল্লাহ্‌, -- তিনি সর্বশ্রোতা, সর্বজ্ঞাতা।’’\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@dccxlvi{বলো -- ''হে গ্রন্থপ্রাপ্ত লোকেরা! তোমাদের ধর্মমতে বাড়াবাড়ি করো না সত্য কারণ ছাড়া, আর লোকদের হীন-কামনার অনুবর্তী হয়ো না, -- যারা ইতিপূর্বে পথভ্রষ্ট হয়েছিল আর বহুজনকে করেছিল পথহারা, আর বিপথে গিয়েছিল সরল পথ থেকে।\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@dccxlvii{ইসরাইলের বংশধরদের মধ্যে যারা অবিশ্বাস পোষণ করেছিল তারা অভিশপ্ত হয়েছিল দাউদ ও মরিয়ম-পুত্র ঈসার জিহবার দ্বারা। এটি হয়েছিল, কেননা তারা অবাধ্য হয়েছিল আর করতো সীমালঙ্ঘন।\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@dccxlviii{তারা পরস্পরকে নিষেধ করতো না কুকর্ম সন্বন্ধে যা তারা করতো। নিশ্চয়ই মন্দ যা তারা করে চলতো।\qt@no{(79)}}
\qt@newcmd\qurantrans@bn@dccxlix{তুমি দেখতে পাবে তাদের মধ্যের অনেকে বন্ধু বানিয়েছে যারা অবিশ্বাস পোষণ করে তাদের। নিশ্চয়ই মন্দ যা তাদের জন্য তাদের আ‌ত্মা আগবাড়িয়েছে যার দরুন আল্লাহ্ তাদের উপরে হয়েছেন অসন্তষ্ট, আর শাস্তির মধ্যেই তারা কাটাবে দীর্ঘকাল।\qt@no{(80)}}
\qt@newcmd\qurantrans@bn@dccl{আর যদি তারা ঈমান এনে থাকতো আল্লাহ্‌তে ও নবীর প্রতি, আর যা তাঁর কাছে অবতীর্ণ হয়েছে তাতে তবে তারা ওদের বন্ধুরূপে গ্রহণ করতো না। কিন্তু তাদের মধ্যের অনেকেই দুষ্কৃতিপরায়ণ।\qt@no{(81)}}
\qt@newcmd\qurantrans@bn@dccli{তুমি নিশ্চয়ই দেখতে পাবে যে যারা ঈমান এনেছে তাদের সাথে শত্রুতায় সব চাইতে কঠোর লোক হচ্ছে ইহুদীরা ও যারা শরীক করে, আর নিশ্চয়ই তুমি আবিস্কার করবে যে যারা ঈমান এনেছে তাদের সাথে বন্ধুত্বে সব চাইতে তাদের ঘনিষ্ঠ হচ্ছে ওরা যারা বলে -- ''নিঃসন্দেহ আমরা খ্রীষ্টান।’’ এটি এই জন্য যে তাদের মধ্যে রয়েছে পাদরীরা ও সাধুসন্ন্যাসীরা, আর যেহেতু তারা অহঙ্কার করে না।\qt@no{(82)}}
\qt@newcmd\qurantrans@bn@dcclii{আর যখন তারা শোনে যা রসূলের কাছে নাযিল হয়েছে, তুমি দেখবে তাদের চোখ অ‌শ্রুপ্লাবিত হয়েছে সত্যতা তারা উপলব্ধি করেছিল বলে। তারা বলে -- ''আমাদের প্রভু! আমরা ঈমান এনেছি, তাই আমাদের লিখে রাখো সাক্ষ্যদাতাদের সঙ্গে।\qt@no{(83)}}
\qt@newcmd\qurantrans@bn@dccliii{''আর কি কারণ আমাদের থাকতে পারে যার জন্য আমরা বিশ্বাস করবো না আল্লাহ্‌তে আর যে সত্য আমাদের কাছে এসেছে তাতে, যখন আমরা আকুল আকাঙ্খা করি যে আমাদের প্রভু যেন সৎকর্মশীল লোকদের সঙ্গে আমাদের অন্তর্ভুক্ত করেন?’’\qt@no{(84)}}
\qt@newcmd\qurantrans@bn@dccliv{কাজেই আল্লাহ্ তাদের পুরস্কার দিয়েছিলেন যা তারা বলেছিল সেজন্য, -- বাগানসমূহ যাদের নিচে দিয়ে বয়ে চলে ঝরনারাজি, তাতে তারা থাকবে চিরকাল। আর এটি হচ্ছে সৎকর্মীদের পুরস্কার।\qt@no{(85)}}
\qt@newcmd\qurantrans@bn@dcclv{আর যারা অবিশ্বাস পোষণ করে ও আমাদের নির্দেশসমূহে মিথ্যারোপ করে, তারা হচ্ছে জ্বলন্ত আগুনের বাসিন্দা।\qt@no{(86)}}
\qt@newcmd\qurantrans@bn@dcclvi{ওহে যারা ঈমান এনেছ! ভালো বিষয়গুলো যা আল্লাহ্ তোমাদের জন্য বৈধ করেছেন সে-সব তোমরা নিষিদ্ধ করো না, আবার বাড়াবাড়িও করো না। নিঃসন্দেহ আল্লাহ্ ভালোবাসেন না সীমালঙ্ঘনকারীদের।\qt@no{(87)}}
\qt@newcmd\qurantrans@bn@dcclvii{আর আল্লাহ্ তোমাদের যা হালাল ও ভালো রিযেক দিয়েছেন তা থেকে ভোগ করো আর আল্লাহ্‌কে ভয়-শ্রদ্ধা করো, -- যাঁর প্রতি তোমরা মুমিন হয়েছ।\qt@no{(88)}}
\qt@newcmd\qurantrans@bn@dcclviii{আল্লাহ্ তোমাদের পাকড়াবেন না তোমাদের শপথগুলোর মধ্যে যা খেলো, কিন্তু তিনি তোমাদের পাকড়াও করবেন সেইসব শপথের জন্য যা তোমরা সেচ্ছাকৃতভাবে করো, তাই এর প্রায়শ্চিত্ত হচ্ছে দশজন গরীবকে খাওয়ানো, -- তোমাদের পরিজনকে তোমরা যেভাবে খাওয়াও সেইভাবে সাধারণ ধরনে, অথবা তাদের পরানো, অথবা একজন দাসকে মুক্ত করা। কিন্তু যে পায় না তবে তিন দিন রোযা। এ হচ্ছে তোমাদের শপথের প্রায়শ্চিত্ত যখন তোমরা হলফ করো। আর তোমাদের শপথ হেফাজতে রাখো। এইভাবে আল্লাহ্ তোমাদের জন্য তাঁর নির্দেশাবলী সুস্পষ্ট করেছেন যেন তোমরা কৃতজ্ঞতা জ্ঞাপন করো।\qt@no{(89)}}
\qt@newcmd\qurantrans@bn@dcclix{ওহে যারা ঈমান এনেছ! নিঃসন্দেহ মাদকদ্রব্য ও জুয়া, আর প্রস্তর বেদী বসানো ও তীরের লটারি খেলা -- নিশ্চয়ই হচ্ছে অপবিত্র, শয়তানের কাজের অন্তর্ভুক্ত, কাজেই এ-সব এড়িয়ে চলো, যেন তোমরা সফলকাম হতে পারো।\qt@no{(90)}}
\qt@newcmd\qurantrans@bn@dcclx{নিঃসন্দেহ শয়তান কেবলই চায় যে তোমাদের মধ্যে শত্রুতা ও বিদ্বেষ জাগরিত হোক মাদকদ্রব্য ও জুয়ার মাধ্যমে, আর তোমাদের ফিরিয়ে রাখবে আল্লাহ্‌র গুণগান থেকে ও নামায থেকে। তোমরা কি তাহলে পরিহৃত থাকবে?\qt@no{(91)}}
\qt@newcmd\qurantrans@bn@dcclxi{অতএব আল্লাহ্‌কে অনুসরণ করো, আর রসূলের অনুগমন করো, আর সাবধান হও, কিন্তু যদি তোমরা ফিরে যাও, তাহলে জেনে রেখো -- নিঃসন্দেহ আমাদের রসূলের উপরে হচ্ছে মাত্র স্পষ্টভাবে পৌঁছে দেয়া।\qt@no{(92)}}
\qt@newcmd\qurantrans@bn@dcclxii{যারা ঈমান এনেছে ও সৎকর্ম করে যাচ্ছে তাদের উপরে কোনো অপরাধ হবে না যা তারা খেয়েছে সেজন্য, যখন তারা ভয়-শ্রদ্ধা করে ও ঈমান আনে ও সৎকর্ম করে, পুনরায় ভয়ভক্তি করে ও ঈমান আনে, আবার তারা ভয়শ্রদ্ধা করে ও ভালো করে। আর আল্লাহ্ ভালোবাসেন সৎকর্মশীলদের।\qt@no{(93)}}
\qt@newcmd\qurantrans@bn@dcclxiii{ওহে যারা ঈমান এনেছ! আল্লাহ্ নিশ্চয়ই তোমাদের পরীক্ষা করবেন শিকারের কিছু ব্যাপারে যা তোমাদের হাত ও তোমাদের বর্শা নাগাল পায়, যেন আল্লাহ্ যাচাই করতে পারেন কে তাঁকে ভয় করে অগোচরে। কাজেই যে কেউ এর পরেও সীমালঙ্ঘন করে তার জন্য ব্যথাদায়ক শাস্তি।\qt@no{(94)}}
\qt@newcmd\qurantrans@bn@dcclxiv{ওহে যারা ঈমান এনেছ! শিকার হত্যা করো না যখন তোমরা হারামে থাকো। আর তোমাদের মধ্যে যে কেউ ইচ্ছা করে তা হত্যা ক’রে ক্ষতিপূরণ তবে হচ্ছে সে যা হত্যা করেছে তার অনুরূপ গবাদি-পশু থেকে যা ধার্য করে দেবে তোমাদের মধ্যের দুইজন ন্যায়বান লোক, সে কুরবানি পৌঁছানো চাই কা'বাতে, অথবা প্রায়শ্চিত্ত হচ্ছে গরীবকে খাওয়ানো, অথবা তার সমতুল্য রোযা রাখা, -- যেন সে তার কাজের দন্ড ভোগ করে। আল্লাহ্ মাফ করে দেন যা হয়ে গেছে। কিন্তু যে কেউ পুনরাবর্তন করে, আল্লাহ্ সেজন্য প্রতিফল দেবেন। আর আল্লাহ্ মহাশক্তিশালী, প্রতিফল দানে সক্ষম।\qt@no{(95)}}
\qt@newcmd\qurantrans@bn@dcclxv{তোমাদের জন্য বৈধ জলের শিকার আর তার খাদ্য তোমাদের জন্য ও পর্যটকদের জন্য উপকরণ, আর তোমাদের জন্য নিষিদ্ধ ডাঙায় শিকার যে সময়ে তোমরা হারামে থাকো। আর ভয়শ্রদ্ধা করো আল্লাহ্‌কে, যাঁর কাছে তোমাদের একত্রিত করা হচ্ছে।\qt@no{(96)}}
\qt@newcmd\qurantrans@bn@dcclxvi{আল্লাহ্ পবিত্র গৃহ কা'বাকে বানিয়েছেন মানুষের জন্য এক অবলন্বন, আর পবিত্র মাস, আর উৎসর্গকৃত পশুদের, আর মালা- পরানো উটদের। এ-সব এই জন্য যে তোমরা যেন জানতে পারো -- আল্লাহ্ জানেন যা-কিছু আছে মহাকাশমন্ডলে ও যা-কিছু আছে পৃথিবীতে, আর আল্লাহ্ সব-কিছু সন্বন্ধে সর্বজ্ঞাতা।\qt@no{(97)}}
\qt@newcmd\qurantrans@bn@dcclxvii{তোমরা জেনে রেখো যে আল্লাহ্ প্রতিফল দানে কঠোর, আর আল্লাহ্ পরিত্রাণকারী, অফুরন্ত ফলদাতা।\qt@no{(98)}}
\qt@newcmd\qurantrans@bn@dcclxviii{রসূলজনের উপরে অন্য দায়িত্ব নেই পৌঁছে দেয়া ছাড়া। আর আল্লাহ্ জানেন যা তোমরা প্রকাশ করো আর যা লুকিয়ে রাখো।\qt@no{(99)}}
\qt@newcmd\qurantrans@bn@dcclxix{বলো -- ''মন্দ আর ভালো সমতুল্য নয়’’, যদিও মন্দের প্রাচুর্য তোমাকে তাজ্জব বানিয়ে দেয়। কাজেই আল্লাহ্‌কে ভয়শ্রদ্ধা করো, হে বিজ্ঞ ব্যক্তিগণ! যেন তোমরা সফলকাম হতে পারো।\qt@no{(100)}}
\qt@newcmd\qurantrans@bn@dcclxx{ওহে যারা ঈমান এনেছ! সে-সব বিষয় সন্বন্ধে প্রশ্ন করো না যা তোমাদের কাছে ব্যক্ত করলে তোমাদের অসুবিধা হতে পারে। আর যদি তোমরা সে-সব বিষয়ে প্রশ্ন করো যে সময়ে কুরআন অবতীর্ণ হচ্ছে তবে তোমাদের জন্য ব্যক্ত করা হবে। আল্লাহ্ এটি থেকে মাফ করেছেন, কেননা আল্লাহ্ পরিত্রাণকারী, অতি অমায়িক।\qt@no{(101)}}
\qt@newcmd\qurantrans@bn@dcclxxi{তোমাদের পূর্বে একটি দল এ-ধরনের প্রশ্ন করতো, তারপর সেইসব কারণে পরমুহূর্তে তারা হলো অবিশ্বাসী।\qt@no{(102)}}
\qt@newcmd\qurantrans@bn@dcclxxii{আল্লাহ্ তৈরি করেন নি কোনো বাহীরাহ্‌, বা সা’ইবাহ্‌, বা ওস্বীলাহ্‌, বা হামি, কিন্তু যারা অবিশ্বাস পোষণ করে তারা আল্লাহ্‌র বিরুদ্ধে এই মিথ্যা রচনা করেছে। কিন্তু তাদের অধিকাংশই বুঝতে পারে না।\qt@no{(103)}}
\qt@newcmd\qurantrans@bn@dcclxxiii{আর যখন তাদের বলা হয় -- ''আল্লাহ্ যা নাযিল করেছেন তার দিকে আর রসূলের দিকে এস’’, তারা বলে -- ''আমাদের জন্য এ-ই যথেষ্ট যার উপরে আমাদের পিতৃপুরুষদের দেখেছি।’’ কী! যদিও তাদের পিতৃপুরুষরা কিছুই জানতো না আর তারা হেদায়তও গ্রহণ করে নি।\qt@no{(104)}}
\qt@newcmd\qurantrans@bn@dcclxxiv{ওহে যারা ঈমান এনেছ! তোমাদের উপরে ভার রয়েছে তোমাদের জীবনের, যে পথভ্রষ্ট হয়েছে সে তোমাদের কোনো ক্ষতি করতে পারবে না যদি তোমরা পথনির্দেশ মেনে চল। আল্লাহ্‌র কাছেই তোমাদের সকলের প্রত্যাবর্তন, তখন তিনি তোমাদের জানাবেন কী তোমরা করতে।\qt@no{(105)}}
\qt@newcmd\qurantrans@bn@dcclxxv{ওহে যারা ঈমান এনেছ! যখন মৃত্যু তোমাদের কারো কাছে হাজির হয় তখন তোমাদের মধ্যে সাক্ষী ডাকো ওছিয়ৎ করবার সময়ে, -- দুইজন ন্যায়পরায়ণ লোক তোমাদের মধ্যে থেকে, অথবা অপর দুইজন তোমাদের বাইরের থেকে -- যদি তোমরা দেশ- ভ্রমণে থাকো আর তোমাদের উপরে মৃত্যুর বিভীষিকা ঘটে। এ দু’জনকে তোমরা ধরে রাখবে নামাযের পরে, আর যদি তোমরা সন্দেহ করো তবে তারা উভয়ে আল্লাহ্‌র নামে শপথ করুক -- ''আমরা এটি বিক্রি করবো না যে কোনো দামে, যদিও বা নিকট-আ‌ত্মীয় হয়, আর আমরা সাক্ষ্য লুকাবো না, কেননা তাহলে আমরা নিশ্চয়ই পাপীদের অন্তর্ভুক্ত হবো।’’\qt@no{(106)}}
\qt@newcmd\qurantrans@bn@dcclxxvi{পক্ষান্তরে যদি আবিস্কার করা হয় যে তাদের দু’জনই পাপের যোগ্যতা লাভ করেছে তবে তাদের স্থলে দাঁড়াক অপর দুইজন তাদের মধ্যে থেকে যাদের দাবি উল্টানো হয়েছে প্রথম দুইজনের দ্বারা, তখন তারা আল্লাহ্‌র নামে কসম খাক -- ''আমাদের দু’জনের সাক্ষ্য ঐ দুইজনের সাক্ষ্যের চাইতে অধিকতর সত্য, আর আমরা সীমা লঙ্ঘন করি নি, কেননা তবে নিঃসন্দেহ আমরা অন্যায়কারীদের অন্তর্ভুক্ত হবো।’’\qt@no{(107)}}
\qt@newcmd\qurantrans@bn@dcclxxvii{এইভাবে এটি অধিক সম্ভবপর যে তারা সাক্ষ্য দেবে তাদের মুখের উপর, অথবা তারা আশংকা করবে যে অন্য শপথ তাদর শপথকে পরবর্তীকালে বাতিল ক’রে দেবে। আর আল্লাহ্‌কে ভয়ভক্তি করো ও শোন। আর আল্লাহ্ হেদায়ত করেন না অবাধ্য লোকদের।\qt@no{(108)}}
\qt@newcmd\qurantrans@bn@dcclxxviii{যেদিন আল্লাহ্ রসূলগণকে একত্রিত করবেন, তারপর বলবেন -- ''তোমাদের কী জবাব দেয়া হয়েছিল?’’ তাঁরা বলবেন -- ''আমাদের কিছু জানা নেই, নিঃসন্দেহ তুমিই অদৃশ্য সন্বন্ধে পরিজ্ঞাত।’’\qt@no{(109)}}
\qt@newcmd\qurantrans@bn@dcclxxix{তখন আল্লাহ্ বলবেন -- ''হে মরিয়ম-পুত্র ঈসা! তোমার প্রতি ও তোমার মাতার প্রতি আমার অনুগ্রহ স্মরণ করো। স্মরণ করো! কেমন ক’রে তোমাকে আমি 'রূহুল ক্কুদুস’ দিয়ে বলীয়ান করেছিলাম, তুমি লোকদের সঙ্গে কথা বলেছিলে দোলনায় থাকাকালে ও বার্ধক্যকালে, আর স্মরণ করো! কেমন ক’রে তোমাকে শিখিয়েছিলাম কিতাব ও জ্ঞান-বিজ্ঞান, আর তওরাত ও ইনজীল, আর স্মরণ করো! কেমন করে তুমি মাটি দিয়ে তৈরি করতে পাখির মতো মূর্তি আমার অনুমতিক্রমে, তারপর তুমি তাতে ফুৎকার দিতে, তখন তা পাখি হয়ে যেত আমার অনুমতিক্রমে, আর তুমি আরোগ্য করতে জন্মান্ধকে ও কুষ্ঠরোগীকে আমার অনুমতিক্রমে, আর স্মরণ করো! কেমন ক’রে তুমি মৃতকে বের করতে আমার অনুমতিক্রমে, আর স্মরণ করো! কেমন ক’রে আমি ইসরাইলবংশীয় লোকদের নিবৃত্ত রেখেছিলাম তোমা থেকে যখন তুমি তাদের কাছে এসেছিলে স্পস্প্রমাণাবলী নিয়ে।’’ কিন্তু তাদের মধ্যের যারা অবিশ্বাস পোষণ করেছিল তারা বলেছিল -- ''এ স্পষ্ট জাদু ছাড়া আর কিছুই নয়।’’\qt@no{(110)}}
\qt@newcmd\qurantrans@bn@dcclxxx{আর স্মরণ করো! আমি হাওয়ারিদের কাছে প্রত্যাদেশ দিয়েছিলাম এই বলে -- ''তোমরা আমার প্রতি ও আমার রসূলের প্রতি ঈমান আনো।’’ তারা বলেছিল -- ''আমরা ঈমান আনলাম, আর তুমি সাক্ষী থেকো যে আমরা নিশ্চয়ই আ‌ত্মসমর্পিত।\qt@no{(111)}}
\qt@newcmd\qurantrans@bn@dcclxxxi{স্মরণ করো! হাওয়ারিগণ বলেছিল -- ''হে মরিয়ম-পুত্র ঈসা! তোমার প্রভু কি আমাদের জন্য আকাশ থেকে খাদ্য-পরিবেশিত টেবিল পাঠাতে রাজি হবেন?’’ তিনি বলেছিলেন -- ''আল্লাহ্‌কে ভয়-ভক্তি করো যদি তোমরা মুমিন হও।’’\qt@no{(112)}}
\qt@newcmd\qurantrans@bn@dcclxxxii{তারা বলেছিল -- ''আমরা চাই যে আমরা যেন তা থেকে আহার করি, আর আমাদের চিত্ত যেন পরিতৃপ্ত হয়, আর যেন আমরা জানতে পারি যে তুমি আমাদের কাছে হককথাই বলেছিলে, আর আমরা যেন সে-বিষয়ে সাক্ষীদের মধ্যেকার হতে পারি।’’\qt@no{(113)}}
\qt@newcmd\qurantrans@bn@dcclxxxiii{মরিয়ম-পুত্র ঈসা বললেন -- ''হে আল্লাহ্‌! আমাদের প্রভু! আমাদের জন্য আকাশ থেকে খাদ্য-পরিপূর্ণ খাঞ্চা প্রেরণ করো, যা হবে আমাদের জন্য এক ঈদ, -- আমাদের অগ্রগামীদের জন্য ও পশ্চাদগামীদের জন্য, আর তোমার কাছ থেকে একটি নিদর্শন, আর আমাদের রিযেক দান করো, কেননা তুমিই রিযেকদাতাদের সর্বোত্তম।’’\qt@no{(114)}}
\qt@newcmd\qurantrans@bn@dcclxxxiv{আল্লাহ্ বললেন -- ''আমি অবশ্যই তা তোমাদের জন্য পাঠাব, কিন্তু তোমাদের মধ্যে যে কেউ এরপরেও অবিশ্বাস পোষণ করবে আমি তবে তাকে নিশ্চয়ই এমন শাস্তিতে শাস্তি দেবো যেমন শাস্তি আমি বিশ্বজগতের অপর কাউকেও দেবো না।’’\qt@no{(115)}}
\qt@newcmd\qurantrans@bn@dcclxxxv{আর দেখো! আল্লাহ্ বলবেন -- ''হে মরিয়ম-পুত্র ঈসা! তুমি কি লোকদের বলেছিলে -- “আমাকে ও আমার মাকে আল্লাহ্ ছাড়া দুইজন উপাস্যরূপে গ্রহণ করো?’’ তিনি বলবেন -- ''তোমারই সব মহিমা! এটি আমার পক্ষে সম্ভবপর নয় যে আমি তা বলবো যাতে আমার কোনো অধিকার নেই। যদি আমি তা বলতাম তবে তুমি তা নিশ্চয়ই জানতে। আমার অন্তরে যা আছে তা তুমি জানো, আর আমি জানি না কি আছে তোমার অন্তরে। নিঃসন্দেহ কেবল তুমিই অদৃশ্য সন্বন্ধে পরিজ্ঞাত।\qt@no{(116)}}
\qt@newcmd\qurantrans@bn@dcclxxxvi{''আমি তাদের বলি নি তুমি যা আমাকে আদেশ করেছ তা ছাড়া অন্য কিছু, যথা -- 'তোমরা আল্লাহ্‌র উপাসনা করো যিনি আমার প্রভু ও তোমাদের প্রভু’, আর আমি তাদের সাক্ষী ছিলাম যতদিন আমি তাদের মধ্যে ছিলাম, কিন্তু যখন তুমি আমার মৃত্যু ঘটালে তখন তুমিই ছিলে তাদের উপরে প্রহরী। আর তুমিই হচ্ছো সব-কিছুরই সাক্ষী।\qt@no{(117)}}
\qt@newcmd\qurantrans@bn@dcclxxxvii{''তুমি যদি তাদের শাস্তি দাও তবে তারা তো তোমারই দাস, আর যদি তাদের তুমি পরিত্রাণ করো তবে তুমিই তো মহাশক্তিশালী, পরমজ্ঞানী।’’\qt@no{(118)}}
\qt@newcmd\qurantrans@bn@dcclxxxviii{আল্লাহ্ বলবেন -- ''এই দিনে সত্যনিষ্ঠদের তাদের সত্যপরায়ণতা উপকৃত করবে। তাদের জন্য রয়েছে স্বর্গোদ্যানসমূহ যাদের নিচে দিয়ে বয়ে চলে ঝরনারাজি, তারা সেখানে থাকবে চিরকাল। আল্লাহ্ তাদের উপরে সুপ্রসন্ন আর তারা তাঁতে চির-সন্তষ্ট -- এটি হচ্ছে এক বিরাট সাফল্য।\qt@no{(119)}}
\qt@newcmd\qurantrans@bn@dcclxxxix{মহাকাশমন্ডল ও পৃথিবীর সার্বভৌমত্ব ও তাদের মধ্যে যা-কিছু আছে সে-সবই আল্লাহ্‌র। আর তিনি হচ্ছেন সব-কিছুর উপরে সর্বশক্তিমান।\qt@no{(120)}}
\qt@newcmd\qurantrans@bn@dccxc{\basmalahbn সমস্ত প্রশংসা আল্লাহ্‌র জন্য যিনি মহাকাশমন্ডল ও পৃথিবী সৃষ্টি করেছেন, আর তিনি তৈরি করেছেন অন্ধকার ও আলো। তবু যারা অবিশ্বাস পোষণ করে তারা তাদের প্রভুর সাথে দাঁড় করায় সমকক্ষ।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@dccxci{তিনিই সেইজন যিনি তোমাদের সৃষ্টি করেছেন কাদা থেকে তারপর তিনি নির্ধারিত করেছেন একটি আয়ুস্কাল, আর তাঁর কাছে নির্ধারিত রয়েছে একটি কাল, তবু তোমরা সন্দেহ করো!\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@dccxcii{আর তিনিই আল্লাহ্ মহাকাশমন্ডলে ও পৃথিবীতে। তিনি জানেন তোমাদের গোপনীয় বিষয় ও তোমাদের প্রকাশ্য বিষয়, আর তিনি জানেন যা তোমরা অর্জন করো।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@dccxciii{আর তাদের কাছে তাদের প্রভুর নির্দেশাবলীর মধ্যে থেকে এমন কোনো নির্দেশ আসে না যা থেকে তারা ফেরতগামী না হয়।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@dccxciv{সুতরাং তারা নিশ্চয়ই সত্যকে প্রত্যাখ্যান করেছে যখনই তা তাদের কাছে এসেছে, কাজেই অচিরেই তাদের কাছে বার্তা আসবে যা নিয়ে তারা ঠাট্টা-বিদ্রূপ করতো।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@dccxcv{তারা কি দেখে না -- তাদের আগে আমরা কত মানব-বংশকে ধ্বংস করেছি যাদের আমরা পৃথিবীতে এমনভাবে প্রতিষ্ঠিত করেছিলাম যেমন তোমাদেরও প্রতিষ্ঠিত করি নি? আর আমরা মেঘমালা পাঠিয়েছিলাম তাদের উপরে অজস্র বৃষ্টিপাত করতে, আর তাদের নিচে দিয়ে ঝরনারাজি প্রবাহিত হতে দিয়েছিলাম, তারপর তাদের ধ্বংস করেছিলাম তাদের অপরাধের জন্য, আর তাদের পরে পত্তন করেছিলাম অন্য এক মানব-বংশের।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@dccxcvi{আর আমরা যদি তোমার কাছে কাগজের মধ্যে কিতাব অবতারণ করতাম আর তাদের হাত দিয়ে তারা তা স্পর্শও করতো, তবু যারা অবিশ্বাস পোষণ করে তারা নিশ্চয়ই বলতো -- ''এ স্পষ্ট জাদু ব্যতীত আর কিছুই নয়।’’\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@dccxcvii{আর তারা বলে -- ''একজন ফিরিশ্‌তাকে কেন তাঁর কাছে নামানো হয় না?’’ আর যদিও আমরা একজন ফিরিশ্‌তাকে পাঠাতাম তা হলে ব্যাপারটি নিশ্চয়ই মীমাংসা হয়ে যেত, তখন তাদের অবকাশ দেয়া হবে না।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@dccxcviii{আর আমরা যদি তাঁকে ফিরিশ্‌তা বানাতাম তবে নিশ্চয়ই আমরা তাকে মানুষ বানাতাম, আর তাদের জন্য ঘোরালো করতাম যা তারা ঘোরালো করছে।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@dccxcix{আর নিশ্চয়ই তোমার পূর্বে রসূলগণকে ঠাট্টা-বিদ্রূপ করা হয়েছিল, কাজেই যা নিয়ে তারা ঠাট্টা-বিদ্রূপ করতো তা ঘেরাও করেছিল তাদের মধ্যের যারা বিদ্রূপ করেছিল তাদের।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@dccc{বলো -- ''পৃথিবীতে পরিভ্রমণ করো, তারপর চেয়ে দেখো কেমন হয়েছিল প্রত্যাখ্যানকারীদের পরিণাম।’’\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@dccci{বলো -- ''মহাকাশমন্ডলে ও পৃথিবীতে যা-কিছু আছে সে-সব কার জন্য?’’ বলো -- ''আল্লাহ্‌রই জন্য।’’ তিনি তাঁর নিজের উপরে কর্তব্য ঠাওরেছেন করুণা। তিনি অবশ্যই কিয়ামতের দিনের প্রতি তোমাদের জমায়েৎ করতে যাচ্ছেন -- কোনো সন্দেহ নেই তাতে। যারা নিজেদের অন্তরা‌ত্মার ক্ষতিসাধন করেছে তারা তবে ঈমান আনবে না।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@dcccii{আর তাঁরই যা-কিছু অবস্থান করে রাতে ও দিনের বেলায়, আর তিনি সর্বশ্রোতা, সর্বজ্ঞাতা।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@dccciii{বলো -- ''আমি কি মহাকাশমন্ডল ও পৃথিবীর আদি-স্রষ্টা আল্লাহ্ ব্যতীত অন্যকে মুরব্বীরূপে গ্রহণ করবো, অথচ তিনি খাওয়ান, কিন্ত তাঁকে খাওয়ানো হয় না।’’ বলো -- ''আমি নিশ্চয়ই আদিষ্ট হয়েছি যেন যারা আ‌ত্মসমর্পণ করে তাদের মধ্যে আমি অগ্রণী হই।’’ আর তুমি মুশরিকদের অন্তর্ভুক্ত হয়ো না।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@dccciv{তুমি বলো -- ''আমি অবশ্যই ভয় করি এক ভীষণ দিনের শাস্তি যদি আমি আমার প্রভুর অবাধ্যতা করি।’’\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@dcccv{যার কাছ থেকে সেদিন এটি অপসারিত করা হবে তাকে তবে নিশ্চয় তিনি করুণা করেছেন। আর এ এক সুস্পষ্ট সাফল্য!\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@dcccvi{আর আল্লাহ্ যদি তোমাকে দুঃখ দিয়ে স্পর্শ করেন তবে তার মোচনকারী তিনি ব্যতীত আর কেউ নেই। আর যদি তিনি তোমাকে স্পর্শ করেন কল্যাণ দিয়ে তবে তিনিই তো সব-কিছুর উপরে সর্বশক্তিমান।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@dcccvii{আর তাঁর বান্দাদের উপরেও তিনি পরম ক্ষমতাশালী! আর তিনি পরমজ্ঞানী, চির-ওয়াকিফহাল।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@dcccviii{বলো ''সাক্ষ্যদানে সবচাইতে গুরুত্বপূর্ণ কি?’’ বলো -- ''আল্লাহ্‌ই আমার ও তোমাদের মধ্যে সাক্ষী, আর এই কুরআন আমার নিকট প্রত্যাদিষ্ট হয়েছে যেন এর দ্বারা আমি তোমাদের এবং যার কাছে এটি পৌঁছুতে পারে তাদের সতর্ক করতে পারি। তোমরা কি সত্যিই এই সাক্ষ্য দাও যে আল্লাহ্‌র সঙ্গে অন্য আরো উপাস্য আছে?’’ তুমি বলো -- ''আমি সাক্ষ্য দিই না।’’ বলো -- ''নিঃসন্দেহ তিনিই একমাত্র উপাস্য, আর আমি অবশ্যই মুক্ত তোমরা যে-সব অংশীদার দাঁড় করাও তা থেকে।’’\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@dcccix{যাদের আমরা কিতাব দিয়েছি তারা তাঁকে চিনতে পেরেছিল যেমন তারা চেনে তাদের সন্তানদের। যারা তাদের অন্তরা‌ত্মার ক্ষতি করেছে তারা তবে ঈমান আনবে না।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@dcccx{আর কে তার চাইতে বেশী অন্যায়কারী যে আল্লাহ্‌-সন্বন্ধে মিথ্যা রচনা করে অথবা তাঁর আয়াতসমূহ প্রত্যাখ্যান করে? নিঃসন্দেহ অন্যায়কারীরা সফলকাম হবে না।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@dcccxi{আর একদিন আমরা তাদের সবাইকে একত্রিত করবো, তারপর যারা অংশীদার নিযুক্ত করেছিল তাদের বলবো -- ''কোথায় আছে তোমাদের সেইসব অনুসঙ্গী দেবতারা যাদের তোমরা তুলে ধরেছিলে?’’\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@dcccxii{তখন তাদের আর কিছু অজুহাত থাকবে না এই বলা ছাড়া -- ''আমাদের প্রভু আল্লাহ্‌র কসম, আমরা বহুখোদাবাদী ছিলাম না।’’\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@dcccxiii{দেখ, কিভাবে তারা নিজেদের বিরুদ্ধে মিথ্যা কথা বলে, আর তাদের থেকে বিদায় নিয়েছে যা তারা রচনা করতো!\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@dcccxiv{আর তাদের মধ্যে কেউ-কেউ তোমার দিকে কান পাতে, আর তাদের অন্তঃকরণের উপরে আমরা দিয়ে রেখেছি ঢাকনা পাছে তারা তা উপলব্ধি করতে পারে, আর তাদের কানে গুরুভার। আর যদিও তারা প্রত্যেকটি নিদর্শন প্রত্যক্ষ করে তবু তারা তোমার সঙ্গে তর্কবিতর্ক করে, যারা অবিশ্বাস পোষণ করে তারা বলে -- ''এ তো আগের দিনের উপকথা ব্যতীত আর কিছুই নয়।’’\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@dcccxv{আর তারা অন্যকে নিষেধ করে এ থেকে, আর এ থেকে তারা দূরে চলে যায়, আর তারা অবশ্যই ধ্বংস করে শুধু তাদের নিজেদেরই, কিন্ত তারা অনুভব করে না।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@dcccxvi{আর যদি তুমি দেখতে পেতে যখন আগুনের সামনে তাদের দাঁড় করানো হবে, তখন তারা বলবে -- ''হায়! যদি আমরা ফিরে যেতে পারতাম, আর যদি আমাদের প্রভুর নির্দেশাবলী প্রত্যাখ্যান না করতাম, আর যদি আমরা হতাম বিশ্বাসীদের অন্তর্ভুক্ত!’’\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@dcccxvii{না, তারা পূর্বে যা লুকিয়েছিল তা প্রকাশ পাবে তাদের কাছে। আর তাদের ফেরত পাঠানো হলেও তারা তাতেই ফিরে যেতো যা থেকে তাদের নিষেধ করা হয়েছিল, আর নিঃসন্দেহ তারাই মিথ্যাবাদী।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@dcccxviii{আর তারা বলে -- ''আমাদের দুনিয়াদারী জীবন ব্যতীত আর কিছুই নেই, আর আমরা পুনরুত্থিতও হব না।’’\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@dcccxix{আর যদি তুমি দেখতে পেতে যখন তাদের প্রভুর সামনে তাদের দাঁড় করানো হবে! তিনি বলবেন -- ''এ কি সত্য নয়?’’ তারা বলবে -- ''হাঁ আমাদের প্রভুর কসম!’’ তিনি বলবেন -- ''তবে তোমরা আস্বাদন করো সেই শাস্তি যা তোমরা অবিশ্বাস করতে।’’\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@dcccxx{তারা নিশ্চয়ই ক্ষতি করেছে যারা আল্লাহ্‌র সাথে মুলাকাত হওয়া অস্বীকার করে, যে পর্যন্ত না তাদের কাছে অতর্কিতে এসে পড়ে ঘড়ি-ঘান্টা, তখন তারা বলবে -- ''হায়! এ সন্বন্ধে আমরা অবহেলা করেছিলাম ব’লে আফসোস!’’ আর তারা তাদের বোঝা তাদের পিঠে বহন করবে। এটি কি অতি নিকৃষ্ট নয় যা তারা বহন করছে?\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@dcccxxi{আর এই দুনিয়ার জীবন ছেলেখেলা ও কৌতুক বই আর কিছুই নয়। আর পরকালের আবাসই শ্রেষ্ঠ তাদের জন্য যারা ধর্মপরায়ণতা পালন করে। তবে কি তোমরা অনুধাবন করো না?\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@dcccxxii{আমরা অবশ্যই জানি যে তারা যা বলে তা নিশ্চিতই তোমাকে কষ্ট দেয়, কিন্ত তারা তো নিশ্চয়ই তোমাকে মিথ্যাবাদী বলে না, কিন্ত অন্যায়কারীরা আল্লাহ্‌র আয়াতকেই অমান্য করে।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@dcccxxiii{আর তোমার পূর্বেও রসূলগণকে অবশ্যই মিথ্যারোপ করা হয়েছিল, কিন্ত তাঁরা অধ্যবসায়ী হয়েছিলেন তাদেরকে মিথ্যারোপ করা ও যন্ত্রণা দেয়া সত্ত্বেও, যে পর্যন্ত না আমাদের সাহায্য তাদের কাছে এসেছিল, আর আল্লাহ্‌র বাণী কেউ বদলাতে পারে না। আর তোমার কাছে প্রেরিত-পুরুষগণের সন্বন্ধে সংবাদ নিশ্চয়ই এসেছে।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@dcccxxiv{আর যদি তাদের ফিরে যাওয়া তোমার কাছে কষ্টকর হয়, তবে যদি সমর্থ হও তো ভূগর্ভে সুড়ঙ্গপথ খোঁজো অথবা আকাশে উঠবার একটি মই, এবং তাদের কাছে নিয়ে এস কোনো নিদর্শন! আর যদি আল্লাহ্ ইচ্ছা করতেন তবে তিনি তাদের সকলকে অবশ্য সৎপথে সমবেত করতেন, কাজেই তুমি অজ্ঞদের অন্তর্ভুক্ত হয়ো না।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@dcccxxv{কেবল তারাই সাড়া দেয় যারা শোনে। আর মৃতের সন্বন্ধে -- আল্লাহ্ তাদের পুনর্জীবিত করবেন, তখন তাঁর দিকেই তাদের ফিরিরে আনা হবে।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@dcccxxvi{আর তারা বলাবলি করে -- ''কেন তাঁর কাছে তাঁর প্রভুর নিকট থেকে কোনো নিদর্শন অবতীর্ণ হয় না?’’ তুমি বলো -- ''নিঃসন্দেহ আল্লাহ্ নিদর্শন অবতীর্ণ করতে সক্ষম, কিন্ত তাদের অধিকাংশই জানে না।’’\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@dcccxxvii{আর এমন কোনো পার্থিব জীব নেই এই পৃথিবীতে আর না আছে কোন উড়ন্ত প্রাণী যে উড়ে তার দুই ডানার সাহায্যে, যারা তোমাদের মতো এক সম্প্রদায়ের নয়। আমরা এই কিতাবে কোনো কিছুই ফেলে রাখি নি। অতঃপর তাদের প্রভুর দিকে তাদের একত্রিত করা হবে।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@dcccxxviii{আর যারা আমাদের নির্দেশসমূহে মিথ্যারোপ করে তারা বধির ও বোবা, ঘোর অন্ধকারে। আল্লাহ্ যাকে ইচ্ছা করেন তাকে তিনি বিপথে যেতে দেন, আর যাকে ইচ্ছা করেন তাকে তিনি স্থাপন করেন সহজ-সঠিক পথের উপরে।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@dcccxxix{বলো -- ''তোমরা কি ভেবে দেখেছ যে আল্লাহ্‌র শাস্তি তোমাদের উপরে যদি এসে পড়ে অথবা সেই ঘড়ি-ঘন্টা তোমাদের নিকটে উপস্থিত হয়, তোমরা কি আল্লাহ্ ছাড়া অপর কাউকে ডাকবে? যদি তোমরা সত্যবাদী হও।’’\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@dcccxxx{বরং তাঁকেই তোমরা ডাকবে, আর তিনি যদি ইচ্ছা করেন তবে দূর ক’রে দেবেন তা যার জন্য তাঁকে তোমরা ডেকে থাকো, আর তোমরা ভুলে যাবে তোমরা যে-সব অংশী দাঁড় করাও।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@dcccxxxi{আর আমরা নিশ্চয়ই তোমার পূর্বের সম্প্রদায়ের কাছে রসূল পাঠিয়েছিলাম, তারপর আমরা দুর্দশা ও বিপদপাত দ্বারা তাদের পাকড়াও করেছিলাম যেন তারা নিজেদের বিনত করে।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@dcccxxxii{তবে কেন, যখন আমাদের থেকে দুর্দশা তাদের উপরে এসেছিল, তারা বিনত করল না? পরন্ত, তাদের অন্তঃকরণ কঠিন হয়ে উঠল, আর শয়তান তাদের কাছে চিত্তাকর্ষক করে তুললো যে-সব তারা করে যাচ্ছিল।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@dcccxxxiii{তারপর যখন তারা ভুলে গেল যে বিষয়ে তাদের স্মরণ করিয়ে দেয়া হয়েছিল, তাদের জন্য আমরা খুলে দিলাম সব-কিছুর দরজা, যে পর্যন্ত না তারা মেতে উঠেছিল যা তাদের দেয়া হয়েছিল তাতে, আমরা তাদের পাকড়াও করলাম অতর্কিতে, কাজেই দেখো! তারা তখন হতভন্ব!\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@dcccxxxiv{এইভাবে শিকড় কাটা হয়েছিল সেইসব গোষ্ঠীর যারা অন্যায় করেছিল। আর ''সমস্ত প্রশংসা আল্লাহ্‌র জন্য, সৃষ্টজগতের প্রভু।’’\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@dcccxxxv{বলো -- ''তোমরা কি ভেবে দেখেছ, আল্লাহ্ যদি কেড়ে নেন তোমাদের শ্রবণশক্তি ও তোমাদের দৃষ্টিশক্তি, আর মোহর মেরে দেন তোমাদের হৃদয়ের উপরে, তবে আল্লাহ্ ব্যতীত কে উপাস্য আছে যে তোমাদের ঐগুলো ফিরিয়ে দেবে?’’ দেখো, কিরূপে আমরা নির্দেশসমূহ নানাভাবে বর্ণনা করি, এতদসত্ত্বেও তারা ফিরে যায়!\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@dcccxxxvi{বলো -- ''তোমাদের কি দৃষ্টিগোচর হয়েছে, -- তোমাদের উপরে যদি আল্লাহ্‌র শাস্তি এসে পড়ে অতর্কিতে অথবা প্রকাশ্যভাবে, তবে অত্যাচারিগোষ্ঠী ছাড়া আর কাউকে কি ধ্বংস করা হবে?’’\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@dcccxxxvii{আর কোনো বাণীবাহককে আমরা পাঠাই না সুসংবাদদাতারূপে ও সতর্ককারীরূপে ভিন্ন। অতএব যে কেউ ঈমান আনে ও সৎকাজ করে তাদের উপরে থাকবে না কোনো ভয়ভীতি, আর তারা করবে না অনুতাপ।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@dcccxxxviii{আর যারা আমাদের নির্দেশাবলীতে মিথ্যারোপ করেছে, শাস্তি তাদের পাকড়াও করবে যেহেতু তারা দুষ্কৃতি করে যাচ্ছিল।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@dcccxxxix{বলো -- ''আমি তোমাদের বলি না যে আমার কাছে আল্লাহ্‌র ধনভান্ডার রয়েছে, আর অদৃশ্য সন্বন্ধেও আমি জানি না, আর আমি তোমাদের বলি না যে আমি নিশ্চয়ই একজন ফিরিশ্‌তা, আমার কাছে যা প্রত্যাদিষ্ট হয় আমি শুধু তারই অনুসরণ করি।’’ বলো -- ''অন্ধ ও চক্ষুষ্মান কি একসমান? তোমরা কি তবু অনুধাবন করবে না?’’\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@dcccxl{আর এর দ্বারা তাদের সতর্ক করো যারা ভয় করে যে তাদের প্রভুর কাছে তাদের সমবেত করা হবে, তাদের জন্য তিনি ছাড়া কোনো অভিভাবক নেই আর কোনো সুপারিশকারীও নেই, অতএব তারা যেন ধর্মপরায়ণতা অবলন্বন করে।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@dcccxli{আর তাদের তাড়িয়ে দিও না যারা তাদের প্রভুকে ডাকে প্রাতে ও সন্ধ্যায়, তারা চায় তাঁরই শুভ মুখ। তোমার উপরে তাদের হিসাবপত্রের কোন দায়দায়িত্ব নেই, আর তোমার হিসেবপত্রের কোনো দায়দায়িত্ব তাদের উপরে নেই, কাজেই যদি তাদের তাড়িয়ে দাও তবে তুমি হবে অন্যায়কারীদের অন্তর্ভুক্ত।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@dcccxlii{আর এইভাবে আমরা তাদের একদলকে শাসন করি অন্য দলের দ্বারা, তার ফলে তারা বলে -- ''এরাই কি তারা যাদের প্রতি আল্লাহ্ অনুগ্রহ করলেন আমাদের মধ্যে থেকে?’’ আল্লাহ্ কি ভালো জানেন না কৃতজ্ঞদের?\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@dcccxliii{আর যারা আমাদের আয়াতসমূহে ঈমান এনেছে তারা যখন তোমার কাছে আসে তখন বলো -- ''সালামুন 'আলাইকুম।’’ তোমাদের প্রভু তাঁর নিজের উপরে কর্তব্য ঠাওরেছেন করুণা, সেজন্য তোমাদের মধ্যে যে অজ্ঞানতাবশতঃ পাপকার্য করে, অতঃপর তার পরে ফেরে ও সৎকাজ করে, তবে তো তিনি পরিত্রাণকারী, অফুরন্ত ফলদাতা।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@dcccxliv{আর এইভাবে আমরা আয়াতসমূহ বিশদভাবে বর্ণনা করি, আর যেন অপরাধীদের পথ স্পষ্ট প্রতীয়মান হয়।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@dcccxlv{বলো -- ''আমাকে নিশ্চয়ই নিষেধ করা হয়েছে আল্লাহ্ ব্যতীত তাদের উপাসনা করতে যাদের তোমরা পূজা-অর্চনা করো।’’ বলো -- ''আমি তোমাদের খেয়ালখুশির অনুসরণ করি না, কেননা তাহলে আমি নিশ্চয়ই বিপথে যাব, আর আমি সৎপথপ্রাপ্তদের অন্তর্ভুক্ত থাকবো না।’’\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@dcccxlvi{বলো -- ''আমি নিশ্চয়ই আমার প্রভুর কাছ থেকে স্পষ্ট প্রমাণের উপরে, অথচ তোমরা তাতে মিথ্যারোপ করেছ। আমার কাছে তা নেই যা তোমরা তাড়াতাড়ি ঘটাতে চাচ্ছ। সিদ্ধান্ত তো আল্লাহ্ ছাড়া কারোর নয়। তিনি সত্য বর্ণনা করেন, আর মীমাংসাকারীদের মধ্যে তিনিই শ্রেষ্ঠ।’’\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@dcccxlvii{বলো -- ''আমার কাছে যদি তা থাকতো যা তোমরা সত্বর ঘটাতে চাও তাহলে নিশ্চয়ই ব্যাপারটির মীমাংসা হয়ে যেতো আমার মধ্যে ও তোমাদের মধ্যে। আর আল্লাহ্ ভালো জানেন অন্যায়কারীদের।’’\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@dcccxlviii{আর তাঁরই কাছে অদৃশ্যের চাবিকাঠি রয়েছে, কেউ তা জানে না তিনি ছাড়া। আর তিনি জানেন যা আছে স্থলদেশে ও সমুদ্রে। আর গাছের এমন একটি পাতাও পড়ে না যা তিনি জানেন না, আর নেই একটি শস্যকণাও মাটির অন্ধকারে, আর নেই কোনো তরতাজা জিনিস অথবা শুকনোবস্তু -- যা রয়েছে সুস্পষ্ট কিতাবে।\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@dcccxlix{আর তিনিই সেইজন যিনি তোমাদের গ্রহণ করেন রাত্রিকালে, আর তিনি জানেন তোমরা যা অর্জন করো দিনের বেলায়, তারপর এতে তিনি তোমাদের জাগরিত করেন যেন নির্ধারিত কাল পূর্ণ হয়। তারপর তাঁর কাছেই তোমাদের প্রত্যাবর্তন, তখন তিনি তোমাদের জানিয়ে দেবেন যা তোমরা করতে।\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@dcccl{আর তিনিই প্রভাবশালী তাঁর দাসদের উপরে, আর তিনিই তোমাদের উপরে রক্ষক প্রেরণ করেন। আবশেষে যখন তোমাদের কারো কাছে মৃত্যু আসে তখন আমাদের দূতরা তাকে গ্রহণ করে, আর তারা অবহেলা করে না।\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@dcccli{অতঃপর তাদের আনা হয় তাদের প্রকৃত মনিব আল্লাহ্‌র কাছে। কর্তৃত্ব কি তাঁরই নয়? আর তিনি হিসাবরক্ষকদের মধ্যে সর্বাপেক্ষা তৎপর।\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@dccclii{বলো -- ''কে তোমাদের উদ্ধার করেন স্থলদেশের ও সমুদ্রের অন্ধকার থেকে তোমরা তাঁকে ডাকো কাতরভাবে ও মনে মনে -- 'যদি তিনি এ থেকে আমাদের উদ্ধার করেন তবে নিশ্চয়ই আমরা হবো কৃতজ্ঞদের মধ্যেকার’?’’\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@dcccliii{বলো -- ''আল্লাহ্‌ই তোমাদের উদ্ধার করেন এ-সব থেকে আর প্রত্যেকটি দুঃখকষ্ট থেকে, তথাপি তোমরা অংশীদার দাঁড় করাও।’’\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@dcccliv{বলো -- ''তিনি ক্ষমতাশীল তোমাদের উপরে শাস্তি আরোপ করতে তোমাদের উপর থেকে অথবা তোমাদের পায়ের নিচে থেকে, অথবা তোমাদের দিশাহারা করতে পারেন দলাদলি করিয়ে, আর তোমাদের একদলকে ভোগ করাতে পারেন অন্য দলের নিপীড়ন।’’ দেখো, কিরূপে আমরা নির্দেশসমূহ নানাভাবে বর্ণনা করি যেন তারা বুঝতে পারে!\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@dccclv{আর তোমার সম্প্রদায় এতে মিথ্যারোপ করেছে, অথচ এইটিই সত্য। বলো -- ''আমি তোমাদের জন্য উকিল নই।\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@dccclvi{''প্রত্যেক ভবিষ্যদ্বাণীর জন্য নির্ধারিত কাল রয়েছে, আর শীঘ্রই তোমরা জানতে পারবে।’’\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@dccclvii{আর তুমি যখন দেখতে পাবে তাদের যারা আমাদের আয়াতসমূহে নিরর্থক তর্ক করে তখন তাদের থেকে সরে যাবে যে পর্যন্ত না তারা অন্য কোনো প্রসঙ্গে প্রবেশ করে। আর যদি শয়তান তোমাকে ভুলিয়ে দেয় তবে মনে পড়ার পরে বসে থেকো না অন্যায়কারীদের দলের সঙ্গে।\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@dccclviii{আর যারা ধর্মপরায়ণতা অবলন্বন করে তাদের উপরে ওদের হিসাবপত্রের কোনো কিছুতে দায়িত্ব নেই, তবে স্মরণ করিয়ে দেয়া, যাতে ওরাও ধর্মপরায়ণতা অবলন্বন করে।\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@dccclix{আর তাদের বর্জন করো যারা তাদের ধর্মকে খেলা ও কৌতুকরূপে গ্রহণ করেছে, আর এ দ্বারা স্মরণ করিয়ে দাও পাছে কোনো প্রাণ বিধবস্ত হয়ে যায় যা সে অর্জন করে তার দ্বারা, তার জন্য আল্লাহ্‌কে ছেড়ে দিয়ে অন্য কোনো অভিভাবক থাকবে না, আর না কোনো সুপারিশকারী, আর যদি তারা খেসারত দেয় সবরকমের খেসারতি, তবুও তাদের থেকে তা গ্রহণ করা হবে না। এরাই তারা যাদের ধ্বংস করা হবে তারা যা অর্জন করেছে সেজন্য, তাদের জন্য পানীয় হচ্ছে ফুটন্ত জল থেকে, আর হচ্ছে এক ব্যথাদায়ক শাস্তি যেহেতু তারা অবিশ্বাস পোষণ করে চলতো।\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@dccclx{বলো -- ''আমরা কি আল্লাহ্ ছাড়া তাকে ডাকবো যে আমাদের উপকার করতে পারে না এবং আমাদের অপকারও করতে পারে না, আর আমরা কি আমাদের গোড়ালির উপরে মোড় ফিরিয়ে নেব আল্লাহ্ আমাদের পথ দেখিয়ে দেবার পরে, -- তার মতো যাকে শয়তানরা হীন প্রবৃত্তিতে উসকানি দিয়েছে দুনিয়াতে হয়রানিতে ফেলে, তার সহচরগণ রয়েছে যারা তাকে আহ্বান করছে ধর্মপথের দিকে -- 'আমাদের দিকে এসো’?’’ বলো -- ''নিঃসন্দেহ আল্লাহ্‌র পথনির্দেশ -- এই হচ্ছে পথনির্দেশ। আর আমাদের আদেশ দেওয়া হয়েছে যেন আমরা আ‌ত্মসমর্পণ করি বিশ্বজগতের প্রভুর কাছে, --\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@dccclxi{''আর নামায প্রতিষ্ঠিত রাখতে ও তাঁকে ভয়ভক্তি করতে, আর তিনিই সেইজন যাঁর কাছে তোমাদের সমবেত করা হবে।’’\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@dccclxii{আর তিনিই সেইজন যিনি মহাকাশমন্ডল ও পৃথিবী সৃষ্টি করেছেন সত্যের সাথে। আর যখন তিনি বলেন -- ''হও’’, তখন হয়ে যায়। তাঁর কথাই সত্য। আর তাঁরই সার্বভৌম কর্তৃত্ব সেদিনকার যেদিন শিংগায় ফুৎকার দেয়া হবে। অদৃশ্য ও প্রকাশ্য বিষয়ে সর্বজ্ঞাতা, আর তিনি পরমজ্ঞানী, পূর্ণ-ওয়াকিফহাল।\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@dccclxiii{আর স্মরণ করো! ইব্রাহীম বলেছিলেন তাঁর পিতৃ-পুরুষ আষারকে -- ''তুমি কি মূর্তিদের উপাস্যরূপে গ্রহণ করেছ? নিঃসন্দেহ আমি তোমাকে ও তোমার গোষ্ঠীকে স্পষ্ট ভ্রান্তির মধ্যে দেখতে পাচ্ছি।’’\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@dccclxiv{আর এইভাবে আমরা ইব্রাহীমকে দেখিয়েছিলাম মহাকাশমন্ডল ও পৃথিবীর সার্বভেম রাজত্ব যাতে তিনি হতে পারেন দৃঢ়প্রত্যয়ীদের অন্তর্ভুক্ত।\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@dccclxv{তারপর রাত্রি যখন তাঁর উপরে অন্ধকার ছেয়ে আনলো তখন তিনি একটি তারা দেখতে পেলেন, তিনি বললেন -- ''এইটি আমার প্রভু!’’ তারপর যখন তা অস্ত গেল তখন তিনি বললেন -- ''আমি অস্তগামীদের ভালোবাসি না।’’\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@dccclxvi{অতঃপর যখন তিনি চন্দ্রকে উদিত হতে দেখলেন তখন বললেন -- ''এইটি আমার প্রভু!’’ কিন্ত যখন তা অস্ত গেল তখন তিনি বললেন -- ''যদি আমার প্রভু আমাকে পথ-প্রদর্শন না করতেন তাহলে আমি অবশ্যই হয়ে পড়তাম পথভ্রষ্টদের দলভুক্ত।\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@dccclxvii{তারপর যখন তিনি দেখলেন সৃর্য উদয় হচ্ছে তখন তিনি বললেন -- ''এইটি আমার প্রভু, এটি সব চাইতে বড়!’’ কিন্ত যখন এটিও অস্ত গেল তখন তিনি বললেন -- ''হে আমার সম্প্রদায়, তোমরা যাদের শরিক কর তা থেকে আমি অবশ্যই মুক্ত।\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@dccclxviii{''নিঃসন্দেহ আমি তাঁর দিকে আমার মুখ ফেরাচ্ছি একনিষ্ঠভাবে যিনি মহাকাশমন্ডল ও পৃথিবী সৃষ্টি করেছেন, আর আমি বহু- খোদাবাদীদের অন্তর্ভুক্ত নই।’’\qt@no{(79)}}
\qt@newcmd\qurantrans@bn@dccclxix{আর তাঁর লোকেরা তাঁর সঙ্গে হুজ্জৎ শুরু করল। তিনি বললেন -- ''তোমরা কি আমার সঙ্গে আল্লাহ্ সন্বন্ধে হুজ্জৎ করছো, অথচ তিনি আমাকে নিশ্চয়ই সৎপথ দেখিয়েছেন? আর আমি তাদের একটুও ভয় করি না যাদের তোমরা তাঁর সাথে শরিক করেছ, যদি না আমার প্রভু অন্যবিধ ইচ্ছা করেন। আমার প্রভু সব-কিছুর উপরেই জ্ঞানে আধিপত্য রাখেন। তবু কি তোমরা অনুধাবন করবে না?\qt@no{(80)}}
\qt@newcmd\qurantrans@bn@dccclxx{''আর কেমন ক’রে আমি ভয় করবো তাদের যাদের তোমরা শরিক করো, অথচ তোমরা ভয় করো না যখন আল্লাহ্‌র সঙ্গে তোমরা অংশী দাঁড় করাতে যাও যার জন্য তিনি তোমাদের কাছে কোনো সনদ পাঠান নি? সুতরাং এই দুই দলের কারা নিরাপত্তা সন্বন্ধে বেশি হক্‌দার? যদি তোমরা জেনে থাকো।’’\qt@no{(81)}}
\qt@newcmd\qurantrans@bn@dccclxxi{যারা আল্লাহ্‌তে ঈমান এনেছে আর যারা তাদের ঈমানকে অন্যায় আচরণ দ্বারা মাখামাখি করে নি, তারাই -- এদেরই প্রাপ্য নিরাপত্তা, আর এরাই হচ্ছে সুপথে চালিত।\qt@no{(82)}}
\qt@newcmd\qurantrans@bn@dccclxxii{আর এইগুলো হচ্ছে আমাদের যুক্তিতর্ক যা আমরা ইব্রাহীমকে তাঁর লোকদের বিরুদ্ধে দিয়েছিলাম। আমরা যাকে ইচ্ছা করি বহুস্তর উন্নত করি। নিঃসন্দেহ তোমার প্রভু পরমজ্ঞানী, সর্বজ্ঞাতা।\qt@no{(83)}}
\qt@newcmd\qurantrans@bn@dccclxxiii{আর আমরা তাঁকে দিয়েছিলাম ইসহাক ও ইয়াকুব। প্রত্যেককে আমরা সৎপথ দেখিয়েছিলাম, আর নূহকে পথ দেখিয়েছিলাম এর আগে, আর তাঁর বংশধরদের মধ্য থেকে দাউদ ও সুলাইমান আর আইয়ূব ও ইউসুফ আর মূসা ও হারূন। আর এইভাবে আমরা পুরস্কার প্রদান করি সৎকর্মশীলদের।\qt@no{(84)}}
\qt@newcmd\qurantrans@bn@dccclxxiv{আর যাকারিয়া ও ইয়াহ্‌য়া আর ঈসা ও ইলয়াস। প্রতেকেই হয়েছিলেন পুণ্যকর্মাদের অন্তর্ভুক্ত।\qt@no{(85)}}
\qt@newcmd\qurantrans@bn@dccclxxv{আর ইসমাইল, আর ইয়াসাআ ও ইউনুস, আর লূত। আর সবাইকে আমরা মানবগোষ্ঠীর উপরে শ্রেষ্ঠত্ব দিয়েছিলাম।\qt@no{(86)}}
\qt@newcmd\qurantrans@bn@dccclxxvi{আর তাঁদের পিতাদের, আর তাঁদের বংশধরদের, আর তাঁদের ভাইদের মধ্যে থেকে, আর আমরা তাদের নির্বাচিত করেছিলাম এবং তাদের পরিচালিত করেছিলাম সহজ-সঠিক পথের দিকে।\qt@no{(87)}}
\qt@newcmd\qurantrans@bn@dccclxxvii{এই হচ্ছে আল্লাহ্‌র পথনির্দেশ, এর দ্বারা তিনি পথ দেখান তাঁর বান্দাদের মধ্যের যাকে ইচ্ছে করেন। আর যদি তাঁরা অংশী দাঁড় করতেন তবে তাঁরা যা করছিলেন সে-সব নিশ্চয়ই তাঁদের জন্য বৃথা হতো।\qt@no{(88)}}
\qt@newcmd\qurantrans@bn@dccclxxviii{এরাঁই তাঁরা যাঁদের আমরা দিয়েছিলাম কিতাব, আর কর্তৃত্ব, আর নবুওৎ; কাজেই এরা যদি এ-সবে অবিশ্বাস পোষণ করে তবে আমরা নিশ্চয়ই এর তত্ত্বাবধানের ভার দিয়েছি এমন এক সম্প্রদায়ের উপরে যারা এতে অবিশ্বাসী হবে না।\qt@no{(89)}}
\qt@newcmd\qurantrans@bn@dccclxxix{এরাঁই তাঁরা যাঁদের আল্লাহ্ সৎপথে পরিচালিত করেছেন, সুতরাং তুমি তাঁদের পথনির্দেশের অনুসরণ করো। বলো -- ''আমি তোমাদের কাছে এর জন্য কোনো প্রতিদান চাই না। এতো নিঃসন্দেহ মানবগোষ্ঠীর কাছে স্মারকই মাত্র।’’\qt@no{(90)}}
\qt@newcmd\qurantrans@bn@dccclxxx{আর তারা আল্লাহ্‌র সম্মান করে না তাঁর যথাযোগ্য মর্যাদার সাথে যখন তারা বলে -- ''আল্লাহ্ কোনো মানুষের কাছে কিছুই অবতারণ করেন নি।’’ বলো -- ''কে অবতারণ করেছিলেন গ্রন্থখানা যা নিয়ে মূসা এসেছিলেন -- মানুষের জন্য আলোক ও পথনির্দেশরূপে, যা তোমরা কাগজপত্রে তুলে তা প্রকাশ করো ও বেশির ভাগ গোপন করো, আর তোমাদের শেখানো হয়েছিল যা তোমরা জানতে না, -- তোমরা আর তোমাদের পিতৃপুরুষরাও না?’’ বলো -- ''আল্লাহ্‌।’’ অতঃপর তাদের ছেড়ে দাও তাদের বাজে কথায় খেলাধুলো করতে।\qt@no{(91)}}
\qt@newcmd\qurantrans@bn@dccclxxxi{আর এই হচ্ছে কিতাব যা আমরা অবতারণ করেছি কল্যাণময় ক’রে, যা এর পূর্বেকার তার সত্য-সমর্থকরূপে, আর যেন তুমি সতর্ক করতে পারো নগর জননীকে আর যারা এর চতুর্দিকে রয়েছে তাদের। আর যারা পরকালে বিশ্বাস করে তারা এতে বিশ্বাস করে, আর তারা তাদের নামাযের হেফাজত করে চলে।\qt@no{(92)}}
\qt@newcmd\qurantrans@bn@dccclxxxii{আর কে তার চাইতে বেশি অন্যায়কারী যে আল্লাহ্ সন্বন্ধে মিথ্যা রচনা করে, অথবা বলে -- 'আমার কাছে প্রত্যাদেশ এসেছে’, অথচ তার কাছে কোনো-প্রকার প্রত্যাদেশ আসে নি, আর যে বলে -- 'আমি অবতারণ করতে পারি যা আল্লাহ্ অবতারণ করেছেন তার মতো জিনিস’? আর তুমি যদি দেখতে পেতে যখন অন্যায়কারীরা মৃত্যু-যন্ত্রণায় থাকবে আর ফিরিশ্‌তারা তাদের হাত বাড়াবে -- ''বের করো তোমাদের অন্তরা‌ত্মা! আর তোমাদের দেয়া হবে লাঞ্ছনাপূর্ণ শাস্তি যেহেতু তোমরা আল্লাহ্‌র বিরুদ্ধে বলে চলেছিলে সততার সীমা ছাড়িয়ে, আর তোমরা তাঁর আয়াতসমূহে অহংকার পোষণ করতে।’’\qt@no{(93)}}
\qt@newcmd\qurantrans@bn@dccclxxxiii{আর তোমরা নিশ্চয়ই আমাদের কাছে এসেছ একে একে যেমন তোমাদের আমরা প্রথমবার সৃষ্টি করেছিলাম, আর যা তোমাদের দিয়েছিলাম তা তোমরা তোমাদের পিঠের পেছনে ফেলে এসেছ, আর তোমাদের সঙ্গে তোমাদের সুপারিশকারীদের দেখছি না যাদের তোমরা দাবি করতে যে তারা তোমাদের মধ্যে নিশ্চিত অংশীদার। নিশ্চয় তোমাদের মধ্যেকার বন্ধন ছিন্ন হয়েছে আর তোমাদের থেকে উধাও হয়েছে যা তোমরা দাবি করতে।\qt@no{(94)}}
\qt@newcmd\qurantrans@bn@dccclxxxiv{নিঃসন্দেহ আল্লাহ্ -- তিনি শস্যবীজ ও আটিরঁ অংকুরোদগমকারী। তিনি মৃতদের থেকে জীবিতদের উদগত করেন, আবার তিনিই মৃতদের উদগমকারী জীবিতদের থেকে। এই তো আল্লাহ্‌! সুতরাং কোথা থেকে তোমরা ফিরে যাবে?\qt@no{(95)}}
\qt@newcmd\qurantrans@bn@dccclxxxv{তিনিই উষার ঊন্মেষকারী, আর তিনি রাত্রিকে সৃষ্টি করেছেন বিশ্রামের জন্য, আর সূর্যকে এবং চন্দ্রকে হিসাবের জন্য। এই-ই মহাশক্তিশালী সর্বজ্ঞাতার বিধান।\qt@no{(96)}}
\qt@newcmd\qurantrans@bn@dccclxxxvi{আর তিনিই সেইজন যিনি তোমাদের জন্য সৃষ্টি করেছেন তারকারাজি, যেন তোমরা তাদের সাহায্যে স্থলের ও সমুদ্রের অন্ধকারে পথ চলতে পারো। আমরা নিশ্চয়ই নিদর্শনসমূহ বিশদভাবে বিবৃত করেছি এমন লোকের জন্য যারা জ্ঞান রাখে।\qt@no{(97)}}
\qt@newcmd\qurantrans@bn@dccclxxxvii{আর তিনিই সেইজন যিনি তোমাদের উদ্ভব করেছেন একই নফস থেকে, এবং রয়েছে এক বিশ্রাম-স্থল আর এক পাত্রাধার। আমরা নিশ্চয়ই নিদর্শনগুলো ব্যাখ্যা করেছি তেমন লোকের জন্য যারা হৃদয়ম করে।\qt@no{(98)}}
\qt@newcmd\qurantrans@bn@dccclxxxviii{আর তিনিই সেইজন যিনি আকাশ থেকে নামান বৃষ্টি, তখন তার দ্বারা আমরা উদ্‌গত করি সব রকমের চারা গাছ, তারপর তা থেকে উদগম করি সবুজ গাছপালা, যা থেকে উদ্ভব করি থোকা থোকা শস্য, আর খেজুর গাছ থেকে -- তার মাথি থেকে ঝুলন্ত কাঁদি, আর আঙ্গুরের ও জলপাইয়ের ও ডালিমের বাগান -- এক রকমের ও সামস্যবিহীন। তোমরা তাকিয়ে দেখো তার ফলের দিকে যখন তা ফলবান হয় ও তার পেকে ওঠাতে। নিঃসন্দেহ এগুলোতে রয়েছে নিদর্শনাবলী তেমন লোকের জন্য যারা বিশ্বাস স্থাপন করে।\qt@no{(99)}}
\qt@newcmd\qurantrans@bn@dccclxxxix{তথাপি তারা আল্লাহ্‌র সঙ্গে শরিক করে জিনকে, যদিও তিনিই ওদের সৃষ্টি করেছেন, আর তারা কোনো জ্ঞান ছাড়াই তাঁতে আরোপ করে পুত্র ও কন্যাদের। তাঁরই সব মহিমা! আর তারা যা আরোপ করে সে-সব থেকে তিনি বহু ঊর্ধ্বে।\qt@no{(100)}}
\qt@newcmd\qurantrans@bn@dcccxc{মহাকাশমন্ডল ও পৃথিবীর আদিস্রষ্টা! কোথা থেকে তাঁর সন্তান হবে যখন তাঁর জন্য কোনো সহচরী নেই। আর তিনিই সব- কিছু সৃষ্টি করেছেন, আর তিনিই তো সব-কিছু সন্বন্ধে সর্বজ্ঞাতা।\qt@no{(101)}}
\qt@newcmd\qurantrans@bn@dcccxci{এই হচ্ছেন আল্লাহ্‌, তোমাদের প্রভু! তিনি ছাড়া অন্য উপাস্য নেই, তিনি সব-কিছুরই সৃষ্টিকর্তা, কাজেই তাঁরই উপাসনা করো, আর তিনি সব বিষয়ের উপরে কর্ণধার।\qt@no{(102)}}
\qt@newcmd\qurantrans@bn@dcccxcii{দৃষ্টি তাঁর ইয়ত্তা পায় না, কিন্ত তিনি দৃষ্টিতে পরিদর্শন করেন। আর তিনিই সুক্ষদর্শী, পূর্ণ ওয়াকিফহাল।\qt@no{(103)}}
\qt@newcmd\qurantrans@bn@dcccxciii{''নিশ্চয়ই তোমাদের কাছে তোমাদের প্রভুর কাছ থেকে জ্ঞান দৃষ্টি এসেছে, কাজেই যে কেউ দেখতে পায়, সেটি তার নিজের আ‌ত্মার জন্যে, আর যে কেউ অন্ধ হবে, সেটি তার বিরুদ্ধে যাবে। আর আমি তোমাদের উপরে তত্ত্বাবধায়ক নই।’’\qt@no{(104)}}
\qt@newcmd\qurantrans@bn@dcccxciv{আর এইভাবে আমরা নির্দেশাবলী নানাভাবে বর্ণনা করি, আর যেন তারা বলতে পারে,''তুমি পাঠ করেছ’’, আর যেন আমরা এটি সুস্পষ্ট করতে পারি তেমন লোকদের কাছে যারা জানে।\qt@no{(105)}}
\qt@newcmd\qurantrans@bn@dcccxcv{তুমি তার অনুসরণ করো যা তোমার কাছে তোমার প্রভুর কাছ থেকে প্রত্যাদেশ দেওয়া হয়েছে -- 'তিনি ছাড়া অন্য উপাস্য নেই’, আর সরে দাঁড়াও বহুখোদাবাদীদের থেকে।\qt@no{(106)}}
\qt@newcmd\qurantrans@bn@dcccxcvi{আর যদি আল্লাহ্ ইচ্ছে করতেন তবে তারা শরিক করতো না। আর আমরা তোমাকে তাদের উপরে রক্ষাকারীরূপে নিযুক্ত করি নি, আর তুমি তাদের উপরে কার্যনির্বাহকও নও।\qt@no{(107)}}
\qt@newcmd\qurantrans@bn@dcccxcvii{আর তারা আল্লাহ্‌কে ছেড়ে দিয়ে যাদের উপাসনা করে তাদের গালি দিও না, পাছে তারাও শত্রুতাবশতঃ আল্লাহ্‌কে গালি দেয় জ্ঞানহীনতার জন্য। এইভাবে প্রত্যেক সম্প্রদায়ের জন্য তাদের ক্রিয়াকলাপ আমরা চিত্তাকর্ষক করেছি। তারপর তাদের প্রভুর কাছেই হচ্ছে তাদের প্রত্যাবর্তন, তখন তিনি তাদের জানিয়ে দেবেন কি তারা করতো।\qt@no{(108)}}
\qt@newcmd\qurantrans@bn@dcccxcviii{আর তারা আল্লাহ্‌র নামে কসম খায় তাদের জোরালো শপথের দ্বারা যে যদি কোনো নিদর্শন তাদের কাছে আসতো তবে তারা নিশ্চয়ই তাতে বিশ্বাস করতো। বলো -- ''নিঃসন্দেহ নিদর্শনসমূহ আল্লাহ্‌র কাছেই রয়েছে। আর কেমন ক’রে তোমাদের জানানো যাবে যে যখন তা আসবে তারা বিশ্বাস করবে না?’’\qt@no{(109)}}
\qt@newcmd\qurantrans@bn@dcccxcix{আর আমরাও তাদের অন্তঃকরণ ও তাদের দৃষ্টি পাল্টে দেবো যেমন তারা প্রথমবার এতে বিশ্বাস করে নি, আর তাদের ছেড়ে দেবো তাদের অবাধ্যতার মধ্যে উদ্‌ভ্রান্ত ভাবে ঘুরে বেড়াতে।\qt@no{(110)}}
\qt@newcmd\qurantrans@bn@cm{আর যদিবা আমরা তাদের প্রতি পাঠাতাম ফিরিশ্‌তাদের, আর মড়াও যদি তাদের সঙ্গে কথা বলতো, আর সব-কিছুই যদি তাদের সামনে একত্রে হাজির করতাম, তবুও তারা বিশ্বাস করতো না, যদি না আল্লাহ্ ইচ্ছা করতেন, কিন্ত তাদের অধিকাংশই অজ্ঞতা পোষণ করে।\qt@no{(111)}}
\qt@newcmd\qurantrans@bn@cmi{আর এইভাবে আমরা প্রত্যেক নবীর জন্যে সৃষ্টি করেছি শত্রু -- মানুষ ও জিন-এর মধ্যেকার শয়তানদের, তারা একে অন্যকে প্ররোচিত করে চমক্‌প্রদ বাক্যদ্বারা প্রতারণার উদ্দেশ্যে। আর তোমার প্রভু যদি ইচ্ছা করতেন তবে তারা এ করতো না। অতএব ছেড়ে দাও তাদের আর তারা যা মিথ্যা রচনা করে তা, --\qt@no{(112)}}
\qt@newcmd\qurantrans@bn@cmii{আর যারা পরকালে বিশ্বাস করে না তাদের আন্তরা‌ত্মা যেন এদিকে ঝুঁকে পড়ে, আর যেন তারা এতে খুশিও হয়, আর যেন তারা যা করে চলেছে তাতে যেন মশগুল থাকে।\qt@no{(113)}}
\qt@newcmd\qurantrans@bn@cmiii{''তবে কি আল্লাহ্ ছাড়া আমি অন্যকে বিচারক খুজঁবো যখন তিনিই সেইজন যিনি তোমাদের কাছে অবতারণ করেছেন এ কিতাব, বিশদভাবে ব্যাখ্যাকৃত?’’ আর যাদের আমরা গ্রন্থ দিয়েছিলাম তারা জানে যে এটি অবতীর্ণ হয়েছে তোমার প্রভুর নিকট থেকে সত্যের সাথে, অতএব তুমি সন্দিহানদের অন্তর্ভুক্ত হয়ো না।\qt@no{(114)}}
\qt@newcmd\qurantrans@bn@cmiv{আর তোমার প্রভুর বাণী সম্পূর্ণ হয়েছে সত্যে ও ন্যায়ে। তাঁর বাণী কেউ বদলাতে পারে না, আর তিনিই সর্বশ্রোতা, সর্বজ্ঞাতা।\qt@no{(115)}}
\qt@newcmd\qurantrans@bn@cmv{আর যদি তুমি দুনিয়ার বাসিন্দাদের অধিকাংশের আজ্ঞাপালন করো তবে তারা তোমাকে আল্লাহ্‌র পথ থেকে বিচ্যুত করবে। তারা তো শুধু অসার বিষয়ের অনুসরণ করে, আর তারা তো শুধু আন্দাজের উপরেই চলে।\qt@no{(116)}}
\qt@newcmd\qurantrans@bn@cmvi{নিঃসন্দেহ তোমার প্রভু -- তিনি ভালো জানেন কে তাঁর পথ থেকে বিপথে যায়, আর তিনি ভালো জানেন যারা সুপথে চালিত তাদের।\qt@no{(117)}}
\qt@newcmd\qurantrans@bn@cmvii{কাজেই আহার করো যার উপরে আল্লাহ্‌র নাম উল্লেখ করা হয়েছে, -- যদি তোমরা তাঁর নির্দেশসমূহে বিশ্বাসী হও।\qt@no{(118)}}
\qt@newcmd\qurantrans@bn@cmviii{আর তোমাদের কি হয়েছে যে তোমরা তা খাবে না যার উপরে আল্লাহ্‌র নাম উল্লেখ করা হয়েছে, আর তিনি ইতিপূর্বে তোমাদের জন্য বিশদভাবে বর্ণনা করেছেন যা তোমাদের জন্য তিনি নিষেধ করেছেন, তবে যতটাতে তোমরা বাধ্য হও তা ব্যতীত? আর নিঃসন্দেহ অনেকেই বিপথে চালিত করে তাদের খেয়াল-খুশির দ্বারা জ্ঞানহীনতা বশতঃ। নিঃসন্দেহ তোমার প্রভু -- তিনি ভলো জানেন সীমা-লঙ্ঘনকারীদের।\qt@no{(119)}}
\qt@newcmd\qurantrans@bn@cmix{আর পরিহার করো প্রকাশ্য পাপ ও তার গোপনীয়গুলোও। নিঃসন্দেহ যারা পাপ অর্জন করে তাদের প্রতিফল দেওয়া হবে তারা যা উপার্জন করে থাকে তার দ্বারা।\qt@no{(120)}}
\qt@newcmd\qurantrans@bn@cmx{আর আহার করো না যাতে আল্লাহ্‌র নাম উল্লেখ করা হয় নি, কারণ নিঃসন্দেহ এটি নিশ্চিত পাপাচার। আর নিঃসন্দেহ শয়তানরা তাদের বন্ধুবান্ধদের প্ররোচনা দেয় তোমাদের সঙ্গে বিবাদ করতে, আর তোমরা যদি তাদের আজ্ঞাপালন করো তবে নিঃসন্দেহ তোমরা নিশ্চয়ই বহুখোদাবাদী হবে।\qt@no{(121)}}
\qt@newcmd\qurantrans@bn@cmxi{যিনি ছিলেন মৃত, তারপর তাঁকে আমরা জীবন্ত করলাম, আর তাঁর জন্য তৈরি করলাম আলো যার সাহায্যে তিনি মানুষদের মধ্যে চলাফেরা করেন, -- তিনি কি তার মতো যার তুলনা হচ্ছে এমন এক লোক যে থাকে অন্ধকারে যা থেকে তার বেরুনোর পথ নেই? এইভাবে অবিশ্বাসীদের জন্য আমরা চিত্তাকর্ষক করে থাকি যা তারা করতে থাকে।\qt@no{(122)}}
\qt@newcmd\qurantrans@bn@cmxii{আর এইভাবে আমরা প্রত্যেক জনপদে সেখানকার অপরাধীদের বানিয়েছি সর্দার, যেন তারা তার মধ্যে চক্রান্ত ক’রে চলে, আর তারা চক্রান্ত করে না শুধু তাদের আপন অন্তরা‌ত্মার বিরুদ্ধে ছাড়া, আর তারা বুঝে না।\qt@no{(123)}}
\qt@newcmd\qurantrans@bn@cmxiii{আর যখন তাদের কাছে কোনো নিদর্শন আসে, তারা বলে -- ''আমরা কখনো বিশ্বাস করবো না যে পর্যন্ত না আল্লাহ্‌র রসূলদের যা দেয়া হয়েছে তার অনুরূপ কিছু আমাদেরও দেওয়া হয়।’’ আল্লাহ্‌ই ভালো জানেন কোথায় তাঁর প্রত্যাদেশের ভারার্পণ করবেন। যারা অপরাধ করে চলে তাদের উপরে শীঘ্রই ঘটবে আল্লাহ্‌র তরফ থেকে লাঞ্ছনা এবং কঠোর শাস্তি -- তারা যা চক্রান্ত করে চলেছে সেজন্য।\qt@no{(124)}}
\qt@newcmd\qurantrans@bn@cmxiv{অতএব আল্লাহ্ যদি কাউকে ইচ্ছা করেন যে তিনি তাকে ধর্মপথে পরিচালন করবেন, তবে তার বক্ষ তিনি ইসলামের প্রতি প্রশস্ত করবেন, আর যার জন্য তিনি ইচ্ছা করেন যে তিনি তাকে পথভ্রষ্টতায় ফেলে রাখবেন, তার বক্ষকে তিনি আটোঁসাঁটো ও সংকীর্ণ করে ফেলেন যেন সে আকাশে আরোহণ করে চলেছে। এইভাবে আল্লাহ্ কলুষতা আনয়ন করেন তাদের উপরে যারা বিশ্বাস স্থাপন করে না।\qt@no{(125)}}
\qt@newcmd\qurantrans@bn@cmxv{আর এই হচ্ছে তোমার প্রভুর পথ -- সহজ-সঠিক। আমরা নিশ্চয় নির্দেশসমূহ বিশদভাবে ব্যাখ্যা করেছি তেমন লোকের জন্য যারা মনোনিবেশ করে।\qt@no{(126)}}
\qt@newcmd\qurantrans@bn@cmxvi{তাদের জন্য রয়েছে শান্তিনিকেতন তাদের প্রভুর কাছে, আর তারা যা করে থাকে সেজন্য তিনি তাদের রক্ষাকারী বন্ধু।\qt@no{(127)}}
\qt@newcmd\qurantrans@bn@cmxvii{আর যেদিন তিনি তাদের সবাইকে একত্র করবেন -- ''হে জিন সম্প্রদায়! তোমরা মানুষদের অনেককেই নিয়ে গিয়েছিলে।’’ আর মানবগোষ্ঠীর মধ্যে থেকে তাদের বন্ধুবান্ধবরা বলবে -- ''আমাদের প্রভূ! আমাদের কেউ কেউ অন্যদের দ্বারা লাভবান হয়েছিলাম, কিন্ত আমরা পৌছেগেছি আমাদের অন্তিম সময়ে যা তুমি আমাদের জন্য নির্ধারিত করেছিলে। তিনি বলবেন -- ''আগুন হচ্ছে তোমাদের আবাসস্থল, সেখানে দীর্ঘকাল থাকবার জন্য -- আল্লাহ্ যাকে ইচ্ছা করেন সে ব্যতীত। নিঃসন্দেহ তোমার প্রভু পরমজ্ঞানী, সর্বজ্ঞাতা।\qt@no{(128)}}
\qt@newcmd\qurantrans@bn@cmxviii{আর এইভাবে আমরা কোনো-কোনো অন্যায়কারীদের অন্যদের সহায় হতে দিই যা তারা অর্জন করে থাকে সেজন্য।\qt@no{(129)}}
\qt@newcmd\qurantrans@bn@cmxix{হে জিন ও মানব সম্প্রদায়! তোমাদের কাছে কি তোমাদের মধ্যে থেকে রসূলগণ আসেন নি যাঁরা তোমাদের কাছে আমার নির্দেশাবলী বর্ণনা করতেন আর তোমাদের সতর্ক করতেন তোমাদের এই দিনটিতে একত্রিত হওয়া সন্বন্ধে? তারা বলবে -- ''আমরা সাক্ষ্য দিচ্ছি আমাদের নিজেদের বিরুদ্ধেই।’’ আর এই দুনিয়ার জীবন তাদের ভুলিয়েছিল, আর তারা নিজেদের বিরুদ্ধেই সাক্ষ্য দেবে যে তারা বস্তুতঃ অবিশ্বাসী ছিল।\qt@no{(130)}}
\qt@newcmd\qurantrans@bn@cmxx{এটি এজন্য যে কোনো জনপদকে অন্যায়ভাবে ধ্বংস করা তোমার প্রভুর কাজ নয়, যখন তাদের বাসিন্দারা অজ্ঞ থাকে।\qt@no{(131)}}
\qt@newcmd\qurantrans@bn@cmxxi{আর প্রত্যেকের জন্যে রয়েছে তারা যা করে সেই অনুপাতে স্তরসমূহ। আর তোমার প্রভু অনবহিত নন তারা যা করে সে- সন্বন্ধে।\qt@no{(132)}}
\qt@newcmd\qurantrans@bn@cmxxii{আর তোমার প্রভু স্বয়ংসম্পূর্ণ, করুণার অধিকারী। তিনি যদি ইচ্ছা করেন তবে তিনি তোমাদের সরিয়ে দিতে পারেন এবং তোমাদের পরে তোমাদের স্থলাভিষিক্ত করতে পারেন যাদের তিনি চান, যেমন তিনি তোমাদের উত্থিত করেছিলেন অন্য এক গোষ্ঠীর বংশ থেকে।\qt@no{(133)}}
\qt@newcmd\qurantrans@bn@cmxxiii{নিঃসন্দেহ তোমাদের কাছে যা ওয়াদা করা হয়েছে তা অবশ্যই ঘটবে, আর তোমরা এড়িয়ে যেতে পারবে না।\qt@no{(134)}}
\qt@newcmd\qurantrans@bn@cmxxiv{বলো -- ''হে আমার লোকেরা! তোমাদের স্থলে তোমরা কাজ করে চলো, আমিও কাজ করে যাচ্ছি, আর শীঘ্রই তোমরা জানতে পারবে কার জন্য রয়েছে শেষ-আলয়।’’ নিঃসন্দেহ অন্যায়কারীরা সফলকাম হবে না।\qt@no{(135)}}
\qt@newcmd\qurantrans@bn@cmxxv{আর তারা আল্লাহ্‌র জন্য নির্দিষ্ট করে শস্যক্ষেত্র ও পশুপালন থেকে যা তিনি উৎপাদন করেছেন তার এক অংশ, এবং বলে -- ''এই হচ্ছে আল্লাহ্‌র জন্য’’ -- তাদের ধারণানুযায়ী, -- ''আর এই হচ্ছে আমাদের অংশীদেবতাদের জন্য।’’ তারপর যা তাদের অংশীদেবতাদের জন্য তা আল্লাহ্‌র কাছে পৌঁছে না, আর যা আল্লাহ্‌র জন্য তা পেছে যাঁয় তাদের অংশীদেবতাদের কাছে। কি নিকৃষ্ট যা তারা সিদ্ধান্ত করে!\qt@no{(136)}}
\qt@newcmd\qurantrans@bn@cmxxvi{আর এইভাবে বহুখোদাবাদীদের অধিকাংশের জন্য তাদের অংশীদেবতারা চিত্তাকর্ষক করেছে তাদের সন্তান-হত্যা, যেন তারা এদের ধ্বংস করতে পারে আর তাদের ধর্মকে তাদের জন্য বিভ্রান্তিকর করতে পারে। আর আল্লাহ্ যদি ইচ্ছে করতেন তবে তারা এ করতো না, কাজেই তাদের ও তারা যা জালিয়াতি করে তাকে উপেক্ষা করো।\qt@no{(137)}}
\qt@newcmd\qurantrans@bn@cmxxvii{আর তারা বলে -- ''এইসব গবাদি-পশু ও শস্যক্ষেত্র নিষিদ্ধ, কেউ এইসব খেতে পারবে না আমরা যাদের ইচ্ছা করি তারা ব্যতীত’’, -- তাদের ধারণানুযায়ী, এবং কতক পশু যাদের পিঠ নিষেধ করা হয়েছে, আর গবাদি-পশু যাদের উপরে তারা আল্লাহ্‌র নাম স্মরণ করে না, -- এ-সব তাঁর বিরুদ্ধে মিথ্যা উদ্ভাবন। তিনি অচিরেই তাদের প্রতিফল দেবেন তারা যা উদ্ভাবন করে থাকে তার জন্য।\qt@no{(138)}}
\qt@newcmd\qurantrans@bn@cmxxviii{আর তারা বলে -- ''এই গবাদি-পশুর পেটে যা আছে তা বিশেষভাবে আমাদের পুরুষদের জন্য, আর নিষিদ্ধ আমাদের নারীদের জন্য, আর যদি তা মৃত হয় তবে তারাও ওতে অংশীদার।’’ তিনি শীঘ্রই তাদের প্রতিদান দেবেন তাদের ধার্য করার জন্য। নিঃসন্দেহ তিনি পরমজ্ঞানী, সর্বজ্ঞাতা।\qt@no{(139)}}
\qt@newcmd\qurantrans@bn@cmxxix{নিঃসন্দেহ তারা ক্ষতিগ্রস্ত যারা তাদের সন্তানদের হত্যা করে নিরবুদ্ধিতার বশে, জ্ঞানহীনতার জন্য, আর নিষেধ করে আল্লাহ্ তাদের যা খেতে দিয়েছেন -- আল্লাহ্‌র বিরুদ্ধে মিথ্যা রচনা ক’রে। তারা অবশ্যই গোল্লায় গেছে, আর তারা সৎপথপ্রাপ্তও নয়।\qt@no{(140)}}
\qt@newcmd\qurantrans@bn@cmxxx{আর তিনিই সেইজন যিনি সৃষ্টি করেছেন বাগান -- মাচা-বাঁধানো ও মাচা-বিহীন, আর খেজুর গাছ, আর শস্যক্ষেত্র যার রকম- রকমের স্বাদ, আর জলপাই ও ডালিম -- এক রকমের ও সাদৃশ্যবিহীন। সে-সবের ফল খাও যখন তা ফল ধরে, আর ওর হক্ প্রদান করো ফসল তোলার দিনে, আর অপচয় করো না। নিঃসন্দেহ তিনি অপচয়কারীদের ভালোবাসেন না।\qt@no{(141)}}
\qt@newcmd\qurantrans@bn@cmxxxi{আর গবাদি-পশুদের মধ্যে কতকগুলো ভার বহনের জন্য আর কিছু ক্ষুদ্রাকার। আল্লাহ্ তোমাদের যা খাদ্যবস্তু দিয়েছেন সে- সব থেকে আহার করো, আর শয়তানের পদাঙ্ক অনুসরণ করো না। নিঃসন্দেহ তোমাদের জন্য সে হচ্ছে প্রকাশ্য শত্রু ।\qt@no{(142)}}
\qt@newcmd\qurantrans@bn@cmxxxii{আটটি জোড়ায় -- ভেড়া থেকে দুটো ও ছাগল থেকে দুটো। বলো -- ''তিনি কি নিষেধ করেছেন নর দুটি অথবা মাদী দুটি, অথবা মাদী-দুটির গর্ভ যা ধরে রেখেছে তা? জ্ঞানের সাথে আমাকে জানাও যদি তোমরা সত্যবাদী হয়ে থেকো।’’\qt@no{(143)}}
\qt@newcmd\qurantrans@bn@cmxxxiii{আর উট থেকে দুটো ও গরু থেকে দুটো। বলো -- ''তিনি কি নিষেধ করেছেন নর দুটি অথবা মাদী দুটি, না মাদী-দুটির গর্ভ যা ধারণ করেছে তা? অথবা তোমরা কি সাক্ষী ছিলে যখন আল্লাহ্ তোমাদের জন্য এই বিধান দিয়েছিলেন?’’ সুতরাং কে বেশি অন্যায়কারী তার চাইতে যে আল্লাহ্‌র বিরুদ্ধে মিথ্যা রচনা করে, যেন সে লোককে বিভ্রান্ত করতে পারে জ্ঞানহীনভাবে? নিঃসন্দেহ আল্লাহ্ ধর্মপথে পরিচালিত করেন না অন্যায়কারী লোকদের।\qt@no{(144)}}
\qt@newcmd\qurantrans@bn@cmxxxiv{বলো -- ''আমার কাছে যা প্রত্যাদিষ্ট হয়েছে তাতে আমি খাদকের জন্য নিষিদ্ধ পাই নি তা খেতে এইসব ব্যতীত -- যা মৃত হয়ে গেছে, অথবা ঝরে পড়া রক্ত, অথবা শূকরের মাংস, -- কেননা তা নিঃসন্দেহ অশুচি, অথবা যা হালাল করা হয়েছে তার উপরে আল্লাহ্ ছাড়া অন্য নাম নেওয়ার পাপাচারে, কিন্ত যে কেউ চাপে পড়েছে, অবাধ্য না হয়ে বা মাত্রা না ছাড়িয়ে, তবে তোমার প্রভু নিঃসন্দেহ পরিত্রাণকারী, অফুরন্ত ফলদাতা।\qt@no{(145)}}
\qt@newcmd\qurantrans@bn@cmxxxv{আর যারা ঈহুদী মত পোষণ করে তাদের জন্য আমরা নিষেধ করেছিলাম প্রত্যেক অবিভক্ত খুর-বিশিষ্ট প্রাণী, আর গরু ও মেষের মধ্যে তাদের জন্য আমরা নিষেধ করেছিলাম উভয়ের চর্বি, তবে যা জড়িত থাকত তাদের পিঠে বা অন্ত্রে, অথবা যা সংযুক্ত থাকত হাড়ের সঙ্গে তা ব্যতীত। এভাবে তাদের আমরা প্রতিফল দিয়েছিলাম তাদের অবাধ্যতার জন্য, আর নিঃসন্দেহ আমরা সত্যপরায়ণ।\qt@no{(146)}}
\qt@newcmd\qurantrans@bn@cmxxxvi{কাজেই তারা যদি তোমাকে প্রত্যাখ্যান করে তবে বলো -- ''তোমাদের প্রভু সর্বব্যাপী করুণার মালিক, কিন্ত তাঁর শাস্তি প্রতিহত হবে না অপরাধী সম্প্রদায়ের থেকে।’’\qt@no{(147)}}
\qt@newcmd\qurantrans@bn@cmxxxvii{যারা বহুখোদাবাদী তারা তখন বলবে -- ''আল্লাহ্ যদি ইচ্ছা করতেন তবে আমরা অংশী দাঁড় করতাম না, আর আমাদের পিতৃপুরুষরাও না, আর আমরা কিছুই নিষেধ করতাম না।’’ এইভাবে এদের পূর্বে যারা ছিল তারাও প্রত্যাখ্যান করেছিল, যে পর্যন্ত না তারা আমাদের ক্ষমতা আস্বাদ করেছিল! বলো -- ''তোমাদের কাছে কি কোনো জ্ঞান রয়েছে? থাকলে তা আমাদের নিকট হাজির করো। তোমরা শুধু কল্পনারই অনুসরণ করছো, আর তোমরা তো শুধু আন্দাজে হাতড়াচ্ছ।’’\qt@no{(148)}}
\qt@newcmd\qurantrans@bn@cmxxxviii{বলো -- ''তবে চূড়ান্ত যুক্তি-তর্ক আল্লাহ্‌রই, কাজেই তিনি যদি ইচ্ছা করতেন তবে তোমাদের সবাইকে তিনি সৎপথে পরিচালিত করতেন।’’\qt@no{(149)}}
\qt@newcmd\qurantrans@bn@cmxxxix{বলো -- ''হাজির করো তোমাদের সাক্ষীদের যারা সাক্ষ্য দিতে পারে যে আল্লাহ্ এ নিষেধ করেছেন।’’ অতএব যদি তারা সাক্ষ্য দেয় তবে তুমি তাদের সঙ্গে সাক্ষ্য দিতে যেও না, আর তাদের খেয়ালখুশির অনুসরণ করো না যারা আমাদের নির্দেশাবলী প্রত্যাখ্যান করেছে, আর যারা পরকালে বিশ্বাস করে না, আর তারাই তাদের প্রতিপালকের প্রতি সমকক্ষ ঠাওরায়।\qt@no{(150)}}
\qt@newcmd\qurantrans@bn@cmxl{বলো -- ''এসো আমি বাতলে দিই তোমাদের প্রভু তোমাদের জন্য কি নিষেধ করেছেন, -- তোমরা তাঁর সঙ্গে অন্য কিছু শরিক করো না, আর পিতা-মাতার প্রতি সদ্ব্যবহার, আর তোমাদের সন্তানদের তোমরা হত্যা করো না দারিদ্রের কারণে,’’ -- আমারাই জীবিকা দিই তোমাদের ও তাদেরও, -- ''আর অশ্লিলতার ধারে-কাছেও যেও না তার যা প্রকাশ পায় ও যা গোপন থাকে, আর তেমন কোনো লোককে হত্যা করো না যাকে আল্লাহ্ নিষেধ করেছেন, -- যথাযথ কারণ ব্যতীত। এইসব দিয়ে তিনি তোমাদের আদেশ জারি করেছেন, যেন তোমরা বুঝতে পারো।\qt@no{(151)}}
\qt@newcmd\qurantrans@bn@cmxli{''আর এতীমের সম্পত্তির কাছে যেও না যা শ্রেষ্ঠতর সেই উদ্দেশ্য ব্যতীত, যে পর্যন্ত না সে তার সাবালকত্বে পৌঁছে। আর পুরো মাপ ও ওজন দেবে ন্যায্যভাবে।’’ আমরা কোনো লোকের উপরে ভার চাপাই না যা তার ক্ষমতার অতিরিক্ত। ''আর যখন তোমরা কথা বলো তখন ন্যায়নিষ্ঠ হও যদিও তা আপনজনের ব্যাপারে হয়। আর আল্লাহ্‌র ওয়াদা সম্পাদন করো। -- এইসব দিয়ে তোমাদের তিনি নির্দেশ দিয়েছেন যেন তোমরা মনোনিবেশ করো।\qt@no{(152)}}
\qt@newcmd\qurantrans@bn@cmxlii{''আর যে এটিই আমার সহজ-সঠিক পথ, কাজেই এরই অনুসরণ করো, এবং অন্যান্য পথ অনুসরণ করো না, কেননা সে-সব তাঁর পথ থেকে তোমাদের বিচ্ছিন্ন করবে।’’ এইসব দ্বারা তিনি তোমাদের নির্দেশ দিয়েছেন যেন তোমরা ধর্মপরায়ণতা অবলন্বন করো।\qt@no{(153)}}
\qt@newcmd\qurantrans@bn@cmxliii{পুনরায়, আমরা মূসাকে দিয়েছিলাম গ্রন্থ -- পূর্ণাঙ্গ তারজন্য যে শুভকাজ করে এবং যা হচ্ছে সব-কিছুর বিশদ বিবরণ, আর পথনির্দেশ ও করুণা, -- যেন তারা তাদের প্রভুর সঙ্গে মুলাকাতের সন্বন্ধে বিশ্বাস করে।\qt@no{(154)}}
\qt@newcmd\qurantrans@bn@cmxliv{আর এ এক গ্রন্থ -- আমরা এটি অবতারণ করেছি কল্যাণময় ক’রে, কাজেই এর অনুসরণ করো ও ভয়ভক্তি করো যেন তোমাদের প্রতি দয়া প্রদর্শন করা হয়, --\qt@no{(155)}}
\qt@newcmd\qurantrans@bn@cmxlv{পাছে তোমরা বলো -- ''আমাদের আগে গ্রন্থ অবতীর্ণ হয়েছিল শুধু দুটি সম্প্রদায়ের কাছে, আর আমরা তাদের পড়াশুনা সন্বন্ধে অজ্ঞাত ছিলাম।’’\qt@no{(156)}}
\qt@newcmd\qurantrans@bn@cmxlvi{অথবা পাছে তোমরা বলো -- ''যদি আমাদের কাছে গ্রন্থ অবতীর্ণ হতো তবে আমরা তাদের চাইতে ভালোভাবে সুপথগামী হতাম।’’ এখন তো তোমাদের কাছে তোমাদের প্রভুর কাছ থেকে এসেছে স্পষ্ট প্রমাণ এবং পথনির্দেশ ও কুরুণা। অতএব তার চাইতে কে বেশি অন্যায়কারী যে আল্লাহ্‌র নির্দেশসমূহ প্রত্যাখ্যান করে আর সে-সব থেকে ফিরে যায়? যারা আমাদের নির্দেশাবলী থেকে ফিরে যায় তাদের আমরা অচিরেই প্রতিফল দেবো নিকৃষ্ট শাস্তি দিয়ে, যেহেতু তারা ফিরে যেতো।\qt@no{(157)}}
\qt@newcmd\qurantrans@bn@cmxlvii{তারা কি প্রতীক্ষা করছে পাছে ফিরিশ্‌তারা তাদের কাছে আসুক, অথবা তোমার প্রভু আসুন, অথবা তোমার প্রভুর কোনো কোনো নিদর্শন আসুক, তখন কোনো লোকেরই তার ঈমানে কোনো ফায়দা হবে না যে এর আগে বিশ্বাস স্থাপন করে নি, কিংবা যে তার ঈমানের দ্বারা কোনো কল্যাণ অর্জন করে নি। বলো -- ''তোমরা অপেক্ষা করো, আমরাও প্রতীক্ষাকারী।”\qt@no{(158)}}
\qt@newcmd\qurantrans@bn@cmxlviii{নিঃসন্দেহ যারা তাদের ধর্মকে বিভক্ত করেছে এবং বিভিন্ন দল হয়ে গেছে, তাদের জন্য তোমার কোনো দায়দায়িত্ব নেই। নিঃসন্দেহ তাদের ব্যাপার আল্লাহ্‌র কাছে, তিনিই এরপরে তাদের জানাবেন যা তারা করে চলতো।\qt@no{(159)}}
\qt@newcmd\qurantrans@bn@cmxlix{যে কেউ একটি ভালো কাজ নিয়ে আসে, তার জন্য তবে রয়েছে দশটি তার অনুরূপ, আর যে কেউ একটি মন্দ কাজ নিয়ে আসে, তাকে তবে প্রতিদান দেয়া হয় না তার অনুরূপ ব্যতীত, আর তাদের প্রতি অন্যায় করা হবে না।\qt@no{(160)}}
\qt@newcmd\qurantrans@bn@cml{বলো -- ''নিঃসন্দেহ আমার প্রভু আমাকে পরিচালনা করেছেন সহজ-সঠিক পথের দিকে -- এক সুষ্ঠাঙ্গ ধর্মে -- একনিষ্ঠ ইব্রাহীমের ধর্মমতে, আর তিনি বহুখোদাবাদীদের অন্তর্ভুক্ত ছিলেন না।’’\qt@no{(161)}}
\qt@newcmd\qurantrans@bn@cmli{বলো -- ''নিঃসন্দেহ আমার নামায ও আমার কুরবানি, আর আমার জীবন ও আমার মরণ -- আল্লাহ্‌র জন্য যিনি সমস্ত বিশ্বজগতের প্রভু।\qt@no{(162)}}
\qt@newcmd\qurantrans@bn@cmlii{''কোনো শরিক নেই তাঁর, আর এভাবেই আমি আদিষ্ট হয়েছি, আর আমি থাকবো আ‌ত্মসমর্পণকারীদের একেবারে পুরোভাগে।’’\qt@no{(163)}}
\qt@newcmd\qurantrans@bn@cmliii{বলো -- ''কী! আমি কি আল্লাহ্ ছাড়া অন্য প্রভু খুজঁবো, অথচ তিনিই সব-কিছুর রব্ব?’’ আর প্রত্যেক সত্তা অর্জন করে না তার জন্যে ছাড়া, আর কোনো ভারবাহক অন্যের ভার বহন করবে না। তারপর তোমাদের প্রভুর কাছেই তোমাদের প্রত্যাবর্তন, তখন তিনি তোমাদের জানিয়ে দেবেন যে-বিষয়ে তোমরা মতভেদ ক’রে চলছিলে।\qt@no{(164)}}
\qt@newcmd\qurantrans@bn@cmliv{আর তিনিই সেইজন যিনি তোমাদের পৃথিবীর প্রতিনিধি বানিয়েছেন, আর তোমাদের কাউকে অন্যদের উপরে মর্যাদায় উন্নত করেছেন, যেন তিনি তোমাদের নিয়মানুবর্তী করতে পারেন যা তিনি তোমাদের দিয়েছেন তার দ্বারা। নিঃসন্দেহ তিনি পরিত্রাণকারী, অফুরন্ত ফলদাতা।\qt@no{(165)}}
\qt@newcmd\qurantrans@bn@cmlv{\basmalahbn আলিফ, লাম, মীম, স্বাদ।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@cmlvi{তোমার কাছে অবতীর্ণ একটি গ্রন্থ, -- অতএব তোমার বক্ষে এর জন্য কোন সংকোচ না থাকুক -- যেন তুমি এর দ্বারা সতর্ক করতে পারো, এবং মুমিনদের জন্য একটি স্মারক।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@cmlvii{''তোমাদের প্রভুর কাছ থেকে তোমাদের কাছে যা অবতীর্ণ হয়েছে তা অনুসরণ করো আর তাঁকে বাদ দিয়ে অভিভাবকদের অনুসরণ করো না। অল্পই যা তোমরা মনে রাখো।’’\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@cmlviii{আর জনবসতির মধ্যের কতটা যে আমরা ধ্বংস করেছি, তাই আমাদের শাস্তি তাতে এসেছিল নিশাকালে, অথবা তারা যখন দুপুরবেলায় ঘুম দিচ্ছিল।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@cmlix{কাজেই তাদের কাছে যখন আমাদের শাস্তি এসে পড়েছিল তখন তাদের অজুহাত আর কিছু ছিল না এই বলা ছাড়া -- ''নিঃসন্দেহ আমরা ছিলাম অন্যায়কারী।’’\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@cmlx{আমরা তখন তাদের অবশ্যই প্রশ্ন করবো যাদের কাছে প্রেরণ করা হয়েছিল, আর আমরা নিশ্চয়ই প্রেরিত-পুরুষগণকেও জিজ্ঞাসা করবো।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@cmlxi{তখন আমরা নিশ্চয়ই তাদের কাছে বর্ণনা করবো জ্ঞানের সাথে, আর আমরা তো অনুপস্থিত ছিলাম না।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@cmlxii{আর সেদিন ওজন হবে সঠিকভাবে। কাজেই যার পাল্লা ভারী হবে তারাই তবে হবে সফলকাম।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@cmlxiii{আর যার পাল্লা হাল্কা হবে এরাই তবে তারা যারা তাদের আ‌ত্মার ক্ষতি সাধন করেছে, কেননা তারা আমাদের নির্দেশাবলীর প্রতি অন্যায় করেছিল।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@cmlxiv{আর আমরা তো পৃথিবীতে তোমাদের প্রতিষ্ঠিত করেছি, আর তোমাদের জন্য তাতে করেছি জীবিকার ব্যবস্থা। অল্পই সেইটুকু যা কৃতজ্ঞতা তোমার জ্ঞাপন করো।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@cmlxv{আর নিশ্চয়ই আমরা তোমাদের সৃষ্টি করেছি, তারপর তোমাদের রূপদান করেছি, তারপর ফিরিশ্‌তাদের বললাম -- ''আদমের প্রতি সিজদা করো।’’ কাজেই তারা সিজদা করলো, কিন্তু ইবলীস করলো না সে সিজদাকারীদের অন্তর্ভুক্ত হলো না।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@cmlxvi{তিনি বললেন -- ''কি তোমাকে বাধা দিয়েছিল যেজন্য তুমি সিজদা করলে না যখন আমি তোমাকে আদেশ করেছিলাম?’’ সে বললে -- ''আমি তার চাইতে শ্রেষ্ঠ, আমাকে তুমি আগুন দিয়ে সৃষ্টি করেছ, আর তাকে তুমি সৃষ্টি করেছ কাদা দিয়ে।’’\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@cmlxvii{তিনি বললেন -- ''তবে এখানে থেকে রসাতলে যাও, তোমার জন্য নয় যে তুমি এখানে অহংকার করবে। কাজেই বেরিয়ে যাও, তুমি আলবৎ অধমদের মধ্যেকার।’’\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@cmlxviii{সে বললে -- ''আমাকে সময় দাও সেইদিন পর্যন্ত যখন তারা পুনরুত্থিত হবে।’’\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@cmlxix{তিনি বললেন -- ''বেশ, তুমি অবকাশপ্রাপ্তদের মধ্যেকার।’’\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@cmlxx{সে বললে -- ''তবে তুমি যেমন আমাকে বিপথে যেতে দিয়েছ, আমিও তেমনি ওত পেতে থাকবো তাদের জন্য তোমার সহজ- সঠিক পথে।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@cmlxxi{''তারপর আমি আলবৎ তাদের উপরে এসে পড়বো তাদের সামনে থেকে ও তাদের পেছন থেকে, আর তাদের ডাইনে থেকে ও তাদের বামে থেকে, আর তাদের অনেককেই তুমি কৃতজ্ঞ পাবে না।’’\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@cmlxxii{তিনি বললেন -- ''বেরোও এখান থেকে, বেহায়া, বিতাড়িত! তাদের মধ্যের যে কেউ তোমার অনুসরণ করবে, -- আমি নিশ্চয় জাহান্নাম ভর্তি করবো তোমাদের মধ্যের সবকে দিয়ে।’’\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@cmlxxiii{আর -- ''হে আদম! তুমি ও তোমার সঙ্গিনী এই বাগানে বসবাস করো, আর যেখান থেকে তোমরা চাও আহার করো, কিন্তু এই বৃক্ষের ধারেকাছেও যেও না, তাহলে তোমরা অন্যায়কারীদের অন্তর্ভুক্ত হবে।’’\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@cmlxxiv{তারপর শয়তান তাদের কুমন্ত্রণা দিলে যেন সে তাদের কাছে প্রকাশ করতে পারে তাদের লজ্জার বিষয়ের যা তাদের কাছে গোপন ছিল, তাই সে বললে -- ''তোমাদের প্রভু এই গাছের থেকে তোমাদের নিষেধ করেন নি এই জন্য ছাড়া যে তোমরা ফিরিশ্‌তা হয়ে যাবে কিংবা তোমরা হবে চিরজীবীদের অন্তর্ভুক্ত।’’\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@cmlxxv{আর সে তাদের কাছে কসম খেলো -- ''নিঃসন্দেহ আমি তো তোমাদের জন্য সদুপদেশদাতাদের মধ্যেকার।’’\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@cmlxxvi{এভাবে সে তাদের বিপথে চালালো প্রতারণার দ্বারা, অতঃপর তারা যখন বৃক্ষের আস্বাদ গ্রহণ করলো, তখন তাদের লজ্জা তাদের কাছে প্রকাশ পেলো, আর তারা তাদের আবৃত করতে লাগলো সেই বাগানের পাতা দিয়ে। আর তাদের প্রভু তাদের ডেকে বললেন -- ''আমি কি তোমাদের নিষেধ করি নি ঐ বৃক্ষ সন্বন্ধে, আর তোমাদের তো আমি বলেইছি যে শয়তান তোমাদের জন্য প্রকাশ্য শত্রু?’’\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@cmlxxvii{তারা বললে -- ''আমাদের প্রভু! আমরা আমাদের নিজেদের প্রতি অন্যায় করেছি, আর যদি তুমি আমাদের পরিত্রাণ না করো ও আমাদের তুমি দয়া করো তাহলে আমরা নিশ্চয়ই ক্ষতিগ্রস্তদের অন্তর্ভুক্ত হয়ে যাবো।’’\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@cmlxxviii{তিনি বললেন -- '' তোমরা অধঃপাতে যাও। তোমাদের কেউ কেউ অন্য কারোর শত্রু। আর তোমাদের জন্য পৃথিবীতে রয়েছে জিরানোর স্থান ও কিছু সময়ের জন্য সংস্থান।’’\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@cmlxxix{তিনি বললেন -- ''এইখানেই তোমরা জীবন যাপন করবে, আর এতেই তোমরা মৃত্যু বরণ করবে, আর এরই মধ্য থেকে তোমাদের পুনরুত্থিত করা হবে।’’\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@cmlxxx{হে আদম-সন্তানগণ! আমরা তোমাদের জন্য নিশ্চয়ই পোশাক পাঠিয়েছি তোমাদের লজ্জা ঢাকবার ও বেশভূষার জন্য। আর ধর্মপরায়ণতার পোশাক -- তাই সর্বশ্রেষ্ঠ। এ হচ্ছে আল্লাহ্‌র নির্দেশাবলী থেকে, যেন তারা মনে রাখে।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@cmlxxxi{হে আদম-সন্তানগণ! শয়তান যেন তোমাদের কিছুতেই প্রলোভিত না করে, যেমন সে তোমাদের পিতামাতাকে বের করে দিয়েছিল এই বাগান থেকে, তাদের থেকে তাদের পোশাক ছিন্ন ক’রে, যেন সে তাদের দেখাতে পারে তাদের লজ্জা। নিঃসন্দেহ সে তোমাদের দেখে -- সে ও তার কাফেলা, যেখান থেকে তোমরা তাদের দেখতে পাও না। নিঃসন্দেহ আমরা শয়তানকে বানিয়েছি তাদের অভিভাবক যারা বিশ্বাস করে না।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@cmlxxxii{আর যখন তারা কোনো অশ্লীল আচরণ করে তখন বলে -- ''আমরা আমাদের পিতৃপুরুষকে এতে পেয়েছি, আর আল্লাহ্ আমাদের এতে আদেশ করেছেন।’’ বলো -- ''নিঃসন্দেহ আল্লাহ্ অশ্লীলতাতে আদেশ করেন না। তোমরা কি আল্লাহ্‌র বিরুদ্ধে বলো যা তোমরা জানো না?’’\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@cmlxxxiii{তুমি বলো -- ''আমার প্রভু আদেশ দেন ন্যায় বিচারের, আর তোমাদের মুখ সোজা দাঁড় করো প্রত্যেক সিজদাস্থলে, আর তাঁকে ডাকো তাঁর প্রতি ধর্মে একনিষ্ঠভাবে।’’ যেমন তিনি তোমাদের সৃষ্টি করেছিলেন তোমরা সেভাবে ফিরে আসবে।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@cmlxxxiv{একদলকে তিনি সুপথগামী করেছেন, আর আরেক দলের পথভ্রান্তি তাদের উপরে সংগত হয়েছে। নিঃসন্দেহ তারা আল্লাহ্‌কে ছেড়ে দিয়ে শয়তানদের গ্রহণ করেছিল অভিভাবকরূপে, আর তারা মনে করত যে তারা অবশ্যই সুপথে চালিত।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@cmlxxxv{হে আদম-সন্তানরা! তোমাদের বেশভূষা গ্রহণ করো প্রত্যেক সিজদাস্থলে, আর খাও ও পান করো, কিন্তু অপচয় করো না, নিঃসন্দেহ তিনি অমিতব্যয়ীদের ভালোবাসেন না।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@cmlxxxvi{বলো -- ''কে নিষিদ্ধ করেছে আল্লাহ্‌র শোভা, -- যা তিনি তাঁর বান্দাদের জন্য সৃষ্টি করেছেন, আর জীবিকা থেকে বিশুদ্ধ বস্তুসমূহ?’’ বলো -- ''এ-সব এই দুনিয়ার জীবনে তাদের জন্য যারা ঈমান এনেছে, -- পুনর্জাগরণের দিনে বিশেষভাবে।’’ এইভাবে আমরা আমাদের নির্দেশাবলী বিশদভাবে ব্যাখ্যা করি তেমন সম্প্রদায়ের জন্য যারা জানে।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@cmlxxxvii{বলো -- ''নিঃসন্দেহ আমার প্রভু নিষিদ্ধ করেছেন অশ্লীলতা -- তার যা প্রকাশ পায় ও যা গোপন থাকে, আর পাপাচার, আর ন্যায়বিরুদ্ধ বিদ্রোহাচরণ, আর আল্লাহ্‌র সঙ্গে তোমরা যা শরিক করো যার জন্য কোনো দলিল তিনি অবতীর্ণ করেন নি, আর যেন তোমরা আল্লাহ্‌র বিরুদ্ধে বলো যা তোমরা জানো না।’’\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@cmlxxxviii{আর প্রত্যেক জাতির জন্য রয়েছে একটি নির্ধারিত কাল, কাজেই যখন তাদের নির্ধারিত কাল এসে পড়ে তখন তারা দেরি করতে পারবে না ঘন্টাখানেকের জন্যে, আর তারা এগিয়েও আনতে পারবে না।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@cmlxxxix{হে আদমের বংশধরগণ! যখন তোমাদের কাছে তোমাদের মধ্যে থেকে রসূলগণ আসেন তোমাদের কাছে আমার নির্দেশাবলী বর্ণনা করেন, তখন যে কেউ ভয়-ভক্তি করে ও সৎকর্ম করে, তাদের জন্য তবে থাকবে না ভয়ভীতি, আর তারা করবেও না অনুতাপ।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@cmxc{আর যারা আমাদের নির্দেশাবলীতে মিথ্যারোপ করে আর সে-সব থেকে গর্ববোধ করে, তারাই হচ্ছে আগুনের বাসিন্দা, তারা তাতে থাকবে দীর্ঘকাল।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@cmxci{অতএব তার চাইতে কে বেশী অন্যায়কারী যে আল্লাহ্ সন্বন্ধে মিথ্যা রচনা করে অথবা তাঁর নির্দেশাবলী প্রত্যাখ্যান করে? এরাই, -- এদের কাছে পৌঁছুবে কিতাব থেকে তাদের ভাগ। শেষ পর্যন্ত যখন আমাদের দূতরা তাদের কাছে আসবে তখন তারা তাদের মৃত্যু ঘটাবে, তারা বলবে -- ''কোথায় আছে তারা যাদের তোমরা আহ্বান করতে আল্লাহ্‌কে ছেড়ে দিয়ে?’’ তারা বলবে -- ''তারা আমাদের থেকে চলে গেছে । আর তারা নিজেদের বিরুদ্ধে সাক্ষ্য দেবে যে তারা নিঃসন্দেহ অবিশ্বাসী ছিল।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@cmxcii{তিনি বলবেন -- ''তোমরা প্রবেশ করো আগুনের মধ্যে দলগতভাবে যারা তোমাদের আগে গত হয়ে গেছে জিন ও মানুষের মধ্য থেকে। যখনি একটি দল প্রবেশ করবে সে অভিশাপ দেবে তার ভগিনীকে। তারপর যখন তারা সবে মিলে তাতে এসে পড়বে, তাদের পশ্চাদগামীরা তাদের অগ্রগামীদের সন্বন্ধে বলবে -- ''আমাদের প্রভু! এরা আমাদের পথভ্রষ্ট করেছিল, সেজন্য তাদের দাও আগুন দ্বারা দ্বিগুণ শাস্তি।’’ তিনি বলবেন -- ''প্রত্যেকের জন্য রয়েছে দ্বিগুণ শাস্তি, কিন্তু তোমরা জানো না।’’\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@cmxciii{আর তাদের অগ্রগামীরা তাদের পশ্চাদগামীদের বলবে -- ''তাহলে তোমাদের কারণে আমাদের উপরে কোনো শ্রেষ্ঠত্ব নেই, অতএব তোমরা যা অর্জন করে যাচ্ছিলে তার জন্য শাস্তি আস্বাদন করো।’’\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@cmxciv{নিঃসন্দেহ যারা আমাদের নির্দেশসমূহে মিথ্যারোপ করে আর সে-সব থেকে হামবড়াই করে, তাদের জন্য মহাকাশের দ্বার উন্নুক্ত করা হবে না আর তারা বেহেশতেও প্রবেশ করতে পারবে না, যে পর্যন্ত না উট প্রবেশ করে সূচের ছিদ্র দিয়ে। আর এইভাবে আমরা অপরাধীদের প্রতিফল দিই।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@cmxcv{তাদের জন্য রয়েছে জাহান্নামের শয্যা আর তাদের উপরে রয়েছে আবরণ। আর এইভাবে আমরা প্রতিফল দিই অন্যায়-কারীদের।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@cmxcvi{আর যারা ঈমান এনেছে এবং সৎকর্ম করছে -- আমরা কোনো সত্ত্বাকে ভারাক্রান্ত করি না তার ক্ষমতার অতিরিক্ত, -- এরাই হচ্ছে জান্নাতের বাসিন্দা, তারা সেখানে থাকবে চিরকাল।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@cmxcvii{আর আমরা দূর করে দেবো মনোমালিন্যের যা-কিছু আছে তাদের বুকে, -- তাদের নিচে দিয়ে বয়ে চলবে ঝরনারাজি, আর তারা বলবে -- ''সমুদয় প্রশংসা আল্লাহ্‌রই যিনি আমাদের পথ দেখিয়েছেন এই দিকে, আর আমরা নিজেরা সুপথ পেতাম না যদি আল্লাহ্ আমাদের পথ না দেখাতেন, নিশ্চয়ই আমাদের প্রভুর রসূলগণ সত্য নিয়ে এসেছিলেন।’’ আর তাদের কাছে ঘোষণা করা হবে -- ''দেখো! এই বেহেশত তোমাদের সামনে, তোমরা এ উত্তরাধিকার করলে তোমরা যা করতে তার জন্য।’’\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@cmxcviii{আর জান্নাতবাসীরা আগুনের বাসিন্দাদের ডেকে বলবে -- ''আমরা নিশ্চয়ই পেয়েছি আমাদের প্রভু আমাদের কাছে যা ওয়াদা করেছিলেন তা সত্য, তোমরাও কি তবে তোমাদের প্রভু যা ওয়াদা করেছিলেন তা সত্য পেয়েছ?’’ তারা বলবে -- ''হাঁ।’’ তখন জনৈক মুওজ্জিন তাদের মধ্যে ঘোষণা করবে -- ''আল্লাহ্‌র ধিক্কার হোক দুরাচারীদের উপরে --\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@cmxcix{''যারা আল্লাহ্‌র পথ থেকে সরিয়ে দেয় আর তাকে কুটিল করতে চেষ্টা করে, আর তারা আখেরাতের সন্বন্ধে অবিশ্বাসী।’’\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@m{আর এই দুয়ের মধ্যে থাকবে একটি পর্দা। আর উঁচু স্থানসমূহে থাকবে কিছু লোক যাঁরা সবাইকে চেনেন তাদের চিহ্নের দ্বারা। আর তাঁরা বেহেশতের আগন্তক বাসিন্দাদের ডেকে বলবেন -- ''সালামুন আলাইকুম।’’ তারা এখনও তাতে প্রবেশ করে নি, তবে তারা আশা রাখে।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mi{আর যখন তাদের দৃষ্টি ফেরানো হবে তখন তা নকরবাসীদের সাক্ষাৎ পাবে, তারা বলবে -- ''আমাদের প্রভু! অন্যায়কারী দলের সঙ্গে আমাদের ফেলে দিও না।’’\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mii{আর উঁচুস্থানসমূহের বাসিন্দারা ডাকবেন সেইসব লোকদের যাদের তাঁরা চিনতে পারবেন ওদের চিহ্নের দ্বারা, তাঁরা বলবেন -- ''তোমাদের কোনো কাজে এলো না তোমাদের সঞ্চয় আর যা নিয়ে তোমরা হামবড়াই করতে!\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@miii{''এরাই কি! তারা যাদের সন্বন্ধে তোমরা কসম খেয়েছিলে যে আল্লাহ্ তাদের প্রতি করুণা প্রদর্শন করবেন না?’’ ''বেহেশতে প্রবেশ করো, তোমাদের উপরে কোনো ভয় নেই, আর তোমরা অনুতাপও করবে না।’’\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@miv{আর নরকবাসীরা জান্নাতবাসীদের ডেকে বলবে -- ''আমাদের উপরে পানি কিছুটা ঢেলে দাও, অথবা আল্লাহ্ তোমাদের যা খাওয়াচ্ছেন তা থেকে।’’ তারা বলবে -- ''নিঃসন্দেহ আল্লাহ্ এ দুটোই নিষেধ করেছেন অবিশ্বাসীদের জন্য --\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mv{''যারা তাদের ধর্মকে গ্রহণ করেছিল খেলা ও কৌতুকরূপে, আর এই দুনিয়ার জীবন যাদের ভুলিয়েছিল।’’ সুতরাং আজ আমরা তাদের পরিত্যাগ করেছি যেমন তারা অবহেলা করেছিল তাদের এই দিনটির সঙ্গে মিলিত হওয়ার ব্যাপারে, আর যেহেতু তারা আমাদের নির্দেশাবলী প্রত্যাখ্যান করেছিল।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mvi{আর নিশ্চয়ই আমরা তাদের জন্য নিয়ে এসেছি একখানা কিতাব যাতে বিশদ ব্যাখ্যা করেছি জ্ঞান দ্বারা, -- এক পথনির্দেশ ও করুণা যারা বিশ্বাস করে তেমন লোকের জন্য।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mvii{তারা কি আর কিছুর অপেক্ষা করে ওর পরিণাম ছাড়া? যেদিন এর পরিণাম আসবে, যারা এর আগে এটি অবহেলা করেছিল তারা বলবে -- ''আমাদের প্রভুর রসূলগণ নিশ্চয়ই সত্য নিয়ে এসেছিলেন। আমাদের জন্য কোনো সুপারিশকারী আছে কি? তারা তবে আমাদের জন্য সুপারিশ করুক, অথবা আমরা কি প্রত্যাবৃত্ত হতে পারি যেন আমরা যা করতাম তার বিপরীত কিছু করতে পারি?’’ তারা আলবৎ তাদের অন্তরা‌ত্মা হারিয়েছে, আর তাদের থেকে বিদায় নিয়েছে সেইসব যাদের তারা উদ্ভাবন করেছিল।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mviii{নিঃসন্দেহ তোমাদের প্রভু হচ্ছেন আল্লাহ্ যিনি সৃষ্টি করেছেন মহাকাশমন্ডল ও পৃথিবী ছয় দিনে, তখন তিনি আরশে অধিষ্ঠিত হন। তিনি দিনকে আবৃত করেন রাত্রি দিয়ে, -- যা দ্রতগতিতে তার অনুসরণ করে। আর সূর্য ও চন্দ্র ও নক্ষত্ররাজি তাঁর হুকুমের আজ্ঞাধীন। সৃষ্টি করা ও নির্দেশ দান কি তাঁর অধিকারভুক্ত নয়? মহিমাময় আল্লাহ্ -- বিশ্বজগতের প্রভু!\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mix{তোমাদের প্রভুকে ডাকো বিনীতভাবে ও গোপনতার সাথে। নিঃসন্দেহ তিনি সীমালঙ্ঘনকারীদের ভালোবাসেন না।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mx{আর দুনিয়াতে গন্ডগোল সৃষ্টি করো না তার মধ্যে শান্তিপ্রতিষ্ঠার পরে, আর তাঁকে ডাকো ভয়ে ও আশায়। নিঃসন্দেহ আল্লাহ্‌র অনুগ্রহ সৎকর্মশীলদের নিকটবর্তী।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mxi{আর তিনিই সেইজন যিনি মলয়বায়ুপ্রবাহ পাঠান তাঁর অনুগ্রহের প্রাক্কালে সুসংবাদবাহীরূপে। শেষ পর্যন্ত যখন তারা সঘন মেঘমালা বহন ক’রে আনে, আমরা তখন তা মৃত ভূখন্ডের দিকে পাঠাই, তারপর আমরা তাতে পানি বর্ষণ করি, তারপরে এর সাহায্যে উৎপাদন করি সব রকমের ফলফসল। এইভাবে আমরা মৃতকে বের করে আনি, যেন তোমরা স্মরণ করতে পারো।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mxii{আর ভালো জমি -- এর গাছপালা গজায় তার প্রভুর অনুমতিক্রমে, আর যা মন্দ -- কিছুই গজায় না অল্পস্বল্প ছাড়া। এই ভাবে আমরা নির্দেশসমূহ বিশদভাবে বর্ণনা করি যারা কৃতজ্ঞতা প্রকাশ করে তেমন লোকের জন্য।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mxiii{আমরা অবশ্যই নূহকে পাঠিয়েছিলাম তাঁর সম্প্রদায়ের কাছে। তিনি তখন বলেছিলেন -- ''হে আমার সম্প্রদায়! আল্লাহ্‌র উপাসনা করো, তিনি ছাড়া তোমাদের অন্য উপাস্য নেই। নিঃসন্দেহ আমি তোমাদের জন্য আশংকা করছি এক ভয়ংকর দিনের শাস্তি।’’\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mxiv{তাঁর সম্প্রদায়ের প্রধানরা বললে -- ''নিঃসন্দেহ আমরা তো তোমাকে দেখছি স্পষ্ট ভ্রান্তির মধ্যে।’’\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mxv{তিনি বললেন -- ''হে আমার জনগণ! আমার মধ্যে কোনো পথভ্রান্তি নেই, বরং আমি হচ্ছি বিশ্বজগতের প্রভুর তরফ থেকে একজন রসূল।\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mxvi{''আমি তোমাদের কাছে পৌঁছে দিই আমার প্রভুর বাণীসমূহ এবং আমি তোমাদের সদুপদেশ দিই, কারণ আমি আল্লাহ্‌র কাছ থেকে জানি যা তোমরা জানো না।\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mxvii{''আচ্ছা, তোমরা কি বিস্মিত হচ্ছো যে তোমাদের কাছে তোমাদের প্রভুর কাছ থেকে উপদেশ এসেছে তোমাদেরই মধ্যেকার একজন মানুষের মাধ্যমে যেন তিনি তোমাদের সতর্ক করেন, আর যেন তোমরা ধর্মভীরুতা অবলন্বন করো, আর যেন তোমাদের করুণা প্রদর্শন করা হয়?\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mxviii{কিন্তু তারা তাঁকে মিথ্যারোপ করলো, তাই তাঁকে ও তাঁর সঙ্গে যারা ছিল তাদের আমরা উদ্ধার করেছিলাম জাহাজে, আর ডুবিয়ে দিয়েছিলাম তাদের যারা আমাদের নির্দেশসমূহ প্রত্যাখ্যান করেছিল। নিঃসন্দেহ তারা ছিল এক অন্ধ সম্প্রদায়।\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mxix{আর 'আদ জাতির কাছে তাদের ভাই হূদকে। তিনি বললেন -- ''হে আমার সম্প্রদায়! আল্লাহ্‌র উপাসনা করো, তোমাদের জন্য তিনি ছাড়া অন্য উপাস্য নেই। তোমরা কি তবে ধর্মভীরুতা অবলন্বন করবে না?’’\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mxx{তাঁর সম্প্রদায়ের মধ্যে থেকে যারা অবিশ্বাস করেছিল তাদের প্রধানরা বললে -- ''নিঃসন্দেহ আমরা তো তোমাকে দেখছি অকাট- বোকামিতে, আর আমরা আলবৎ তোমাকে মিথ্যাবাদীদের মধ্যে গণ্য করি।’’\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mxxi{তিনি বললেন -- ''হে আমার লোকেরা! আমার মধ্যে কোনো মূর্খতা নেই, বরং আমি হচ্ছি বিশ্বজগতের প্রভুর তরফ থেকে একজন রসূল।\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mxxii{''আমি তোমাদের কাছে পৌঁছে দিই আমার প্রভুর বাণীসমূহ, আর আমি তোমাদের জন্য একজন বিশ্বস্ত উপদেষ্টা।\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mxxiii{''আচ্ছা, তোমরা কি তাজ্জব হচ্ছো যে তোমাদের কাছে তোমাদের প্রভুর নিকট থেকে উপদেশ এসেছে তোমাদেরই মধ্যেকার একজন মানুষের মাধ্যমে যেন তিনি তোমাদের সতর্ক করেন? আর স্মরণ করো, কেমন ক’রে তিনি তোমাদের নূহ্‌-এর সম্প্রদায়ের পরবর্তীকালে প্রতিনিধি বানিয়েছিলেন, আর তোমাদের বর্ধিত করেছেন আকৃতির বৈশিষ্ট্যে। সুতরাং তোমরা আল্লাহ্‌র অনুগ্রহসমূহ স্মরণ করো যেন তোমরা সফল হতে পারো।’’\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mxxiv{তারা বললে -- ''তুমি কি আমাদের কাছে এসেছ যেন আমরা একমাত্র আল্লাহ্‌র উপাসনা করি, আর বর্জন করি আমাদের পিতৃপুরুষরা যার উপাসনা করতো? অতএব নিয়ে এসো আমাদের উপরে যার দ্বারা তুমি আমাদের ভয় দেখাচ্ছ, যদি তুমি সত্যবাদীদের অন্তর্ভুক্ত হও।’’\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@mxxv{তিনি বললেন -- ''তোমাদের উপরে তোমাদের প্রভুর কাছ থেকে শাস্তি ও ক্রোধ তো হাজির হয়েই আছে। তোমরা কি আমার সঙ্গে বচসা করো কতকগুলি নাম সন্বন্ধে যে-সব নাম দিয়েছ -- তোমরা ও তোমাদের পিতৃপুরুষরা, যার জন্যে আল্লাহ্ কোনো সনদ পাঠান নি? অতএব অপেক্ষা করো, আমিও তোমাদের সাথে অপেক্ষাকারীদের মধ্যে রয়েছি।’’\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@mxxvi{কাজে কাজেই তাঁকে ও তাঁর সঙ্গে যারা ছিল তাদের আমরা উদ্ধার করেছিলাম আমাদের থেকে অনুগ্রহ বশতঃ, আর কেটে দিয়েছিলাম তাদের শিকড় যারা আমাদের নির্দেশসমূহ প্রত্যাখ্যান করেছিল ও যারা মুমিন ছিল না।\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@mxxvii{আর ছামূদ জাতির কাছে তাদের ভাই সালিহ্‌কে। তিনি বললেন -- ''হে আমার সম্প্রদায়! আল্লাহ্‌র উপাসনা করো, তোমাদের জন্য তিনি ব্যতীত অন্য উপাস্য নেই। আলবৎ তোমাদের জন্য তোমাদের প্রভুর নিকট থেকে এসেছে স্পষ্ট প্রমাণ। এটি হচ্ছে আল্লাহ্‌র উষ্টী, -- তোমাদের জন্য একটি নিদর্শন, অতএব এটিকে ছেড়ে দাও আল্লাহ্‌র মাটিতে চরে খেতে, আর তাকে কোনো ক্ষতিতে ক্ষতি করো না, পাছে মর্মন্তুদ শাস্তি তোমাদের পাকড়াও করে।\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@mxxviii{''আর স্মরণ করো! কেমন ক’রে তিনি তোমাদের 'আদ-এর পরবর্তীকালে প্রতিনিধি বানিয়েছিলেন, আর তোমাদের প্রতিষ্ঠিত করেছিলেন পৃথিবীতে -- যার সমতলক্ষেত্রে তোমরা প্রাসাদ গড়েছিলে আর পাহাড় কেটে বানালে বাড়িঘর। সেজন্য তোমরা স্মরণ করো আল্লাহ্‌র অনুগ্রহসমূহ, আর দেশে গর্হিত আচরণ করো না গন্ডগোল সৃষ্টিকারী হয়ে।’’\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@mxxix{তাঁর সম্প্রদায়ের মধ্যে যারা গর্ব করেছিল তাদের প্রধানরা বললে ওদের যারা দুর্বলতা বোধ করতো -- ওদের মধ্যে যারা ঈমান এনেছিল তাদের -- ''তোমরা কি জানো যে সালিহ্ তার প্রভুর কাছ থেকে একজন প্রেরিত-পুরুষ?’’ তারা বললে -- ''নিঃসন্দেহ তাঁকে দিয়ে যা পাঠানো হয়েছে তাতে আমরা বিশ্বাসী।’’\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@mxxx{যারা গর্ববোধ করতো তারা বললে -- ''তোমরা যে-সব বিষয়ে বিশ্বাস করো তাতে আমরা নিশ্চয়ই অবিশ্বাসী।’’\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@mxxxi{অতঃপর তারা উষ্টী হত্যা করলে, আর অমান্য করলে তাদের প্রভুর নির্দেশ ও বললে -- ''হে সালিহ্‌! এনো তো আমাদের জন্য যা দিয়ে তুমি আমাদের ভয় দেখাচ্ছ, যদি তুমি রসূলদের একজন হও।’’\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@mxxxii{সুতরাং তাদের পাকড়াও করল ভূমিকম্প, কাজেই তারা হয়ে গেল আপন বাড়িঘরেই নিথরদেহী।\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@mxxxiii{তারপর তিনি তাদের থেকে ফিরে গেলেন আর বললেন -- ''হে আমার সম্প্রদায়! আমি তোমাদের কাছে আমার প্রভুর বাণীসমূহ নিশ্চয়ই পৌঁছে দিয়েছিলাম, আর তোমাদের সদুপদেশ দিয়েছিলাম, কিন্তু তোমরা উপদেষ্টাদের পছন্দ করলে না। ’’\qt@no{(79)}}
\qt@newcmd\qurantrans@bn@mxxxiv{আর লূত। স্মরণ করো! তিনি তাঁর লোকদের বললেন -- ''তোমরা কি এমন অশ্লীলতা করছো যা তোমাদের পূর্বে জগদ্বাসীদের আর কেউ চালু করে নি?\qt@no{(80)}}
\qt@newcmd\qurantrans@bn@mxxxv{''নিঃসন্দেহ তোমরা তো কামাতুর হয়ে কামিনীদের ছেড়ে দিয়ে পুরুষদের কাছে আস। না, তোমরা সীমালঙ্ঘনকারী লোক।’’\qt@no{(81)}}
\qt@newcmd\qurantrans@bn@mxxxvi{আর তাঁর লোকদের উত্তর এ ভিন্ন অন্য কিছু ছিল না যে তারা বললে -- ''তোমাদের জনপদ থেকে এদের বের করে দাও। এরা তো এমন লোক যারা পবিত্র হতে চায়!’’\qt@no{(82)}}
\qt@newcmd\qurantrans@bn@mxxxvii{কাজেই আমরা তাঁকে ও তাঁর পরিবারবর্গকে উদ্ধার করেছিলাম -- তাঁর স্ত্রী ব্যতীত, সে ছিল পেছনে-পড়ে-থাকাদের অন্তর্ভুক্ত।\qt@no{(83)}}
\qt@newcmd\qurantrans@bn@mxxxviii{আর তাদের উপরে আমরা বর্ষণ করেছিলাম এক বর্ষণ। অতএব দেখো, অপরাধীদের পরিণাম কেমন হয়েছিল?\qt@no{(84)}}
\qt@newcmd\qurantrans@bn@mxxxix{আর মাদয়ানবাসীদের নিকট তাদের ভাই শোআইবকে। তিনি বললেন -- ''হে আমার সম্প্রদায়! আল্লাহ্‌র উপাসনা করো, তোমাদের জন্য তিনি ব্যতীত অন্য উপাস্য নেই। তোমাদের কাছে তোমাদের প্রভুর কাছ থেকে নিশ্চয়ই এসেছে স্পষ্ট প্রমাণ। কাজেই পুরো মাপ ও ওজন দেবে, আর কোন লোককে বঞ্চিত করো না তাদের বিষয়বস্তুতে, আর পৃথিবীতে গন্ডগোল সৃষ্টি করো না তাতে সুব্যবস্থা আনয়নের পরে এটিই তোমাদের জন্য শ্রেয় যদি তোমরা বিশ্বাসী হও।\qt@no{(85)}}
\qt@newcmd\qurantrans@bn@mxl{''আর প্রত্যেক রাস্তায় ওত পেতে থেকো না ভয় দেখিয়ে, আর আল্লাহ্‌র পথ থেকে তাকে ফিরিয়ে নিতে যে তাঁর প্রতি ঈমান এনেছে, আর তাকে কুটিল করতে যেও না। আর স্মরণ করো -- যখন তোমরা অল্প ছিলে, তখন তিনি তোমাদের বাড়িয়ে দিয়েছিলেন। অতএব দেখো, কি হয়েছিল বিপর্যয় সৃষ্টিকারীদের পরিণাম!\qt@no{(86)}}
\qt@newcmd\qurantrans@bn@mxli{''আর যদি তোমাদের একদলও বিশ্বাস করে আমাকে যা দিয়ে পাঠানো হয়েছে তাতে, আর একদল বিশ্বাস করে না, তখন ধৈর্য ধরো যে পর্যন্ত না আল্লাহ্ আমাদের উভয়ের মধ্যে মীমাংসা করে দেন, আর তিনিই বিচারকর্তাদের মধ্যে শ্রেষ্ঠ।’’\qt@no{(87)}}
\qt@newcmd\qurantrans@bn@mxlii{তাঁর সম্প্রদায়ের মধ্যে যারা গর্ব করেছিল তাদের প্রধানরা বললে, ''আমরা নিশ্চয়ই তোমাকে তাড়িয়ে দেবো, হে শোআইব! আর যারা তোমার সঙ্গে ঈমান এনেছে তাদেরও, আমাদের জনপদ থেকে, অথবা আমাদের ধর্মমতে তোমাদের ফিরে আসতেই হবে।’’ তিনি বললেন, ''কি! যদিও আমরা ঘৃণা করি?\qt@no{(88)}}
\qt@newcmd\qurantrans@bn@mxliii{''আমরা নিশ্চয়ই আল্লাহ্‌র বিরুদ্ধে মিথ্যা সৃষ্টি করবো যদি আমরা ফিরে যাই তোমাদের ধর্মমতে তা থেকে আল্লাহ্ আমাদের উদ্ধার করার পরেও, আর এটি আমাদের সমীচীন হবে না যে আমরা ওতে ফিরে যাই, যদি না আমাদের প্রভু আল্লাহ্ ইচ্ছে করেন। আমাদের প্রভু জ্ঞানে সব-কিছুতে ব্যাপকতা রাখেন। আল্লাহ্‌র উপরেই আমরা নির্ভর করি -- 'আমাদের প্রভু! আমাদের মধ্যে ও আমাদের সম্প্রদায়ের মধ্যে ন্যায্যভাবে নিস্পত্তি করে দাও, আর তুমিই নিস্পত্তিকারীদের মধ্যে সর্বশ্রেষ্ঠ।’’\qt@no{(89)}}
\qt@newcmd\qurantrans@bn@mxliv{আর তাঁর লোকদের মধ্যের যারা অবিশ্বাস করেছিল তাদের প্রধানরা বললে -- ''যদি তোমরা শোআইবকে অনুসরণ কর তবে তোমরা আলবৎ ক্ষতিগ্রস্ত হবে।’’\qt@no{(90)}}
\qt@newcmd\qurantrans@bn@mxlv{তারপর ভূমিকম্প তাদের পাকড়ালো, ফলে তারা হয়ে গেল আপন বাড়িঘরেই নিথরদেহী।\qt@no{(91)}}
\qt@newcmd\qurantrans@bn@mxlvi{যারা শোআইবকে মিথ্যারোপ করেছিল তাদের দশা হলো -- তারা যেন কখনো সেখানে বসবাস করে নি, যারা শোআইবকে মিথ্যারোপ করেছিল তারা নিজেরাই হলো ক্ষতিগ্রস্ত!\qt@no{(92)}}
\qt@newcmd\qurantrans@bn@mxlvii{এর পর তিনি তাদের থেকে ফিরে দাঁড়ালেন ও বললেন -- ''হে আমার সম্প্রদায়! আমি তো অবশ্যই তোমাদের কাছে আমার প্রভুর নির্দেশসমূহ পৌঁছে দিয়েছিলাম আর তোমাদের সদুপদেশ দিয়েছিলাম, সুতরাং কেনই বা আমি দুঃখ করবো এক অবিশ্বাসী সম্প্রদায়ের জন্য!’’\qt@no{(93)}}
\qt@newcmd\qurantrans@bn@mxlviii{আর আমরা কোনো জনপদে কোনো নবী পাঠাইনি তাদের বাসিন্দাদের দুঃখ ও দুর্দশা দিয়ে পাকড়াও না-ক’বে, যেন তারা নিজেরা বিনয়াবনত হয়।\qt@no{(94)}}
\qt@newcmd\qurantrans@bn@mxlix{তারপর আমরা দুঃখকষ্টের অবস্থা বদলে দিলাম ভালো দিয়ে, যে পর্যন্ত না তারা ফেঁপে উঠলো ও বললে -- ''আমাদের পিতৃপুরুষদেরও দুঃখদুর্দশা ও আমোদ-আহ্লাদ স্পর্শ করেছিল।’’ কাজেই আমরা তাদের পাকড়াও করলাম অতর্কিতে, আর তারা টেরও পেলো না।\qt@no{(95)}}
\qt@newcmd\qurantrans@bn@ml{আর যদি জনপদসমূহের অধিবাসীরা ঈমান আনতো ও ধর্ম-ভীরুতা অবলন্বন করতো তবে আমরা নিশ্চয়ই তাদের জন্য উন্নুক্ত করতাম মহাকাশমন্ডল ও পৃথিবী থেকে আশীর্বাদসমূহ, কিন্তু তারা তো অবিশ্বাস করেছিল, তাই আমরা তাদের পাকড়াও করলাম যা তারা অর্জন করেছিল তার জন্যে।\qt@no{(96)}}
\qt@newcmd\qurantrans@bn@mli{তবে কি জনপদের বাসিন্দারা নিরাপদ বোধ করছে তাদের উপরে আমাদের বিপর্যয় এসে পড়া সম্পর্কে রাত্রির আক্রমণরূপে, যখন তারা থাকে নিদ্রামগ্ন?\qt@no{(97)}}
\qt@newcmd\qurantrans@bn@mlii{অথবা জনপদের বাসিন্দারা কি নিরাপদ ভাবে তাদের উপরে আমাদের বিপর্যয় এসে পড়া সম্পর্কে সকাল বেলায় যখন তারা থাকে খেলায় রত?\qt@no{(98)}}
\qt@newcmd\qurantrans@bn@mliii{তারা কি তবে নিরাপদ বোধ করে আল্লাহ্‌র পরিকল্পনা থেকে? আর আল্লাহ্‌র পরিকল্পনা থেকে কেউ নিরাপদ থাকতে পারে না ক্ষতিগ্রস্ত সম্প্রদায় ব্যতীত।\qt@no{(99)}}
\qt@newcmd\qurantrans@bn@mliv{এটি কি নির্দেশা‌ত্মক নয় তাদের জন্য যারা দেশের উত্তরাধিকারপ্রাপ্ত হয় তার বাসিন্দাদের পরে, যে যদি আমরা ইচ্ছা করি তবে তাদেরও আমরা আঘাত হানতে পারি তাদের অপরাধের জন্য, আর তাদের হৃদয়ের উপরে সিল এঁটে দিতে পারি, ফলে তারা শুনবে না?\qt@no{(100)}}
\qt@newcmd\qurantrans@bn@mlv{এই জনবসতিগুলো -- তাদের কাহিনী থেকে কিছুটা আমরা তোমার কাছে বর্ণনা করছি। আর নিশ্চয়ই তাদের কাছে তাদের রসূলগণ এসেছিলেন স্পষ্ট প্রমাণাবলী নিয়ে, কিন্তু তাদের বিশ্বাস করবার অবস্থা ছিল না তাতে যা তারা ইতিপূর্বে অবিশ্বাস করেছিল। এইভাবে আল্লাহ্ মোহর মেরে দেন অবিশ্বাসীদের হৃদয়ের উপরে।\qt@no{(101)}}
\qt@newcmd\qurantrans@bn@mlvi{আর তাদের বেশিরভাগের মধ্যে আমরা প্রতি‌শ্রুতি পালনের কিছুই পাই নি, বরং তাদের অধিকাংশকে অবশ্যই পেয়েছি ডাহা অসৎকর্মা।\qt@no{(102)}}
\qt@newcmd\qurantrans@bn@mlvii{অবশেষে তাদের পরে আমরা মূসাকে নিযুক্ত করেছিলাম ফিরআউন ও তার পরিষদবর্গের কাছে আমাদের নির্দেশাবলী সঙ্গে দিয়ে, কিন্তু তারা এগুলোর প্রতি অবিচার করেছিল, অতএব দেখো কেমন হয়েছিল বিপর্যয় সৃষ্টিকারীদের পরিণাম!\qt@no{(103)}}
\qt@newcmd\qurantrans@bn@mlviii{আর মূসা বললেন -- ''হে ফিরআউন, নিঃসন্দেহ আমি বিশ্বজগতের প্রভুর তরফ থেকে একজন রসূল, --\qt@no{(104)}}
\qt@newcmd\qurantrans@bn@mlix{''স্থিরনিশ্চিত যে আল্লাহ্ সন্বন্ধে আমি সত্য ছাড়া বলবো না। আমি তোমাদের কাছে এসেছি তোমাদের প্রভুর কাছ থেকে স্পষ্ট প্রমাণাবলী নিয়ে, সুতরাং আমার সঙ্গে পাঠিয়ে দাও ইসরাইলবংশীয় লোকদের।’’\qt@no{(105)}}
\qt@newcmd\qurantrans@bn@mlx{সে বললে -- ''যদি তুমি কোনো নিদর্শন নিয়ে এসে থাকো তবে তা উপস্থাপিত করো, যদি তুমি সত্যবাদীদের মধ্যেকার হও।’’\qt@no{(106)}}
\qt@newcmd\qurantrans@bn@mlxi{কাজেই তিনি তাঁর লাঠি নিক্ষেপ করলেন, তখন আশ্চর্য! তা হলো এক স্পষ্ট সাপ।\qt@no{(107)}}
\qt@newcmd\qurantrans@bn@mlxii{আর তিনি তাঁর হাত বের করলেন, তখন আশ্চর্য! তা হলো দর্শকদের কাছে সাদা।\qt@no{(108)}}
\qt@newcmd\qurantrans@bn@mlxiii{ফিরআউনের লোকদের প্রধানরা বললে -- ''নিঃসন্দেহ এ একজন বিজ্ঞ জাদুকর।’’\qt@no{(109)}}
\qt@newcmd\qurantrans@bn@mlxiv{''সে চায় তোমাদের দেশ থেকে তোমাদের বের করে দিতে, কাজেই তোমরা কি পরামর্শ দাও?’’\qt@no{(110)}}
\qt@newcmd\qurantrans@bn@mlxv{তারা বললে -- ''তাকে ও তার ভাইকে কিঞ্চিৎ অবকাশ দাও, আর শহরে-নগরে পাঠাও তলবকারীদের --\qt@no{(111)}}
\qt@newcmd\qurantrans@bn@mlxvi{''তোমার কাছে তারা নিয়ে আসুক প্রত্যেক ঝানু জাদুকর।’’\qt@no{(112)}}
\qt@newcmd\qurantrans@bn@mlxvii{আর জাদুকররা ফিরআউনের কাছে এলো। তারা বললে -- ''আমাদের পুরস্কার থাকা চাই যদি আমরা নিজেরা বিজেতা হই।’’\qt@no{(113)}}
\qt@newcmd\qurantrans@bn@mlxviii{সে বললে -- ''হাঁ আর আলবৎ তোমরা হবে নিকটবর্তীদের অন্তর্ভুক্ত।’’\qt@no{(114)}}
\qt@newcmd\qurantrans@bn@mlxix{তারা বললে -- ''হে মূসা! তুমি কি নিক্ষেপ করবে, না আমরাই হবো নিক্ষেপকারী?\qt@no{(115)}}
\qt@newcmd\qurantrans@bn@mlxx{তিনি বললেন -- ''তোমরাই ফেলো।’’ অতঃপর যখন তারা ফেললো তখন লোকদের চোখে ধাঁধাঁ লাগিয়ে দিল আর তাদের ভয়াতুর করলো, আর তারা নিয়ে এলো এক বড় রকমের জাদু!\qt@no{(116)}}
\qt@newcmd\qurantrans@bn@mlxxi{তখন আমরা মূসাকে প্রত্যাদেশ দিলাম যে -- ''তোমার লাঠি নিক্ষেপ করো।’’ তখন কি আশ্চর্য! তা গ্রাস করতে লাগলো যা তারা রচনা করেছিল।\qt@no{(117)}}
\qt@newcmd\qurantrans@bn@mlxxii{কাজেই সত্য প্রতিষ্ঠা লাভ করলো এবং তারা যা করছিল তা বাতিল হয়ে গেল।\qt@no{(118)}}
\qt@newcmd\qurantrans@bn@mlxxiii{সুতরাং তারা সেইখানেই পরাভূত হলো, আর তারা মোড় ফেরালো ছোট হয়ে।\qt@no{(119)}}
\qt@newcmd\qurantrans@bn@mlxxiv{আর জাদুকররা লুটিয়ে পড়লো সিজদারত অবস্থায়।\qt@no{(120)}}
\qt@newcmd\qurantrans@bn@mlxxv{তারা বললে -- ''আমরা ঈমান আনলাম বিশ্বজগতের প্রভুর প্রতি --\qt@no{(121)}}
\qt@newcmd\qurantrans@bn@mlxxvi{''মূসা ও হারূনের প্রভু।’’\qt@no{(122)}}
\qt@newcmd\qurantrans@bn@mlxxvii{ফিরআউন বললে -- ''তোমরা তাতে বিশ্বাস করছ আমি তোমাদের অনুমতি দেবার আগেই! নিশ্চয় এটি এক চক্রান্ত যা তোমরা এ শহরে ফেদেছঁ যেন তোমরা এ থেকে এর লোকদের বার করে দিতে পারো। বেশ, শীঘ্রই তোমরা টের পাবে!\qt@no{(123)}}
\qt@newcmd\qurantrans@bn@mlxxviii{''আমি আলবৎ তোমাদের হাত ও তোমাদের পা উল্টো-পাল্টা কেটে দেবো, তারপর তোমাদের নিশ্চয়ই শূলে চড়াবো একসঙ্গে।’’\qt@no{(124)}}
\qt@newcmd\qurantrans@bn@mlxxix{তারা বললে -- ''নিঃসন্দেহ আমাদের প্রভুর কাছেই আমরা প্রত্যাবর্তনকারী।\qt@no{(125)}}
\qt@newcmd\qurantrans@bn@mlxxx{''আর তুমি আমাদের উপরে প্রতিহিংসা নিচ্ছ না শুধু এজন্য ছাড়া যে আমরা বিশ্বাস স্থাপন করেছি আমাদের প্রভুর নির্দেশাবলীতে যখন সে-সব আমাদের কাছে এসেছিল। 'আমাদের প্রভু! আমাদের উপরে ধৈর্য বর্ষণ করো, আর আমাদের মৃত্যু ঘটাও মুসলিমরূপে।’’\qt@no{(126)}}
\qt@newcmd\qurantrans@bn@mlxxxi{আর ফিরআউনের লোকদের প্রধানরা বললে -- ''আপনি কি মূসাকে ও তার লোকদের ছেড়ে দেবেন দেশে বিপর্যয় সৃষ্টি করতে এবং আপনাকে এবং আপনার দেবতাদের পরিত্যাগ করতে?’’ সে বললে -- ''আমরা তাদের পুত্রদের অবশ্যই হত্যা করবো আর তাদের কন্যাদের বাঁচতে দেবো, আর আমরা আলবৎ তাদের উপরে প্রতাপশালী।’’\qt@no{(127)}}
\qt@newcmd\qurantrans@bn@mlxxxii{মূসা তাঁর লোকদের বললেন -- ''আল্লাহ্‌র কাছে সাহায্য চাও ও ধৈর্য ধারণ করো, নিঃসন্দেহ পৃথিবী তো আল্লাহ্‌র, তিনি তার উত্তরাধিকার দেবেন তাঁর বান্দাদের মধ্যের যাদের তিনি পছন্দ করেন। আর পরিণাম হচ্ছে ধর্মপরায়ণদেরই জন্যে।’’\qt@no{(128)}}
\qt@newcmd\qurantrans@bn@mlxxxiii{তারা বললে -- ''আমরা অত্যাচারিত হয়েছি আমাদের কাছে তোমার আগমনের আগে এবং আমাদের কাছে তোমার আসার পরেও।’’ তিনি বললেন -- ''হতে পারে তোমাদের প্রভু তোমাদের শত্রুদের ধ্বংস করবেন, আর অচিরেই তোমাদের তিনি প্রতিনিধি ঠাওরাবেন দেশের মধ্যে, যেন তিনি দেখতে পারেন কেমনভাবে তোমরা কাজ করো।’’\qt@no{(129)}}
\qt@newcmd\qurantrans@bn@mlxxxiv{আর আমরা নিশ্চয়ই ফিরআউনের লোকদের পাকড়াও করেছিলাম বহুবৎসরের খরা আর ফল-ফসলের ক্ষতি দিয়ে, যেন তারা অনুধাবন করে।\qt@no{(130)}}
\qt@newcmd\qurantrans@bn@mlxxxv{কিন্তু যখন তাদের কাছে ভালো অবস্থা আসতো, তারা বলতো -- ''এ-সব আমাদের জন্য।’’ আর যখন মন্দ অবস্থা তাদের উপরে ঘটতো তারা আরোপ করতো মূসার ও তাঁর সঙ্গে যারা ছিল তাদের উপরে। একি নয় যে নিঃসন্দেহ তাদের ক্রিয়াকলাপ আল্লাহ্‌র কাছে রয়েছে? কিন্তু তাদের অধিকাংশই জানে না।\qt@no{(131)}}
\qt@newcmd\qurantrans@bn@mlxxxvi{আর তারা বললে -- ''তুমি নিদর্শন থেকে যে কোনোটাই আমাদের কাছে আনো না কেন তা দিয়ে আমাদের জাদু করতে, আমরা কিন্তু তোমাতে বিশ্বাস স্থাপনকারী হবো না।’’\qt@no{(132)}}
\qt@newcmd\qurantrans@bn@mlxxxvii{তারপর আমরা তাদের উপরে পাঠালাম সুদূর প্রসারিত মৃত্যু, আর পঙ্গপাল ও উকুন, আর বেঙ ও রক্ত -- বিশদভাবে বর্ণিত নিদর্শনাবলী, কিন্তু তারা অহংকার করেছিল এবং তারা ছিল একটি অপরাধী সম্প্রদায়।\qt@no{(133)}}
\qt@newcmd\qurantrans@bn@mlxxxviii{আর যখন তাদের উপরে মড়কের আবির্ভাব হলো তারা বললে -- ''হে মূসা! তোমার প্রভুর কাছে আমাদের জন্য প্রার্থনা করো যেমন তিনি তোমার কাছে ওয়াদা করেছেন, তুমি যদি আমাদের কাছ থেকে মহামারী অপসারিত করে দাও তবে আমরা নিশ্চয়ই তোমাতে ঈমান আনবো আর তোমার সঙ্গে অবশ্যই ইসরাইলবংশীয়দের পাঠিয়ে দেবো।\qt@no{(134)}}
\qt@newcmd\qurantrans@bn@mlxxxix{কিন্তু যখন আমরা তাদের থেকে মহামারী দূর করলাম নির্দিষ্ট সময়ের জন্য যাতে তারা পৌঁছুল, দেখো! তারা ভঙ্গ করলো!\qt@no{(135)}}
\qt@newcmd\qurantrans@bn@mxc{সেজন্য আমরা তাদের থেকে শেষপরিণতি নিলাম, আর তাদের আমরা ডুবিয়ে দিয়েছিলাম সাগরের জলে যেহেতু তারা প্রত্যাখ্যান করেছিল আমাদের নির্দেশসমূহ, আর এতে তারা ছিল অমনোযোগী।\qt@no{(136)}}
\qt@newcmd\qurantrans@bn@mxci{আর আমরা উত্তরাধিকার দিয়েছিলাম সেই লোকদের যাদের দুর্বল গণ্য করা হয়েছিল, -- দেশের পূর্ব্বাঞ্চলসমূহ ও তার পশ্চিমাঞ্চল সমূহ -- যাতে আমরা সমৃদ্ধি অর্পণ করেছিলাম। আর তোমার প্রভুর মনোরম বাণী পরিপূর্ণ হয়েছিল ইসরাইলের বংশধরদের ক্ষেত্রে যেহেতু তারা ধৈর্য ধরেছিল। আর আমরা ভেঙ্গে ফেলেছিলাম ফিরআউন ও তার লোকেরা যা গড়ে ছিল, আর যে- সব তারা বানিয়েছিল।\qt@no{(137)}}
\qt@newcmd\qurantrans@bn@mxcii{আর আমরা ইসরাইল বংশীয় লোকদের সমূদ্র পার করিয়ে দিই, তারপর তারা এল এক জাতির সংস্পর্শে যারা তাদের অবশিষ্ট প্রতিমাগুলোর প্রতি আসক্ত ছিল। তারা বললে -- ''হে মূসা! আমাদের জন্য একটি দেবতা গড়ে দাও যেমন তাদের দেবতারা রয়েছে ।’’ তিনি বললেন -- ''তোমরা নিঃসন্দেহ এমন এক সম্প্রদায় যারা বোকামো করছো।\qt@no{(138)}}
\qt@newcmd\qurantrans@bn@mxciii{''নিঃসন্দেহ এদের ব্যাপারে -- যাতে তারা লিপ্ত রয়েছে তা ধ্বংসপ্রাপ্ত হতে যাচ্ছে, আর বৃথা যা তারা করে চলেছে।’’\qt@no{(139)}}
\qt@newcmd\qurantrans@bn@mxciv{তিনি বললেন -- ''আমি কি আল্লাহ্ ছাড়া তোমাদের জন্য অন্য উপাস্য খুঁজবো, অথচ তিনি তোমাদের শ্রেষ্ঠত্ব দিয়েছেন সমস্ত বিশ্বজগতের উপরে?’’\qt@no{(140)}}
\qt@newcmd\qurantrans@bn@mxcv{আর স্মরণ করো, আমরা তোমাদের উদ্ধার করেছিলাম ফিরআউনের লোকদের থেকে, তারা তোমাদের অত্যাচার করেছিল মর্মান্তিক শাস্তি দিয়ে, -- তারা তোমাদের পুত্রসন্তানদের হত্যা করতো ও বাচঁতে দিত তোমাদের কন্যাদের। আর এতে ছিল তোমাদের জন্য তোমাদের প্রভুর তরফ থেকে এক বিরাট সঙ্কট।\qt@no{(141)}}
\qt@newcmd\qurantrans@bn@mxcvi{আর আমরা মূসার সঙ্গে ওয়াদা করেছিলাম ত্রিশ রাত্রি, আর তা পূর্ণ করি দশ দিয়ে -- তাতে পূর্ণ হলো তাঁর প্রভুর নির্ধারিত চল্লিশ রাত্রি। আর মূসা তাঁর ভাই হারূনকে বললেন -- ''আমার সম্প্রদায়ের মধ্যে তুমি আমার প্রতিনিধিত্ব করবে ও ভালোভাবে চলবে, আর গন্ডগোল সৃষ্টিকারীদের পথ অনুসরণ করো না।’’\qt@no{(142)}}
\qt@newcmd\qurantrans@bn@mxcvii{আর যখন মূসা আমাদের নির্ধারিত-স্থলে এসে পৌঁছুলেন এবং তাঁর প্রভু তাঁর সাথে কথা বললেন, তিনি বললেন -- ''আমার প্রভু! আমাকে দর্শন দাও, আমি তোমাকে দেখবো।’’ তিনি বললেন -- ''তুমি কখনই আমাকে দেখতে পাবে না, বরং পাহাড়টির দিকে তাকাও, যদি তা তার জায়গায় স্থির থাকে তবে তুমি আমাকে দেখবে।’’ তারপর যখন তাঁর প্রভু পাহাড়টিতে জ্যোতিষ্মান হলেন তখন তিনি তাকে চূর্ণ-বিচূর্ণ করলেন, আর মূসা পড়ে গেলেন সংজ্ঞাহীন হয়ে। তারপর যখন তিনি চেতনা পেলেন, তিনি বললেন -- ''তোমারই সব মহিমা! আমি তোমারই দিকে ফিরছি, আর আমি হব মুমিনদের মধ্যে অগ্রণী।’’\qt@no{(143)}}
\qt@newcmd\qurantrans@bn@mxcviii{তিনি বললেন -- ''হে মূসা! নিঃসন্দেহ আমি তোমাকে নির্বাচন করেছি জনগণের উপরে আমার বাণী প্রেরণের দ্বারা ও আমার বাক্যালাপের দ্বারা, কাজেই তুমি ধারণ করো যা বিধান আমি তোমাকে দিয়েছি, আর কৃতজ্ঞদের মধ্যেকার হও।’’\qt@no{(144)}}
\qt@newcmd\qurantrans@bn@mxcix{আর আমরা তাঁর জন্য লিপিবদ্ধ করেছিলাম ফলকগুলোতে হরেক রকমের উপদেশ আর সব-কিছুর ব্যাখ্যা, -- ''এ-সব তাহলে শক্তভাবে ধারণ করো, আর তোমার লোকদের নির্দেশ দাও শ্রেষ্ঠগুলো গ্রহণ করতে। আমি অচিরেই তোমাদের দেখাবো সত্যত্যাগীদের বাসস্থান।’’\qt@no{(145)}}
\qt@newcmd\qurantrans@bn@mc{অচিরেই আমার নির্দেশাবলী থেকে আমি ফিরিয়ে দেবো তাদের যারা দেশের মধ্যে অন্যায়ভাবে অহংকার করে। আর যদিও তারা প্রত্যেকটি নিদর্শন দেখতে পায় তবু তারা ওতে বিশ্বাস করবে না, আর যদি তারা ভ্রান্ত পথের দেখা পায় তবে তাকে তারা পথ বলে গ্রহণ করে। এটি এজন্য যে তারা আমাদের নির্দেশ-সমূহকে প্রত্যাখ্যান করেছিল, আর তাতে তারা উদাসীন হয়েছিল।\qt@no{(146)}}
\qt@newcmd\qurantrans@bn@mci{আর যারা মিথ্যারোপ করেছিল আমাদের নির্দেশাবলীতে ও পরকালের মুলাকাতের সন্বন্ধে, তাদের ক্রিয়াকলাপ বৃথা হয়েছে। তাদের কি প্রতিফল দেয়া হবে যা তারা করে যাচ্ছিল তার বিপরীতে?\qt@no{(147)}}
\qt@newcmd\qurantrans@bn@mcii{আর মূসার লোকেরা তাঁর পরে গ্রহণ করলো তাদের অলংকার দিয়ে একটি গোবৎসকে -- একটি দেহ, যাতে ফোকলা আওয়াজ হতো। তারা কি দেখলো না যে এটি তো তাদের সঙ্গে কথা বলে না আর তাদের পথে পরিচালিতও করে না? তারা এটিকে গ্রহণ করলো, আর তারা ছিল অন্যায়কারী।\qt@no{(148)}}
\qt@newcmd\qurantrans@bn@mciii{আর যখন তাদের হাতে কামড় পড়লো আর দেখলো যে তারা বিপথে চলে গেছে, তারা বললে -- ''যদি না আমাদের প্রভু আমাদের প্রতি করুণা করেন ও আমাদের পরিত্রাণ করেন তবে আমরা আলবৎ ক্ষতিগ্রস্তদের অন্তর্ভুক্ত হবো।’’\qt@no{(149)}}
\qt@newcmd\qurantrans@bn@mciv{আর যখন মূসা ফিরে এলেন তাঁর লোকদের কাছে ক্ষুদ্ধ ও ত্রুদ্ধ হয়ে, তিনি বললেন -- ''আমার পরে তোমরা আমার স্থলে যা কারেছ তা জঘন্য! তোমরা কি তোমাদের প্রভুর বিচার এগিয়ে আনতে চাও?’’ আর তিনি ফলকগুলো ফেলে দিলেন, আর তাঁর ভাইয়ের মাথা ধরলেন তাঁর দিকে তাঁকে টেনে আনতে। তিনি বললেন -- ''হে আমার সহোদর! নিঃসন্দেহ লোকেরা আমাকে দুর্বল ঠাওরেছিল ও আমাকে প্রায় মেরেই ফেলেছিল। সুতরাং আমার দশায় শত্রুদের পুলকিত করো না, আর, আমাকে পাপিষ্ঠ লোকদের দলভুক্ত করো না।’’\qt@no{(150)}}
\qt@newcmd\qurantrans@bn@mcv{তিনি বললেন -- ''আমার প্রভু! আমাকে ও আমার ভাইকে পরিত্রাণ করো, আর আমাদের দাখিল করো তোমার অনুগ্রহের মধ্যে, কেননা তুমিই দয়ালুদের মধ্যে শ্রেষ্ঠ করুণাময়।’’\qt@no{(151)}}
\qt@newcmd\qurantrans@bn@mcvi{নিঃসন্দেহ যারা গো-বৎসকে গ্রহণ করেছিল তাদের পাকড়াও করবে তাদের প্রভুর ক্রোধ ও লাঞ্ছনা এই দুনিয়ার জীবনে। আর এইভাবেই আমরা প্রতিফল দিই মিথ্যারচনাকারীদের।\qt@no{(152)}}
\qt@newcmd\qurantrans@bn@mcvii{আর যারা অসদাচরণ করে আর তারপরে ফেরে ও বিশ্বাস করে, -- নিঃসন্দেহ তোমার প্রভু তো এর পরে পরম ক্ষমাশীল, অফুরন্ত ফলদাতা।\qt@no{(153)}}
\qt@newcmd\qurantrans@bn@mcviii{আর মূসা থেকে ক্রোধ যখন প্রশমিত হলো তিনি তখন ফলকগুলো তুলে নিলেন, সে-সবের লেখনে ছিল পথনির্দেশ ও করুণা, তাদের জন্য যারা তাদের প্রভুর প্রতি ভয় করে।\qt@no{(154)}}
\qt@newcmd\qurantrans@bn@mcix{আর মূসা তাঁর সম্প্রদায়ের মধ্যে সত্তর জন লোককে বাছাই করলেন আমাদের নির্ধারিত স্থলের জন্য, কাজেই যখন ভূমিকম্প তাদের পাকড়ালো, তিনি বললেন -- ''আমার প্রভু! তুমি যদি ইচ্ছা করতে তবে এর আগেই তো তুমি তাদের ধ্বংস করতে পারতে, আর আমাকেও। তুমি কি আমাদের ধ্বংস করবে আমাদের মধ্যের নির্বোধরা যা করেছে তার জন্যে? এ তোমার পরীক্ষা বৈ তো নয়। এর দ্বারা তুমি বিপথগামী করো যাদের তুমি ইচ্ছা করো, আর সৎপথে চালাও যাদের তুমি ইচ্ছা করো। তুমিই আমাদের অভিভাবক, অতএব আমাদের পরিত্রাণ করো ও আমাদের প্রতি করুণা করো, কারণ তুমিই পরিত্রাণকারীদের মধ্যে সর্বোত্তম।\qt@no{(155)}}
\qt@newcmd\qurantrans@bn@mcx{''আর আমাদের জন্য বিধান করো এই দুনিয়াতেই কল্যাণ এবং পরকালেও, আমরা নিঃসন্দেহ তোমার দিকেই ফিরছি।’’ তিনি বললেন -- ''আমার শাস্তি -- তা দিয়ে আমি আঘাত হানবো যাকে ইচ্ছা করবো, কিন্তু আমার করুণা -- তা সব-কিছুই পরিবেষ্ঠন করে। সুতরাং আমি তা বিধান করবো তাদের জন্য যারা ধর্মভীরুতা অবলন্বন করে, আর যাকাত আদায় করে, আর যারা আমাদের নির্দেশাবলীতে বিশ্বাস করে, --\qt@no{(156)}}
\qt@newcmd\qurantrans@bn@mcxi{''যারা অনুসরণ করে সেই রসূলকে -- নবী, উম্মী, যাঁকে তারা পায় উল্লিখিত রয়েছে তাদের কাছের তওরাতে ও ইঞ্জীলে, আর যিনি তাদের নির্দেশ দেন সৎকাজের ও তাদের নিষেধ করেন অসৎকাজ থেকে, আর তাদের জন্য বৈধ করেন ভালো বিষয়বস্তু ও তাদের জন্য নিষেধ করেন মন্দ জিনিসগুলো, আর যিনি তাদের থেকে দূর করে দেন তাদের বোঝা ও বন্ধন যা তাদের উপরে ছিল। অতএব যারা তাঁতে বিশ্বাস করে ও তাঁকে মান্য করে ও তাঁকে সাহায্য করে আর অনুসরণ করে সেই আলো যা তাঁর সঙ্গে অবতীর্ণ হয়েছে, -- এরা নিজেরাই হচ্ছে সফলকাম।’’\qt@no{(157)}}
\qt@newcmd\qurantrans@bn@mcxii{বলো -- ''ওহে জনগণ! আমি নিশ্চয়ই আল্লাহ্‌র রসূল তোমাদের সবার কাছে, -- মহাকাশমন্ডল ও পৃথিবীর সার্বভৌমত্ব যাঁর সেইজনেরই, তিনি ছাড়া অন্য উপাস্য নেই, তিনি জীবন দান করেন ও মৃত্যু ঘটান। সেজন্য আল্লাহ্‌তে বিশ্বাস করো ও তাঁর রসূলের প্রতি -- উম্মী নবী, যিনি ঈমান এনেছেন আল্লাহতে ও তাঁর বাণীসমূহে, আর তোমরাও তাঁর অনুসরণ করো যেন তোমরা সৎপথপ্রাপ্ত হতে পারো।’’\qt@no{(158)}}
\qt@newcmd\qurantrans@bn@mcxiii{আর মূসার সম্প্রদায়ের মধ্যেও একটি দল রয়েছে যারা পথ দেখায় সত্যের দ্বারা ও তার দ্বারা ন্যায়বিচার করে।\qt@no{(159)}}
\qt@newcmd\qurantrans@bn@mcxiv{আর আমরা তাদের বিভক্ত করেছিলাম বারোটি গোত্রে দলে। আর মূসার কাছে আমরা প্রেরণা দিলাম যখন তাঁর লোকেরা তাঁর কাছে পানি চাইল, এই বলে -- ''তোমার লাঠি দিয়ে পাথরে আঘাত করো।’’ তখন তা থেকে বারোটি ঝরনা প্রবাহিত হলো। প্রত্যেক গোত্র আপন জলপান-স্থান চিনে নিলো। আর তাদের উপরে আমরা মেঘ দিয়ে আচ্ছাদান করেছিলাম, আর তাদের কাছে পাঠিয়েছিলাম 'মান্না’ ও 'সালওয়া’, -- ''তোমাদের যা জীবিকা দিয়েছি তার ভালো ভালো জিনিস থেকে আহার করো।’’ কিন্তু তারা আমাদের কোনো অনিষ্ট করে নি, বরং তারা তাদের নিজেদের প্রতি অনিষ্ট করছিল।\qt@no{(160)}}
\qt@newcmd\qurantrans@bn@mcxv{আর স্মরণ করো! তাদের বলা হয়েছিল -- ''এ জনবসতিতে বসবাস করো, আর এ থেকে আহার করো যখন-যেখানে ইচ্ছা করো, আর বলো 'হিৎতাতুন’, আর সদর-দরজা দিয়ে প্রবেশ করো নতমস্তকে, তোমাদের সমস্ত ভুলভ্রান্তি আমরা তোমাদের থেকে ক্ষমা করে দেবো। উপরন্তু আমরা বাড়িয়ে দেবো শুভকর্মীদের জন্য।’’\qt@no{(161)}}
\qt@newcmd\qurantrans@bn@mcxvi{কিন্তু তাদের মধ্যে যারা অন্যায় করেছিল তারা তাদের যা বলা হয়েছিল তার বিপরীত কথায় তা বদলে দিল, সেজন্য তাদের উপরে আমরা আকাশ থেকে পাঠালাম মহামারী, যেহেতু তারা অন্যায় ক’রে চলছিল।\qt@no{(162)}}
\qt@newcmd\qurantrans@bn@mcxvii{আর তাদের জিজ্ঞাসা করো সেই জনবসতি সন্বন্ধে যারা ছিল সমুদ্রের কিনারে। স্মরণ করো! তারা সব্বাতের উল্লঙ্ঘন করেছিল, কারণ তাদের মাছগুলো তাদের কাছে আসতো তাদের সাব্বাতের দিনে ঝাঁকে-ঝাঁকে, আর যেদিন তারা সব্বাত পালন করতো না তারা তাদের কাছে আসতো না। এইভাবে আমরা তাদের নিয়ন্ত্রিত করেছিলাম, কেননা তারা পাপাচার করে চলতো।\qt@no{(163)}}
\qt@newcmd\qurantrans@bn@mcxviii{আর যখন তাদের মধ্যের একটি দল বললে -- ''কেন তোমরা সেই লোকদের উপদেশ দিচ্ছ আল্লাহ্ যাদের ধ্বংস করতে যাচ্ছেন অথবা কঠোর শাস্তিতে শাস্তি দিতে যাচ্ছেন’’? তাঁরা বললেন -- ''তোমাদের প্রভুর কাছে দোষমুক্ত হবার জন্য, আর যাতে তারা ধর্মপরায়ণতা অবলন্বন করে।’’\qt@no{(164)}}
\qt@newcmd\qurantrans@bn@mcxix{কিন্তু যখন তারা বিস্মৃত হলো যা তাদের স্মরণ করিয়ে দেয়া হয়েছিল, আমরা উদ্ধার করেছিলাম তাদের যারা নিষেধ করতো অসৎকাজ থেকে, আর যারা অন্যায় করে তাদের আমরা পাকড়াও করলাম কঠিন শাস্তিতে, যেহেতু তারা পাপাচার করতো।\qt@no{(165)}}
\qt@newcmd\qurantrans@bn@mcxx{তারপর যখন তারা তাচ্ছিল্য করলো তাতে যা করতে তাদের নিষেধ করা হয়েছিল তখন আমরা তাদের বললাম -- ''তোমরা ঘৃণ্য বানর হয়ে যাও।’’\qt@no{(166)}}
\qt@newcmd\qurantrans@bn@mcxxi{আর স্মরণ করো! তোমার প্রভু ঘোষণা করলেন যে তিনি তাদের বিরুদ্ধে কিয়ামতের দিন পর্যন্ত নিযুক্ত করবেন যারা তাদের পীড়ন করবে কঠিন নিপীড়নে। নিশ্চয় তোমার প্রভু তো প্রতিফল-দানে তৎপর এবং তিনি তো নিশ্চয়ই পরিত্রাণকারী, অফুরন্ত ফলদাতা।\qt@no{(167)}}
\qt@newcmd\qurantrans@bn@mcxxii{আর আমরা পৃথিবীতে তাদের বিভক্ত করেছি বিভিন্ন দলে, তাদের মধ্যে কেউ-কেউ সৎপথাবলন্বী, আর তাদের কতক এর বিপরীত। আর আমরা তাদের নিয়ন্ত্রিত করেছি ভালো দিয়ে ও মন্দ দিয়ে, যেন তারা ফিরে আসে।\qt@no{(168)}}
\qt@newcmd\qurantrans@bn@mcxxiii{অতঃপর তাদের পরে স্থলাভিষিক্ত হয়েছিল এক উত্তরপুরুষ যারা গ্রন্থ উত্তরাধিকার করেছিল, তারা আঁকড়ে ধরেছিল এই সাধারণ জীবনের তুচ্ছ-বস্তুসব আর বলতো -- ''আমাদের তো মাফ করে দেয়া হবে।’’ আর যদি তাদের কাছে তার মতো বস্তুগুলো আসে তবে তারা তা গ্রহণ করে। তাদের কাছ থেকে কি গ্রন্থের অঙ্গীকার নেওয়া হয় নি যে তারা আল্লাহ্ সন্বন্ধে সত্য ছাড়া আর কিছু বলবে না, আর তারা পাঠও করেছে যা তাতে রয়েছে? আর পরকালের বাসস্থানই শ্রেয় তাদের জন্য যারা ধর্মভীরুতা অবলন্বন করে। তোমরা কি তবে বুঝো না?\qt@no{(169)}}
\qt@newcmd\qurantrans@bn@mcxxiv{আর যারা কিতাব শক্তভাবে ধারণ করে ও নামায কায়েম করে -- আমরা নিশ্চয় সৎকর্মশীলদের কর্মফল বিনষ্ট করি না।\qt@no{(170)}}
\qt@newcmd\qurantrans@bn@mcxxv{আরোও স্মরণ করো! আমরা তাদের উপরে পর্বতকে কম্পিত করলাম তা যেন হয়েছিল একটি আচ্ছাদন, আর তারা ভেবেছিল যে এ নিশ্চয়ই তাদের উপরে ভেঙ্গে পড়েছে, ''আমরা তোমাদের যা দিয়েছি তা দৃঢ়ভাবে আকঁড়ে ধরো, আর তাতে যা রয়েছে তা স্মরণ রেখো, যাতে তোমরা ধর্মভীরুতা অবলন্বন করো’’।\qt@no{(171)}}
\qt@newcmd\qurantrans@bn@mcxxvi{আর স্মরণ করো! তোমার প্রভু আদমের বংশধরদের থেকে -- তাদের পৃষ্ঠদেশ থেকে -- তাদের সন্তান-সন্ততি এনেছিলেন, আর তাদের নিজেদের সন্বন্ধে তাদের সাক্ষ্য দিইয়েছিলেন -- ''আমি কি তোমাদের প্রভু নই?’’ তারা বলেছিল -- ''হাঁ, আমরা সাক্ষ্য দিচ্ছি।’’ এজন্য যে পাছে তোমরা কিয়ামতের দিনে বলো -- ''আমরা তো এ বিষয়ে অজ্ঞাত ছিলাম,’’ --\qt@no{(172)}}
\qt@newcmd\qurantrans@bn@mcxxvii{অথবা তোমরা বলো -- ''আসল ব্যাপার হচ্ছে আমাদের পূর্বপুরুষরা এর আগেই অংশীদার ঠাওরেছিল, আর আমরা তাদের পরবর্তীকালে বংশধরই ছিলাম। তুমি কি তবে আমাদের ধ্বংস করবে ভ্রষ্টাচারীরা যা করেছিল সেজন্য?\qt@no{(173)}}
\qt@newcmd\qurantrans@bn@mcxxviii{আর এইভাবে আমাদের নির্দেশাবলী আমরা ব্যাখ্যা করি যেন তারা ফিরে আসে।\qt@no{(174)}}
\qt@newcmd\qurantrans@bn@mcxxix{আর তাদের কাছে পাঠ করো ওর বৃত্তান্ত যাকে আমরা আমাদের নির্দেশাবলী প্রদান করেছিলাম, কিন্তু সে সে-সব থেকে গুটিয়ে নেয়, সেজন্য শয়তান তার পিছু নেয়, কাজেই সে বিপথ-গামীদের অন্তর্ভুক্ত হয়।\qt@no{(175)}}
\qt@newcmd\qurantrans@bn@mcxxx{আর যদি আমরা ইচ্ছা করতাম তবে নিশ্চয়ই এর দ্বারা তাকে আমরা উন্নীত করতাম, কিন্তু সে মাটি আকঁড়ে ধরলো, আর সে তার হীন-কামনার অনুসরণ করে চললো। সুতরাং তার উপমা হচ্ছে কুকুরের দৃষ্টান্তের মতো -- ওকে যদি তুমি তাড়া করো, সে জিব বের ক’রে হাঁপাবে, আর যদি তুমি তাকে এড়িয়ে চলো সে জিব বার করে হাঁপাবে। এই হচ্ছে সে-সব লোকের দৃষ্টান্ত যারা আমাদের নির্দেশসমূহ প্রত্যাখ্যান করে। তুমি ইতিবৃত্ত বিবৃত করো যেন তারা চিন্তা করতে পারে।\qt@no{(176)}}
\qt@newcmd\qurantrans@bn@mcxxxi{মন্দের দৃষ্টান্ত সেই লোকেরা যারা আমাদের বাণীসমূহে মিথ্যারোপ করে, আর তাদের অন্তরা‌ত্মার প্রতিই তারা অত্যাচার করে চলে!\qt@no{(177)}}
\qt@newcmd\qurantrans@bn@mcxxxii{যাকে আল্লাহ্ পথ দেখান সে-ই তবে সৎপথে চালিত, আর যাকে তিনি বিপথে চলতে দেন, তাহলে তারা নিজেরাই ক্ষতিগ্রস্ত হয়।\qt@no{(178)}}
\qt@newcmd\qurantrans@bn@mcxxxiii{আর আমরা জাহান্নামের জন্য নিশ্চয়ই ছড়িয়ে দিয়েছি জিন ও মানুষের মধ্যের অনেককে, -- তাদের হৃদয় আছে তা দিয়ে তারা বুঝে না, আর তাদের চোখ আছে তা দিয়ে তারা দেখে না, আর তাদের কান আছে তা দিয়ে তারা শোনে না। তারা গবাদি-পশুর ন্যায়, বরং তারা আরো পথভ্রষ্ট। তারা নিজেরাই হচ্ছে উদাসীন।\qt@no{(179)}}
\qt@newcmd\qurantrans@bn@mcxxxiv{আর আল্লাহ্‌রই হচ্ছে সবচাইতে ভালো নামাবলী, কাজেই তাঁকে ডাকো সেই সবের দ্বারা, আর তাদের ছেড়ে দাও যারা তাঁর নামাবলী নিয়ে বিকৃতি করে। অচিরেই তাদের প্রতিফল দেয়া হবে তারা যা করে যাচ্ছে তার জন্য।\qt@no{(180)}}
\qt@newcmd\qurantrans@bn@mcxxxv{আর যাদের আমরা সৃষ্টি করেছি তাদের মধ্যে আছে একটি দল যারা পথ দেখায় সত্যের দ্বারা, আর তার দ্বারা তারা ন্যায়পরায়ণতা করে।\qt@no{(181)}}
\qt@newcmd\qurantrans@bn@mcxxxvi{আর যারা আমাদের বাণীসমূহে মিথ্যারোপ করে তাদের আমরা ক্রমাগত টেনে নিয়ে যাই, -- কোথা থেকে তা তারা জানে না।\qt@no{(182)}}
\qt@newcmd\qurantrans@bn@mcxxxvii{আর আমি তাদের অবসর দিই, নিঃসন্দেহ আমার ব্যবস্থা অত্যন্ত বলিষ্ঠ।\qt@no{(183)}}
\qt@newcmd\qurantrans@bn@mcxxxviii{তারা কি চিন্তা করে না? তাদের সহচরের মধ্যে কোনো পাগলামি নেই। বাস্তবে তিনি তো এক সুস্পষ্ট সতর্ককারী।\qt@no{(184)}}
\qt@newcmd\qurantrans@bn@mcxxxix{তারা কি তাকায় না মহাকাশমন্ডল ও পৃথিবীর সাম্রাজ্যের প্রতি আর যা-কিছু আল্লাহ্ সৃষ্টি করেছেন, আর হতে পারে তাদের নির্ধারিত কাল ঘনিয়ে এসেছে? এর পরে আর কোন পর্যালোচনার দ্বারা তারা তবে বিশ্বাস করবে?\qt@no{(185)}}
\qt@newcmd\qurantrans@bn@mcxl{যাকে আল্লাহ্ বিপথে যেতে দেন তার জন্যে তবে কোনো পথপ্রদর্শক নেই। আর তাদের তিনি ছেড়ে দেন তাদের অবাধ্যতায় উদভ্রান্তভাবে ঘুরপাক খেতে।\qt@no{(186)}}
\qt@newcmd\qurantrans@bn@mcxli{তারা তোমাকে ঘড়িঘন্টা সন্বন্ধে জিজ্ঞাসা করছে -- কখন তা ঘটবে। বলো -- ''এর জ্ঞান অবশ্যই রয়েছে আমার প্রভুর কাছে, এর সময় সন্বন্ধে তা প্রকাশ করতে পারে না তিনি ছাড়া কেউ। এ অতি গুরুতর ব্যাপার মহাকাশমন্ডলে ও পৃথিবীতে, এ এসে পড়বে না তোমাদের উপরে অতর্কিতে ছাড়া।’’ তারা তোমাকে জিজ্ঞাসা করছে যেন তুমিই এ বিষয়ে আগ্রহী। বলো -- ''এর জ্ঞান আলবৎ আল্লাহ্‌র কাছে, কিন্তু অধিকাংশ লোকই জানে না।’’\qt@no{(187)}}
\qt@newcmd\qurantrans@bn@mcxlii{বলো -- ''আমার কোনো অধিকার নেই আমার নিজেরই কোনো লাভ বা ক্ষতি করবার -- আল্লাহ্ যা চান তা-ব্যতীত। আর যদি আমি অদৃশ্যের সম্যক্ জ্ঞান রাখতাম তবে কল্যাণের প্রাচুর্য বানিয়ে নিতাম, আর কোনো অনিষ্ট আমাকে স্পর্শ করতো না। আমি তো একজন সতর্ককারী বই নই, আর একজন সুসংবাদদাতা সেই লোকদের জন্য যারা ঈমান এনেছে।\qt@no{(188)}}
\qt@newcmd\qurantrans@bn@mcxliii{তিনিই সেইজন যিনি তোমাদের সৃষ্টি করেছেন একই নফস থেকে, আর তা থেকে তিনি তৈরি করেছেন তার সঙ্গিনী যেন সে তার মধ্যে শান্তি পেতে পারে। অতএব যখন সে তাতে উপগত হয় সে তখন একটি হাল্কা বোঝা ধারণ করে আর তা নিয়ে চলাফেরা করে, তারপর যখন তা ভারী হয়ে উঠে তখন উভয়ে আহ্বান করে তাদের প্রভু আল্লাহ্‌কে -- ''যদি তুমি আমাদের সুষ্ঠু একটি দাও আমরা তবে নিশ্চয়ই হবো কৃতজ্ঞদের অন্তর্ভুক্ত।’’\qt@no{(189)}}
\qt@newcmd\qurantrans@bn@mcxliv{কিন্তু তিনি যখন তাদের সুষ্ঠু একটি দান করলেন তারা তাঁর সঙ্গে দাঁড় করালো অংশীদার তিনি তাদের যা দিয়েছেন তার সন্বন্ধে। কিন্তু বহু উচ্চে অবস্থিত আল্লাহ্ তারা যা অংশী বানায় সে-সব থেকে।\qt@no{(190)}}
\qt@newcmd\qurantrans@bn@mcxlv{তারা কি অংশীদার বসায় তাকে যে কিছুই সৃষ্টি করে না, বরং তাদেরই সৃষ্টি করা হয়েছে?\qt@no{(191)}}
\qt@newcmd\qurantrans@bn@mcxlvi{আর ওরা কোনো ক্ষমতা রাখে না তাদের সাহায্য করার, আর তারা তাদের নিজেদেরও সাহায্য করতে পারে না।\qt@no{(192)}}
\qt@newcmd\qurantrans@bn@mcxlvii{আর যদি তোমরা তাদের আহ্বান করো সৎপথের প্রতি, তারা তোমাদের অনুসরণ করবে না। তোমরা তাদের আহ্বান করো অথবা তোমরা চুপচাপ থাকো, তোমাদের জন্যে সমান।\qt@no{(193)}}
\qt@newcmd\qurantrans@bn@mcxlviii{নিঃসন্দেহ তোমরা আল্লাহ্‌কে ছেড়ে দিয়ে যাদের আহ্বান কর তারা তোমাদেরই ন্যায় দাস, সুতরাং তাদের ডাকো, তোমাদের প্রতি তারা তবে সাড়া দিক, -- যদি তোমরা সত্যবাদী হও।\qt@no{(194)}}
\qt@newcmd\qurantrans@bn@mcxlix{তাদের কি পা আছে যা দিয়ে তারা চলতে পারে, অথবা তাদের কি হাত আছে যা দিয়ে ধরতে পারে, অথবা তাদের কি চোখ আছে যা দিয়ে দেখতে পারে, অথবা তাদের কি কান আছে যা দিয়ে তারা শুনতে পারে? বলো -- ''ডাকো তোমাদের অংশীদারদের, তারপর আমার বিরুদ্ধে ফন্দি আটোঁ, আর আমাকে অবকাশ দিও না!\qt@no{(195)}}
\qt@newcmd\qurantrans@bn@mcl{''নিঃসন্দেহ আমার অভিভাবক হচ্ছেন আল্লাহ্ যিনি কিতাব অবতারণ করেছেন, আর তিনিই অভিভাবকত্ব করেন সৎপথা- বলন্বীদের।\qt@no{(196)}}
\qt@newcmd\qurantrans@bn@mcli{''আর যাদের তোমরা আহ্বান কর তাঁকে ছেড়ে দিয়ে, তারা কোনো ক্ষমতা রাখে না তোমাদের সাহায্য করার, আর তাদের নিজেদেরও তারা সাহায্য করতে পারে না।’’\qt@no{(197)}}
\qt@newcmd\qurantrans@bn@mclii{আর যদি তোমরা তাদের আহ্বান কর সৎপথের প্রতি, তারা শোনে না। আর তুমি তাদের দেখতে পাও তারা তোমার দিকে তাকিয়ে আছে, কিন্তু তারা দেখতে পাবে না।\qt@no{(198)}}
\qt@newcmd\qurantrans@bn@mcliii{ক্ষমা অবলন্বন করো আর সদয়তার নির্দেশ দাও, আর অজ্ঞদের পরিহার করে চলো।\qt@no{(199)}}
\qt@newcmd\qurantrans@bn@mcliv{আর যদি শয়তানের থেকে খোঁচাখুচি তোমাকে আহত করে তবে আল্লাহ্‌র কাছে আশ্রয় চাও। নিঃসন্দেহ তিনি সর্ব শ্রোতা, সর্বজ্ঞাতা।\qt@no{(200)}}
\qt@newcmd\qurantrans@bn@mclv{নিঃসন্দেহ যারা ধর্মপরায়ণতা অবলন্বন করে, যখন শয়তানের আক্রমণ তাদের স্পর্শ করে তারা স্মরণ করে, -- তাহলে দেখো! তারাই হয় দৃষ্টিশক্তিমান!\qt@no{(201)}}
\qt@newcmd\qurantrans@bn@mclvi{আর তাদের ভাইয়েরা, -- তারা এদের টেনে নেয় ভ্রান্তির মধ্যে, আর তারা থামে না।\qt@no{(202)}}
\qt@newcmd\qurantrans@bn@mclvii{আর যখন তুমি তাদের কাছে কোনো আয়াত আনো না, তারা বলে -- ''কেন তুমি তা বেছে নাও না?’’ তুমি বলো -- ''আমি শুধু তারই অনুসরণ করি যা আমার কাছে প্রত্যাদিষ্ট হয়েছে আমার প্রভুর কাছ থেকে, এটি হচ্ছে তোমাদের প্রভুর কাছ থেকে দৃষ্টিদায়ক, আর পথনির্দেশক, আর হচ্ছে করুণা সেই লোকদের জন্য যারা বিশ্বাস করে।’’\qt@no{(203)}}
\qt@newcmd\qurantrans@bn@mclviii{আর যখন কুরআন পঠিত হয় তখন তা শোনো, আর চুপ করে থেকো, যেন তোমাদের প্রতি করুণা বর্ষিত হয়।\qt@no{(204)}}
\qt@newcmd\qurantrans@bn@mclix{আর স্মরণ করো তোমার প্রভুকে নিজের অন্তরে সবিনয়ে ও সভয়ে ও অনুচ্চস্বরে, প্রাতে ও অপরাহ্নে, আর উদাসীনদের অন্তর্ভুক্ত হয়ো না।\qt@no{(205)}}
\qt@newcmd\qurantrans@bn@mclx{নিঃসন্দেহ যারা তোমার প্রভুর সান্নিধ্যে রয়েছে তারা তাঁর উপাসনায় অহংকার দেখায় না, আর তারা তাঁরই মহিমা কীর্তন করে, আর তাঁরই প্রতি সিজদা প্রদান করে।\qt@no{(206)}}
\qt@newcmd\qurantrans@bn@mclxi{\basmalahbn তারা তোমাকে যুদ্ধে-লব্ধ ধনসম্পদ সন্বন্ধে জিজ্ঞাসা করছে। বলো -- ''যুদ্ধে-লব্ধ ধনসম্পত্তি আল্লাহ্ ও রসূলের জন্য। সুতরাং আল্লাহ্‌কে তোমরা ভয়ভক্তি করো, আর তোমাদের নিজেদের মধ্যে সাব স্থাপন করো, আর আল্লাহ্ ও তাঁর রসূলকে মেনে চলো যদি তোমরা মুমিন হও।’’\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mclxii{মুমিন তো কেবল তারাই যাদের হৃদয় ভয়ে কাঁপে যখন আল্লাহ্‌র কথা বলা হয়, আর যখন তাদের কাছে তাঁর বাণীসমূহ পাঠ করা হয় তা তাদের জন্য ধর্মবিশ্বাস বাড়িয়ে দেয়, আর তাদের প্রভুর উপরেই তারা নির্ভর করে, --\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mclxiii{যারা নামায কায়েম করে আর আমরা তাদের যা রিযেক দিয়েছি তা থেকে তারা খরচ করে থাকে।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mclxiv{তারা নিজেরাই হচ্ছে সত্যিকারের মুমিন। তাদের জন্য রয়েছে তাদের প্রভুর কাছে মর্যাদার স্তরসমূহ, আর পরিত্রাণ ও সম্মানজনক জীবিকা।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mclxv{যেমন, -- তোমার প্রভু তোমাকে তোমার বাড়িঘর থেকে বের ক’রে আনলেন সত্যের সাথে, যদিও মুমিনদের মধ্যের একটি দল অবশ্যই ছিল বিরূপভাবাপন্ন।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mclxvi{তারা তোমার সঙ্গে সত্য সন্বন্ধে বিতর্ক করছিল তা সুস্পষ্ট হবার পরেও, যেন তারা মৃত্যুর দিকে তাড়িত হচ্ছিল, আর তারা তাকিয়ে রয়েছিল।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mclxvii{আর স্মরণ করো! আল্লাহ্ তোমাদের প্রতি‌শ্রুতি দিয়েছিলেন দুই দলের একটি সন্বন্ধে যে তা তোমাদের হবে, আর তোমরা চেয়েছিলে যা অস্ত্রসজ্জিত নয় তাই তোমাদের হোক, অথচ আল্লাহ্ চেয়েছিলেন যেন সত্য সত্য প্রতিপন্ন হয় তাঁর বাণীর দ্বারা, আর যেন তিনি অবিশ্বাসীদের শিকড় কেটে দেন --\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mclxviii{যেন তিনি সত্যকে সত্য প্রতিপন্ন করেন ও মিথ্যাকে বাতিল করে দেন, যদিও অপরাধীরা তা অপছন্দ করে।’’\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mclxix{স্মরণ করো! তোমরা তোমাদের প্রভুর সাহায্য প্রার্থনা করেছিলে, তাই তিনি তোমাদের প্রতি সাড়া দিয়েছিলেন -- ''আমি নিশ্চয়ই তোমাদের সাহায্য করবো অক্ষুন্ন পরম্পরায় আগত ফিরিশ্‌তাদের একহাজার জন দিয়ে।’’\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mclxx{আর আল্লাহ্ এটি করেন নি সুসংবাদ দান ছাড়া আর যেন এর দ্বারা তোমাদের হৃদয় প্রশান্তি লাভ করে, আর সাহায্য তো আসে না আল্লাহ্‌র কাছ থেকে ছাড়া। নিঃসন্দেহ আল্লাহ্ হচ্ছেন মহাশক্তিশালী, পরমজ্ঞানী।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mclxxi{স্মরণ করো! তিনি তোমাদের উপরে প্রশান্তি এনেছিলেন তাঁর তরফ থকে স্বস্তিরূপে, আর তিনি তোমাদের উপরে আকাশ থেকে বর্ষণ করলেন বৃষ্টি, যেন তিনি এর দ্বারা তোমাদের পরিস্কার করতে পারেন, আর যেন তোমাদের থেকে দূর করতে পারেন শয়তানের নোংরামি, আর যেন তিনি তোমাদের অন্তরে বলসঞ্চার করতে পারেন, আর যেন এর দ্বারা পদক্ষেপ দৃঢ়প্রতিষ্ঠিত করতে পারেন।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mclxxii{স্মরণ করো! তোমার প্রভু ফিরিশ্‌তাদের কাছে প্রেরণা দিলেন -- ''আমি নিশ্চয়ই তোমাদের সাথে আছি, কাজেই যারা ঈমান এনেছে তাদের সুপ্রতিষ্ঠিত করো। আমি অচিরেই তাদের অন্তরে ভীতি সঞ্চার করবো যারা অবিশ্বাস পোষণ করে, অতএব ঘাড়ের উপরে আঘাত করো আর তাদের থেকে সমস্ত প্রত্যঙ্গ কেটে ফেলো।’’\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mclxxiii{এটি এইজন্য যে তারা আল্লাহ্ ও তাঁর রসূলের বিরোধিতা করে, আর যে কেউ আল্লাহ্ ও রসূলের বিরুদ্ধে দাঁড়ায় -- আল্লাহ্ তবে নিশ্চয়ই শাস্তিদানে কঠোর।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mclxxiv{''এটিই তোমাদের জন্য! অতএব এর আস্বাদ গ্রহণ করো! আর অবিশ্বাসীদের জন্য নিশ্চয়ই রয়েছে আগুনের শাস্তি।’’\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mclxxv{ওহে যারা ঈমান এনেছ! যারা অবিশ্বাস পোষণ করে তাদের যখন তোমরা দেখা পাও যুদ্ধযাত্রা করছে তখন তাদের দিকে পিঠ ফেরাবে না।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mclxxvi{আর যে কেউ সেইদিন তার পিঠ ফেরাবে -- যুদ্ধের কেশল অবলন্বন ব্যতীত, অথবা দলে যোগ দেবার জন্যে, -- সে তাহলে নিশ্চয়ই আল্লাহ্‌র ক্রোধ অর্জন করবে, আর তার আশ্রয় হবে জাহান্নাম, আর তা হচ্ছে নিকৃষ্ট গন্তব্যস্থল!\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mclxxvii{অতএব তোমরা তাদের বধ করো নি, বরং আল্লাহ্‌ই তাদের বধ করেছেন। আর তুমি ছুঁড়ে মারো নি যখন তুমি নিক্ষেপ করেছিলে বরং আল্লাহ্‌ই নিক্ষেপ করেছিলেন, আর যেন তিনি বিশ্বাসীদের প্রদান করেন তাঁর নিজের থেকে এক উত্তম পুরস্কার। নিঃসন্দেহ আল্লাহ্ সর্বশ্রোতা, সর্বজ্ঞাতা।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mclxxviii{এটিই তোমাদের জন্য! আর আল্লাহ্ অবশ্যই অবিশ্বাসীদের চক্রান্ত দুর্বলকারী।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mclxxix{তোমরা যখন বিজয়-কামনা করেছিলে তখন তোমাদের কাছে আলবৎ চূড়ান্ত বিজয় এসেছে। আর যদি তোমরা বিরত হও তবে তা হবে তোমাদের জন্য ভালো, কিন্তু যদি তোমরা ফিরে আসো, আমরাও ফিরে আসবো, আর তোমাদের ফৌজ তোমাদের কোনো কাজে আসবে না, যদিও তা সংখ্যাগরিষ্ঠ হোক। আর আল্লাহ্ নিঃসন্দেহ মুমিনদেরই সাথে রয়েছেন।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mclxxx{ওহে যারা ঈমান এনেছ! আল্লাহ্ ও তাঁর রসূলের আজ্ঞাপালন করো, আর তাঁর থেকে ফিরে যেও না যখন তোমরা শোনো।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mclxxxi{আর তোমরা তাদের মতো হয়ো না যারা বলেছিল -- ''আমরা শুনলাম’’, কিন্তু তারা শোনে নি।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mclxxxii{নিঃসন্দেহ আল্লাহ্‌র নিকট নিকৃষ্টতম জীব হচ্ছে -- বধির বোবা -- যারা বোঝে না।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mclxxxiii{আর আল্লাহ্ যদি তাদের মধ্যে ভালো কিছু জানতেন তবে তিনি আলবৎ তাদের শোনাতেন। কিন্তু যদিও তিনি তাদের শোনাতেন তবু তারা ফিরে যেতো, যেহেতু তারা বিমুখ।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mclxxxiv{ওহে যারা ঈমান এনেছ! আল্লাহ্ ও রসূলের প্রতি সাড়া দাও যখন তিনি তোমাদের আহ্বান করেন তাতে যা তোমাদের জীবন দান করে। আর জানো যে আল্লাহ্ মানুষের ও তার অন্তঃকরণের মাঝখানে বিরাজ করছেন, আর নিঃসন্দেহ তিনি -- তাঁরই কাছে তোমাদের একত্রিত করা হবে।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mclxxxv{আর ধর্মভীরুতা অবলন্বন করো সেই বিপদ সন্বন্ধে যা তোমাদের মধ্যের যারা অত্যাচারী শুধুমাত্র তাদের উপরেই পড়ে না। আর জেনে রেখো যে আল্লাহ্ আলবৎ প্রতিফল দানে কঠোর।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mclxxxvi{আর স্মরণ করো! যখন তোমরা ছিলে স্বল্পসংখ্যক, দুনিয়াতে তোমরা দুর্বলরূপে পরিগণিত হতে, তোমরা ভয় করতে যে লোকেরা তোমাদের আচমকা ধরে নিয়ে যাবে, তখন তিনি তোমাদের আশ্রয় দেন, আর তোমাদের বলবৃদ্ধি করেন তাঁর সাহায্যের দ্বারা, আর তোমাদের জীবিকা দান করলেন উত্তম বিষয়-বস্তু থেকে, যেন তোমরা ধন্যবাদ জানাতে পারো।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mclxxxvii{ওহে যারা ঈমান এনেছ! আল্লাহ্ ও রসূলের প্রতি বিশ্বাসভঙ্গ করো না, আর না তোমাদের আমানত খিয়ানত করবে, -- তাও তোমরা জেনে-শুনে।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mclxxxviii{আর জেনে রেখো যে নিঃসন্দেহ তোমাদের ধনদৌলত ও তোমাদের সন্তানসন্ততি তোমাদের জন্য এক পরীক্ষা, আর নিঃ সন্দেহ আল্লাহ্ -- তাঁরই কাছে রয়েছে বিরাট পুরস্কার।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mclxxxix{ওহে যারা ঈমান এনেছ! তোমরা যদি আল্লাহ্‌কে ভয়ভক্তি করো তবে তিনি তোমাদের দেবেন ফুরকান, আর তোমাদের থেকে তোমাদের মন্দ ঘুচিয়ে দেবেন, আর তোমাদের পরিত্রাণ করবেন। আর আল্লাহ্ বিপুল কল্যাণের অধিকর্তা।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mcxc{আর স্মরণ করো! যারা অবিশ্বাস পোষণ করে তারা তোমার বিরুদ্ধে ষড়যন্ত্র করেছিল যে তারা তোমাকে আটক করবে, অথবা তারা তোমাকে হত্যা করবে, অথবা তারা তোমাকে নির্বাসিত করবে। আর তারা ষড়যন্ত্র করেছিল, আর আল্লাহ্‌ও পরিকল্পনা করেছিলেন। আর পরিকল্পনাকারীদের মধ্যে আল্লাহ্‌ই শ্রেষ্ঠ।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mcxci{আর যখন তাদের কাছে আমাদের বাণী পড়ে শোনানো হয় তারা বলে -- ''আমরা ইতিমধ্যেই শুনেছি, আমরাও ইচ্ছা করলে এর ন্যায় অবশ্যই বলতে পারি, এ তো পুরাকালের উপকথা বৈ নয়’’।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mcxcii{আরও স্মরণ করো! তারা বলেছিল -- ''হে আল্লাহ্‌, এই যদি তোমার কাছ থেকে আসা যথার্থ সত্য হয় তবে আমাদের উপরে আকাশ থেকে পাথর বর্ষণ করো কিংবা আমাদের কাছে মর্মন্তুদ শাস্তি নিয়ে এস!’’\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mcxciii{আর আল্লাহ্ তাদের শাস্তি দেবেন না যতক্ষণ তুমি তাদের মধ্যে রয়েছে। আর আল্লাহ্ এরূপ নন যে তিনি তাদের শাস্তিদাতা হবেন যখন তারা ক্ষমা প্রার্থনা করে।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mcxciv{আর কি তাদের থাকতে পারে যে আল্লাহ্ তাদের শাস্তি দেবেন না যখন তারা পবিত্র মসজিদ থেকে বাধা দেয়, অথচ তারা এর তত্ত্বাবধায়ক হতে পারে না। এর তত্ত্বাবধায়ক হচ্ছে শুধু মুত্তকীরা, কিন্তু তাদের অধিকাংশই জানে না।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mcxcv{আর গৃহের নিকটে তাদের নামায শুধু শিস দেওয়া ও হাততালি দেওয়া ছাড়া আর কিছুই নয়। সুতরাং ''শাস্তির আস্বাদ গ্রহণ করো যেহেতু তোমরা অবিশ্বাস পোষণ করছিলে।’’\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mcxcvi{নিঃসন্দেহ যারা অবিশ্বাস পোষণ করে তারা তাদের ধনসম্পত্তি খরচ করে আল্লাহ্‌র পথ থেকে বাধা দেবার জন্যে। তারা এটা খরচ করবেই, তারপর এটি হবে তাদের জন্য মনস্তাপের কারণ, তারপর তাদের পরাজিত করা হবে। আর যারা অবিশ্বাস পোষণ করে তাদের জাহান্নামের দিকে একত্রিত করা হবে, --\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mcxcvii{যেন আল্লাহ্ পৃথক করতে পারেন মন্দকে ভালো থেকে, আর মন্দকে তিনি স্থাপন করবেন তাদের একটিকে অন্যটির উপরে, তারপর সবটাকে তিনি একত্রে স্তূপীকৃত করবেন এবং তাকে ফেলবেন জাহান্নামে। তারা নিজেরাই হচ্ছে ক্ষতিগ্রস্ত।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mcxcviii{যারা অবিশ্বাস পোষণ করে তাদের বলো -- যদি তারা নিবৃত্ত হয় তবে যা গত হয়ে গেছে তা তাদের ক্ষমা করা হবে, আর যদি তারা ফিরে যায় তবে পূর্ববর্তীদের ঘটনাবলী ইতিপূর্বে ঘটে গেছে।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mcxcix{আর তোমরা তাদের বিরুদ্ধে সংগ্রাম করতে থাকবে যতক্ষণ উৎপীড়ন আর না থাকে, আর ধর্ম তো সামগ্রিকভাবে আল্লাহ্‌র জন্যেই হবে। অতএব যদি তারা বিরত হয় তবে তারা যা করে আল্লাহ্ নিশ্চয়ই তার দর্শক।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mcc{কিন্তু যদি তারা ফিরে যায় তবে জেনে রেখো যে আল্লাহ্ নিঃসন্দেহ তোমাদের অভিভাবক, -- কতো উত্তম অভিভাবক ও উত্তম সাহায্যকারী!\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mcci{আর জেনে রেখো যা কিছু তোমরা যুদ্ধক্ষেত্রে লাভ করো তার পঞ্চমাংশ তাহলে আল্লাহ্‌র, জন্য যথা রসূলের জন্য, আর নিকটা‌ত্মীয়ের জন্য, আর এতীমদের, মিসকিনদের, ও পথচারীদের জন্য, যদি তোমরা বিশ্বাস করো আল্লাহ্‌তে আর তাতে যা আমরা আমাদের বান্দার কাছে অবতারণ করেছি সেই ফুরকানের দিনে, যেদিন দুই দল মুখোমুখি হয়েছিল। আর আল্লাহ্ সব-কিছুর উপরে সর্বশক্তিমান।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mccii{স্মরণ করো! তোমরা ছিলে উপত্যকার নিকট প্রান্তে আর তারা উপত্যকার দূর প্রান্তে, আর কাফেলা ছিল তোমাদের চেয়ে নিন্ম ভূমিতে। আর যদি তোমরা পরস্পরের মধ্যে কোনো বন্দোবস্ত করে থাকতে তবে এ সিদ্ধান্তে তোমরা মতভেদ করতে, কিন্তু -- যেন আল্লাহ্ ব্যাপার একটা ঘটাতে পারেন যেটা ঘটেই গেছে, যেন যার ধ্বংস হবার সে ধ্বংস হতে পারে স্পষ্ট প্রমাণের ফলে, আর যার বাঁচবার সে বাঁচতে পারে স্পষ্ট প্রমাণের ফলে। আর নিঃসন্দেহ আল্লাহ্ অবশ্যই সর্বশ্রোতা, সর্বজ্ঞাতা।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mcciii{স্মরণ করো! আল্লাহ্ তোমার কাছে তাদের দেখিয়েছিলেন তোমার স্বরে মধ্যে অল্পসংখ্যক। আর তিনি যদি তোমার কাছে তাদের দেখাতেন বহুসংখ্যক তবে তোমরা অবশ্যই দুর্বল-চিত্ত হয়ে পড়তে এবং ব্যাপারটি সন্বন্ধে তোমরা তর্কবিতর্ক করতে, কিন্তু আল্লাহ্ রক্ষা করেছেন। নিঃসন্দেহ তিনি বিশেষভাবে অবহিত আছেন বুকের ভেতরে যা রয়েছে সে-সন্বন্ধে।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mcciv{আর স্মরণ করো! তিনি তোমাদের কাছে তাদের দেখিয়ে-ছিলেন, যখন তোমরা মুখোমুখি হয়েছিলে, তোমাদের চোখে অল্পসংখ্যক, আর তিনি তোমাদের করেছিলেন স্বল্পসংখ্যক তাদের চোখে, এইজন্য যেন আল্লাহ্ ব্যাপার একটা ঘটাতে পারেন যা ঘটেই গেছে। আর আল্লাহ্‌র কাছেই সব ব্যাপার ফিরিয়ে আনা হয়।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mccv{ওহে যারা ঈমান এনেছ! তোমরা যখন কোনো সৈন্যদলের সম্মুখীন হও তখন দৃঢ়সংকল্প হবে, আর আল্লাহ্‌কে বেশী ক’রে স্মরণ করবে যেন তোমরা সফলকাম হও।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mccvi{আর আল্লাহ্ ও তাঁর রসূলকে মেনে চলো, আর বিবাদ করো না পাছে তোমরা দুর্বলচিত্ত হও, ও তোমাদের বায়ুপ্রবাহ চলে যাক, আর অধ্যবসায় অবলন্বন করো। নিঃসন্দেহ আল্লাহ্ অধ্যবসায়ীদের সাথে রয়েছেন।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mccvii{আর তোমরা তাদের মতো হয়ো না যারা তাদের ঘর থেকে বেরিয়েছিল গর্বভরে ও লোক দেখানোর জন্যে, আর বাধা দেয় আল্লাহ্‌র পথ থেকে। আর তারা যা করে আল্লাহ্ তা ঘিরে রয়েছেন।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mccviii{আর স্মরণ করো! শয়তানটি তাদের কার্যাবলী তাদের কাছে চিত্তাকর্ষক করেছিল ও বলেছিল -- ''আজকের দিনে লোকদের মধ্যে কেউই তোমাদের উপরে বিজয়ী হতে পারবে না, আর নিঃসন্দেহ আমি তো রয়েছি তোমাদের সাহায্যকারী।’’ কিন্তু তারপর যখন দুই সৈন্যদলে দেখাদেখি হলো, সে তার গোড়ালির উপরে মোড় ফেরালো আর বললে -- ''আমি আলবৎ তোমাদের থেকে বিদায়, আমি নিঃসন্দেহ দেখতে পাচ্ছি যা তোমরা দেখছো না, আমি অবশ্যই আল্লাহ্‌কে ভয় করি, আর আল্লাহ্ প্রতিফল দানে অতি কঠোর।’’\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mccix{স্মরণ করো! কপটরা আর যাদের অন্তরে ব্যাধি রয়েছে তারা বলে -- ''তাদের ধর্মই তাদের বিভ্রান্ত করেছে।’’ বস্তুত যে কেউ আল্লাহ্‌র উপরে নির্ভর করে, তবে নিঃসন্দেহ আল্লাহ্ মহাশক্তিশালী, পরমজ্ঞানী।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mccx{আর তুমি যদি দেখতে পেতে যখন যারা অবিশ্বাস পোষণ করে তাদের প্রাণ হরণ করছে, ফিরিশ্‌তারা আঘাত করছে তাদের মুখে ও তাদের পিঠে, আর -- ''পোড়ার যন্ত্রণা আস্বাদ করো!’’\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mccxi{''এ এ-জন্য যা তোমাদের হাত আগবাড়িয়ে দিয়েছিল, আর আল্লাহ্ কখনো বান্দাদের প্রতি অত্যাচারী নন।’’\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mccxii{ফিরআউনের সাঙ্গপাঙ্গদের অবস্থায় ন্যায় আর যারা তাদের পূর্ববর্তী ছিল। তারা আল্লাহ্‌র নিদর্শনসমূহ প্রত্যাখ্যান করেছিল, তাই আল্লাহ্ তাদের পাকড়াও করলেন তাদের পাপের দরুন। নিঃসন্দেহ আল্লাহ্ অসীম ক্ষমতাশালী, প্রতিফল দানে অতি কঠোর।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mccxiii{এ এজন্য যে আল্লাহ্ অনুগ্রহ পরিবর্তনকারী হোন না যা কোনো জাতির প্রতি তিনি অর্পণ করেছেন, যতক্ষণ না তারা নিজেরা সে- সব বদলিয়ে ফেলে। আর আল্লাহ্ নিঃসন্দেহ সর্বশ্রোতা, সর্বজ্ঞাতা।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mccxiv{ফিরআউনের গোষ্ঠীর অবস্থার ন্যায় আর যারা তাদের পূর্ববর্তী ছিল। তারা তাদের প্রভুর বাণীসমূহে মিথ্যারোপ করেছিল, কাজেই তাদের পাপের দরুন আমরা তাদের ধ্বংস করেছিলাম আর ফিরআউনের সাঙ্গোপাঙ্গদের আমরা ডুবিয়ে দিয়েছিলাম, আর তারা সবাই ছিল অত্যাচারী।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mccxv{নিঃসন্দেহ আল্লাহ্‌র কাছে নিকৃষ্টতম জীব হচ্ছে তারা যারা অবিশ্বাস পোষণ করে, কাজেই তারা ঈমান আনে না ।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mccxvi{ওদের মধ্যে যাদের সঙ্গে তুমি চুক্তি সম্পাদন করো, -- তারপর তারা তাদের চুক্তি প্রত্যেক বারেই ভঙ্গ করে, আর তারা ভয়ভক্তি করে না।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mccxvii{সুতরাং যুদ্ধের মধ্যে যদি তাদের করায়ত্ত করো তবে তাদের দ্বারা যারা তাদের পশ্চাদনুসরণ করে তাদের বিধবস্ত করো, যেন তারা সতর্কতা অবলন্বন করে।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mccxviii{আর যদি তুমি কোনো দল থেকে বিশ্বাসঘাতকতার আশঙ্কা করো, তবে ছোঁড়ে দাও তাদের দিকে সমান-সমানভাবে। নিঃসন্দেহ আল্লাহ্ বিশ্বাসঘাতকদের ভালোবাসেন না।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mccxix{আর যারা অবিশ্বাস পোষণ করে তারা যেন না ভাবে যে তারা ডিঙিয়ে যেতে পারবে। নিঃসন্দেহ তারা পরিত্রাণ পাবে না।\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mccxx{আর তোমরা তাদের বিরুদ্ধে প্রস্তুত রাখবে যা-কিছুতে তোমরা সমর্থ হও -- শৌর্য-বীর্যে ও হৃস্পুষ্ট ঘোড়াগুলোয়, -- তার দ্বারা ভীত-সন্ত্রস্ত রাখবে আল্লাহ্‌র শত্রুদের তথা তোমাদের শত্রুদের, আর তাদের ছাড়া অন্যদেরও, তাদের তোমরা জানো না, আল্লাহ্ তাদের জানেন। আর যা-কিছু তোমরা আল্লাহ্‌র পথে ব্যয় করবে তা তোমাদের পুরোপুরি প্রতিদান দেওয়া হবে, আর তোমরা অত্যাচারিত হবে না।\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mccxxi{আর যদি তারা শান্তির দিকে ঝোঁকে তবে তুমিও এর দিকে ঝুকঁবে, আর আল্লাহ্‌র প্রতি নির্ভর করো। নিঃসন্দেহ তিনিই সর্বশ্রোতা, সর্বজ্ঞাতা।\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mccxxii{আর যদি তারা চায় যে তারা তোমাকে ফাঁকি দেবে, তবে নিঃসন্দেহ আল্লাহ্ তোমার জন্য যথেষ্ট। তিনিই সেই জন যিনি তোমাকে বলীয়ান করেন তাঁর সহায়তার দ্বারা আর মুমিনদের দ্বারা।\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mccxxiii{আর তাদের হৃদয়ের মধ্যে তিনি প্রীতি স্থাপন করেছেন। তুমি যদি পৃথিবীতে যা আছে তার সবটাই খরচ করতে তবু তুমি তাদের হৃদয়ের মধ্যে সম্প্রীতি স্থাপন করতে পারতে না, কিন্তু আল্লাহ্ তাদের মধ্যে প্রীতি স্থাপন করেছেন। নিঃসন্দেহ তিনি মহাশক্তিশালী, পরমজ্ঞানী।\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mccxxiv{হে প্রিয় নবী! আল্লাহ্‌ই তোমার জন্য আর সেইসব মুমিনদের জন্য যথেষ্ট যারা তোমার অনুসরণ করে।\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mccxxv{হে প্রিয় নবী! মুমিনদের যুদ্ধের জন্য উৎসাহিত করো। যদি তোমাদের মধ্যে কুড়িজন ধৈর্যশীল থাকে তবে তারা দু’শ জনকে পরাজিত করবে, আর যদি তোমাদের মধ্যে একশত জন থাকে তবে তারা পরাজিত করবে যারা অবিশ্বাস পোষণ করে তাদের একহাজার জনকে, যেহেতু তারা হচ্ছে একটি সম্প্রদায় যারা বোঝে না।\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mccxxvi{এখনকার সময়ে আল্লাহ্ তোমাদের বোঝা হাল্কা করেছেন, কেননা তিনি জানেন যে তোমাদের মধ্যে দুর্বলতা আছে। সেজন্য যদি তোমাদের মধ্যে একশত জন ধৈর্যশীল থাকে তবে তারা দু’শ জনকে পরাজিত করবে, আর যদি তোমাদের মধ্যে একহাজার জন থাকে তবে তারা আল্লাহ্‌র অনুমতিক্রমে দুইহাজারকে পরাজিত করবে। আর আল্লাহ্ ধৈর্যশীলদের সাথে রয়েছেন।\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mccxxvii{একজন নবীর জন্য সংগত নয় যে তাঁর জন্য বন্দীদের রাখা হোক যে পর্যন্ত না তিনি দেশে জয়লাভ করেছেন। তোমরা চাও পার্থিব সম্পদ, অথচ আল্লাহ্ চান পরলোক। আর আল্লাহ্ মহাশক্তিশালী, পরমজ্ঞানী।\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mccxxviii{যদি আল্লাহ্‌র তরফ থেকে বিধান না থাকতো যা পূর্বেই উল্লেখ হয়েছে, তবে তোমরা যা গ্রহণ করতে যাচ্ছিলে সেজন্য তোমাদের উপরে পড়তো এক বিরাট শাস্তি।\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mccxxix{অতএব ভোগ করো যে-সব বৈধ ও পবিত্র দ্রব্য তোমরা যুদ্ধক্ষেত্রে সংগ্রহ করেছ, আর আল্লাহ্‌কে ভয়ভক্তি করো। নিঃসন্দেহ আল্লাহ্ পরিত্রাণকারী, অফুরন্ত ফলদাতা।\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mccxxx{হে প্রিয় নবী! তোমাদের হাতে বন্দীদের যারা আছে তাদের বলো -- ''আল্লাহ্ যদি তোমাদের হৃদয়ে ভালো কিছু জানতে পারেন তবে তিনি তোমাদের দান করবেন আরো ভালো কিছু যা তোমাদের কাছ থেকে নেয়া হয়েছে তা থেকেও, আর তিনি তোমাদের পরিত্রাণ করবেন। আর আল্লাহ্ পরিত্রাণকারী, অফুরন্ত ফলদাতা।’’\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@mccxxxi{কিন্তু যদি তারা চায় তোমার প্রতি বিশ্বাসঘাতকতা করতে, তবে এর আগেও তারা অবশ্যই আল্লাহ্‌র প্রতি বিশ্বাসভঙ্গ করেছে, সুতরাং তিনি কর্তৃত্ব দিলেন তাদের অনেকের উপরে। আর আল্লাহ্ সর্বজ্ঞাতা, পরমজ্ঞানী।\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@mccxxxii{নিঃসন্দেহ যারা ঈমান এনেছে ও হিজরত করেছে, আর তাদের ধনদৌলত ও তাদের জান-প্রাণ দিয়ে আল্লাহ্‌র পথে সংগ্রাম করেছে, আর যারা আশ্রয় দান করেছে ও সাহায্য করেছে, -- এরাই হচ্ছে পরস্পর পরস্পরের বন্ধু। আর যারা ঈমান এনেছে, অথচ হিজরত করে নি, তাদের অভিভাবকত্ব কোনোভাবেই তোমাদের দায়িত্ব নয় যে পর্যন্ত না তারাও হিজরত করে। কিন্তু যদি তারা তোমাদের কাছে ধর্মের ব্যাপারে সাহায্য প্রার্থনা করে তবে সাহায্য করা তোমাদের কর্তব্য, অবশ্য সে-সম্প্রদায়ের বিরুদ্ধে ছাড়া যাদের মধ্যে চুক্তি রয়েছে। আর তোমরা যা করো আল্লাহ্ তার সম্যক দ্রষ্টা।\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@mccxxxiii{আর যারা অবিশ্বাস পোষণ করে -- তাদের কেউ কেউ অপরদের বন্ধু। যদি তোমরা এ না করো তবে দেশে অনাচার ও বিরাট- বিপর্যয় সৃষ্টি হবে।\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@mccxxxiv{আর যারা ঈমান এনেছে ও হিজরত করেছে ও আল্লাহ্‌র পথে জিহাদ করেছে, আর যারা আশ্রয় দিয়েছে ও সাহায্য করেছে, -- এরা নিজেরাই হচ্ছে প্রকৃত মুমিন। এদের জন্যেই রয়েছে পরিত্রাণ ও মহৎ জীবিকা।\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@mccxxxv{আর যারা পরে ঈমান এনেছে এবং গৃহত্যাগ করেছে ও তোমাদের সঙ্গে থেকে সংগ্রাম করেছে, তারাও তোমাদের মধ্যেকার। আর রক্তসম্পর্কের লোকেরা -- তারা আল্লাহ্‌র বিধানে পরস্পর পরস্পরের অধিকতর নিকটা‌ত্মীয়। নিঃসন্দেহ আল্লাহ্ সর্ববিষয়ে সর্বজ্ঞাতা।\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@mccxxxvi{\basmalahbn এক অব্যাহতি আল্লাহ্ ও তাঁর রসূলের তরফ থেকে সেইসব বহুখোদাবাদীদের প্রতি যাদের সঙ্গে তোমরা সন্ধি করেছিলে।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mccxxxvii{সুতরাং তোমরা দেশে অবাধে ঘোরাফেরা করো চার মাসকাল, আর জেনে রেখো -- তোমরা নিশ্চয়ই আল্লাহ্‌র কাছ থেকে ফসকে যাবার পাত্র নও। আর আল্লাহ্ আলবৎ অবিশ্বাসীদের লাঞ্ছিত করে থাকেন।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mccxxxviii{আর আল্লাহ্ ও তাঁর রসূলের তরফ থেকে জনগণের প্রতি এই মহান হজের দিনে এ এক ঘোষণা যে আল্লাহ্ মুশরিকদের কাছে দায়মুক্ত, আর তাঁর রসূলও। অতএব তোমরা যদি তওবা করো তবে সেটি হবে তোমাদের জন্য কল্যাণজনক, কিন্তু তোমরা যদি ফিরে যাও তাহলে জেনে রেখো -- তোমরা নিঃসন্দেহ আল্লাহ্‌র কাছ থেকে ফসকে যাবার পাত্র নও। আর যারা অবিশ্বাস পোষণ করে তাদের মর্মন্তুদ শাস্তির সংবাদ দাও, --\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mccxxxix{মুশরিকদের মধ্যের সেইসব ছাড়া যাদের সঙ্গে তোমরা চুক্তি করেছ, তারপর তারা তোমাদের সাথে কোনো ত্রুটি করে নি, আর তোমাদের বিরুদ্ধে অন্য কারোর পৃষ্ঠপোষকতাও করে নি, তাদের সঙ্গে তাহলে তাদের চুক্তি প্রতিপালন করো সেগুলোর মেয়াদ পর্যন্ত। নিঃসন্দেহ আল্লাহ্ ভালোবাসেন ধর্মপরায়ণদের।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mccxl{অতঃপর নিষিদ্ধ মাসগুলো যখন অতিবাহিত হয়ে যায় তখন মুশরিকদের কাতল করো যেখানে তাদের পাও, আর তাদের বন্দী করো, আর তাদের ঘেরাও করো, আর তাদের জন্য ওৎ পেতে থাকো প্রত্যেক ঘাঁটিতে। কিন্তু যদি তারা তওবা করে এবং নামায কায়েম করে আর যাকাত আদায় করে তবে তাদের পথ ছেড়ে দিয়ো। নিঃসন্দেহ আল্লাহ্ পরিত্রাণকারী অফুরন্ত ফলদাতা।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mccxli{আর যদি মুশরিকদের কোনো একজন তোমার কাছে আশ্রয় চায় তবে তাকে আশ্রয় দাও যেন সে আল্লাহ্‌র বাণী শোনে, তারপর তাকে তার নিরাপদ যায়গায় পৌঁছে দিয়ো। এটি এই জন্য যে তারা হচ্ছে এমন এক সম্প্রদায় যারা জানে না।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mccxlii{কেমন ক’রে মুশরিকদের জন্য আল্লাহ্‌র সঙ্গে ও তাঁর রসূলের সঙ্গে চুক্তি হতে পারে, তাদের সম্পর্কে ছাড়া যাদের সঙ্গে তোমরা চুক্তি করেছিলে পবিত্র মসজিদের নিকটে? সুতরাং যতক্ষণ তারা তোমাদের প্রতি কায়েম থাকবে ততক্ষণ তোমরাও তাদের প্রতি কায়েম রইবে। নিঃসন্দেহ আল্লাহ্ ধর্মপরায়ণদের ভালোবাসেন।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mccxliii{কেমন ক’রে যখন তারা যদি তোমাদের পিঠে চড়তে পারে তবে তারা তোমাদের সঙ্গে আ‌ত্মীয়তার বা চুক্তির বন্ধন মানবে না? তারা তোমাদের খুশী রাখতে চায় তাদের মুখ দিয়ে, কিন্তু তাদের হৃদয় অস্বীকার করে, আর তাদের অধিকাংশই দুষ্কৃতিকারী।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mccxliv{তারা আল্লাহ্‌র আয়াতকে স্বল্পমূল্যে বিনিময় করে, তাই তারা তাঁর পথ থেকে ফিরিয়ে রাখে। নিঃসন্দেহ জঘন্য যা তারা করে যাচ্ছে।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mccxlv{তারা কোনো মুমিনের বেলায় আ‌ত্মীয়তার বা চুক্তির বন্ধন-সন্বন্ধে ভাবে না। এরা নিজেরাই হচ্ছে সীমালংঘনকারী।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mccxlvi{কিন্তু যদি তারা তওবা করে, আর নামায কায়েম করে, আর যাকাত আদায় করে, তবে তারা ধর্মে তোমাদের ভাই। আর আমরা নির্দেশাবলী বিশদভাবে বিবৃত করি সেই লোকদের জন্য যারা জানে।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mccxlvii{আর তারা যদি তাদের চুক্তি সম্পাদনের পরেও তাদের প্রতি‌শ্রুতি ভঙ্গ করে আর তোমাদের ধর্ম নিয়ে বিদ্রূপ করে তবে অবিশ্বাসের সর্দারদের সাথে যুদ্ধ করো, -- নিঃসন্দেহ তাদের বেলা প্রতিজ্ঞাসব তাদের কাছে কিছুই নয়, -- যেন তারা বিরত হতে পারে।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mccxlviii{তোমরা কি যুদ্ধ করবে না সেইসব সম্প্রদায়ের সাথে যারা তাদের প্রতি‌শ্রুতি ভঙ্গ করেছে, আর সংকল্প করেছে রসূলকে বহিস্কার করার, আর তারাই তোমাদের উপরে শুরু করেছে প্রথমে? তোমরা কি তাদের ভয় করো? কিন্তু আল্লাহ্‌ই অধিকতর দাবিদার যে তোমরা তাঁকে ভয় করবে -- যদি তোমরা মূমিন হও।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mccxlix{তাদের সঙ্গে যুদ্ধ করো, আল্লাহ্ তাদের শাস্তি দেবেন তোমাদের হাতে, আর তাদের লাঞ্ছিত করবেন, আর তোমাদের সাহায্য করবেন তাদের বিরুদ্ধে, আর মুমিন সম্প্রদায়ের বুক প্রশমিত করবেন।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mccl{আর তিনি তাদের বুকের ক্ষোভ দূর করবেন। আর যাকে ইচ্ছে করেন তার প্রতি আল্লাহ্ ফেরেন। আর আল্লাহ্ সর্বজ্ঞাতা, পরমজ্ঞানী।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mccli{তোমরা কি মনে করো যে তোমাদের ছেড়ে দেয়া হবে, অথচ আল্লাহ্ জেনে নেন নি যে তোমাদের মধ্যের কারা সংগ্রাম করছে, আর কারা আল্লাহ্‌কে ছেড়ে দিয়ে বা তাঁর রসূলকে বাদ দিয়ে বা মুমিনদের ব্যতীত কোনো অন্তরঙ্গ বন্ধু গ্রহণ করে নি? আর তোমরা যা করো আল্লাহ্ সে-সন্বন্ধে পূর্ণ-ওয়াকিফহাল।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mcclii{মুশরিকদের কোনো অধিকার নেই যে তারা আল্লাহ্‌র মসজিদগুলো দেখাশোনা করবে যখন তারা তাদের নিজেদের বিরুদ্ধে অবিশ্বাসের সাক্ষ্য দেয়। এরাই তারা যাদের কাজকর্ম ব্যর্থ হয়েছে, আর আগুনের মধ্যে তারাই অবস্থান করবে।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mccliii{নিঃসন্দেহ সে-ই শুধু আল্লাহ্‌র মসজিদগুলো রক্ষণাবেক্ষণ করবে যে আল্লাহ্‌তে বিশ্বাস করে আর পরকালেও, আর নামায কায়েম করে ও যাকাত আদায় করে, আর আল্লাহ্ ছাড়া কাউকেও ভয় করে না, কাজেই এদের পক্ষেই সাব্য যে এরা হেদায়তপ্রাপ্তদের মধ্যেকার হবে।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mccliv{তোমরা কি হজযাত্রীদের পানি সরবরাহ করা ও পবিত্র মসজিদের দেখাশোনা করাকে তুল্যজ্ঞান করো তার সাথে যে আল্লাহ্‌র প্রতি ও পরকালের প্রতি আস্থা রেখেছে আর আল্লাহ্‌র পথে সংগ্রাম করছে? আল্লাহ্‌র কাছে ওরা সমতুল্য নয়। আর আল্লাহ্ অন্যায়কারী সম্প্রদায়কে সৎপথে পরিচালন করেন না।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mcclv{যারা ঈমান এনেছে ও হিজরত করেছে, আর আল্লাহ্‌র পথে তাদের ধনদৌলত ও তাদের জানপ্রাণ দিয়ে সংগ্রাম করেছে, তারা আল্লাহ্‌র কাছে মর্যাদায় উন্নততর। আর এরা নিজেরাই সফলকাম।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mcclvi{তাদের প্রভু তাদের সুসংবাদ দিচ্ছেন তাঁর তরফ থেকে করুণাধারার, আর প্রসন্নতার, আর বাগ-বাগিচার যাতে তাদের জন্যে রয়েছে চিরস্থায়ী সুখসমৃদ্ধি --\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mcclvii{সেখানে তারা থাকবে চিরকাল। নিঃসন্দেহ আল্লাহ্ -- তাঁর কাছে রয়েছে পরম পুরস্কার।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mcclviii{ওহে যারা ঈমান এনেছ! তোমাদের পিতৃবর্গকে ও তোমাদের ভ্রাতৃবৃন্দকে তোমরা অভিভাবকরূপে গ্রহণ করো না যদি তারা বিশ্বাসের চাইতে অবিশ্বাসকেই ভালোবাসে। আর তোমাদের মধ্যে যে কেউ তাদের মুরব্বীরূপে গ্রহণ করে তবে তারা নিজেরাই হবে অন্যায়কারী ।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mcclix{বলো, ''যদি তোমাদের পিতারা ও তোমাদের পুত্রেরা, আর তোমাদের ভাইয়েরা ও তোমাদের পরিবাররা, আর তোমাদের আ‌ত্মীয়স্বজন, আর মাল-আসবাব যা তোমরা অর্জন করেছ, আর ব্যবসা-বাণিজ্য যার অচলাবস্থা তোমরা আশঙ্কা করো, আর বাড়িঘর যা তোমরা ভালোবাসো -- তোমাদের কাছে আল্লাহ্ ও তাঁর রসূলের ও তাঁর পথে সংগ্রামের চেয়ে অধিকতর প্রিয় হয় তবে অপেক্ষা করো যে পর্যন্ত না আল্লাহ্ নিয়ে আসেন তাঁর আদেশ।’’ আর আল্লাহ্ দুষ্কৃতিকারী সম্প্রদায়কে সৎপথ প্রদর্শন করেন না।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mcclx{আল্লাহ্ ইতিমধ্যে বহুক্ষেত্রে তোমাদের সাহায্য করেছেন, আর হুনাইনের দিনেও যখন তোমাদের সংখ্যাধিক্য তোমাদের উৎফুল্ল করেছিল, কিন্তু তা তোমাদের লাভবান করে নি কোনো-ভাবেই, আর পৃথিবী বিস্তৃত হওয়া সত্ত্বেও তোমাদের জন্য হয়েছিল সংকীর্ণ, তোমরা ফিরেছিলে পলায়নপর হয়ে।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mcclxi{তারপর আল্লাহ্ তাঁর প্রশান্তি বর্ষণ করলেন তাঁর রসূলের উপরে আর মুমিনদের উপরে, আর তিনি অবতীর্ণ করেছিলেন এক সেনাবাহিনী যা তোমরা দেখতে পাও নি, আর শাস্তি দিয়েছিলেন তাদের যারা অবিশ্বাস পোষণ করে। আর এই হচ্ছে অবিশ্বাসীদের কর্মফল।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mcclxii{তারপর আল্লাহ্ এর পরেও ফেরেন যার প্রতি তিনি ইচ্ছা করেন। আর আল্লাহ্ পরিত্রাণকারী, অফুরন্ত ফলদাতা।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mcclxiii{ওহে যারা ঈমান এনেছ! নিঃসন্দেহ মুশরিকরা হচ্ছে অপবিত্র, কাজেই তাদের এই বৎসরের পরে তারা পবিত্র মসজিদের সন্নিকটে আসতে পারবে না; আর যদি তোমরা দারিদ্রের আশঙ্কা করো তা হলে আল্লাহ্ অচিরেই তোমাদের সমৃদ্ধ করবেন তাঁর করুণাভান্ডার থেকে যদি তিনি চান। নিঃসন্দেহ আল্লাহ্ সর্বজ্ঞাতা, পরমজ্ঞানী।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mcclxiv{যুদ্ধ করো তাদের সঙ্গে যারা আল্লাহ্‌তে বিশ্বাস করে না আর আখেরাতের দিনেও না, আর নিষেধ করে না যা আল্লাহ্ ও তাঁর রসূল নিষেধ করেছেন, আর সত্যধর্মে ধর্মনিষ্ঠা পালন করে না -- তাদের মধ্যে থেকে যাদের ধর্মগ্রন্থ দেয়া হয়েছে, যে পর্যন্ত না তারা স্বহস্তে জিযিয়া প্রদান করে, আর তারা আনুগত্য মেনে নেয়।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mcclxv{আর ইহুদীরা বলে -- ''উযাইর আল্লাহ্‌র পুত্র’’, আর খ্রীষ্টানরা বলে -- ''মসীহ আল্লাহ্‌র পুত্র।’’ এসব হচ্ছে তাদের মুখ দিয়ে তাদের বুলি আওড়ানো, -- তারা ওদের কথার অনুসরণ করে যারা পূর্বকালে অবিশ্বাস পোষণ করেছিল। আল্লাহ্ তাদের ধ্বংস করবেন। তারা কেমন ক’রে বিমুখ হয়!\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mcclxvi{তারা আল্লাহ্‌কে ছেড়ে দিয়ে তাদের পন্ডিতগণকে ও সন্ন্যাসীদের প্রভুরূপে গ্রহণ করেছে, আর মরিয়ম-পুত্র মসীহ্‌কেও, অথচ শুধু এক উপাস্যের উপাসনা করা ছাড়া অন্য নির্দেশ তাদের দেয়া হয় নি। তিনি ছাড়া অন্য উপাস্য নেই। তাঁরই সব মহিমা -- তারা যে- সব অংশী দাঁড় করার সে-সব থেকে?\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mcclxvii{তারা আল্লাহ্‌র জ্যোতি নিভিয়ে দিতে চায় তাদের মুখ দিয়ে, আর আল্লাহ্ তাঁর জ্যোতির পূর্ণাঙ্গ সাধন না ক’রে থামছেন না যদিও অবিশ্বাসীরা অসন্তোষ বোধ করছে।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mcclxviii{তিনিই সেইজন যিনি তাঁর রসূলকে পাঠিয়েছেন পথনির্দেশ ও সত্য-ধর্মের সাথে যেন তিনি তাকে প্রাধান্য দিতে পারেন ধর্মের -- তাদের সবক’টি উপরে, যদিও মুশরিকরা অনিচ্ছুক।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mcclxix{ওহে যারা ঈমান এনেছ! নিঃসন্দেহ পন্ডিতদের ও সন্ন্যাসীদের মধ্যের অনেকে লোকের ধনসম্পত্তি অন্যায়ভাবে গলাধঃকরণ করে আর আল্লাহ্‌র পথ থেকে ফিরিয়ে রাখে। বস্তুতঃ যারা সোনা ও রূপা পুঞ্জীভূত করে অথচ আল্লাহ্‌র পথে খরচ করে না, তাদের তাহলে সংবাদ দাও মর্মন্তুদ শাস্তির, --\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mcclxx{যেদিন এগুলো উত্তপ্ত করা হবে জাহান্নামের আগুনে, তারপর তা দিয়ে দেগে দেয়া হবে তাদের কপালে ও তাদের পার্শ্বদেশে ও তাদের পিঠে। ''এটিই সেই যা তোমরা জড়ো করেছিলে, অতএব আস্বাদন করো যা তোমরা জমিয়েছিলে!’’\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mcclxxi{নিঃসন্দেহ আল্লাহ্‌র কাছে মাসগুলোর সংখ্যা হচ্ছে আল্লাহ্‌র বিধানে বারো মাস, -- যেদিন থেকে তিনি মহাকাশমন্ডল ও পৃথিবী সৃষ্টি করেছেন, -- এর মধ্যে চারটি হচ্ছে পবিত্র। এই হচ্ছে সুপ্রতিষ্ঠিত বিধান, কাজেই এদের মধ্যে তোমাদের নিজেদের প্রতি অন্যায় করো না, আর মুশরিকদের বিরুদ্ধে সমবেতভাবে যুদ্ধ করো যেমন তারা সমবেতভাবে তোমাদের সাথে যুদ্ধ করে থাকে। আর জেনে রেখো -- আল্লাহ্ আলবৎ ধর্মভীরুদের সঙ্গে রয়েছেন।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mcclxxii{পিছিয়ে দেয়া অবিশ্বাসেরই মাত্রা বৃদ্ধি মাত্র, এর দ্বারা যারা অবিশ্বাস পোষণ করে তাদের পথভ্রষ্ট করা হয়, তারা এ বৈধ করে কোনো বছর আর একে অবৈধ করে কোনো বছর, যেন তারা ঠিক রাখতে পারে সংখ্যা যা আল্লাহ্ নিষিদ্ধ করেছেন, ফলে তারা বৈধ করে যা আল্লাহ্ অবৈধ করেছেন। তাদের মন্দ কাজগুলো তাদের কাছ চিত্তাকর্ষক করা হয়ছে। আর আল্লাহ্ পথ দেখান না অবিশ্বাসী সম্প্রদায়কে।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mcclxxiii{ওহে যারা ঈমান এনেছ? কি তোমাদের হয়েছে যখন তোমাদের বলা হচ্ছে -- 'আল্লাহ্‌র পথে বেরিয়ে পড়ো’, -- তখন তোমরা ভারি হয়ে ঝুকঁছো মাটির দিকে? তোমরা কি বেশি পরিতুষ্ট পরকালের পরিবর্তে এই দুনিয়ার জীবনে বস্তুতঃ পার্থিব জীবনের ভোগবিলাস পরকালের তুলনায় যৎসামান্য বই তো নয়।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mcclxxiv{যদি তোমরা বের না হও তবে তিনি তোমাদের শাস্তি দেবেন মর্মন্তুদ শাস্তিতে, আর তোমাদের পরিবর্তে বদলে নেবেন ভিন্ন এক জাতিকে, আর তোমরা তাঁর কোনোই ক্ষতি করতে পারবে না। বস্তুতঃ আল্লাহ্ সব-কিছুর উপরে সর্বশক্তিমান।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mcclxxv{তোমরা যদি তাঁকে সাহায্য না কর তবে আল্লাহ্ তাঁকে ইতিপূর্বে সাহায্য করেছিলেন যখন যারা অবিশ্বাস পোষণ করেছিল তারা তাঁকে বের করে দিয়েছিল, দুই জনের দ্বিতীয় জন, যখন তাঁরা দুজন ছিলেন গুহার ভেতরে, যখন তিনি তাঁর সঙ্গীকে বলেছিলেন -- ''বিষন্ন হয়ো না, নিঃসন্দেহ আল্লাহ্ আমাদের সঙ্গে রয়েছেন।’’ অতঃপর আল্লাহ্ তাঁর প্রশান্তি অবতারণ করেছিলেন তাঁর উপরে আর তাঁর বলবৃদ্ধি করেছিলেন এমন এক বাহিনী দিয়ে যাদের তোমরা দেখতে পাও নি, আর যারা অবিশ্বাস পোষণ করেছিল তাদের কথাবার্তাকে হেয় করেছিলেন। আর আল্লাহ্‌র বাণী -- তা হচ্ছে উচ্চতম। আর আল্লাহ্ হচ্ছেন মহাশক্তিশালী, পরমজ্ঞানী।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mcclxxvi{বেরিয়ে পড় হাল্কাভাবে ও ভারী হয়ে আর তোমাদের ধনসম্পদ ও তোমাদের জানপ্রাণ দিয়ে আল্লাহ্‌র পথে সংগ্রাম করো। এটিই তোমাদের জন্য ভালো যদি তোমরা জানতে।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mcclxxvii{যদি এটি হতো আশু লাভের ব্যাপার ও হাল্কা সফর তবে তারা নিশ্চয়ই তোমাকে অনুসরণ করতো, কিন্তু দুর্গম-পথ তাদের কাছে সুদীর্ঘ মনে হলো। আর তারা আল্লাহ্‌র নামে হলফ করে বললে -- ''আমরা যদি পারতাম তবে নিশ্চয়ই তোমাদের সঙ্গে আমরাও বের হতাম।’’ তারা তাদের নিজেদেরই ধ্বংস সাধন করছে, আর আল্লাহ্ জানেন যে তারা আলবৎ ডাহা মিথ্যাবাদী।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mcclxxviii{আল্লাহ্ তোমাকে ক্ষমা করুন! কেন তুমি তাদের অব্যাহতি দিলে যে পর্যন্ত না তোমার কাছে সুস্পষ্ট হয়েছিল যে কারা সত্যকথা বলছে, আর তুমি জানতে পেরেছিলে মিথ্যাবাদীদের?\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mcclxxix{যারা আল্লাহ্‌তেও ও আখেরাতের দিনে আস্থা রাখে তারা তোমার কাছে অনুমতি চায় না তাদের ধনসম্পদ ও তাদের জানপ্রাণ দিয়ে সংগ্রাম করা থেকে। আর আল্লাহ্ ধর্মপরায়ণদের সম্পর্কে সর্বজ্ঞাতা।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mcclxxx{তোমার নিকট অনুমতি চায় কেবল ওরাই যারা আল্লাহ্‌তে ও শেষদিনে ঈমান আনে না, আর তাদের হৃদয় দ্বিধাগ্রস্ত। কাজেই তাদের সন্দেহের মধ্যেই তারা দোল খাচ্ছে।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mcclxxxi{আর তারা যদি যাত্রা করবার ইচ্ছা করতো তবে তারা নিশ্চয়ই তার জন্য যোগাড়যন্ত্র যোগাড় করতো, কিন্তু আল্লাহ্ অনিচ্ছুক তাদের গমনে, তাই তাদের তিনি ঠেকিয়ে রেখেছেন, আর বলা হলো -- ''বসে থাকো বসে-থাকা লোকদের সাথে।’’\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mcclxxxii{তারা যদি তোমাদের সঙ্গে বের হত তবে তারা বিশৃঙ্খলা সৃষ্টি ছাড়া তোমাদের আর কিছুই বাড়াতো না, আর তারা নিশ্চয়ই তোমাদের মধ্যে ছুটোছুটি করতো তোমাদের মধ্যে বিদ্রোহ কামনা ক’রে, আর তোমাদের মধ্যে ওদের কথা শোনবার লোক রয়েছে। আর আল্লাহ্ অত্যাচারীদের সন্বন্ধে সর্বজ্ঞাতা।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mcclxxxiii{তারা বাস্তবিকই ইতিপূর্বে বিশৃঙ্খলা সৃষ্টি করতে চেয়েছিল, আর তারা তোমার জন্য কাজকর্ম পন্ড করতে যাচ্ছিল, যতক্ষণ না সত্য এসেছিল ও আল্লাহ্‌র আদেশ প্রকাশ পেলো, যদিও তারা অনিচ্ছুক ছিল।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mcclxxxiv{আর তাদের মধ্যে এমন আছে যে বলে -- ''আমাকে ছেড়ে দাও এবং আমাকে সমস্যায় ফেলো না।’’ তারা কি সমস্যায় পড়ে যায় নি? আর নিঃসন্দেহ জাহান্নাম অবিশ্বাসীদের ঘেরাও করেই রয়েছে।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mcclxxxv{যদি তোমার উপরে ভালো কিছু ঘটে তবে তা তাদের দুঃখ দেয়, আর যদি তোমার কোনো বিপদ ঘটে তারা বলে -- ''আমরা তো আমাদের ব্যাপার আগেই গুটিয়ে নিয়েছিলাম’’, আর তারা ফিরে যায় এবং তারা উৎফুল্লচিত্ত হয়।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mcclxxxvi{বলো -- ''আল্লাহ্ আমাদের জন্য যা বিধান করেছেন তা ব্যতীত কিছুই আমাদের উপরে কখনো ঘটবে না। তিনিই আমাদের রক্ষক, আর আল্লাহ্‌র উপরেই তবে মুমিনরা নির্ভর করুক।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mcclxxxvii{বলে যাও -- ''তোমরা আমাদের জন্য দুটি কল্যাণের কোনো একটি ছাড়া আর কিসের প্রতীক্ষা করতে পারো? আর আমরা তোমাদের জন্য প্রতীক্ষা করছি যে আল্লাহ্ তোমাদের শাস্তি হানবেন তাঁর তরফ থেকে অথবা আমাদের হাতে। অতএব প্রতীক্ষা করো, আমরাও অবশ্যই তোমাদের সাথে প্রতীক্ষমাণ।’’\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mcclxxxviii{বলো -- ''তোমরা ইচ্ছাকৃতভাবে খরচ করো অথবা অনিচ্ছা-কৃতভাবে, তোমাদের কাছ থেকে তা কখনো কবুল করা হবে না। নিঃসন্দেহ তোমরা হচ্ছো একটি দুষ্কৃতিকারী সম্প্রদায়।’’\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mcclxxxix{আর তাদের খরচপত্র তাদের কাছ থেকে কবুল হতে তাদের জন্য কোনো বাধা ছিল না শুধু এজন্য ছাড়া যে তারা আল্লাহ্‌তে ও তাঁর রসূলের প্রতি অবিশ্বাস পোষণ করে। আর তারা নামাযে আসে না তাদের গড়িমসি করা অবস্থা ছাড়া, আর তারা খরচ করে না তাদের অনিচ্ছার ভাব ছাড়া।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mccxc{তাদের ধনদৌলত তোমাকে যেন তাজ্জব না করে আর তাদের সন্তানসন্ততিও না। আল্লাহ্ আলবৎ চান এ-সবের দ্বারা পার্থিব জীবনে তাদের শাস্তি দিতে; আর তাদের প্রাণ ত্যাগ করে যায় তাদের অবিশ্বাসী থাকা অবস্থায়।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mccxci{আর তারা আল্লাহ্‌র নামে হলফ করে যে তারা নিঃসন্দেহ তোমাদেরই মধ্যেকার। কিন্তু তারা তোমাদের মধ্যেকার নয়, বস্তুতঃ তারা এমন এক সম্প্রদায় যারা কাপুরুষ।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mccxcii{তারা যদি পেতো কোনো আশ্রয়স্থল বা কোনো গুহাগহ্বর অথবা কোনো প্রবেশ করার জায়গা, -- তারা নিশ্চয়ই সেখানে চলে যেত দ্রতগতিতে পলায়নপর হয়ে।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mccxciii{আর ওদের মধ্যে এমনও আছে যে তোমাকে দোষারোপ করে দানের ব্যাপারে। অতঃপর তাদের যদি এ থেকে দেয়া হয় তবে তারা খুশী হয়, কিন্তু যদি তাদের এ থেকে দেয়া না হয় তো দেখো! -- তারা রাগ করে!\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mccxciv{আর ওরা যদি সন্তষ্ট থাকতো আল্লাহ্ ও তাঁর রসূল ওদের যা দিয়েছেন তাতে, আর বলতো -- ''আল্লাহ্‌ই আমাদের জন্য যথেষ্ট, -- আল্লাহ্ শীঘ্রই তাঁর করুণাভান্ডার থেকে আমাদের দেবেন আর তাঁর রসূলও, নিঃসন্দেহ আল্লাহ্‌র কাছেই আমরা আসক্ত’’।\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mccxcv{দান তো কেবল অক্ষমদের জন্য, আর অভাবগ্রস্তদের, আর এর জন্য নিযুক্ত কর্মচারীদের, আর যাদের হৃদয় ঝোঁকোনো হয় তাদের, আর দাস-মুক্তির, আর ঋণগ্রস্তদের, আর আল্লাহ্‌র পথে, আর পর্যটকদের জন্য, -- আল্লাহ্‌র তরফ থেকে এই বিধান। আর আল্লাহ্ সর্বজ্ঞাতা, পরমজ্ঞানী।\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mccxcvi{আর ওদের এমনও আছে যারা নবীকে উত্ত্যক্ত করে আর বলে -- ''উনি তো কান দেন।’’ তুমি বলো -- ''কান দেন তোমাদের ভালোর জন্যে, তিনি আল্লাহ্‌তে বিশ্বাস করেন আর বিশ্বাস করেন মুমিনদের, আর তোমাদের মধ্যে যারা ঈমান আনে তাদের জন্য তিনি করুণা।’’ আর যারা আল্লাহ্‌র রসূলকে উত্ত্যক্ত ক’রে তাদের জন্য রয়েছে মর্মন্তুদ শাস্তি।\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mccxcvii{তারা তোমাদের কাছে আল্লাহ্‌র নামে হলফ করে যেন তারা তোমাদের খুশী করতে পারে, অথচ আল্লাহ্ ও তাঁর রসূলের বেশী অধিকার আছে যেন তারা তাঁকে রাজী করে, যদি তারা মুমিন হয়।\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mccxcviii{তারা কি জানে না যে যে-কেউ আল্লাহ্ ও তাঁর রসূলের বিরুদ্ধে কাজ করে তার জন্য তবে রয়েছে জাহান্নামের আগুন তাতে অবস্থানের জন্যে? ঐটিই তো চরম লাঞ্ছনা।\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mccxcix{মুনাফিকরা ভয় করে পাছে তাদের সংক্রান্তে এমন কোনো সূরা অবতীর্ণ হয়ে যায় যা ওদের অন্তরে যা-কিছু আছে তা তাদের ব্যক্ত করে দেবে! বলো -- ''বিদ্রূপ ক’রে যাও, নিঃসন্দেহ আল্লাহ্ বের করে আনবেন তোমরা যা ভয় করো তা।’’\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mccc{আর তুমি যদি ওদের প্রশ্ন করো ওরা নিশ্চয়ই বলবে -- ''আমরা তো শুধু আলাপ-আলোচনা ও ক্রীড়া-কৌতুক করছিলাম।’’ বলো -- ''তোমরা কি আল্লাহ্ ও তাঁর বাণীসমূহ ও তাঁর রসূলকে নিয়ে মস্করা করছিলে?’’\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mccci{অজুহাত দেখিও না, তোমরা আলবৎ অবিশ্বাস করেছ তোমাদের বিশ্বাস স্থাপনের পরে। যদি আমরা ক্ষমা করি তোমাদের মধ্যের কোনো এক দলকে, অন্য এক দলকে শাস্তিও দেবো, কেননা তারা নিশ্চয়ই অপরাধী।\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mcccii{মুনাফিক পুরুষরা ও মুনাফিক নারীরা -- তাদের কতকজন অপর কতকজনের মধ্যেকার। তারা অসৎ কাজের নির্দেশ দেয় আর সৎকাজে নিষেধ করে, আর তারা নিজেদের হাত গুটিয়ে নেয়। তারা আল্লাহ্‌কে ভুলে গেছে, তাই তিনিও তাদের ভুলে গেছেন। নিঃসন্দেহ মুনাফিকরা নিজেরাই দুষ্কৃতিকারী।\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mccciii{মুনাফিক পুরুষদের ও মুনাফিক নারীদের ও অবিশ্বাসীদের জন্য আল্লাহ্ ওয়াদা করেছেন জাহান্নামের আগুন, তাতে তারা অবস্থান করবে। তাই তাদের জন্য পর্যাপ্ত, আর আল্লাহ্ তাদের ধিক্কার দিয়েছেন, আর তাদের জন্য রয়েছে নির্ধারিত শাস্তি।\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mccciv{তাদের মতো যারা ছিল তোমাদের পূর্ববর্তীকালে, -- তারা ছিল তোমাদের চাইতে বল-বিক্রমে বেশী প্রবল আর ধন-সম্পদে ও সন্তান সন্ততিতে বেশী সমৃদ্ধ। কাজেই তারা তাদের ভাগ ভোগ করে গেছে, অতএব তোমরাও তোমাদের ভাগ ভোগ করছো, যেমন ওরা যারা তোমাদের পূর্ববর্তী ছিল তারা ভোগ করেছিল তাদের ভাগ, আর তোমরাও বৃথা-বাক্যালাপ করছো যেমন তারা অনর্থক খোশ- গল্প করেছিল। এরাই -- এদের ক্রিয়াকলাপ ব্যর্থ হয়েছে ইহকালে ও পরকালে, আর এরা নিজেরাই হচ্ছে ক্ষতিগ্রস্ত।\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mcccv{তাদের কাছে কি তাদের পূর্বে যারা ছিল তাদের সংবাদ আসে নি -- নূহ্‌-এর লোকদের ও 'আদ-এর ও ছামূদের, আর ইব্রাহীমের সম্প্রদায়ের ও মাদয়ানের বাসিন্দাদের ও বিধবস্ত শহরগুলোর? ওদের কাছে ওদের রসূলগণ এসেছিলেন স্পষ্ট প্রমাণ নিয়ে। কাজেই আল্লাহ্ তো ওদের উপরে অবিচার করার জন্য নন, কিন্তু ওরা ওদের নিজেদেরই প্রতি জুলুম করেছিল।\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@mcccvi{আর মুমিন পুরুষরা ও মুমিন নারীরা -- তাদের কতকজন অপর কতকজনের বন্ধু। তারা ভালো কাজের নির্দেশ দেয় ও মন্দ কাজ থেকে নিষেধ করে, আর তারা নামায কায়েম করে ও যাকাত আদায় করে, আর তারা আল্লাহ্ ও তাঁর রসূলকে অনুসরণ করে। এরা -- আল্লাহ্ শীঘ্রই এদের করুণা করবেন। নিঃসন্দেহ আল্লাহ্ মহাশক্তিশালী, পরমজ্ঞানী।\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@mcccvii{বিশ্বাসী পুরুষদের ও বিশ্বাসিনী নারীদের আল্লাহ্ ওয়াদা করেছেন স্বর্গোদ্যানসমূহ যাদের নিচে দিয়ে বয়ে চলে ঝরনারাজি, তারা তাতে অবস্থান করবে, আর পুণ্য বাসস্থানসমূহ ইডেন গার্ডেনে। আর আল্লাহ্‌র সন্তষ্টিই হচ্ছে সর্বশ্রেষ্ঠ। এটি -- এই-ই হচ্ছে চরম সাফল্য।\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@mcccviii{হে প্রিয় নবী! অবিশ্বাসীদের ও মুনাফিকদের বিরুদ্ধে সংগ্রাম করো, আর তাদের প্রতি কঠোর হও। আর তাদের আবাসস্থল জাহান্নাম। আর মন্দ সেই গন্তব্যস্থান।\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@mcccix{তারা আল্লাহ্‌র নামে হলফ করে যে তারা কিছু বলে নি, অথচ তারা নিশ্চয়ই অবিশ্বাসের কথা বলেছিল, আর অবিশ্বাস পোষণ করেছিল তাদের ইসলাম গ্রহণের পরে, আর তারা মতলব করেছিল যা তারা পেরে ওঠে নি, আর তারা উত্তেজনা বোধ করে নি এ ভিন্ন যে আল্লাহ্ ও তাঁর রসূল তাদের সমৃদ্ধ করেছেন তাঁর প্রাচুর্য থেকে। কাজেই যদি তারা তওবা করে তবে সেটি তাদের জন্য হবে ভালো, আর যদি তারা ফিরে যায় তবে আল্লাহ্ তাদের শাস্তি দেবেন মর্মন্তুদ শাস্তিতে -- এই দুনিয়াতে ও পরকালে। আর তাদের জন্য এই পৃথিবীতে থাকবে না কোনো বন্ধুবান্ধব, না কোনো সাহায্যকারী।\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@mcccx{আর ওদের মধ্যে কেউ-কেউ আল্লাহ্‌র কাছে অঙ্গীকার করেছিল -- ''তিনি যদি তাঁর করুণাভান্ডার থেকে আমাদের দান করেন তবে আমরা নিশ্চয়ই সদকা-খয়রাত করবো আর আমরা অবশ্যই হবো সৎকর্মীদের মধ্যেকার।’’\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@mcccxi{কিন্তু যখন তিনি তাদের দিলেন তাঁর করুণাভান্ডার থেকে, তারা এতে কার্পণ্য করলো ও ফিরে গেল আর তারা হলো বিমুখ।\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@mcccxii{সুতরাং তিনি তাদের অন্তরে মুনাফিকি ন্যস্ত করেছেন সেদিন পর্যন্ত যেদিন তারা তাঁর সাথে মিলিত হবে, কেননা তারা আল্লাহ্‌র কাছে ভঙ্গ করেছিল যা তাঁর কাছে তারা ওয়াদা করেছিল, আর যেহেতু তারা মিথ্যাকথা বললো।\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@mcccxiii{তারা কি জানে না যে আল্লাহ্ অবশ্যই জানেন তাদের লুকোনো ও তাদের সলাপরামর্শ, আর আল্লাহ্ নিঃসন্দেহ অদৃশ্য ব্যাপারগুলো সম্পর্কে পরিজ্ঞাত।\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@mcccxiv{যারা বিদ্রূপ করে মুমিনদের মধ্যের তাদের যারা দানদক্ষিণায় বদান্য আর তাদের যারা কিছুই পায় না নিজেদের কায়িক শ্রম ব্যতীত, অথচ এদের তারা অবজ্ঞা করে, -- আল্লাহ্ তাদের অবজ্ঞা করবেন, আর তাদের জন্য রয়েছে মর্মন্তুদ শাস্তি।\qt@no{(79)}}
\qt@newcmd\qurantrans@bn@mcccxv{তুমি ওদের জন্য ক্ষমা প্রার্থনা করো অথবা ওদের জন্য ক্ষমা প্রার্থনা না করো, -- তুমি যদি ওদের জন্য সত্তরবারও ক্ষমা প্রার্থনা করো আল্লাহ্ কখনো ওদের ক্ষমা করবেন না। এটি এইজন্য যে তারা আল্লাহ্‌তে ও তাঁর রসূলের প্রতি অবিশ্বাস পোষণ করে। আর আল্লাহ্ দুষ্কৃতিকারী সম্প্রদায়কে পথপ্রদর্শন করেন না।\qt@no{(80)}}
\qt@newcmd\qurantrans@bn@mcccxvi{যারা পেছনে রয়ে গিয়েছিল তারা আল্লাহ্‌র রসূলের পশ্চাতে তাদের বসে থাকাতেই আনন্দবোধ করলো, আর তাদের ধনদৌলত ও তাদের জানপ্রাণ দিয়ে আল্লাহ্‌র পথে সংগ্রাম করতে তারা বিমুখ ছিল, আর তারা বলেছিল -- ''এই গরমের মধ্যে বেরিয়ো না।’’ তুমি বলো -- ''জাহান্নামের আগুন আরো বেশী গরম।’’ যদি তারা বুঝতে পারতো!\qt@no{(81)}}
\qt@newcmd\qurantrans@bn@mcccxvii{অতএব তারা কিছুটা হেসে নিক ও খুব ক’রে কাঁদুক, -- তারা যা অর্জন করছিল তার প্রতিফলস্বরূপ?\qt@no{(82)}}
\qt@newcmd\qurantrans@bn@mcccxviii{কাজেই আল্লাহ্ যদি তোমাকে ফিরিয়ে আনেন তাদের মধ্যের কোনো দলের নিকট, তারপর তারা যদি তোমার অনুমতি চায় বের হওয়ার জন্য তবে বলো -- ''তোমরা কোনো ক্রমেই আমার সাথে কখনো বেরুতে পারবে না, এবং তোমরা আমার সঙ্গী হয়ে কখনো কোনো শত্রুর বিরূদ্ধে লড়তে পারবে না। নিঃসন্দেহ তোমরা বসে থাকাতেই সন্তষ্ট ছিলে প্রথম বারে, অতএব বসে থাকো পশ্চাতে অবস্থানকারীদের সঙ্গে।’’\qt@no{(83)}}
\qt@newcmd\qurantrans@bn@mcccxix{আর তাদের মধ্যের একজনের জন্যেও, সে মারা গেলে, তুমি কখনো নামায পড়বে না, আর তার কবরের পাশেও দাঁড়াবে না। নিঃসন্দহে তারা আল্লাহ্‌তে ও তাঁর রসূলে অবিশ্বাস করেছে, আর তারা মরেছে যখন তারা ছিল দুষ্কৃতিপরায়ণ।\qt@no{(84)}}
\qt@newcmd\qurantrans@bn@mcccxx{আর তাদের ধনসম্পত্তি ও তাদের সন্তানসন্ততি তোমাকে যেন তাজ্জব না করে। আল্লাহ্ অবশ্যই চান এ-সবের দ্বারা পার্থিব জীবনে তাদের শাস্তি দিতে, আর যেন তাদের আ‌ত্মা চলে যায় ওদের অবিশ্বাসী থাকা অবস্থায়।\qt@no{(85)}}
\qt@newcmd\qurantrans@bn@mcccxxi{আর যখন কোনো সূরা অবতীর্ণ হয় এই মর্মে -- 'আল্লাহ্‌র প্রতি ঈমান আনো ও তাঁর রসূলের সঙ্গী হয়ে সংগ্রাম করো’, তাদের মধ্যের শক্তি- সামর্থের অধিকারীরা তোমার কাছে অব্যাহতি চায় ও বলে -- ''আমাদের রেহাই দিন, আমরা বসে-থাকা-লোকদের সঙ্গে ই থাকবো।’’\qt@no{(86)}}
\qt@newcmd\qurantrans@bn@mcccxxii{তারা পেছনে-রয়ে-থাকাদের সাথে অবস্থান করাই পছন্দ করেছিল, আর তাদের হৃদয়ের উপরে মোহর মেরে দেয়া হয়েছে, কাজেই তারা বুঝতে পারে না।\qt@no{(87)}}
\qt@newcmd\qurantrans@bn@mcccxxiii{কিন্তু রসূল এবং যারা তাঁর সঙ্গে ঈমান এনেছে তারা সংগ্রাম করে তাদের ধনদৌলত ও তাদের জানপ্রাণ দিয়ে। আর এরাই -- এদের জন্যেই রয়েছে কল্যাণ, আর এরা নিজেরাই হচ্ছে সফলকাম।\qt@no{(88)}}
\qt@newcmd\qurantrans@bn@mcccxxiv{আল্লাহ্ এদের জন্য প্রস্তুত করেছেন স্বর্গোদ্যানসমূহ, যাদের নিচে দিয়ে বয়ে চলে ঝরনারাজি, তারা সেখানে থাকবে স্থায়ীভাবে। এটি হচ্ছে বিরাট সাফল্য।\qt@no{(89)}}
\qt@newcmd\qurantrans@bn@mcccxxv{আর বেদুইনদের মধ্যের ওজর প্রদর্শনকারীরা এসেছিল যেন তাদের অব্যাহতি দেয়া হয়, আর যারা আল্লাহ্ ও তাঁর রসূলের কাছে মিথ্যাকথা বলেছিল তারা বসে রইল। তাদের মধ্যের যারা অবিশ্বাস পোষণ করে তাদের অচিরেই মর্মন্তুদ শাস্তি দেয়া হবে।\qt@no{(90)}}
\qt@newcmd\qurantrans@bn@mcccxxvi{দুর্বলদের উপরে, কোনো দোষ হবে না, পীড়িতদের উপরেও না, ওদের উপরেও না যারা খুঁজে পায় না কি তারা খরচ করবে, যে পর্যন্ত তারা আল্লাহ্ ও তাঁর রসূলের প্রতি অনুরাগ দেখাবে। সৎকর্মপরায়ণদের উপরে কোনো রাস্তা নেই। আর আল্লাহ্ পরিত্রাণকারী, অফুরন্ত ফলদাতা।\qt@no{(91)}}
\qt@newcmd\qurantrans@bn@mcccxxvii{আর ওদের উপরেও নেই যারা তোমার কাছে এসেছিল যেন তুমি তাদের জন্য বাহন যোগাড় করে দাও, তখন তুমি বলেছিল -- 'যার উপরে আমি তোমাদের বহন করব তা আমি পাচ্ছি না’, ওরা ফিরে গিয়েছিল আর ওদের চোখে অ‌শ্রু প্রবাহিত হচ্ছিল তারা যা খরচ করতে চায় তা না পাওয়ার দুঃখে।\qt@no{(92)}}
\qt@newcmd\qurantrans@bn@mcccxxviii{বস্তুতঃ পথ তাদেরই বিরুদ্ধে যারা তোমার কাছে অব্যাহতি চায় অথচ তারা বিত্তবান। তারা পেছনে রয়ে থাকাদের সাথে অবস্থানই পছন্দ করেছিল, আর আল্লাহ্ তাদের হৃদয়ের উপরে মোহর মেরে দিয়েছেন, যেজন্য তারা বুঝতে পারে না।\qt@no{(93)}}
\qt@newcmd\qurantrans@bn@mcccxxix{তারা তোমাদের কাছে অজুহাত দেখাবে যে কেন তারা যখন তোমরা তাদের কাছে ফিরে আসবে। তুমি বলো -- ''অজুহাত পেশ করো না, আমরা কখনো তোমাদের বিশ্বাস করব না, আল্লাহ্ ইতিমধ্যে তোমাদের খবরাখবর আমাদের জানিয়ে দিয়েছেন। আর আল্লাহ্ ও তাঁর রসূল অবশ্যই তোমাদের কার্যকলাপ লক্ষ্য করবেন, তারপর তোমাদের ফিরিয়ে আনা হবে অদৃশ্য ও দৃশ্য বস্তুর পরিজ্ঞাতার নিকটে, তখন তিনি তোমাদের জানিয়ে দেবেন যা তোমরা করে যাচ্ছিলে।’’\qt@no{(94)}}
\qt@newcmd\qurantrans@bn@mcccxxx{তোমরা তাদের কাছে সঙ্গে-সঙ্গে আল্লাহ্‌র নামে তোমাদের কাছে শপথ করবে যেন তাদের তোমরা উপেক্ষা করো। কাজেই তোমরা তাদের উপেক্ষা করবে। নিঃসন্দেহ তারা ঘৃণ্য, আর তাদের আশ্রয়স্থল হচ্ছে জাহান্নাম -- তারা যা কর ছিল এ তারই প্রতিদান!\qt@no{(95)}}
\qt@newcmd\qurantrans@bn@mcccxxxi{তারা তোমাদের কাছে হলফ করবে যেন তোমরা তাদের প্রতি সন্তষ্ট হও। কিন্তু তোমরা যদিও বা তাদের প্রতি সন্তষ্ট হও তথাপি আল্লাহ্ নিশ্চয়ই দুষ্কৃতিকারিগোষ্ঠীর প্রতি তুষ্ট হবেন না।\qt@no{(96)}}
\qt@newcmd\qurantrans@bn@mcccxxxii{বেদুইনরা অবিশ্বাসে ও মুনাফিকিতে অতিশয় অটল, আর আল্লাহ্ তাঁর রসূলের কাছে যা অবতারণ করেছেন তার চৌহদ্দি না জানার প্রতিই বেশী অনুরক্ত। আর আল্লাহ্ সর্বজ্ঞাতা, পরমজ্ঞানী।\qt@no{(97)}}
\qt@newcmd\qurantrans@bn@mcccxxxiii{আর বেদুইনদের মধ্যে কেউ-কেউ ধরে নেয় যে সে যা খরচ করে তা জরিমানা, আর তোমাদের জন্য প্রতীক্ষা করে বিপর্যয়ের। তাদেরই উপরে ঘটবে অশুভ বিপর্যয়, আর আল্লাহ্ সর্বশ্রোতা, সর্বজ্ঞাতা।\qt@no{(98)}}
\qt@newcmd\qurantrans@bn@mcccxxxiv{আর বেদুইনদের মধ্যের কেউ-কেউ আল্লাহ্‌তে ও শেষদিনে ঈমান আনে, আর যা সে খরচ করে তা আল্লাহ্‌র নৈকট্য ও রসূলের আশীর্বাদ আনবে বলে গণ্য করে। বাস্তবিকই এ নিঃসন্দেহ তাদের জন্য নৈকট্যলাভ। আল্লাহ্ অচিরেই তাদের প্রবেশ করাবেন তাঁর করুণাসিন্ধুতে। নিঃসন্দেহ আল্লাহ্ পরিত্রাণকারী, অফুরন্ত ফলদাতা।\qt@no{(99)}}
\qt@newcmd\qurantrans@bn@mcccxxxv{আর মুহাজিরদের ও আনসারদের মধ্যের অগ্রবর্তীরা -- প্রাথমিকরা, আর যারা তাদের অনুসরণ করেছিল কল্যাণকর্মের সাথে -- আল্লাহ্ তাদের উপরে সন্তষ্ট আর তারাও সন্তষ্ট তাঁর উপরে; আর তাদের জন্য তিনি প্রস্তুত করেছেন স্বর্গোদ্যানসমূহ, যাদের নিচে দিয়ে বয়ে চলে ঝরনারাজি, সেখানে তারা থাকবে চিরকাল, -- এই হচ্ছে মহাসাফল্য।\qt@no{(100)}}
\qt@newcmd\qurantrans@bn@mcccxxxvi{আর বেদুইনদের মধ্যের যারা তোমাদের আশেপাশে আছে তাদের মধ্যে রয়েছে মুনাফিকরা, আবার মদীনার বাসিন্দাদের মধ্যেও -- ওরা কপটতায় নাছোড়বান্দা। তুমি তাদের জানো না, আমরা ওদের জানি। আমরা অচিরেই তাদের দু বার শাস্তি দেবো, তারপর তাদের ফিরিয়ে নেয়া হবে কঠোর শাস্তির দিকে।\qt@no{(101)}}
\qt@newcmd\qurantrans@bn@mcccxxxvii{আর অন্যরা নিজেদের অপরাধ স্বীকার করেছে, তারা এক ভালো কাজের সাথে মন্দ অপরটি মিশিয়ে ফেলেছে। হতে পারে আল্লাহ্ তাদের দিকে ফিরবেন। নিঃসন্দেহ আল্লাহ্ পরিত্রাণকারী, অফুরন্ত ফলদাতা।\qt@no{(102)}}
\qt@newcmd\qurantrans@bn@mcccxxxviii{তাদের ধনসম্পত্তি থেকে দান গ্রহণ করো, এর দ্বারা তুমি তাদের পবিত্র করতে ও তাদের পরিশোধিত করতে পারবে, আর তাদের তুমি আশীর্বাদ করবে। নিঃসন্দেহ তোমার আশীর্বাদ তাদের জন্য প্রশান্তিকর। আর আল্লাহ্ সর্বশ্রোতা, সর্বজ্ঞাতা।\qt@no{(103)}}
\qt@newcmd\qurantrans@bn@mcccxxxix{তারা কি জানে না যে আল্লাহ্ -- তিনিই তাঁর বান্দাদের থেকে তওবা কবুল করেন আর দান গ্রহণ করেন, আর আল্লাহ্ নিশ্চয়ই সদা ফেরেন, অফুরন্ত ফলদাতা।\qt@no{(104)}}
\qt@newcmd\qurantrans@bn@mcccxl{আর বলো -- ''তোমরা কাজ করে যাও, অচিরেই আল্লাহ্ তোমাদের কার্যকলাপ লক্ষ্য করবেন, আর তাঁর রসূল ও মুমিনরাও। আর শীঘ্রই তোমাদের ফিরিয়ে আনা হবে অদৃশ্য ও দৃশ্যের পরিজ্ঞাতার নিকটে, তখন তিনি তোমাদের জানিয়ে দেবেন যা তোমরা করে যাচ্ছিলে।’’\qt@no{(105)}}
\qt@newcmd\qurantrans@bn@mcccxli{আর অন্যরা আল্লাহ্‌র বিধানের অপেক্ষায় রয়েছে, হয়তো তিনি তাদের শাস্তি দেবেন, নয়তো তাদের প্রতি ফিরবেন। আর আল্লাহ্ সর্বজ্ঞাতা, পরমজ্ঞানী।\qt@no{(106)}}
\qt@newcmd\qurantrans@bn@mcccxlii{আর যারা একটি মসজিদ স্থাপন করলো ক্ষতিসাধনের ও অবিশ্বাসের জন্য, আর বিশ্বাসীদের মধ্যে বিভেদ সৃষ্টির উদ্দেশ্যে, আর তার ঘাঁটি স্বরূপ যে এর আগে আল্লাহ্ ও তাঁর রসূলের বিরুদ্ধে লড়াই করছিল, তারা নিশ্চয়ই হলফ করে বলবে -- ''আমরা তো চেয়ছিলাম শুধু ভালো।’’ কিন্তু আল্লাহ্ সাক্ষ্য দিচ্ছেন যে তারা তো আলবৎ মিথ্যাবাদী।\qt@no{(107)}}
\qt@newcmd\qurantrans@bn@mcccxliii{তুমি কখনো এতে দাঁড়াবে না। নিঃসন্দেহ সেই মসজিদ যা প্রথম দিন থেকেই ধর্মনিষ্ঠার উপরে স্থাপিত তার বেশি দাবি রয়েছে যে তুমি সেখানে দাঁড়াবে। তাতে এমন লোক রয়েছে যারা ভালো পায় যে তারা পবিত্র হবে। আর আল্লাহ্ ভালোবাসেন তাদের যারা পবিত্র হয়েছে।\qt@no{(108)}}
\qt@newcmd\qurantrans@bn@mcccxliv{আচ্ছা! যে তা’হলে তার ভিত্তি গড়েছে আল্লাহ্‌র প্রতি ধর্মনিষ্ঠতা ও সন্তষ্টির উপরে সে-ই ভালো, না যে তার ভিত্তি স্থাপন করেছে পতনপ্রায় ধসের কিনারার উপরে, ফলে তা তাকে নিয়ে ভেঙে পড়লো জাহান্নামের আগুনে? আর আল্লাহ্ পথ দেখান না অন্যায়কারী লোকদের।\qt@no{(109)}}
\qt@newcmd\qurantrans@bn@mcccxlv{তাদের যে ভবন তারা বানিয়েছে তা তাদের হৃদয়ে অশান্তি সৃষ্টি থেকে বিরত হবে না, যদি না তাদের হৃদয় কুটি কুটি করা হয়। আর আল্লাহ্ সর্বজ্ঞাতা, পরমজ্ঞানী।\qt@no{(110)}}
\qt@newcmd\qurantrans@bn@mcccxlvi{নিঃসন্দেহ আল্লাহ্ মুমিনদের কাছ থেকে কিনে নিয়েছেন তাদের সত্ত্বা ও তাদের বিত্ত যেন তারা পেতে পারে বেহেশত। তারা আল্লাহ্‌র পথে লড়াই করে, ফলে তারা মারে ও মরে, -- এই ওয়াদা তাঁর জন্যে সত্য তওরাতে ও ইঞ্জীলে এবং কুরআনে। আর কে নিজ ওয়াদাতে বেশি সত্যনিষ্ঠ আল্লাহ্‌র চাইতে? অতএব আনন্দ করো তোমাদের সওদার জন্য যা তোমরা বিনিময় করেছ তাঁর সাথে। আর এইটিই হচ্ছে মহা সাফল্য।\qt@no{(111)}}
\qt@newcmd\qurantrans@bn@mcccxlvii{তওবাকারীরা, উপাসনাকারীরা, মহিমাকীর্তনকারীরা, রোযা পালনকারীরা, রুকুকারীরা, সিজদাকারীরা, সৎকর্মে নিদের্শ- দানকারীরা ও অসৎকর্মে নিষেধকারীরা, এবং আল্লাহ্‌র চৌহদ্দি রক্ষাকারীরা। আর মুমিনদের তুমি সুসংবাদ দাও।\qt@no{(112)}}
\qt@newcmd\qurantrans@bn@mcccxlviii{নবী ও যারা ঈমান এনেছে তাদের জন্য নয় যে তাঁরা ক্ষমা প্রার্থনা করবেন বহুখোদাবাদীদের জন্যে, যদিও বা তারা নিকটা‌ত্মীয় হয়, এটি তাঁদের কাছে স্পষ্ট হবার পরে যে তারা নিশ্চয়ই হচ্ছে জ্বলন্ত আগুনের বাসিন্দা।\qt@no{(113)}}
\qt@newcmd\qurantrans@bn@mcccxlix{আর ইব্রাহীমের তাঁর পিতার জন্যে ক্ষমা প্রার্থনা করা শুধু এজন্য ছাড়া অন্য কারণে নয় যে একটি অঙ্গীকার যা তিনি ওর সন্বন্ধে ওয়াদা করেছিলেন। কিন্তু যখন এটি তাঁর কাছে পরিস্কার করা হ’ল যে সে নিঃসন্দেহ আল্লাহ্‌র একজন শত্রু তখন তিনি ওর থেকে নির্লিপ্ত হয়ে গেলেন। নিঃসন্দেহ ইব্রাহীম ছিলেন কোমল হৃদয়ের, সহনশীল।\qt@no{(114)}}
\qt@newcmd\qurantrans@bn@mcccl{এটি আল্লাহ্‌র নয় যে তিনি একটি সম্প্রদায়কে পথভ্রষ্ট করবেন তাদের তিনি পথ-দেখানোর পরে -- এতদূর যে তিনি তাদের কাছে সুস্পষ্ট করে দেন কিসে তারা ধর্মনিষ্ঠা পালন করবে। নিঃসন্দেহ আল্লাহ্ সব-কিছুতে সর্বজ্ঞাতা।\qt@no{(115)}}
\qt@newcmd\qurantrans@bn@mcccli{নিঃসন্দেহ আল্লাহ্ -- মহাকাশমন্ডল ও পৃথিবীর রাজত্ব তাঁরই। তিনি জীবন দান করেন ও মৃত্যু ঘটান। আর আল্লাহ্‌কে ছেড়ে দিয়ে তোমাদের জন্য অভিভাবকের কেউ নেই বা সাহায্যকারীও নেই।\qt@no{(116)}}
\qt@newcmd\qurantrans@bn@mccclii{আল্লাহ্ নিশ্চয়ই ফিরেছেন নবীর প্রতি এবং মুহাজিরদের ও আনসারদের প্রতি যারা তাঁকে অনুসরণ করেছিল সঙ্কটের মুহূর্তে, তাদের একদলের মন প্রায় ঘুরে যাওয়ার পরেও, তারপর তিনি তাদের দিকে ফিরলেন। কারণ তিনি তাদের প্রতি পরম স্নেহময়, অফুরন্ত ফলদাতা।\qt@no{(117)}}
\qt@newcmd\qurantrans@bn@mcccliii{আর তিনজনের প্রতি যাদের পিছনে ছেড়ে যাওয়া হয়েছিল, তখন কিন্তু পৃথিবী প্রশস্ত হওয়া সত্ত্বেও তাদের কাছে তা সংকুচিত হয়েছিল, আর তাদের অন্তরা‌ত্মাও তাদের জন্য হয়েছিল সংকুচিত, আর তারা বুঝতে পেরেছিল যে আল্লাহ্ থেকে কোনো আশ্রয় নেই তাঁর দিকে ছাড়া। অতঃপর তিনি তাদের দিকে ফিরলেন যেন তারাও ফেরে। নিঃসন্দেহ আল্লাহ্ -- তিনি বারবার ফেরেন, অফুরন্ত ফলদাতা।\qt@no{(118)}}
\qt@newcmd\qurantrans@bn@mcccliv{ওহে যারা ঈমান এনেছ! আল্লাহ্‌কে ভয়শ্রদ্ধা করো আর সত্যপরায়ণদের অন্তর্ভুক্ত হও।\qt@no{(119)}}
\qt@newcmd\qurantrans@bn@mccclv{মদীনার বাসিন্দাদের ও তাদের আশপাশের বেদুইনদের জন্যে নয় যে তারা আল্লাহ্‌র রসূলের পিছনে থেকে যাবে, এবং নিজেদের জীবনকে তাঁর জীবনের চেয়ে বেশি প্রিয় মনে করাও নয়। এটি তাদের বেলা এই জন্য যে আল্লাহ্‌র পথে তাদের কষ্ট দেয় না পিপাসা, আর ক্লান্তিও না, আর ক্ষুধাও না, আর তারা এমন পথে পথ চলে না যা অবিশ্বাসীদের ক্রোধ উদ্রেক করে, আর তারা শত্রুর থেকে সংগ্রহ করে না কোনো সংগ্রহের বস্তু, -- তবে এ-সবের দ্বারা তাদের জন্যে লিখিত হয় শুভ কাজ। নিঃসন্দেহ আল্লাহ্ সৎকর্মশীলদের পুরস্কার ব্যর্থ করেন না।\qt@no{(120)}}
\qt@newcmd\qurantrans@bn@mccclvi{আর তারা খরচ করে না কোনো সামান্য খরচা আর কোনো বিরাটও নয়, আর তারা কোনো মাঠও পার হয় না তবে তাদের জন্যে তা লিখিত হয়ে যায়, যেন আল্লাহ্ তাদের পুরস্কার দিতে পারেন তারা যা করে যাচ্ছিল তার চেয়ে উত্তম।\qt@no{(121)}}
\qt@newcmd\qurantrans@bn@mccclvii{আর মুমিনদের পক্ষে সঙ্গত নয় যে তারা একজোটে বেরিয়ে পড়বে। সুতরাং তাদের মধ্যের প্রত্যেক গোত্র থেকে কেন একটি দল বেরিয়ে পড়ে না ধর্মে জ্ঞানানুশীলন করতে, যার ফলে তারা যেন নিজ নিজ সম্প্রদায়কে সতর্ক করতে পারে যখন তারা ফিরে আসে তাদের কাছে যাতে তারা সাবধান হতে পারে?\qt@no{(122)}}
\qt@newcmd\qurantrans@bn@mccclviii{ওহে যারা ঈমান এনছ! অবিশ্বাসীদের মধ্যে যারা তোমাদের নিকটে রয়েছে তাদের সঙ্গে যুদ্ধ করো, আর তারা যেন তোমাদের মধ্যে দেখতে পায় কঠোরতা। আর জেনে রেখো -- নিঃসন্দেহ আল্লাহ্ ধর্মপরায়ণদের সাথে রয়েছেন।\qt@no{(123)}}
\qt@newcmd\qurantrans@bn@mccclix{আর যখনই একটি সূরা অবতীর্ণ হয় তখন তাদের কেউ কেউ বলে -- ''এ তোমাদের মধ্যের কার বিশ্বাস সমৃদ্ধ করল?’’ আসলে যারা বিশ্বাস স্থাপন করেছে তাদের কিন্তু এটি বিশ্বাসে সমৃদ্ধ করে, আর তারাই তো সুসংবাদ উপভোগ করে।\qt@no{(124)}}
\qt@newcmd\qurantrans@bn@mccclx{আর তাদের ক্ষেত্রে যাদের অন্তরে রয়েছে ব্যাধি, -- এ তখন তাদের কলুষতার সঙ্গে কলুষতা তাদের জন্য বাড়িয়ে তোলে, আর তারা প্রাণত্যাগ করে, আর তারা রয়ে যায় অবিশ্বাসী।\qt@no{(125)}}
\qt@newcmd\qurantrans@bn@mccclxi{তারা কি দেখে না যে প্রতি বছর একবার বা দুবার করে অবশ্যই তাদের পরীক্ষা নেয়া হচ্ছে? তবুও তারা ফেরে না বা মনও দেয় না।\qt@no{(126)}}
\qt@newcmd\qurantrans@bn@mccclxii{আর যখনই কোনো সূরা অবতীর্ণ হয় তাদের কেউ কেউ অন্যের দিকে তাকায় -- ''কেউ কি তোমাদের দেখছে?’’ তারপর তারা সরে পড়ে। আল্লাহ্ তাদের হৃদয়কে সত্যবিমুখ করেছেন যেহেতু তারা নিঃসন্দেহ এমন এক দল যারা বুঝতে চায় না।\qt@no{(127)}}
\qt@newcmd\qurantrans@bn@mccclxiii{এখন তো তোমাদের কাছে একজন রসূল এসেছেন তোমাদেরই মধ্যে থেকে, তাঁর পক্ষে এটি দুঃসহ যা তোমাদের কষ্ট দেয়, তোমাদের জন্য তিনি পরম কল্যাণকামী, বিশ্বাসীদের প্রতি তিনি অতি দয়ার্দ্র, বিশেষ কৃপাময়।\qt@no{(128)}}
\qt@newcmd\qurantrans@bn@mccclxiv{অতঃপর যদি তারা ফিরে যায় তাহলে বলো -- ''আল্লাহ্ আমার জন্যে যথেষ্ট, তিনি ব্যতীত অন্য উপাস্য নেই, তাঁরই উপরে আমি নির্ভর করি, আর তিনিই তো মহাসিংহাসনের অধিপতি।’’\qt@no{(129)}}
\qt@newcmd\qurantrans@bn@mccclxv{\basmalahbn আলিফ, লাম, রা। এগুলো জ্ঞানগর্ভ গ্রন্থের আয়াতসমূহ।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mccclxvi{এ কি মানবগোষ্ঠীর জন্য বিস্ময়ের ব্যাপার যে তাদেরই মধ্যেকার একজন মানুষকে আমরা প্রত্যাদেশ দিয়েছি এই ব’লে -- ''তুমি মানবজাতিকে সতর্ক করো, আর যারা ঈমান এনেছে তাদের সুসংবাদ দাও যে তাদের জন্য তাদের প্রভুর কাছে রয়েছে সুনিশ্চিত পদমর্যাদা’’? অবিশ্বাসীরা বলে -- ''নিঃসন্দেহ এ একজন জলজ্যান্ত জাদুকর।’’\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mccclxvii{নিঃসন্দেহ তোমাদের প্রভু হচ্ছেন আল্লাহ্ যিনি মহাকাশমন্ডল ও পৃথিবী সৃষ্টি করেছেন ছয় দিনে, তখন তিনি অধিষ্ঠিত হলেন আরশের উপরে, তিনি সমস্ত ব্যাপার নিয়ন্ত্রণ করেন। তাঁর অনুমতিক্রমে ব্যতীত কোনো সুপারিশকারী নেই। এই-ই আল্লাহ্ -- তোমাদের প্রভু, অতএব তাঁরই উপাসনা করো। তোমরা কি তবে খেয়াল করো না।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mccclxviii{তাঁরই দিকে তোমাদের সকলের প্রত্যাবর্তন। আল্লাহ্‌র এই প্রতি‌শ্রুতি ধ্রুবসত্য। নিঃসন্দেহ তিনিই সৃষ্টির সূচনা করেন, তারপর তিনি তার পুনরাবর্তন ঘটান, যেন তিনি ন্যায়সঙ্গতভাবে পারিতোষিক দিতে পারেন তাদের যারা বিশ্বাস করে ও সৎকর্ম করে। আর যারা অবিশ্বাস করে তাদের জন্যে রয়েছে ফুটন্ত জলের পানীয়, আর মর্মন্তুদ শাস্তি, কেননা তারা অবিশ্বাস পোষণ করত।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mccclxix{তিনিই তো সূর্যকে করেছেন তেজস্কর, আর চন্দ্রকে জ্যোতির্ময়, আর তার জন্য নির্ধারিত করেছেন অবস্থানসমূহ যেন তোমরা জানতে পারো বৎসরের গণনা ও হিসাব। আল্লাহ্ এ সৃষ্টি করেন নি সার্থকতা ছাড়া। তিনি নির্দেশাবলী বিশদ-ব্যাখ্যা করেন সেইসব লোকের জন্য যারা জ্ঞান রাখে।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mccclxx{নিঃসন্দেহ রাত ও দিনের বিবর্তনের মধ্যে, আর আল্লাহ্ যা-কিছু সৃষ্টি করেছেন মহাকাশে ও পৃথিবীতে, সে-সমস্তে রয়েছে নিদর্শন সেইসব লোকের জন্যে যারা ধর্মপরায়ণ।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mccclxxi{নিঃসন্দেহ যারা আমাদের সাথে মুলাকাত আশা করে না আর পার্থিব জীবনেই পরিতৃপ্ত থাকে আর তাতেই নিশ্চিন্ত বোধ করে, আর যারা আমাদের নির্দেশাবলীতে অমনোযোগী, --\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mccclxxii{এরাই -- এদের আবাসস্থল হচ্ছে আগুন, তারা যা উপার্জন করেছে সেজন্য।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mccclxxiii{নিঃসন্দেহ যারা বিশ্বাস স্থাপন করে ও সৎকর্ম করে, তাদের প্রভু তাদের পথ দেখিয়ে নেবেন তাদের বিশ্বাসের দ্বারা, -- তাদের নিচে দিয়ে বয়ে চলবে ঝরনারাজি আনন্দময় বাগানে।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mccclxxiv{সেখানে তাদের আহ্বান হবে -- ''তোমারই মহিমা হোক, হে আল্লাহ্‌?’’ আর তাদের অভিবাদন সেখানে হবে -- ''সালাম’’, আর তাদের শেষ আহ্বান হবে -- ''সকল প্রশংসা হচ্ছে আল্লাহ্‌র যিনি সমস্ত বিশ্বজগতের প্রভু’’।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mccclxxv{আল্লাহ্ যদি মানুষের জন্য অকল্যাণ ত্বরান্বিত করতেন যেমন তারা তাদের জন্য কল্যাণ ত্বরান্বিত করতে চায়, তাহলে তাদের শেষ- পরিণতি তাদের উপরে ঘটে যেত। কিন্তু যারা আমাদের সাথে মুলাকাত করা পছন্দ করে না -- তাদের আমরা অন্ধভাবে ঘুরে বেড়াতে দিই তাদের অবাধ্যতার মধ্যে।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mccclxxvi{আর যখন কোনো দুঃখ-দুর্দশা মানুষকে স্পর্শ করে সে তখন আমাদের ডাকে কাত হয়ে শায়িত অবস্থায় অথবা বসা অবস্থায় অথবা দাঁড়িয়ে থেকে, কিন্তু যখন আমরা তার থেকে তার বিপদ দূর করে দিই, সে তখন ঘুরে বেড়ায় যেন সে আমাদের কদাচ ডাকে নি বিপদের সময়ে যা তাকে স্পর্শ করেছিল। এইভাবে দায়িত্বহীনদের কাছে চিত্তাকর্ষক করা হয় যা তারা করে চলে।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mccclxxvii{আর ইতিমধ্যে তোমাদের পূর্ববর্তী অনেক মানবগোষ্ঠীকে আমরা ধ্বংস করেছিলাম যখন তারা অনাচার করেছিল, আর তাদের রসূলগণ তাদের কাছে এসেছিলেন স্পষ্ট প্রমাণাবলী নিয়ে, কিন্তু তারা বিশ্বাস করতে প্রস্তুত ছিল না। এইভাবে আমরা প্রতিদান দিই অপরাধী সম্প্রদায়কে।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mccclxxviii{তারপর আমরা তোমাদের এই পৃথিবীতে প্রতিনিধি বানিয়ে-ছিলাম তাদের পরে যেন আমরা দেখতে পারি তোমরা কেমনতর কাজ কর।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mccclxxix{আর যখন তাদের কাছে পাঠ করা হয় আমাদের সুস্পষ্ট বণীসমূহ, যারা আমাদের সাথে মুলাকাতের আশা করে না তারা বলে -- ''এ ছাড়া অন্য এক কুরআন আনো অথবা এটি বদলাও।’’ বলো, ''একে আমার নিজের ইচ্ছায় বদলানো আমার কাজ নয়। আমার কাছে যা প্রত্যাদিষ্ট হয় শুধু তারই আমি অনুসরণ করি। আমি আলবৎ ভয় করি, -- যদি আমি আমার প্রভুর অবাধ্য হই, -- এক ভয়ঙ্কর দিনের শাস্তির।’’\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mccclxxx{বলো -- ''যদি আল্লাহ্ ইচ্ছা করতেন তবে আমি তোমাদের কাছে এ পাঠ করতাম না আর তিনিও তোমাদের কাছে এ জানাতেন না। আমি তো তোমাদের মধ্যে এর আগে এক জীবনকাল কাটিয়েছি। তোমরা কি তবে বোঝো না?’’\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mccclxxxi{কে তবে বেশি অন্যায়কারী তার চাইতে যে আল্লাহ্ সম্পর্কে মিথ্যা রচনা করে অথবা তাঁর নির্দেশসমূহ প্রত্যাখ্যান করে? নিঃসন্দেহ অপরাধীরা সফলকাম হবে না।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mccclxxxii{আর ওরা আল্লাহ্‌কে ছেড়ে দিয়ে তার উপাসনা করে যা তাদের কোনো ক্ষতি করতে পারে না বা তাদের উপকারও করতে পারে না, আর তারা বলে -- ''এরা আমাদের জন্য আল্লাহ্‌র কাছে সুপারিশকারী।’’ বলো -- ''তোমরা কি আল্লাহ্‌কে জানাতে চাও যা তিনি জানেন না মহাকাশে আর পৃথিবীতেও না?’’ তারঁই সব মহিমা! আর তারা যাকে অংশী করে তা হতে তিনি বহু ঊর্ধ্বে।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mccclxxxiii{মানবগোষ্ঠী একই জাতি বইতো নয়, তারপর তারা মতপার্থক্য করলো। আর যদি তোমার প্রভুর কাছ থেকে ঘোষণাটি বলা না হতো তাহলে যে বিষয়ে তারা মতভেদ করছে তা তাদের মধ্যে মীমাংসা হয়ে যেতো।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mccclxxxiv{আর তারা বলে -- ''তার প্রভুর কাছ থেকে কেন একটি নিদর্শন তার কাছে পাঠানো হয় না?’’ তবে বলো -- ''অদৃশ্য কেবল আল্লাহ্‌রই রয়েছে, কাজেই অপেক্ষা করো, নিঃসন্দেহ আমিও তোমাদেরই সঙ্গে অপেক্ষাকারীদের মধ্যেকার।’’\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mccclxxxv{আর যখন আমরা লোকদের করুণার আস্বাদ দিই কোনো দুঃখ-দুর্দশা তাদের স্পর্শ করার পরে, দেখো! তারা আমাদের নিদর্শনসমূহের বিরুদ্ধে ষড়যন্ত্র করে। বলো -- ''আল্লাহ্ পরিকল্পনা করায় অধিকতর তৎপর।’’ নিঃসন্দেহ আমাদের দূতরা লিখে রাখে যে ষড়যন্ত্র তোমরা করো।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mccclxxxvi{তিনিই সেইজন যিনি তোমাদের ভ্রমণ করান স্থলে ও জলে। তারপর তোমরা যখন জাহাজে থাকো, আর তাদের নিয়ে তা যাত্রা করে অনুকুল হওয়ায়, আর তারা তাতে মৌজ করে, তাতে এসে পড়ে এক ঝড়ো বাতাস, আর চতুর্দিক থেকে ঢেউ আসতে থাকে তাদের কাছে, আর তারা মনে করে যে তারা আলবৎ এর দ্বারা ঘেরাও হয়ে পড়েছে, তারা আল্লাহ্‌কে ডাকে তাঁর প্রতি আনুগত্যে বিশুদ্ধচিত্ত হয়ে -- ''যদি এ থেকে তুমি আমাদের উদ্ধার করো তবে আমরা অবশ্যই কৃতজ্ঞদের অন্তর্ভুক্ত হবো।’’\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mccclxxxvii{তারপর তিনি যখন তাদের উদ্ধার করেন, দেখো! তারা পৃথিবীতে দৌরা‌ত্ম্য শুরু করে অন্যায়ভাবে। ওহে মানবগোষ্ঠি! তোমাদের দৌরা‌ত্ম্য বস্তুতঃ তোমাদেরই বিরুদ্ধে, দুনিয়ার জীবনের সামান্য উপভোগ, তারপর আমাদেরই কাছে তোমাদের প্রত্যাবর্তন, তখন আমরা তোমাদের জানিয়ে দেবো যা তোমরা করে চলেছিলে।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mccclxxxviii{এই দুনিয়ার জীবনের তুলনা হচ্ছে বৃষ্টির ন্যায় যা আমরা আকাশ থেকে বর্ষণ করি, তখন তার দ্বারা পৃথিবীর গাছপালা ভুইঁফোঁড়ে বাড়ে যা থেকে মানুষ ও জীবজন্তু আহার করে থাকে, তারপর যখন পৃথিবী তার সোনালী শোভা ধারণ করে ও সাজসজ্জা পরে, আর এর মালিকেরা ভাবে যে তারা আলবৎ এর উপরে আয়ত্তাধীন, তখন আমাদের আদেশ এর উপরে এসে পড়ে রাতে অথবা দিনে, ফলে আমরা একে বানাই কাটা শস্যের মতন যেন গতকালও তার প্রাচুর্য ছিল না। এইভাবে আমরা নির্দেশাবলী বিশদ ব্যাখ্যা করি সেইসব সম্প্রদায়ের জন্য যারা চিন্তা করে।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mccclxxxix{আর আল্লাহ্ আহ্বান করেন শান্তির আলয়ে, আর যাকে তিনি ইচ্ছে করেন তাকে পরিচালিত করেন সহজ-সঠিক পথের দিকে।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mcccxc{যারা ভালো করে তাদের জন্য রয়েছে ভালো এবং আরো বেশি। আর তাদের মুখমন্ডলকে আচ্ছাদন করবে না কোনো কালিমা এবং কোনো অপমানও নয়। এরাই হচ্ছে বেহেশতের অধিবাসী, তারা সেখানে থাকবে স্থায়ীভাবে।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mcccxci{আর যারা মন্দ অর্জন করে মন্দকাজের প্রতিফল হবে তার অনুরূপ, আর তাদের আচ্ছাদন হবে অপমান। তাদের জন্য আল্লাহ্ থেকে কোনো রক্ষক নেই, -- যেন তাদের মুখমন্ডল আচ্ছাদিত হয়েছে নিশীথের গহন অন্ধকারের একাংশ দিয়ে। এরাই হচ্ছে আগুনের অধিবাসী, তারা সেখানে থাকবে দীর্ঘকাল।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mcccxcii{আর যেদিন আমরা ওদের সবাইকে সমবেত করবো, তারপর যারা অংশী দাঁড় করেছিল তাদের বলবো -- ''তোমরা ও তোমাদের অংশীরা নিজ নিজ স্থানে অবস্থান করো।’’ তারপর আমরা তাদের একে অন্য থেকে বিচ্ছিন্ন করে দেবো, আর তাদের অংশীরা বলবে -- ''তোমরা তো আমাদের উপাসনা করতে না।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mcccxciii{''সেজন্য আমাদের মধ্যে ও তোমাদের মধ্যে সাক্ষীরূপে আল্লাহ্‌ই যথেষ্ট যে তোমাদের পূজা-অর্চনা সন্বন্ধে আমরা অনবহিত ছিলাম।’’\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mcccxciv{সেখানে প্রত্যেক আ‌ত্মা উপলব্ধি করবে যা সে পূর্বে পাঠিয়েছে, আর তাদের ফিরিয়ে আনা হবে তাদের প্রকৃত অভিভাবক আল্লাহ্‌র নিকটে, আর তাদের কাছ থেকে বিদায় নেবে যাদের তারা উদ্ভাবন করেছিল।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mcccxcv{বলো -- ''কে তোমাদের জীবিকা দান করে মহাকাশমন্ডল ও পৃথিবী থেকে? অথবা শ্রবণশক্তি ও দৃষ্টিশক্তি কার কর্তৃত্বাধীন? আর কে মৃত থেকে জীবিতকে নির্গত করে ও জীবিত থেকে মৃতকে নির্গত করে? আর কে বিষয়-আশয় নিয়ন্ত্রণ করে?’’ তখন তারা বলবে -- ''আল্লাহ্‌।’’ তাহলে বলো -- ''তবে কেন তোমরা ধর্মপরায়ণতা অবলন্বন করো না?’’\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mcccxcvi{এই তবে আল্লাহ্‌, -- তোমাদের আসল প্রভু, সত্যের পরে তবে মিথ্যা ভিন্ন আর কি থাকে? সুতরাং কোথায় তোমরা ফিরে যাচ্ছ?\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mcccxcvii{এইভাবে তোমার প্রভুর বাণী সত্যপ্রতিপন্ন হয় তাদের বিরুদ্ধে যারা অবাধ্যাচরণ করে -- ''নিঃসন্দেহ তারা ঈমান আনবে না’’।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mcccxcviii{বলো -- ''তোমাদের অংশীদের মধ্যে কেউ কি আছে যে আদি-সৃষ্টি আর করতে পারে, তারপর তা পুনরুৎপাদন করতে পারে?’’ তুমি বলো -- ''আল্লাহ্‌ই সৃষ্টি শুরু করেন, তারপর তা পুনরুৎপাদন করেন। সুতরাং তোমরা কোথায় চলে যাচ্ছ?’’\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mcccxcix{বলো -- ''তোমাদের অংশীদের মধ্যে কেউ কি আছে যে পরিচালিত করে সত্যের প্রতি?’’ তুমি বলো -- ''আল্লাহ্‌ই সত্যের প্রতি পরিচালিত করেন।’’ অতএব যিনি সত্যের প্রতি পথ দেখান তিনি অনুসরণের অধিকতর দাবিদার, না যে পরিচালন করে না যদি না সে পরিচালিত হয়? তোমাদের তবে কি হয়েছে? কিভাবে তোমরা বিচার করো?\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mcd{আর তাদের অধিকাংশই অনুমান ছাড়া আর কিছুই অনুসরণ করে না। নিঃসন্দেহ সত্যের পরিবর্তে অনুমানের কোনোই মূল্য নেই। ওরা যা করে সে বিষয়ে আল্লাহ্ অবশ্যই সর্বজ্ঞাতা।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mcdi{আর এই কুরআন এমন নয় যা রচনা করতে পারে আল্লাহ্ ছাড়া অন্য কেউ, পক্ষান্তরে এ সমর্থন করে এর পূর্বে যা ছিল তার, আর গ্রন্থের এ এক বিশদ ব্যাখ্যা -- কোনো সন্দেহ নেই এতে বিশ্বজগতের প্রভুর কাছ থেকে।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mcdii{অথবা তারা কি বলে -- ''তিনি এটি রচনা করেছেন’’? তুমি বলো -- ''তাহলে নিয়ে এস এর মতো একটি সূরা, আর আল্লাহ্‌কে ছেড়ে দিয়ে যাদের পারো ডাকো, যদি তোমরা সত্যবাদী হয়ে থাকো।’’\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mcdiii{না, তারা প্রত্যাখ্যান করে যার জ্ঞানের সীমা তারা পায় না, আর এখনও এর মর্ম তাদের কাছে আসে নি। এইভাবে প্রত্যাখ্যান করেছিল তারা যারা তাদের পূর্বে ছিল, সুতরাং দেখো কেমন হয়েছিল অত্যাচারীদের পরিণাম।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mcdiv{আর তাদের মধ্যে কেউ কেউ আছে যে এতে বিশ্বাস করে, আর তাদের মধ্যে কেউ কেউ আছে যে এতে বিশ্বাস করে না। আর তোমার প্রভু গন্ডগোল সৃষ্টিকারীদের ভালো জানেন।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mcdv{আর তারা যদি তোমার প্রতি মিথ্যারোপ করে তবে বলো -- ''আমার কাজ আমার জন্য, আর তোমাদের কাজ তোমাদের জন্য, তোমরা দায়ী নও আমি যা করি সে বিষয়ে আর আমিও দায়ী নই তোমরা যা করো সে বিষয়ে।’’\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mcdvi{আর তাদের মধ্যে কেউ কেউ তোমার কথা শোনে। তুমি কি বধিরকে শোনাতে পারো, -- পরন্ত তারা বুদ্ধিশুদ্ধি রাখে না?\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mcdvii{আর তাদের মধ্যে কেউ কেউ তোমার দিকে তাকিয়ে থাকে। তুমি কি অন্ধকে পথ দেখতে পারো, -- পরন্ত তারা দেখতে পায় না?\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mcdviii{নিঃসন্দেহ আল্লাহ্ মানুষের প্রতি কোনো অন্যায় করেন না, কিন্তু মানুষরা তাদের নিজেদেরই প্রতি অন্যায় করে।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mcdix{আর যেদিন তিনি তাদের একত্রিত করবেন যেন তারা দিনের এক ঘন্টাও কাটায় নি, তারা একে-অন্যকে চিনতে পারবে। আল্লাহ্‌র সঙ্গে মুলাকাত হওয়াকে যারা মিথ্যা বলেছিল তারা আলবৎ ক্ষতিগ্রস্ত হয়েছে, আর তারা সঠিক পথে চালিত ছিল না।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mcdx{আর তোমাকে যদি আমরা দেখিয়ে দিই ওদের যা আমরা ওয়াদা করেছিলাম তার কিছুটা, অথবা তোমার মৃত্যু ঘটিয়ে দিই, তা হলেও আমাদের কাছেই তাদের প্রত্যাবর্তন, তার উপর আল্লাহ্ সাক্ষী রয়েছেন যা তারা করে তার।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mcdxi{আর প্রত্যেক জাতির জন্যে একজন রসূল, অতএব যখন তাদের রসূল এসেছিলেন তখন ন্যায়-বিচারের সাথে ওদের মধ্যে মীমাংসা হয়েছে, আর তাদের প্রতি অন্যায় করা হয় নি।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mcdxii{আর তারা বলে -- ''এ ওয়াদা কবে ফলবে, -- যদি তোমরা সত্যবাদী হও?’’\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mcdxiii{তুমি বলো -- ''আমি নিজের থেকে কোনো অনিষ্ট-সাধনের কর্তৃত্ব রাখি না বা মুনাফা দেবারও নয় -- আল্লাহ্ যা ইচ্ছা করেন তা ব্যতীত।’’ প্রত্যেক জাতির জন্য এক নির্দিষ্ট সময় আছে, যখন তাদের সময় ঘনিয়ে আসবে তখন তারা ঘন্টাখানেকের জন্যেও দেরি করতে পারবে না বা এগিয়েও আনতে পারবে না।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mcdxiv{বলো -- ''তোমরা কি ভেবে দেখেছ যে যদি তাঁর শাস্তি তোমাদের উপরে এসে পড়ে রাত্রির আক্রমণরূপে অথবা দিনের বেলায়, তবে এর মধ্যের কোনটা ত্বরান্বিত করতে চায় অপরাধীরা?\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mcdxv{তবে কি তখন তোমরা এতে বিশ্বাস করবে যখন এটি ঘটবে? ''আহা, এখন! তোমরা তো এটিই ত্বরান্বিত করতে চেয়েছিলে!’’\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mcdxvi{তারপর যারা অন্যায়াচরণ করেছিল তাদের বলা হবে -- ''স্থায়ী শাস্তি আস্বাদন করো। তোমরা যা অর্জন ক’রে চলেছিলে তা ছাড়া অন্য কিছু কি তোমাদের প্রতিদান দেওয়া হচ্ছে?’’\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mcdxvii{আর তারা তোমার কাছে জানতে চায় -- ''এ কি সত্য?’’ বলো -- ''হাঁ, আমার প্রভুর কসম, এ আলবৎ সত্য। আর তোমাদের এড়াবার নহে!’’\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mcdxviii{আর প্রতিটি লোকের, যে অন্যায় করেছে, তার যদি হতো পৃথিবীতে যা কিছু আছে সে অবশ্যই সেগুলো দিয়ে মুক্তি চাইত। আর তারা অনুতাপ অনুভব করবে যখন তারা শাস্তি দেখতে পাবে, কিন্তু তাদের সন্বন্ধে মীমাংসা করা হয়েছে ন্যায়সঙ্গত ভাবে, আর তাদের জুলুম করা হবে না।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mcdxix{যা-কিছু মহাকাশে ও পৃথিবীতে রয়েছে সে-সবই কি বাস্তবে আল্লাহ্‌র নয়? আল্লাহ্‌র ওয়াদা কি অবশ্যই সত্য নয়? কিন্তু তাদের অনেকেই জানে না।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mcdxx{তিনিই জীবনদান করেন ও মৃত্যু ঘটান, আর তাঁরই কাছে তোমাদের ফিরিয়ে আনা হবে।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mcdxxi{ওহে মানবগোষ্ঠি! তোমাদের কাছে নিশ্চয়ই তোমাদের প্রভুর কাছ থেকে এসেছে এক ধর্মোপদেশ আর অন্তরে যা আছে তার জন্য এক আরোগ্য বিধান, আর বিশ্বাসীদের জন্য এক পথনির্দেশ ও এক করুণা।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mcdxxii{বলো -- ''আল্লাহ্‌র বদান্যতায় ও তাঁর করুণায়’’ -- অতএব এতে তারা তবে আনন্দ প্রকাশ করুক। তারা যা পুঞ্জীভূত করে তার চাইতে এ অধিকতর শ্রেয়।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mcdxxiii{বলো -- ''তোমরা কি দেখেছ আল্লাহ্ তোমাদের জন্য জীবিকা থেকে কত কি পাঠিয়েছেন, তারপর তোমরা তার কিছু হারাম ও হালাল বানিয়েছে?’’ বলো -- ''আল্লাহ্ কি তোমাদের জন্য অনুমতি দিয়েছেন, না তোমরা আল্লাহ্‌র প্রতি মিথ্যারোপ করছো?’’\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mcdxxiv{আর যারা আল্লাহ্ সন্বন্ধে মিথ্যা উদ্ভাবন করে তারা কিয়ামতের দিন সন্বন্ধে কি ভাবছে? নিঃসন্দেহ আল্লাহ্ মানুষের প্রতি অবশ্যই বদান্যতার সর্বময় কর্তা, কিন্তু তাদের অধিকাংশই কৃতজ্ঞতা প্রকাশ করে না।\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mcdxxv{আর তুমি এমন কোনো কাজে নও বা সে-সম্পর্কে কুরআন থেকে আবৃত্তি করো না, আর তোমরা এমন কোনো কাজ করো না -- আমরা কিন্তু তোমাদের উপরে সাক্ষী রয়েছি যখন তোমরা তাতে নিযুক্ত থাক। আর তোমার প্রভুর কাছ থেকে অণু পরিমাণ কিছুও লুকোনো থাকছে না এ পৃথিবীতে আর মহাকাশেও নয়, আর তার চাইতে ছোটও নেই ও বড়ও নেই যা নয় এক সুস্পষ্ট গ্রন্থে।\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mcdxxvi{জেনে রোখো! নিঃসন্দেহ আল্লাহ্‌র বন্ধুরা -- তাদের উপরে কোনো ভয় নেই, আর তারা অনুতাপও করবে না।\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mcdxxvii{যারা বিশ্বাস স্থাপন করে ও ভয়ভক্তি করে --\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mcdxxviii{তাদের জন্য রয়েছে সুসংবাদ এই পৃথিবীর জীবনে এবং পরকালে। আল্লাহ্‌র বাণীর কোনো পরিবর্তন নেই, -- এটিই হচ্ছে মহা সাফল্য।\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mcdxxix{আর তাদের কথা তোমাকে যেন দুঃখ না দেয়। সম্মান নিঃসন্দেহ সম্পূর্ণরূপে আল্লাহ্‌র। তিনি সর্বশ্রোতা, সর্বজ্ঞাতা!\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mcdxxx{এটি কি নয় যে নিঃসন্দেহ মহাকাশমন্ডলে যারা আছে ও যারা আছে পৃথিবীতে তারা আল্লাহ্‌র? আর যারা আল্লাহ্‌কে ছেড়ে দিয়ে অংশীদের আরাধনা করে তারা অনুসরণ করে না। তারা তো শুধু অনুমানেরই অনুসরণ করে, আর তারা শুধু মিথ্যাই বলে।\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mcdxxxi{তিনিই সেইজন যিনি তোমাদের জন্য সৃষ্টি করেছেন রাত্রি যেন তোমরা তাতে বিশ্রাম করতে পারো, আর দেখবার জন্য দিন। নিঃসন্দেহ এ-সবে রয়েছে সঠিক নিদর্শনসমূহ সেই লোকদের জন্য যারা শোনে।\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mcdxxxii{তারা বলে -- ''আল্লাহ্ একটি পুত্র গ্রহণ করেছেন’’। তাঁরই মহিমা হোক! তিনি স্বয়ং-সমৃদ্ধ। মহাকাশমন্ডলীতে যা-কিছু আছে ও যা-কিছু আছে পৃথিবীতে সে-সবই তাঁর। এ বিষয়ে কোনো সনদ তোমাদের নিকট নেই। তোমরা কি আল্লাহ্ সন্বন্ধে বলো যা তোমরা জানো না?\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mcdxxxiii{বলো -- ''নিঃসন্দেহ যারা আল্লাহ্‌র বিরুদ্ধে মিথ্যা উদ্ভাবন করে তারা সফলকাম হবে না।’’\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mcdxxxiv{দুনিয়ার সুখ-সম্ভোগ, এরপর আমাদেরই কাছে তাদের প্রত্যাবর্তন, তখন আমরা তাদের আস্বাদন করাবো কঠোর শাস্তি, যেহেতু তারা অবিশ্বাস পোষণ করেছিল।\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@mcdxxxv{আর তাদের কাছে নূহ-এর কাহিনী বর্ণনা করো। স্মরণ করো! তিনি তাঁর লোকদের বলেছিলেন -- ''হে আমার সম্প্রদায়! যদি আমার বসবাস এবং আল্লাহ্‌র বাণীদ্বারা আমার উপদেশদান তোমাদের উপরে গুরুভার হয়, তাহলে আল্লাহ্‌র উপরেই আমি নির্ভর করছি, সুতরাং তোমাদের কাজের ধারা ও তোমাদের অংশীদের গুটিয়ে নাও, তারপর তোমাদের কাজের ধারায় যেন তোমাদের কোনো সংশয় না থাকে, তখন আমার দিকে তা খাটাও, এবং আমাকে বিরাম দিয় না।\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@mcdxxxvi{''কিন্তু যদি তোমরা ফিরে যাও তবে আমি তোমাদের কাছ থেকে কোনো পারিশ্রমিক চাইনি। আমার পারিশ্রমিক কেবল আল্লাহ্‌র কাছেই রয়েছে, আর আমাকে আদেশ করা হয়েছে যেন আমি মুসলিমদের অন্তর্ভুক্ত হই।’’\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@mcdxxxvii{কিন্তু তারা তাঁকে প্রত্যাখ্যান করল, সেজন্যে আমরা তাঁকে ও তাঁর সঙ্গে যারা ছিল তাদের উদ্ধার করেছিলাম জাহাজে, আর আমরা তাদের প্রতিনিধি করেছিলাম, আর ডুবিয়ে দিয়েছিলাম তাদের যারা আমাদের নির্দেশাবলী প্রত্যাখ্যান করেছিল। অতএব চেয়ে দেখো! কেমন হয়েছিল সতর্কীকৃতদের পরিণাম।\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@mcdxxxviii{অতঃপর তাঁর পরে আমরা রসূলদের দাঁড় করিয়েছিলাম তাঁদের সম্প্রদায়ের কাছে, তাঁরা তাই তাদের কাছে এসেছিলেন স্পষ্ট প্রমাণাবলী নিয়ে, কিন্তু তারা তাতে বিশ্বাস করার মতো ছিল না যা তারা ইতিপূর্বে প্রত্যাখ্যান করেছে। এইভাবে আমরা সীমা- লঙ্ঘনকারীদের হৃদয়ের উপরে মোহর মেরে দিই।\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@mcdxxxix{অনন্তর তাঁদের পরে আমরা পাঠিয়েছিলাম মূসা ও হারূনকে ফিরআউন ও তার পরিষদবর্গের কাছে আমাদের নিদর্শনসমূহ সঙ্গে দিয়ে, কিন্তু তারা অহংকার করেছিল আর তারা ছিল একটি অপরাধী সম্প্রদায়।\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@mcdxl{তারপর তাদের কাছে যখন আমাদের তরফ থেকে সত্য এল তারা তখন বললে -- ''এ তো নিশ্চয়ই পরিস্কার জাদু।’’\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@mcdxli{মূসা বললেন, ''কি তোমরা বলছ সত্য সন্বন্ধে যখন এ তোমাদের কাছে এল? এ কি জাদু? আর জাদুকররা সফলকাম হয় না।’’\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@mcdxlii{তারা বলল -- ''তুমি কি আমাদের কাছে এসেছ আমাদের বিচ্যুত করতে তা থেকে যার উপরে আমাদের পিতৃপুরুষদের পেয়েছি, আর যেন তোমাদের দুজনেরই প্রতিপত্তি হয় এ দেশে? সুতরাং তোমাদের দুজনের প্রতি আমরা তো বিশ্বাসী হচ্ছি না।’’\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@mcdxliii{আর ফিরআউন বললে -- ''প্রত্যেক ওস্তাদ জাদুকরকে আমার কাছে নিয়ে এস।’’\qt@no{(79)}}
\qt@newcmd\qurantrans@bn@mcdxliv{সুতরাং যখন জাদুকররা এল তখন মূসা তাদের বললেন -- ''তোমাদের যা ফেলবার আছে ফেল।’’\qt@no{(80)}}
\qt@newcmd\qurantrans@bn@mcdxlv{যখন তারা ফেলল, মূসা বললেন -- ''তোমরা যা নিয়ে এসেছ তা ভেলকিবাজী। নিঃসন্দেহ আল্লাহ্ একে বাতিল করে দেবেন ।’’ আল্লাহ্ নিশ্চয়ই হুজ্জতকারীদের কাজে ভাল করেন না।\qt@no{(81)}}
\qt@newcmd\qurantrans@bn@mcdxlvi{আল্লাহ্ তাঁর বাণী অনুযায়ী সত্যকে সুপ্রতিষ্ঠিত করেন যদিও অপরাধীরা অসন্তষ্ট হয়।\qt@no{(82)}}
\qt@newcmd\qurantrans@bn@mcdxlvii{কিন্তু তাঁর সম্প্রদায়ের সন্তানসন্ততি ব্যতীত আর কেউ মূসার প্রতি বিশ্বাস করে নি ফিরআউন ও তাদের পরিষদবর্গের ভয়ে পাছে তারা তাদের নির্যাতন করে। আর ফিরআউন দেশের মধ্যে অবশ্যই ছিল মহাপ্রতাপশালী, আর সে নিশ্চয়ই ছিল ন্যায়লঙ্ঘন-কারীদের অন্তর্ভুক্ত।\qt@no{(83)}}
\qt@newcmd\qurantrans@bn@mcdxlviii{আর মূসা বললেন -- ''হে আমার সম্প্রদায়! তোমরা যদি আল্লাহ্‌র প্রতি বিশ্বাস করে থাক তবে তাঁর উপরেই তোমরা নির্ভর কর যদি তোমরা মুসলিম হও।’’\qt@no{(84)}}
\qt@newcmd\qurantrans@bn@mcdxlix{সুতরাং তারা বললে -- ''আল্লাহ্‌র উপরেই আমরা নির্ভর করছি। আমাদের প্রভু! অত্যাচারিগোষ্ঠীর উৎপীড়নের পাত্র আমাদের বানিও না,\qt@no{(85)}}
\qt@newcmd\qurantrans@bn@mcdl{''আর তোমার করুণার দ্বারা আমাদের উদ্ধার কর অবিশ্বাসিগোষ্ঠী থেকে।’’\qt@no{(86)}}
\qt@newcmd\qurantrans@bn@mcdli{আর আমরা মূসা ও তাঁর ভাইয়ের প্রতি প্রত্যাদেশ দিলাম এই বলে -- ''তোমাদের লোকদের জন্য মিশরে বাড়িঘর স্থাপন করো, আর তোমাদের ঘরগুলোকে উপাসনার স্থান বানাও আর নামায কায়েম করো। আর বিশ্বাসীদের সুসংবাদ দাও।’’\qt@no{(87)}}
\qt@newcmd\qurantrans@bn@mcdlii{আর মূসা বললেন -- ''আমাদের প্রভু! নিশ্চয় তুমি ফিরআউন ও তার পরিষদবর্গকে এই দুনিয়ার জীবনে শোভা-সৌন্দর্য ও ধন- দৌলত প্রদান করেছ, যা দিয়ে, আমাদের প্রভু! তারা তোমার পথ থেকে পথভ্রষ্ট করে। আমাদের প্রভু! বিনষ্ট করে দাও তাদের ধনসম্পত্তি, আর কাঠিন্য এনে দাও তাদের হৃদয়ের উপরে, তারা তো বিশ্বাস করে না যে পর্যন্ত না তারা মর্মন্তুদ শাস্তি প্রত্যক্ষ করে।’’\qt@no{(88)}}
\qt@newcmd\qurantrans@bn@mcdliii{তিনি বললেন -- ''তোমাদের দুজনের দোয়া ইতিমধ্যেই মঞ্জুর হল, কাজেই তোমারা উভয়ে অটল থেকো, আর তাদের পথ অনুসরণ করো না যারা জানে না।’’\qt@no{(89)}}
\qt@newcmd\qurantrans@bn@mcdliv{আর ইসরাইলের বংশধরদের আমরা সমূদ্র পার করালাম, আর ফিরআউন ও তার সৈন্যদল তাদের ধাওয়া করল নির্যাতন ও উৎপীড়নের জন্য! শেষে যখন ডুবে যাওয়া তাকে পাকড়াল সে বললে -- ''আমি ঈমান আনছি যে ইসরাইলের বংশধরেরা যাঁর প্রতি বিশ্বাস করে তিনি ছাড়া অন্য কোনো উপাস্য নেই, আর আমি হচ্ছি মুসলিমদের অন্তর্ভুক্ত।’’\qt@no{(90)}}
\qt@newcmd\qurantrans@bn@mcdlv{''আহা, এখন! আর একটু আগেই তুমি তো অবাধ্যতা করছিলে আর তুমি ছিলে অশান্তি সৃষ্টিকারীদের মধ্যেকার।’’\qt@no{(91)}}
\qt@newcmd\qurantrans@bn@mcdlvi{তবে আজকের দিনে আমরা উদ্ধার করব তোমার দেহ, যেন তুমি তোমার পরবর্তীদের জন্য নিদর্শন হয়ে থাক। কিন্তু মানুষের মধ্যের অনেকেই আমাদের নিদর্শন সন্বন্ধে অবশ্যই বেখেয়াল।\qt@no{(92)}}
\qt@newcmd\qurantrans@bn@mcdlvii{আর ইসরাইলের বংশধরদের আমরা অবশ্যই উত্তম আবাসভূমিতে বসবাস করালাম, আর তাদের আমরা উত্তম বিষয়বস্তু দিয়ে জীবিকাদান করলাম, আর তারা বিভেদ সৃষ্টি করে নি যে পর্যন্ত না তাদের কাছে জ্ঞান এল। নিঃসন্দেহ তোমার প্রভু কিয়ামতের দিনে তাদের মধ্যে বিচার করবেন সে-সন্বন্ধে যাতে তারা মতভেদ করেছিল।\qt@no{(93)}}
\qt@newcmd\qurantrans@bn@mcdlviii{কিন্তু যদি তুমি সন্দেহের মধ্যে থাক যা তোমার কাছে আমরা অবতারণ করেছি সে-সন্বন্ধে তবে তাদের জিজ্ঞাসা করো যারা তোমার আগে গ্রন্থ পাঠ করেছে। তোমার কাছে আলবৎ সত্য এসেছে তোমার প্রভুর কাছ থেকে, সুতরাং তুমি সংশয়ীদের মধ্যেকার হয়ো না,\qt@no{(94)}}
\qt@newcmd\qurantrans@bn@mcdlix{আর তুমি তাদের অন্তর্ভুক্ত হয়ো না যারা আল্লাহ্‌র বাণী প্রত্যাখ্যান করে, পাছে তুমি ক্ষতিগ্রস্তদের মধ্যেকার হয়ে যাবে।\qt@no{(95)}}
\qt@newcmd\qurantrans@bn@mcdlx{নিঃসন্দেহ যাদের বিরুদ্ধে তোমার প্রভুর বাক্য সাব্যস্ত হয়ে গেছে তারা বিশ্বাস করবে না, --\qt@no{(96)}}
\qt@newcmd\qurantrans@bn@mcdlxi{যদিও তাদের কাছে প্রতিটি নিদর্শন এসে যায়, যে পর্যন্ত না তারা মর্মন্তুদ শাস্তি প্রত্যক্ষ করে।\qt@no{(97)}}
\qt@newcmd\qurantrans@bn@mcdlxii{সুতরাং কেন এমন একটি জনপদবাসী নেই যারা বিশ্বাস করেছিল ও তাদের সেই বিশ্বাস তাদের উপকার করেছিল ইউনুসের লোকদের ব্যতীত? যখন তারা বিশ্বাস করল তখন আমরা তাদের থেকে সরিয়ে নিয়েছিলাম পার্থিব জীবনের হীনতাজনক শাস্তি, এবং তাদের জীবনোপভোগ করতে দিয়েছিলাম কিছু কালের জন্য।\qt@no{(98)}}
\qt@newcmd\qurantrans@bn@mcdlxiii{আর তোমার প্রভু যদি ইচ্ছা করতেন তবে যারা পৃথিবীতে আছে তাদের সবাই একসঙ্গে বিশ্বাস করত। তুমি কি তবে লোকজনের উপরে জবরদস্তি করবে যে পর্যন্ত না তারা মুমিন হয়?\qt@no{(99)}}
\qt@newcmd\qurantrans@bn@mcdlxiv{আর কোনো প্রাণীর পক্ষে বিশ্বাস করা সম্ভবপর নয় আল্লাহ্‌র অনুমতি ব্যতীত। আর তিনি কলুষতা নিক্ষেপ করেন তাদের উপরে যারা বুঝে না।\qt@no{(100)}}
\qt@newcmd\qurantrans@bn@mcdlxv{বলো -- ''তাকিয়ে দেখ যা-কিছু আছে মহাকাশমন্ডলীতে ও পৃথিবীতে।’’ আর নিদর্শনসমূহ ও সতর্ককারীরা কোনো কাজে আসে না সেই সম্প্রদায়ের জন্য যারা বিশ্বাস করে না।\qt@no{(101)}}
\qt@newcmd\qurantrans@bn@mcdlxvi{তবে তারা কিসের প্রতীক্ষা করে ওদের দিনের অনুরূপ ব্যতীত যারা তাদের আগে গত হয়ে গেছে? বলোঃ ''তবে তোমরা প্রতীক্ষা কর, নিঃসন্দেহ আমিও তোমাদের সঙ্গে প্রতীক্ষমাণদের মধ্যে রয়েছি।’’\qt@no{(102)}}
\qt@newcmd\qurantrans@bn@mcdlxvii{তারপর আমরা রসূলগণকে উদ্ধার করি আর যারা বিশ্বাস করেছেন তাদেরও, এইভাবেই, -- বিশ্বাসীদের উদ্ধার করা আমাদের দায়িত্ব।\qt@no{(103)}}
\qt@newcmd\qurantrans@bn@mcdlxviii{বলো -- ''ওহে মানবগোষ্ঠি! তোমরা যদি আমার ধর্ম সন্বন্ধে সন্দেহের মধ্যে থাক তবে আমি তাদের উপাসনা করি না আল্লাহ্ ব্যতীত যাদের তোমরা উপাসনা কর, আমি কিন্তু আল্লাহ্‌র উপাসনা করি যিনি তোমাদের মৃত্যু ঘটাবেন। আর আমি আদিষ্ট হয়েছি যে আমি মুমিনদের অন্তর্ভুক্ত হব।’’\qt@no{(104)}}
\qt@newcmd\qurantrans@bn@mcdlxix{আর তোমার মুখ ধর্মের প্রতি একনিষ্ঠভাবে প্রতিষ্ঠিত রাখো, আর কখনো মুশরিকদের অন্তর্ভুক্ত হয়ো না।\qt@no{(105)}}
\qt@newcmd\qurantrans@bn@mcdlxx{আর আল্লাহ্‌কে ছেড়ে দিয়ে অন্যকে ডেকো না যে তোমার উপকারও করে না ও অপকারও করে না, কেননা তুমি যদি তা করো তাহলে তুমি তো সে-ক্ষেত্রে অন্যায়কারীদের মধ্যেকার হবে।\qt@no{(106)}}
\qt@newcmd\qurantrans@bn@mcdlxxi{আর আল্লাহ্ যদি কোনো আঘাত দিয়ে আমাকে পীড়ন করেন তাহলে তিনি ছাড়া এ মোচনকারী আর কেউ নেই, আর তিনি যদি তোমাকে চান ভাল করতে তাহলে তাঁর প্রাচুর্য রদ হবার নয়। তিনি তা আনয়ন করেন তাঁর দাসদের মধ্যের যার প্রতি ইচ্ছা করেন। আর তিনিই তো পরিত্রাণকারী, অফুরন্ত ফলদাতা।\qt@no{(107)}}
\qt@newcmd\qurantrans@bn@mcdlxxii{বলো -- ''ওহে মানবগোষ্ঠি! নিশ্চয়ই তোমাদের প্রভুর কাছ থেকে তোমাদের কাছে সত্য এসেছে, সেজন্যে যে কেউ সৎপথ অবলন্বন করে সে নিঃসন্দেহ তার নিজের জন্যেই সৎপথে বিচরণ করে, আর যে ভ্রান্তপথ ধরে সে নিঃসন্দেহ তার নিজের বিরুদ্ধেই ভ্রান্তপথে চলে। আর আমি তোমাদের উপরে তো কার্যনির্বাহক নই।’’\qt@no{(108)}}
\qt@newcmd\qurantrans@bn@mcdlxxiii{আর তোমার কাছে যা প্রত্যাদিষ্ট হয়েছে তারই অনুসরণ করো, তবে অধ্যবসায় চালিয়ে যাও যে পর্যন্ত না আল্লাহ্ বিধান দেন, আর তিনিই সর্বোত্তম বিধানকর্তা।\qt@no{(109)}}
\qt@newcmd\qurantrans@bn@mcdlxxiv{\basmalahbn আলিফ, লাম, রা। এ গ্রন্থ যার আয়াতসমূহকে জ্ঞান-সমৃদ্ধ করা হয়েছে, তারপর বিশদ ব্যাখ্যা দেয়া হয়েছে পরমজ্ঞানী পূর্ণ- ওয়াকিফহালের তরফ থেকে!\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mcdlxxv{যেন তোমরা আল্লাহ্ ছাড়া অন্যের উপাসনা করবে না। ''আমি অবশ্যই তোমাদের কাছে তাঁর পক্ষ থেকে সতর্ককারী এবং সুসংবাদদাতা --\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mcdlxxvi{''আর যেন তোমাদের প্রভুর কাছে পরিত্রাণ খোঁজো, তারপর তাঁর দিকে ফেরো, -- তিনি তোমাদের সুন্দর জীবনোপকরণ উপভোগ করতে দেবেন এক নির্দিষ্ট কালের জন্য, আর তিনি প্রত্যেক প্রাচুর্যের অধিকারীকে তাঁর প্রাচুর্য প্রদান করেন। আর যদি তোমরা ফিরে যাও তবে নিঃসন্দেহ আমি তোমাদের জন্য আশংকা করি এক মহাদিনের শাস্তির।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mcdlxxvii{''আল্লাহ্‌রই কাছে তোমাদের প্রত্যাবর্তন, আর তিনি সব-কিছুর উপরে সর্বশক্তিমান।’’\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mcdlxxviii{সাবধান! নিঃসন্দেহ তারা কি নিজেদের বুক ভাঁজ করেছে তাঁর কাছ থেকে লুকিয়ে রাখার জন্যে? সাবধান! তারা যখন তাদের পোশাকের দ্বারা নিজেদের আবৃত করে, তিনি জানেন যা তারা লুকিয়ে রাখে ও যা তারা প্রকাশ করে। নিঃসন্দেহ বুকের ভেতরে যা আছে সে-সন্বন্ধে তিনি সর্বজ্ঞাতা।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mcdlxxix{আর পৃথিবীতে এমন কোন প্রাণী নেই যার জীবিকার ভার আল্লাহ্‌র উপরে নয়, আর তিনিই জানেন তার বাসস্থান ও তার বিশ্রামস্থল। সবই আছে এক সুস্পষ্ট গ্রন্থে।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mcdlxxx{আর তিনিই সেইজন যিনি মহাকাশমন্ডলী ও পৃথিবী সৃষ্টি করেছেন ছয় দিনে, আর তাঁর আরশ রয়েছে পানির উপরে, যেন তিনি তোমাদের যাচাই করতে পারেন যে তোমাদের মধ্যে কে আচরণে শ্রেষ্ঠ। আর যদি তোমাকে বলতে হয় -- ''নিঃসন্দেহ মৃত্যুর পরে তোমাদের পুনরুত্থিত করা হবে’’, যারা অবিশ্বাস করে তারা নিশ্চয় বলবে -- ''এ তো স্পষ্টতঃ জাদু বই নয়।’’\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mcdlxxxi{আর যদি তাদের থেকে নির্দিষ্ট কাল পর্যন্ত আমরা শাস্তি স্থগিত রাখি তবে তারা নিশ্চয়ই বলবে -- ''কিসে একে বাধা দিচ্ছে?’’ এটি কি নয় যে যেদিন তাদের নিকটে এ আসবে সেদিন তাদের থেকে এটি প্রতিহত হবে না, আর যা নিয়ে তারা ঠাট্টা-বিদ্রূপ করছিল তাই তাদের ঘেরাও করবে?\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mcdlxxxii{আর যদি আমরা মানূষকে আমাদের থেকে করুণার আস্বাদ করাই ও পরে তার থেকে তা নিয়ে নিই, তাহলে সে নিশ্চয়ই হবে হতাশ্বাস, অকৃতজ্ঞ।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mcdlxxxiii{আর যদি আমরা তাকে অনুগ্রহের আস্বাদ করাই দুঃখ-কষ্ট তাকে স্পর্শ করার পরে সে তখন বলেই থাকে -- ''আমার থেকে বিপদ-আপদ কেটে গেছে।’’ নিঃসন্দেহ সে উল্লসিত, অহংকারী, --\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mcdlxxxiv{তারা ছাড়া যারা ধৈর্যধারণ করে ও সৎকর্ম করে, এরাই -- এদের জন্য রয়েছে পরিত্রাণ ও মহাপুরস্কার।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mcdlxxxv{তুমি কি তবে পরিত্যাগকারী হবে তোমার কাছে যা প্রত্যাদিষ্ট হয়েছে তার কিছু অংশ, আর তোমার বক্ষ এর দ্বারা সংকুচিত করবে যেহেতু তারা বলে -- ''তার কাছে কেন কোনো ধনভান্ডার পাঠানো হয় না অথবা তার সঙ্গে কোনো ফিরিশ্‌তা আসে না?’’ নিঃসন্দেহ তুমি তো একজন সতর্ককারী। আর আল্লাহ্ সব-কিছুর উপরে কর্ণধার।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mcdlxxxvi{অথবা তারা কি বলে -- ''সে এটি বানিয়েছে?’’ বলো -- ''তাহলে এর মত দশটি বানানো সূরা নিয়ে এস, আর আল্লাহ্‌কে ছেড়ে দিয়ে যাকে পার ডাকো, যদি তোমরা সত্যবাদী হও।’’\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mcdlxxxvii{আর যদি তারা তোমাদের প্রতি সাড়া না দেয় তবে জেনে রেখো -- এ অবশ্যই অবতীর্ণ হয়েছে আল্লাহ্‌র জ্ঞানভান্ডার থেকে, আর তিনি ছাড়া অন্য উপাস্য নেই। তোমরা কি তবে আ‌ত্মসমর্পণকারী হবে না?\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mcdlxxxviii{যে কেউ পার্থিব জীবন ও এর শোভা-সৌন্দর্য কামনা করে তাদের ক্রিয়াকর্মের জন্য এখানেই আমরা তাদের পুরোপুরি প্রতিফল প্রদান করি, আর এ ব্যাপারে তারা ক্ষতিসাধিত হবে না।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mcdlxxxix{এরাই তারা যাদের জন্য পরকালে আগুন ছাড়া আর কিছুই নেই, আর তারা যা করেছে তা সেখানে বৃথা যাবে, আর তারা যা করে যাচ্ছিল সে-সবই নিরর্থক।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mcdxc{তবে কি যে রয়েছে তার প্রভুর কাছে থেকে স্পষ্ট-প্রমাণের উপরে প্রতিষ্ঠিত এবং তাঁর কাছ থেকে একজন সাক্ষী তা পাঠ করেন, আর এর আগে মুসার গ্রন্থ পথনির্দেশক ও করুণাস্বরূপ? এরা এতে বিশ্বাস করে। আর দলগুলোর মধ্যের যে এতে অবিশ্বাস পোষণ করে তার প্রতি‌শ্রুত স্থান তবে আগুন, অতএব তুমি এ-সন্বন্ধে সন্দেহে থেকো না। নিঃসন্দেহ এটি তোমার প্রভুর কাছ থে কে ধ্রুবসত্য, কিন্তু বেশিরভাগ লোকেই বিশ্বাস করে না।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mcdxci{আর কে তার চাইতে বেশী অন্যায়কারী যে আল্লাহ্ সন্বন্ধে মিথ্যা রচনা করে? এদের আনা হবে তাদের প্রভুর সামনে, আর সাক্ষীগণ বলবে -- ''এরাই তারা যারা তাদের প্রভুর বিরুদ্ধে মিথ্যা আরোপ করেছিল।’’ এমন কি নয় যে আল্লাহ্‌র অসন্তষ্টি যালিমদের উপরে --\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mcdxcii{যারা আল্লাহ্‌র পথ থেকে ফিরিয়ে রাখে এবং একে করতে চায় কুটিল? আর এরা নিজেরাই পরকাল সন্বন্ধে অবিশ্বাসী।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mcdxciii{এরা পৃথিবীতে প্রতিহত করতে পারত না, আর তাদের জন্য আল্লাহ্‌কে ছেড়ে দিয়ে কোনো অভিভাবক নেই। তাদের জন্য শাস্তি দ্বিগুণ করা হবে। তারা শোনা সহ্য করতে পারত না, আর তারা দেখতেও পারত না।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mcdxciv{এরাই তারা যারা তাদের অন্তরা‌ত্মার ক্ষতিসাধন করেছে, আর যা তারা উদ্ভাবন করেছিল তা তাদের থেকে বিদায় নিয়েছে।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mcdxcv{সন্দেহ নেই যে পরকালে তারা নিজেরা অবশ্যই হবে সব চাইতে ক্ষতিগ্রস্ত।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mcdxcvi{নিঃসন্দেহ যারা বিশ্বাস করে ও সৎকর্ম করে, এবং বিনয়াবনত হয় তাদের প্রভুর কাছে, -- তারাই বেহেশতের বাসিন্দা, এতে তারা থাকবে চিরকাল।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mcdxcvii{দল দুটির উপমা হচ্ছে অন্ধ ও বধিরের এবং চক্ষুষ্মান ও শ্রবণশক্তিমানের মতো, -- উভয় কি তুলনায় সমান-সমান? তবুও কি তোমরা মনোনিবেশ করবে না?\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mcdxcviii{আর নিশ্চয়ই আমরা নূহকে পাঠিয়েছিলাম তাঁর সম্প্রদায়ের কাছে, ''নিঃসন্দেহ আমি তোমাদের জন্য একজন সতর্ক কারী, --\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mcdxcix{''যেন তোমরা আল্লাহ্ ছাড়া কারো উপাসনা করবে না। নিঃসন্দেহ আমি আশংকা করি তোমাদের জন্য মর্মন্তুদ দিনের শাস্তি।’’\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@md{কিন্তু তাঁর সম্প্রদায়ের মধ্যের যারা অবিশ্বাস করেছিল তাদের প্রধানরা বললে -- ''আমরা তো তোমাকে আমাদের মতো একজন মানুষ বই দেখছি না, আর আমরা তোমাকে দেখছি না যে তোমাকে তারা ছাড়া এমন অন্য কেউ অনুসরণ করছে যারা হচ্ছে প্রথম দৃষ্টিতেই আমাদের মধ্যে অধম, আর আমরা তোমাদের মধ্যে আমাদের চাইতে কোনো গুণপনাও দেখছি না, বরং আমরা তোমাদের মনে করি মিথ্যাবাদী।’’\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mdi{তিনি বললেন -- ''হে আমার সম্প্রদায়! তোমরা কি ভেবে দেখেছ -- আমি যদি আমার প্রভুর কাছ থেকে স্পষ্ট-প্রমাণে প্রতিষ্ঠিত থাকি এবং তিনি যদি আমাকে তাঁর তরফ থেকে অনুগ্রহ প্রদান করে থাকেন, অথচ তোমাদের কাছে এটি ঝাপসা হয়ে গেছে, আমরা কি তবে এটিতে তোমাদের বাধ্য করতে পারি যখন তোমরা এর প্রতি বিরূপ?\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mdii{''আর হে আমার সম্প্রদায়! এর বিনিময়ে আমি তোমাদের কাছে ধনদৌলত চাই না। আমার শ্রমফল কেবল আল্লাহ্‌র কাছেই রয়েছে, আর যারা বিশ্বাস করেছে তাদের আমি তাড়িয়েও দেবার নই। নিঃসন্দেহ তাদের প্রভুর কাছে তারা মুলাকাত করতে যাচ্ছে, কিন্তু আমি তোমাদের দেখছি একটি অজ্ঞানতাকুশল সম্প্রদায়।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mdiii{''আর হে আমার সম্প্রদায়! কে আমাকে সাহায্য করবে আল্লাহ্‌র বিরুদ্ধে যদি আমি তাদের তাড়িয়ে দিই? তোমরা কি তবে ভেবে দেখবে না?\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mdiv{''আর আমি তোমাদের বলি না -- আমার কাছে আল্লাহ্‌র ধনভান্ডার রয়েছে, আর আমি অদৃশ্য সন্বন্ধেও জানি না, আর আমি বলি না যে আমি তো একজন ফিরিশ্‌তা, আর তোমাদের চোখে যাদের নগণ্য ভাব তাদের সন্বন্ধে আমি বলি না যে আল্লাহ্ কখনো তাদের করুণাভান্ডার দেবেন না। আল্লাহ্ ভাল জানেন যা-কিছু আছে তাদের অন্তরে, -- তাহলে আমি আলবৎ অন্যায়কারীদের মধ্যেকার হতাম।’’\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mdv{তারা বললে -- ''হে নূহ্‌! তুমি অবশ্যই আমাদের সঙ্গে বিতর্ক করছ আর আমাদের সঙ্গে তর্ক বাড়িয়ে তুলেছ, সুতরাং আমাদের কাছে নিয়ে এস যার ভয় আমাদের দেখাচ্ছ, যদি তুমি সত্যবাদীদের মধ্যেকার হও।’’\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mdvi{তিনি বললেন -- ''শুধু আল্লাহ্‌ই তোমাদের উপরে তা নিয়ে আসবেন যদি তিনি ইচ্ছা করেন, আর তোমরা এড়িয়ে যাবার নও।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mdvii{''আর আমার উপদেশ তোমাদের উপকার করবে না যদিও আমি চাই তোমাদের উপদেশ দিতে, যদি আল্লাহ্ চান যে তিনি তোমাদের বিভ্রান্ত করবেন। তিনিই তোমাদের প্রভু, আর তাঁর কাছেই তোমাদের ফিরিয়ে আনা হবে।’’\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mdviii{অথবা তারাও কি বলে -- ''তিনি এটি বানিয়েছেন?’’ বলো -- ''যদি আমি এটি বানিয়ে থাকি তবে আমার উপরেই আমার অপরাধ, আর তোমরা যে-সব অপরাধ করছ সে-সব থেকে আমি নিষ্কৃত।’’\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mdix{আর নূহের কাছে প্রত্যাদেশ দেয়া হল -- ''নিঃসন্দেহ তোমার সম্প্রদায়ের মধ্যে থেকে কেউ কখনও বিশ্বাস করবে না সে ব্যতীত যে ইতিমধ্যে বিশ্বাস করেছে, সুতরাং তারা যা করে চলেছে তার জন্য দুঃখ কর না।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mdx{''আর আমাদের চোখের সামনে ও আমাদের প্রত্যাদেশ মতে জাহাজ তৈরি কর, আর যারা অত্যাচার করেছে তাদের সন্বন্ধে আমার কাছে আবেদন কর না, নিঃসন্দেহ তারা নিমজ্জিত হবে।”\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mdxi{আর তিনি জাহাজ তৈরি করতে লাগলেন, আর যখনই তাঁর সম্প্রদায়ের প্রধানেরা তাঁর পাশ দিয়ে যেতো তারা তাঁর প্রতি উপহাস করত। তিনি বলেছিলেন -- ''যদি তোমরা আমাদের সন্বন্ধে হাসাহাসি কর তবে আমরাও তোমাদের সন্বন্ধে তেমনি হাসব যেমন তোমরা হাসছ।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mdxii{''সুতরাং অচিরেই তোমরা জানতে পারবে কার উপরে শাস্তি আসছে যা তাকে লাঞ্ছিত করে, আর কার উপরে নামছে স্থায়ী শাস্তি।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mdxiii{যে পর্যন্ত না আমাদের আদেশ এল এবং মাটঘাট প্লাবিত হল, আমরা বললাম -- ''এতে বোঝাই কর প্রত্যেক জাতের দুটি -- এক জোড়া, এবং তোমার পরিবার -- তাকে ছাড়া যার বিরুদ্ধে সিদ্ধান্ত বর্তিত হয়েছে, আর যারা বিশ্বাস করেছে তাদের।’’ আর যারা তাঁর সঙ্গে বিশ্বাস করেছিল তারা তো স্বল্পসংখ্যক।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mdxiv{আর তিনি বললেন -- ''এতে আরোহণ কর, আল্লাহ্‌র নামে হোক এর যাত্রা ও এর পৌঁছা, নিঃসন্দেহ আমার প্রভু তো পরিত্রাণকারী, অফুরন্ত ফলদাতা।’’\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mdxv{আর তাদের নিয়ে এটি বয়ে চললো পাহাড়ের মত ঢেউয়ের মধ্য দিয়ে, আর নূহ তাঁর পুত্রকে ডেকে বললেন আর সে ডাঙায় রয়েছিল, -- ''হে আমার পুত্র! আমাদের সঙ্গে চড়, আর অবিশ্বাসীদের সঙ্গী হয়ো না।’’\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mdxvi{সে বললে -- ''আমি এখনি কোনো পাহাড়ে আশ্রয় নেব, তা আমাকে প্লাবন থেকে রক্ষা করবে।’’ তিনি বললেন -- ''আজকের দিনে আল্লাহ্‌র হুকুম থেকে রক্ষা করার কেউ নেই, শুধু সে যাকে তিনি দয়া করবেন।’’ আর তাদের উভয়ের মধ্যে ঢেউ এসে পড়ল, ফলে সে হয়ে গেল নিমজ্জিতদের অন্তর্ভুক্ত।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mdxvii{এরপর বলা হল -- ''হে পৃথিবী। তোমার জল শোষণ করে নাও, আর হে আকাশ! ক্ষান্ত হও।’’ তখন জল শুকিয়ে এটি জুদী পর্বতের উপরে থামল, আর বলা হল -- ''দূর হোক অন্যায়কারিগোষ্ঠী!’’\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mdxviii{আর নূহ্ তাঁর প্রভুকে ডাকলেন ও বললেন -- ''আমার প্রভু! আমার পুত্র আলবৎ আমার পরিবারভুক্ত আর তোমার ওয়াদা নিঃসন্দেহ সত্য, আর তুমি বিচারকদের মধ্যে শ্রেষ্ঠ বিচারক।’’\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mdxix{তিনি বললেন -- ''হে নূহ! নিঃসন্দেহ সে তোমার পরিবারভুক্ত নয়। নিঃসন্দেহ তার কাজকর্ম সৎকর্মের বর্হিভূত, কাজেই আমার কাছে সওয়াল কর না যে-সন্বন্ধে তোমার কোনো জ্ঞান নেই। আমি অবশ্যই তোমাকে উপদেশ দিচ্ছি -- পাছে তুমি অজ্ঞদের অন্তর্ভুক্ত হয়ে পড়।’’\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mdxx{তিনি বললেন -- ''আমার প্রভু! আমি অবশ্যই তোমার কাছে আশ্রয় চাইছি পাছে যে ব্যাপারে আমার কোনো জ্ঞান নেই সে- সন্বন্ধে তোমার কাছে প্রার্থনা করে ফেলি। আর তুমি যদি আমাকে রক্ষা না কর ও আমার প্রতি করুণা না দর্শাও তবে আমি ক্ষতিগ্রস্তদের অন্তর্ভুক্ত হয়ে যাব।’’\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mdxxi{বলা হল -- ''হে নূহ! অবতরণ কর আমাদের থেকে শান্তির সাথে, আর তোমার উপরে ও তোমার সাথে যারা রয়েছে তাদের সম্প্রদায়ের উপরে আশীর্বাদ নিয়ে। আর এমন জাতিরাও হবে যাদের আমরা অচিরেই জীবনোপকরণ দেব, তারপর আমাদের থেকে মর্মন্তুদ শাস্তি তাদের স্পর্শ করবে।’’\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mdxxii{এসব হচ্ছে অদৃশ্য সন্বন্ধে সংবাদ যা আমরা তোমার কাছে প্রত্যাদেশ করছি। তুমি এর আগে এ-সব জানতে না -- তুমিও না, তোমার সম্প্রদায়ও না। অতএব অধ্যবসায় অবলন্বন কর। নিঃসন্দেহ শুভপরিণাম ধর্মভীরুদেরই জন্যে।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mdxxiii{আর 'আদ-এর কাছে তাদের ভাই হূদকে। তিনি বললেন -- ''হে আমার সম্প্রদায়! আল্লাহ্‌র উপাসনা কর, তোমাদের জন্য তিনি ছাড়া অন্য উপাস্য নেই। তোমরা তো শুধু মিথ্যা রচনাকারী।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mdxxiv{''হে আমার সম্প্রদায়! আমি এর জন্য তোমাদের কাছে কোনো প্রতিদান চাইছি না। আমার শ্রমফল কেবল তাঁর কাছে যিনি আমাকে সৃষ্টি করেছেন। তোমরা কি তবে বুঝবে না?\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mdxxv{''আর হে আমার সম্প্রদায়! তোমাদের প্রভুর কাছে ক্ষমা প্রার্থনা কর, তারপর তাঁর দিকে ফেরো, তিনি আকাশকে তোমাদের প্রতি পাঠাবেন বর্ষণোন্নুখ করে, আর তোমাদের শক্তির উপরে তোমাদের শক্তি বাড়িয়ে দেবেন, আর তোমরা ফিরে যেও না অপরাধী হয়ে।’’\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mdxxvi{তারা বললে -- ''হে হূদ! তুমি আমাদের কাছে কোনো স্পষ্ট প্রমাণ আন নি, আর তোমার কথায় আমরা আমাদের দেবতাদের পরিত্যাগ করতে যাচ্ছি না, আর তোমার প্রতি আমরা বিশ্বাসীও নই।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mdxxvii{''আমরা বলি নি এ ছাড়া অন্য কিছু যে আমাদের কোনো দেবতা তোমাতে ভর করেছেন খারাপ ভাবে।’’ তিনি বললেন -- ''নিঃসন্দেহ আমি আল্লাহ্‌কে সাক্ষী করি, আর তোমরাও সাক্ষী থেকো যে আমি আলবাৎ সংস্রবহীন তাদের সঙ্গে যাদের তোমরা শরিক কর --\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mdxxviii{''তাঁকে ছেড়ে দিয়ে, কাজেই তোমরা সবাই মিলে আমার বিরুদ্ধে ষড়যন্ত্র করে যাও এবং আমাকে অবকাশ দিয় না।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mdxxix{''আমি অবশ্যই নির্ভর করি আল্লাহ্‌র উপরে -- যিনি আমার প্রভু ও তোমাদেরও প্রভু। এমন কোনো প্রাণী নেই যার আলচুল তিনি ধরে না আছেন। নিঃসন্দেহ আমার প্রভু সহজ-সঠিক পথে অধিষ্ঠিত।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mdxxx{''কিন্তু তোমরা যদি ফিরে যাও তবে আমি নিশ্চয় তোমাদের কাছে পৌঁছে দিয়েছি যা দিয়ে আমাকে তোমাদের কাছে পাঠানো হয়েছিল। আর আমার প্রভু তোমাদের থেকে পৃথক কোনো সম্প্রদায়কে স্থলাভিষিক্ত করবেন, আর তোমরা তাঁর কোনো ক্ষতি করতে পারবে না। নিঃসন্দেহ আমার প্রভু সব-কিছুর উপরে তত্ত্বাবধায়ক।’’\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mdxxxi{আর যখন আমাদের নির্দেশ ঘনিয়ে এল তখন আমরা হূদকে ও তাঁর সঙ্গে যারা আস্থা রেখেছিল তাদের উদ্ধার করেছিলাম আমাদের অনুগ্রহের ফলে, আর আমরা তাদের উদ্ধার করেছিলাম কঠিন শাস্তি থেকে।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mdxxxii{আর এই ছিল 'আদ জাতি, তারা তাদের প্রভুর নির্দেশাবলী অস্বীকার করেছিল ও তাঁর রসূলগণকে অমান্য করেছিল, আর অনুসরণ করেছিল।\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mdxxxiii{আর এই দুনিয়াতে অভিশাপকে তাদের পিছু ধরান হয়েছিল, আর কিয়ামতের দিনেও। এটি কি নয় যে 'আদ জাতি তাদের প্রভুকে অস্বীকার করেছিল? এটি কি নয় -- “দূর হও 'আদ জাতি -- হূদের সম্প্রদায়!’’\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mdxxxiv{আর ছামুদ জাতির কাছে তাদের ভাই সালিহ্‌কে। তিনি বললেন -- ''হে আমার সম্প্রদায়! আল্লাহ্‌র উপাসনা কর, তোমাদের জন্য তিনি ব্যতীত অন্য উপাস্য নেই। তিনি তোমাদের গড়ে তুলেছেন মাটি থেকে আর এতেই তোমাদের বসবাস করিয়েছেন, অতএব তাঁর কাছেই পরিত্রাণ খোঁজো এবং তাঁর দিকেই ফেরো। নিঃসন্দেহ আমার প্রভু নিকটেই, জবাবদয়াক।’’\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mdxxxv{তারা বললে -- ''হে সালিহ্‌! তুমি তো আমাদের কাছে এর আগে ছিলে আশা-ভরসার পাত্র, তুমি কি আমাদের পিতৃপুরুষরা যাদের উপাসনা করত তাদের উপাসনা করতে আমাদের নিষেধ করছ? আর আমরা তো অবশ্যই সন্দেহের মধ্যে রয়েছি সে-সন্বন্ধে যার প্রতি তুমি আমাদের আহ্বান করছ -- বিভ্রান্তিকর!’’\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mdxxxvi{তিনি বললেন -- ''হে আমার সম্প্রদায়! তোমরা কি ভেবে দেখেছ -- আমি যদি আমার প্রভু থেকে পাওয়া স্পষ্ট-প্রমাণের উপরে প্রতিষ্ঠিত থাকি এবং তিনি যদি তাঁর কাছ থেকে আমাকে অনুগ্রহ দান করে থাকেন তবে কে আমাকে সাহায্য করবে আল্লাহ্‌র কবল থেকে যদি আমি তাঁর অবাধ্যতা করি? সুতরাং তোমরা তো ক্ষতি সাধন করা ছাড়া আমার আর কিছুই বাড়াবে না।’’\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mdxxxvii{''আর হে আমার সম্প্রদায়! এটি হচ্ছে আল্লাহ্‌র উষ্টী, -- তোমাদের জন্য একটি নিদর্শন, অতএব এটিকে ছেড়ে দাও আল্লাহ্‌র মাটিতে চরে খেতে, আর তাকে কোনো ক্ষতিতে ক্ষতি কর না, পাছে আসন্ন শাস্তি তোমাদের পাকড়াও করে।’’\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mdxxxviii{কিন্তু তারা তাকে হত্যা করলে, সেজন্য তিনি বললেন -- ''তোমরা তোমাদের বাড়িঘরে তিন দিন জীবন উপভোগ করে নাও, এ একটি প্রতি‌শ্রুতি যা মিথ্যা হওয়ার নয়।’’\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mdxxxix{তারপর যখন আমাদের নির্দেশ এল তখন আমরা সলিহকে ও তাঁর সঙ্গে যারা আস্থা রেখেছিল তাদের উদ্ধার করেছিলাম আমাদের অনুগ্রহের ফলে, আর সেই দিনের লাঞ্ছনা থেকে। নিঃসন্দেহর তোমার প্রভু -- তিনিই মহাবলীয়ান, মহাশক্তিশালী।\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mdxl{অতঃপর প্রচন্ড আওয়াজ পাকড়াও করল তাদের যারা অত্যাচার করেছিল, কাজেই তারা হয়ে গেল আপন বাড়িঘরে নিথরদেহী, --\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mdxli{যেন তারা কখনও সেখানে বসবাস করে নি। এটি কি নয় যে ছামুদ জাতি তাদের প্রভুকে অস্বীকার করেছিল? এটি কি নয় -- ''দূর হও ছামুদ জাতি!’’?\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mdxlii{আর আমাদের বাণীবাহকরা ইব্রাহীমের কাছে এসেছিলেন সুসংবাদ নিয়ে, তারা বললে -- ''সালাম’’। তিনিও বললেন -- ''সালাম’’, আর তিনি দেরি করলেন না একটি কাবাব করা গোরুর বাছুর আনতে।\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mdxliii{কিন্তু যখন তিনি দেখলেন তাদের হাত ওর দিকে বাড়ছে না তখন তিনি তাদের বিস্ময়কর ভাবলেন এবাং তাদের সন্বন্ধে তিনি ভয় অনুভব করলেন। তারা বললে -- ''ভয় করো না, আমরা লুতের লোকদের প্রতি প্রেরিত হয়েছি।’’\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@mdxliv{আর তাঁর স্ত্রী দাঁড়িয়ে রয়েছেন এবং তিনি হাসলেন, আমরা তখন তাঁকে সুসংবাদ দিলাম ইসহাকের এবং ইসহাকের পরে ইয়াকুবের।\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@mdxlv{তিনি বললেন -- ''হায় আমার আফসোস! আমি কি সন্তান জন্ম দেব যখন আমি বৃদ্ধা হয়ে গেছি আর আমার স্বামীও বৃদ্ধ? এটি নিশ্চয়ই আজব ব্যাপার।’’\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@mdxlvi{তারা বললে -- ''তুমি কি তাজ্জব হচ্ছ আল্লাহ্‌র হুকুমের প্রতি? আল্লাহ্‌র অনুগ্রহ ও তাঁর আশীর্বাদ তোমাদের উপরে রয়েছে, হে পরিবারবর্গ, নিঃসন্দেহ তিনি প্রশংসার্হ, মহিমান্নিত।\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@mdxlvii{তারপর যখন ইব্রাহীমের থেকে ভয় চলে গেল এবং তাঁর কাছে সুসংবাদ এল তখন তিনি আমাদের কাছে কাকুতি-মিনতি শুরু করলেন লূতের লোকদের সম্পর্কে।\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@mdxlviii{নিঃসন্দেহ ইব্রাহীম তো ছিলেন সহনশীল, কোমল হৃদয়, সতত প্রত্যাবর্তনকারী।\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@mdxlix{''হে ইব্রাহীম! এ থেকে ক্ষান্ত হও, নিঃসন্দেহ তোমাদের প্রভুর বিধান এসে পড়েছে, আর ওদের ক্ষেত্রে -- শাস্তি তাদের উপরে আসবেই, তা ফেরানো যাবে না।’’\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@mdl{আর যখন আমাদের বাণীবাহকরা লূত-এর কাছে এসেছিল তখন তিনি ব্যতিব্যস্ত হলেন, এবং তিনি তাদের রক্ষা করতে নিজেকে অসহায় বোধ করছিলেন, তাই তিনি বলেছিলেন -- ''এ এক নিদারুণ দিন!’’\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@mdli{আর তাঁর লোকেরা তাঁর কাছে এল, উদভ্রান্ত হয়ে তাঁর দিকে এল, আর আগে থেকেই তারা কুকর্ম করে যাচ্ছিল। তিনি বললেন -- ''হে আমার সম্প্রদায়! এরাই আমার কন্যা, এরা তোমাদের জন্য পবিত্রতর, কাজেই আল্লাহ্‌কে ভয়ভক্তি কর, আর আমার মেহ্‌মানদের সন্বন্ধে আমাকে লজ্জিত কর না। তোমাদের মধ্যে কি কোনো ভাল মানুষ নেই?’’\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@mdlii{তারা বললে -- ''তুমি নিশ্চয়ই জানো যে তোমার কন্যাদের প্রতি আমাদের কোনো দাবি নেই, আর নিশ্চয়ই তুমি ভাল করেই জান কি আমরা চাই।’’\qt@no{(79)}}
\qt@newcmd\qurantrans@bn@mdliii{তিনি বললেন -- ''হায়, তোমাদের বাধা দেবার যদি আমার ক্ষমতা থাকতো, অথবা যদি কোনো জোরালো অবলন্বন পেতাম!’’\qt@no{(80)}}
\qt@newcmd\qurantrans@bn@mdliv{তারা বললে -- ''হে লূত! আমরা নিশ্চয় তোমার প্রভুর দূত। তারা কখনই তোমার কাছে ঘেসতে পারবে না, সুতরাং তোমার পরিবারবর্গসহ যাত্রা করো রাতের এই প্রহরের মধ্যে, আর তোমাদের মধ্যের কেউই পেছন ফেরো না তোমার স্ত্রী ব্যতীত, কেননা ওদের যা ঘটবে তারও তাই ঘটবে। নিঃসন্দেহ তাদের নির্ধারিত সময় হচ্ছে ভোরবেলা। ভোরবেলা কি আসন্ন নয়?’’\qt@no{(81)}}
\qt@newcmd\qurantrans@bn@mdlv{অতঃপর আমাদের হুকুম যখন এল তখন আমরা এগুলোর উপরভাগ করে দিলাম তাদের নিচেরভাগ, আর তাদের উপরে বর্ষণ করলাম পোড়া-মাটির পাথর -- স্তরীভূতভাবে --\qt@no{(82)}}
\qt@newcmd\qurantrans@bn@mdlvi{যা তোমার প্রভুর কাছে চিহ্নিত ছিল। আর তা অন্যায়কারীদের থেকে দূরে নয়।\qt@no{(83)}}
\qt@newcmd\qurantrans@bn@mdlvii{আর মাদয়ানবাসীর নিকট তাদের ভাই শোআইবকে। তিনি বললেন -- ''হে আমার সম্প্রদায়! আল্লাহ্‌র উপাসনা করো, তোমাদের জন্য তিনি ছাড়া অন্য উপাস্য নেই। আর মাপে ও ওজনে কম কর না, নিঃসন্দেহ আমি তোমাদের দেখছি সমৃদ্ধিশালী, আর আমি নিশ্চয়ই তোমাদের জন্য আশংকা করছি এক সর্বগ্রাসী দিনের শাস্তির।\qt@no{(84)}}
\qt@newcmd\qurantrans@bn@mdlviii{''আর হে আমার সম্প্রদায়! পুরো মাপ ও ওজন দেবে ন্যায়সঙ্গতভাবে, আর কোনো লোককে তাদের বিষয়বস্তুতে বঞ্চিত কর না, আর পৃথিবীতে গর্হিত আচরণ কর না গোলযোগ সৃষ্টিকারী হয়ে।\qt@no{(85)}}
\qt@newcmd\qurantrans@bn@mdlix{''আল্লাহ্‌র কাছে যা বাকি থাকে তা তোমাদের জন্য উত্তম -- যদি তোমরা বিশ্বাসী হও, আর আমি তোমাদের উপরে রক্ষক নই।’’\qt@no{(86)}}
\qt@newcmd\qurantrans@bn@mdlx{তারা বললে -- ''হে শোআইব! তোমার নামায কি তোমাকে নির্দেশ দেয় যে আমাদের পিতৃপুরুষরা যার উপাসনা করত তা আমাদের বর্জন করতে হবে, অথবা আমাদের ধন-সম্পদ সন্বন্ধে আমাদের যা খুশি তা করতে পারব না? তুমি তো সত্যিসত্যি সহনশীল, সদাচারী!’’\qt@no{(87)}}
\qt@newcmd\qurantrans@bn@mdlxi{তিনি বললেন -- ''হে আমার সম্প্রদায়! তোমরা ভেবে দেখো -- আমি যদি আমার প্রভুর কাছ থেকে স্পষ্ট দলিল-প্রমাণে প্রতিষ্ঠিত থাকি এবং তিনি যদি তাঁর কাছ থেকে উত্তম জীবনোপকরণ দিয়ে আমাকে জীবিকা দান করেন? আর আমি চাই না যে তোমাদের বিপরীতে আমি সেই আচরণ করি যা করতে আমি তোমাদের নিষেধ করে থাকি। আমি শুধু চাই সংস্কার করতে যতটা আমি সাধ্যমত পারি। আর আমার কার্যসাধন আল্লাহ্‌র সাহায্যে বৈ নয়। আমি তাঁরই উপরে নির্ভর করি আর তাঁরই দিকে আমি ফিরি।\qt@no{(88)}}
\qt@newcmd\qurantrans@bn@mdlxii{''আর, হে আমার সম্প্রদায়! আমার সঙ্গে মতানৈক্য তোমাদের অপরাধী না করুক যার ফলে তোমাদের উপরে ঘটতে পারে তার মতো যা ঘটেছিল নূহ-এর সম্প্রদায়ের উপরে, অথবা হূদ-এর সম্প্রদায়ের উপরে, কিংবা সালিহ্‌-এর সম্প্রদায়ের উপরে, আর লূত- এর সম্প্রদায়ও তোমাদের থেকে দূরে নয়।\qt@no{(89)}}
\qt@newcmd\qurantrans@bn@mdlxiii{''সুতরাং তোমাদের প্রভুর কাছে পরিত্রাণ খোঁজো, তারপর তাঁর দিকে ফেরো। নিঃসন্দেহ আমার প্রভু অফুরন্ত ফলদাতা, পরম প্রেমময়।’’\qt@no{(90)}}
\qt@newcmd\qurantrans@bn@mdlxiv{তারা বললে -- ''হে শোআইব! তুমি যা বল তার অধিকাংশই আমরা বুঝি না, আর আমরা অবশ্য আমাদের মধ্যে তোমাকে দুর্বলই তো দেখছি, আর তোমার পরিজনবর্গের জন্যে না হলে আমরা তোমাকে পাথর মেরেই শেষ করতাম, আর তুমি আমাদের উপরে মোটেই শক্তিশালী নও।’’\qt@no{(91)}}
\qt@newcmd\qurantrans@bn@mdlxv{তিনি বললেন -- ''হে আমার সম্প্রদায়! আমার পরিজনবর্গ কি তোমাদের কাছে আল্লাহ্‌র চেয়েও বেশী শ্রদ্ধেয়? আর তোমরা তাঁকে গ্রহণ করেছ তোমাদের পৃষ্ঠদেশের পশ্চাদভাগে ফেলা বস্তুর মত। নিঃসন্দেহ তোমরা যা কর আমার প্রভু তা ঘেরাও করে আছেন।\qt@no{(92)}}
\qt@newcmd\qurantrans@bn@mdlxvi{''আর, হে আমার সম্প্রদায়! তোমাদের বাড়িঘরে কাজ করে যাও, আমিও অবশ্য করে যাচ্ছি। তোমরা শীঘ্রই জানতে পারবে কার উপরে শাস্তি নামবে যা তাকে লাঞ্ছিত করে, আর কে হচ্ছে মিথ্যাবাদী। সুতরাং তোমরা প্রতীক্ষা কর, আমিও তোমাদের সাথে প্রতীক্ষাকারী।’’\qt@no{(93)}}
\qt@newcmd\qurantrans@bn@mdlxvii{আর যখন আমাদের নির্দেশ এল তখন আমরা শোআইবকে ও যারা তাঁর সঙ্গে বিশ্বাস করেছিল তাদের উদ্ধার করেছিলাম আমার তরফ থেকে অনুগ্রহের ফলে। আর যারা অত্যাচার করেছিল তাদের পাকড়াও করেছিল এক মহাধ্বনি, ফলে তারা হয়ে গেল তাদের ঘরে ঘরে নিথরদেহী, --\qt@no{(94)}}
\qt@newcmd\qurantrans@bn@mdlxviii{যেন তারা সেখানে বসবাস করে নি। এটি কি নয় -- ''দূর হও মাদয়ানবাসী, যেমন দূর করা হয়েছে ছামূদ জাতিকে?’’\qt@no{(95)}}
\qt@newcmd\qurantrans@bn@mdlxix{আর আমরা অবশ্যই মূসাকে পাঠিয়েছিলাম আমাদের নির্দেশাবলী ও সুস্পষ্ট কর্তৃত্ব দিয়ে --\qt@no{(96)}}
\qt@newcmd\qurantrans@bn@mdlxx{ফিরআউন ও তার প্রধানদের কাছে, কিন্তু তারা ফিরআউনের আদেশের অনুগমন করেছিল, অথচ ফিরআউনের নির্দেশ সঠিক ছিল না।\qt@no{(97)}}
\qt@newcmd\qurantrans@bn@mdlxxi{সে কিয়ামতের দিন তার লোকদের চালিত করবে আর তাদের নামিয়ে দেবে আগুনে। আর নিকৃষ্ট সেই খাদ সেখানে তাদের নামান হবে!\qt@no{(98)}}
\qt@newcmd\qurantrans@bn@mdlxxii{আর এক অভিশাপ তাদের পিছু নিয়েছে এইখানে ও কিয়ামতের দিনে। নিকৃষ্ট সেই পুরস্কার যা তাদের দেয়া হবে!\qt@no{(99)}}
\qt@newcmd\qurantrans@bn@mdlxxiii{এই হচ্ছে জনপদসমূহের কিছু সংবাদ যা তোমার কাছে বর্ণনা করলাম, এগুলোর মধ্যে কতকটা দাঁড়িয়ে আছে, আর কেটে ফেলা হয়েছে।\qt@no{(100)}}
\qt@newcmd\qurantrans@bn@mdlxxiv{আর আমরা তাদের প্রতি অন্যায় করি নি, কিন্তু তারা তাদের নিজেদের প্রতি অন্যায় করেছিল, সুতরাং তাদের দেবতারা, যাদের তারা আহ্বান করত আল্লাহ্‌কে ছেড়ে দিয়ে, তাদের কোনো কাজে আসে নি যে-সময়ে তোমার প্রভুর বিধান এসে পৌঁছাল। আর তারা ধ্বংস ব্যতীত কিছুই তাদের জন্য সংযোগ করে নি।\qt@no{(101)}}
\qt@newcmd\qurantrans@bn@mdlxxv{আর এইভাবেই হচ্ছে তোমার প্রভুর পাকড়ানো যখন তিনি পাকড়াও করেন জনপদগুলোকে যখন তারা অন্যায়াচরণ করে। নিঃসন্দেহ তাঁর পাকড়ানো মর্মন্তুদ, কঠিন।\qt@no{(102)}}
\qt@newcmd\qurantrans@bn@mdlxxvi{নিঃসন্দেহ এতে রয়েছে নিদর্শন তার জন্য যে পরকালের শাস্তিকে ভয় করে। এই হচ্ছে মানুষকে একত্রিত করণের দিন, আর এই হচ্ছে সাক্ষ্যদানের দিন।\qt@no{(103)}}
\qt@newcmd\qurantrans@bn@mdlxxvii{আর আমরা এটি পিছিয়ে রাখি না একটি নির্দিষ্ট সময়ের জন্য ব্যতীত।\qt@no{(104)}}
\qt@newcmd\qurantrans@bn@mdlxxviii{যখন সে-দিনটি আসবে তখন কোনো সত্ত্বাই তাঁর অনুমতি ব্যতীত কথা বলতে পারবে না, কাজে-কাজেই তাদের মধ্যে কেউ হবে হতভাগ্য আর কেউ ভাগ্যবান।\qt@no{(105)}}
\qt@newcmd\qurantrans@bn@mdlxxix{তারপর যারা হবে হতভাগ্য তারা আগুনে, তাদের জন্য সেখানে থাকবে দীর্ঘশ্বাস ও আর্তনাদ, --\qt@no{(106)}}
\qt@newcmd\qurantrans@bn@mdlxxx{তারা সেখানে থাকবে যতদিন মহাকাশমন্ডল ও পৃথিবী বিদ্যমান থাকবে -- যদি না তোমার প্রভু অন্যথা ইচ্ছা করেন। নিঃসন্দেহ তোমার প্রভু যা ইচ্ছা করেন তাই করে থাকেন।\qt@no{(107)}}
\qt@newcmd\qurantrans@bn@mdlxxxi{আর যারা হবে ভাগ্যবান তারা থাকবে বেহেশতে, তারা সেখানে থাকবে যতদিন মহাকাশমন্ডল ও পৃথিবী বিদ্যমান থাকবে -- যদি না তোমার প্রভু অন্যথা ইচ্ছা করেন। একটি দান যা কখনো কাটছাঁট হবে না।\qt@no{(108)}}
\qt@newcmd\qurantrans@bn@mdlxxxii{কাজেই তুমি সন্দেহের মধ্যে থেকো না তারা যাদের উপাসনা করে তাদের সন্বন্ধে। তারা উপাসনা করে না যেভাবে তাদের পিতৃপুরুষরা ইতিপূর্বে উপাসনা করত সেভাবে ছাড়া। আর নিঃসন্দেহ তাদের পাওনা আমরা অবশ্যই তাদের পুরোপুরি মিটিয়ে দেবো কিছু মাত্র কমতি না ক’রে।\qt@no{(109)}}
\qt@newcmd\qurantrans@bn@mdlxxxiii{আর আমরা অবশ্য মুসাকে গ্রন্থ দিয়েছিলাম, কিন্তু তাতে মতভেদ ঘটেছিল। আর যদি তোমার প্রভুর তরফ থেকে ঘোষণাটি সাব্যস্ত না হতো তাহলে তাদের মধ্যে মীমাংসা হয়ে যেত। আর নিঃসন্দেহ তারা তো সন্দেহের মধ্যে রয়েছে সে-সন্বন্ধে, -- বিভ্রান্তিকর।\qt@no{(110)}}
\qt@newcmd\qurantrans@bn@mdlxxxiv{আর নিঃসন্দেহ তোমার প্রভু যথাসময়ে তাদের প্রত্যেকের কর্মফল তাদের কাছে অবশ্যই পুরোপুরি মিটিয়ে দেবেন। তারা যা করে সে-বিষয়ে তিনি নিশ্চয়ই সবিশেষ অবহিত।\qt@no{(111)}}
\qt@newcmd\qurantrans@bn@mdlxxxv{অতএব তুমি সহজ-সঠিক পথে আঁকড়ে থেকো যেমন তোমাকে আদেশ করা হয়েছে, আর সেও যে তোমার সঙ্গে ফিরেছে, আর তোমরা সীমালংঘন করো না। তোমরা যা কর তিনি নিশ্চয়ই তার দ্রষ্টা।\qt@no{(112)}}
\qt@newcmd\qurantrans@bn@mdlxxxvi{আর তোমরা তাদের দিকে ঝুকোঁ না যারা অন্যায় করে, পাছে আগুন তোমাদের স্পর্শ করে। আর আল্লাহ্‌কে ছেড়ে দিয়ে তোমাদের জন্য কোনো অভিভাবকমন্ডলী নেই, সুতরাং তোমাদের সাহায্য করা হবে না।\qt@no{(113)}}
\qt@newcmd\qurantrans@bn@mdlxxxvii{আর নামায কায়েম রাখো দিনের দুই প্রান্ত ভাগে, আর রাতের প্রথমাংশে। শুভকাজ নিশ্চয়ই মন্দ কাজকে দূর করে দেয়। এটি এক স্মরণীয় উপদেশ তাদের জন্য যারা স্মরণকারী।\qt@no{(114)}}
\qt@newcmd\qurantrans@bn@mdlxxxviii{আর অধ্যবসায় অবলন্বন কর, কেননা আল্লাহ্ নিশ্চয়ই সৎকর্মশীলদের কর্মফল ব্যর্থ করেন না।\qt@no{(115)}}
\qt@newcmd\qurantrans@bn@mdlxxxix{তবে কেন তোমাদের পূর্বপুরুষদের মধ্যে বাকী থাকা লোকজন নেই যারা নিষেধ করে পৃথিবীতে বিপর্যয় ঘটাতে -- যাদের আমরা উদ্ধার করেছিলাম তাদের মধ্য থেকে শুধু অল্প কয়েকজন ছাড়া? কিন্তু যারা অন্যায় আচরণ করেছিল তারা অনুসরণ করেছিল তাদের যারা এতে সচ্ছল-সমৃদ্ধ ছিল, ফলে তারা ছিল অপরাধী।\qt@no{(116)}}
\qt@newcmd\qurantrans@bn@mdxc{আর তোমার প্রভুর পক্ষে এটি নয় যে তিনি কোনো জনপদকে ধ্বংস করবেন অন্যায়ভাবে, যখন সে-সবের অধিবাসীরা থাকে সৎপথাবলন্বী।\qt@no{(117)}}
\qt@newcmd\qurantrans@bn@mdxci{আর যদি তোমার প্রভু ইচ্ছা করতেন তবে তিনি মানবগোষ্ঠীকে অবশ্য এক জাতি বানিয়ে নিতেন, কিন্তু তারা মতভেদ করতেই থাকবে, --\qt@no{(118)}}
\qt@newcmd\qurantrans@bn@mdxcii{সে ব্যতীত যাকে তোমার প্রভু করুণা করেছেন, আর এর জন্যেই তিনি তাদের সৃষ্টি করেছেন। আর সম্পূর্ণ হয়েছে তোমার প্রভুর বাণী -- ''আমি আলবৎ একই সঙ্গে জিনদের ও মানুষদের দ্বারা জাহান্নাম ভর্তি করব।’’\qt@no{(119)}}
\qt@newcmd\qurantrans@bn@mdxciii{আর রসূলগণের কাহিনী থেকে সব-কিছু আমরা তোমার কাছে বর্ণনা করছি এজন্য যে সে-সবের দ্বারা আমরা তোমার চিত্তকে বলিষ্ঠ করব, আর এতে তোমার কাছে এসেছে মুমিনদের জন্য সত্য ও উপদেশ ও স্মরণীয় বার্তা।\qt@no{(120)}}
\qt@newcmd\qurantrans@bn@mdxciv{আর যারা বিশ্বাস করে না তাদের বলো -- ''তোমাদের নিজ নিজ ক্ষেত্রে কাজ করে যাও, নিঃসন্দেহ আমরাও কর্তব্যরত।\qt@no{(121)}}
\qt@newcmd\qurantrans@bn@mdxcv{''আর অপেক্ষা কর, আমরাও নিঃসন্দেহ অপেক্ষারত।’’\qt@no{(122)}}
\qt@newcmd\qurantrans@bn@mdxcvi{আর মহাকাশমন্ডল ও পৃথিবীর অদৃশ্য বিষয়বস্তু আল্লাহ্‌রই, আর তাঁরই কাছে বিষয়-আশয়ের সব-কিছু ফিরিয়ে আনা হবে। সুতরাং তাঁর উপাসনা কর আর তাঁরই উপরে নির্ভর কর। বস্তুতঃ তোমরা যা কর সে-সন্বন্ধে তোমার প্রভু অনবহিত নন।\qt@no{(123)}}
\qt@newcmd\qurantrans@bn@mdxcvii{\basmalahbn আলিফ, লাম, রা। এসব সুস্পষ্ট গ্রন্থের আয়াতসমূহ।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mdxcviii{নিঃসন্দেহ আমরা এটি অবতারণ করেছি -- আরবী কুরআন, যেন তোমরা বুঝতে পার।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mdxcix{আমরা তোমার কাছে এই কুরআন প্রত্যাদেশের দ্বারা তোমার নিকট শ্রেষ্ঠ কাহিনী বর্ণনা করছি। আর অবশ্যই এর আগে তুমি তো ছিলে অনবহিতদের অন্তর্ভূক্ত।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mdc{স্মরণ করো! ইউসুফ তাঁর পিতাকে বললেন -- ''হে আমার আব্বা! আমি নিশ্চয়ই দেখলাম এগারোটি তারা আর সূর্য ও চন্দ্র -- তাদের দেখলাম আমার কারণে তারা সিজদারত।’’\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mdci{তিনি বললেন, ''হে আমার পুত্র! তোমার স্বপ্ন তোমার ভাইদের কাছে বর্ণনা কর না পাছে তারা তোমার বিরুদ্ধে কোনো চক্রান্তের ফন্দি আঁটে। নিঃসন্দেহ শয়তান মানুষের জন্য প্রকাশ্য শত্রু।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mdcii{''আর এইভাবে তোমার প্রভু তোমাকে মনোনীত করবেন, আর তোমাকে শিক্ষা দেবেন ঘটনাবলীর ব্যাখ্যা সম্পর্কে, আর তাঁর অনুগ্রহ পূর্ণাঙ্গ করবেন তোমার প্রতি ও ইয়াকুবের বংশধরদের প্রতি, যেমন তিনি তা পূর্ণাঙ্গ করেছিলেন এর আগে তোমার পূর্বপুরুষ ইব্রাহীম ও ইসহাকের প্রতি। নিঃসন্দেহ তোমার প্রভু সর্বজ্ঞাতা, পরমজ্ঞানী।’’\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mdciii{ইউসুফ ও তাঁর ভাইদের মধ্যে নিশ্চয়ই নিদর্শন রয়েছে জিজ্ঞাসুদের জন্যে।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mdciv{স্মরণ করো! তারা বলাবলি করলে -- ''ইউসুফ ও তার ভাই তো আমাদের আব্বার কাছে আমাদের চেয়েও বেশি প্রিয়, যদিও আমরা দলে ভারী। আমাদের আব্বা নিশ্চয়ই স্পষ্ট বিভ্রান্তিতে রয়েছেন।’’\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mdcv{''ইউসুফকে মেরে ফেল অথবা কোনো দেশে নির্বাসন দাও, তাহলে তোমাদের আব্বার মুখ তোমাদের দিকেই নিবিষ্ট হবে, এবং তার পরে তোমরা ভাল লোক হতে পারবে।’’\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mdcvi{তাদের মধ্যে থেকে একজন বক্তা বললে -- ''ইউসুফকে কাতল করো না, তাকে বরং কোনো কুয়োর তলায় ফেলে দাও, ভ্রমণকারীদের কেউ তাকে তুলেও নিতে পারে, -- যদি তোমরা কাজ করতে চাও।’’\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mdcvii{তারা বলল -- ''হে আমাদের আব্বা! তোমার কি হয়েছে যেজন্যে তুমি ইউসুফের ব্যাপারে আমাদের বিশ্বাস কর না, অথচ নিঃসন্দেহ আমরা তো তার শুভাকাঙ্খী?\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mdcviii{''তাকে আমাদের সঙ্গে কালকে পাঠিয়ে দাও, সে আমোদ করুক ও খেলাধুলা করুক, আর আমরা তো নিশ্চয়ই তার হেফাজতকারী।’’\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mdcix{তিনি বললেন -- ''এতে অবশ্যই আমাকে কষ্ট দেবে যে তোমরা তাকে নিয়ে যাবে, আর আমি ভয় করছি পাছে নেকড়ে তাকে খেয়ে ফেলে, যদি তোমরা তার প্রতি বেখেয়াল হয়ে যাও!’’\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mdcx{তারা বললে, ''আমরা দলে ভারী হওয়া সত্ত্বেও যদি তাকে নেকড়ে খেয়ে ফেলে তবে আমরাই তো নিশ্চয় সর্বহারা হব।’’\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mdcxi{তারপর তারা যখন তাকে নিয়ে গেল এবং সবাই একমত হল যে তারা তাকে ফেলে দেবে কুয়োর তলায়, তখন আমরা তার কাছে প্রত্যাদেশ দিলাম -- ''তুমি তাদের অবশ্যই জানিয়ে দেবে তাদের এই কাজের কথা, আর তারা চিনতেও পারবে না।’’\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mdcxii{আর তারা তাদের পিতার কাছে কাঁদতে কাঁদতে এলো রাত্রিবেলায়।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mdcxiii{তারা বললে -- ''হে আমাদের আব্বা! আমরা দৌড়াদেড়ি করে চলেছিলাম, আর ইউসুফকে রেখে গিয়েছিলাম আমাদের আসবাবপত্রের পাশে, তখন নেকড়ে তাকে খেয়ে ফেলেছে, কিন্তু তুমি তো আমাদের প্রতি বিশ্বাসকারী হবে না, যদিও আমরা হচ্ছি সত্যবাদী।’’\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mdcxiv{আর তারা এল তাঁর সার্টের উপরে ঝুটা রক্ত নিয়ে। তিনি বললেন -- ''না, তোমাদের অন্তর তোমাদের জন্য এই বিষয়টি উদ্ভাবন করেছে, কিন্তু ধৈর্যধারণই উত্তম। আর আল্লাহ্‌ই সাহায্য কামনার স্থল তোমরা যা বর্ণনা করছ সে-ক্ষেত্রে।’’\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mdcxv{এদিকে ভ্রমণকারীরা এল এবং তাদের পানিওয়ালাকে পাঠাল, সে তখন তার বালতি নামিয়ে দিল। সে বললে, ''কি সুখবর! এ যে একটি ছোকরা!’’ অতঃপর তারা তাঁকে লুকিয়ে রাখল পণ্য-দ্রব্যের মতো। আর তারা যা করেছিল সে-সন্বন্ধে আল্লাহ্ সর্বজ্ঞাতা।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mdcxvi{আর তারা তাঁকে বিক্রি করল সামান্য মূল্যে -- গুণতির কয়েকটি দিরহামে, আর তাঁর প্রতি তারা ছিল অনাসক্ত।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mdcxvii{আর মিশরীয় যে তাঁকে কিনেছিল সে তার স্ত্রীকে বললে -- ''সম্মানজনকভাবে এর থাকবার জায়গা কর, হয়ত সে আমাদের উপকারে আসবে, অথবা তাকে আমরা পুত্ররূপে গ্রহণ করতে পারি।’’ আর এইভাবে আমরা ইউসুফের জন্য বাসস্থান ঠিক করে দিলাম সে-দেশে, যেন তাঁকে শেখাতে পারি ঘটনাবলীর ব্যাখ্যা সন্বন্ধে। আল্লাহ্ তাঁর কাজকর্মে সর্বেসর্বা, কিন্তু অধিকাংশ লোকেই জানে না।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mdcxviii{আর যখন তিনি তাঁর পূর্ণ যৌবনে পৌঁছুলেন, আমরা তাঁকে বুদ্ধি ও বিদ্যা দান করলাম। আর এইভাবে আমরা সৎকর্মশীলদের পুরস্কার প্রদান করি।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mdcxix{আর যে মহিলায় গৃহে তিনি ছিলেন সে তাঁকে কামনা করল তাঁর অন্তরঙ্গতার, আর বন্ধ করে দিলে দরজাগুলো ও বললে -- ''এসো হে তুমি!’’ তিনি বললেন -- ''আল্লাহ্ সহায় হোন! আমার প্রভু নিশ্চয়ই আমার আশ্রয়স্থল অতি উত্তম বানিয়েছেন। নিঃসন্দেহ তিনি অন্যায়কারীদের উন্নতি করেন না।’’\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mdcxx{আর সে নারী নিশ্চয়ই তাঁর প্রতি আসক্ত হয়েছিল, আর তিনিও তার প্রতি আসক্ত হয়ে পড়তেন যদি না তিনি তাঁর প্রভুর স্পষ্ট- প্রমাণ প্রত্যক্ষ করতেন। এইভাবে আমরা যেন তাঁর কাছ থেকে হটিয়ে দিতে পারি মন্দকাজ ও অশ্লীলতা। নিঃসন্দেহ তিনি ছিলেন আমাদের একান্ত অনুরক্ত দাসদের অন্যতম।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mdcxxi{আর তারা দুজনেই দরজার দিকে দৌড়লো, আর সে তাঁর জামা পেছনের দিক থেকে ছিড়ে ফেঁললো, আর তারা দুজনে দরজার নিকটে দেখা পেল তার স্বামীর। সে বললে -- ''যে তোমার পরিবারের সঙ্গে কুকর্ম কামনা করে তার পরিণাম কারাদন্ড বা মর্মন্তুদ শাস্তি ছাড়া আর কী হতে পারে?’’\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mdcxxii{তিনি বললেন -- ''উনিই আমাকে কামনা করেছিলেন আমার অন্তরঙ্গতার।’’ আর তারই পরিবারের একজন সাক্ষী সাক্ষ্য দিলে -- ''যদি তার সার্টটি সামনের দিকে ছেঁড়া হয় তবে ইনি সত্যবাদী এবং ও মিথ্যাবাদীদের মধ্যের।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mdcxxiii{''আর যদি তার সার্টটি পেছনের দিকে ছেঁড়া থাকে তবে ইনিই মিথ্যাবাদী আর ও সত্যবাদীদের অন্তর্ভুক্ত।’’\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mdcxxiv{সুতরাং সে যখন দেখলে যে তাঁর জামাটি পেছনের দিকে ছেঁড়া তখন সে বললে -- ''এ নিঃসন্দেহ তোমাদের ছলাকলা, তোমাদের ছলচাতুরী বড়ই ভীষণ।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mdcxxv{''হে ইউসুফ, তুমি এ বিষয়ে কিছু মনে করো না; আর তুমি ক্ষমা প্রার্থনা কর তোমার অপরাধের জন্য; নিঃসন্দেহ তুমি হচ্ছো পাপিষ্ঠাদের মধ্যেকার।’’\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mdcxxvi{আর শহরের নারীরা বললে, ''আজীযের স্ত্রী তার যুবক দাসকে কামনা করেছিল তার অন্তরঙ্গতার! নিশ্চয়ই সে তাকে প্রেমে অভিভূত করেছে। আমরা তাকে দেখছি স্পষ্ট বিভ্রান্তিতে পড়েছে।’’\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mdcxxvii{সুতরাং সে যখন শুনলে তাদের ফন্দির কথা, সে তাদের ডেকে পাঠালে এবং তাদের জন্য তৈরি করলে গদির আসন, আর তাদের মধ্যের প্রত্যেককে দিলে একটি করে ছুরি, আর বললে -- ''বেরিয়ে এস এদের সামনে।’’ অতঃপর তারা যখন তাঁকে দেখল তাঁকে ভাবলো অতুলনীয়, আর নিজেদের হাত কেটে ফেলল ও বললো -- ''আল্লাহ্‌র কি নিখুঁত সৃষ্টি! এ তো মানুষ নয়, এ তো এক মহিমান্নিত ফিরিশ্‌তা।’’\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mdcxxviii{সে বললে -- ''এ-ই তো সেই যার সন্বন্ধে তোমরা আমার নিন্দা করেছ, আর আমি অবশ্যই তাকে কামনা করেছিলাম তার অন্তরঙ্গতার, কিন্তু সে নিজেকে সংযত রেখেছিল। আর আমি তাকে যা আদেশ করি তা যদি সে না করে তবে সে নিশ্চিত কারারুদ্ধ হবে এবং সে হবে অবশ্যই ছোটলোকদের মধ্যেকার।’’\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mdcxxix{তিনি বললেন -- ''আমার প্রভু! তারা আমাকে যার প্রতি আহ্বান করছে তার চেয়ে কারাগারই আমার কাছে অধিক প্রিয়। আর তুমি যদি আমার থেকে তাদের ছলনা দূরীভূত না কর তবে আমি তাদের প্রতি আকৃষ্ট হয়ে পড়ব, ফলে আমি হয়ে যাব অজ্ঞদের অন্তর্ভুক্ত।’’\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mdcxxx{অতএব তাঁর প্রভু তাঁর প্রতি সাড়া দিলেন আর তাঁর থেকে তাদের ছলাকলা হটিয়ে দিলেন। নিঃসন্দেহ তিনি সর্বশ্রোতা, সর্বজ্ঞাতা।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mdcxxxi{অতঃপর সাক্ষীসাবুদ তারা দেখার পরে তাদের মনে হল তাঁকে কিছুকালের জন্য কারারুদ্ধ করাই উচিত।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mdcxxxii{আর তাঁর সঙ্গে দু’জন যুবক জেলে ঢুকেছিল। তাদের একজন বললে, ''আমি দেখলাম মদ তৈরি করছি।’’ আর অন্যজন বললে, ''আমি দেখলাম আমি আমার মাথার উপরে রুটি বয়ে নিচ্ছি, তা থেকে পাখিরা খাচ্ছে।’’ ''আমাদের এর তাৎপর্য বলে দাও, আমরা নিশ্চয়ই তোমাকে দেখছি ভালো-লোকদের মধ্যেকার।’’\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mdcxxxiii{তিনি বললেন -- ''তোমাদের যা খেতে দেয়া হয় সে খাদ্য তোমাদের কাছে এসে পৌঁছুবেনা না, অথচ তোমাদের কাছে তা আসার আগেই আমি তোমাদের বলে দেব এর তাৎপর্য। এটি হচ্ছে আমার প্রভু আমাকে যা শিখিয়েছেন তা থেকে। আমি নিশ্চয়ই পরিত্যাগ করেছি সেই লোকদের ধর্মমত যারা আল্লাহ্‌তে বিশ্বাস করে না, আর তারা নিজেরাই পরকালেও অবিশ্বাসী।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mdcxxxiv{''আর আমি অনুসরণ করি আমার পিতৃপুরুষ ইব্রাহীম ও ইসহাক ও ইয়াকুবের ধর্মমত। এটি আমাদের জন্য নয় যে আমরা আল্লাহ্‌র সঙ্গে কোনো ধরনের অংশী দাঁড় করাব। এটি আমাদের প্রতি আল্লাহ্‌র অনুগ্রহ-প্রাচুর্যের ফলে আর মানবগোষ্ঠীর প্রতিও, কিন্তু অধিকাংশ লোকেরা কৃতজ্ঞতা প্রকাশ করে না।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mdcxxxv{''হে আমার জেলখানার সঙ্গিদ্বয়! ভিন্ন ভিন্ন প্রভুসব ভাল, না একক সর্বশক্তিমান আল্লাহ্‌?\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mdcxxxvi{''তাঁকে ছেড়ে দিয়ে তোমরা যাদের উপাসনা কর তারা নামাবলী মাত্র যা তোমরা নামকরণ করেছ -- তোমরা ও তোমাদের পূর্বপুরুষরা, যেজন্যে কোনো দলিল-দস্তাবেজ আল্লাহ্ পাঠান নি। বিধান দেবার অধিকার শুধু আল্লাহ্‌র। তিনি আদেশ দিয়েছেন যে তোমরা তাঁকে ছাড়া আর কারোর উপাসনা করবে না। এই হচ্ছে সঠিক ধর্ম, কিন্তু অধিকাংশ লোকেই জানে না।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mdcxxxvii{''হে আমার কারাগারের সঙ্গিদ্বয়! তোমাদের একজন সন্বন্ধে -- সে তার প্রভুকে সুরা পান করাবে, কিন্তু অন্যজনের ক্ষেত্রে -- সে তখন শূলবিদ্ধ হয়ে মরবে, তার ফলে পাখিরা তার মাথা থেকে খাবে। তোমরা যার সন্বন্ধে জিজ্ঞাসা করছিলে সে-বিষয় নিস্পত্তি হয়ে গিয়েছে!’’\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mdcxxxviii{আর দুইজনের মধ্যে যাকে তিনি জানতেন যে সে মুক্তি পাবে তাকে তিনি বললেন, ''তোমার প্রভুর কাছে আমার কথা বলো।’’ কিন্তু শয়তান তাকে ভুলিয়ে দিয়েছিল তার প্রভুর কাছে স্মরণ করিয়ে দিতে, তাই তিনি কারাগারে থাকলেন আরো কয়েক বছর।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mdcxxxix{আর রাজা বললেন -- ''আমি নিশ্চয়ই দেখলাম সাতটি হৃস্পুষ্ট গরু, তাদের খেয়ে ফেলল সাতটি জীর্ণশীর্ণ, আর সাতটা সবুজ শীষ আর অপর শুক্‌নো। ওহে প্রধানগণ! আমার স্বরে তাৎপর্য আমাকে বলে দাও যদি তোমরা স্বপ্নের ব্যাখ্যা করতে পারো।’’\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mdcxl{তারা বললে -- ''এলোমেলো স্বপ্ন, আর স্বপ্নের মর্মোদ্ধারে আমরা অভিজ্ঞ নই।’’\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mdcxli{আর সেই দুইজনের যে মুক্তি পেয়েছিল ও দীর্ঘকাল পরে যার মনে পড়ল সে বললে -- ''আমিই এর তাৎপর্য আপনাদের জানিয়ে দেব, সেজন্যে আমাকে পাঠিয়ে দিন।’’\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mdcxlii{''ইউসুফ! হে সত্যবাদী! আমাদের জন্য ব্যাখ্যা করে দাও সাতটি মোটাসোটা গরু যাদের খেয়ে ফেলল রোগা-পাতলা সাতটি, এবং সাতটি সবুজ শীষ ও অন্যগুলো শুক্‌নো, -- যেন আমি লোকদের কাছে ফিরে যেতে পারি যাতে তারা জানতে পারে।’’\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mdcxliii{তিনি বললেন -- ''তোমরা সাত বছর যথারীতি ক্ষেত করে যাবে, আর তোমরা যা তুলবে তা রেখে দেবে তার শীষের মধ্যে, শুধু তা থেকে যে সামান্যটুকু তোমরা খাবে তা ছাড়া।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mdcxliv{''তখন এর পরে আসবে সাতটি কঠোর, তা খেয়ে ফেলবে সে-ক’টির জন্য তোমরা যা এগিয়ে দেবে, কেবল সামান্য কিছু ছাড়া যা তোমরা সংরক্ষণ কর।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mdcxlv{''আর তার পরে আসবে এক বছর যাতে লোকেরা পাবে প্রচুর বৃষ্টিপাত, আর তাতে তারা পিযবে।’’\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mdcxlvi{আর রাজা বললেন -- ''তাকে আমার কাছে নিয়ে এস।’’ সুতরাং যখন দূত তাঁর কাছে এল, তিনি বললেন -- ''তোমার মনিবের কাছে ফিরে যাও এবং তাঁকে জিজ্ঞেস কর সেই নারীদের কি হল যারা তাদের হাত কেটেছিল। নিঃসন্দেহ আমাব প্রভু, তাদের ফন্দিফিকির সন্বন্ধে পূর্ণ ওয়াকিফহাল।’’\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mdcxlvii{তিনি বললেন -- ''তোমাদের কি হয়েছিল যখন তোমরা ইউসুফকে কামনা করেছিলে তার অন্তরঙ্গতার?’’ তারা বললে -- আল্লাহ্‌র কি নিখুঁত সৃষ্টি! আমরা ওর মধ্যে কোনো দোষের কথা জানি না।’’ নগর-প্রধানের স্ত্রী বললে -- ''এক্ষণে সত্য প্রকাশ পেয়েছে, আমিই তাকে কামনা করেছিলাম তার অন্তরঙ্গতার, আর নিঃসন্দেহ সে অবশ্যই ছিল সত্যপরায়ণদের মধ্যেকার।’’\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mdcxlviii{''এটিই, যেন তিনি জানতে পারেন যে আমি গোপনে তাঁর প্রতি বিশ্বাসঘাতকতা করি নি। আর নিঃসন্দেহ আল্লাহ্ বিশ্বাসহন্তাদের ছলাকলা পরিচালিত করেন না।’’\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mdcxlix{''আমি আমার নিজেকে মুক্ত বলি না, নিঃসন্দেহ মানুষমাত্রেরই মন্দের দিকে প্রবণতা রয়েছে, শুধু যাদের প্রতি আমার প্রভুর করুণা রয়েছে তারা ভিন্ন। নিঃসন্দেহ আমার প্রভু পরিত্রাণকারী, অফুরন্ত ফলদাতা।’’\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mdcl{আর রাজা বললেন -- ''তাঁকে আমার কাছে নিয়ে এস, আমি তাঁকে আমার নিজের জন্য একান্তভাবে গ্রহণ করব।’’ সুতরাং তিনি যখন তাঁর সাথে আলাপ করলেন তখন বললেন -- ''আপনি আজ নিশ্চয়ই হলেন আমাদের সমক্ষে সুপ্রতিষ্ঠিত, বিশ্বাসভাজন।’’\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mdcli{তিনি বললেন -- ''আমাকে দেশের ধনসম্পদের দায়িত্বে নিয়োগ করুন। নিঃসন্দেহ আমি সুরক্ষক, সুবিবেচক।’’\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mdclii{আর এইভাবে আমরা ইউসুফকে প্রতিষ্ঠিত করলাম দেশে, -- সেখানে তিনি কর্তৃত্ব চালাতেন যেখানে তিনি চাইতেন। আমরা যাকে ইচ্ছা করি আমাদের করুণাদ্বারা হিতসাধন করি, আর সৎকর্মশীলদের কর্মফল আমরা ব্যর্থ করি না।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mdcliii{আর অবশ্যই পরকালের পুরস্কার আরো ভালো তাদের জন্য যারা বিশ্বাস করে এবং ভয়-ভক্তি অবলন্বন করে।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mdcliv{আর ইউসুফের ভাইয়েরা এল এবং তাঁর দরবারে প্রবেশ করল, তিনি তখন তাদের চিনতে পারলেন, কিন্তু তারা তাঁর সন্বন্ধে অজ্ঞাত রইল।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mdclv{আর তিনি যখন তাদের পরিবেশন করলেন তাদের রসদের দ্বারা তখন তিনি বললেন, ''তোমরা তোমাদের পিতার তরফের তোমাদের ভাইকে আমার কাছে নিয়ে এস। তোমরা কি দেখো নি যে আমি আলবৎ পুরো মাপ দিই এবং আমি ভাল আপ্যায়ণকারী।\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mdclvi{''কিন্তু তোমরা যদি তাকে আমার কাছে না আনো তবে তোমাদের জন্য আমার নিকট থেকে কোনো পরিমাপ থাকবে না, এবং তোমরা আমার নিকটবর্তী হয়ো না।’’\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mdclvii{তারা বললে -- ''আমরা আলবৎ চেষ্টা করব তার সন্বন্ধে তার পিতার কাছে এবং আমরা নিশ্চয়ই কাজ করব।’’\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mdclviii{আর তিনি তাঁর জোয়ানদের বললেন -- ''তাদের দ্রব্যমূল্য তাদের মালপত্রের ভিতরে রেখে দাও যেন তাদের পরিবারবর্গের কাছে যখন তারা ফিরে যাবে তখন তারা এটা চিনতে পারে, তাহলে তারা ফিরে আসবে।’’\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mdclix{তারপর তারা যখন তাদের পিতার কাছে ফিরে এল তখন তারা বললে -- ''হে আমাদের আব্বা! আমাদের কাছে পরিমাপ নিষেধ করা হয়েছে, অতএব আমাদের সঙ্গে আমাদের ভাইকেও পাঠিয়ে দাও যেন আমরা পরিমাপ পেতে পারি, আর আমরা তো অবশ্যই তার হেফাজতকারী।’’\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mdclx{তিনি বললেন -- ''তোমাদের কি তার সন্বন্ধে বিশ্বাস করতে পারি যেভাবে তার ভাইয়ের ব্যাপারে এর আগে তোমাদের আমি বিশ্বাস করেছিলাম? বস্তুতঃ আল্লাহ্‌ই রক্ষণাবেক্ষণে সর্বশ্রেষ্ঠ, আর তিনিই ফলদানকারীদের মধ্যে শ্রেষ্ঠ ফলদাতা।’’\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mdclxi{আর যখন তারা তাদের জিনিসপত্র খুললো তারা দেখতে পেল তাদের দ্রব্যমূল্য তাদের কাছে ফিরিয়ে দেয়া হয়েছে। তারা বললে -- ''হে আমাদের আব্বা! কী আমরা প্রত্যাশা করি? এই তো আমাদের দ্রব্যমূল্য আমাদের ফিরিয়ে দেয়া হয়েছে, আর আমাদের পরিজনবর্গের জন্য আমরা রসদ আনতে পারব, আর আমাদের ভাইয়ের আমরা হেফাজত করব, আর আমরা এক উটের পরিমাপ অতিরিক্ত আনব। এটি তো এক সামান্য পরিমাপ।’’\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mdclxii{তিনি বললেন -- ''আমি তাকে কিছুতেই তোমাদের সাথে পাঠাব না যতক্ষণ না তোমরা আমার কাছে আল্লাহ্‌র নামে ওয়াদা কর যে তোমরা নিশ্চয় আমার কাছে তাকে ফিরিয়ে আনবে, যদি না তোমরা একান্ত অসহায় হও।’’ অতএব তারা যখন তাঁকে তাদের প্রতি‌শ্রুতি দিল তখন তিনি বললেন -- ''আমরা যা বলছি তার উপরে আল্লাহ্‌ই কর্ণধার।’’\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mdclxiii{তিনি আরো বললেন, ''হে আমার পুত্রগণ! তোমরা একই দরজা দিয়ে ঢুকো না, বরং তোমরা ভিন্ন ভিন্ন দরজা দিয়ে ঢুকবে। আল্লাহ্‌র বিরুদ্ধে তোমাদের জন্যে আমার কিছুই করার ক্ষমতা নেই। বিধান তো একমাত্র আল্লাহ্‌র বৈ তো নয়। তাঁর উপরেই আমি নির্ভর করি, আর তাঁরই উপরে তবে নির্ভর করুক নির্ভরশীলগণ।’’\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mdclxiv{আর তারা যখন ঢুকল যেভাবে তাদের পিতা তাদের আদেশ করেছিলেন, তখন আল্লাহ্‌র বিরুদ্ধে তাদের কিছুই করার সামর্থ্য ছিল না, কিন্তু এটি ইয়াকুবের অন্তরের একটি বাসনা যা তিনি চরিতার্থ করেছিলেন। আর নিঃসন্দেহ তিনি অবশ্যই ছিলেন জ্ঞানের অধিকারী যেহেতু আমরা তাঁকে জ্ঞানদান করেছিলাম, কিন্তু অধিকাংশ লোকেই জানে না।\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mdclxv{আর তারা যখন ইউসুফের দরবারে প্রবেশ করল তাঁর ভাইকে তিনি নিজের সঙ্গে রাখলেন, তিনি বললেন -- ''আমিই তোমার ভাই, সুতরাং তারা যা করে তাতে দুঃখ করো না।’’\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mdclxvi{তারপর তিনি যখন তাদের পরিবেশন করলেন তাদের রসদের দ্বারা, তখন তাঁর ভাইয়ের মালপত্রের ভিতরে একটি পানপাত্র কেউ রেখে দিল। তারপর একজন আহবায়ক চিৎকার ক’রে বলল -- ''ওহে উট-চালকের দল! তোমরা নিশ্চয়ই চোর।’’\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@mdclxvii{তারা তাদের নিকটে এসে বললে -- ''কি জিনিস তোমরা হারিয়েছ?’’\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@mdclxviii{তারা বললে -- ''আমরা রাজার পানপাত্র হারিয়েছি, আর যে এটি নিয়ে আসবে এক উট-বোঝাই মাল, আর আমি এরজন্যে জামিন।’’\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@mdclxix{তারা বললে -- ''আল্লাহ্‌র কসম! তোমরা নিশ্চয়ই জান যে আমরা এদেশে দুস্কর্ম করতে আসি নি, আর আমরা চোরও নই।’’\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@mdclxx{তারা বললে -- ''তবে কি হবে এর প্রতিফল যদি তোমরা হচ্ছ মিথ্যাবাদী?’’\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@mdclxxi{তারা বললে -- ''এর প্রতিফল হবে -- যার মালপত্রের মধ্যে এটি পাওয়া যাবে সেই হবে এর প্রতিফলের পাত্র। এইভাবেই আমরা অন্যায়কারীদের শাস্তি দিই।’’\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@mdclxxii{অতঃপর তিনি তাদের মালপত্রে আর করলেন তাঁর ভাইয়ের মালের আগে, তারপর তিনি তা বের করলেন তাঁর ভাইয়ের মালপত্র থেকে। এইভাবেই আমরা ইউসুফের জন্য পরিকল্পনা করেছিলাম। তাঁর পক্ষে রাজার আইন অনুসারে তাঁর ভাইকে রাখা সম্ভব ছিল না যদি না আল্লাহ্ ইচ্ছা করতেন। আমরা যাকে ইচ্ছা করি স্তরে স্তরে উন্নত করি। আর প্রত্যেক জ্ঞানবানদের উপরে রয়েছেন সর্বজ্ঞানময়।\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@mdclxxiii{তারা বললে -- ''যদি সে চুরি করে থাকে তার ভাইও তো এর আগে চুরি করেছিল।’’ তখন ইউসুফ এটি নিজের অন্তরেই গোপন রেখেছিলেন এবং তিনি তা তাদের কাছে প্রকাশ করেন নি। তিনি বললেন -- ''তোমরা আরও হীন অবস্থাতে রয়েছ, আর আল্লাহ্ ভাল জানেন তোমরা যা আরোপ করছ সে-সন্বন্ধে।’’\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@mdclxxiv{ওরা বললে -- ''ওহে প্রধান! এর পিতা আছেন, অত্যন্ত বুড়ো মানুষ, অতএব তার জায়গায় আমাদের একজনকে রেখে নিন, যেহেতু আমরা আপনাকে দেখছি মহানুভবদের মধ্যেকার।’’\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@mdclxxv{তিনি বললেন -- ''আল্লাহ্ রক্ষা করুন যে আমরা যার কাছে আমাদের জিনিস পেয়েছি তাকে ছাড়া অন্যকে ধরে রাখি, কেননা সে ক্ষেত্রে আমরা অবশ্যই অন্যায়কারী হব!’’\qt@no{(79)}}
\qt@newcmd\qurantrans@bn@mdclxxvi{যখন তারা তাঁর কাছ থেকে হতাশ হল তখন তারা পরামর্শের জন্যে আলদা হল। তাদের বড়জন বললে -- ''তোমরা কি জান না যে তোমাদের আব্বা তোমাদের কাছ থেকে আল্লাহ্‌র নামে অংগীকার নিয়েছেন, আর এর আগে ইউসুফের ব্যাপারেও তোমরা কি রকম ত্রুটি করেছিলে? কাজেই আমি কিছুতেই এ দেশ ছেড়ে যাব না যে পর্যন্ত না আমার আব্বা আমাকে অনুমতি দেন, অথবা আল্লাহ্ আমার জন্য কোনো হুকুম দেন, কেননা তিনিই হাকিমগণের মধ্যে সর্বশ্রেষ্ঠ।\qt@no{(80)}}
\qt@newcmd\qurantrans@bn@mdclxxvii{''তোমরা তোমাদের আব্বার কাছে ফিরে যাও এবং বলো -- ''হে আমাদের আব্বা! নিঃসন্দেহ তোমার ছেলে চুরি করেছে, আর আমরা যা জানি তা ছাড়া অন্য প্রত্যক্ষ বিবরণ দিচ্ছি না, আর অদৃশ্যের ব্যাপারে আমরা কিছুই জানি না।\qt@no{(81)}}
\qt@newcmd\qurantrans@bn@mdclxxviii{''আর আমরা যেখানে ছিলাম সেই শহরবাসীদের জিজ্ঞাসা কর, আর যাদের সঙ্গে আমরা এসেছি সেই যাত্রীদলকেও। আর আমরা তো অবশ্যই সত্যবাদী।’’\qt@no{(82)}}
\qt@newcmd\qurantrans@bn@mdclxxix{তিনি বললেন -- ''না এ, বরং তোমাদের অন্তর তোমাদের জন্য ও বিষয়টি উদ্ভাবন করেছে, কিন্তু ধৈর্যধারণই উত্তম। হতে পারে আল্লাহ্ ওদের সবাইকে আমার কাছে এনে দেবেন। নিঃসন্দেহ তিনিই সর্বজ্ঞাতা, পরমজ্ঞানী।’’\qt@no{(83)}}
\qt@newcmd\qurantrans@bn@mdclxxx{আর তিনি তাদের থেকে ফিরলেন ও বললেন -- ''হায় আমার আফসোস ইউসুফের জন্য!’’ আর তাঁর চোখ সাদা হয়ে গিয়েছিল শোকাবেগ বশতঃ, যদিও তিনি সংবরণকারী ছিলেন।\qt@no{(84)}}
\qt@newcmd\qurantrans@bn@mdclxxxi{তারা বললে, ''দোহাই আল্লাহ্‌র! তুমি ইউসুফকে স্মরণ করা ছাড়বে না যে পর্যন্ত না তুমি রোগাক্রান্ত হও, অথবা প্রাণত্যাগী হয়ে যাও।’’\qt@no{(85)}}
\qt@newcmd\qurantrans@bn@mdclxxxii{তিনি বললেন -- ''আমার অসহনীয় দুঃখ ও আমার বেদনা নিবেদন করছি আল্লাহ্‌রই কাছে, আর আমি আল্লাহ্‌র তরফ থেকে জানি যা তোমরা জান না।\qt@no{(86)}}
\qt@newcmd\qurantrans@bn@mdclxxxiii{''হে আমার ছেলেরা! তোমরা যাও এবং ইউসুফ ও তার ভাইয়ের খোঁজ কর, আর আল্লাহ্‌র আশিস সন্বন্ধে নিরাশ হয়ো না। নিঃসন্দেহ অবিশ্বাসী লোকেরা ছাড়া অন্য কেউ আল্লাহ্‌র আশিস সন্বন্ধে নিরাশ হয় না।’’\qt@no{(87)}}
\qt@newcmd\qurantrans@bn@mdclxxxiv{তারপর তারা যখন তাঁর দরবারে দাখিল হল তখন বলল -- ''ওহে প্রধান! আমাদের ও আমাদের পরিবার-পরিজনের উপরে দুর্দিন এসে পড়েছে, আর আমরা সামান্য দ্রব্যমূল্য নিয়ে এসেছি, সেজন্যে আমাদের পূর্ণমাত্রায় দিন এবং আমাদের প্রতি দানখয়রাত করুন। নিঃসন্দেহ আল্লাহ্ দানশীলদের পুরস্কার দিয়ে থাকেন।’’\qt@no{(88)}}
\qt@newcmd\qurantrans@bn@mdclxxxv{তিনি বললেন -- ''তোমরা কি জানো ইউসুফ ও তার ভাইয়ের প্রতি তোমরা কি করেছিলে যখন তোমরা ছিলে বিবেচনাহীন?’’\qt@no{(89)}}
\qt@newcmd\qurantrans@bn@mdclxxxvi{তারা বললে -- ''আপনিই কি তবে ইউসুফ?’’ তিনি বললে -- ''আমিই ইউসুফ আর এই আমার সহোদর। আল্লাহ্ আলবৎ আমাদের প্রতি অনুগ্রহ করেছেন। নিঃসন্দেহ যে কেউ ধর্মপরায়ণতা অবলন্বন করে ও ধৈর্যধারণ করে -- কেননা আল্লাহ্ নিশ্চয়ই সৎকর্মশীলদের কর্মফল বিফল করেন না।’’\qt@no{(90)}}
\qt@newcmd\qurantrans@bn@mdclxxxvii{তারা বললে, ''আল্লাহ্‌র কসম! আল্লাহ্ অবশ্যই আমাদের উপরে তোমাকে প্রাধান্য দিয়েছেন, আর আমরা নিশ্চয় পাপী ছিলাম।’’\qt@no{(91)}}
\qt@newcmd\qurantrans@bn@mdclxxxviii{তিনি বললেন -- ''তোমাদের বিরুদ্ধে আজ কোনো অভিযোগ নয়। আল্লাহ্ তোমাদের ক্ষমা করুন, আর তিনিই তো ফলদান- কারীদের মধ্যে শ্রেষ্ঠ ফলদাতা।’’\qt@no{(92)}}
\qt@newcmd\qurantrans@bn@mdclxxxix{''আমার এই জামাটি নিয়ে যাও এবং এটি আমার আব্বার মুখের সামনে রেখো, তিনি চক্ষুষ্মান হবেন। আর তোমাদের পরিবার- পরিজনদের সকলকে নিয়ে আমার কাছে এস।’’\qt@no{(93)}}
\qt@newcmd\qurantrans@bn@mdcxc{আর যখন যাত্রীদল বেরিয়ে পড়ল তখন তাদের পিতা লোকজনকে বললেন, ''নিঃসন্দেহ আমি আলবৎ ইউসুফের হাওয়া-বাতাস টের পাচ্ছি, যদিও তোমরা আমাকে মতিচ্ছন্ন মনে কর।’’\qt@no{(94)}}
\qt@newcmd\qurantrans@bn@mdcxci{তারা বললে -- ''আল্লাহ্‌র কসম! আপনি নিঃসন্দেহ আপনার পুরনো ভ্রান্তিতেই রয়েছেন।’’\qt@no{(95)}}
\qt@newcmd\qurantrans@bn@mdcxcii{তারপর যখন সুসংবাদবাহক এল, সে সেটি তাঁর মুখের সামনে রাখল, তখন তিনি চক্ষুষ্মান হলেন। তিনি বললেন -- ''আমি কি তোমাদের বলি নি যে আমি আল্লাহ্‌র কাছ থেকে জানি যা তোমরা জান না?’’\qt@no{(96)}}
\qt@newcmd\qurantrans@bn@mdcxciii{তারা বললে -- ''হে আমাদের আব্বা! আমাদের অপরাধের জন্যে আমাদের তরফ থেকে ক্ষমা প্রার্থনা করো, নিঃসন্দেহ আমরা হচ্ছি দোষী।’’\qt@no{(97)}}
\qt@newcmd\qurantrans@bn@mdcxciv{তিনি বললেন -- ''আমি শীঘ্রই তোমাদের জন্য আমার প্রভুর কাছে মার্জনা চাইব। নিঃসন্দেহ তিনি নিজেই পরিত্রাণকারী, অফুরন্ত ফলদাতা।’’\qt@no{(98)}}
\qt@newcmd\qurantrans@bn@mdcxcv{তারপর তাঁরা যখন ইউসুফের দরবারে দাখিল হলেন তখন তিনি তাঁর পিতামাতাকে নিজের সঙ্গে রাখলেন এবং বললেন -- ''ইন- শা-আল্লাহ্ মিশরে নির্বিঘ্নে প্রবেশ করুন।’’\qt@no{(99)}}
\qt@newcmd\qurantrans@bn@mdcxcvi{আর তিনি তাঁর পিতামাতাকে উচ্চাসনে বসালেন, আর তাঁর কারণে তাঁরা সিজদারত হলেন। তখন তিনি বললেন, ''হে আমার আব্বা! এটিই আমার পূর্বেকার দৈবদর্শনের তাৎপর্য, আমার প্রভু তা সত্যে পরিণত করেছেন। আর তিনি আমার প্রতি অনুগ্রহ করেছিলেন যখন তিনি আমাকে কারাগার থেকে মুক্ত করেছিলেন, এবং মরুভূমি থেকে আপনাদের নিয়ে এসেছেন আমার মধ্যে ও আমার ভাইয়ের মধ্যে শয়তান বিরোধ বাধাবার পরে। নিঃসন্দেহ আমার প্রভু যাকে ইচ্ছা করেন তার প্রতি পরম সদাশয়। নিঃসন্দেহ তিনি নিজেই সর্বজ্ঞাতা, পরমজ্ঞানী।\qt@no{(100)}}
\qt@newcmd\qurantrans@bn@mdcxcvii{''আমার প্রভু! তুমি ইতিমধ্যেই আমাকে রাজত্বের অধিকার প্রদান করেছ এবং ঘটনাবলীর তাৎপর্য সম্পর্কে আমাকে শিক্ষাদান করেছ, হে মহাকাশমন্ডলী ও পৃথিবীর আদি-স্রষ্টা! তুমিই এই দুনিয়া ও আখেরাতে আমার মনিব, আমাকে মুসলিম অবস্থায় মরতে দাও এবং আমাকে সৎকর্মীদের সঙ্গে সংযুক্ত করো।’’\qt@no{(101)}}
\qt@newcmd\qurantrans@bn@mdcxcviii{এই হচ্ছে অদৃশ্য ব্যাপারের সংবাদ যা আমরা তোমার কাছে প্রত্যাদেশ করছি। আর তুমি তাদের সঙ্গে ছিলে না যখন তারা তাদের ব্যাপার-স্যাপার গুটাচ্ছিল ও তারা ফন্দি আটঁছিল।\qt@no{(102)}}
\qt@newcmd\qurantrans@bn@mdcxcix{আর যদিও তুমি একান্তভাবে চাও তথাপি অধিকাংশ লোকেই বিশ্বাসকারী নয়।\qt@no{(103)}}
\qt@newcmd\qurantrans@bn@mdcc{আর তুমি এর জন্য তাদের কাছে কোনো পারিশ্রমিক চাইছ না। এ তো বিশ্বজগতের জন্য উপদেশ ব্যতীত নয়।\qt@no{(104)}}
\qt@newcmd\qurantrans@bn@mdcci{আর মহাকাশমন্ডলে ও পৃথিবীতে কত না নিদর্শন রয়েছে যার পাশ দিয়ে তারা যাতায়ত করে, তথাপি তারা এ-সবের প্রতি উদাসীন!\qt@no{(105)}}
\qt@newcmd\qurantrans@bn@mdccii{আর তাদের অধিকাংশই আল্লাহ্‌র প্রতি বিশ্বাস করে না তারা বহুখোদাবাদী না হওয়া পর্যন্ত।\qt@no{(106)}}
\qt@newcmd\qurantrans@bn@mdcciii{তারা কি তবে নিরাপদ বোধ করে তাদের উপরে আল্লাহ্‌র শাস্তির ঘেরাটোপ এসে পড়া সন্বন্ধে, অথবা তারা যখন বেখেয়াল থাকে তখন ঘন্টা অতর্কিতে তাদের উপরে এসে পড়া সন্বন্ধে?\qt@no{(107)}}
\qt@newcmd\qurantrans@bn@mdcciv{তুমি বল -- ''এই হচ্ছে আমার পথ, আমি আল্লাহ্‌র প্রতি আহ্বান করি, আমি ও যারা আমাকে অনুসরণ করে তারা জ্ঞানালোকের উপরে রয়েছি। আর আল্লাহ্‌রই সব মহিমা, আর আমি বহুখোদাবাদীদের মধ্যেকার নই।’’\qt@no{(108)}}
\qt@newcmd\qurantrans@bn@mdccv{আর তোমার পূর্বে জনপদবাসীদের মধ্যে থেকে মানুষ ছাড়া অন্য কাউকে আমরা পাঠাই নি যাঁদের কাছে আমরা প্রত্যাদেশ দিয়েছিলাম। কাজেই তারা কি পৃথিবীতে পর্যটন করে নি এবং দেখে নি কেমন হয়েছিল তাদের পরিণাম যারা ছিল তাদের অগ্রগামী? আর পরকালের আবাসস্থল অবশ্যই অধিকতর ভাল তাদের জন্য যারা ধর্মভীরুতা অবলন্বন করে। তোমরা কি তবে বোঝ না?\qt@no{(109)}}
\qt@newcmd\qurantrans@bn@mdccvi{অবশেষে যখন রসূলগণ হতাশ হয়েছিলেন, আর তারা ভেবেছিল যে তাদের নিশ্চয়ই মিথ্যা বলা হয়েছে, তখনই এসে পৌঁছাল। কাজেই যাদের আমরা ইচ্ছা করলাম তাদের উদ্ধার করলাম। আর অপরাধী সম্প্রদায় থেকে আমাদের শাস্তি প্রতিহত হয় না।\qt@no{(110)}}
\qt@newcmd\qurantrans@bn@mdccvii{তাদের কাহিনীর মধ্যে অবশ্যই শিক্ষণীয় বিষয় রয়েছে বোধশক্তিসম্পন্নদের জন্যে। এ এমন কাহিনী নয় যা জাল করা হয়েছে, বরঞ্চ এ হচ্ছে এর আগে যা এসেছিল তার সমর্থনকারী, এবং সব বিষয়ের বিস্তারিত বৃত্তান্ত, আর পথনির্দেশ ও করুণা যারা বিশ্বাস করে সেই সম্প্রদায়ের জন্য।\qt@no{(111)}}
\qt@newcmd\qurantrans@bn@mdccviii{\basmalahbn আলিফ, লাম, মীম, রা। এসব হচ্ছে গ্রন্থখানার আয়াতসমূহ। আর যা তোমার প্রভুর কাছ থেকে তোমার নিকট অবতীর্ণ হয়েছে তা পরমসত্য, কিন্তু অধিকাংশ লোক বিশ্বাস করে না।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mdccix{আল্লাহ্‌ই তিনি যিনি মহাকাশমন্ডলকে ঊর্ধ্বে স্থাপন করেছেন কোনো স্তম্ভ ছাড়া -- তোমরা তো এ দেখছ, আর তিনি আরশে সমাসীন হলেন, আর তিনি সূর্য ও চন্দ্রকে অনুগত করলেন। প্রত্যেকে আবর্তন করছে একটি নির্দিষ্ট কক্ষপথে। তিনিই ব্যাপার নিয়ন্ত্রণ করেন, বিশদভাবে বর্ণনা করেন নির্দেশাবলী, যেন তোমরা তোমাদের প্রভুর সঙ্গে সাক্ষাৎকার সন্বন্ধে নিশ্চিত বিশ্বাস করতে পার।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mdccx{আর তিনিই সেইজন যিনি পৃথিবীকে বিস্তৃত করেছেন, আর তাতে স্থাপন করেছেন পর্বতমালা ও নদনদী। আর প্রত্যেক ফলের ক্ষেত্রে -- তার মধ্যে তিনি সৃষ্টি করেছেন জোড়ায়-জোড়ায় দুটি-দুটি। তিনি রাত্রিকে দিয়ে দিনকে আবৃত করেন। নিঃসন্দেহ এতে সাক্ষাৎ নিদর্শন রয়েছে সেই লোকদের জন্য যারা চিন্তা করে।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mdccxi{আর পৃথিবীতে আছে পাশাপাশি মাঠ, আর আঙুরের বাগান ও শস্যক্ষেত্র ও খেজুরের গাছ -- ভিড় ক’রে ও ভিড় না ক’রে -- ওদের পানি দেওয়া হয় একই পানি। আর তাদের কতকটাকে কতকটার উপরে প্রাধান্য দিয়েছি আস্বাদনের ক্ষেত্রে। নিঃসন্দেহ এতে বিশিষ্ট নিদর্শন রয়েছে সেইসব লোকের জন্য যারা বুদ্ধি-বিবেচনা প্রয়োগ করে।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mdccxii{আর যদি তুমি তাজ্জব হও তবে আজব ব্যাপার হচ্ছে তাদের কথা -- ''কী, আমরা যখন ধুলো হয়ে যাব তখন কি আমরা বাস্তবিকই নতুন জীবন লাভ করব?’’ এরাই তারা যারা তাদের প্রভুর প্রতি অবিশ্বাস পোষণ করে, আর এরাই -- এদের গলায় থাকবে শিকল, আর এরাই হবে আগুনের বাসিন্দা, তাতে তারা করবে অবস্থান।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mdccxiii{আর ওরা তোমাকে ভালর আগেই মন্দকে ত্বরান্বিত করতে বলে, যদিও ওদের পূর্বে বহু লক্ষণীয় শাস্তি গত হয়েছে। আর নিঃসন্দেহ তোমার প্রভু লোকদের জন্য তাদের অন্যায়াচরণ সত্ত্বেও ক্ষমার অধিকারী, আর নিঃসন্দেহ তোমার প্রভু প্রতিফল দানে অতি কঠোর।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mdccxiv{আর যারা অবিশ্বাস পোষণ করে তারা বলে -- ''কেন তাঁর কাছে তাঁর প্রভুর কাছ থকে কোনো নিদর্শন প্রেরিত হয় না?’’ তুমি তো একজন সতর্ককারী মাত্র, এবং সকল জাতির জন্যে একজন পথপ্রদর্শক।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mdccxv{আল্লাহ্ জানেন প্রত্যেক স্ত্রীলোক যা গর্ভে ধারণ করে, আর যা জরায়ূ শুষে নেয়, আর যা তারা বর্ধিত করে। আর তাঁর কাছে প্রত্যেক বস্তুরই এক নির্দিষ্ট পরিমাপ রয়েছে।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mdccxvi{তিনি অদৃশ্য ও দৃশ্য বিষয়ে জ্ঞাতা -- মহামহিম, চিরউন্নত।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mdccxvii{একসমান তোমাদের মধ্যে যে কথা লুকোয় ও যে তা খুলে বলে, আর যে রাত্রিবেলায় আ‌ত্মগোপন করে আর দিনের বেলায় বিচরণ করে।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mdccxviii{তাঁর জন্য প্রহরী রয়েছে তাঁর সম্মুখভাগে ও তাঁর পশ্চাদভাগে, ওরা তাঁকে রক্ষণাবেক্ষণ করে আল্লাহ্‌র আদেশক্রমে। আল্লাহ্ অবশ্যই কোনো জাতির অবস্থায় পরিবর্তন করেন না যতক্ষণ না তারা নিজেরাই তা পরিবর্তন করে। আর যখন আল্লাহ্ কোনো জাতির জন্য অকল্যাণ চান তখন তা রদ করার উপায় নেই, আর তাদের জন্য তিনি ছাড়া কোনো অভিভাবক নেই।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mdccxix{তিনিই সেইজন যিনি তোমাদের দেখান বিদ্যুৎ ভয়উদ্দীপক এবং আশাসঞ্চারক, আর তিনি নিয়ে আসেন ভারী মেঘ।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mdccxx{আর বজ্র-নিনাদ মহিমা ঘোষণা করে তাঁর প্রশংসার সাথে, আর ফিরিশ্‌তারাও তাঁর ভয়ে, আর তিনি বজ্রপাত প্রেরণ করেন, আর তা দিয়ে আঘাত করেন যাকে তিনি ইচ্ছা করেন, তবু তারা আল্লাহ্‌র সন্বন্ধে তর্কাতর্কি করে, যদিও তিনি ক্ষমতায় কঠোর।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mdccxxi{সত্যিকারের প্রার্থনা তাঁরই জন্য। আর তাঁকে ছেড়ে দিয়ে তারা যাদের কাছে প্রার্থনা জানায় তারা তাদের প্রতি কোনো প্রকারের সাড়া দেয় না, তবে যেন সে তার দুই হাত পানির দিকে বাড়িয়ে দিয়েছে যাতে তা তার মুখে পৌঁছুতে পারে, কিন্তু তা তাতে পৌঁছুবে না। বস্তুতঃ অবিশ্বাসীদের প্রার্থনা ভ্রান্তিতে ভিন্ন নয়।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mdccxxii{আর আল্লাহ্‌কেই সিজদা করে যারাই আছে মহাকাশ-মন্ডলে ও পৃথিবীতে -- স্বেচ্ছায় অথবা অনিচ্ছায়, আর তাদের ছায়াও সকালে ও সন্ধ্যায়।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mdccxxiii{বলো -- ''কে মহাকাশমন্ডল ও পৃথিবীর প্রভু?’’ বল -- ''আল্লাহ্‌।’’ বল, ''তবে কি তোমরা তাঁকে ছেড়ে দিয়ে অভিভাবক-রূপে গ্রহণ কর তাদের যারা তাদের নিজেদের জন্যে কোনো লাভ কামাতে সক্ষম নয় আর ক্ষতিসাধনেও নয়?’’ বলো -- ''অন্ধ ও চক্ষুষ্মান কি এক-সমান অথবা অন্ধকার আর আলোক কি সমান-সমান? অথবা তারা কি আল্লাহ্‌র এমন অংশী দাঁড় করিয়েছে যারা তাঁর সৃষ্টির মত সৃষ্টি করেছে, যার ফলে সৃষ্টি তাদের কাছে সন্দেহ ঘটিয়েছে?’’ বল -- ''আল্লাহ্‌ই সব-কিছুর সৃষ্টিকর্তা, আর তিনি একক, সর্বাধিনায়ক।’’\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mdccxxiv{তিনি আকাশ থেকে পানি অবতারণ করেন, তারপর জলধারা প্রবাহিত হয় তাদের পরিমাপ অনুসারে, আর খরস্রোত বয়ে নিয়ে যায় ফেঁপে ওঠা ফেনার রাশি। আর যা তারা আগুনে গলায় গহনাগাটি বা যন্ত্রপাতি নির্মাণের উদ্দেশ্যে তা থেকেও ওঠে ওর মতো ফেনায়িত গাদ। এইভাবে আল্লাহ্ সত্য ও মিথ্যার দৃষ্টান্ত দিয়ে থাকেন। কাজেই যা কিছু গাদ -- তা চলে যায় জালরূপে, আর যা মানুষের উপকারে আসে তা কিন্তু থেকে যায় পৃথিবীতে। এইভাবে আল্লাহ্ উপমা দিয়ে থাকেন।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mdccxxv{যারা তাদের প্রভুর প্রতি সাড়া দেয় তাদের জন্য রয়েছে কল্যাণ, আর যারা তাঁর প্রতি সাড়া দেয় না -- তাদের যদি থাকত পৃথিবীতে যা-কিছু আছে সবটাই ও সেই সঙ্গে তার সমপরিমাণ, তবে তারা নিশ্চয়ই তা মুক্তিপণরূপে অর্পণ করতো। এরাই -- এদের জন্য হবে মন্দ হিসাব, আর তাদের আবাস হবে জাহান্নাম, আর তা বড় নিকৃষ্ট বাসস্থান।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mdccxxvi{যেজন জানে যে তোমার প্রভুর কাছ থেকে তোমার নিকট যা অবতীর্ণ হয়েছে তা সত্য সে কি তার মতো যে অন্ধ? নিঃসন্দেহ বোধশক্তিসম্পন্ন লোকেরাই কেবল স্মরণ করবে, --\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mdccxxvii{যারা আল্লাহ্‌র অংগীকার রক্ষা করে ও প্রতিজ্ঞা ভঙ্গ করে না,\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mdccxxviii{আর যারা সংযুক্ত রাখে যা অক্ষুন্ন রাখতে আল্লাহ্ আদেশ করেছেন, আর যারা তাদের প্রভুকে ভয় করে, আর যারা ভয় করে মন্দ হিসাব সন্বন্ধে।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mdccxxix{আর যারা তাদের প্রভুর সন্তষ্টিলাভের অন্বেষণে অধ্যবসায় অবলন্বন করে, আর নামায কায়েম রাখে, আর আমরা তাদের যা জীবনোপকরণ দিয়েছি তা থেকে যারা গোপনে ও প্রকাশ্যে ব্যয় করে, আর ভাল দিয়ে মন্দকে দূর করে, -- এরাই তারা যাদের জন্য রয়েছে চরমোৎকর্ষ আবাস, --\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mdccxxx{নন্দন কানন যাতে তারা প্রবেশ করবে, আর তাদের পিতামাতাদের ও তাদের পতিপত্নীদের ও তাদের সন্তানসন্ততি দের মধ্যে যারা সৎকর্ম করেছে, আর ফিরিশ্‌তাগণ তাদের সামনে প্রবেশ করবে প্রত্যেক দরজা দিয়ে, --\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mdccxxxi{''শান্তি বর্ষিত হোক তোমাদের উপরে যেহেতু তোমরা অধ্যবসায় অবলন্বন করেছিলে, কাজেই কত ভাল এই চরমোৎকর্ষ আবাস!’’\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mdccxxxii{আর যারা আল্লাহ্‌র সাথের অংগীকার ভঙ্গ করে সেটির সুদৃঢ়ীকরণের পরে, আর ছিন্ন করে যা অক্ষুন্ন রাখতে আল্লাহ্ আদেশ করেছেন, আর পৃথিবীতে অশান্তি সৃষ্টি করে, এরাই -- এদের জন্যেই রয়েছে ধিক্কার, আর এদেরই জন্যে আছে নিকৃষ্ট আবাস।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mdccxxxiii{আল্লাহ্ জীবিকা বাড়িয়ে দেন যাকে তিনি ইচ্ছে করেন, আর তিনি মাপজোখ করেন। আর তারা পার্থিব জীবনে উল্লসিত। অথচ ইহকালের জীবনটা তো পরকালের তুলনায় যৎসামান্য সুখ-ভোগ বৈ নয়।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mdccxxxiv{আর যারা অবিশ্বাস পোষণ করে তারা বলে -- ''কেন তাঁর কাছে তাঁর প্রভুর কাছ থেকে একটি নিদর্শন অবতীর্ণ হয় না?’’ বলো -- ''নিঃসন্দেহ আল্লাহ্ ভ্রান্তপথে যেতে দেন যাকে তিনি ইচ্ছে করেন, আর তাঁর দিকে পরিচালিত করেন যে ফেরে;\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mdccxxxv{''যারা আস্থা স্থাপন করেছে আর আল্লাহ্‌র গুণকীর্তনে যাদের হৃদয় প্রশান্ত হয়।’’ এটি কি নয় যে আল্লাহ্‌র গুণগানেই হৃদয় প্রশান্তি লাভ করে?\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mdccxxxvi{যারা ঈমান এনেছে ও সৎকর্ম করছে তাদেরই জন্য পরম সুখ ও শুভ পরিণাম।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mdccxxxvii{এইভাবে তোমাকে আমরা পাঠিয়েছি একটি জাতির মধ্যে যার পূর্বে বহু জাতি গত হয়ে গেছে, যেন তুমি তাদের কাছে পাঠ করতে পার যা আমরা তোমার কাছে প্রত্যাদেশ করছি, তথাপি তারা অবিশ্বাস করে পরম করুণাময়ের প্রতি! বল -- ''তিনিই আমার প্রভু, তিনি ছাড়া অন্য উপাস্য নেই, তাঁরই উপরে আমি নির্ভর করি আর তাঁর কাছেই আমার প্রত্যাবর্তন।’’\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mdccxxxviii{আর যদি এমন একখানা কুরআন থাকত যার দ্বারা পাহাড়গুলো হটিয়ে দেয়া যেতো, অথবা তার দ্বারা পৃথিবীকে ছিন্নভিন্ন করা যেতো, অথবা মৃতকে তার দ্বারা কথা বলানো যেতো। বস্তুতঃ হুকুম পুরোপুরি আল্লাহ্‌র। যারা বিশ্বাস করেছে তারা কি জানে না যে, যদি আল্লাহ্ তেমন ইচ্ছে করতেন তবে সব মানুষকে একই সাথে সৎপথে চালিত করতেন? আর যারা অবিশ্বাস পোষণ করে তারা যা করে সেজন্য তাদের উপরে বিপর্যয় আঘাত হানতে ক্ষান্ত হবে না, অথবা এটি তাদের বাড়িঘরের নিকটেই আপতিত হতে থাকবে, যে পর্যন্ত না আল্লাহ্‌র ওয়াদা সমাগত হয়। আল্লাহ্ আলবৎ ওয়াদা খেলাপ করেন না।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mdccxxxix{আর নিশ্চয়ই তোমার পূর্বে রসূলগণকে ঠাট্টাবিদ্রূপ করা হয়েছিল, সুতরাং যারা অবিশ্বাস করেছিল তাদের আমি অবকাশ দিয়েছিলাম, তারপর আমি তাদের পাকড়াও করেছিলাম, কাজেই কেমন ছিল আমার প্রতিফলদান!\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mdccxl{তবে কি প্রত্যেক সত্ত্বা কি অর্জন করছে তাতে যিনি অধিষ্ঠিত রয়েছেন? তথাপি তারা আল্লাহ্‌র সাথে অংশী দাঁড় করায়! তুমি বল -- ''ওদের নাম দাও।’’ তবে কি তোমরা তাঁকে জানাতে চাও পৃথিবীতে এমন কিছু বিষয় যা তিনি জানেন না? না এটি বাহ্যতঃ একটি কথা মাত্র? না, ওদের ছলা-কলা চিত্তাকর্ষক মনে হয় তাদের কাছে যারা অবিশ্বাস পোষণ করে, আর তাদের ফিরিয়ে আনা হয় সৎপথ থেকে। আর যাকে আল্লাহ্ পথভ্রষ্ট হতে দেন তার জন্য তবে কোনো পথপ্রদর্শক নেই।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mdccxli{তাদের জন্য শাস্তি রয়েছে এই দুনিয়ার জীবনেই, আর পরকালের শাস্তি তো আরো কঠোর, আর তাদের জন্য আল্লাহ্‌র বিরুদ্ধে কোনো রক্ষাকারী নেই।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mdccxlii{ধর্মভীরুদের কাছে যেটি প্রতি‌শ্রুতি দেওয়া হয়েছে সেই স্বর্গোদ্যানের উপমা হচ্ছে -- তার নিচে দিয়ে বয়ে যাচ্ছে ঝরনারাজি, তার ফলফসল চিরস্থায়ী আর তার ছায়াও। এই তাদের প্রতিফল যারা ধর্মপরায়ণতা অবলন্বন করে, আর অবিশ্বাসীদের পরিণাম হচ্ছে আগুন।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mdccxliii{আর যাদের আমরা ধর্মগ্রন্থ দিয়েছি তারা আনন্দ বোধ করে যা তোমার কাছে অবতীর্ণ হয়েছে তাতে, আর গোত্রদের মধ্যে এমনও আছে যে এর কিছুটা অস্বীকার করে। তুমি বলো -- ''নিঃসন্দেহ আমি আদিষ্ট হয়েছি যে আমি আল্লাহ্‌রই উপাসনা করবো এবং তাঁর সাথে কোন অংশী দাঁড় করাবো না। তাঁরই প্রতি আমি আহ্বান করি এবং তাঁরই নিকট আমার প্রত্যাবর্তন।’’\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mdccxliv{আর এইভাবে আমরা এটি অবতারণ করেছি -- একটি হুকুম আরবীতে। আর তুমি যদি তাদের খেয়ালখুশির অনুসরণ করো তোমার কাছে জ্ঞানের যা এসেছে তার পরে তবে আল্লাহ্‌র বিরুদ্ধে তুমি পাবে না কোনো বন্ধুবান্ধব, আর না কোনো রক্ষক।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mdccxlv{আর অবশ্যই তোমার পূর্বে আমরা বহু রসূল পাঠিয়েছি, আর তাঁদের জন্য আমরা দিয়েছিলাম স্ত্রী ও সন্তান-সন্ততি, আর কোনো রসূলের পক্ষে এটি নয় যে তিনি কোনো নিদর্শন উপস্থাপিত করবেন আল্লাহ্‌র অনুমতি ব্যতীত। প্রত্যেক নির্ধারিত কালের জন্য বিধান রয়েছে।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mdccxlvi{আল্লাহ্ বিলুপ্ত করেন যা তিনি ইচ্ছে করেন, আর প্রতিষ্ঠিত করেন, আর তাঁরই কাছে রয়েছে ধর্মগ্রন্থের ভিত্তি।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mdccxlvii{আর তোমাকে যদি আমরা দেখাই ওদের যা ওয়াদা করেছি তা থেকে কিছুটা, অথবা তোমার মৃত্যু ঘটিয়ে দিই, -- সর্বাবস্থায়ই তোমার উপরে হচ্ছে পৌঁছে দেওয়া, আর আমাদের উপরে হচ্ছে হিসাব গ্রহণ।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mdccxlviii{ওরা কি দেখে না যে আমরা এই দেশটাকে নিয়ে চলেছি, একে সংকুচিত করছি তার চৌহদ্দি থেকে? আল্লাহ্ রায় দান করেন, তাঁর হুকুম প্রতিহত হবার নয়। আর তিনি হিসেব-নিকেশে তৎপর।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mdccxlix{আর তাদের পূর্ববর্তীকালে যারা ছিল তারাও নিশ্চয়ইচক্রান্ত করেছিল, কিন্তু সমস্ত চক্রান্তই আল্লাহ্‌র। তিনি জানেন প্রত্যেক সত্ত্বা কী অর্জন করে। আর অবিশ্বাসীরা অচিরেই জানতে পারবে কার জন্য রয়েছে চরমোৎকর্ষ আবাস।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mdccl{আর যারা অবিশ্বাস পোষণ করে তারা বলে -- ''তুমি আল্লাহ্‌র রসূল নও।’’ বলো -- ''আমার ও তোমাদের মধ্যে সাক্ষীরূপে আল্লাহ্‌ই যথেষ্ট, আর সে যার কাছে রয়েছে ধর্মগ্রন্থের জ্ঞান।’’\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mdccli{\basmalahbn আলিফ, লাম, রা। একখানা গ্রন্থ, আমরা তোমার কাছে এ অবতারণ করেছি যেন তুমি মানবগোষ্ঠিকে তাদের প্রভুর অনুমতিক্রমে অন্ধকার থেকে আলোকে বের করে আনতে পারো, -- মহাশক্তিশালী পরম প্রশংসার্হের পথে,\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mdcclii{সেই আল্লাহ্‌, -- মহাকাশমন্ডলীতে যা-কিছু আছে আর যা-কিছু আছে পৃথিবীতে সে-সবটাই তাঁর। আর কি দুর্ভোগ অবিশ্বাসীদের জন্য কঠিন শাস্তির কারণে! --\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mdccliii{যারা পরকালের উপরি এই দুনিয়ার জীবনটাকেই বেশী ভালোবাসে, আর আল্লাহ্‌র পথ থেকে নিবৃত্ত করে, আর একে করতে চায় কুটিল। এরাই রয়েছে সুদূর-প্রসারিত ভ্রান্তিতে।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mdccliv{আর আমরা এমন কোনো রসূলকে পাঠাইনি তাঁর স্বজাতির ভাষা ব্যতীত, যেন তাদের জন্য তিনি সুস্পষ্ট করতে পারেন। তারপর আল্লাহ্ পথভ্রষ্ট হতে দেন যাকে তিনি ইচ্ছে করেন, আর যাকে ইচ্ছে করেন সৎপথে চালান। আর তিনিই তো মহাশক্তিশালী, পরমজ্ঞানী।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mdcclv{আর আমরা নিশ্চয়ই মূসাকে আমাদের নির্দেশাবলী দিয়ে পাঠিয়েছিলাম এই ব’লে -- ''তোমার সম্প্রদায়কে অন্ধকার থেকে আলোকে বের করে আনো, আর তাদের স্মরণ করিয়ে দাও আল্লাহ্‌র দিনগুলোর কথা।’’ নিঃসন্দেহ এতে নিদর্শন রয়েছে প্রত্যেক অধ্যবসায়ী কৃতজ্ঞদের জন্য।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mdcclvi{আর স্মরণ করো! মূসা তাঁর সম্প্রদায়কে বললেন -- ''তোমাদের প্রতি আল্লাহ্‌র অনুগ্রহ স্মরণ করো -- যখন তিনি তোমাদের উদ্ধার করেছিলেন ফিরআউনের লোকদের কবল থেকে, যারা তোমাদের পীড়ন করতো কঠোর নিপীড়নে, আর হত্যা করতো তোমাদের পুত্রসন্তানদের ও বাঁচতে দিত তোমাদের নারীদের। আর তোমাদের জন্য এতে তোমাদের প্রভুর কাছ থেকে ছিল এক কঠোর সংকট।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mdcclvii{আর স্মরণ করো! তোমাদের প্রভু ঘোষণা করলেন -- ''তোমরা যদি কৃতজ্ঞতা প্রকাশ করো তাহলে আমি অবশ্যই তোমাদের বাড়িয়ে দেবো, কিন্তু তোমরা যদি অকৃতজ্ঞ হও তাহলে আমার শাস্তি নিশ্চয়ই সুকঠোর।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mdcclviii{আর মূসা বলেছিলেন -- ''তোমরা যদি অকৃতজ্ঞ হও, তোমরা আর পৃথিবীতে যারা আছে সবাই, তাহলে নিঃসন্দেহ আল্লাহ্ তো অতি ধনবান, পরম প্রশংসার্হ।’’\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mdcclix{তোমাদের নিকট কি পৌঁছেনি তোমাদের পূর্বে যারা ছিল তাদের ইতিহাস -- নূহ্ ও 'আদ ও ছামূদের সম্প্রদায়ের আর যারা ওদের পরে ছিল? আল্লাহ্ ছাড়া অন্য কেউ তাদের জানে না। তাদের রসূলগণ তাদের কাছে এসেছিলেন স্পষ্ট প্রমাণাবলী নিয়ে, কিন্তু তারা তাদের হাত দিয়েছিল তাদের মুখের ভেতরে, আর তারা বলেছিল, ''আমরা অবশ্যই অবিশ্বাস করি যা নিয়ে তোমরা প্রেরিত হয়েছ, আর আমরা তো নিশ্চয়ই সন্দেহের মধ্যে রয়েছি যার দিকে তোমরা আমাদের ডাকছ সে-সন্বন্ধে, কিংকর্তব্যবিমূঢ়।’’\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mdcclx{তাদের রসূলগণ বলেছিলেন, ''আল্লাহ্ সন্বন্ধে কি কোনো সন্দেহ আছে, -- মহাকাশমন্ডলী ও পৃথিবীর আদি স্রষ্টা? তিনি তোমাদের আহ্বান করছেন তোমাদের দোষত্রুটি থেকে তোমাদের পরিত্রাণ করতে, আর এক নির্দিষ্টকাল পর্যন্ত তোমাদের অব্যাহতি দিতে।’’ তারা বললে, ''তোমরা তো আমাদের ন্যায় মানুষ বই নও। তোমরা চাচ্ছ আমাদের বিরত রাখতে আমাদের পিতৃপুরুষরা যার উপাসনা করত তা থেকে! অতএব তোমরা আমাদের কাছে কোনো সুস্পষ্ট প্রমাণ নিয়ে এসো।’’\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mdcclxi{তাদের রসূলগণ তাদের বলেছিলেন, ''সত্য বটে আমরা তোমাদের মতো মানুষ বই তো নই, কিন্তু আল্লাহ্ তাঁর বান্দাদের মধ্যে থেকে যাকে ইচ্ছে করেন তার প্রতি অনুগ্রহ বর্ষণ করেন। আর আমাদের জন্য এটি নয় যে আল্লাহ্‌র অনুমতি ব্যতীত তোমাদের কাছে কোনো প্রমাণ নিয়ে আসব। অতএব আল্লাহ্‌র উপরেই তবে মুমিনরা নির্ভর করুক।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mdcclxii{''আর আমাদের কি কারণ থাকতে পারে যে আমরা আল্লাহ্‌র উপরে নির্ভর করব না, অথচ তিনিই তো আমাদের চালিত করেছেন আমাদের পথে? আর আমরা নিশ্চয়ই অধ্যবসায় অবলন্বন করব তোমরা আমাদের যা ক্লেশ দিচ্ছ তা সত্ত্বেও। আর আল্লাহ্‌র উপরেই তবে নির্ভর করুক নির্ভরকারীরা।’’\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mdcclxiii{আর যারা অবিশ্বাস পোষণ করে তারা তাদের রসূলগণকে বলেছিল -- ''আমাদের দেশ থেকে আমরা নিশ্চয়ই তোমাদের বের করে দেবো, অথবা আমাদের ধর্মমতে তোমাদের ফিরে আসতেই হবে।’’ তখন তাঁদের প্রভু তাঁদের কাছে প্রত্যাদেশ দিয়েছিলেন -- ''আমরা নিশ্চয়ই অন্যায়কারীদের বিধ্বস্ত করব,\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mdcclxiv{''আর তাদের পরে আমরা দেশে অবশ্যই তোমাদের প্রতিষ্ঠিত করব। এটি তার জন্য যে ভয় করে আমার সামনে দাঁড়াতে, এবং ভয় করে আমার শাস্তির।’’\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mdcclxv{আর তারা বিজয়কামনা করেছিল, আর প্রত্যেক দুরাচারী বিরুদ্ধাচারী ব্যর্থ মনোরথ হল।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mdcclxvi{তার সামনে রয়েছে জাহান্নাম, আর তাকে পান করানো হবে নোংরা-পচা জল।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mdcclxvii{সে তা চুমুক দিয়ে পান করবে, আর সে তা সহজে গলাধঃকরণ করতে পারবে না, আর মরণ যন্ত্রণা তার কাছে আসবে সব দিক থেকে, কিন্তু সে মরবে না। আর তার সামনে রয়েছে কড়া শাস্তি।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mdcclxviii{যারা তাদের প্রভুকে অস্বীকার করে তাদের উপমা হচ্ছে -- তাদের ক্রিয়াকর্ম ছাইয়ের মতো, যার উপর দিয়ে বয়ে চলে ঝড়- তুফানের দিনের ঝড়ো বাতাস। তারা যা অর্জন করেছে তার কিছুরই উপরে তারা কোনো ক্ষমতা রাখতে পারবে না। এইটি হচ্ছে সুদূর প্রসারিত বিভ্রান্তি।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mdcclxix{তোমরা কি দেখ না যে আল্লাহ্ মহাকাশমন্ডল ও পৃথিবী সৃষ্টি করেছেন সত্যের সাথে? তিনি যদি চান তাহলে তোমাদের সরিয়ে দিতে পারেন এবং এক নতুন সৃষ্টি আনয়ন করবেন,\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mdcclxx{আর এটি আল্লাহ্‌র জন্যে কঠিন নয়।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mdcclxxi{আর তারা সবাই আসবে আল্লাহ্‌র সামনে, তখন দুর্বলেরা বলবে যারা অহংকার করত তাদের -- ''আমরা তো নিশ্চয়ই তোমাদের অনুগামী ছিলাম, সুতরাং আল্লাহ্‌র শাস্তি থেকে কিছুটা আমাদের থেকে তোমরা সরিয়ে নিতে পার কি?’’ তারা বলবে -- ''আল্লাহ্ যদি আমাদের সৎপথে চালিত করতেন তবে আমরাও তোমাদের সৎপথে চালিত করতাম। আমরা অসহিষ্ণুতা দেখাই বা ধৈর্যধারণ করি আমাদের জন্য সবই সমান, আমাদের জন্য কোনো নিষ্কৃতি নেই।’’\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mdcclxxii{আর যখন ব্যাপারটার মীমাংসা হয়ে যাবে তখন শয়তান বলবে -- ''নিঃসন্দেহ আল্লাহ্ তোমাদের ওয়াদা করেছিলেন সত্য ওয়াদা, আর আমিও তোমাদের কাছে অঙ্গীকার করেছিলাম, কিন্তু তোমাদের কাছে আমি খেলাফ করি। আর তোমাদের উপরে আমার কোনো আধিপত্য ছিল না, আমি শুধুমাত্র তোমাদের ডেকেছিলাম, তখন তোমরা আমার প্রতি সাড়া দিয়েছিলে। সুতরাং তোমরা আমাকে দোষ দিও না, বরং তোমাদের নিজেদেরকেই দোষারোপ কর। আমি তোমাদের উদ্ধারের পাত্র নই আর তোমরাও আমার উদ্ধারের পাত্র নও। আমি নিঃসন্দেহ অস্বীকার করি তোমরা যে ইতিপূর্বে আমাকে অংশী বানিয়েছিলে।’’ নিঃসন্দেহ অন্যায়কারীরা, -- তাদের জন্য রয়েছে মর্মন্তুদ শাস্তি।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mdcclxxiii{আর যারা ঈমান এনেছে ও সৎকর্ম করছে তাদের প্রবেশ করানো হবে স্বর্গোদ্যানসমূহে যাদের নিচে দিয়ে বয়ে যাচ্ছে ঝরনারাজি, সেখানে তারা থাকবে স্থায়ীভাবে তাদের প্রভুর অনুমতিক্রমে। সেখানে তাদের অভিবাদন হবে ''সালাম’’!\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mdcclxxiv{তোমরা কি ভেবে দেখ নি আল্লাহ্ কিভাবে উপমা দিয়ে থাকেন সাধু কথাকে উৎকৃষ্ট গাছের সঙ্গে, যার শিকড় হচ্ছে মজবুত ও যার ডালপালা আকাশে,\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mdcclxxv{তা তার ফল দিচ্ছে প্রত্যেক মৌসুমে তার প্রভুর অনুমতিক্রমে। আর আল্লাহ্ মানবসমাজের জন্য উপমাসমূহ প্রয়োগ করেন যেন তারা স্মরণ করতে পারে।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mdcclxxvi{আর খারাপ কথার উপমা হচ্ছে মন্দ গাছের মতো যা মাটির উপর থেকে উপড়ে ফেলা হয়েছে, এর কোনো স্থিতি নেই।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mdcclxxvii{যারা ঈমান এনেছে আল্লাহ্ তাদের প্রতিষ্ঠিত করেন শাশ্বত বাণীর দ্বারা এই দুনিয়ার জীবনে ও পরকালে, আর আল্লাহ্ পথহারা করেন অন্যায়কারীদের, আর আল্লাহ্ যা ইচ্ছে করেন তাই করেন।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mdcclxxviii{তুমি কি তাদের দেখো নি যারা আল্লাহ্‌র অনুগ্রহ বদলে নেয় অবিশ্বাস দিয়ে, আর তাদের লোকজনকে নামিয়ে নিয়েছে ধ্বংসের আবাসে?\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mdcclxxix{জাহান্নাম -- যাতে তারা প্রবেশ করবে, আর নিকৃষ্ট এই বাসস্থান!\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mdcclxxx{আর তারা আল্লাহ্‌র সমকক্ষ দাঁড় করায় যেন তারা তাঁর পথ থেকে বিপথে চালাতে পারে। তুমি বলো -- ''উপভোগ করো, তারপর তোমাদের প্রত্যাবর্তন নিশ্চয়ই আগুনের দিকে।’’\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mdcclxxxi{আমার বান্দাদের যারা বিশ্বাস করে তাদের বলো -- তারা নামায কায়েম করুক, এবং আমরা তাদের যে জীবনোপক রণ দিয়েছি তা থেকে তারা খরচ করুক, গোপনে ও প্রকাশ্যভাবে, সেইদিন আসবার আগে যাতে চলবে না কোনো লেনদেন, না কোনো বন্ধু- সম্পর্ক।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mdcclxxxii{আল্লাহ্ তিনিই যিনি মহাকাশমন্ডলী ও পৃথিবী সৃষ্টি করেছেন, আর আকাশ থেকে বর্ষণ করেন পানি, তারপর তার সাহায্যে তিনি উৎপাদন করেন তোমাদের জীবিকার জন্য ফলমূল, আর তোমাদের জন্য তিনি অধীন করেছেন জাহাজ যেন তাঁর বিধান অনুযায়ী তা সমুদ্রে চলাচল করে, আর তোমাদের জন্য তিনি বশীভূত করেছেন নদনদী।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mdcclxxxiii{আর তিনি তোমাদের অনুগত করেছেন সূর্য ও চন্দ্রকে যারা নিয়মানুগতভাবে চলমান, আর তিনি তোমাদের অধীন করেছেন রাত ও দিনকে।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mdcclxxxiv{আর তিনি তোমাদের প্রদান করেন তোমরা তাঁর কাছে যা প্রার্থনা কর তার সব-কিছু থেকেই। আর তোমরা যদি আল্লাহ্‌র অনুগ্রহ গণনা করতে যাও তোমরা তা গণতে পারবে না। মানুষ আলবৎ বড়ই অন্যায়কারী, অত্যন্ত অকৃতজ্ঞ।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mdcclxxxv{আর স্মরণ কর! ইব্রাহীম বলেছিলেন -- ''আমার প্রভু! এই শহরটাকে নিরাপদ করো, আর আমাকে ও আমার সন্তান-সন্ততিকে পুতুল প্রতিমা পূজা-অর্চনা থেকে রক্ষা করো।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mdcclxxxvi{''আমার প্রভু! নিঃসন্দেহ তারা মানবসমাজের অনেককে বিপথে নিয়েছে, সুতরাং যে আমাকে অনুসরণ করে সেই তবে আমার মধ্যেকার, আর যে আমাকে অমান্য করে তুমিই তো পরিত্রাণকারী, অফুরন্ত ফলদাতা।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mdcclxxxvii{''আমার প্রভু! আমি নিশ্চয়ই আমার বংশধরদের কতককে বসবাস করালাম তোমার পবিত্র গৃহের নিকটে চাষ-বাসহীন উপত্যকায়, -- আমাদের প্রভু! যেন তারা নামায কায়েম করে, সেজন্যে কিছু লোকের মন তাদের প্রতি অনুরাগী বানিয়ে দাও, আর তাদের ফলফসল দিয়ে জীবিকা প্রদান করো, যেন তারা কৃতজ্ঞতা প্রকাশ করে।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mdcclxxxviii{''আমাদের প্রভু! তুমি নিশ্চয় জান যা আমরা গোপন করি ও যা আমরা প্রকাশ করি। আর আল্লাহ্‌র কাছে পৃথিবীতে কোনো কিছুই লুকোনো নেই আর মহাকাশেও নয়।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mdcclxxxix{''সমস্ত প্রশংসা আল্লাহ্‌র যিনি আমাকে বৃদ্ধ বয়েসে ইসমাইল ও ইসহাককে দান করেছেন। নিঃসন্দেহ আমার প্রভু প্রার্থনা শ্রবণকারী।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mdccxc{''আমার প্রভু! আমাকে নামাযে সুপ্রতিষ্ঠিত করে দাও, আর আমার বংশধরদের থেকেও, আমাদের প্রভু! আর আমার প্রার্থনা কবুল করো।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mdccxci{''আমাদের প্রভু! আমাকে পরিত্রাণ করো, আর আমার পিতামাতাকেও আর বিশ্বাসিগণকেও -- যেদিন হিসাবপত্র নেওয়া হবে তখন।’’\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mdccxcii{আর তোমরা ভেবো না যে অন্যায়কারীরা যা করে আল্লাহ্ সে-সন্বন্ধে বেখেয়াল। তিনি তাদের শুধু অবকাশ দিচ্ছেন সেইদিন পর্যন্ত যেদিন চোখগুলো হবে পলকহীন স্থির --\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mdccxciii{ছুটে চলেছে তাদের মাথা খাড়া করে, তাদের দৃষ্টি তাদের নিজেদের দিকেও ফিরছে না, আর তাদের চিত্ত হয়েছে ফাঁকা।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mdccxciv{আর লোকজনকে সতর্ক কর সেইদিন সন্বন্ধে যখন তাদের উপরে শাস্তি ঘনিয়ে আসবে, যারা অন্যায় করেছিল তারা তখন বলবে, ''আমাদের প্রভু! আমাদের অবকাশ দাও অল্প কিছুকাল পর্যন্ত যেন আমরা তোমার ডাকে সাড়া দিতে পারি এবং রসূলগণকে অনুসরণ করতে পারি।’’ ''কি! তোমরা কি ইতিপূর্বে শপথ করতে থাক নি যে তোমাদের জন্য কোনো পড়ন্ত অবস্থা নেই?\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mdccxcv{''আর তোমরা বাস করতে তাদের বাসভূমিতে যারা নিজেদের আ‌ত্মার প্রতি অন্যায়াচরণ করেছিল, অথচ তোমাদের কাছে এটি সুস্পষ্ট করা হয়েছিল কিভাবে আমরা তাদের প্রতি ব্যবহার করেছিলাম আর তোমাদের জন্য বানিয়েছিলাম দৃষ্টান্ত।’’\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mdccxcvi{আর তারা নিশ্চয়ই তাদের চক্রান্ত এঁটেছিল, কিন্তু তাদের চক্রান্ত আছে আল্লাহ্‌র কাছে, যদিও তাদের চক্রান্ত এমন যে তার দ্বারা পাহাড়গুলো টলে যায়।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mdccxcvii{সুতরাং তুমি কখনো ভেবো না যে আল্লাহ্ তাঁর রসূলগণের কাছে দেওয়া তাঁর প্রতি‌শ্রুতি খেলাফ করবেন। নিঃসন্দেহ আল্লাহ্ মহাশক্তিশালী, প্রতিফল প্রদানকারী।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mdccxcviii{সেইদিন এ পৃথিবী বদলে হবে অন্য পৃথিবী, আর মহাকাশমন্ডলীও, আর তারা হাজির হবে আল্লাহ্‌র সামনে, যিনি একক, সর্বশক্তিমান।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mdccxcix{আর তুমি দেখতে পাবে -- অপরাধীরা সেইদিন শিকলের মধ্যে বাঁধা অবস্থায়, --\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mdccc{তাদের জামা হবে পীচের, আর তাদের মুখমন্ডল আবৃত করে থাকবে আগুন, --\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mdccci{যেন আল্লাহ্ প্রত্যেক সত্ত্বাকে প্রতিদান দিতে পারেন যা সে অর্জন করেছে, নিঃসন্দেহ আল্লাহ্ হিসেব-নিকেশে তৎপর।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mdcccii{এই হচ্ছে মানব সমাজের জন্য এক বার্তা যেন তারা জানতে পারে যে তিনিই নিঃসন্দেহ একক উপাস্য, আর বোধ শক্তিসম্পন্নেরা যেন উপদেশ গ্রহণ করতে পারে।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mdccciii{\basmalahbn আলিফ, লাম, রা। এগুলো হচ্ছে ধর্মগ্রন্থের আয়াতসমূহ, আর একটি সুস্পষ্ট পাঠ্য।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mdccciv{সময়কালে যারা অবিশ্বাস করেছিল তারা চাইবে যে যদি তারা মুসলিম হতো!\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mdcccv{ছেড়ে দাও তাদের খানাপিনা করতে ও আমোদ-আাদ করতে, আর আশা-আকাঙ্খা তাদের ভুলিয়ে রাখুক, যেহেতু শীগগিরই তারা বুঝতে পারবে!\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mdcccvi{আর আমরা কোনো জনপদকে ধ্বংস করি নি যে পর্যন্ত না তার জন্য বিধান মালুম করানো হয়েছে।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mdcccvii{কোনো জাতি তার নির্ধারিত কাল ত্বরান্বিত করতে পারবে না, আর তারা বিলন্বিত করতে পারবে না।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mdcccviii{আর তারা বলে -- ''ওহে যার কাছে স্মারকগ্রন্থ অবতীর্ণ হয়েছে! তুমি তো আলবৎ মাথা-পাগলা।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mdcccix{''তুমি কেন আমাদের কাছে ফিরিশ্‌তাদের নিয়ে এস না, যদি তুমি সত্যবাদীদের মধ্যেকার হও।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mdcccx{আমরা ফিরিশ্‌তাদের পাঠাই না সত্যের সাথে ছাড়া, আর তখন তারা অবকাশ প্রাপ্ত হবে না।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mdcccxi{নিঃসন্দেহ আমরা নিজেই স্মারকগ্রন্থ অবতারণ করেছি, আর আমরাই তো এর সংরক্ষণকারী।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mdcccxii{আর তোমার আগে আমরা নিশ্চয়ই পাঠিয়েছিলাম প্রাচীনকালের সম্প্রদায়ের মধ্যে।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mdcccxiii{কিন্তু তাদের কাছে এমন কোনো রসূল আসেন নি যাঁকে নিয়ে তারা ঠাট্টা-বিদ্রূপ করত না।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mdcccxiv{এইভাবে আমরা একে অপরাধীদের অন্তরে প্রবেশ করাই।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mdcccxv{তারা এতে বিশ্বাস করে না, অথচ পূর্ববর্তীদের নজীর অবশ্যই গত হয়েছে।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mdcccxvi{আর যদি আমরা তাদের জন্য মহাকাশের দরজা খুলে দিই আর তাতে তারা আরোহণ করতে থাকে --\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mdcccxvii{তারা তবুও বলবে -- ''আমাদের চোখে ধাঁধা লেগেছে, আমরা বরং মোহাচ্ছন্ন দল হয়েছি।’’\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mdcccxviii{আর বাস্তবিকই আমরা আকাশে দুর্গ তৈরি করেছি, আর তা সুশোভিত করেছি দর্শকদের জন্য।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mdcccxix{আর আমরা তাকে রক্ষা করি প্রত্যেক বিতাড়িত শয়তানের থেকে, --\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mdcccxx{সে ব্যতীত যে লুকিয়ে শোনে, ফলে তার পশ্চাদ্ধাবন করে প্রখর অগ্নিশিখা।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mdcccxxi{আর পৃথিবী -- আমরা তাকে প্রসারিত করেছি, আর তাতে স্থাপন করেছি পর্বতমালা, আর তাতে উৎপন্ন করেছি হরেক রকমের জিনিস সুপরিমিতভাবে।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mdcccxxii{আর তোমাদের জন্য তাতে সৃষ্টি করেছি খাদ্যবস্তু, আর তোমরা যাদের জীবিকাদাতা নও তাদের জন্যেও।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mdcccxxiii{আর এমন কোনো-কিছু নেই যার ভান্ডার আমাদের কাছে নয়, আর আমরা তা পাঠাই না নির্ধারিত পরিমাপে ছাড়া।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mdcccxxiv{আর আমরা উর্বরতা-সঞ্চারক বায়ু পাঠাই, তারপর আকাশ থেকে আমরা পানি পাঠাই, তখন তোমাদের তা পান করতে দিই, আর তোমরা তার কোষাধ্যক্ষ নও!\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mdcccxxv{আর নিঃসন্দেহ আমরা নিজেই জীবন দান করি ও মৃত্যু ঘটাই, আর আমরাই হচ্ছি উত্তরাধিকারী।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mdcccxxvi{আর আমরা নিশ্চয়ই জানি তোমাদের মধ্যের অগ্রগামীদের, আর আমরা অবশ্য জানি পশ্চাতে-পড়ে-থাকাদের।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mdcccxxvii{আর নিঃসন্দেহ তোমার প্রভু -- তিনি তাদেরকে একত্রে সমবেত করবেন। তিনি নিশ্চয়ই পরমজ্ঞানী, সর্বজ্ঞাতা।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mdcccxxviii{আর আমরা নিশ্চয়ই মানুষ সৃষ্টি করেছি আওয়াজদায়ক মাটি থেকে, কালো কাদা থেকে রূপ দিয়ে।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mdcccxxix{আর আমরা এর আগে জিন সৃষ্টি করেছি প্রখর আগুন দিয়ে।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mdcccxxx{আর স্মরণ কর! তোমার প্রভু ফিরিশ্‌তাদের বললেন -- ''নিঃসন্দেহ আমি মানুষ সৃষ্টি করতে যাচ্ছি আওয়াজদায়ক মাটি থেকে, -- কালো কাদা থেকে রূপ দিয়ে।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mdcccxxxi{সুতরাং যখন আমি তাকে সুঠাম করব আর তাতে আমার রূহ্ ফুকঁবো তখন তার প্রতি তোমরা পড় সিজদাবনত হয়ে।’’\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mdcccxxxii{তখন ফিরিশ্‌তারা সিজদা করলে, তাদের সবাই সববেত-ভাবে, --\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mdcccxxxiii{ইবলিস ব্যতীত, সে সিজদাকারীদের অন্তর্ভুক্ত হতে অস্বীকার করল।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mdcccxxxiv{তিনি বললেন -- ''হে ইবলিস! তোমার কি হয়েছে যে তুমি সিজদাকারীদের সঙ্গী হলে না?’’\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mdcccxxxv{সে বললে -- ''আমি তেমন নই যে আমি সিজদা করব একজন মানুষকে যাকে তুমি সৃষ্টি করেছ আওয়াজদায়ক মাটি থেকে -- কালো কাদা থেকে রূপ দিয়ে।’’\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mdcccxxxvi{তিনি বললেন -- ''তাহলে বেরিয়ে যাও এখান থেকে, কেননা নিঃসন্দেহ তুমি বিতাড়িত,\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mdcccxxxvii{''আর নিশ্চয় তোমার উপরে থাকবে অসন্তষ্টি শেষবিচারের দিন পর্যন্ত।’’\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mdcccxxxviii{সে বললে -- ''আমার প্রভু! তবে আমাকে অবকাশ দাও সেই দিন পর্যন্ত যখন তাদের পুনরুত্থিত করা হবে!’’\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mdcccxxxix{তিনি বললেন -- ''তবে তুমি নিশ্চয়ই অবকাশপ্রাপ্তদের মধ্যেকার --\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mdcccxl{নির্ধারিত সময়ের দিন পর্যন্ত।’’\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mdcccxli{সে বললে -- ''আমার প্রভু! তুমি যেমনি আমাকে বিপথে যেতে দিয়েছ, আমিও তেমনি নিশ্চয়ই তাদের নিকট চিত্তাকর্ষক করব এই পৃথিবীতে, আর অবশ্যই তাদের একসাথে বিপথগামী করব --\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mdcccxlii{তাদের মধ্যে তোমার খাস বান্দাদের ব্যতীত।’’\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mdcccxliii{তিনি বললেন -- ''এটিই হচ্ছে আমার দিকে সহজ-সঠিক পথ।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mdcccxliv{''নিঃসন্দেহ আমার দাসদের সন্বন্ধে -- তাদের উপরে তোমার কোনো আধিপত্য নেই, বিপথগামীদের মধ্যে যারা তোমার অনুসরণ করে তাদের ব্যতীত।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mdcccxlv{''আর নিঃসন্দেহ জাহান্নাম হচ্ছে তাদের সকলের জন্য প্রতি‌শ্রুত স্থান --\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mdcccxlvi{''তার সাতটি দরজা আছে। প্রত্যেক প্রবেশপথের জন্য রয়েছে তাদের মধ্যের পৃথক পৃথক দল।’’\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mdcccxlvii{নিঃসন্দেহ ধর্মপরায়ণরা থাকবে স্বর্গোদ্যানে ও ঝরনারাজির মধ্যে।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mdcccxlviii{''তোমরা এতে প্রবেশ কর শান্তিতে ও নিরাপত্তায়।’’\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mdcccxlix{আর আমরা বের করে দেব তাদের অন্তরে যা-কিছু হিংসা-বিদ্বেষ রয়েছিল, ফলে তারা ভাইদের মতো থাকবে আসনের উপরে মুখোমুখি হয়ে।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mdcccl{সেখানে তাদের স্পর্শ করবে না কোনো অবসাদ, আর তারা সেখান থেকে বহিষ্কৃত হবে না।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mdcccli{আমার বান্দাদের খবর দাও যে আমিই তো নিশ্চয়ই পরিত্রাণকারী, অফুরন্ত ফলদাতা,\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mdccclii{আর আমার শাস্তি, -- তা অতি মর্মন্তুদ শাস্তি।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mdcccliii{আর তাদের খবর দাও ইব্রাহীমের অতিথিদের সন্বন্ধে।’’\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mdcccliv{যখন তারা তাঁর কাছে হাজির হল তখন তারা বললে -- ''সালাম’’। তিনি বললেন -- ''আমরা অবশ্য তোমাদের সন্বন্ধে ভয় করছি।’’\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mdccclv{তারা বললেন -- ''ভয় করো না, নিঃসন্দেহ আমরা তোমাকে সুসংবাদ দিচ্ছি এক জ্ঞানবান ছেলের সন্বন্ধে।’’\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mdccclvi{তিনি বললেন -- ''তোমরা কি আমাকে সুসংবাদ দিচ্ছ যখন বার্ধক্য আমাকে স্পর্শ করেছে? তবে কিসের তোমরা সুসংবাদ দিচ্ছ?\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mdccclvii{তারা বললে -- ''আমরা তোমাকে সুসংবাদ দিচ্ছি সত্যের সাথে, সুতরাং তুমি হতাশদের মধ্যেকার হয়ো না।’’\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mdccclviii{তিনি বললেন -- ''আর কে হতাশ হয় তার প্রভুর করুণা থেকে পথভ্রষ্টরা ব্যতীত?’’\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mdccclix{তিনি বললেন -- ''তবে কি তোমাদের কাজ রয়েছে, হে প্রেরিতগণ?’’\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mdccclx{তারা বললে -- ''আমরা নিশ্চয়ই প্রেরিত হয়েছি একটি অপরাধী সম্প্রদায়ের প্রতি,\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mdccclxi{''লুতের অনুবর্তীরা ব্যতীত। নিঃসন্দেহ তাঁদের সবাইকে আমরা অবশ্যই উদ্ধার করব --\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mdccclxii{তাঁর স্ত্রী ব্যতীত। আমরা সঠিক জেনেছি যে সে তো নিশ্চয়ই পেছনে-পড়েথাকাদের মধ্যেকার।’’\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mdccclxiii{তারপর যখন বাণীবাহকরা লূত-এর পরিজনের কাছে এল,\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mdccclxiv{তিনি বললেন -- ''তোমরা তো অপরিচিত লোক।’’\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mdccclxv{তারা বললে -- ''আমরা নিশ্চয়ই তোমার কাছে এসেছি তাই নিয়ে যে-সন্বন্ধে তারা তর্ক-বিতর্ক করত।\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mdccclxvi{''আর আমরা তোমার কাছে নিয়ে এসেছি সত্যবার্তা, আর আমরা নিঃসন্দেহ সত্যবাদী।\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mdccclxvii{''সুতরাং তোমার পরিবার-পরিজনকে নিয়ে বেরিয়ে পড় রাতের এক অংশে, আর তুমি তাদের পেছন থেকে অনুসরণ কর, আর তোমাদের মধ্যের কেউ যেন পিছন দিকে না দেখে, আর চলে যাও যেখানে তোমাদের আদেশ করা হয়েছে।’’\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mdccclxviii{আর তাঁর কাছে আমরা জানিয়ে দিলাম এই নির্দেশ যে এদের শেষটুকুও কেটে দেওয়া হবে ভোরে জেগে ওঠার বেলায়।\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mdccclxix{আর শহরের লোকেরা এল উৎফুল্ল হয়ে।\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mdccclxx{তিনি বললেন -- ''এরা নিশ্চয়ই আমার অতিথি, সুতরাং আমাকে বেইজ্জত করো না।\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mdccclxxi{''আর আল্লাহ্‌কে ভয়শ্রদ্ধা কর, আর আমাকে লজ্জা দিয়ো না!’’\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mdccclxxii{তারা বললে -- ''আমরা কি তোমাকে নিষেধ করি নি জগদ্বাসীদের সম্পর্কে?’’\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@mdccclxxiii{তিনি বললেন -- ''এরা আমার কন্যা, যদি তোমরা করতে চাও!’’\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@mdccclxxiv{তোমার জীবনের কসম! তারা নিঃসন্দেহ তাদের মত্ততায় অন্ধভাবে ঘুরছিল।\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@mdccclxxv{কাজেই এক মহাধ্বনি তাদের পাকড়াও করল সূর্যোদয়কালে।\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@mdccclxxvi{কাজেকাজেই এর উপরভাগ আমরা বানিয়ে দিলাম এর নিচের ভাগ, আর তাদের উপরে বর্ষণ করলাম পোড়া-মাটির পাথর।\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@mdccclxxvii{নিশ্চয়ই এতে চিন্তাশীলদের জন্য নিদের্শনাবলী রয়েছে।\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@mdccclxxviii{আর নিঃসন্দেহ এটি একটি সড়কের উপরে অবস্থিত।\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@mdccclxxix{নিঃসন্দেহ এতে তো নিদর্শন রয়েছে মুমিনদের জন্য।\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@mdccclxxx{আর আসহাবুল আইকাহ্ অবশ্যই ছিল অন্যায়াচারী।\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@mdccclxxxi{সেজন্য তাদের থেকে আমরা প্রতিফল আদায় করেছিলাম। তারা উভয়েই তো রয়েছে প্রকাশ্য রাজপথে।\qt@no{(79)}}
\qt@newcmd\qurantrans@bn@mdccclxxxii{আর নিশ্চয় পাথুরে-পাহাড়ের বাসিন্দারাও রসূলগণকে প্রত্যাখ্যান করেছিল।\qt@no{(80)}}
\qt@newcmd\qurantrans@bn@mdccclxxxiii{আর তাদের আমরা আমাদের নির্দেশাবলী দিয়েছিলাম, কিন্তু তারা সে-সব থেকে ফিরে গিয়েছিল।\qt@no{(81)}}
\qt@newcmd\qurantrans@bn@mdccclxxxiv{আর তারা পাহাড় কেটে নিশ্চিন্ত হয়ে বাড়িঘর তৈরি করত।\qt@no{(82)}}
\qt@newcmd\qurantrans@bn@mdccclxxxv{কিন্তু প্রচন্ড আওয়াজ তাদের পাকড়াও করল সকালবেলায়।\qt@no{(83)}}
\qt@newcmd\qurantrans@bn@mdccclxxxvi{কাজেই তারা যা অর্জন করত তা তাদের কোনো কাজে আসে নি।\qt@no{(84)}}
\qt@newcmd\qurantrans@bn@mdccclxxxvii{আর আমরা মহাকাশমন্ডলী ও পৃথিবী এবং এ দুইয়ের মধ্যে যা-কিছু আছে তা সৃষ্টি করি নি সত্যের সঙ্গে ব্যতীত। আর নিঃসন্দেহ ঘড়ি-ঘন্টা তো এসে পড়ল; সুতরাং উপেক্ষা করো মহৎ উপেক্ষাভরে।\qt@no{(85)}}
\qt@newcmd\qurantrans@bn@mdccclxxxviii{নিঃসন্দেহ তোমার প্রভু, -- তিনি সর্বস্রষ্টা, সর্বজ্ঞাতা।\qt@no{(86)}}
\qt@newcmd\qurantrans@bn@mdccclxxxix{আর নিশ্চয়ই তোমাকে আমরা দিয়েছি বারবার-পঠিত সাতটি, আর এক সুমহান কুরআন।\qt@no{(87)}}
\qt@newcmd\qurantrans@bn@mdcccxc{তাদের মধ্যের কতক পরিবারকে যা ভোগবিলাসের বস্তু দিয়েছি তার প্রতি তোমার চোখ দিয়ো না, আর তাদের প্রতি তুমি ক্ষোভ করো না, বরং তোমার ডানা নামাও মুমিনদের জন্য।\qt@no{(88)}}
\qt@newcmd\qurantrans@bn@mdcccxci{আর বলো -- ''নিঃসন্দেহ আমি, আমি হচ্ছি একজন প্রকাশ্য সতর্ককারী।’’\qt@no{(89)}}
\qt@newcmd\qurantrans@bn@mdcccxcii{যেমন আমরা পাঠিয়েছিলাম বিভক্তদের প্রতি, --\qt@no{(90)}}
\qt@newcmd\qurantrans@bn@mdcccxciii{যারা কুরআনকে করে ছিন্নভিন্ন।\qt@no{(91)}}
\qt@newcmd\qurantrans@bn@mdcccxciv{সুতরাং, তোমার প্রভুর কসম! আমরা নিশ্চয়ই তাদের সবাইকে প্রশ্ন করব --\qt@no{(92)}}
\qt@newcmd\qurantrans@bn@mdcccxcv{তারা যা করে চলেছিল সে-সন্বন্ধে।\qt@no{(93)}}
\qt@newcmd\qurantrans@bn@mdcccxcvi{কাজেই প্রকাশ্যে ঘোষণা করো যা তোমাকে আদেশ করা হয়েছে, আর বহুখোদাবাদীদের থেকে ফিরে থেকো।\qt@no{(94)}}
\qt@newcmd\qurantrans@bn@mdcccxcvii{আমরাই তো তোমার জন্য যথেষ্ট বিদ্রূপকারীদের বিরুদ্ধে --\qt@no{(95)}}
\qt@newcmd\qurantrans@bn@mdcccxcviii{যারা আল্লাহ্‌র সাথে দাঁড় করায় অন্য উপাস্য, কাজেই শীঘ্রই তারা জানতে পারবে।\qt@no{(96)}}
\qt@newcmd\qurantrans@bn@mdcccxcix{আর আমরা অবশ্য জানি যে তারা যা বলে তাতে তোমার বক্ষ আলবৎ পীড়িত হয়,\qt@no{(97)}}
\qt@newcmd\qurantrans@bn@mcm{সুতরাং তোমার প্রভুর প্রশংসা দ্বারা মহিমা কীর্তন করো, আর সিজদাকারীদের মধ্যেকার হও,\qt@no{(98)}}
\qt@newcmd\qurantrans@bn@mcmi{আর তোমার প্রভুর উপাসনা কর যে পর্যন্ত না তোমার কাছে আসে যা সুনিশ্চিত।\qt@no{(99)}}
\qt@newcmd\qurantrans@bn@mcmii{\basmalahbn আল্লাহ্‌র হুকুম এসেই গেছে, সুতরাং তা ত্বরান্বিত করতে চেয়ো না। সমস্ত মহিমা তাঁরই, আর তারা যা অংশী করে তিনি তার বহু ঊর্ধ্বে।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mcmiii{তিনি ফিরিশ্‌তাদের পাঠান তাঁর নির্দেশে প্রেরণা দিয়ে তাঁর বান্দাদের মধ্যের যার উপরে তিনি ইচ্ছে করেন, এই বলে -- ''তোমরা সাবধান করে দাও যে আমি ছাড়া আর কোনো উপাস্য নেই, সুতরাং আমাকেই ভয়ভক্তি করো।’’\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mcmiv{তিনি মহাকাশমন্ডলী ও পৃথিবী সৃষ্টি করেছেন সত্যের সাথে। তারা যা অংশী দাঁড় করায় তিনি তার থেকে বহু ঊর্ধ্বে।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mcmv{তিনি মানুষ সৃষ্টি করেছেন শুক্রকীট থেকে, অথচ দেখো! সে একজন প্রকাশ্য বিতন্ডাকারী।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mcmvi{আর গবাদি-পশু, তিনি তাদের সৃষ্টি করেছেন, তোমাদের জন্য তাদের মধ্যে রয়েছে গরম পোশাক, আর মূনাফা, আর তাদের মধ্যে থেকে তোমরা খাও।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mcmvii{আর তোমাদের জন্য তাদের মধ্যে রয়েছে শোভা-সৌন্দর্য যখন তোমরা তাদের ঘরে নিয়ে এস ও বাইরে নিয়ে যাও ।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mcmviii{আর তারা তোমাদের বোঝা বয়ে নেয় তেমন দেশে যেখানে তোমরা পৌঁছুতে পারতে না নিজেদেরকে অত্যন্ত কষ্ট না দিয়ে। নিঃসন্দেহ তোমাদের প্রভু তো পরম স্নেহময়, অফুরন্ত ফলদাতা।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mcmix{আর ঘোড়া ও খচ্চর ও গাধা যেন তোমরা তাদের চড়তে পার, এবং শোভাদানের জন্য। আর তিনি সৃষ্টি করেন যা তোমরা জানো না।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mcmx{আর আল্লাহ্‌র উপরেই রয়েছে সরলপথ, আর তাদের কতক হচ্ছে বাঁকা। আর তিনি যদি ইচ্ছা করতেন তবে তিনি তোমাদের সকলকেই সৎপথে পরিচালিত করতে পারতেন।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mcmxi{তিনিই সেইজন যিনি আকাশ থেকে তোমাদের জন্য পানি বর্ষান, তা থেকে হয় পানীয় জল আর তা থেকে হয় গাছগাছড়া যাতে তোমরা পশুচারণ কর।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mcmxii{তিনি তোমাদের জন্য তার দ্বারা জন্মান শস্য ও জলপাই, আর খেজুর ও আঙুর, আর হরেক রকমের ফলফসল। নিঃসন্দেহ এতে অবশ্যই আছে নিদর্শন সেই লোকদের জন্য যারা চিন্তা করে।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mcmxiii{আর তিনি তোমাদের জন্য সেবারত করেছেন রাত ও দিনকে, আর সূর্য ও চন্দ্রকে। আর গ্রহনক্ষত্রও অধীন হয়েছে তাঁর বিধানে। নিঃসন্দেহ এতে নিশ্চয়ই নিদর্শন রয়েছে সেই লোকদের জন্য যারা জ্ঞানবুদ্ধি রাখে।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mcmxiv{আর যা-কিছু তিনি তোমাদের জন্য পৃথিবীতে সৃষ্টি করেছেন -- বিচিত্র সে-সবের রঙ। নিঃসন্দেহ এতে আলবৎ নিদর্শন রয়েছে সেই লোকদের জন্য যারা মনোযোগ দেয়।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mcmxv{আর তিনিই সেইজন যিনি সমুদ্রকে করেছেন বশীভূত যেন তা থেকে তোমরা খেতে পার টাটকা মাংস, আর তা থেকে বের করে আনতে পার অলংকার যা তোমরা পরো, আর তোমরা দেখতে পাও ওর বুক চিরে জাহাজ চলাচল করে যেন তোমরা তাঁর অনুগ্রহসামগ্রী সন্ধান করতে পার, আর যেন তোমরা কৃতজ্ঞতা প্রকাশ করো।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mcmxvi{আর তিনি পৃথিবীতে স্থাপন করেছেন পাহাড়-পর্বত, পাছে তোমাদের নিয়ে তা কাত হয়ে যায়, আর নদ-নদী ও রাস্তাঘাট, যেন তোমরা সঠিক পথ লাভ কর।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mcmxvii{আর চিহ্নসমূহ। আর তারার সাহায্যেও তারা পথনির্দেশ পায়।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mcmxviii{যিনি সৃষ্টি করেন তিনি কি তবে তার মতো যে সৃষ্টি করে না? তবুও কি তোমরা মনোযোগ দেবে না?\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mcmxix{আর তোমরা যদি আল্লাহ্‌র অনুগ্রহ গণনা করতে যাও তোমরা তা গণতে পারবে না। নিঃসন্দেহ আল্লাহ্‌ই তো পরিত্রাণকারী, অফুরন্ত ফলদাতা।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mcmxx{আর আল্লাহ্ জানেন তোমরা যা গোপন রাখ আর যা তোমরা প্রকাশ কর।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mcmxxi{আর আল্লাহ্‌কে ছেড়ে দিয়ে যাদের তারা ডাকে তারা কিছুই সৃষ্টি করে নি, আর তারা নিজেরাই তো সৃষ্ট, --\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mcmxxii{তারা মৃত, জীবন্ত নয়, আর তারা জানে না কখন তাদের পুনরুত্থিত করা হবে।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mcmxxiii{তোমাদের উপাস্য একক উপাস্য; সেজন্য যারা পরকালে বিশ্বাস করে না তাদের অন্তর প্রত্যাখ্যানকারী, আর তারা অহংকারী।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mcmxxiv{কোনো সন্দেহ নেই যে আল্লাহ্ জানেন যা তারা লুকিয়ে রাখে, আর যা তারা প্রকাশ করে। নিঃসন্দেহ তিনি অহংকারীদের ভালোবাসেন না।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mcmxxv{আর যখন তাদের বলা হয় -- ''তোমাদের প্রভু কী বিষয়বস্তু অবতারণ করেছেন?’’ তারা বলে -- ''সেকেলে গালগল্প!’’\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mcmxxvi{ফলে কিয়ামতের দিনে তারা নিজেদের বোঝা পুরোমাত্রায় বহন করবে, আর তাদেরও বোঝার কতকটা যাদের তারা পথভ্রষ্ট করেছে কোনো জ্ঞান না থাকা সত্ত্বেও। তারা যা বহন করে তা কি নিকৃষ্ট নয়?\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mcmxxvii{তাদের পূর্ববর্তীরাও নিশ্চয়ই চক্রান্ত করেছিল, কিন্তু আল্লাহ্ তাদের ধ্বংস করেছিলেন বুনিয়াদ থেকে, ফলে ছাদ তাদের উপরে ভেঙ্গে পড়েছিল তাদের উপর থেকে, আর তাদের উপরে শাস্তি এসে পড়েছিল এমন দিক থেকে যা তারা জানতে পারে নি।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mcmxxviii{তারপর কিয়ামতের দিনে তিনি তাদের লাঞ্ছিত করবেন, আর তিনি বলবেন -- ''কোথায় রয়েছে আমার অংশীরা যাদের সন্বন্ধে তোমরা বাক্‌বিতন্ডা করতে?’’ যাদের জ্ঞান দেওয়া হয়েছিল তারা বলবেন -- ''নিঃসন্দেহ আজকের দিনে লাঞ্ছনা ও অমঙ্গল অবিশ্বাসীদের উপরেই’’ --\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mcmxxix{এরা তারা যাদের প্রাণ হরণ করবে ফিরিশ্‌তারা ওরা নিজেদের প্রতি অন্যায়কারী থাকা কালে। তখন তারা আ‌ত্মসমর্পণ করবে -- ''আমরা খারাপ কিছু করি নি।’’ ''না, তোমরা যা করতে সে বিষয়ে আল্লাহ্ নিশ্চয়ই সর্বজ্ঞাতা।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mcmxxx{''সুতরাং জাহান্নামের দরজাগুলো দিয়ে ঢোকে যাও সেখানে থাকার জন্যে। অতএব অহংকারীদের বাসস্থান কত নিকৃষ্ট!’’\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mcmxxxi{আর যারা ধর্মভীরুতা অবলন্বন করেছে তাদের বলা হবে -- ''কী সেটি যা তোমাদের প্রভু অবতারণ করেছিলেন?’’ তারা বলবে -- ''মহাকল্যাণ।’’ যারা ভাল কাজ করে তাদের জন্য এই দুনিয়াতেই রয়েছে মঙ্গল, আর পরকালের বাড়িঘর অতি উত্তম। আর ধর্মপরায়ণদের আবাসস্থল কতো উৎকৃষ্ট! --\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mcmxxxii{নন্দন কানন যাতে তারা প্রবেশ করবে, সে-সবের নিচে দিয়ে বয়ে যাচ্ছে ঝরনারাজি, তারা যা চায় তাদের জন্য সেখানে তাই থাকবে। এইভাবেই আল্লাহ্ প্রতিদান দেন ধর্মনিষ্ঠদের --\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mcmxxxiii{এরা তারা যাদের প্রাণহরণ করবে ফিরিশ্‌তারা উত্তমভাবে, তারা বলবে -- ''তোমাদের প্রতি সালাম! তোমরা যা করতে সেজন্য স্বর্গোদ্যানে প্রবেশ করো।’’\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mcmxxxiv{তারা আর কিছুর অপেক্ষা করে না এ ছাড়া যে তাদের কাছে ফিরিশ্‌তারা আসুক, অথবা তোমার প্রভুর নির্দেশনামা আসুক। এইভাবে আচরণ করেছিল তারা যারা এদের পূর্বে বিদ্যমান ছিল। আর আল্লাহ্ তাদের প্রতি অন্যায় করেন নি, বরং তারা তাদের নিজেদের প্রতিই অন্যায় করে যাচ্ছিল।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mcmxxxv{সুতরাং তারা যা করত তার মন্দটা তাদের পাকড়াও করবে, আর যা নিয়ে তারা মস্করা করত তাই ওদের ঘেরাও করবে।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mcmxxxvi{আর যারা অংশী দাঁড় করায় তারা বলে -- আল্লাহ্ যদি ইচ্ছা করতেন তবে আমরা তাঁকে ছেড়ে দিয়ে অন্য কোনো-কিছু উপাসনা করতাম না, আমরা বা আমাদের পিতৃপুরুষরাও না, এবং আমরা তাঁকে ছেড়ে দিয়ে কোনো-কিছু নিষেধ করতাম না।’’ এইভাবেই তাদের পূর্বে যারা ছিল তারাও আচরণ করত। তবে রসূলগণের উপরে সুস্পষ্টভাবে পৌঁছে দেওয়া ছাড়া অন্য কিছু আছে কি?\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mcmxxxvii{আর আমরা অবশ্যই প্রত্যেক জাতির মধ্যে এক-এক জন রসূল দাঁড় করেছি এই বলে -- ''আল্লাহ্‌র উপাসনা কর এবং তাগুতকে বর্জন কর।’’ সুতরাং তাদের মধ্যে কতকজন আছে যাদের আল্লাহ্ সৎপথে পরিচালিত করেছেন, আর তাদের মধ্যের কতক আছে যাদের উপরে পথভ্রান্তিই সমীচীন হয়েছে। সেজন্যে পৃথিবীতে তোমরা ভ্রমণ কর এবং দেখে নাও কেমন হয়েছিল প্রত্যাখ্যানকারীদের পরিণাম।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mcmxxxviii{যদিও তুমি তাদের পথপ্রাপ্তির জন্যে বিশেষ প্রচেষ্টা কর তথাপি আল্লাহ্ নিশ্চয় তাকে পথ দেখান না যে বিপথে চালিয়েছে, ফলে তাদের জন্য কোনো সাহায্যকারী নেই।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mcmxxxix{আর তাদের জোরালো শপথের দ্বারা তারা আল্লাহ্‌র নামে শপথ করে -- ''আল্লাহ্ তাকে পুনরুত্থিত করবেন না যে মারা গেছে।’’ না, এটি তাঁর উপরে নিয়োজিত পরম সত্য ওয়াদা, কিন্তু অধিকাংশ লোকেই জানে না, --\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mcmxl{যেন তিনি তাদের কাছে সুস্পষ্ট করতে পারেন সেই বিষয় যাতে তারা মতভেদ করছে, আর যারা অবিশ্বাস পোষণ করে তারা যেন জানতে পারে যে তারা নিশ্চয় মিথ্যাবাদী ছিল।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mcmxli{নিঃসন্দেহ কোনো বিষয়ে আমাদের উক্তি হচ্ছে যখন আমরা তা ইচ্ছা করি, তখন তার প্রতি আমরা বলি -- ''হও ’’, তখন তা হয়ে যায়।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mcmxlii{আর যারা আল্লাহ্‌র পথে হিজরত করে অত্যাচারিত হবার পরে, আমরা অবশ্যই তাদের প্রতিষ্ঠা করব এই দুনিয়াতেই সুন্দরভাবে। আর পরকালের পুরস্কার নিশ্চয়ই আরো ভাল, যদি তারা জানতে পারত! --\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mcmxliii{যারা অধ্যবসায় করে এবং তাদের প্রভুর উপরে নির্ভর করে।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mcmxliv{আর তোমার আগে আমরা মানুষদের ছাড়া অন্য কাউকে পাঠাই নি যাদের কাছে আমরা প্রত্যাদেশ দিয়েছিলাম, অতএব তোমরা স্মরণীয় গ্রন্থপ্রাপ্তদের জিজ্ঞেস কর যদি তোমরা জানো না, --\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mcmxlv{স্পষ্ট প্রমাণাবলী ও যবূর নিয়ে। আর তোমার কাছে আমরা অবতারণ করেছি স্মারক গ্রন্থ যেন তুমি লোকদের কাছে সুস্পষ্ট করে দিতে পার যা তাদের কাছে অবতীর্ণ হয়েছিল, আর যেন তারা চিন্তাও করতে পারে।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mcmxlvi{যারা কুকর্মের চক্রান্ত করে তারা কি তবে নিরাপদ বোধ করে যে তাদের জন্য আল্লাহ্ পৃথিবীকে ফাটল করবেন না, অথবা তাদের উপরে শাস্তি এসে পড়বে না এমন দিক থেকে যা তারা ধারণাও করে না,\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mcmxlvii{অথবা তাদের তিনি পাকড়াও করবেন না তাদের এদিক-ওদিক যাবার কালে, তার ফলে তারা নিষ্কৃতিপ্রাপ্ত হবে না, --\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mcmxlviii{অথবা তাদের তিনি পাকড়াবেন না ভয়ভীতি দিয়ে? সুতরাং তোমাদের প্রভু নিশ্চয়ই তো পরম স্নেহময়, অফুরন্ত ফলদাতা।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mcmxlix{ভাল কথা, তারা কি লক্ষ্য করে নি সব-কিছু যা আল্লাহ্ সৃষ্টি করেছেন, যার ছায়া ঝোঁকে ডাইনে ও বামে আল্লাহ্‌র প্রতি সিজদাবনত হয়ে, আর তারা বিনয়াবনত থাকে।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mcml{আর আল্লাহ্‌র প্রতি সিজদা করে জীবজন্তুদের মধ্যের যারা আছে মহাকাশমন্ডলে আর যারা আছে পৃথিবীতে, আর ফিরিশ্‌তারাও, আর তারা অহংকার করে না।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mcmli{তারা তাদের প্রভুকে ভয় করে তাদের উপরে থেকে, আর যা তাদের আদেশ করা হয় তারা তা পালন কবে।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mcmlii{আর আল্লাহ্ বলছেন -- ''তোমরা দুইজন ক’রে উপাস্য গ্রহণ করো না, নিঃসন্দেহ তিনি একজন মাত্র উপাস্য, সুতরাং আমাকে, শুধু আমাকেই তোমরা ভয় করবে।’’\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mcmliii{আর মহাকাশমন্ডলে ও পৃথিবীতে যা-কিছু আছে তা তাঁরই, আর ধর্ম সর্বদাই তাঁর। তোমরা কি তবে আল্লাহ্ ব্যতীত অন্যকে ভয়শ্রদ্ধা করবে?\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mcmliv{আর তোমরা অনুগ্রহের যে-সব পেয়েছ তা তো আল্লাহ্‌র কাছ থেকে, আবার যখন দুঃখকষ্ট তোমাদের পীড়া দেয় তখন তাঁর কাছেই তোমরা সাহায্য প্রার্থনা কর।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mcmlv{তারপর যখন তিনি তোমাদের থেকে দুঃখদুর্দশা দূর করে দেন, দেখো, তোমাদের একদল তাদের প্রভুর সঙ্গে অংশী দাঁড় করায়, --\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mcmlvi{যাতে তারা অস্বীকার করতে পারে যা আমরা তাদের দিয়েছিলাম। ''অতএব ভোগ করে নাও, শীঘ্রই কিন্তু টের পাবে!’’\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mcmlvii{আর আমরা তাদের যা জীবনোপকরণ দিয়েছি তা থেকে এক অংশ তারা নির্ধারিত করে, তাদের জন্য যাদের সন্বন্ধে তারা জানে না। আল্লাহ্‌র কসম! তোমাদের নিশ্চয়ই প্রশ্ন করা হবে যা তোমরা উদ্ভাবন করেছিলে সে-সন্বন্ধে।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mcmlviii{আর তারা আল্লাহ্‌তে আরোপ করে কন্যাসন্তান! সমস্ত মহিমা তাঁরই! -- অথচ নিজেদের জন্য যা তারা কামনা করে।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mcmlix{আর যখন তাদের কাউকে সুসংবাদ দেয়া হয় মেয়েছেলের সন্বন্ধে তখন তার মুখমন্ডল কালো হয়ে যায়, আর সে হয় বড়ই ব্যথিত।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mcmlx{সে লোকেদের থেকে নিজেকে লুকোয় তাকে যে সংবাদ দেয়া হয়েছে তার গ্লানির জন্যে। সে কি একে রাখবে হীনতা সত্ত্বেও, না তাকে পুতে ফেলবে মাটির নিচে? তারা যা সিদ্ধান্ত করে তা কি নিকৃষ্ট নয়?\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mcmlxi{যারা পরকালে বিশ্বাস করে না তাদের গুণবত্তা নিকৃষ্ট, আর আল্লাহ্‌র হচ্ছে সর্বোন্নত গুণাবলী। আর তিনি মহাশক্তিশালী, পরমজ্ঞানী।\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mcmlxii{আর আল্লাহ্ যদি মানুষকে পাকড়াও করতেন তাদের অন্যায়াচারণের জন্যে তবে তিনি এর উপরে কোনো জীবজন্তুকেই রাখতেন না, কিন্তু তিনি তাদের অবকাশ দিয়ে থাকেন একটি নির্দিষ্টকাল পর্যন্ত, সেজন্যে যখন তাদের মিয়াদ এসে যায় তখন তারা ঘন্টাখানেকের জন্যেও পিছিয়ে দিতে পারে না, আর এগিয়েও আনতে পারে না।\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mcmlxiii{আর তারা আল্লাহ্‌তে আরোপ করে যা তারা অপছন্দ করে, আর তাদের জিহবা মিথ্যাকথা রচনা করে যে ভাল বিষয়বস্তু তাদের জন্যেই। সন্দেহ নেই যে তাদের জন্য রয়েছে আগুন, আর নিঃসন্দেহ তারা অচিরেই পরিত্যক্ত হবে।\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mcmlxiv{আল্লাহ্‌র কসম! আমরা নিশ্চয়ই তোমার আগে জাতিগুলোর কাছে রসূল পাঠিয়েছিলাম, কিন্তু শয়তান তাদের ক্রিয়াকলাপ তাদের কাছে চিত্তাকর্ষক করেছিল; সেজন্যে সে আজ তাদের মুরব্বী, আর তাদের জন্য রয়েছে মর্মন্তুদ শাস্তি।\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mcmlxv{আর তোমার কাছে আমরা এই গ্রন্থ পাঠাই নি এইজন্য ছাড়া যে তুমি তাদের কাছে সুস্পষ্টভাবে বর্ণনা করবে যে-বিষয়ে তারা মতভেদ করে, আর একটি পথনির্দেশ ও করুণা সেই লোকদের জন্য যারা বিশ্বাস করে।\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mcmlxvi{আর আল্লাহ্ আকাশ থেকে পানি বর্ষণ করেন, আর তা দিয়ে তিনি পৃথিবীকে জীবন্ত করেন তার মৃত্যুর পরে। নিঃসন্দেহ এতে যথার্থ নিদর্শন রয়েছে সেই লোকদের জন্য যারা শোনে।\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mcmlxvii{আর নিঃসন্দেহ গবাদি-পশুর মধ্যে তোমাদের জন্য তো শিক্ষণীয় বিষয় রয়েছে। আমরা তোমাদের পান করাই যা রয়েছে তাদের পেটের মধ্যে -- গোবর ও রক্তের মধ্যে থেকে -- খাঁটি দুধ, পানকারীদের জন্য সুস্বাদু।\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mcmlxviii{আর খেজুর গাছের ও আঙুরলতার ফল থেকে -- তোমরা তাদের থেকে পাও মদিরা ও উত্তম খাদ্যবস্তু। নিঃসন্দেহ এতে প্রকৃত নিদর্শন রয়েছে সেই লোকদের জন্য যারা বুদ্ধি-বিবেচনা প্রয়োগ করে।\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mcmlxix{আর তোমার প্রভু মৌমাছিকে প্রত্যাদেশ দিলেন -- ''বাসা তৈরি কর পাহাড়ের মাঝে ও গাছের মধ্যে, আর তারা যে ঘর তৈরি করে তাতে, --\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mcmlxx{''তারপর প্রত্যেক ফল থেকে খাও, তারপর তোমার প্রভুর রাস্তা অনুসরণ কর সুগম-করা পথে।’’ তাদের পেট থেকে বেরিয়ে আসে একটি পানীয়, বিচিত্র যার বর্ণ, যাতে রয়েছে মানুষের জন্য রোগমুক্তি। নিঃসন্দেহ এতে নিশ্চিত নিদর্শন রয়েছে সেই লোকদের জন্য যারা চিন্তা করে।\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mcmlxxi{আর আল্লাহ্ তোমাদের সৃষ্টি করেছেন, তারপর তিনি তোমাদের মৃত্যু ঘটান। আর তোমাদের মধ্যের কাউকে কাউকে আনা হয় বয়েসের অধমতম দশায়, যার ফলে জ্ঞানলাভের পরে সে কিছুই জানে না। নিঃসন্দেহ আল্লাহ্ সর্বজ্ঞাতা, কর্মক্ষম।\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@mcmlxxii{আর আল্লাহ্ তোমাদের কাউকে অন্য কারও উপরে জীবনোপকরণের ব্যাপারে প্রাধান্য দিয়েছেন। তারপর যাদের প্রাধান্য দেয়া হয়েছে তারা তাদের জীবনোপকরণ দিয়ে দেয় না তাদের ডান হাত যাদের ধরে রেখেছে, যেন এরা এ বিষয়ে সমান হয়ে যায়। তবে কি আল্লাহ্‌র অনুগ্রহকে তারা অস্বীকার করে?\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@mcmlxxiii{আর আল্লাহ তোমাদের জন্য তোমাদের নিজেদের থেকে জোড়া সৃষ্টি করেছেন, আর তোমাদের যুগল থেকে তোমাদের জন্য দিয়েছেন সন্তানসন্ততি ও নাতি-নাতনী, আর তোমাদের রিযেক দান করেছেন উত্তম জিনিস থেকে। তবে কি তারা মিথ্যাতে বিশ্বাস করে এবং আল্লাহ্‌র অনুগ্রহসামগ্রীতে তারাই অবিশ্বাস করে?\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@mcmlxxiv{আর তারা উপাসনা করে আল্লাহ্‌কে ছেড়ে দিয়ে তাদের যারা একটুকুও ক্ষমতা রাখে না মহাকাশমন্ডলী ও পৃথিবী থেকে আসা রিযেকের উপরে, আর তারা কোনো ক্ষমতা রাখে না।\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@mcmlxxv{অতএব আল্লাহ্‌র সঙ্গে কোনো সদৃশ স্থির করো না। নিঃসন্দেহ আল্লাহ্ জানেন আর তোমরা জান না।\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@mcmlxxvi{আল্লাহ্ উপমা দিচ্ছেন অপরের অধিকারভুক্ত একজন দাসের -- কোনো-কিছুর উপরে সে ক্ষমতা রাখে না, আর এমন এক ব্যক্তির যাকে আমাদের তরফ থেকে উত্তম জীবিকা দিয়ে আমরা ভরণপোষণ করেছি, সুতরাং সে তা থেকে গোপনে ও প্রকাশ্যে খরচ করে। তারা কি সমান-সমান? সমস্ত প্রশংসা আল্লাহ্‌র। কিন্তু তাদের অধিকাংশই জানে না।\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@mcmlxxvii{আল্লাহ্ আরো উপমা দিচ্ছেন দুইজন লোকের -- তাদের একজন বোবা, কোনো-কিছুতেই সে ক্ষমতা রাখে না, সে তার মনিবের উপরে একটি বোঝা, তাকে যেখানেই পাঠানো হোক না কেন সে ভাল কিছুই আনতে পারে না। সে এবং সেইব্যক্তি যিনি ন্যায়বিচারের নির্দেশ দেন তারা কি সমান-সমান, আর তিনি রয়েছেন সহজ-সঠিক পথে?\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@mcmlxxviii{আর মহাকাশমন্ডলী ও পৃথিবীর অদৃশ্য বিষয় আল্লাহ্‌র। আর সেই ঘড়িঘন্টার ব্যাপার তো চোখের পলক বা তার চাইতেও নিকটতর বৈ নয়। নিঃসন্দেহ আল্লাহ্ সব-কিছুর উপরে সর্বশক্তিমান।\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@mcmlxxix{আর আল্লাহ্ তোমাদের নির্গত করেছেন তোমাদের মায়েদের গর্ভ থেকে, তোমরা কিছুই জানতে না, আর তোমাদের জন্য তিনি দিয়েছেন শ্রবণশক্তি ও দৃষ্টিশক্তি ও অন্তঃকরণ, যেন তোমরা কৃতজ্ঞতা প্রকাশ করো।\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@mcmlxxx{তারা কি পাখিদের লক্ষ্য করে না -- আকাশের শূন্যগর্ভে ভাসমান? আল্লাহ্ ছাড়া আর কেউ ওদের ধরে রাখে না। নিঃসন্দেহ এতে প্রকৃত নিদর্শন রয়েছে সেই লোকদের জন্য যারা বিশ্বাস করে।\qt@no{(79)}}
\qt@newcmd\qurantrans@bn@mcmlxxxi{আর আল্লাহ্ তোমাদের বাড়িঘরে তোমাদের জন্য আবাসস্থল বানিয়েছেন, আর গবাদি-পশুর চামড়া থেকে তোমাদের জন্য ঘর বানিয়েছেন যা তোমাদের যাত্রার দিনে তোমরা হালকা বোধ কর, আর তোমাদের অবস্থানের দিনেও, আর তাদের পশম ও তাদের লোমশ চামড়া ও তাদের চুল থেকে রয়েছে গৃহস্থালী-বস্তু ও কিছুকালের জন্য উপভোগ-সামগ্রী।\qt@no{(80)}}
\qt@newcmd\qurantrans@bn@mcmlxxxii{আর তিনি যা সৃষ্টি করেছেন তা থেকে আল্লাহ্ তোমাদের জন্য বানিয়েছেন ছায়া, আর পাহাড়ের মধ্যে তোমাদের জন্য তিনি বানিয়েছেন আশ্রয়স্থল, আর তোমাদের জন্য তিনি ব্যবস্থা করেছেন পোশাক যা তোমাদের রক্ষা করে গরম থেকে, আর বর্ম যা তোমাদের রক্ষা করে তোমাদের যুদ্ধবিগ্রহে। এইভাবে তিনি তোমাদের প্রতি তাঁর অনুগ্রহ পরিপূর্ণ করেছেন যেন তোমরা আ‌ত্মসমর্পণ করো।\qt@no{(81)}}
\qt@newcmd\qurantrans@bn@mcmlxxxiii{কিন্তু যদি তারা ফিরে যায় তবে তোমার উপরে তো দায়িত্ব হচ্ছে স্পষ্টভাবে পৌঁছে দেওয়া।\qt@no{(82)}}
\qt@newcmd\qurantrans@bn@mcmlxxxiv{তারা আল্লাহ্‌র অনুগ্রহ চিনতে পারে, তথাপি তারা সেইটি অস্বীকার করে, আর তাদের অধিকাংশই অবিশ্বাসী।\qt@no{(83)}}
\qt@newcmd\qurantrans@bn@mcmlxxxv{আর সেদিন আমরা প্রত্যেক জাতির মধ্যে থেকে এক-এক জন সাক্ষী দাঁড় করাব, তখন যারা অবিশ্বাস করেছিল তাদের অনুমতি দেয়া হবে না, আর তাদের ক্ষমা-প্রার্থনা করতে দেওয়া হবে না।\qt@no{(84)}}
\qt@newcmd\qurantrans@bn@mcmlxxxvi{আর যারা অন্যায়াচরণ করেছে তারা যখন শাস্তি দেখতে পাবে তখন তাদের থেকে তা লাঘব করা হবে না, আর তারা অব্যাহতিও পাবে না।\qt@no{(85)}}
\qt@newcmd\qurantrans@bn@mcmlxxxvii{আর যারা অংশী দাঁড় করিয়েছিল তারা যখন তাদের দেবতাদের দেখতে পাবে তখন তারা বলবে -- ''আমাদের প্রভু! এরাই আমাদের ঠাকুরদেবতা যাদের আমরা পূজা করতাম তোমাকে ছেড়ে দিয়ে।’’ তখন তারা তাদের দিকে কথাটা ছুঁড়ে মারবে -- ''নিঃসন্দেহ তোমরাই তো মিথ্যাবাদী।’’\qt@no{(86)}}
\qt@newcmd\qurantrans@bn@mcmlxxxviii{আর তারা সেইদিন আল্লাহ্‌র কাছে আ‌ত্মসমর্পণে ঝোঁকে পড়বে, আর তারা যা উদ্ভাবন করত তা তাদের থেকে বিদায় নেবে।\qt@no{(87)}}
\qt@newcmd\qurantrans@bn@mcmlxxxix{যারা অবিশ্বাস পোষণ করে ও আল্লাহ্‌র পথ থেকে ফিরিয়ে রাখে, আমরা শাস্তির উপরে তাদের জন্য শাস্তি বাড়িয়ে দেব, যেহেতু তারা অশান্তি সৃষ্টি করত।\qt@no{(88)}}
\qt@newcmd\qurantrans@bn@mcmxc{আর সেদিন আমরা প্রত্যেক জাতির মধ্যে দাঁড় করাব তাদের মধ্যে থেকে তাদের বিষয়ে এক-একজন সাক্ষী, আর তোমাকে আমরা আনব একজন সাক্ষীরূপে এদের উপরে। আর তোমার কাছে আমরা অবতারণ করেছি ধর্মগ্রন্থ সব বিষয়ের সুস্পষ্ট ব্যাখ্যাস্বরূপ আর পথনির্দেশ ও করুণা এবং আ‌ত্মসমর্পণকারীদের জন্য সুসংবাদ-স্বরূপ।\qt@no{(89)}}
\qt@newcmd\qurantrans@bn@mcmxci{নিঃসন্দেহ আল্লাহ্ নির্দেশ দিচ্ছেন ন্যায়পরায়ণতার, আর সদাচরণের, ও আ‌ত্মীয়স্বজনকে দানদক্ষিণা করার, আর তিনি নিষেধ করেছেন অশালীনতা, আর দুষ্কৃতি, ও বিদ্রোহাচরণ। তিনি তোমাদের উপদেশ দিচ্ছেন যেন তোমরা মনোযোগ দাও।\qt@no{(90)}}
\qt@newcmd\qurantrans@bn@mcmxcii{আর আল্লাহ্‌র অংগীকার পূরণ করো যখনি তোমরা কোনো অংগীকার করে থাক, আর প্রতিজ্ঞাগুলো ভঙ্গ করো না সেগুলোর দৃঢ়ীকরণের পরে, অথচ তোমরা আল্লাহ্‌কে তোমাদের মধ্যে জামিন করেছ। নিঃসন্দেহ আল্লাহ্ জানেন যা তোমরা করছ।\qt@no{(91)}}
\qt@newcmd\qurantrans@bn@mcmxciii{আর সেই নারীর মতো হয়ো না যে তার সুতো খুলে ফেলে টুকরো টুকরো ক’রে তা মজবুত করে বোনার পরে। তোমাদের শপথগুলোকে তোমাদের মধ্যে ছলনার জন্যে তোমরা ব্যবহার করছ, যেন তোমাদের এক জাতি অন্য জাতির চাইতে ক্ষমতাশীল হতে পার। আল্লাহ্ অবশ্যই এর দ্বারা তোমাদের পরীক্ষা করছেন, আর যেন কিয়ামতের দিনে তোমাদের কাছে সুস্পষ্ট করতে পারেন যে- বিষয়ে তোমরা মতভেদ করছিলে।\qt@no{(92)}}
\qt@newcmd\qurantrans@bn@mcmxciv{আর আল্লাহ্ যদি ইচ্ছা করতেন তবে তিনি নিশ্চয়ই তোমাদের এক জাতিভুক্ত করে দিতেন, কিন্তু তিনি পথহারা হতে দেন যাকে ইচ্ছে করেন, আর যাকে ইচ্ছে সৎপথে পরিচালিত করেন। আর তোমাদের অতিঅবশ্য জিজ্ঞাসা করা হবে যা তোমরা করে যাচ্ছিলে সে-সন্বন্ধে।\qt@no{(93)}}
\qt@newcmd\qurantrans@bn@mcmxcv{আর তোমাদের শপথগুলোকে তোমাদের মধ্যে ছলনার জন্যে ব্যবহার করো না, পাছে পা পিছলে যায় তা সুপ্রতিষ্ঠিত হবার পরে, আর তোমরা মন্দের আস্বাদ গ্রহণ করবে যেহেতু তোমরা আল্লাহ্‌র পথ থেকে ফিরে গেছ, আর তোমাদের জন্য রয়েছে কঠোর শাস্তি।\qt@no{(94)}}
\qt@newcmd\qurantrans@bn@mcmxcvi{আর তোমরা আল্লাহ্‌র অংগীকারকে স্বল্প মূল্যে বিনিময় করো না। নিঃসন্দেহ যা আল্লাহ্‌র কাছে রয়েছে তা তোমাদের জন্য শ্রেষ্ঠ, যদি তোমরা জানতে!\qt@no{(95)}}
\qt@newcmd\qurantrans@bn@mcmxcvii{যা তোমাদের কাছে রয়েছে তা খতম হয়ে যায়, আর যা আল্লাহ্‌র কাছে আছে তা স্থায়ী। আর যারা অধ্যবসায় অবলন্বন করে তাদের পারিশ্রমিক আমরা অবশ্যই প্রদান করব তারা যা করে যাচ্ছে তার শ্রেষ্ঠ প্রতিদানরূপে।\qt@no{(96)}}
\qt@newcmd\qurantrans@bn@mcmxcviii{পুরুষ অথবা নারীর মধ্যে যে কেউ সৎকর্ম করে, আর সে মূমিন হয়, তাকেই তবে আমরা নিশ্চয়ই জীবনধারণ করতে দেবো সুন্দর জীবনে আর তাদের পারিশ্রমিক আমরা অবশ্যই তাদের প্রদান করব তারা যা করে যাচ্ছে তার শ্রেষ্ঠ প্রতিদানরূপে।\qt@no{(97)}}
\qt@newcmd\qurantrans@bn@mcmxcix{সুতরাং যখন তোমরা কুরআন পাঠ করবে তখন আল্লাহ্‌র কাছে আশ্রয় চাও ভ্রষ্ট শয়তানের থেকে।\qt@no{(98)}}
\qt@newcmd\qurantrans@bn@mm{নিঃসন্দেহ সে -- তার কোনো আধিপত্য নেই তাদের উপরে যারা ঈমান এনেছে এবং তাদের প্রভুর উপরেই নির্ভর করছে।\qt@no{(99)}}
\qt@newcmd\qurantrans@bn@mmi{তার আধিপত্য তো কেবল তাদের উপরে যারা তাকে বন্ধুরূপে গ্রহণ করছে, আর সেই লোকদের যারা তাঁর সঙ্গে অংশী দাঁড় করায়।\qt@no{(100)}}
\qt@newcmd\qurantrans@bn@mmii{আর যখন আমরা বদল করে আনি একটি আয়াত অন্য আয়াতের স্থলে, আর আল্লাহ্ ভাল জানেন যা তিনি অবতারণ করছেন, তারা বলে -- ''নিঃসন্দেহ তুমি একজন জালিয়াত।’’ কিন্তু তাদের অধিকাংশই জানে না।\qt@no{(101)}}
\qt@newcmd\qurantrans@bn@mmiii{তুমি বলো যে রুহুল কুদুস তোমার প্রভুর কাছ থেকে সত্যসহ এটি অবতারণ করেছে যেন তিনি দৃঢ়প্রতিষ্ঠিত করতে পারেন তাদের যারা ঈমান এনেছে, আর পথনির্দেশ ও সুসংবাদরূপে আ‌ত্মসমর্পণকারীদের জন্য।\qt@no{(102)}}
\qt@newcmd\qurantrans@bn@mmiv{আর আমরা অবশ্যই জানি যে তারা বলে -- ''নিঃসন্দেহ তাঁকে তো কোনো এক মানুষ শেখায়।’’ ওরা যার প্রতি ইঙ্গিত করে তার ভাষা ভিন্নদেশীয়, অথচ এটি পরিস্কার আরবী ভাষা।\qt@no{(103)}}
\qt@newcmd\qurantrans@bn@mmv{নিঃসন্দেহ যারা আল্লাহ্‌র বাণীসমূহে বিশ্বাস করে না আল্লাহ্ তাদের পথ দেখাবেন না, আর তাদের জন্য রয়েছে মর্মন্তুদ শাস্তি।\qt@no{(104)}}
\qt@newcmd\qurantrans@bn@mmvi{কেবল তারাই মিথ্যা উদ্ভাবন করে যারা আল্লাহ্‌র বাণীসমূহে বিশ্বাস করে না, আর তারা নিজেরাই হচ্ছে মিথ্যাবাদী।\qt@no{(105)}}
\qt@newcmd\qurantrans@bn@mmvii{আর যে আল্লাহতে অবিশ্বাস পোষণ করে তার বিশ্বাস স্থাপনের পরে, -- সে ছাড়া যে বাধ্য হয় অথচ তার হৃদয় ঈমানে অবিচলিত থাকে -- কিন্তু তার ক্ষেত্রে যে অবিশ্বাসের জন্য বক্ষ প্রসারিত করে, তাদের উপরেই তবে আল্লাহ্‌র ক্রোধ, আর তাদের জন্য রয়েছে কঠোর শাস্তি।\qt@no{(106)}}
\qt@newcmd\qurantrans@bn@mmviii{এটি এইজন্য যে তারা এই দুনিয়ার জীবনকে পরকালের চেয়ে বেশী ভালবাসে, আর এইজন্য যে আল্লাহ্ অবিশ্বাসী সম্প্রদায়কে, পথ দেখান না।\qt@no{(107)}}
\qt@newcmd\qurantrans@bn@mmix{এরাই তারা যাদের হৃদয়ের উপরে ও যাদের কানের উপরে ও যাদের চোখের উপরে আল্লাহ্ মোহর মেরে দিয়েছেন, আর তারা নিজেরাই হচ্ছে বেখেয়াল।\qt@no{(108)}}
\qt@newcmd\qurantrans@bn@mmx{কোনো সন্দেহ নেই যে পরকালে তারা নিজেরাই হবে ক্ষতিগ্রস্ত।\qt@no{(109)}}
\qt@newcmd\qurantrans@bn@mmxi{তারপর তোমার প্রভু নিশ্চয়ই -- যারা হিজরত করে নির্যাতিত হবার পরে, তারপর জিহাদ করে ও অধ্যবসায় চালায় -- নিঃসন্দেহ তোমার প্রভু এর পরে অবশ্যই পরিত্রাণকারী, অফুরন্ত ফলদাতা।\qt@no{(110)}}
\qt@newcmd\qurantrans@bn@mmxii{সেইদিন প্রত্যেক সত্ত্বা আপন আ‌ত্মার জন্য ওকালতি ক’রে আসবে, আর প্রত্যেক সত্ত্বাকে পুরো প্রাপ্য দেওয়া হবে যা সে করেছে তার জন্য, আর তাদের প্রতি অন্যায় করো হবে না।\qt@no{(111)}}
\qt@newcmd\qurantrans@bn@mmxiii{আর আল্লাহ্ একটি উপমা ছুড়ঁছেন -- একটি শহর যা নিরাপত্তায় ও নিশ্চিন্তে ছিল, এর রিযেক সব দিক থেকে প্রচুর পরিমাণে এর কাছে আসত, তারপর আল্লাহ্‌র অনুগ্রহাবলী সন্বন্ধে সে অকৃতজ্ঞ হলো, কাজেই তারা যা করে চলেছিল সেজন্য আল্লাহ্ তাকে আস্বাদন করালেন ক্ষুধার আবরণ দিয়ে ও ভয় দিয়ে।\qt@no{(112)}}
\qt@newcmd\qurantrans@bn@mmxiv{আর আলবৎ তাদের কাছে তাদের মধ্যে থেকে একজন রসূল এসেছিলেন, কিন্তু তারা তাঁর প্রতি মিথ্যারোপ করল, সুতরাং শাস্তি তাদের পাকড়াও করল যখন তারা ছিল অন্যায়কারী।\qt@no{(113)}}
\qt@newcmd\qurantrans@bn@mmxv{অতএব আল্লাহ্ তোমাদের যে-সব বৈধ ও পবিত্র রিযেক দিয়েছেন তা থেকে তোমরা আহার করো, আর আল্লাহ্‌ব অনুগ্রহাবলীর জন্য কৃতজ্ঞতা জ্ঞাপন কর যদি তোমরা তাঁকেই উপাসনা করে থাকো।\qt@no{(114)}}
\qt@newcmd\qurantrans@bn@mmxvi{নিঃসন্দেহ তিনি তোমাদের জন্য অবৈধ করেছেন যা নিজে মরে, ও রক্ত, ও শূকরের মাংস, আর যা হালাল করা হয়েছে তার উপরে আল্লাহ্‌র নাম ছাড়া, কিন্তু যে কেউ চাপে পড়েছে, অবাধ্য না হয়ে বা মাত্রা না ছাড়িয়ে, তবে আল্লাহ্ নিঃসন্দেহ পরিত্রাণকারী, অফুরন্ত ফলদাতা।\qt@no{(115)}}
\qt@newcmd\qurantrans@bn@mmxvii{আর যেহেতু তোমাদের জিহবা মিথ্যা বলায় পটু, তাই তোমরা বলো না -- ''এটি বৈধ ও এটি অবৈধ’’, -- আল্লাহ্‌র নামে মিথ্যা আরোপ ক’রে। নিঃসন্দেহ যারা আল্লাহ্‌র নামে মিথ্যা রচনা করে তারা উন্নতিলাভ করবে না।\qt@no{(116)}}
\qt@newcmd\qurantrans@bn@mmxviii{সামান্য সুখ-সম্ভোগ, আর তাদের জন্য মর্মন্তুদ শাস্তি।\qt@no{(117)}}
\qt@newcmd\qurantrans@bn@mmxix{আর যারা ইহুদী মত পোষণ করে তাদের জন্য যা আমরা অবৈধ করেছিলাম তা ইতিপূর্বে তোমার কাছে আমরা বর্ণনা করেছি, আর তাদের প্রতি আমরা কোনো অন্যায় করি নি, বরং তারা তাদের নিজেদের প্রতিই অন্যায় করছিল।\qt@no{(118)}}
\qt@newcmd\qurantrans@bn@mmxx{অতঃপর নিঃসন্দেহ তোমার প্রভু -- যারা অজ্ঞতাবশতঃ পাপ করে, এবং তার পরে ফেরে ও সৎকর্ম করে, তাদের জন্য তোমার প্রভু নিশ্চয়ই এর পরে পরিত্রাণকারী, অফুরন্ত ফলদাতা।\qt@no{(119)}}
\qt@newcmd\qurantrans@bn@mmxxi{নিঃসন্দেহ ইব্রাহীম ছিলেন এক সম্প্রদায়, আল্লাহ্‌র অনুগত, একনিষ্ঠ। আর তিনি বহুখোদাবাদীদের অন্তর্ভুক্ত ছিলেন না, --\qt@no{(120)}}
\qt@newcmd\qurantrans@bn@mmxxii{তাঁর অনুগ্রহাবলীর জন্য কৃতজ্ঞ। তিনি তাঁকে পরিচালিত করেছিলেন সহজ-সঠিক পথের দিকে।\qt@no{(121)}}
\qt@newcmd\qurantrans@bn@mmxxiii{আর আমরা তাঁকে দুনিয়াতে কল্যাণ দিয়েছিলাম, আর তিনি পরকালেও নিশ্চয়ই হচ্ছেন সাধুপুরুষদের অন্তর্ভুক্ত।\qt@no{(122)}}
\qt@newcmd\qurantrans@bn@mmxxiv{অতঃপর আমরা তোমার কাছে প্রত্যাদেশ দিয়েছিলাম এই বলে -- ''একনিষ্ঠ ইব্রাহীমের ধর্মমতের অনুসরণ কর, আর তিনি বহুখোদাবাদীদের মধ্যেকার ছিলেন না।’’\qt@no{(123)}}
\qt@newcmd\qurantrans@bn@mmxxv{নিঃসন্দেহ সাব্বাতের নিয়ম ধার্য করা হয়েছিল কেবল তাদের জন্য যারা এ-সন্বন্ধে মতভেদ করেছিল। আর তোমার প্রভু অবশ্যই তাদের মধ্যে কিয়ামতের দিনে মীমাংসা করে দেবেন যে-বিষয়ে ওরা মতভেদ করত সেই বিষয়ে।\qt@no{(124)}}
\qt@newcmd\qurantrans@bn@mmxxvi{তোমার প্রভুর রাস্তায় আহ্বান করো জ্ঞান ও সুষ্ঠু উপদেশের দ্বারা, আর তাদের সাথে পর্যালোচনা কর এমনভাবে যা শ্রেষ্ঠ। নিঃসন্দেহ তোমার প্রভু স্বয়ং ভাল জানেন তাকে যে তাঁর পথ থেকে ভ্রষ্ট হয়েছে, আর তিনি ভাল জানেন সৎপথাবলন্বীদের।\qt@no{(125)}}
\qt@newcmd\qurantrans@bn@mmxxvii{আর যদি তোমরা আঘাত দাও তবে আঘাত দিয়ো যেমন তোমাদের আঘাত দেওয়া হয়েছিল তেমনিভাবে। আর যদি তোমরা অধ্যাবসায় অবলন্বন কর সেটি তাহলে অধ্যবসায়ীদের জন্য আরো ভাল।\qt@no{(126)}}
\qt@newcmd\qurantrans@bn@mmxxviii{আর তুমি অধ্যবসায় অবলন্বন কর, আর তোমার অধ্যবসায় আল্লাহ্ থেকে বৈ নয়, আর তুমি তাদের কারণে আফসোস করো না, আর তুমি মনঃক্ষুন্ন হয়ো না তারা যা চক্রান্ত করে সেজন্য।\qt@no{(127)}}
\qt@newcmd\qurantrans@bn@mmxxix{নিঃসন্দেহ আল্লাহ্ তাদের সাথে রয়েছেন যারা ধর্মপরায়ণতা অবলন্বন করে ও যারা স্বয়ং সৎকর্মপরায়ণ।\qt@no{(128)}}
\qt@newcmd\qurantrans@bn@mmxxx{\basmalahbn সকল মহিমা তাঁর যিনি তাঁর বান্দাকে রাত্রিবেলা ভ্রমণ করিয়েছিলেন পবিত্র মসজিদ থেকে দূরবর্তী মসজিদে -- যার পরিবেশ আমরা মঙ্গলময় করেছিলাম যেন আমরা তাঁকে দেখাতে পারি আমাদের কিছু নিদর্শন। নিঃসন্দেহ তিনি স্বয়ং সর্বশ্রোতা, সর্বদ্রষ্টা।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmxxxi{আর আমরা মুসাকে গ্রন্থ দিয়েছিলাম আর ইসরাইল বংশীয়দের জন্য আমরা একে পথনির্দেশক বানিয়েছিলাম এই বলে -- ''আমাকে ছেড়ে দিয়ে কোনো কর্ণধার গ্রহণ করো না।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmxxxii{''তাদের বংশধর যাদের আমরা নূহ-এর সঙ্গে বহন করেছিলাম। নিঃসন্দেহ তিনি ছিলেন একজন কৃতজ্ঞ বান্দা।’’\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmxxxiii{আর আমরা ইসরাইল বংশীয়দের কাছে গ্রন্থের মধ্যে স্পষ্ট জানিয়েছিলাম -- ''তোমরা অবশ্য দুইবার পৃথিবীতে বিপর্যয় সৃষ্টি করবে, আর তোমরা নিশ্চয়ই ঘোর অহঙ্কারে অহঙ্কার করবে।’’\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmxxxiv{অতঃপর যখন এই দুয়ের প্রথম ওয়াদার সময় এল তখন আমরা তোমাদের বিরুদ্ধে পাঠালাম আমার অতিশয় শক্তিশালী বান্দাদের, তাই তারা ঘরে অন্দরমহলে ঢুকে ধ্বংসলীলা শুরু করল। আর এই ওয়াদা কার্যকর হয়েই ছিল।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmxxxv{তারপর আমরা তাদের উপরে তোমাদের ফিরিয়ে দিলাম পালটা মোড, আর তোমাদের সাহায্য করলাম ধনসম্পদ ও সন্তান-সন্ততি দিয়ে, আর দলেবলে তোমাদের গরিষ্ট করলাম।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmxxxvi{তোমরা যদি সৎকাজ কর তবে তোমাদের নিজেদের জন্যেই সৎকাজ করছো, আর যদি তোমরা মন্দ কর তবে তাও নিজেদের জন্যে। সুতরাং যখন পরবর্তী ওয়াদার সময় এল তখন যেন তারা তোমাদের মুখমন্ডল কালিমাচ্ছন্ন করতে পারে, আর যেন তারা মসজিদে ঢুকতে পারে যেমন ওরা প্রথমবার এতে ঢুকেছিল, আর যেন তারা পূর্ণ বিধ্বংসে ধ্বংস করতে পারে যা-কিছু তারা দখল করে।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmxxxvii{হতে পারে যে তোমাদের প্রভু তোমাদের প্রতি করুণা করবেন, কিন্তু যদি তোমরা ফেরো তবে আমরাও ফিরব। আর আমরা অবিশ্বাসীদের জন্য জাহান্নামকে কয়েদখানা বানিয়েছি।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmxxxviii{নিঃসন্দেহ এই কুরআন পথ দেখায় সেইদিকে যা সঠিক, আর মুমিনদের যারা সৎকর্ম করে তাদের সুসংবাদ দেয় যে তাদের জন্য রয়েছে মহান পারিশ্রমিক।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmxxxix{আর যারা পরকালে বিশ্বাস করে না তাদের জন্য আমরা তৈরি করেছি মর্মন্তুদ শাস্তি।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmxl{আর মানুষ মন্দের জন্য কামনা করে যেমন তার উচিত ভালোর জন্য কামনা করা। আর মানুষ সদা ব্যস্ত-সমস্ত।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmxli{আর আমরা রাতকে এবং দিনকে বানিয়েছি দুটি নিদর্শন, কাজেই রাতের নিদর্শনকে আমরা মুছে ফেলি, আর দিনের নিদর্শনকে বানাই সুদৃশ্য যেন তোমরা তোমাদের প্রভুর কাছ থেকে করুণাভান্ডার অণ্বেষণ করতে পার, আর যেন তোমরা বছরের গণনা ও হিসাব জানতে পার। আর সব-কিছুই আমরা বর্ণনা করেছি বিশদভাবে।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmxlii{আর প্রত্যেকটি মানুষ -- আমরা তার পাখি তার গলায় বেঁধে দিয়েছি। আর কিয়ামতের দিনে আমরা তার জন্য বের করে দেব একটি খাতা যা সে দেখতে পাবে সম্পূর্ণ খোলা।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmxliii{''পড় তোমার গ্রন্থ, -- আজকের দিনে তোমার আ‌ত্মাই তোমার উপরে হিসাব-তলবকারীরূপে যথেষ্ট।’’\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmxliv{যে কেউ সঠিক পথে চলে সে তো তবে নিজের জন্যেই সঠিক পথ ধরে, আর যে বিপথে যায় সে তো তবে নিজের বিরুদ্ধেই বিপথে চলে। আর একজন বোঝা বহনকারী অন্যের বোঝা বহন করবে না। আর আমরা শাস্তিদাতা নই যে পর্যন্ত না আমরা কোনো রসূল পাঠিয়েছি।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmxlv{আর যখন আমরা মনস্থ করি যে কোনো জনপদকে আমরা ধ্বংস করব তখন আমরা ওর সমৃদ্ধিশালী লোকদের কাছে নির্দেশ পাঠাই, কিন্তু তারা সেখানে গুন্ডামি করে, কাজেই আজ্ঞা তার উপরে ন্যায়সংগত হয়ে যায়। সুতরাং আমরা তাকে ধ্বংস করি পূর্ণ বিধ্বংসে।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmxlvi{আর নূহ্‌-এর পরে কত জনপদকে আমরা ধ্বংস করেছি! আর তোমার প্রভুই তাঁর বান্দাদের পাপাচার সন্বন্ধে খবরদার, দর্শকরূপে যথেষ্ট।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmxlvii{যে কেউ কামনা করে বর্তমানকাল, আমরা তার জন্য সে-ক্ষেত্রে যা ইচ্ছা করি তাই ত্বরান্বিত করি -- যার জন্য আমরা মনস্ত করি, তারপর তার জন্যে আমরা ধার্য করি জাহান্নাম, তাতে সে প্রবেশ করবে নিন্দিত বিতাড়িত হয়ে।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmxlviii{আর যে কেউ পরকাল কামনা করে, আর তার জন্যে চেষ্টা করে যথাযথ প্রচেষ্টায় এবং সে মুমিন হয়, তাহলে এরাই -- এদের প্রচেষ্টা হবে স্বীকৃত।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmxlix{প্রত্যেককেই আমরা দিই, এদের এবং ওদের, তোমার প্রভুর দানসামগ্রী থেকে। আর তোমার প্রভুর দানসামগ্রী সীমাবদ্ধ নয়।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mml{দেখ কেমন ক’রে আমরা তাদের কাউকে শ্রেষ্ঠত্ব দিয়েছি অন্যের উপরে। আর পরকাল নিশ্চয়ই মর্যাদার দিক দিয়ে শ্রেষ্ঠ এবং মহিমার দিক দিয়েও শ্রেষ্ঠ।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmli{আল্লাহ্‌র সাথে অন্য উপাস্য খাড়া করো না, পাছে তুমি বসে থাক নিন্দিত নিঃসহায় হয়ে।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmlii{আর তোমার প্রভু বিধান করেছেন -- তাঁকে ছাড়া তোমরা অন্যের উপাসনা করো না, আর পিতামাতার প্রতি সদ্ব্যবহার। যদি তোমাদের সামনে তাদের একজন বা উভয়ে বার্ধক্যে পৌঁছোয় তবুও তাদের প্রতি ''আঃ’’ বলো না, আর তাদের তিরস্কার করো না, বরং তাদের প্রতি বলবে বিনয়নম্র কথা।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmliii{আর তাদের উভয়ের প্রতি আনত করো করুণার সাথে আনুগত্যের ডানা দুখানা, আর বলো -- ''আমার প্রভু! তাঁদের উভয়ের প্রতি করুণা করো যেমন তাঁরা ছোটবেলায় আমাকে প্রতিপালন ক’রে বড় করেছন।’’\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmliv{তোমাদের প্রভু ভাল জানেন তোমাদের অন্তরে যা-কিছু আছে। তোমরা যদি সৎকর্মপরায়ণ হও তবে নিঃসন্দেহ তিনি মুখাপেক্ষীদের প্রতি পরিত্রাণকারী।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmlv{আর নিকটা‌ত্মীয়কে দাও তার প্রাপ্য, আর অভাবগ্রস্তকে ও পথচারীকেও, আর অপব্যয় করো না অপচয়ের সাথে।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmlvi{নিঃসন্দেহ অপব্যয়ীরা হচ্ছে শয়তানগোষ্ঠীর ভাই-বিরাদর। আর শয়তান হচ্ছে তার প্রভুর প্রতি বড় অকৃতজ্ঞ।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmlvii{আর তুমি যদি তাদের থেকে বিমুখ হও অথচ তোমার প্রভুর কাছ থেকে অনুগ্রহ লাভ করতে চাও যা তুমি প্রত্যাশা কর, তাহলে তাদের সঙ্গে সদয় সুরে কথা বলো।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmlviii{আর তোমার হাত তোমার গলার সঙ্গে আটকে রেখো না, আর তা প্রসারিত করো না পুরো সম্প্রসারণে, পাছে তুমি বসে থাক নিন্দিত সর্বস্বান্ত হয়ে।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmlix{নিঃসন্দেহ তোমার প্রভু রিযেক বাড়িয়ে দেন যার জন্য তিনি ইচ্ছে করেন আর মেপেজোখে দেন। নিঃসন্দেহ তিনি তাঁর বান্দাদের চির ওয়াকিফহাল, সর্বদ্রষ্টা।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmlx{আর তোমাদের সন্তানসন্ততিকে হত্যা করো না দারিদ্রের ভয়ে। আমরাই তাদের রিযেক দিই আর তোমাদেরও। নিঃসন্দেহ তাদের মেরে ফেলা এক মহাপাপ।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmlxi{আর ব্যভিচারের ধারেকাছেও যেয়ো না, নিঃসন্দেহ তা একটি অশ্লীলতা, আর এটি এক পাপের পথ।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmlxii{আর কোনো সত্ত্বাকে যথাযথ কারণ ব্যতীত হত্যা করো না যাকে আল্লাহ্ নিষেধ করেছেন। আর যে কেউ অন্যায়ভাবে নিহত হয় ইতিমধ্যে আমরা তো তার অভিভাবককে অধিকার দিয়েছি, কাজেই হত্যার ব্যাপারে সে যেন বাড়াবাড়ি না করে। সে নিশ্চয়ই সাহায্যপ্রাপ্ত হবে।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmlxiii{আর এতীমের সম্পত্তির কাছে যেও না যা শ্রেষ্ঠতম সেই উদ্দেশ্য ব্যতীত, যে পর্যন্ত না সে তার সাবালকত্বে পৌঁছে। আর প্রতি‌শ্রুতি পালন করো, নিঃসন্দেহ প্রতি‌শ্রুতি সন্বন্ধে প্রশ্ন করা হবে।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmlxiv{আর পুরো মাপ দিয়ো যখন তোমরা মাপজোখ কর, আর ওজন করো সঠিক পাল্লায়। এটিই উত্তম আর পরিণামে শ্রেষ্ঠ।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmlxv{আর যে বিষয়ে তোমার কোনো জ্ঞান নেই তার অনুসরণ করো না। নিঃসন্দেহ শ্রবণশক্তি ও দৃষ্টিশক্তি ও অন্তঃকরণ -- এ দের প্রত্যেকটিকে তাদের সন্বন্ধে সওয়াল করা হবে।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmlxvi{আর দুনিয়াতে গর্বভরে চলাফেরা করো না, নিঃসন্দেহ তুমি তো কখনো পৃথিবীটাকে এফোঁড়-ওফোঁড় করতে পারবে না আর উচ্চতায় পাহাড়ের নাগালও পেতে পারবে না।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmlxvii{এইসব -- এগুলোর যা মন্দ তা তোমার প্রভুর কাছে ঘৃণ্য।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmlxviii{এগুলো হচ্ছে তোমার প্রভু জ্ঞানের বিষয়ে তোমার কাছে যা প্রত্যাদেশ করেছেন তার মধ্যে থেকে। সুতরাং আল্লাহ্‌র সঙ্গে অন্য উপাস্য দাঁড় করো না, পাছে তুমি জাহান্নামে নিক্ষিপ্ত হয়ে যাও নিন্দিত পরিত্যক্ত অবস্থায়।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmlxix{তবে কি তোমাদের প্রভু তোমাদেরে ভূষিত করেছেন পুত্রসন্তানদের দিয়ে, এবং তিনি নিয়েছেন ফিরিশ্‌তাদের থেকে কন্যাসব? নিঃসন্দেহ তোমরা তো বলছ এক ভয়ানক কথা!\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmlxx{আর আমরা এই কুরআনে বারবার বিবৃত করেছি যেন তারা স্মরণ করে। কিন্তু এটি তাদের বিতৃষ্ণা ছাড়া আর কিছু বাড়ায় না।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmlxxi{বলো -- ''তারা যেমন বলে তাঁর সঙ্গে যদি তেমন আরো উপাস্য থাকত তবে তারা আরশের অধিপতির প্রতি পথ খোঁজতো।’’\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmlxxii{তাঁরই সমস্ত মহিমা! আর তারা যা বলে তা হতে তিনি মহিমান্নিত, বহু ঊর্ধ্বে!\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmlxxiii{সাত আসমান ও জমিন এবং তাদের মধ্যে যারা রয়েছে তারা তাঁর মহিমা ঘোষণা করে। আর এমন কিছু নেই যা তাঁর প্রশংসার সাথে মহিমা ঘোষণা করে না, কিন্তু তোমরা তাদের মহিমাকীর্তন অনুধাবন করতে পার না। নিঃসন্দেহ তিনি হচ্ছেন অতি অমায়িক, পরিত্রাণকারী।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmlxxiv{আর যখন তুমি কুরআন পাঠ কর তখন তোমার মধ্যে ও যারা পরকালে বিশ্বাস করে না তাদের মধ্যে আমরা স্থাপন করি এক অদৃশ্য পর্দা।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmlxxv{আর আমরা তাদের হৃদয়ের উপরে এক আবরণ দিয়ে দিয়েছি পাছে তারা এটি উপলব্ধি করতে পারে, আর তাদের কানে বধিরতা। আর যখন তুমি কুরআনে তোমার প্রভুব -- তাঁর একত্বের উল্লেখ কর তখন তারা তাদের পিঠ ঘুরিয়ে ফিরে যায় বিতৃষ্ণায়।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmlxxvi{আমরা ভাল জানি যখন তারা এটি শুনতে যায় তখন তারা তোমার প্রতি শোনে, আর যখন তারা সলাপরামর্শ করে, দেখো! অন্যায়কারীরা বলে -- ''তোমরা তো শুধু এক জাদুগ্রস্ত লোককে অনুসরণ করছ।’’\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmlxxvii{দেখো, কিরূপ উপমা তারা তোমার জন্য ছোঁড়ে, কাজেই তারা বিপথে গেছে, সুতরাং তারা পথ পাবার সামর্থ্য রাখে না।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmlxxviii{আর তারা বলে -- ''কি! আমরা যখন হাড্ডি ও চূর্ণ-বিচূর্ণ হয়ে যাব, তখন কি আমরা নতুন সৃষ্টিতে পুনরুত্থিত হব?’’\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmlxxix{বলো -- ''তোমরা পাথর অথবা লোহা হয়ে যাও,\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmlxxx{''অথবা আর কোনো সৃষ্টবস্তু যা তোমাদের ধারণায় আরো শক্ত!’’ তখন তারা বলবে -- ''কে আমাদের ফিরিয়ে আনবে?’’ বলো -- ''যিনি তোমাদের প্রথমবারে সৃষ্টি করেছিলেন।’’ তখন তারা তোমার দিকে তাদের মাথা নাড়বে ও বলবে -- ''এ কখন হবে!’’ তুমি বলো -- ''হতে পারে এ নিকটবর্তী।’’\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmlxxxi{যেদিন তিনি তোমাদের ডাকবেন তখন অচিরেই তোমরা সাড়া দেবে তাঁর প্রশংসার সাথে, আর তোমরা ভাববে যে তোমরা তো অবস্থান করছিলে শুধু অল্পক্ষণ।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmlxxxii{আর আমার বান্দাদের বল যে তারা যেন কথা বলে যা সর্বোৎকৃষ্ট। নিঃসন্দেহ শয়তান তাদের মধ্যে বিরোধের উসকানি দেয়। শয়তান মানুষের জন্য নিশ্চয় প্রকাশ্য শত্রু।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmlxxxiii{তোমাদের প্রভু তোমাদের ভালভাবে জানেন। তিনি যদি ইচ্ছে করেন তবে তিনি তোমাদের প্রতি করুণা করবেন, অথবা তিনি যদি চান তো তোমাদের শাস্তি দেবেন। আর তোমাকে আমরা পাঠাই নি তাদের উপরে কর্ণধাররূপে।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmlxxxiv{আর তোমার প্রভু ভাল জানেন তাদের যারা আছে মহাকাশমন্ডলীতে ও পৃথিবীতে। আর আমরা নিশ্চয় কোনো-কোনো নবীকে প্রাধান্য দিয়েছি অন্যদের উপরে, আর দাউদকে আমরা দিয়েছিলাম যবূর।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mmlxxxv{বলো -- ''তাঁকে ছেড়ে দিয়ে তোমরা যাদের প্রতি ঝোঁকো তাদের ডাকো, কিন্তু তারা তোমাদের থেকে বিপদ-আপদ দূর করার কোনো ক্ষমতা রাখে না, আর তা বদলাবারও না।’’\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mmlxxxvi{ঐ সব যাদের তারা ডাকে তারা তাদের প্রভুর কাছে অছিলা খোঁজে -- তাদের মধ্যের কে হবে নিকটতম, আর তারা তাঁর করুণার প্রত্যাশা করে ও তাঁর শাস্তির ভয় করে। নিঃসন্দেহ তোমার প্রভুর শাস্তিকে এড়িয়ে চলতে হবে।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mmlxxxvii{আর এমন কোনো জনপদ নেই যাকে না আমরা কিয়ামতের দিনের আগে বিধ্বংস করব, অথবা কঠোর শাস্তিতে তাদের শাস্তি দেব। এটি গ্রন্থের মধ্যে লিপিবদ্ধ অবস্থায় রয়েছে।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mmlxxxviii{আর আমাদের নিদর্শনসমূহ পাঠাতে কিছুই আমাদের বাধা দেয় না এ ভিন্ন যে প্রাচীনকালীনরা সে-সব প্রত্যাখ্যান করেছিল। আর আমরা ছামূদ জাতিকে দিয়েছিলাম উষ্টী -- এক স্পষ্ট নিদর্শনরূপে, কিন্তু তারা ওর প্রতি অন্যায় করেছিল। বস্তুতঃ আমরা নিদর্শনসমূহ পাঠাই না হুশিয়াঁর করার জন্যে ছাড়া।\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mmlxxxix{আর স্মরণ করো! আমরা তোমাকে বলেছিলাম -- ''নিঃসন্দেহ তোমার প্রভু মানুষকে ঘেরাও করে আছেন। আর তো মাকে যা দেখিয়েছিলাম সেই দৈবদর্শন আমরা মানুষের জন্যে একটি পরীক্ষার জন্য ছাড়া বানাই নি, আর কুরআনে বর্ণিত অভিশপ্ত বৃক্ষও। আর আমরা তাদের হুশিয়াঁর করছি, কিন্তু এটি তাদের তীব্র অবাধ্যতা ছাড়া আর কিছুই বাড়ায় না।\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mmxc{আর আমরা যখন ফিরিশ্‌তাদের বললাম -- ''আদমকে সিজদা করো’’, তখন তারা সিজদা করল, ইবলিস ব্যতীত। সে বললে -- ''আমি কি তাকে সিজদা করব যাকে তুমি কাদা দিয়ে সৃষ্টি করেছ?’’\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mmxci{সে বললে -- ''দেখুন তো! এই বুঝি সে যাকে আপনি আমার উপরে মর্যাদা দিলেন? কিয়ামতের দিন পর্যন্ত যদি আমাকে আপনি অবকাশ দেন তবে আমি আলবৎ তার বংশধরদের সর্বনাশ করব অল্প কয়েকজন ছাড়া।’’\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mmxcii{তিনি বললেন -- ''চলে যাও! বস্তুতঃ তাদের মধ্যের যে কেউ তোমার অনুসরণ করবে তাহলে জাহান্নামই তোমাদের পরিণতি -- এক পরিপূর্ণ প্রতিফল।\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mmxciii{''আর তাদের যাকে পার তোমার আহ্বানে প্রতারিত কর, আর তাদের উপরে হামলা চালাও তোমার ঘোড়সওয়ারদের দ্বারা, আর তোমার পদাতিক বাহিনীর দ্বারা, আর তাদের অংশী হও ধনসম্পত্তিতে এবং সন্তানসন্ততিতে, আর তাদের ওয়াদা করো।’’ আর শয়তান তাদের প্রতি‌শ্রুতি দেয় না প্রতারণা করা ছাড়া।\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mmxciv{''নিঃসন্দেহ আমার বান্দাদের সন্বন্ধে, -- তাদের উপরে তোমার কোনো প্রভাব নেই।’’ আর কর্ণধাররূপে তোমার প্রভুই যথেষ্ট।\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mmxcv{তোমাদের প্রভু তিনিই যিনি তোমাদের জন্য সাগরে জাহাজ পরিচালিত করেন যেন তোমরা তাঁর করুণাভান্ডার থেকে অনুসন্ধান করতে পার। নিঃসন্দেহ তিনি তোমাদের জন্য সদা অফুরন্ত ফলদাতা।\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mmxcvi{আর যখন সমুদ্রের মধ্যে বিপদ তোমাদের স্পর্শ করে তখন যাদের তোমরা ডাকো তারা চলে যায় কেবলমাত্র তিনি ছাড়া, কিন্তু তিনি যখন তোমাদের উদ্ধার ক’রে তীরে নিয়ে আসেন তখন তোমরা ফিরে যাও। আর মানুষ বড় অকৃতজ্ঞ।\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mmxcvii{তবে কি তোমরা নিশ্চিত বোধ কর যে তিনি কোনো জমির কিনারায় তোমাদের নিশ্চিহ করবেন না অথবা তোমাদের উপরে কোনো কঙ্করময় ঝড় বর্ষণ করবেন না? তখন তোমরা তোমাদের জন্য কোনো কর্ণধার পাবে না।\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mmxcviii{অথবা তোমরা কি নিশ্চিত বোধ কর যে তোমাদের এই দশায় আর একবার নিয়ে যাবেন না, তখন তোমাদের বিরুদ্ধে পাঠাবেন এক প্রচন্ড ঝড় এবং তোমাদের ডুবিয়ে দেবেন যেহেতু তোমরা অবিশ্বাস করেছিলে? তখন তোমরা আমাদের বিরুদ্ধে তোমাদের জন্য এই ব্যাপারে কোনো প্রতিকারকারী পাবে না?\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mmxcix{আর আমরা অবশ্য আদমসন্তানদের মর্যাদাদান করেছি, আর আমরা তাদের বহন করি স্থলে ও জলে, এবং তাদের রিযেক দান করেছি উৎকৃষ্ট বস্তু দিয়ে, আর আমরা যাদের সৃষ্টি করেছি তাদের অনেকের উপরে আমরা তাদের প্রাধান্য দিয়েছি শ্রেষ্ঠত্বের সাথে।\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@mmc{সেইদিন আমরা প্রত্যেক জনসমাজকে আহ্বান করব তাদের ইমাম সহ। সুতরাং যাকে তার কিতাব তার ডান হাতে দেয়া হবে তারা তবে তাদের কিতাব পড়বে, আর তাদের প্রতি খেজুর-বিচির-পাতলা-পরত পরিমাণেও অন্যায় করা হবে না।\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@mmci{আর যে ইহলোকে অন্ধ সে তবে পরলোকেও হবে অন্ধ, এবং পথ থেকে অধিকতর পথভ্রষ্ট।\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@mmcii{আর অবশ্যই তারা মতলব করেছিল তোমার কাছে আমরা যা প্রত্যাদেশ দিয়েছি তা থেকে তোমাকে বিচ্যুত করতে, যেন তুমি আমাদের বিরুদ্ধে তার পরিবর্তে অন্য কিছু জাল কর, আর তখন তারা তোমাকে নিশ্চয়ই গ্রহণ করবে অন্তরঙ্গ বান্ধবরূপে।\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@mmciii{আর আমরা যদি তোমাকে সুপ্রতিষ্ঠিত না করতাম তা’হলে তুমি আলবৎ তাদের প্রতি সামান্য কিছু ঝুঁকেই পড়তে, --\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@mmciv{সেক্ষেত্রে আমরা নিশ্চয় তোমাকে দ্বিগুণ শাস্তি আস্বাদন করাতাম ইহজীবনে এবং দ্বিগুণ মৃত্যুকালে, তখন আমাদের বিরুদ্ধে তোমার জন্য কোনো সাহায্যকারী পাবে না।\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@mmcv{আর তারা নিশ্চয় চেয়েছিল যে দেশ থেকে তোমাকে তারা উৎখাত করবে যাতে তারা তোমাকে সেখানে থেকে বহিস্কার করতে পারে। আর সেক্ষেত্রে তোমার পরে তারা টিকে থাকত না অল্পকাল ছাড়া।\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@mmcvi{এটিই রীতি তোমার আগে আমাদের রসূলদের মধ্যের যাদের আমরা পাঠিয়েছিলাম তাঁদের সন্বন্ধে, আর আমাদের রীতির কোনো পরিবর্তন তুমি পাবে না।\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@mmcvii{নামায কায়েম করো সূর্যের হেলে পড়া থেকে রাতের অন্ধকার পর্যন্ত, আর ফজরের কুরআন পাঠ। নিঃসন্দেহ ফজরের কুরআন- পাঠ পরিলক্ষিত হয়।\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@mmcviii{আর রাতের মধ্যে থেকে এর দ্বারা জাগরণে কাটাও -- তোমার জন্য এক অতিরিক্ত, হতে পারে তোমার প্রভু তোমাকে উন্নত করবেন এক সুপ্রশংসিত অবস্থায়।\qt@no{(79)}}
\qt@newcmd\qurantrans@bn@mmcix{আর তুমি বলো -- ''আমার প্রভু! আমাকে প্রবেশ করতে দাও মঙ্গলজনক প্রবেশকরণে, এবং আমাকে বের করে আনো মঙ্গলময় নির্গমনে, আর তোমার কাছ থেকে আমাকে দাও একটি সহায়ক কর্তৃত্ব।’’\qt@no{(80)}}
\qt@newcmd\qurantrans@bn@mmcx{আর বলো -- ''সত্য এসেই গেছে আর মিথ্যা অন্তর্ধান করেছে। নিঃসন্দেহ মিথ্যা তো সদা অন্তর্ধানশীল।’’\qt@no{(81)}}
\qt@newcmd\qurantrans@bn@mmcxi{আর আমরা কুরআনের মধ্যে অবতীর্ণ করেছি যা হচ্ছে বিশ্বাসীদের জন্য উপশম এবং করুণা, আর এটি অন্যায়কারীদের ক্ষতিসাধন ছাড়া আর কিছু বাড়ায় না।\qt@no{(82)}}
\qt@newcmd\qurantrans@bn@mmcxii{আর যখন আমরা মানুষের প্রতি করুণা বর্ষণ করি সে ঘুরে দাঁড়ায় ও অহংকার দেখায়, আর যখন মন্দ তাকে স্পর্শ করে সে হতাশ হয়ে যায়।\qt@no{(83)}}
\qt@newcmd\qurantrans@bn@mmcxiii{বলো -- ''প্রত্যেকে কাজ করে চলে আপন ধরনে।’’ কিন্তু তোমাদের প্রভু ভাল জানেন কে হচ্ছে পথে চালিত।\qt@no{(84)}}
\qt@newcmd\qurantrans@bn@mmcxiv{আর তারা তোমাকে জিজ্ঞাসা করে রূহ সম্পর্কে। বলো -- ''রূহ আমার প্রভুর নির্দেশাধীন, আর তোমাদের তো জ্ঞানভান্ডারের সৎসামান্য বৈ দেওয়া হয় নি।’’\qt@no{(85)}}
\qt@newcmd\qurantrans@bn@mmcxv{আর আমরা যদি চাইতাম তবে তোমার কাছে যা প্রত্যাদেশ পাঠিয়েছি তা আমরা আলবৎ প্রত্যাহার করতাম, তখন এ বিষয়ে তুমি আমাদের বিরুদ্ধে কোনো কার্যনির্বাহক পেতে না, --\qt@no{(86)}}
\qt@newcmd\qurantrans@bn@mmcxvi{কিন্তু এটি তোমার প্রভুর কাছ থেকে করুণা। নিঃসন্দেহ তোমার প্রতি তাঁর করুণা অতি বিরাট।\qt@no{(87)}}
\qt@newcmd\qurantrans@bn@mmcxvii{বলো -- ''যদি মানুষ ও জিন সম্মিলিত হতো এই কুরআনের সমতুল্য কিছু নিয়ে আসতে, তারা এর মতো কিছুই আনতে পারত না, যদিও-বা তাদের কেউ-কেউ অন্যদের পৃষ্ঠপোষক হতো।’’\qt@no{(88)}}
\qt@newcmd\qurantrans@bn@mmcxviii{আর আমরা অবশ্যই লোকেদের জন্য এই কুরআনে সব রকমের দৃষ্টান্ত বিশদভাবে বর্ণনা করেছি, কিন্তু অধিকাংশ মানুষই প্রত্যাখ্যান করা ছাড়া আর সব-কিছুতেই অসম্মত।\qt@no{(89)}}
\qt@newcmd\qurantrans@bn@mmcxix{আর তারা বলে -- ''আমরা কখনই তোমাতে বিশ্বাস করব না যতক্ষণ না তুমি পৃথিবী থেকে আমাদের জন্য একটি ঝরনা উৎসারণ করো,\qt@no{(90)}}
\qt@newcmd\qurantrans@bn@mmcxx{''আর না হয় তোমার জন্যেই থাকুক খেজুরের ও আঙুরের বাগান, যার মধ্যে তুমি ঝরনারাজি উৎসারিত করে বইয়ে দেবে,\qt@no{(91)}}
\qt@newcmd\qurantrans@bn@mmcxxi{''অথবা তুমি আকাশকে আমাদের উপরে নামাবে খন্ড-বিখন্ড ক’রে যেমন তুমি ভাব, নতুবা তুমি আল্লাহ্‌কে ও ফিরিশ্‌তাগণকে সামনা-সামনি নিয়ে আসবে,\qt@no{(92)}}
\qt@newcmd\qurantrans@bn@mmcxxii{''নয়ত তোমার জন্য হোক একটি সোনার তৈরি ঘর, অথবা তুমি আকাশে আরোহণ করবে। আর আমরা কখনো তোমার ঊর্ধ্বারোহণে বিশ্বাস করব না যতক্ষণ না তুমি আমাদের জন্য এক কিতাব নামিয়ে আনো -- যা আমরা পড়তে পারি।’’ বলো, -- ''সকল মহিমা আমার প্রভুর! আমি কি একজন মানুষ -- একজন রসূল ছাড়া অন্য কিছু?’’\qt@no{(93)}}
\qt@newcmd\qurantrans@bn@mmcxxiii{আর লোকগুলোকে বিশ্বাস স্থাপন করতে অন্য কিছু বাধা দেয় না যখন তাদের কাছে হেদায়ত আসে এই ভিন্ন যে তারা বলে -- ''আল্লাহ্ কি একজন মানুষকেই রসূল ক’রে দাঁড় করিয়েছেন?’’\qt@no{(94)}}
\qt@newcmd\qurantrans@bn@mmcxxiv{তুমি বলো -- ''যদি পৃথিবীতে ফিরিশ্‌তারা চলাফেরা করত নিশ্চিন্তভাবে, তবে আমরা নিশ্চয়ই তাদের কাছে আকাশ থেকে একজন ফিরিশ্‌তাকেই পাঠাতাম রসূলরূপে।’’\qt@no{(95)}}
\qt@newcmd\qurantrans@bn@mmcxxv{বলো -- ''আল্লাহই আমার মধ্যে ও তোমাদের মধ্যে সাক্ষীরূপে যথেষ্ট। নিঃসন্দেহ তিনি তাঁর বান্দাদের সন্বন্ধে চির- ওয়াকিফহাল, সর্বদ্রষ্টা।’’\qt@no{(96)}}
\qt@newcmd\qurantrans@bn@mmcxxvi{আর যাকে আল্লাহ্ পথ দেখান সে তবে পথপ্রাপ্ত, আর যাকে তিনি বিপথে চলতে দেন তাদের জন্য তুমি পাবে না তাঁর ব্যতিরেকে কোনো অভিভাবক। আর কিয়ামতের দিনে আমরা তাদের সমবেত করব তাদের মুখের উপরে -- অন্ধ, আর বোবা এবং বধির। তাদের আবাসস্থল হচ্ছে জাহান্নাম। যখনই তা ঝিমিয়ে আসবে আমরা তাদের জন্য শিখা বাড়িয়ে দেব!\qt@no{(97)}}
\qt@newcmd\qurantrans@bn@mmcxxvii{এই হচ্ছে তাদের প্রতিদান কেননা তারা আমাদের নিদের্শাবলী অস্বীকার করেছিল এবং বলেছিল -- ''কী! আমরা যখন হাড়-ও ধুলোকণা হয়ে যাব তখন কি আমরা সত্যই পুনরুত্থিত হব নতুন সৃষ্টিরূপে?’’\qt@no{(98)}}
\qt@newcmd\qurantrans@bn@mmcxxviii{তারা কি দেখছে না যে আল্লাহ্‌, যিনি মহাকাশমন্ডলী ও পৃথিবী সৃষ্টি করেছেন, তিনি তাদের অনুরূপ সৃষ্টি করতে সক্ষম? আর তিনি তাদের জন্য স্থির করেছেন একটি নির্ধারিত কাল -- এতে কোনো সন্দেহ নেই। কিন্তু অন্যায়কারীরা প্রত্যাখ্যান করা ছাড়া আর সবটাতেই অসম্মত থাকে।\qt@no{(99)}}
\qt@newcmd\qurantrans@bn@mmcxxix{বলো -- ''যদি তোমরা আমার প্রভুর করুণা-ভান্ডারের উপরে কর্তৃত্ব করতে তাহলে তোমরা নিশ্চয়ই তা ধরে রাখতে খরচ করার ভয়ে।’’ আর মানুষ বড় কৃপণ।\qt@no{(100)}}
\qt@newcmd\qurantrans@bn@mmcxxx{আর আমরা আলবৎ মূসাকে নয়টি স্পষ্ট নিদর্শন দিয়েছিলাম, সুতরাং ইসরাইলের বংশধরদের জিজ্ঞেস করে দেখ -- যখন তিনি তাদের কাছে এসেছিলেন, -- ফিরআউন তখন তাঁকে বলেছিল -- ''আমি অবশ্য তোমাকে, হে মূসা! মনে করি জাদুগ্রস্ত।’’\qt@no{(101)}}
\qt@newcmd\qurantrans@bn@mmcxxxi{তিনি বললেন -- ''তুমি নিশ্চয়ই জান যে মহাকাশমন্ডলী ও পৃথিবীর প্রভুর ব্যতিরেকে অন্য কেউ এইসব নিদর্শন পাঠান নি, আর আমি তো তোমাকেই, হে ফিরআউন! মনে করি বিনাশপ্রাপ্ত।’’\qt@no{(102)}}
\qt@newcmd\qurantrans@bn@mmcxxxii{তখন সে সংকল্প করল দেশ থেকে তাঁদের উচ্ছেদ করতে, কাজেই আমরা তাকে ও তার সঙ্গে যারা ছিল সবাইকে ডুবিয়ে দিয়েছিলাম।\qt@no{(103)}}
\qt@newcmd\qurantrans@bn@mmcxxxiii{আর এ পরে আমরা ইসরাইলের বংশধরদের বলেছিলাম -- ''তোমরা এ দেশে বসবাস কর, তারপর যখন ভবিষ্যতের প্রতি‌শ্রুতি এসে পড়বে আমরা তখন তোমাদের জড় করব দুমড়ে ফেলে।’’\qt@no{(104)}}
\qt@newcmd\qurantrans@bn@mmcxxxiv{আর সত্যের সঙ্গে আমরা এটি অবতারণ করেছি, আর সত্যের সঙ্গে এটি এসেছে। আর তোমাকে আমরা পাঠাই নি সুসংবাদদাতা ও সতর্ককারীরূপে ভিন্ন।\qt@no{(105)}}
\qt@newcmd\qurantrans@bn@mmcxxxv{আর এ কুরআন -- আমরা এটিকে ভাগভাগ করেছি যেন তুমি তা লোকদের কাছে ক্রমে ক্রমে পড়তে পার, আর আমরা এটি অবতারণ করেছি অবতারণে।\qt@no{(106)}}
\qt@newcmd\qurantrans@bn@mmcxxxvi{বলো -- ''তোমরা এতে বিশ্বাস কর অথবা বিশ্বাস নাই কর। নিঃসন্দেহ যাদের এর আগে জ্ঞান দেয়া হয়েছিল -- যখন তা দের কাছে এটি পাঠ করা হয় তখন চিবুকের উপরে তারা লুটিয়ে পড়ে সিজদা-রত হয়ে।’’\qt@no{(107)}}
\qt@newcmd\qurantrans@bn@mmcxxxvii{আর তারা বলে -- ''মহিমা হোক আমাদের প্রভুর? আমাদের প্রভুর অংগীকার কৃতকার্য হবেই!’’\qt@no{(108)}}
\qt@newcmd\qurantrans@bn@mmcxxxviii{আর তারা লুটিয়ে পড়ে চিবুকের উপরে কাঁদতে কাঁদতে, আর এতে তাদের বিনয় বেড়ে যায়।\qt@no{(109)}}
\qt@newcmd\qurantrans@bn@mmcxxxix{বলো -- ''তোমরা 'আল্লাহ্‌’ বলে ডাকো অথবা 'রহমান’ বলে ডাকো। বস্তুতঃ যে নামেই তোমরা ডাক, তাঁরই কিন্তু সকল সুন্দর সুন্দর নাম।’’ আর তোমরা নামাযে আওয়াজ চড়া করো না এবং এতে নিঃশব্ধও হয়ো না, বরং এই উভয়ের মধ্যে পথ অনুসরণ করো।\qt@no{(110)}}
\qt@newcmd\qurantrans@bn@mmcxl{আর তুমি বলো -- ''সমস্ত প্রশংসা আল্লাহ্‌র, যিনি কোনো সন্তান গ্রহণ করেন নি, আর যাঁর জন্য এই সাম্রাজ্যে কোনো শরিক নেই, এবং যাঁর কোনো মনিব নেই দুর্দশা থেকে, সুতরাং তাঁর মাহা‌ত্ম্য ঘোষণা করো সসম্ভ্রমে।’’\qt@no{(111)}}
\qt@newcmd\qurantrans@bn@mmcxli{\basmalahbn সকল প্রশংসা আল্লাহ্‌র যিনি তাঁর বান্দার কাছে এই কিতাব অবতারণ করেছেন, আর তিনি এতে কোনো কুটিলতা রাখেন নি,\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmcxlii{সুপ্রতিষ্ঠিত, যেন তাঁর তরফ থেকে আসা কঠোর দুর্যোগ সন্বন্ধে এটি সতর্ক করতে পারে এবং সুসংবাদ দিতে পারে মুমিনদের যারা সৎকর্ম করে থাকে, -- যে তাদের জন্য অবশ্যই রয়েছে উত্তম প্রতিদান,\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmcxliii{সেখানে তারা থাকবে চিরকাল,\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmcxliv{আর যেন এটি সাবধান করতে পারে তাদের যারা বলে যে আল্লাহ্ একটি সন্তান গ্রহণ করেছেন।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmcxlv{তাদের এ বিষয়ে কোনো জ্ঞান নেই আর তাদের পিতৃপুরুষদেরও ছিল না। এ এক সাংঘাতিক কথা যা তাদের মুখ থেকে নির্গত হয়। তারা যা বলে তা মিথ্যা বৈ তো নয়।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmcxlvi{কাজেই হয়ত বা তাদের পেছনে ঘুরে ঘুরে তোমার নিজেকে তুমি দুঃখে কাতর করে তুলবে যেহেতু তারা এই নতুন বাণীতে বিশ্বাস করছে না।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmcxlvii{নিঃসন্দেহ পৃথিবীর উপরে যা-কিছু আছে আমরা সেগুলোকে ওর অলংকাররূপে স্থাপন করেছি যেন আমরা তাদের যাচাই করতে পারি তাদের কারা কাজে সর্বোত্তম।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmcxlviii{আর নিঃসন্দেহ তার উপরে যা-কিছু আছে আমরা তাকে করব তৃণলতাহীন মাটির গুড়োঁ।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmcxlix{অথবা, তুমি কি মনে কর যে গুহার বাসিন্দারা ও লিখিত-ফলক আমাদের নিদর্শনাবলীর মধ্যে বিস্ময়কর?\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmcl{দেখো, কিছু যুবক গুহায় আশ্রয় নিল, তখন তারা বললে -- ''আমাদের প্রভু! তোমার কাছ থেকে আমাদের অনুগ্রহ প্রদান করো, আর আমাদের কাজকর্মে সঠিক রাস্তা বাতলে দাও।’’\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmcli{সেজন্য গুহার মধ্যে কয়েক বছরের জন্য আমরা তাদের কানে চাপা দিলাম,\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmclii{তারপর আমরা তাদের তোলে আনলাম যেন আমরা জানতে পারি দুই দলের কারা ভাল ক’রে গণতে পারে কত সময় তারা অবস্থান করেছিল।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmcliii{আমরা তোমার কাছে তাদের কাহিনী বর্ণনা করছি সঠিকভাবে -- নিঃসন্দেহ এরা ছিল কয়েকজন যুবক যারা তাদের প্রভুর প্রতি ঈমান এনেছিল, আর আমরা তাদের সৎপথে চলার ক্ষমতা বাড়িয়ে দিয়েছিলাম।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmcliv{আর আমরা তাদের হৃদয়ে শক্তিবর্ধন করেছিলাম যখন তারা দাঁড়িয়েছিল ও বলেছিল -- ''আমাদের প্রভু হচ্ছেন মহাকাশমন্ডলী ও পৃথিবীর প্রভু, আমরা কখনই তাঁকে ছেড়ে দিয়ে অন্য উপাস্যকে ডাকব না, কেননা সেক্ষেত্রে আমরা আলবৎ বলে থাকব এক ডাহা মিথ্যা।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmclv{''আমাদেরই এই স্বজাতিরা তাঁকে ছেড়ে দিয়ে অন্য উপাস্যদের গ্রহণ করেছে। এরা কেন তাদের সন্বন্ধে কোনো স্পষ্ট প্রমাণ নিয়ে আসে না? তা’হলে কে বেশি অন্যায়কারী তার চাইতে যে আল্লাহ্ সন্বন্ধে মিথ্যা রচনা করে?’’\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmclvi{আর স্মরণ করো! তোমরা তাদের থেকে এবং আল্লাহ্ ছাড়া যাদের তারা উপাসনা করত সে-সব থেকে বিচ্ছিন্ন হলে, তখন তোমরা গুহার দিকে আশ্রয় নিলে। তোমাদের প্রভু তোমাদের জন্য তাঁর করুণা বিস্তার করলেন, এবং তোমাদের জন্য তৈরি করলেন তেমাদের কাজকর্ম থেকে লাভজনক পরিস্থিতি।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmclvii{আর সূর্য যখন উদয় হত তখন তুমি দেখতে পেতে তাদের গুহা থেকে ডান দিকে হেলে আছে, আর যখন অস্ত যেত তখন বাম পাশ দিয়ে তাদের অতিক্রম করছে, আর তারা এর এক বিস্তৃত অঞ্চল জুড়ে রয়েছিল। এটি ছিল আল্লাহ্‌র নিদর্শনগুলোর অন্যতম। যাকে আল্লাহ্ সৎপথে চালান সেই তবে সৎপথে চালিত, আর যাকে তিনি পথভ্রষ্ট হতে দেন তার জন্যে তুমি তবে কোনো পথ প্রদর্শনকারী অভিভাবক পাবে না।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmclviii{আর তুমি তাদের মনে করতে জাগ্রত যদিও তারা ছিল ঘুমন্ত, আর আমরা তাদের পাশ ফিরিয়ে দিতাম ডান দিকে ও বাঁ দিকে, আর তাদের কুকুরটি থাবা মেলে রয়েছিল প্রবেশপথে। তুমি যদি তাদের হঠাৎ দেখতে তবে তাদের থেকে পিছন ফিরতে পলায়নপর হয়ে, আর তুমি নিশ্চয়ই তাদের কারণে ভয়ে বিহল হতে।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmclix{আর এইভাবে আমরা তাদের জাগিয়ে তোলেছিলাম যেন তারা তাদের নিজেদের মধ্যে জিজ্ঞাসাবাদ করতে পারে। তাদের মধ্যের একজন বক্তা বললে -- ''কতকাল তোমরা অবস্থান করেছিলে?’’ তারা বললে, ''আমরা অবস্থান করেছিলাম একদিন বা একদিনের কিছু অংশ।’’ তারা বললে -- ''তোমাদের প্রভু ভাল জানেন কতক্ষণ তোমরা অবস্থান করেছ। এখন তোমাদের একজনকে এই রেপ্যমুদ্রা দিয়ে শহরে পাঠাও, সে তখন দেখুক কোনটা কোনটা ভাল খাবার, আর তা থেকে যেন তোমাদের খাবার নিয়ে আসে। আর সে যেন বিচক্ষণতার সাথে চলে এবং তোমাদের সন্বন্ধে কাউকেও কিছু জানতে না দেয়।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmclx{''নিঃসন্দেহ তাদের ক্ষেত্রে -- তারা যদি তোমাদের সন্বন্ধে জানতে পারে তবে তোমাদের পাথর ছুঁড়ে মেরে ফেলবে অথবা তাদের ধর্মে তোমাদের ফিরিয়ে নেবে এবং সেক্ষেত্রে তোমরা কখনো সফলকাম হবে না।’’\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmclxi{আর এইভাবে আমরা জানিয়ে দিলাম ওদের সন্বন্ধে যেন তারা জানতে পারে যে আল্লাহ্‌র ওয়াদাই সত্য, আর ঘড়ি-ঘন্টা সন্বন্ধে, এতে কোনো সন্দেহ নেই। যখন তারা নিজেদের মধ্যে তাদের কর্তব্য সন্বন্ধে বিতর্ক করছিল তখন তারা বললে -- ''তাদের উপরে একটি সৌধ নির্মাণ কর’’। তাদের প্রভু তাদের বিষয়ে ভাল জানেন। তাদের কর্তব্য সন্বন্ধে যারা প্রভাব বিস্তার করল তারা বলল -- ''আমরা সুনিশ্চিত তাদের উপরে একটি মসজিদ বানাব’’।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmclxii{তারা অচিরেই বলবে -- ''তিনজন, তাদের চতুর্থজন ছিল তাদের কুকুর’’, আর তারা বলবে -- ''পাঁচজন, তাদের ষষ্ঠজন ছিল তাদের কুকুর’’, -- অজানা সন্বন্ধে আন্দাজ করা মাত্র, আর তারা বলে -- ''সাতজন, তাদের অষ্টমজন তাদের কুকুর। ’’ তুমি বলো -- ''আমার প্রভু ভাল জানেন সংখ্যা, অল্প কয়েকজন ছাড়া অন্যে তাদের চেনে না।’’ সুতরাং তাদের সন্বন্ধে বিতর্ক করো না সাধারণ আলোচনা ছাড়া, আর তাদের সন্বন্ধে ওদের কোনো একজনকেও জিজ্ঞাসাবাদ করো না।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmclxiii{আর কোনো ব্যাপারে কখনই বলো না -- ''আমি এটি নিশ্চয়ই কালকে করে ফেলব --\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmclxiv{''যদি না আল্লাহ্ ইচ্ছা করেন’’। আর তোমার প্রভুকে স্মরণ করো যখনই ভুলে যাও, আর বলো -- ''হয়ত বা আমার প্রভু আমাকে এর চেয়েও নিকটতর রাস্তায় পরিচালিত করবেন।’’\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmclxv{আর তারা তাদের গুহায় অবস্থান করেছিল তিন শত বছর, আর কেউ যোগ করে নয়।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmclxvi{বলো -- ''আল্লাহ্ ভাল জানেন কত কাল তারা অবস্থান করেছিল। মহাকাশমন্ডলী ও পৃথিবীর অজ্ঞাত সব তাঁরই। কত তীক্ষ তাঁর দৃষ্টি ও কত সজাগ কান! তাঁকে বাদ দিয়ে তাদের জন্য কোনো অভিভাবক নেই, আর তিনি কোনো একজনকেও তাঁর কর্তৃত্বের অংশী করেন না।’’\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmclxvii{আর পাঠ করো তোমার প্রভুর কিতাবের থেকে যা তোমাদের কাছে প্রত্যাদিষ্ট হয়েছে। এমন কেউ নেই যে তাঁর বাণী বদল করতে পারে, আর তাঁকে বাদ দিয়ে তুমি পাবে না কোনো আশ্রয়স্থল।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmclxviii{আর যারা সকালে ও সন্ধ্যায় তাদের প্রভুকে তাঁর প্রসন্নতা কামনা ক’রে আহ্বান করে তাদের সঙ্গে তুমি নিজেও অধ্যবসায় অবলন্বন করো, আর তাদের থেকে তোমার দৃষ্টি ফিরিয়ে নিয়ো না এই দুনিয়ার জীবনের শোভা- সৌন্দর্য কামনা ক’রে । আর যার হৃদয়কে আমাদের নামকীর্তন থেকে আমরা বেখেয়াল করেছি আর যে তার খেয়াল-খুশির অনুসরণ করে আর যার কার্যকলাপ সীমালংঘন করে গেছে তুমি তার অনুসরণ করো না।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmclxix{তুমি বলো -- ''তোমাদের প্রভুর কাছ থেকে সত্য, সেজন্য যে ইচ্ছা করে সে যেন বিশ্বাস করে, আর যে চায় সে অবিশ্বাসই করুক।’’ নিঃসন্দেহ অন্যায়কারীদের জন্য আমরা তৈরি করেছি আগুন, এর বেড়া তাদের ঘেরাও করে রাখবে। আর তারা যদি পানীয় চায় তবে তাদের পানীয় দেয়া হবে গলিত সীসার মতো জল যা তাদের মুখমন্ডল পুড়িয়ে দেবে। এ এক নিকৃষ্ট পানীয়! আর মন্দ সেই বিশ্রামস্থল!\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmclxx{নিঃসন্দেহ যারা ঈমান এনেছে ও সৎকর্ম করছে -- আমরা নিশ্চয়ই যারা ভাল কাজ করে তাদের কর্মফল ব্যর্থ করি না।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmclxxi{এরাই -- এদের জন্য রয়েছে নন্দন কানন সমূহ, যাদের নিচ দিয়ে বয়ে চলে ঝরনারাজি, তাদের সেখানে অলংকৃত করানো হবে সোনার কাঁকন দিয়ে, আর তাদের পরানো হবে মিহি রেশমের ও পুরু জরির সবুজ পোশাকে, সেখানে সমাসীন হবে সুসজ্জিত আসনে। কি উত্তম পুরস্কার, আর কত সুন্দর বিশ্রামস্থল!\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmclxxii{আর তাদের জন্য একটি রূপক ছুড়োঁ দুজন লোকের -- তাদের একজনের জন্য আমরা বানিয়েছি আঙুরলতার দুটি বাগান, আর এ দুটিকে ঘিরে দিয়েছিলাম খেজুরগাছ দিয়ে, আর সে-সবের মাঝে মাঝে বানিয়েছিলাম শস্যক্ষেত্র।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmclxxiii{বাগান দুটির প্রত্যেকটাই প্রদান করত তার ফলমূল, আর এতে এ কোনো ত্রুটি করত না, আর এ দুইয়ের মধ্যদেশে বইয়েছিলাম জলপ্রবাহ,\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmclxxiv{আর ফলটি ছিল তার। তাই সে তার সঙ্গীকে বললে এবং যে তার সঙ্গে কথাবার্তা বলছিল -- ''আমি ধনসম্পদে তোমার চাইতে প্রাচুর্যময় এবং জনবলেও শক্তিশালী।’’\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmclxxv{আর সে তার বাগানে ঢুকল অথচ সে তার নিজের প্রতি অন্যায় করছিল। সে বললে -- ''আমি মনে করি না যে এসব কখনো নিঃশেষ হয়ে যাবে,\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmclxxvi{''আর আমি মনে করি না যে ঘড়িঘন্টা বলবৎ হবে, আর যদিবা আমার প্রভুর কাছে আমাকে ফিরিয়ে নেয়া হয় তবে আমি তো নিশ্চয়ই এর চেয়েও ভাল প্রত্যাবর্তনস্থল পাব।’’\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmclxxvii{তার সঙ্গী তাকে বললে যখন সে তার সঙ্গে বাক্যালাপ করছিল -- ''তুমি কি তাঁকে অবিশ্বাস কর যিনি তোমাকে সৃষ্টি করেছেন মাটি থেকে, তারপর শুক্রকীট থেকে, তারপর তিনি তোমাকে পূর্ণাঙ্গ করেছেন একজন মানুষে?\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmclxxviii{''কিন্তু আমার বেলা, তিনি আল্লাহ্‌, আমার প্রভু, আর আমি কোনো একজনকেও আমার প্রভুর সাথে শরিক করি না।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmclxxix{''আর তুমি যখন তোমার বাগানে প্রবেশ করতে তখন কেন বল না -- 'মা-শা-আল্লাহ্‌, আল্লাহ্ ছাড়া কোনো শক্তি নেই’? যদিও তুমি আমাকে দেখো ধনদৌলত ও সন্তানসন্ততিতে আমি তোমার চাইতে কম, --\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmclxxx{''তবু হতে পারে আমার প্রভু আমাকে তোমার বাগানের চেয়ে ভাল কিছু দান করবেন, আর এর উপরে তিনি পাঠাবেন আকাশ থেকে এক হিসেব-নিকেশ, ফলে অচিরেই এটি হয়ে যাবে ধুলোমাটির প্রান্তর, গাছপালাহীন।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmclxxxi{''অথবা অচিরেই এর পানি তলিয়ে যাবে ভূগর্ভে, তখন তুমি তা খুঁজে পেতে সমর্থ হবে না।’’\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmclxxxii{আর তার ফলফসলকে ঘেরাও করল, তারপর অচিরেই সে হাত মোচড়াতে লাগল যা সে তার উপরে খরচ করেছিল সেজন্য, আর এটি ভেঙ্গে পড়েছিল তার মাচার উপরে, আর সে বলেছিল -- ''হায় আমার আফসোস! আমি যদি আমার প্রভুর সাথে কাউকেও অংশী না করতাম!’’\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmclxxxiii{আর আল্লাহ্‌কে ছেড়ে দিয়ে তাকে সাহায্য করার জন্য কোনো ফৌজ তার জন্য ছিল না, আর সে নিজেও সাহায্য করতে সমর্থ ছিল না।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmclxxxiv{এই তো! অভিভাবকত্ব আল্লাহ্‌রই, যিনি সত্য। তিনিই পুরস্কারদানে শ্রেষ্ঠ আর পরিণাম নির্ধারণেও শ্রেষ্ঠ।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmclxxxv{আর তাদের কাছে পার্থিব জীবনের উপমা ছুঁড়ো -- এ পানির ন্যায় যা আমরা বর্ষণ করি আকাশ থেকে, তাতে পৃথিবীর গাছপালা ঘন-সন্নিবিষ্ট হয়, তারপর পরক্ষণেই তা হয়ে যায় শুকনো, বাতাস তাকে উড়িয়ে নিয়ে যায়। আর আল্লাহ্ সব কিছুর উপরেই সর্বশক্তিমান।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmclxxxvi{ধনসম্পদ ও সন্তানসন্ততি পার্থিব জীবনের শোভাসৌন্দর্য, কিন্তু স্থায়ী শুভকর্ম তোমার প্রভুর কাছে পুরস্কার প্রাপ্তির জন্যে বেশী ভাল এবং আশা পূরণের জন্যেও অধিকতর শ্রেয়।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmclxxxvii{আর সেই দিনে আমরা পাহাড়গুলো হটিয়ে দেব, আর তুমি পৃথিবীকে দেখবে একটি খোলা ময়দান, আর আমরা তাদের একত্রিত করব, তখন তাদের মধ্যের কোনো একজনকেও আমরা ফেলে রাখব না --\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmclxxxviii{আর তোমার প্রভুর সামনে তাদের হাজির করা হবে সারিবদ্ধভাবে। ''এখন তো আমরা তোমাদের নিয়ে এসেছি যেমন আমরা তোমাদের সৃষ্টি করেছিলাম প্রথমবারে, অথচ তোমরা মনে করতে যে তোমাদের জন্য আমরা কোনো ওয়াদার স্থানকাল কখনো ধার্য করব না।’’\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmclxxxix{আর বইখানা ধরা হবে, তখন তুমি দেখবে -- ওতে যা আছে সেজন্য অপরাধীরা আতংকগ্রস্ত, আর তারা বলবে -- ''হায় আমাদের দুর্ভোগ! এ কেমনতর গ্রন্থ! এ ছোটখাটো বাদ দেয় নি আর বড়গুলো তো নয়ই, বরং সমস্ত কিছু নথিভুক্ত করেছে!’’ আর তারা যা করেছে তা হাজির পাবে। আর তোমার প্রভু কোনো একজনের প্রতিও অন্যায় করেন না।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmcxc{আর স্মরণ করো! আমরা ফিরিশ্‌তাদের বললাম -- ''আদমের প্রতি সিজদা করো’’, তখন তারা সিজদা করল, ইবলিস ব্যতীত। সে ছিল জিনদের মধ্যেকার, কাজেই সে তার প্রভুর আদেশের অবাধ্যাচরণ করেছিল। তবে কি তোমরা আমাকে ছেড়ে দিয়ে তাকে ও তার বংশধরকে অভিভাবকরূপে গ্রহণ করবে, অথচ তারা তো তোমাদের শত্রু? অন্যায়কারীদের জন্য এই বিনিময় কত নিকৃষ্ট!\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmcxci{মহাকাশমন্ডলী ও পৃথিবীর সৃষ্টিকালে আমি ওদের সাক্ষি দিতে ডাকি নি, আর তাদের নিজেদের সৃষ্টিকালেও নয়, আর বিপথে চালনাকারীদের আমি সহায়করূপে গ্রহণ করি না।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmcxcii{আর সেদিন তিনি বলবেন -- ''ডাকো আমার সঙ্গিসাথীদের যাদের তোমরা ভাবতে।’’ সুতরাং তারা তাদের ডাকবে, কিন্তু তারা তাদের প্রতি সাড়া দেবে না, আর আমরা তাদের মধ্যখানে স্থাপন করব এক ব্যবধান।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmcxciii{আর অপরাধীরা আগুন দেখতে পাবে, আর তারা বুঝবে যে তারা নিশ্চয়ই এতে পতিত হচ্ছে, আর তা থেকে তারা কোনো পরিত্রাণ পাবে না।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmcxciv{আর আমরা আলবৎ এই কুরআনে লোকেদের জন্য সব রকমের দৃষ্টান্ত বিশদভাবে ব্যাখ্যা করেছি। আর মানুষ বেশির ভাগ ক্ষেত্রেই বিতর্কপ্রিয়।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmcxcv{আর এমন কিছু মানুষকে বাধা দেয় না বিশ্বাস স্থাপন করতে যখন তাদের কাছে পথনির্দেশ আসে এবং তাদের প্রভুর কাছে ক্ষমা প্রার্থনা করতেও, এ ভিন্ন যে তাদের কাছেও আসুক পূর্ববর্তীদের ঘটনাবলী, অথবা আগেভাগেই তাদের উপরে শাস্তিটা যেন এসে পড়ে।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mmcxcvi{আর আমরা রসূলগণকে পাঠাই না সুসংবাদদাতা ও সতর্ককারীরূপে ভিন্ন, আর যারা অবিশ্বাস পোষণ করে তারা মিথ্যার সাহায্যে বিতর্ক করে যেন তার দ্বারা তারা সত্যকে ব্যর্থ করতে পারে, আর আমার বাণীসমূহ ও যা দিয়ে তাদের সতর্ক করা হয়েছে সে-সবকে তারা বিদ্রূপের বিষয় রূপে গ্রহণ করে থাকে।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mmcxcvii{আর কে বেশী অন্যায়কারী তার চাইতে যাকে স্মরণ করিয়ে দেওয়া হয় তার প্রভুর বাণীসমূহ, কিন্তু সে তা থেকে ফিরে যায় আর ভুলে যায় তার হাত দুখানা কী আগবাড়িয়েছিল? নিঃসন্দেহ আমরা তাদের হৃদয়ের উপরে আবরণ স্থাপন ক রেছি পাছে তারা এটি বুঝতে পারে, আর তাদের কানের ভেতরে বধিরতা। আর তুমি যদি তাদের সৎপথের প্রতি আহান করো তারা সেক্ষেত্রে কখনো সৎপথের দিকে চলবে না।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mmcxcviii{আর তোমরা প্রভু পরিত্রাণকারী, করুণার আধার। তারা যা অর্জন করেছে সেজন্য তিনি যদি তাদের পাকড়াও করতেন তাহলে তিনি নিশ্চয়ই তাদের জন্য শাস্তি ত্বরান্বিত করতেন। কিন্তু তাদের জন্য একটি নির্ধারিত কাল রয়েছে যার তেকে তারা কোনো পরিত্রাণ খুঁজে পাবে না।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mmcxcix{আর ঐ সব জনপদ -- আমরা ওদের ধ্বংস করেছিলাম যখন তারা অন্যায়াচরণ করেছিল, আর ওদের ধ্বংসের জন্য আমরা একটি নির্দিষ্ট সময় স্থির করেছিলাম।\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mmcc{আর স্মরণ করো! মূসা তাঁর ভৃত্যকে বললেন -- ''আমি থামব না যে পর্যন্ত না আমি দুই নদীর সঙ্গমস্থলে পৌঁছি, নতুবা আমি যুগ যুগ ধরে চলতে থাকব।’’\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mmcci{এরপর যখন উভয়ে এ দুইয়ের সঙ্গমস্থলে পৌঁছলেন, তাঁরা তাঁদের মাছের কথা ভুলে গেলেন, কাজেই ফাঁক পেয়ে এটি নদীতে তার পথ ধরল।\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mmccii{তাঁরা যখন এগিয়ে গেলেন তখন তিনি তাঁর ভৃত্যকে বললেন, ''আমাদের সকালের খাবার আমাদের জন্য নিয়ে এস, আমাদের এই সফর থেকে আমরা আলবৎ পরিশ্রান্ত হয়ে পড়েছি।’’\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mmcciii{সে বললে -- ''আপনি কি লক্ষ্য করেছেন, আমরা যখন পাথরের উপরে বিশ্রাম করছিলাম তখন আমি মাছের কথা ভুলে গিয়েছিলাম, আর এটি শয়তান ছাড়া আর কেউ নয় যে আমাকে ভুলিয়ে দিয়েছিল ওর কথা উল্লেখ করতে? আর সেটি নদীতে তার পথ ধরেছিল, আশ্চর্য ব্যাপার!’’\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mmcciv{তিনি বললেন -- ''এটিই আমরা চেয়েছিলাম।’’ সুতরাং তাঁরা নিজেদের পদচিহ্ন অনুসরণ করে ফিরে চললেন।\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mmccv{তারপর তাঁরা আমাদের বান্দাদের মধ্যের একজন বান্দাকে পেলেন যাকে আমরা আমাদের তরফ থেকে করুণা দান করেছিলাম এবং যাঁকে আমাদের তরফ থেকে জ্ঞান শিখিয়েছিলাম।\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mmccvi{মূসা তাঁকে বললেন -- ''আমি কি আপনার অনুসরণ করব এই শর্তে যে সঠিক পথের সম্পর্কে যা আপনাকে শেখানো হয়েছে তা থেকে আপনি আমাকে শেখাবেন?’’\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mmccvii{তিনি বললেন -- ''তুমি আমার সঙ্গে ধৈর্য ধারণ ক’রে থাকতে কখনো সক্ষম হবে না।\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mmccviii{''আর তুমি কেমন করে ধৈর্য ধারণ করতে পারবে সেই বিষয়ে যে-সন্বন্ধে তোমার কোনো খোঁজখবর থাকে না?’’\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mmccix{তিনি বললেন -- ''ইন্ শা আল্লাহ্ আপনি আমাকে এখনি ধৈর্যশীল পবেন, এবং আমি কোনো বিষয়ে আপনাকে অমান্য করব না।’’\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mmccx{তিনি বললেন -- ''বেশ, তুমি যদি আমার অনুসরণ করতে চাও তা’হলে তুমি আমাকে কোনো বিষয়ে প্রশ্ন করতে পারবে না যে পর্যন্ত না আমি সে বিষয়ে মন্তব্য তোমার কাছে প্রকাশ করি।’’\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@mmccxi{এর পর তাঁরা দুজন যাত্রা করলেন, পরে যখন তাঁরা একটি নৌকায় চড়লেন তিনি তাতে ছিদ্র করে দিলেন। তিনি বললেন, ''আপনি কি এতে ছিদ্র করলেন এর আরোহীদের ডুবিয়ে দেবার জন্যে? আপনি তো এক অদ্ভুত কাজ করলেন?’’\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@mmccxii{তিনি বললেন -- ''আমি কি বলি নি যে তুমি আমার সঙ্গে কখনো ধৈর্য ধারণ করতে সক্ষম হবে না?’’\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@mmccxiii{তিনি বললেন -- ''আমার অপরাধ নেবেন না যা আমি ভুলে গিয়েছিলাম সেজন্য, আর আমার ব্যাপারে আপনি আমার প্রতি কঠোর হবেন না।’’\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@mmccxiv{এরপর তাঁরা দুজনে চলতে লাগলেন, পরে যখন তাঁরা একটি বালকের সাক্ষাৎ পেলেন তিনি তাকে মেরে ফেললেন। তিনি বললেন -- ''আপনি কি একজন নির্দোষ লোককে হত্যা করলেন অন্য লোককে ছাড়াই? আপনি তো এক ভয়ানক কাজ করে ফেললেন?’’\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@mmccxv{তিনি বললেন -- ''আমি কি তোমাকে বলি নি যে তুমি আমার সঙ্গে কখনো ধৈর্য ধারণ করতে সক্ষম হবে না?’’\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@mmccxvi{তিনি বললেন -- ''আমি যদি এর পরে কোনো ব্যাপারে আপনাকে প্রশ্ন করি তবে আপনি আমাকে সঙ্গে নেবেন না, আপনি অবশ্যই আমার সন্বন্ধে এক ওজর-আপত্তি পেয়ে যাবেন।’’\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@mmccxvii{তারপর তাঁরা দুজন চলতে লাগলেন যে পর্যন্ত না তাঁরা এসে পৌঁছলেন এক শহরের অধিবাসীদের কাছে, তাঁরা এর লোকদের কাছে খাবার চাইলেন, কিন্তু তারা এ দুজনের আতিথেয়তা করতে অস্বীকার করল। তারপর তাঁরা তাতে পেয়ে গেলেন একটি দেয়াল যা পড়ে যাবার উপক্রম করছিল, কাজেই তিনি তা খাড়া করে দিলেন। তিনি বললেন -- ''আপনি যদি চাইতেন তবে এর জন্যে অবশ্য পারিশ্রমিক গ্রহণ করতে পারতেন।’’\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@mmccxviii{তিনি বললেন -- ''এইবার আমার মধ্যে ও তোমার মধ্যে ছাড়াছাড়ি। আমি এখন জানিয়ে দিচ্ছি তাৎপর্য যে সন্বন্ধে তুমি ধৈর্য ধরতে পারছিলে না।\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@mmccxix{''নৌকো সন্বন্ধে -- এ ছিল কয়েকজন গরীব লোকের যারা নদীতে কাজ করত, আর আমি এটিকে খুতঁময় করতে চেয়েছিলাম, কেননা তাদের পেছনে ছিল এক রাজা যে প্রত্যেক নৌকো জোর ক’রে নিয়ে নিচ্ছিল।\qt@no{(79)}}
\qt@newcmd\qurantrans@bn@mmccxx{''আর বালকটি সন্বন্ধে -- এর পিতামাতা ছিল মুমিন, আর আমরা আশংকা করছিলাম যে সে বিদ্রোহাচরণ ও অবিশ্বাস পোষণের ফলে তাদের ব্যতিব্যস্ত করবে,\qt@no{(80)}}
\qt@newcmd\qurantrans@bn@mmccxxi{''কাজেই আমরা চেয়েছিলাম তাদের প্রভু যেন তাদের জন্য বদলে দেন পবিত্রতায় এর চেয়ে ভাল এবং ভক্তি-ভালবাসায় ঘনিষ্ঠতর।\qt@no{(81)}}
\qt@newcmd\qurantrans@bn@mmccxxii{''আর দেয়াল সন্বন্ধে -- এ ছিল শহরের দুইজন এতিম বালকের, আর তার তলায় ছিল তাদের উভয়ের ধনভান্ডার, আর তাদের পিতা ছিল সজ্জন। কাজেই তোমার প্রভু চেয়েছিলেন যে তারা যেন তাদের সাবালকত্ব প্রাপ্ত হয় এবং তাদের ধনভান্ডার বের করে আনে তোমার প্রভুর তরফ থেকে করুণা হিসেবে, আর আমি এটি করি নি আমার নিজের ইচ্ছায়। এই হচ্ছে তার তাৎপর্য যে সন্বন্ধে তুমি ধৈর্যধারণ করতে পার নি।’’\qt@no{(82)}}
\qt@newcmd\qurantrans@bn@mmccxxiii{আর তারা তোমাকে যুল্‌ক্কারনাইন সন্বন্ধে জিজ্ঞাসা করছে। বলো -- ''আমি এখনি তোমাদের কাছে তাঁর সন্বন্ধে কাহিনী বর্ণনা করব।’’\qt@no{(83)}}
\qt@newcmd\qurantrans@bn@mmccxxiv{নিঃসন্দেহ আমরা তাঁকে দেশে প্রতিষ্ঠিত করেছিলাম এবং তাঁকে দিয়েছিলাম প্রত্যেক বিষয়ের অনুপ্রবেশ ক্ষমতা।\qt@no{(84)}}
\qt@newcmd\qurantrans@bn@mmccxxv{কাজেই তিনি এক পথ অনুসরণ করলেন।\qt@no{(85)}}
\qt@newcmd\qurantrans@bn@mmccxxvi{পরে যখন তিনি সূর্য অস্ত যাবার স্থানে পৌঁছলেন, তিনি এটিকে দেখতে পেলেন এক কালো জলাশয়ে অস্তগমন করছে, আর তার কাছে পেলেন এক অধিবাসী। আমরা বললাম -- ''হে যুল্‌ক্কারনাইন, তুমি শাস্তি দিতে পার অথবা এদের সদয়ভাবে গ্রহণ করতে পার।’’\qt@no{(86)}}
\qt@newcmd\qurantrans@bn@mmccxxvii{তিনি বললেন -- ''যে কেউ অন্যায় করবে আমরা অচিরেই তাকে শাস্তি দেব, তারপর তাকে ফিরিয়ে আনব তার প্রভুর কাছে, তখন তিনি তাকে শাস্তি দেবেন কঠোর শাস্তিতে।\qt@no{(87)}}
\qt@newcmd\qurantrans@bn@mmccxxviii{''আর যে কেউ বিশ্বাস করবে ও সৎকাজ করবে, তার জন্যে তবে রয়েছে উত্তম প্রতিদান এবং তার প্রতি আমাদের আচার-আচরণে মোলায়েম কথা বলব।’’\qt@no{(88)}}
\qt@newcmd\qurantrans@bn@mmccxxix{তারপর তিনি এক পথ ধরলেন।\qt@no{(89)}}
\qt@newcmd\qurantrans@bn@mmccxxx{পরে যখন তিনি সূর্য উদয় হওয়ার যায়গায় পৌঁছলেন, তিনি এটিকে দেখতে পেলেন উদয় হচ্ছে এক অধিবাসীর উপরে যাদের জন্য আমরা এর থেকে কোনো আবরণ বানাই নি, --\qt@no{(90)}}
\qt@newcmd\qurantrans@bn@mmccxxxi{এইভাবে। আর তাঁর ব্যাপারে সব খবর আমরা জানতাম।\qt@no{(91)}}
\qt@newcmd\qurantrans@bn@mmccxxxii{তারপর তিনি এক পথ ধরলেন।\qt@no{(92)}}
\qt@newcmd\qurantrans@bn@mmccxxxiii{পরে যখন তিনি দুই পর্বত-প্রাচীরের মধ্যে পৌঁছলেন তখন এ দুইটির মধ্যাঞ্চলে তিনি এক সম্প্রদায়কে পেলেন যারা কথা কিছুই বুঝতে পারত না।\qt@no{(93)}}
\qt@newcmd\qurantrans@bn@mmccxxxiv{তারা বললে -- ''হে যুল্‌ক্কারনাইন, নিঃসন্দেহ ইয়াজুজ ও মাজুজ দেশে অশান্তি সৃষ্টি করেছে, আমরা কি তবে আপনাকে কর দেব এই শর্তে যে আপনি আমাদের মধ্যে ও তাদের মধ্যে এক প্রাচীর বানিয়ে দেবেন?’’\qt@no{(94)}}
\qt@newcmd\qurantrans@bn@mmccxxxv{তিনি বললেন -- ''আমার প্রভু যাতে আমাকে প্রতিষ্ঠিত করেছেন তা আরো উৎকৃষ্ট, সুতরাং তোমরা আমাকে কায়িক-শ্রম দিয়ে সাহায্য কর, আমি তোমাদের মধ্যে ও তাদের মধ্যে এক মজবুত দেয়াল তৈরি করে দেব।\qt@no{(95)}}
\qt@newcmd\qurantrans@bn@mmccxxxvi{''আমাদের কাছে তোমরা লোহার টুকরোগুলো নিয়ে এস।’’ অতঃপর যখন দুই পাহাড়ের মধ্যবর্তী জায়গা তিনি পূর্ণ করলেন তখন বললেন -- ''হাপরে দম দিতে থাক।’’ তারপর যখন তা আগুন বানিয়ে তুললো তখন তিনি বললেন -- ''আমার কাছে গলিত তামা নিয়ে এস আমি এর উপরে ঢেলে দেব।\qt@no{(96)}}
\qt@newcmd\qurantrans@bn@mmccxxxvii{''সুতরাং তারা এটি ডিঙোতে সক্ষম হবে না, আর তারা এটি ভেদ করতেও পারবে না।’’\qt@no{(97)}}
\qt@newcmd\qurantrans@bn@mmccxxxviii{তিনি বললেন -- ''এ আমার প্রভুর তরফ থেকে অনুগ্রহ, কিন্তু যখন আমার প্রভুর ওয়াদা এসে যাবে তখন তিনি এটিকে টুকরো- টুকরো করে দেবেন, আর আমার প্রভুর ওয়াদা চিরসত্য।’’\qt@no{(98)}}
\qt@newcmd\qurantrans@bn@mmccxxxix{আর সেই সময়ে আমরা তাদের এক দলকে অন্য দলের সাথে যুদ্ধাভিযানে ছেড়ে দেব, আর শিঙায় ফুৎকার দেয়া হবে, তখন আমরা তাদের জমায়েৎ করব এক সমাবেশে।\qt@no{(99)}}
\qt@newcmd\qurantrans@bn@mmccxl{আর সেই সময়ে আমরা জাহান্নামকে বিছিয়ে দেব বিস্তীর্ণভাবে অবিশ্বাসীদের জন্য, --\qt@no{(100)}}
\qt@newcmd\qurantrans@bn@mmccxli{যাদের চোখ ছিল আমার স্মারক সন্বন্ধে পর্দার আড়ালে আর যারা শুনতেও ছিল অপারগ।\qt@no{(101)}}
\qt@newcmd\qurantrans@bn@mmccxlii{যারা অবিশ্বাস পোষণ করে তারা কি ভাবে যে তারা আমাকে ছেড়ে দিয়ে আমার বান্দাদের অভিভাবকরূপে গ্রহণ করতে পারে? নিঃসন্দেহ আমরা জাহান্নামকে তৈরী করেছি অবিশ্বাসীদের জন্য অভ্যর্থনাস্বরূপ!\qt@no{(102)}}
\qt@newcmd\qurantrans@bn@mmccxliii{বলো -- ''আমরা কি তোমাদের জানিয়ে দেব কারা কর্মক্ষেত্রে সবচাইতে বেশি ক্ষতিগ্রস্ত?’’\qt@no{(103)}}
\qt@newcmd\qurantrans@bn@mmccxliv{এরাই তো এই দুনিয়ার জীবনে তাদের প্রচেষ্টা পন্ড করছে, অথচ তারা মনে করে যে তারা তো বেশ ভালো উৎপাদন করছে।\qt@no{(104)}}
\qt@newcmd\qurantrans@bn@mmccxlv{এরাই তারা যারা অবিশ্বাস করে তাদের প্রভুর নির্দেশাবলীতে ও তাঁর সাথে সাক্ষাতের বিষয়ে, ফলে তাদের ক্রিয়াকর্ম ব্যর্থ হয়ে যায়, সুতরাং তাদের জন্য আমরা কিয়ামতের দিনে কোনো দাঁড়িপাল্লা খাড়া করব না।\qt@no{(105)}}
\qt@newcmd\qurantrans@bn@mmccxlvi{এটাই তো, -- তাদের প্রাপ্য হচ্ছে জাহান্নাম যেহেতু তারা অবিশ্বাস পোষণ করেছিল এবং আমার নির্দেশাবলী ও আমার রসূলগণকে তারা তুচ্ছ-তাচ্ছিল্য করেছিল।\qt@no{(106)}}
\qt@newcmd\qurantrans@bn@mmccxlvii{নিঃসন্দেহ যারা ঈমান এনেছে ও সৎকর্ম করছে তাদের জন্য রয়েছে বেহেশতের বাগান অভ্যর্থনার কারণে, --\qt@no{(107)}}
\qt@newcmd\qurantrans@bn@mmccxlviii{তারা সেখানে থাকবে স্থায়ীভাবে, সেখান থেকে কোনো পরিবর্তন তারা চাইবে না।\qt@no{(108)}}
\qt@newcmd\qurantrans@bn@mmccxlix{বলো -- ''সাগর যদি কালি হয়ে যেত আমার প্রভুর কলিমাহ্‌র জন্য তবে নিশ্চয়ই সাগর নিঃশেষ হয়ে যেত আমার প্রভুর কলিমাহ্ শেষ হওয়ার আগে’’, -- যদিও বা আমরা তার মতো আরেকটি আনতাম যোগ করতে।\qt@no{(109)}}
\qt@newcmd\qurantrans@bn@mmccl{বলো -- ''আমি নিঃসন্দেহ তোমাদেরই মতন একজন মানুষ, আমার কাছে প্রত্যাদিষ্ট হয়েছে যে নিঃসন্দেহ তোমাদের উপাস্য একক উপাস্য, সেজন্য যে কেউ তার প্রভুর সঙ্গে মুলাকাতের কামনা করে সে তবে সৎকর্ম করুক এবং তার প্রভুর উপাসনায় অন্য কাউকেও শরীক না করুক।’’\qt@no{(110)}}
\qt@newcmd\qurantrans@bn@mmccli{\basmalahbn কাফ-হা-ইয়া-'আইন-স্বাদ।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmcclii{এ তাঁর বান্দা যাকারিয়ার প্রতি তোমার প্রভুর অনুগ্রহের বিবরণ।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmccliii{স্মরণ করো, তিনি তাঁর প্রভুর প্রতি মৃদু স্বরে আহ্বান করলেন --\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmccliv{তিনি বললেন -- ''আমার প্রভু! আমার ভেতরের হাড়-গোড় জিরজিরে হয়ে গেছে আর মাথাটি হয়ে গেছে জড়ভরত পাকাচুল বিশিষ্ট, আর আমার প্রভু! আমি তো তোমার কাছে আমার প্রার্থনায় কখনো নিরাশ হই নি।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmcclv{''আর আমি অবশ্য আশংকা করছি আমার পরে আমার জ্ঞাতিগোষ্ঠীদের, আর আমার স্ত্রী বন্ধ্যা, সেজন্য তোমার কাছ থেকে আমাকে একজন উত্তরাধিকারী প্রদান করো, --\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmcclvi{''যে আমাকে উত্তরাধিকার করবে এবং ইয়াকুবের বংশধরদের উত্তরাধিকার করবে, আর আমার প্রভু, তাকে সন্তোষভাজন বানিয়ো।’’\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmcclvii{''হে যাকারিয়া, নিঃসন্দেহ আমরা তোমাকে সুসংবাদ দিচ্ছি একটি বেটা-ছেলের, তার নাম হবে ইয়াহ্‌য়া, এর আগে কাউকেও আমরা তার নামধর বানাই নি।’’\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmcclviii{তিনি বললেন -- ''আমার প্রভু! কেমন ক’রে আমার ছেলে হবে যখন আমার স্ত্রী বন্ধ্যা আর আমিও বার্ধক্যের শেষ সীমায় পৌঁছে গেছি!\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmcclix{সে বললে -- ''এমনটাই হবে যেমন তুমি ভাব, তোমার প্রভু বলেছেন -- 'এটি আমার জন্য সহজসাধ্য, আর আমি তো তোমাকে এর আগে সৃষ্টি করেছি যখন তুমি কিছুই ছিলে না’।’’\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmcclx{তিনি বললেন -- ''আমার প্রভু! আমার জন্য একটি নিদর্শন স্থাপন করো।’’ তিনি বললেন, ''তোমার নিদর্শন হচ্ছে -- তুমি লোকের সাথে কথা বলবে না তিন রাত্রি পর্যন্ত সুস্থাবস্থায় থেকে।’’\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmcclxi{তারপর তিনি উপাসনার কামরা থেকে তাঁর লোকদের কাছে বেরুলেন এবং তাদের প্রতি ঘোষণা করলেন -- ''মহিমা কীর্তন করো সকালে ও সন্ধ্যায়।’’\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmcclxii{''হে ইয়াহ্‌য়া, ধর্মগ্রন্থ শক্ত ক’রে ধারণ করো।’’ আর আমরা তাঁকে জ্ঞানদান করেছিলাম শৈশবেই,\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmcclxiii{আর আমাদের তরফ থেকে সহৃদয়তা ও পবিত্রতা। আর তিনি ছিলেন ধর্মপরায়ণ,\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmcclxiv{আর তাঁর পিতামাতার প্রতি অনুগত, আর তিনি ছিলেন না উদ্ধত, অবাধ্য।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmcclxv{আর শান্তি তাঁর উপরে যেদিন তাঁর জন্ম হয়েছিল ও যেদিন তিনি মারা গিয়েছিলেন আর যেদিন তাঁকে পুরুত্থিত করা হবে জীবিত অবস্থায়।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmcclxvi{আর গ্রন্থখানাতে মরিয়মের কথা স্মরণ করো -- যখন তিনি তাঁর পরিবারবর্গ থেকে সরে গিয়েছিলেন পুবদিকের এক জায়গায়,\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmcclxvii{তারপর তিনি তাদের থেকে পর্দা অবলন্বন করলেন, তখন আমরা তাঁর কাছে পাঠালাম আমাদের দূতকে, কাজেই তাঁর কাছে সে এক পুরোপুরি মানুষের অনুরূপে দেখা দিল।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmcclxviii{তিনি বললেন -- ''নিঃসন্দেহ আমি তোমার থেকে আশ্রয় খুজঁছি পরম করুণাময়ের কাছে, যদি তুমি ধর্মভীরু হও।’’\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmcclxix{সে বললে -- ''আমি তো শুধু তোমার প্রভুর বাণীবাহক -- 'যে আমি তোমাকে দান করব এক নিখুঁত ছেলে’।’’\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmcclxx{তিনি বললেন -- ''কেমন ক’রে আমার ছেলে হবে, যেহেতু আমাকে পুরুষ-মানুষ স্পর্শ করে নি এবং আমি অসতীও নই?’’\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmcclxxi{সে বললে -- ''মনটা হবে! তোমার প্রভু বলেছেন -- 'এটি আমার জন্য সহজ-সাধ্য। আর যেন আমরা তাঁকে লোকদের জন্য একটি নিদর্শন বানাতে পারি, আর আমাদের থেকে এক করুণা, আর এ তো এক স্থিরীকৃত ব্যাপার’।’’\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmcclxxii{তারপর তিনি তাঁকে গর্ভে ধারণ করলেন, এবং তৎসহ এক দূরবর্তী স্থানে সরে গেলেন।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmcclxxiii{তখন প্রসব-বেদনা তাঁকে এক খেজুর গাছের গুড়িতে নিয়ে এল। তিনি বললেন -- ''হায় আমার দুর্ভোগ! এর আগে যদি আমি মরেই যেতাম এবং সম্পূর্ণ বিস্মৃতিতে বিস্মৃত হতাম!’’\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmcclxxiv{তখন তাঁর নিচে থেকে তাঁকে ডেকে বললে -- ''দুঃখ করো না, তোমার প্রভু অবশ্য তোমার নিচে দিয়ে একটি জলধারা রেখেছেন।’’\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmcclxxv{''আর খেজুর গাছের কান্ডটি তোমার দিকে টানতে থাক, এটি তোমার উপরে টাটকা-পাকা খেজুর ফেলবে।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmcclxxvi{''সুতরাং খাও ও পান করো এবং চোখ জুড়াও। আর লোকজনের কাউকে যদি দেখতে পাও তবে বলো -- 'আমি পরম করুণাময়ের জন্য রোযা রাখার মানত করেছি, কাজেই আমি আজ কোনো লোকের সঙ্গে কথাবার্তা বলব না’।’’\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmcclxxvii{তারপর তিনি তাঁকে নিয়ে এলেন তাঁর লোকদের কাছে তাঁকে চড়িয়ে। তারা বললে -- ''হে মরিয়ম! তুমি আলবৎ এক অদ্ভুত ফেসাদ নিয়ে এসেছ।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmcclxxviii{''হে হারূনের ভগিনী! তোমার বাপ তো খারাপ লোক ছিল না এবং তোমার মা’ও পাপিষ্ঠা নয়!’’\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmcclxxix{তখন তিনি তাঁর দিকে ইশারা করলেন। তারা বললে -- ''আমরা কেমন ক’রে কথা বলব তার সঙ্গে যে দোলনার শিশু?’’\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmcclxxx{তিনি বললেন -- ''নিঃসন্দেহ আমি আল্লাহ্‌র একজন বান্দা, তিনি আমাকে কিতাব দিয়েছেন এবং আমাকে নবী বানিয়েছেন,\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmcclxxxi{''আর তিনি আমাকে মঙ্গলময় করেছেন যেখানেই আমি থাকি না কেন, আর তিনি আমার প্রতি বিধান দিয়েছেন নামায পড়তে ও যাকাত দিতে যতদিন আমি জীবিত অবস্থায় অবস্থান করি,\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmcclxxxii{''আর আমার মায়ের প্রতি অনুগত থাকতে, আর তিনি আমাকে বিদ্রোহীভাবাপন্ন হতভাগ্য করেন নি।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmcclxxxiii{''আর শান্তি আমার উপরে যেদিন আমার জন্ম হয়েছিল, আর যেদিন আমি মারা যাব আর যেদিন আমাকে পুনরুত্থিত করা হবে জীবিত অবস্থায়।’’\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmcclxxxiv{এই হচ্ছে মরিয়মপুত্র ঈসা, সত্য বিবৃতি যে-সন্বন্ধে তারা বিতর্ক করে।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmcclxxxv{এ আল্লাহ্‌র জন্য নয় যে তিনি এক সন্তান গ্রহণ করবেন। তাঁরই সব মহিমা! তিনি যখন কোনো-কিছু সিদ্ধান্ত করেন তখন সেজন্য তিনি শুধু বলেন -- 'হও’, আর তা হয়ে যায়।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmcclxxxvi{''আর নিশ্চয় আল্লাহ্ আমার প্রভু ও তোমাদেরও প্রভু, অতএব তাঁরই এবাদত করো। এটিই সহজ-সঠিক পথ।’’\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmcclxxxvii{কিন্তু গোত্রেরা তাদের পরস্পরের মধ্য মতানৈক্য সৃষ্টি করল, সুতরাং ধিক্ তাদের প্রতি যারা অবিশ্বাস পোষণ করে সেই ভয়ঙ্কর দিনে হাজিরাদানের কারণে।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmcclxxxviii{কত স্পষ্টভাবে তারা শুনবে ও দেখবে সেইদিন যেদিন তারা আমাদের কাছে আসবে! কিন্তু অন্যায়কারীরা আজ স্পষ্ট ভুলের মধ্যে রয়েছে।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmcclxxxix{আর তাদের সতর্ক করে দাও সেই দারুণ পরিতাপের দিন সন্বন্ধে যখন ব্যাপারের সিদ্ধান্ত হয়ে যাবে। আর তারা তো গাফিলতিতে রয়েছে, আর তারা বিশ্বাসও করে না।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmccxc{নিঃসন্দেহ আমরা নিজেরাই পৃথিবী ও তার উপরে যারা আছে সে-সমস্তের উত্তরাধিকারী, আর আমাদের কাছেই তাদের ফিরিয়ে আনা হবে।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmccxci{আর গ্রন্থখানার মধ্যে ইব্রাহীমের কথা স্মরণ করো। নিঃসন্দেহ তিনি ছিলেন সত্য-পরায়ণ, একজন নবী।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmccxcii{দেখো! তিনি তাঁর পিতৃপুরুষকে বললেন -- ''হে আমার বাপা! তুমি কেন তার উপাসনা কর যে শোনে না ও দেখে না এবং তোমাকে কোনো কিছুতেই সমৃদ্ধ করে না?\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmccxciii{''হে আমার আব্বু! নিঃসন্দেহ আমার কাছে অবশ্যই জ্ঞান এসেছে যা তোমার কাছে আসে নি, সুতরাং আমার অনুসরণ কর, আমি তোমাকে সঠিক পথে পরিচালিত করব।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmccxciv{''হে আমার বাপা! শয়তানের উপাসনা করো না। নিশ্চয়ই শয়তান পরম করুণাময়ের অবাধ্য।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmccxcv{''হে আমার বাপুজি! আমি আলবৎ আশঙ্কা করি যে পরম করুণাময়ের কাছ থেকে শাস্তি তোমাকে স্পর্শ করবে, ফলে তুমি হয়ে পড়বে শয়তানের সঙ্গিসাথী।’\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmccxcvi{সে বললে -- ''হে ইব্রাহীম, তুমি কি আমার উপাস্যদের থেকে বীতশ্রদ্ধ? তুমি যদি না থামো তবে তোমাকে আমি নিশ্চিত পাথর ছুঁড়ে তাড়া করব, আর তুমি আমার থেকে এই মুহূর্তে দূর হয়ে যাও।’’\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmccxcvii{তিনি বললেন, ''তোমার উপরে শান্তি, আমি অবশ্য আমার প্রভুর কাছে তোমার জন্য ক্ষমা প্রার্থনা করব। নিঃসন্দেহ তিনি আমার প্রতি পরম স্নেহময়।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmccxcviii{''আর আমি সরে যাচ্ছি তোমাদের থেকে ও আল্লাহকে ছেড়ে দিয়ে তোমরা যাদের ডাকো ওদের থেকে, আর আমি আমার প্রভুকেই ডাকব, হতে পারে যে আমার প্রভুকে ডেকে আমি করুণাবঞ্চিত হব না।’’\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmccxcix{তারপর যখন তিনি সরে গেলেন তাদের থেকে ও আল্লাহ্‌কে ছেড়ে দিয়ে তারা যাদের ডাকত ওদের থেকে, আমরা তাঁকে দিয়েছিলাম ইসহাককে ও ইয়াকুবকে। আর আমরা প্রত্যেককেই বানিয়েছিলাম নবী।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmccc{আর তাঁদের আমরা দান করেছিলাম আমাদের করুণা থেকে, আর আমরা তাঁদের জন্য নির্ধারণ করেছিলাম সমুচ্চ সুখ্যাতি।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmccci{আর গ্রন্থখানাতে মূসার কথা স্মরণ করো। নিঃসন্দেহ তিনি ছিলেন প্রিয়প্রাত্র, আর তিনি ছিলেন একজন নবী।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmcccii{আর আমরা তাঁকে ডেকেছিলাম পাহাড়ের ডান দিক থেকে, এবং আমরা তাঁকে নিকটে এনেছিলাম যোগাযোগে।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmccciii{আর আমাদের করুণা বশত আমরা তাঁকে দিয়েছিলাম তাঁর ভাই হারুনকে নবীরূপে।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmccciv{আর কিতাবখানাতে স্মরণ করো ইসমাইলের কথা। নিঃসন্দেহ তিনি ছিলেন ওয়াদাতে সত্যপরায়ণ, আর তিনি ছিলেন একজন রসূল, একজন নবী।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmcccv{আর তিনি তাঁর পরিজনবর্গকে নামাযের ও যাকাতের নির্দেশ দিয়েছিলেন, আর তাঁর প্রভুর কাছে তিনি ছিলেন সন্তোষভাজন।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mmcccvi{আর কিতাবখানাতে ইদ্‌রীসের কথা স্মরণ করো। নিঃসন্দেহ তিনি ছিলেন সত্যপরায়ণ, একজন নবী।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mmcccvii{আর আমরা তাঁকে উন্নীত করেছিলাম অত্যুচ্চ পর্যায়ে।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mmcccviii{এরাই তাঁরা যাঁদের উপরে আল্লাহ্ অনুগ্রহ করেছিলেন, -- আদমসন্তানদের থেকে নবীদের মধ্যেকার, আর যাদের আমরা নূহের সাথে বহন করেছিলাম তাদের মধ্যেকার, আর ইব্রাহীম ও ইসমাইলের বংশধরদের মধ্যের এবং যাদের আমরা সৎপথে চালিয়েছিলাম ও মনোনীত করেছিলাম তাদের মধ্যেকার। যখনি পরম করুণাময়ের বাণী তাদের কাছে পাঠ করা হতো তারা লুটিয়ে পড়ত সিজদারত হয়ে ও অ‌শ্রুমোচন করতে করতে।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mmcccix{তারপর তাদের পরে এল পরবর্তিদল যারা নামায বাদ দিল ও কামনা-লালসার অনুসরণ করল, সেজন্য তারা অচিরেই দেখতে পাবে বঞ্চনা, --\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mmcccx{তারা ছাড়া যে তওবা করে ও ঈমান আনে ও সৎকর্ম করে, তারাই তবে বেহেশতে প্রবেশ করবে, আর তাদের প্রতি কোনো অন্যায় করা হবে না, --\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mmcccxi{নন্দন কানন যা পরম করুণাময় তাঁর বান্দাদের জন্য ওয়াদা করেছেন অদৃশ্য জগতে। নিঃসন্দেহ তাঁর প্রতি‌শ্রুতি সদাসর্বদা এসেই থাকে।\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mmcccxii{তারা সেখানে শুনবে না কোনো খেলো কথা 'সালাম’ ব্যতীত। আর তাদের জন্য সেখানে রয়েছে তাদের রিযেক সকালে ও সন্ধ্যায়।\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mmcccxiii{এই সেই বেহেশত যেটি আমরা উত্তরাধিকারসূত্রে দিয়েছি আমাদের বান্দাদের মধ্যের তাদের যারা ধর্মপরায়ণ।\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mmcccxiv{আর -- ''আমরা অবতরণ করি না তোমার প্রভুর নির্দেশ ব্যতীত, যা কিছু আমাদের সামনে রয়েছে ও যা কিছু আমাদের পেছনে আর যা কিছু রয়েছে এই দুইয়ের মধ্যে সে সমস্ত তাঁরই, আর তোমার প্রভু ভুলো নন।\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mmcccxv{''তিনি মহাকাশমন্ডল ও পৃথিবীর এবং এ দুইয়ের মধ্যে যা কিছু আছে তার প্রতিপালক প্রভু। সুতরাং তাঁকেই উপাসনা কর এবং তাঁর উপাসনায় অবিরাম সাধনা কর। তুমি কি কাউকে তাঁর সমকক্ষ জ্ঞান কর?’’\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mmcccxvi{আর লোকে বলে -- ''কি! আমি যখন মরে যাব তখন কি আমাকে বের করে আনা হবে জীবিত অবস্থায়?’’\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mmcccxvii{কি? মানুষ কি স্মরণ করে না যে আমরা তাকে ইতিপূর্বে সৃষ্টি করেছিলাম যখন সে কিছুই ছিল না?\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mmcccxviii{কাজেই তোমার প্রভুর কসম, আমরা অতি অবশ্য তাদের সমবেত করব, আর শয়তানদেরও, তারপর আমরা অবশ্যই তাদের হাজির করব জাহান্নামের চারিদিকে নতজানু অবস্থায়।\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mmcccxix{তারপর আমরা নিশ্চয় বের করে আনব প্রত্যেক দল থেকে তাদের মধ্যের ওকে যে পরম করুণাময়ের প্রতি সর্বাধিক অবাধ্য।\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mmcccxx{আর আমরা নিশ্চয় ভাল জানি তাদের যারা নিজেরাই সেখানে দগ্ধ হবার জন্যে সব চাইতে যোগ্য।\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@mmcccxxi{আর তোমাদের মধ্যে এমন একজনও নেই যে সেখানে না আসবে, -- এটি তোমার প্রভুর জন্যে এক অনিবার্য সিদ্ধান্ত।\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@mmcccxxii{আর আমরা উদ্ধার করব তাদের যারা ধর্মপরায়ণতা অবলন্বন করে, আর অন্যায়কারীদের সেখানে রেখে দেব নতজানু অবস্থায়।\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@mmcccxxiii{আর যখন তাদের কাছে আমাদের সুস্পষ্ট বাণীসমূহ পড়া হয় তখন যারা অবিশ্বাস পোষণ করে তারা বলে যারা বিশ্বাস করেছে তাদের -- ''দুই দলের মধ্যে কোনটি প্রতিষ্ঠার দিকে শ্রেষ্ঠতর ও জাঁকজমকে গুলজার?’’\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@mmcccxxiv{আর তাদের আগে কত মানবগোষ্ঠীকে আমরা ধ্বংস করেছি যারা ধনসম্পদে ও বাগাড়ন্বরে জমজমাট ছিল!\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@mmcccxxv{বলো -- ''যে বিভ্রান্তিতে রয়েছে পরম করুণাময় তার জন্য ঢিলে দিয়ে লন্বা করে দেন যে পর্যন্ত না তারা দেখতে পায় যা তাদের ওয়াদা করা হয়েছিল -- হয় শাস্তি নয়তো ঘড়িঘন্টা, তখন তারা জানতে পারবে কে হচ্ছে অবস্থানে বেশী নিকৃষ্ট এবং শক্তিসামর্থের বেশী দুর্বল।’’\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@mmcccxxvi{আর যারা সৎপথে চলে আল্লাহ্ তাদের সুগতি বাড়িয়ে দেন, আর স্থায়ী সৎকর্ম তোমার প্রভুর কাছে পুরস্কার প্রদানের জন্য সর্বশ্রেষ্ঠ আর সুফল ফলনের জন্যেও সর্বশ্রেষ্ঠ।\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@mmcccxxvii{তুমি কি তাকে দেখেছ যে আমাদের বাণীসমূহ অবিশ্বাস করে ও বলে -- ''আমাকে আলবৎ ধনদৌলত ও সন্তানসন্ততি দেয়া হবে’’?\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@mmcccxxviii{সে কি অদৃশ্য সন্বন্ধে জেনে গেছে, না কি সে পরম করুণাময়ের কাছ থেকে কোনো চুক্তি আদায় করেছে?\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@mmcccxxix{নিশ্চয়ই না! সে যা বলে তা সঙ্গে সঙ্গে আমরা লিখে রাখব, আর তার জন্য আমরা লম্বা করে দেব শাস্তির লম্বাই।\qt@no{(79)}}
\qt@newcmd\qurantrans@bn@mmcccxxx{আর সে যা বলে সে ব্যাপারে আমরা তাকে উত্তরাধিকার করব, আর আমাদের কাছে সে আসবে নিঃসঙ্গ অবস্থায়।\qt@no{(80)}}
\qt@newcmd\qurantrans@bn@mmcccxxxi{আর তারা আল্লাহ্‌কে ছেড়ে দিয়ে অন্য উপাস্য গ্রহণ করেছে যেন তারা তাদের জন্য হতে পারে এক সহায় সন্বল।\qt@no{(81)}}
\qt@newcmd\qurantrans@bn@mmcccxxxii{কখনোই না! তারা শীঘ্রই তাদের বন্দনা অস্বীকার করবে। আর তারা হবে এদের বিরোধিপক্ষ।\qt@no{(82)}}
\qt@newcmd\qurantrans@bn@mmcccxxxiii{তুমি কি লক্ষ্য কর নি যে আমরা শয়তানদের পাঠিয়েছি অবিশ্বাসীদের নিকটে বিশেষ উসকানিতে উসকানি দিতে।\qt@no{(83)}}
\qt@newcmd\qurantrans@bn@mmcccxxxiv{সুতরাং তাদের জন্য ব্যস্ত হয়ো না। আমরা তো তাদের জন্য সংখ্যা গণনা করছি।\qt@no{(84)}}
\qt@newcmd\qurantrans@bn@mmcccxxxv{সেদিন ধর্মপরায়ণদের আমরা সমবেত করব পরম করুণাময়ের কাছে রাজদূতরূপে,\qt@no{(85)}}
\qt@newcmd\qurantrans@bn@mmcccxxxvi{আর অপরাধীদের আমরা তাড়িয়ে নেব জাহান্নামের দিকে তৃষ্ণাতুর অবস্থায়।\qt@no{(86)}}
\qt@newcmd\qurantrans@bn@mmcccxxxvii{পরম করুণাময়ের নিকট থেকে যে কোনো কড়ার লাভ করেছে সে ব্যতীত কারোর সুপারিশ করার ক্ষমতা থাকবে না।\qt@no{(87)}}
\qt@newcmd\qurantrans@bn@mmcccxxxviii{আর তারা বলে -- ''পরম করুণাময় একটি সন্তান গ্রহণ করেছেন।’’\qt@no{(88)}}
\qt@newcmd\qurantrans@bn@mmcccxxxix{তোমরা অবশ্যই এক বিকট ব্যপার অবতারণা করেছ।\qt@no{(89)}}
\qt@newcmd\qurantrans@bn@mmcccxl{এর দ্বারা মহাকাশমন্ডল বিদীর্ণ হয়ে যাবার উপক্রম করছে আর পৃথিবী চূর্ণ-বিচূর্ণ হতে চলছে আর পাহাড়পর্বত খন্ডবিখন্ড হয়ে ভেঙ্গে পড়ছে --\qt@no{(90)}}
\qt@newcmd\qurantrans@bn@mmcccxli{যেহেতু তারা পরম করুণাময়ের প্রতি সন্তান দাবি করছে।\qt@no{(91)}}
\qt@newcmd\qurantrans@bn@mmcccxlii{আর পরম করুণাময়ের পক্ষে এটি সমীচীন নয় যে তিনি সন্তান গ্রহণ করবেন।\qt@no{(92)}}
\qt@newcmd\qurantrans@bn@mmcccxliii{মহাকাশমন্ডলে ও পৃথিবীতে এমন কেউ নেই যে পরম করুণাময়ের কাছে আসবে বান্দারূপে ছাড়া।\qt@no{(93)}}
\qt@newcmd\qurantrans@bn@mmcccxliv{তিনি অবশ্যই তাদের হিসেব রেখেছেন, আর তিনি তাদের গণনা করছেন গুনতিতে।\qt@no{(94)}}
\qt@newcmd\qurantrans@bn@mmcccxlv{আর তাদের সবকয়জনকেই কিয়ামতের দিনে তাঁর কাছে আসতে হবে নিঃসঙ্গ অবস্থায়।\qt@no{(95)}}
\qt@newcmd\qurantrans@bn@mmcccxlvi{নিঃসন্দেহ যারা ঈমান এনেছে ও সৎকর্ম করছে তাদের জন্য পরম করুণাময় এখনি যোগান ধরবেন প্রেম।\qt@no{(96)}}
\qt@newcmd\qurantrans@bn@mmcccxlvii{সুতরাং আমরা তো এটিকে তোমার মাতৃভাষায় সহজবোধ্য করে দিয়েছি যেন এর দ্বারা তুমি ধর্মপরায়ণদের সুসংবাদ দিতে পার আর এর দ্বারা সাবধান করে দিতে পার বিতর্কপ্রিয় সম্প্রদায়কে।\qt@no{(97)}}
\qt@newcmd\qurantrans@bn@mmcccxlviii{আর তাদের আগে আমরা কত মানবগোষ্ঠীকে ধ্বংস করেছি! তুমি কি তাদের মধ্যের একজনকেও দেখতে পাও অথবা তাদের থেকে গুনগুনানি শুনতে পাও?\qt@no{(98)}}
\qt@newcmd\qurantrans@bn@mmcccxlix{\basmalahbn ত্বা, হা।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmcccl{আমরা তোমার কাছে কুরআন অবতারণ করি নি যে তুমি বিপন্ন বোধ করবে, --\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmcccli{যে ভয় করে তাকে স্মরণ করে দেবার জন্যে ছাড়া,\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmccclii{এ একটি অবতারণ তাঁর কাছ থেকে যিনি সৃষ্টি করেছেন পৃথিবী ও সমুচ্চ মহাকাশমন্ডলী।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmcccliii{পরম করুণাময় আরশের উপরে সুপ্রতিষ্ঠিত রয়েছেন।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmcccliv{যা কিছু আছে মহাকাশমন্ডলীতে ও যা কিছু এ দুইয়ের মধ্যে রয়েছে আর যা রয়েছে মাটির নিচে সে-সবই তাঁর।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmccclv{আর যদি তুমি বক্তব্য প্রকাশ কর তবে তো তিনি গোপন জানেন আর যা আরও লুকোনো।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmccclvi{আল্লাহ্‌, তিনি ছাড়া অন্য উপাস্য নেই। তাঁরই হচ্ছে সব সুন্দর সুন্দর নামাবলী।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmccclvii{আর মূসার কাহিনী কি তোমার কাছে এসে পৌঁছেছে?\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmccclviii{স্মরণ করো! তিনি দেখতে পেলেন একটি আগুন, তাই তিনি তাঁর পরিবারবর্গকে বললেন -- ''দাঁড়াও, আমি নিঃসন্দেহ একটি আগুন দেখছি, সম্ভবতঃ তোমাদের জন্য সেখান থেকে আমি জ্বলন্ত আঙটা আনতে পারব অথবা আগুনের কাছ থেকে কোনো পথনির্দেশ পেয়ে যাব।’’\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmccclix{তারপর যখন তিনি সেখানে এলেন তখন ডাকা হ’ল -- ''হে মূসা!\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmccclx{''নিঃসন্দেহ আমি, আমিই তোমার প্রভু, অতএব তোমার জুতো খুলে ফেল, তুমি অবশ্য পবিত্র উপত্যকা 'তুওয়া’তে রয়েছ।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmccclxi{''আর আমি তোমাকে মনোনীত করেছি, তাই শোনো যা প্রত্যাদেশ করা হচ্ছে।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmccclxii{''নিঃসন্দেহ আমি, আমিই আল্লাহ্‌, আমি ছাড়া আর কোনো উপাস্য নেই, সেজন্য আমার উপাসনা করো, আর আমাকে মনে রাখার জন্যে নামায কায়েম করো।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmccclxiii{''নিঃসন্দেহ ঘড়িঘন্টা এসেই যাচ্ছে, আমি চাই এ গোপন রাখতে, যেন প্রত্যেক জীবকে পুরস্কৃত করা যেতে পারে তাই দিয়ে যার জন্য সে চেষ্টা করে।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmccclxiv{''সেজন্য তোমাকে এ থেকে সে যেন না ফেরায় যে এতে বিশ্বাস করে না আর যে তার কামনার অনুবর্তী হয়, পাছে তুমি ধ্বংস হয়ে যাও।’’\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmccclxv{''তোমার ডান হাতে ঐটি কি, হে মূসা?’’\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmccclxvi{তিনি বললেন -- ''এটি আমার লাঠি, আমি এর উপরে ভর দিই, আর এ দিয়ে আমার মেষপালের জন্য আমি গাছের পাতা পেড়ে থাকি, আর আমার জন্য এতে অন্যান্য কাজও হয়।’’\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmccclxvii{তিনি বললেন -- ''এটি ছুঁড়ে মার, হে মূসা!’’\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmccclxviii{সুতরাং তিনি এটি ছুঁড়ে মারলেন, তখন দেখো! এটি হয়ে গেল একটি সাপ -- ছুটতে লাগল।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmccclxix{তিনি বললেন -- ''এটিকে ধর, আর ভয় করো না, এটিকে আমরা সঙ্গে সঙ্গে ফিরিয়ে নেব তার আগের অবস্থায়।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmccclxx{আর তোমার হাত তোমার বগলের মধ্যে চেপে ধর, তা সাদা হয়ে বেরিয়ে আসবে কোনো দোষত্রুটি ছাড়া, -- এ আরেকটি নিদর্শন।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmccclxxi{এই জন্য যে আমরা তোমাকে আমাদের আরো বড় নিদর্শন দেখাতে পারি।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmccclxxii{ফিরআউনের কাছে যাও, নিঃসন্দেহ সে সীমা ছাড়িয়ে যাচ্ছে।’’\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmccclxxiii{তিনি বললেন -- ''আমার প্রভু! আমার বুক আমার জন্য প্রসারিত করো,\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmccclxxiv{''আর আমার কাজ আমার জন্য সহজ করে দাও,\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmccclxxv{''আর আমার জিহ্বা থেকে জড়তা তুমি খুলে দাও,\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmccclxxvi{''যেন তারা আমার বক্তব্য বুঝতে পারে।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmccclxxvii{''আর আমার স্বজনদের মধ্যে থেকে আমার জন্য একজন সাহায্যকারী নিয়োগ করে দাও --\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmccclxxviii{''আমার ভাই হারূনকে,\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmccclxxix{''তাকে দিয়ে আমার কোমর মজবুত করে দাও,\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmccclxxx{''এবং তাকে জুড়ে দাও আমার কাজে,\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmccclxxxi{''যাতে আমরা তোমার মহিমা কীর্তন করতে পারি প্রচুরভাবে,\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmccclxxxii{''আর তোমার গুণগান করতে পারি বহুলভাবে।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmccclxxxiii{''নিঃসন্দেহ তুমি -- তুমিই আমাদের সম্যক দ্রষ্টা।’’\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmccclxxxiv{তিনি বললেন -- ''তোমার আরজি অবশ্য তোমাকে মঞ্জুর করা হ’ল, হে মূসা!\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmccclxxxv{''আর আমরা তো তোমার প্রতি আরও একবার অনুগ্রহ করেছিলাম, --\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmccclxxxvi{''চেয়ে দেখো! আমরা তোমার মাতাকে অনুপ্রেরণা দিয়েছিলাম যা অনুপ্রাণিত করার ছিল।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmccclxxxvii{''এই বলেঃ 'তাকে একটি সিন্দুকের মধ্যে রাখ, তারপর এটিকে পানিতে ভাসিয়ে দাও, তারপর নদী তাকে তীরে ভেড়াবে, তাকে নিয়ে যাবে আমার এক শত্রু ও তারও শত্রু।’’ আর আমি তোমার উপরে আমার তরফ থেকে ভালবাসা অর্পণ করেছিলাম, আর যেন তুমি আমার চোখের সামনে প্রতিপালিত হতে পার।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmccclxxxviii{''চেয়ে দেখো! তোমার ভগিনী হেটে চলেছিল, তখন সে বললে -- 'আমি কি আপনাদের জন্য দেখিয়ে দেব তাকে যে এর ভার নিতে পারে?’’ ফলে তোমাকে আমরা ফিরিয়ে দিলাম তোমার মায়ের কাছে যেন তার চোখ জুড়ায় আর সে যেন পরিতাপ না করে। আর তুমি একটি লোককে মেরে ফেলেছিলে, তারপর আমরা তোমাকে মনঃপীড়া থেকে উদ্ধার করেছিলাম, আর আমরা তোমাকে পরীক্ষা করেছিলাম বহু পরীক্ষায়। এরপর তুমি বহু বৎসর অবস্থান করেছিলে মাদিয়ানবাসীদের সঙ্গে, তারপর, হে মূসা, তুমি সিদ্ধান্ত অনুযায়ী এসে পৌঁছেছ।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmccclxxxix{''আর আমি তোমাকে নির্বাচন করেছি আমার নিজের জন্য।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmcccxc{''তুমি ও তোমার ভাই আমার নির্দেশাবলী নিয়ে যাও, আর আমার নাম-কীর্তনে শিথিল হয়ো না।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmcccxci{''তোমার দুজনে ফিরআউনের কাছে যাও, নিঃসন্দেহ সে সীমা ছাড়িয়ে গেছে।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmcccxcii{''আর তার কাছে তোমরা বল সুরুচিসম্পন্ন কথা, হয়ত বা সে অনুধাবন করবে, অথবা সে ভয় করবে।’’\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmcccxciii{তাঁরা বললেন -- ''আমাদের প্রভু! আমরা অবশ্য আশংকা করছি পাছে সে আমাদের প্রতি আগবেড়ে আক্রমণ করে, অথবা সে সীমা ছাড়িয়ে যায়।’’\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmcccxciv{তিনি বললেন -- ''তোমরা দুজনে ভয় করো না, আমি তো তোমাদের সঙ্গে রয়েছি, আমি শুনছি ও দেখছি।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmcccxcv{''সুতরাং তোমরা উভয়ে তার কাছে যাও এবং বলো -- 'আমরা তোমার প্রভুর বার্তাবাহক, তাই আমাদের সঙ্গে ইসরাইলের বংশধরদের পাঠিয়ে দাও, আর তাদের অত্যাচার করো না। আমরা নিশ্চয়ই তোমার কাছে এসেছি তোমার প্রভুর কাছ থেকে নির্দেশ নিয়ে। আর শান্তি তার উপরে যে পথনির্দেশ অনুসরণ করে।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmcccxcvi{''নিঃসন্দেহ আমাদের কাছে অবশ্য প্রত্যাদিষ্ট হয়েছে যে নিশ্চয় শাস্তি এসে পড়বে তার উপরে যে প্রত্যাখ্যান করে ও ফিরে যায়।’’\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmcccxcvii{সে বললে -- ''তবে কে তোমাদের প্রভু, হে মূসা?’’\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmcccxcviii{তিনি বললেন -- ''আমাদের প্রভু তিনি যিনি সব-কিছুকে দিয়েছেন তার সৃষ্টি, তারপর চালিত করেছেন।’’\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmcccxcix{সে বললে -- ''তাহলে পূর্ববর্তী লোকদের অবস্থা কি হবে?’’\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmcd{তিনি বললেন -- ''তার জ্ঞান আমার প্রভুর কাছে একটি গ্রন্থে রয়েছে, আমার প্রভু ভুল করেন না এবং ভুলেও যান না, --\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmcdi{''যিনি তোমাদের জন্যে পৃথিবীটাকে করেছেন একটি বিছানা, আর তোমাদের জন্য এতে ছড়িয়ে দিয়েছেন পথসমূহ, আর তিনি আকাশ থেকে পাঠান পানি।’’ তারপর এর দ্বারা আমরা উৎপাদন করি জোড়ায় জোড়ায় বিভিন্ন ধরনের গাছপালা।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmcdii{তোমরা খাও আর তোমাদের পশুদের চরাও। নিঃসন্দেহ এই গুলোতে অবশ্যই নিদর্শন রয়েছে বিবেকবুদ্ধিসম্পন্নদের জন্য।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmcdiii{''এ থেকে আমরা তোমাদের সৃষ্টি করেছি, আর এতেই তোমাদের ফিরিয়ে নেব, আর এ থেকেই আমরা তোমাদের বের করে আনব দ্বিতীয় দফায়।’’\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mmcdiv{আর আমরা অবশ্যই তাকে দেখিয়েছিলাম আমাদের নিদর্শনাবলী -- তাদের সব ক’টি, কিন্তু সে প্রত্যাখ্যান করল ও অমান্য করল।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mmcdv{সে বললে -- ''হে মূসা! তুমি কি আমাদের কাছে এসেছ তোমার জাদুর দ্বারা আমাদের দেশ থেকে আমাদের বিতাড়িত করতে?\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mmcdvi{তাহলে আমরাও আলবৎ তোমার কাছে নিয়ে আসছি এরই মতো জাদু, সুতরাং আমাদের মধ্যে ও তোমার মধ্যে একটি স্থানকাল ধার্য হোক যা আমরা ভাঙব না, -- আমরাও না আর তুমিও না, -- এক মধ্যস্থ জায়গায়।’’\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mmcdvii{তিনি বললেন -- ''তোমাদের নির্ধারিত দিনক্ষণ হোক উৎসবের দিন, আর লোকজন যেন জমায়েৎ হয় সকালের দিকে।’’\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mmcdviii{তারপর ফিরআউন উঠে গেল এবং তার ফন্দি আটঁলো, তারপর সে ফিরে এল।\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mmcdix{মূসা তাদের বললেন -- ''ধিক্ তোমাদের! আল্লাহ্‌র প্রতি মিথ্যা আরোপ করো না, পাছে তিনি তোমাদের শাস্তি দিয়ে ধ্বংস করেন, আর যে মিথ্যা রচনা করে সে আলবৎ ব্যর্থ হয়।’’\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mmcdx{তারপর তারা তাদের নিজেদের মধ্যে তাদের কর্তব্য সন্বন্ধে পর্যালোচনা করল, আর সেই আলোচনাটা গোপন রাখল।\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mmcdxi{তারা বলাবলি করলে -- ''এ দুজন নিশ্চয়ই তো দুই জাদুকর যারা চাইছে তাদের জাদু দিয়ে তোমাদের দেশ থেকে তোমাদের বিতাড়িত করতে, আর তোমাদের উৎকৃষ্ট আচার-অনুষ্ঠানকে বিনাশ করতে।\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mmcdxii{''সুতরাং তোমাদের ফন্দি-ফিকির ঠিক করে নাও, তারপর চলে এস সারি বেঁধে, আর সেই আজ বিজয় লাভ করবে যে উপর- হাত হতে পারবে।’’\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mmcdxiii{তারা বললে -- ''হে মূসা! তুমিই কি ছুড়ঁবে, না আমরাই হব প্রথমকার যে ছুড়ঁবে?’’\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mmcdxiv{তিনি বললেন -- ''না, তোমরাই ছোঁড়ো।’’ তখন দেখো! তাদের দড়িদড়া ও তাদের লাঠি-লগুড় তাদের সম্মোহনের ফলে তাঁর কাছে মনে হচ্ছিল যে সেগুলো ঠিকঠিকই দৌড়চ্ছে।\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mmcdxv{ফলে মূসা তাঁর অন্তরে ভীতি অনুভব করলেন।\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mmcdxvi{আমরা বললাম -- ''ভয় করো না, তুমি নিজেই হবে উপরহাত।\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mmcdxvii{''আর তোমার ডান হাতে যা আছে তা ছোঁড়ো, এটি খেয়ে ফেলবে তারা যা বানিয়েছে। নিঃসন্দেহ তারা বানিয়েছে জাদুকরের ভেলকিবাজি। আর জাদুকর কখনো সফল হবে না যেখান থেকেই সে আসুক।’’\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mmcdxviii{তারপর জাদুকররা লুটিয়ে পড়ল সিজদাবনত হয়ে, তারা বললেন -- ''আমরা ঈমান আনলাম হারূন ও মূসার প্রভুর প্রতি।’’\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@mmcdxix{সে বললে -- ''তোমরা তার প্রতি বিশ্বাস স্থাপন করলে আমি তোমাদের অনুমতি দেবার আগেই? সে-ই দেখছি তবে তোমাদের জাদুবিদ্যা শিখিয়েছে। কাজেই আমি নিশ্চয় তোমাদের হাত ও তোমাদের পা আড়াআড়িভাবে কেটে ফেলবই, আর আমি অবশ্যই তোমাদের শূলে চড়াব খেজুর গাছের কান্ডে, আর তোমরা অবশ্যই জানতে পারবে আমাদের মধ্যে কার দেওয়া শাস্তি বেশী কঠোর ও দীর্ঘস্থায়ী।’’\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@mmcdxx{তারা বললে -- ''আমরা কখনই তোমাকে অধিকতর গুরুত্ব দেব না সুস্পষ্ট প্রমাণের যা আমাদের কাছে এসেছে ও যিনি আমাদের সৃষ্টি করেছেন সে-সবের উপরে, কাজেই রায় দাও তুমি যা রায় দিতে চাও। তুমি তো রায় দিতে পার কেবল এই দুনিয়ার জীবন সন্বন্ধে।\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@mmcdxxi{''নিঃসন্দেহ আমরা আমাদের প্রভুর প্রতি বিশ্বাস স্থাপন করেছি, যাতে তিনি ক্ষমা করেন আমাদের অপরাধসমূহ আব যেসব জাদুর প্রতি তুমি আমাদের বাধ্য করেছিলে। আর আল্লাহ্‌ই সর্বশ্রেষ্ঠ ও চিরস্থায়ী।’’\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@mmcdxxii{নিঃসন্দেহ যে কেউ তার প্রভুর কাছে আসে অপরাধী হয়ে তার জন্য তবে তো রয়েছে জাহান্নাম। সে সেখানে মরবে না, আর সে বাঁচবেও না।\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@mmcdxxiii{আর যে কেউ তাঁর কাছে আসে বিশ্বাসী হয়ে সে সৎকাজও করেছে, তাহলে এরাই -- এদের জন্যেই রয়েছে অত্যুচ্চ মর্যাদা-\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@mmcdxxiv{নন্দন কানন, তার নিচ দিয়ে বয়ে চলে ঝরনারাজি, সেখানে তারা থাকবে চিরকাল। আর এটিই হচ্ছে পুরস্কার তার জন্য যে পবিত্র করেছে।\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@mmcdxxv{আর আমরা অবশ্যই মূসার প্রতি প্রত্যাদেশ দিয়েছিলাম এই বলে -- ''আমার বান্দাদের নিয়ে রাত্রিকালে চলে যাও, আর তাদের জন্য সাগরের মধ্য দিয়ে একটি শুকনো পথ ভেঙ্গে চল, ধরা পড়ার আশংকা করো না, আর ভয় করো না।’’\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@mmcdxxvi{অতঃপব ফিরআউন তার সৈন্যবাহিনী নিয়ে তাদের পশ্চাদ্বাবন করল, তখন সাগর থেকে তাদের ডুবিয়ে দিল যা তাদের ডুবিয়েছিল।\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@mmcdxxvii{আর ফিরআউন তার লোকজনকে পথভ্রান্ত করেছিল, আর সে সৎপথে চালায় নি।\qt@no{(79)}}
\qt@newcmd\qurantrans@bn@mmcdxxviii{হে ইসরাইলের বংশধরগণ! আমরা নিশ্চয় তোমাদের উদ্ধার করেছিলাম তোমাদের শত্রুদের থেকে, আর আমরা তোমাদের সঙ্গে একটি ওয়াদা করেছিলাম পর্বতের ডান পার্শ্বে, আর তোমাদের নিকট আমরা পাঠিয়েছিলাম মান্না ও সালওয়া --\qt@no{(80)}}
\qt@newcmd\qurantrans@bn@mmcdxxix{''আমরা তোমাদের যা রিযেক দান করেছি তা থেকে ভাল ভাল বস্তু খাওয়া-দাওয়া করো, আর এতে সীমা ছাড়িয়ে যেও না, পাছে আমার ক্রোধ তোমাদের উপরে অবধারিত হয়ে যায়, আর যার উপরে আমার ক্রোধ অবধারিত হয় সে তো তাহলে ধ্বংস হয়ে যায়।\qt@no{(81)}}
\qt@newcmd\qurantrans@bn@mmcdxxx{''আর নিঃসন্দেহ আমি তো পরম পরিত্রাণকারী তার জন্য যে ফেরে ও বিশ্বাস স্থাপন করে ও সৎকর্ম কবে, তারপব সঠিক পথে চলে।’’\qt@no{(82)}}
\qt@newcmd\qurantrans@bn@mmcdxxxi{''আর হে মূসা, কি তোমাকে তোমার লোকদের থেকে তাড়াতাড়ি নিয়ে এসেছে?’’\qt@no{(83)}}
\qt@newcmd\qurantrans@bn@mmcdxxxii{তিনি বললেন -- ''ঐ তো তারা আমার অনুসরণে রয়েছে, আর হে প্রভু! আমি তাড়াতাড়ি তোমার কাছে এসেছি, যেন তুমি সন্তষ্ট হও।’’\qt@no{(84)}}
\qt@newcmd\qurantrans@bn@mmcdxxxiii{তিনি বললেন -- ''আমরা কিন্তু তোমার পরে তোমার লোকদের তো সংকটের মধ্যে ফেলে দিয়েছি, কারণ সামিরী তাদের বিপথে নিয়েছে।’’\qt@no{(85)}}
\qt@newcmd\qurantrans@bn@mmcdxxxiv{তখন মূসা তাঁর সম্প্রদায়ের নিকট ফিরে এলেন ত্রুদ্ধ ও ক্ষুদ্ধ হয়ে। তিনি বললেন -- ''হে আমার সম্প্রদায়! তোমাদের প্রভু কি তোমাদের সাথে ওয়াদা করেন নি এক উৎকৃষ্ট ওয়াদা? তবে কি প্রতি‌শ্রুত সময় তোমাদের জন্য দীর্ঘ মনে হয়েছিল, না তোমরা চেয়েছিলে যে তোমাদের প্রভুর শাস্তি তোমাদের উপরে অবধারিত হোক, যার জন্য তোমরা আমাকে দেওয়া ওয়াদার খেলাফ করেছ?’’\qt@no{(86)}}
\qt@newcmd\qurantrans@bn@mmcdxxxv{তারা বললে -- ''আমরা নিজেদের থেকে তোমাকে দেওয়া ওয়াদার খেলাফ করি নি, কিন্তু আমাদের উপরে লোকেদের অলংকারের বোঝা চাপিয়ে দেওয়া হয়েছিল আমরা সে-সব ফেলে দিই, আর এভাবেই সামিরী বাতলেছিল।’’\qt@no{(87)}}
\qt@newcmd\qurantrans@bn@mmcdxxxvi{তারপর সে তাদের জন্য এক গরুর বাছুর গঠন করল -- এক কায়া মাত্র, ফাঁকা আওয়াজ ছিল তার, আর তারা বলেছিল -- ''এটিই তোমাদের খোদা ও মূসারও খোদা, কিন্তু তিনি ভুলে গেছেন!’’\qt@no{(88)}}
\qt@newcmd\qurantrans@bn@mmcdxxxvii{তারা কি তবে দেখে নি যে এটি তাদের প্রতি কথার জবাব দিত না, আর তার কোনো ক্ষমতা ছিল না তাদের ক্ষতি করবার, আর ছিল না উপকার করবাব?\qt@no{(89)}}
\qt@newcmd\qurantrans@bn@mmcdxxxviii{আর অবশ্য হারূন এর আগে তাদের বলেছিলেন -- ''হে আমার সম্প্রদায়! নিঃসন্দেহ তোমরা এর দ্বারা সংকটের মধ্যে পড়েছ, আর তোমাদের প্রভু তো পরম করুণাময়, সেজন্য আমার অনুসরণ করো এবং আমার নির্দেশ পালন করো।’’\qt@no{(90)}}
\qt@newcmd\qurantrans@bn@mmcdxxxix{তারা বললে -- ''আমরা কিছুতেই একে ঘিরে বসে থাকা ছেড়ে দেব না যে পর্যন্ত না মূসা আমাদের কাছে ফিরে আসেন।’’\qt@no{(91)}}
\qt@newcmd\qurantrans@bn@mmcdxl{তিনি বললেন -- ''হে হারূন! কিসে তোমাকে নিষেধ করেছিল যখন তাদের দেখলে তারা বিপথে যাচ্ছে --\qt@no{(92)}}
\qt@newcmd\qurantrans@bn@mmcdxli{''যে জন্যে তুমি আমার অনুসরণ করো না? তবে কি তুমি আমার আদেশ অমান্য করলে?’’\qt@no{(93)}}
\qt@newcmd\qurantrans@bn@mmcdxlii{তিনি বললেন -- ''হে আমার সহোদর! আমার দাড়ি পাকড়ো না আর আমার মাথাও না, নিঃসন্দেহ আমি ভয় করেছিলাম পাছে তুমি বলো -- 'ইসরাইলের বংশধরদের মধ্যে তুমি বিভেদ ঘটিয়েছ এবং আমার কথার অপেক্ষা করো নি’।’’\qt@no{(94)}}
\qt@newcmd\qurantrans@bn@mmcdxliii{তিনি বললেন -- ''তবে তোমার কি বক্তব্য, হে সামিরী?’’\qt@no{(95)}}
\qt@newcmd\qurantrans@bn@mmcdxliv{সে বললে -- ''আমি দেখেছিলাম যা তারা দেখতে পায় নি, তাই আমি রসূলের পদচিহ্ন থেকে মুষ্টি-পরিমাণ মুঠোয় ধরেছিলাম, কিন্তু আমি তা বিসর্জন দিয়েছিলাম, আর আমার মন আমার জন্য এইভাবে করাটাই উপযুক্ত ঠাওরেছিল।’’\qt@no{(96)}}
\qt@newcmd\qurantrans@bn@mmcdxlv{তিনি বললেন, ''তবে দূর হও, নিঃসন্দেহ তোমার জীবদ্দশায় তবে এটিই রইল যে তুমি বলবে, 'ছুয়াঁছুঁয়ি নেই।’ আর নিঃসন্দেহ তোমার জন্য রয়েছে একটি ওয়াদা -- তোমাদের জন্য কখনো তার খেলাফ হবে না। আর তোমার উপাস্যের দিকে তাকাও যাকে ঘিরে বসে থেকে তুমি পূজো করতে। আমরা অবশ্যই এটি পুড়ে ফেলব, তারপর নিশ্চয়ই এটিকে ছিটিয়ে দেব সাগরে ছুঁড়ে ছুঁড়ে।’’\qt@no{(97)}}
\qt@newcmd\qurantrans@bn@mmcdxlvi{তোমাদের উপাস্য তো কেবল আল্লাহ্‌, তিনিই তো, তিনি ছাড়া অন্য উপাস্য নেই। তিনি সবকিছু বেষ্টন করে আছেন জ্ঞানের দ্বারা।\qt@no{(98)}}
\qt@newcmd\qurantrans@bn@mmcdxlvii{এইভাবেই আমরা তোমার কাছে বিবৃত করি যা ইতিপূর্বে ঘটছে তার সংবাদ, আর আমরা নিশ্চয় তোমাকে দিয়েছি আমাদের কাছ থেকে এক স্মারক-গ্রন্থ।\qt@no{(99)}}
\qt@newcmd\qurantrans@bn@mmcdxlviii{যে কেউ এ থেকে বিমুখ হবে সে-ই তো তবে কিয়ামতের দিনে বহন করবে বোঝা,\qt@no{(100)}}
\qt@newcmd\qurantrans@bn@mmcdxlix{এর তলায় সে অবস্থান করে রইবে। আর কিয়ামতের দিনে তাদের জন্য এ বোঝা বড়ই মন্দ!\qt@no{(101)}}
\qt@newcmd\qurantrans@bn@mmcdl{সেইদিন শিঙ্গায় ফুৎকার দেয়া হবে, আর আমরা অপরাধীদের সেই দিনে সমবেত করব চোখ নীলাকার করে, --\qt@no{(102)}}
\qt@newcmd\qurantrans@bn@mmcdli{তারা তাদের নিজেদের মধ্যে চুপিচুপি বলাবলি করবে -- ''তোমরা তো অবস্থান করেছ মাত্র দশেক।’’\qt@no{(103)}}
\qt@newcmd\qurantrans@bn@mmcdlii{আমরা ভাল জানি কি তারা বলাবলি করে যখন তাদের মধ্যে চালচলনে দক্ষ ব্যক্তি বলবেন -- ''তোমরা তো একদিন মাত্র অবস্থান করেছিলে।’’\qt@no{(104)}}
\qt@newcmd\qurantrans@bn@mmcdliii{আর তারা তোমাকে পাহাড়গুলো সন্বন্ধে জিজ্ঞাসা করে। কাজেই বলো -- ''আমার প্রভু তাদের ছড়িয়ে দেবেন ছিটিয়ে ছিটিয়ে।’’\qt@no{(105)}}
\qt@newcmd\qurantrans@bn@mmcdliv{তখন তকে পরিণত করবেন মসৃণ সমতল-ভূমিতে,\qt@no{(106)}}
\qt@newcmd\qurantrans@bn@mmcdlv{সেখানে তুমি দেখতে পাবে না কোনো আঁকানো-বাঁকানো আর না কোনো উঁচু-নিচু।\qt@no{(107)}}
\qt@newcmd\qurantrans@bn@mmcdlvi{সেইদিন তারা আহানকারীর অনুসরণ করবে, তাঁর মধ্যে কোনো আঁকানো-বাঁকানো নেই, আর গলার আওয়াজ হবে ক্ষীণ পরম করুণাময়ের সামনে, তারফলে তুমি মৃদু গুন ছাড়া আর কিছুই শুনবে না।\qt@no{(108)}}
\qt@newcmd\qurantrans@bn@mmcdlvii{সেইদিন কোনো সুপারিশে কাজ হবে না তাঁর ব্যতীত যাঁকে পরম করুণাময় অনুমতি দিয়েছেন, আর যার কথায় তিনি সন্তষ্ট হবেন।\qt@no{(109)}}
\qt@newcmd\qurantrans@bn@mmcdlviii{তিনি জানেন কি আছে তাদের সামনে আর কি রয়েছে তাদের পেছনে, আর তারা এটি জ্ঞানের দ্বারা ধারণা করতে পারে না।\qt@no{(110)}}
\qt@newcmd\qurantrans@bn@mmcdlix{আর চেহারাগুলো বিনয়াবনত হবে তাঁর কাছে যিনি চিরীব, সদা-বিদ্যমান। আর সে তো নিশ্চয় ব্যর্থ হবে যে অন্যায়াচরণের বোঝা বহন করবে।\qt@no{(111)}}
\qt@newcmd\qurantrans@bn@mmcdlx{আর যে কেউ সৎকর্ম থেকে কাজ করে যায় আর সে মুমিন হয়, সে তবে আশঙ্কা করবে না কোনো অবিচারের, আর না কোনো ক্ষতি হবার।\qt@no{(112)}}
\qt@newcmd\qurantrans@bn@mmcdlxi{আর এইভাবেই আমরা এটি অবতারণ করেছি -- একখানি আরবী কুরআন, আর তাতে বিশদভাবে বিবৃত করেছি সতর্কবাণী- গুলো থেকে যেন তারা ধর্মপরায়ণতা অবলন্বন করে, অথবা এটি যেন গুণকীর্তনে তাদের উপদেশ দান করে।\qt@no{(113)}}
\qt@newcmd\qurantrans@bn@mmcdlxii{কাজেই আল্লাহ্ অতি মহান, রাজাধিরাজ, চিরন্তন সত্য, আর কুরআন নিয়ে তুমি তাড়াতাড়ি করো না তোমার কাছে এর প্রত্যাদেশ সম্পূর্ণ হওয়ার আগে, বরং বলো -- ''আমার প্রভু! আমাকে জ্ঞান-বিজ্ঞান তুমি বাড়িয়ে দাও’’।\qt@no{(114)}}
\qt@newcmd\qurantrans@bn@mmcdlxiii{আর আমরা অবশ্যই ইতিপূর্বে আদমের প্রতি অঙ্গীকার আরোপ করেছিলাম, কিন্তু সে ভুলে গিয়েছিল, আর আমরা তার মধ্যে কোনো উদ্দেশ্য পাই নি।\qt@no{(115)}}
\qt@newcmd\qurantrans@bn@mmcdlxiv{আর আমরা যখন ফিরিশ্‌তাদের বললাম -- ''আদমকে সিজদা করো’’, তখন তারা সিজদা করল, কিন্তু ইবলিস করল না, সে অমান্য করল।\qt@no{(116)}}
\qt@newcmd\qurantrans@bn@mmcdlxv{সুতরাং আমরা বললাম -- ''হে আদম! নিঃসন্দেহ এ তোমার প্রতি ও তোমার সঙ্গিনীর প্রতি একজন শত্রু, সে যেন বাগান থেকে তোমাদের বের করে না দেয়, তেমন হলে তুমি দুঃখকষ্ট ভোগ করবে।\qt@no{(117)}}
\qt@newcmd\qurantrans@bn@mmcdlxvi{''নিঃসন্দেহ তোমার জন্য এটি যে তুমি সেখানে ক্ষুধা বোধ করবে না, আর তুমি নগ্নও হবে না।\qt@no{(118)}}
\qt@newcmd\qurantrans@bn@mmcdlxvii{''আর তুমি নিশ্চয়ই সেখানে পিপাসার্ত হবে না অথবা রোদেও পুড়বে না।’’\qt@no{(119)}}
\qt@newcmd\qurantrans@bn@mmcdlxviii{অতঃপর শয়তান তাকে কুমন্ত্রণা দিল, সে বললে -- ''হে আদম! আমি কি তোমাকে চালিয়ে নিয়ে যাব অনন্ত-জীবনদায়ক গাছের দিকে ও এক রাজত্বের দিকে যার ক্ষয় নেই?’’\qt@no{(120)}}
\qt@newcmd\qurantrans@bn@mmcdlxix{কাজেই এ থেকে তারা খেল, সুতরাং তাদের লজ্জাস্থানগুলো তাদের কাছে প্রকাশ পেলো, তখন তারা নিজেদের ঢাকতে আরম্ভ করল সেই বাগানের পাতা দিয়ে। আর আদম তার প্রভুর অবাধ্য হয়েছিল, সেজন্য সে ভ্রান্তপথ ধরল।\qt@no{(121)}}
\qt@newcmd\qurantrans@bn@mmcdlxx{এরপর তার প্রভু তাকে নির্বাচিত করলেন আর তার প্রতি ফিরলেন এবং তাকে পথনির্দেশ দিলেন।\qt@no{(122)}}
\qt@newcmd\qurantrans@bn@mmcdlxxi{তিনি বললেন -- ''তোমরা উভয়ে এখান থেকে চলে যাও -- সব ক’জন মিলে, তোমাদের কেউ কেউ অপরদের শত্রু। পরে তোমাদের কাছে আমার পক্ষ থেকে অবশ্যই পথনির্দেশ আসবে, তখন যে আমার পথনির্দেশ অনুসরণ করবে সে তবে বিপথে যাবে না ও দুঃখ-কষ্ট ভোগবে না।\qt@no{(123)}}
\qt@newcmd\qurantrans@bn@mmcdlxxii{''আর যেইজন আমার স্মরণ থেকে ফিরে যাবে তার জন্যে তবে নিশ্চয়ই রয়েছে সংকুচিত জীবিকানির্বাহের উপায়, আর কিয়ামতের দিনে আমরা তাকে তুলব অন্ধ অবস্থায়।’’\qt@no{(124)}}
\qt@newcmd\qurantrans@bn@mmcdlxxiii{সে বলবে -- ''আমার প্রভু! কেন তুমি আমাকে অন্ধ করে তুলেছ, অথচ আমি তো ছিলাম চক্ষুষ্মান?’’\qt@no{(125)}}
\qt@newcmd\qurantrans@bn@mmcdlxxiv{তিনি বলবেন -- ''এইভাবেই আমাদের নির্দেশাবলী তোমার কাছে এসেছিল, কিন্তু তুমি তা অবহেলা করেছিলে, সুতরাং সেইভাবেই আজকের দিনে তুমি অবহেলিত হলে।’’\qt@no{(126)}}
\qt@newcmd\qurantrans@bn@mmcdlxxv{আর এইভাবেই আমরা প্রতিদান দিই তাকে যে বাড়াবাড়ি করে ও তার প্রভুর নির্দেশাবলীতে বিশ্বাস স্থাপন করে না। আর পরকালের শাস্তি তো বড় কঠোর আর আরো স্থায়ী।\qt@no{(127)}}
\qt@newcmd\qurantrans@bn@mmcdlxxvi{এটি কি তাদের সৎপথ দেখায় না যে তাদের পূর্বে আমরা ধ্বংস করেছি কত জনপদকে যাদের বাসভূমিতে এরা বিচরণ করছে? নিঃসন্দেহ এতে তো নিদর্শন রয়েছে বিবেক-বুদ্ধিসম্পন্নদের জন্য।\qt@no{(128)}}
\qt@newcmd\qurantrans@bn@mmcdlxxvii{আর যদি ঘোষণাটি তোমার প্রভুর তরফ থেকে আগেই সাব্যস্ত না হতো তবে এটি অবশ্যাবী হতো, কিন্তু একটি নির্ধারিত কাল রয়েছে।\qt@no{(129)}}
\qt@newcmd\qurantrans@bn@mmcdlxxviii{সেজন্য অধ্যবসায় অবলন্বন করো তারা যা বলে তাতে, আর তোমার প্রভুর প্রশংসার দ্বারা মহিমা জপে থাকো সূর্য উদয়ের আগে ও তার অস্ত যাবার আগে, আর রাত্রির কিছু সময়েও তবে জপতপ করো, আর দিনের বেলায়, যাতে তুমি সন্তষ্টি লাভ করতে পারো।\qt@no{(130)}}
\qt@newcmd\qurantrans@bn@mmcdlxxix{আর তোমার চোখ টাটিয়ো না তার প্রতি যা দিয়ে তাদের মধ্যেকার কোনো কোনো দম্পতিকে আমরা আপ্যায়িত করেছি -- দুনিয়ার জীবনের আড়ন্বর, যেন তার দ্বারা আমরা তাদের পরীক্ষা করতে পারি। আর তোমার প্রভুপ্রদত্ত রিযেক অধিকতর ভালো ও বেশী স্থায়ী।\qt@no{(131)}}
\qt@newcmd\qurantrans@bn@mmcdlxxx{আর তোমার পরিবারবর্গকে নামাযের নির্দেশ দাও আর তাতে লেগে থাকো। আমরা তোমার কাছ থেকে কোনো রিযেক চাই না, আমরাই তোমাকে রিযেক দান করি। আর শুভ পরিণাম তো ধর্মপরায়ণতার জন্য।\qt@no{(132)}}
\qt@newcmd\qurantrans@bn@mmcdlxxxi{আর তারা বলে -- ''কেন সে তার প্রভুর কাছ থেকে আমাদের জন্য একটি নিদর্শন নিয়ে আসে না?’’ কী! তাদের কাছে কি পূর্ববর্তী গ্রন্থগুলোয় যা আছে সে সন্বন্ধে সুস্পষ্ট প্রমাণ আসে নি?\qt@no{(133)}}
\qt@newcmd\qurantrans@bn@mmcdlxxxii{আর আমরা যদি এর আগে তাদের ধ্বংস করতাম শাস্তি দিয়ে তবে তারা বলতে পারত -- ''আমাদের প্রভু! তুমি কেন আমাদের কাছে একজন রসূল পাঠাও নি, তাহলে তো আমরা তোমার নির্দেশাবলী অনুসরণ করতে পারতাম আমাদের লাঞ্ছনা ভোগ করবার ও আমাদের অপমান অনুভবের আগেভাগেই?’’\qt@no{(134)}}
\qt@newcmd\qurantrans@bn@mmcdlxxxiii{তুমি বলো -- '' প্রত্যেকেই প্রতীক্ষা করছে, সুতরাং তোমরাও প্রতীক্ষা কর, তাহলে অচিরেই তোমরা জানতে পারবে কারা সঠিক পথের লোক এবং কারা সৎপথে চলেছে।’’\qt@no{(135)}}
\qt@newcmd\qurantrans@bn@mmcdlxxxiv{\basmalahbn মানুষের কাছে তাদের হিসেব-নিকেশ আসন্ন, তথাপি তারা বেখেয়ালিতে ফিরে যাচ্ছে।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmcdlxxxv{আর তাদের কাছে তাদের প্রভুর কাছ থেকে কোনো নতুন স্মারক আসে না যা তারা শোনে যখন তারা খেলতে থাকে, --\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmcdlxxxvi{তাদের হৃদয় কোনো মনোযোগ দেয় না। আর যারা অন্যায়কারী তারা গোপনে শলাপরামর্শ করে -- এই জন কি তোমাদের মতন একজন মানুষ ছাড়া আর কিছু? তোমরা কি তবে জাদুর বশীভূত হবে, অথচ তোমরা দেখতে পাচ্ছ।’’\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmcdlxxxvii{বলো -- ''আমার প্রভু জানেন সব কথাবার্তা মহাকাশ-মন্ডলীতে ও পৃথিবীতে, কেননা তিনি সর্বশ্রোতা, সর্বজ্ঞাতা।’’\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmcdlxxxviii{তারা বলে -- ''না, এলোমেলো স্বপ্ন! না, সে এটি তৈরি করেছে! না, সে একজন কবি। সে বরং আমাদের কাছে এক নিদর্শন নিয়ে আসুক যেমন পূর্ববর্তীদের পাঠানো হয়েছিল।’’\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmcdlxxxix{ওদের আগে যেসব জনপদ বিশ্বাস করে নি তাদের আমরা ধ্বংস করেছি। এরা কি তবে বিশ্বাস করবে?\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmcdxc{আর তোমার আগে আমরা মানুষ ছাড়া অন্য কাউকে পাঠাই নি যাদের কাছে আমরা প্রত্যাদেশ দিয়েছিলাম, কাজেই স্মারকগ্রন্থের অধিকারীদের তোমরা জিজ্ঞেস করো, যদি তোমরা না জানো।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmcdxci{আর আমরা তাঁদের এমন শরীর দিই নি যে তাঁরা খাদ্য খাবেন না, আর তাঁরা চিরস্থায়ীও ছিলেন না।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmcdxcii{তারপর তাঁদের কাছে আমরা ওয়াদা পূর্ণ করেছিলাম, সুতরাং আমরা তাঁদের উদ্ধার করেছিলাম আর তাদেরও যাদের আমরা ইচ্ছা করেছিলাম, আর আমরা ধ্বংস করেছিলাম সীমা-লংঘনকারীদের।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmcdxciii{আমরা অবশ্যই তোমাদের কাছে অবতারণ করেছি এক গ্রন্থ যাতে রয়েছে তোমাদের মহত্ত্ব। তোমরা কি তবে বুঝবে না?\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmcdxciv{আর আমরা চূর্ণবিচূর্ণ করেছিলাম কত জনপদ যারা অত্যাচার করেছিল, আর তাদের পরে পত্তন করেছিলাম অপর লোকদের।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmcdxcv{তারপর তারা যখন অনুভব করেছিল আমাদের ক্ষমতা, দেখো! তারা এখান থেকে পলায়নপর হয়েছিল।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmcdxcvi{''পালিও না, বরং ফিরে এসো তাতে যাতে তোমরা বিভোর ছিলে, -- তোমাদের বাসস্থানে যেন তোমাদের সওয়াল করা যেতে পারে।’’\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmcdxcvii{তারা বলেছিল -- ''হায় আমাদের দুর্ভোগ! আমরা তো আলবৎ অন্যায়কারী ছিলাম।’’\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmcdxcviii{ফলে তাদের এই আর্তনাদ থামে নি যে পর্যন্ত না আমরা তাদের বানিয়েছিলাম কাটা শস্যের ন্যায়, পুড়িয়ে ফেলা।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmcdxcix{আর আকাশ ও পৃথিবী এবং এ দুইয়ের মধ্যে যা কিছু আছে সে-সমস্ত আমরা খেলাচ্ছলে সৃষ্টি করি নি।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmd{আমরা যদি চাইতাম আমোদ-প্রমোদের জন্য গ্রহণ করতে, তবে আমরা অবশ্যই আমাদের নিজেদের থেকেই তাকে গ্রহণ করতাম, আমরা নিশ্চয়ই তা করব না।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmdi{না, আমরা সত্যের দ্বারা মিথ্যার উপর আঘাত হানি, ফলে তার মগজ চুরমার হয়ে যায়, তখন দেখো! তা অন্তর্হিত হয়। আর ধিক তোমাদের প্রতি! তোমরা যা আরোপ কর সেজন্য।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmdii{আর যারাই আছে মহাকাশগুলীতে ও পৃথিবীতে তারা সবাই তাঁর। আর যারা তাঁর সান্নিধ্যে রয়েছে তারা তাঁর উপাসনা করা থেকে গর্ববোধ করে না, আর তারা ক্লান্তও হয় না, --\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmdiii{তারা রাতে ও দিনে জপতপ করে, তারা শিথিলতা করে না।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmdiv{অপরপক্ষে তারা কি মাটি থেকে উপাস্যদের গ্রহণ করেছে যারা প্রাণবন্ত করতে পারে?\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmdv{যদি ও দুইয়ের মধ্যে আল্লাহ্ ছাড়া অন্যান্য উপাস্যরা থাকত তবে এ দুটোই বিশৃঙ্খল হয়ে যেত। সুতরাং সকল মহিমা আল্লাহ্‌র, যিনি আরশের অধিপতি, -- তারা যা আরোপ করে তার উর্ধ্বে!\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmdvi{তিনি যা করেন যে বিষয়ে তাঁকে প্রশ্ন করা যাবে না, কিন্তু তাদের প্রশ্ন করা হবে।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmdvii{অথবা, তারা কি তাঁকে ছেড়ে দিয়ে উপাস্যদের গ্রহণ করেছে? বলো -- ''তোমাদের প্রমাণ নিয়ে এস। এ হচ্ছে স্মরণীয় বার্তা তাদের জন্য যারা আমার সঙ্গে রয়েছে এবং স্মরণীয় বার্তা আমার পূর্ববর্তীদের জন্যেও।’’ কিন্তু তাদের অধিকাংশই জানে না, ফলে তারা সত্য থেকে বিমুখ থাকে।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmdviii{আর তোমার পূর্বে আমরা কোনো রসূল পাঠাই নি যাঁর কাছে আমরা প্রত্যাদেশ না দিয়েছি এই বলে যে, ''আমি ছাড়া অন্য কোনো উপাস্য নেই, কাজেই আমারই উপাসনা করো’’।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmdix{আর তারা বলে -- ''পরম করুণাময় একটি পুত্র গ্রহণ করেছেন।’’ তাঁরই সব মহিমা! বরং তাঁরা তো সম্মানিত বান্দা, --\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmdx{তাঁরা কথা বলতে তাঁর আগে বেড়ে যান না, আর তাঁরই আদেশ মোতাবেক তাঁরা কাজ করেন।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmdxi{তিনি জানেন যা কিছু আছে তাঁদের সম্মুখে আর যা আছে তাঁদের পশ্চাতে, আর তাঁরা সুপারিশ করেন না তার জন্য ছাড়া যার প্রতি তিনি সন্তষ্ট হয়েছেন, আর তাঁর ভয়ে তাঁরা ভীত-সন্ত্রস্ত।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmdxii{আর তাঁদের মধ্যের যে বলবে -- ''তাঁর পরিবর্তে আমিই একজন উপাস্য’’, তার ক্ষেত্রে তাহলে -- আমরা তাকে প্রতিদান দেব জাহান্নাম। এইভাবেই আমরা প্রতিদান দিই অন্যায়কারীদের।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmdxiii{যারা অবিশ্বাস পোষণ করে তারা কি দেখে না যে মহাকাশমন্ডলী ও পৃথিবী উভয়ে একাকার ছিল, তারপর আমরা তাদের দুটিকে বিচ্ছিন্ন করে দিলাম, আর পানি থেকে আমরা সৃষ্টি করলাম প্রাণবন্ত সবকিছু। তারা কি তবুও বিশ্বাস করবে না?\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmdxiv{আর পৃথিবীতে আমরা পাহাড়-পর্বত স্থাপন করেছি পাছে তাদের সঙ্গে এটি আন্দোলিত হয়, আর ওতে আমরা বানিয়েছি চওড়া পথঘাট যেন তারা সৎপথ প্রাপ্ত হয়।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmdxv{আর আমরা আকাশকে করেছি এক সুরক্ষিত ছাদ। কিন্তু তারা এর নিদর্শনাবলী থেকে বিমুখ থাকে।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmdxvi{আর তিনিই সেই জন যিনি রাত ও দিনকে এবং সূর্য ও চন্দ্রকে সৃষ্টি করেছেন। সব ক’টি কক্ষপথে ভেসে চলেছে।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmdxvii{আর তোমার আগে আমরা কোনো মানুষের জন্য স্থায়িত্ব দিই নি। সুতরাং যদি তোমাকেই মারা যেতে হয় তবে কি তারা চিরজীবী হবে?\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmdxviii{প্রত্যেক সত্ত্বাকে মৃত্যুর স্বাদ গ্রহণ করতেই হবে। আর আমরা তোমাদের পরীক্ষা করি মন্দ ও ভাল দিয়ে যাচাই ক’রে। আর আমাদের কাছেই তোমাদের ফিরিয়ে আনা হবে।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmdxix{আর যারা অবিশ্বাস পোষণ করে তারা যখন তোমাকে দেখে তখন তারা তোমাকে বিদ্রপের পাত্র ছাড়া অন্যভাবে গ্রহণ করে না। ''একি সে যে তোমাদের দেবদেবী সন্বন্ধে সমালোচনা করে?’’ বস্তুতঃ তারা নিজেরাই পরম করুণাময়ের নাম-কীর্তনের বেলা অবিশ্বাস ভাজন করে।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmdxx{মানুষ সৃষ্ট হয়েছে ব্যস্তসমস্ত ছাঁদে। আমি শীঘ্রই তোমাদের দেখাব আমার নিদর্শন সমূহ, সুতরাং তোমারা আমাকে তাড়াতাড়ি করতে বলো না।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmdxxi{আর তারা বলে -- ''কখন এই ওয়াদা ফলবে, যদি তোমরা সত্যবাদী হও?’’\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmdxxii{যারা অবিশ্বাস পোষণ করে তারা যদি জানত সেই সময়ের কথা যখন তারা আগুন সরিয়ে দিতে পারবে না তাদের মুখের থেকে, আর তাদের পিঠের থেকেও না, আর তাদের সাহায্যও করা হবে না।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmdxxiii{বস্তুতঃ তা তাদের উপরে এসে পড়বে অতর্কিতভাবে, ফলে তাদের তা হতবুদ্ধি করে দেবে, সেজন্যে তা এড়াবার ক্ষমতা থাকবে না, এবং তাদের অবকাশও দেওয়া হবে না।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmdxxiv{আর তোমার পূর্বেও রসূলগণকে নিশ্চয়ই বিদ্রপ করা হয়েছিল, তারপর তাদের মধ্যের যারা বিদ্রপ করেছিল তারা যে সন্বন্ধে বিদ্রপ করত সেটাই তাদের পরিবেষ্টন করল।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmdxxv{বলো -- ''কি তোমাদের রক্ষা করবে রাতে ও দিনে পরম করুণাময়ের শাস্তি থেকে?’’ বস্তুতঃ তাদের প্রভুর নামকীর্তন থেকে তারা মুখ ফিরিয়ে নেয়।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmdxxvi{অথবা আমাদের ছেড়ে তোমাদের কি দেবদেবী রয়েছে যারা তাদের রক্ষা করতে পারে? তারা তাদের নিজেদের সাহায্য করার ক্ষমতা রাখে না, আর তারা আমাদের থেকেও রক্ষা পাবে না।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmdxxvii{বস্তুতঃ আমরা এদের আর এদের পিতৃপুরুষদের ভোগ-সম্ভার দিয়েছিলাম যে পর্যন্ত না তাদের জন্য জীবন সুদীর্ঘ হয়েছিল। তারা কি তবে দেখে না যে আমরা দেশটাতে এগিয়ে আসছি এর চৌহদ্দিকে সংকুচিত ক’রে নিয়ে? তারা কি এমতাবস্থায় জয়ী হতে পারবে?\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmdxxviii{বলো -- ''আমি তো তোমাদের সতর্ক করি কেবল প্রত্যাদেশের দ্বারা, আর বধির লোকে আহ্বান শোনে না যখন তাদের সতর্ক করা হয়।’’\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmdxxix{আর যদি তোমার প্রভুর শাস্তির তোড় তাদের স্পর্শ করত তবে তারা নিশ্চয়ই বলত -- ''হায় আমাদের দুর্ভোগ! আমরা নিঃসন্দেহ অন্যায়াচারী ছিলাম।’’\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmdxxx{আর কিয়ামতের দিনে আমরা ন্যায়বিচারের মানদন্ড স্থাপন করব, সেজন্য কারো প্রতি এতটুকুও অন্যায় করা হবে না। আর যদি তা সরসে-বীজের ওজন পরিমাণও হয় আমরা সেটা নিয়ে আসব। আর হিসাব গ্রহণকারীরূপে আমরাই যথেষ্ট।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmdxxxi{আর আমরা অবশ্যই মূসা ও হারূনকে দিয়েছিলাম ফুরকান, আর আলো, আর স্মরণীয় গ্রন্থ -- ধর্মনিষ্ঠদের জন্য, --\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmdxxxii{যারা তাদের প্রভুকে ভয় করে নিভৃতে আর তারা ঘড়িঘন্টা সন্বন্ধে ভীত সন্ত্রস্ত।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmdxxxiii{আর এটি এক কল্যাণময় স্মারকগ্রন্থ যা আমরা অবতারণ করেছি। তোমরা কি তবে এটির প্রতি অমান্যকারী হবে?\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmdxxxiv{আর অবশ্যই আমরা ইব্রাহীমকে ইতিপূর্বে তাঁর সত্যনিষ্ঠতা দিয়েছিলাম, আর তাঁর সন্বন্ধে আমরা সম্যক পরিজ্ঞাত ছিলাম।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmdxxxv{স্মরণ করো! তিনি তাঁর পিতৃপুরুষকে এবং তাঁর লোকদের বললেন -- ''এই মূর্তিগুলো কী যাদের উপাসনায় তোমরা লেগে আছ?’’\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmdxxxvi{তারা বললে -- ''আমরা আমাদের পিতৃপুরুষদের এগুলোকে পূজো করতে দেখেছি।’’\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmdxxxvii{তিনি বললেন -- ''নিশ্চয়ই তোমরা, তোমরা ও তোমাদের পিতৃপুরুষরা, রয়েছ স্পষ্ট বিভ্রান্তিতে।’’\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmdxxxviii{তারা বললে -- ''তুমি কি আমাদের কাছে সত্য নিয়ে এসেছ, না কি তুমি ঠাট্টাবিদ্রপকারীদের একজন?’’\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mmdxxxix{তিনি বললেন -- ''বরং তোমাদের প্রভু হচ্ছেন মহাকাশমন্ডলী ও পৃথিবীর অধীশ্বর যিনি এগুলো শুরুতেই সৃষ্টি করেছেন, এবং এসব সন্বন্ধে আমি সাক্ষ্যদানকারীদের মধ্যেকার।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mmdxl{''আর আল্লাহ্‌র কসম, আমি অবশ্যই তোমাদের প্রতিমাদের সন্বন্ধে পরিকল্পনা গ্রহণ করব তোমরা যখন পিটটান দিয়ে ফিরে যাবে।’’\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mmdxli{তারপর তিনি তাদের টুক্‌রো টুক্‌রো করে ফেললেন তাদের বড়টি ছাড়া, যাতে তারা এর কাছে ফিরে আসতে পারে।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mmdxlii{তারা বললে -- ''আমাদের দেবতাদের প্রতি এ কাজ কে করেছে? নিঃসন্দেহ সে তো অন্যায়কারীদের একজন।’’\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mmdxliii{তারা বললে -- ''আমরা এদের সন্বন্ধে একজন যুবককে বলাবলি করতে শুনেছিলাম, তাকে বলা হয় ইব্রাহীম।’’\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mmdxliv{তারা বললে -- ''তাহলে তাকে লোকদের চোখের সামনে নিয়ে এসো, যেন তারা সাক্ষ্য দিতে পারে।’’\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mmdxlv{তারা বললে -- ''হে ইব্রাহীম, তুমিই কি আমাদের দেবতাদের প্রতি এই কাজ করেছ?\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mmdxlvi{তিনি বললেন -- ''আলবৎ কেউ এটা করেছে, এই তো এদের প্রধান, কাজেই এদের জিজ্ঞেস করো, যদি তারা বলতে পারে।’’\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mmdxlvii{তখন তারা নিজেদের দিকে ফিরল এবং বললে -- ''নিঃসন্দেহ তোমরা নিজেরাই অন্যায়াচারী।’’\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mmdxlviii{তারপর তাদের হেটঁ করা হ’ল তাদের মাথার উপরে ''তুমি তো অবশ্যই জানো যে এরা কথা বলে না।’’\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mmdxlix{তিনি বললেন -- ''তোমরা কি তবে আল্লাহ্‌কে ছেড়ে দিয়ে এমন কিছুর উপাসনা কর যা তোমাদের কোনো উপকার করতে পারে না আর তোমাদের অপকারও করে না?\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mmdl{''ধিক্ তোমাদের প্রতি এবং আল্লাহ্‌কে বাদ দিয়ে তোমরা যাদের উপাসনা কর তাদেরও প্রতি! তোমরা কি তবুও বুঝবে না?’’\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mmdli{তারা বললে -- ''তাকে পুড়িয়ে ফেলো, এবং তোমাদের দেবতাদের সাহায্য করো যদি তোমরা কিছু করতে চাও।’’\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mmdlii{আমরা বললাম -- ''হে আগুন! তুমি শীতল ও শান্ত হও ইব্রাহীমের উপরে।’’\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mmdliii{আর তারা চেয়েছিল তাঁর বিরুদ্ধে ষড়যন্ত্র করতে, কিন্তু আমরা তাদেরই বেশি ক্ষতিগ্রস্ত করেছিলাম।\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@mmdliv{আর আমরা তাঁকে এবং লূতকে উদ্ধার করে এনেছিলাম সেই দেশে যেখানে আমরা জগদ্বাসীর জন্য কল্যাণ রেখেছিলাম।\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@mmdlv{আর আমরা তাঁকে দিয়েছিলাম ইসহাক এবং পৌত্ররূপে ইয়াকুবকে। আর সবাইকে আমরা বানিয়েছিলাম সৎপথাবলন্বী।\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@mmdlvi{আর আমরা তাঁদের বানিয়েছিলাম নেতৃবৃন্দ, তাঁরা আমাদের নির্দেশ অনুসারে সৎপথে চালাতেন, আর তাঁদের কাছে আমরা প্রত্যাদেশ দিয়েছিলাম সৎকাজ করতে ও নামায কায়েম করতে ও যাকাত প্রদান করতে, আর তাঁরা আমাদের প্রতি বন্দনাকারী ছিলেন।\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@mmdlvii{আর লূতের ক্ষেত্রে -- আমরা তাঁকে দিয়েছিলাম বুদ্ধি-বিবেচনা ও জ্ঞান-বিজ্ঞান, আর আমরা তাঁকে উদ্ধার করেছিলাম সেই জনপদ থেকে যারা জঘন্য কাজ করত। নিঃসন্দেহ তারা ছিল দুষ্ট দুরাচারী সম্প্রদায়।\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@mmdlviii{আর তাঁকে আমরা ভর্তি করেছিলাম আমাদের অনুগ্রহের মধ্যে। নিঃসন্দেহ তিনি ছিলেন সৎকর্মীদের অন্তর্ভুক্ত।\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@mmdlix{আর নূহের ক্ষেত্রে, -- স্মরণ করো, তিনি ইতিপূর্বে আহ্বান করেছিলেন, সেজন্য আমরা তাঁর প্রতি সাড়া দিয়েছিলাম, তাই তাঁকে ও তাঁর পরিজনবর্গকে আমরা উদ্ধার করেছিলাম এক বিরাট সংকট থেকে।\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@mmdlx{আর আমরা তাঁকে সাহায্য করেছিলাম সেই লোকদের বিরুদ্ধে যারা আমাদের নির্দেশাবলী প্রত্যাখ্যান করেছিল। নিঃসন্দেহ তারা ছিল দুষ্ট লোক, তাই তাদের সবাইকে আমরা ডুবিয়ে দিয়েছিলাম।\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@mmdlxi{আর দাউদ এবং সুলাইমানের ক্ষেত্রে, -- স্মরণ করো, তাঁরা হুকুম দিয়েছিলেন এক শস্যক্ষেত্র সম্পর্কে যাতে লোকদের ভেড়া ঢুকে পড়েছিল রাতের বেলা, আর আমরা তাঁদের হুকুমের সাক্ষী ছিলাম।\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@mmdlxii{আর আমরা সুলাইমানকে এটি বুঝতে দিয়েছিলাম। আর উভয়কেই আমরা দিয়েছিলাম বিচার-বিবেচনা ও জ্ঞান-বিজ্ঞান, আর আমরা দাউদের সঙ্গে পাহাড়-পর্বতকে ও পাখিগুলোকে মহিমা ঘোষণায় অনুগত করেছিলাম। আর আমরাই কার্যকর্তা।\qt@no{(79)}}
\qt@newcmd\qurantrans@bn@mmdlxiii{আর আমরা তাঁকে শিখিয়েছিলাম তোমাদের জন্য বর্ম তৈরি করতে যেন তা তোমাদের রক্ষা করতে পারে তো মাদের যুদ্ধবিগ্রহে। তোমরা কি তবে কৃতজ্ঞ হবে না?\qt@no{(80)}}
\qt@newcmd\qurantrans@bn@mmdlxiv{আর সুলাইমানকে প্রবল বাতাস, -- তা প্রবাহিত হয়েছিল তাঁর নির্দেশ অনুযায়ী সেই দেশের দিকে যেখানে আমরা কল্যাণ নিহিত করেছিলাম। আর সব বিষয়ে আমরা সম্যক অবগত।\qt@no{(81)}}
\qt@newcmd\qurantrans@bn@mmdlxv{আর শয়তানদের কতক তাঁর জন্য ডুব দিত আর তা ছাড়া আরো কাজ করত, আর আমরা ছিলাম তাদের তত্ত্বাবধায়ক।\qt@no{(82)}}
\qt@newcmd\qurantrans@bn@mmdlxvi{আর আইয়ুবের ক্ষেত্রে, -- স্মরণ করো, তাঁর প্রভুকে তিনি আহ্বান ক’রে বললেন -- ''নিঃসন্দেহ বিপদ আমাকে স্পর্শ করেছে, আর তুমিই তো দয়াশীলদের মধ্যে পরম করুণাময়।’’\qt@no{(83)}}
\qt@newcmd\qurantrans@bn@mmdlxvii{সুতরাং আমরা তাঁর প্রতি সাড়া দিলাম, এবং দুঃখকষ্টের যা থেকে তিনি ভুগছিলেন তা দূর করে দিলাম, আর তাঁকে তাঁর পরিবারবর্গ দিয়েছিলাম এবং তাদের সাথে তাদের মতো লোকদেরও -- আমাদের তরফ থেকে এ এক করুণা, আর বন্দনাকারীদের জন্য স্মরণীয় বিষয়।\qt@no{(84)}}
\qt@newcmd\qurantrans@bn@mmdlxviii{আর ইসমাইল ও ইদরীস ও যুল-কিফল, -- সবাই ছিলেন অধ্যবসায়ীদের মধ্যেকার।\qt@no{(85)}}
\qt@newcmd\qurantrans@bn@mmdlxix{আর তাঁদের আমরা প্রবেশ করিয়েছিলাম আমাদের করুণাভান্ডারে। নিঃসন্দেহ তাঁরা ছিলেন সৎকর্মীদের অন্তর্ভুক্ত ।\qt@no{(86)}}
\qt@newcmd\qurantrans@bn@mmdlxx{আর যুন-নূন, -- স্মরণ করো, তিনি চলে গিয়েছিলেন রেগেমেগে, আর তিনি ভেবেছিলেন যে আমরা কখনো তাঁর উপরে ক্ষমতা চালাব না, তখন সেই সংকটে তিনি আহ্বান করলেন যে ''তুমি ছাড়া অন্য উপাস্য নেই, তোমারই সব মহিমা, আমি নিশ্চয়ই ক্ষতিগ্রস্তদের অন্তর্ভুক্ত হয়েছি।’’\qt@no{(87)}}
\qt@newcmd\qurantrans@bn@mmdlxxi{সুতরাং আমরা তাঁর প্রতি সাড়া দিলাম এবং দুশ্চিন্তা থেকে তাঁকে উদ্ধার করলাম। আর এইভাবেই আমরা মুমিনদের উদ্ধার করে থাকি।\qt@no{(88)}}
\qt@newcmd\qurantrans@bn@mmdlxxii{আর যাকারিয়ার ক্ষেত্রে, -- স্মরণ করো, তিনি তাঁর প্রভুকে আহ্বান করে বললেন -- ''আমার প্রভু! আমাকে একলা রেখো না, আর তুমি উত্তরাধিকারীদের মধ্যে সর্বশ্রেষ্ঠ।’’\qt@no{(89)}}
\qt@newcmd\qurantrans@bn@mmdlxxiii{সুতরাং আমরা তাঁর প্রতি সাড়া দিয়েছিলাম এবং তাঁকে দিয়েছিলাম ইয়াহ্‌য়া, আর তাঁর স্ত্রীকে তাঁর জন্য সুস্থ করেছিলাম। নিঃসন্দেহ তাঁরা সৎকাজে প্রতিযোগিতা করতেন, এবং আমাদের ডাকতেন আশা নিয়ে ও ভয়ের সাথে। আর আমাদের প্রতি তাঁরা ছিলেন বিনীত।\qt@no{(90)}}
\qt@newcmd\qurantrans@bn@mmdlxxiv{আর তাঁর ক্ষেত্রে, যিনি তাঁর সতীত্ব রক্ষা করেছিলেন, সেজন্য আমরা তার মধ্যে আমাদের কাছের আ‌ত্মা থেকে ফুঁকে দিয়েছিলাম, আর আমরা তাকে ও তার ছেলেকে একটি নিদর্শন বানিয়েছিলাম।\qt@no{(91)}}
\qt@newcmd\qurantrans@bn@mmdlxxv{''নিঃসন্দেহ তোমাদের এই সম্প্রদায় একই সম্প্রদায়, আর আমিই তোমাদের প্রভু, সুতরাং আমাকেই তোমরা উপাসনা করো।’’\qt@no{(92)}}
\qt@newcmd\qurantrans@bn@mmdlxxvi{কিন্তু তারা নিজেদের মধ্যে তাদের অনুশাসন কেটে ফেলল। সকলেই আমাদের কাছে ফিরে আসবে।\qt@no{(93)}}
\qt@newcmd\qurantrans@bn@mmdlxxvii{সুতরাং যে কেউ সৎকাজগুলো থেকে কাজ করে যায় আর সে মুমিন হয়, তবে তার কর্মপ্রচেষ্টার কোনো অস্বীকৃতি হবে না, আর নিঃসন্দেহ আমরা হচ্ছি তার জন্য লিপিকার।\qt@no{(94)}}
\qt@newcmd\qurantrans@bn@mmdlxxviii{আর এটি নিষিদ্ধ সেই জনপদের জন্য যাকে আমরা ধ্বংস করেছি, -- যে তারা আর ফিরে আসবে না।\qt@no{(95)}}
\qt@newcmd\qurantrans@bn@mmdlxxix{যদিবা ইয়াজুজ ও মাজুজকে ছেড়ে দেওয়া হয় আর তারা ছড়িয়ে আসে প্রতি ঊর্ধ্বদেশ থেকে।\qt@no{(96)}}
\qt@newcmd\qurantrans@bn@mmdlxxx{আর যথার্থ ওয়াদা ঘনিয়ে আসছে, তখন দেখবে, যারা অবিশ্বাস পোষণ করেছিল তাদের চক্ষু স্থির হয়ে যাবে। ''ধিক্ আমাদের, আমরা তো এ বিষয়ে উদাসীনতায় পড়ে রয়েছিলাম! বরং আমরা অন্যায়কারী ছিলাম।’’\qt@no{(97)}}
\qt@newcmd\qurantrans@bn@mmdlxxxi{নিঃসন্দেহ তোমরা, আর আল্লাহ্‌কে ছেড়ে দিয়ে তোমরা যে-সবের উপাসনা কর তারা তো জাহান্নামের ইন্ধন, তোমরা এতে আসতেই চলেছ।\qt@no{(98)}}
\qt@newcmd\qurantrans@bn@mmdlxxxii{এইগুলো যদি উপাস্য হতো তাহলে তারা এতে আসত না। বস্তুতঃ সকলেই এতে স্থায়ীভাবে থাকবে।\qt@no{(99)}}
\qt@newcmd\qurantrans@bn@mmdlxxxiii{তাদের জন্য তাতে রয়েছে আর্তনাদ, আর সেখানে তারা শুনতে পারবে না।\qt@no{(100)}}
\qt@newcmd\qurantrans@bn@mmdlxxxiv{নিঃসন্দেহ যাদের জন্য আমাদের তরফ থেকে কল্যাণ ইতিমধ্যে ধার্য হয়ে গেছে তদের এ থেকে বহু দূরে রাখা হ বে,\qt@no{(101)}}
\qt@newcmd\qurantrans@bn@mmdlxxxv{তারা এর হিস্‌হিস্ শন্দটুকুও শুনবে না, আর তাদের অন্তর যা কামনা করে সেইখানেই তারা স্থায়ীভাবে থাকবে।\qt@no{(102)}}
\qt@newcmd\qurantrans@bn@mmdlxxxvi{ভয়ংকর আতঙ্ক তাদের বিষাদগ্রস্ত করবে না, আর ফিরিশ্‌তারা তাদের সঙ্গে মুলাকাত করবে -- ''এই হচ্ছে তোমাদের দিন যে সন্বন্ধে তোমাদের ওয়াদা করা হয়েছিল।’’\qt@no{(103)}}
\qt@newcmd\qurantrans@bn@mmdlxxxvii{সেই দিনে আমরা আকাশকে গুটিয়ে নেব যেমন গুটানো হয় লিখিত নথিপত্র! যেভাবে আমরা প্রথম সৃষ্টির সূচনা করেছিলাম সেইভাবে আমরা এটি পুনর্সৃষ্টি করব। ওয়াদা রক্ষাকরণ আমাদের উপরে ন্যস্ত। নিঃসন্দেহ আমরা কর্মকর্তা।\qt@no{(104)}}
\qt@newcmd\qurantrans@bn@mmdlxxxviii{আর স্মারক-গ্রন্থের পরে আমরা যবূর-গ্রন্থে লিখে দিয়েছি যে, দেশটা -- এটাকে উত্তরাধিকার করবে আমার সৎকর্মী বান্দারা।\qt@no{(105)}}
\qt@newcmd\qurantrans@bn@mmdlxxxix{বস্তুতঃ এতে রয়েছে বাণী উপাসনাকারী লোকদের জন্য।\qt@no{(106)}}
\qt@newcmd\qurantrans@bn@mmdxc{আর আমরা তোমাকে পাঠাই নি বিশ্বজগতের জন্য এক করুণারূপে ভিন্ন।\qt@no{(107)}}
\qt@newcmd\qurantrans@bn@mmdxci{বলো -- ''আমার কাছে আলবৎ প্রত্যাদিষ্ট হয়েছে যে, নিঃসন্দেহ তোমাদের উপাস্য একক উপাস্য। তোমরা কি তবে আ‌ত্মসমর্পণকারী হবে না?’’\qt@no{(108)}}
\qt@newcmd\qurantrans@bn@mmdxcii{কিন্তু যদি তারা ফিরে যায় তবে তুমি বলো -- ''আমি তোমাদের সাবধান করে দিয়েছি যথাযথভাবে। আর আমি জানি না তোমাদের যা ওয়াদা করা হয়েছে তা আসন্ন না দূরবর্তী।\qt@no{(109)}}
\qt@newcmd\qurantrans@bn@mmdxciii{''নিঃসন্দেহ তিনি জানেন কথাবার্তার প্রকাশ্য দিক আর জানেন যা তোমরা গোপন কর।\qt@no{(110)}}
\qt@newcmd\qurantrans@bn@mmdxciv{''আর জানি না, হতে পারে এ তোমাদের জন্য একটি পরীক্ষা, এবং কিছুকালের জন্য জীবনোপভোগ।’’\qt@no{(111)}}
\qt@newcmd\qurantrans@bn@mmdxcv{তিনি বললেন -- ''আমার প্রভু! ন্যায়পরায়ণতার সাথে বিচার করে দাও।’’ আর আমাদের প্রভু পরম করুণাময় যাঁর সাহায্য প্রার্থনীয় তোমরা যা আরোপ কর তার বিরুদ্ধে।\qt@no{(112)}}
\qt@newcmd\qurantrans@bn@mmdxcvi{\basmalahbn ওহে মানবগোষ্ঠী! তোমাদের প্রভুকে ভয়শ্রদ্ধা করো। নিঃসন্দেহ ঘড়িঘন্টার ঝাঁকুনি এক ভয়ংকর ব্যাপার।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmdxcvii{সেইদিন যখন তোমরা তা দেখবে, -- প্রত্যেক স্তন্যদাত্রী ভুলে যাবে যাকে সে স্তন্য দিচ্ছিল, আর প্রত্যেক গর্ভবতী তার গর্ভপাত করবে, আর তুমি দেখতে পাবে মানুষকে নেশাগ্রস্ত, অথচ তারা মাতাল নয়, বস্তুতঃ আল্লাহ্‌র শাস্তি হচ্ছে বড় কঠোর।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmdxcviii{আর মানুষদের মধ্যে এমনও আছে যে কোনো জ্ঞান না রেখেই আল্লাহ্ সন্বন্ধে বিতর্ক করে, আর সে অনুসরণ করে প্রত্যেক বিদ্রোহী শয়তানকে, --\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmdxcix{যার বিরুদ্ধে লিখে রাখা হয়েছে যে যে-কেউ তাকে বন্ধুরূপে গ্রহণ করবে সে তবে অবশ্যই তাকে বিপথে চালিত করবে এবং তাকে চালিয়ে নেবে জ্বলন্ত আগুনের শাস্তির দিকে।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmdc{ওহে মানবগোষ্ঠী! তোমরা যদি পুনরুত্থান সন্বন্ধে সন্দেহের মধ্যে থাক, তাহলে আমরা তো তোমাদের সৃষ্টি করেছি মাটি থেকে, তারপর রক্তপিন্ড থেকে তারপর মাংসের তাল থেকে -- গঠনে সুসমঞ্জস ও সামঞ্জস্যবিহীন, যেন আমরা তোমাদের জন্য সুস্পষ্ট করতে পারি। আর যাকে আমরা ইচ্ছা করি তাকে মাতৃগর্ভে থাকতে দিই নির্দিষ্ট কাল পর্যন্ত, তারপর তোমাদের বের ক’রে আনি শিশুরূপে, তারপর যেন তোমরা তোমাদের পূর্ণজীবনে পৌঁছুতে পার। আর তোমাদের মধ্যে কেউ কেউ মৃত্যুমুখে পতিত হয় আর তোমাদের মধ্যে কাউকে আনা হয় জীবনের অধমতম দশায় যার ফলে জ্ঞানলাভের পরে সে কিছুই না-জানা হয়। আর তুমি পৃথিবীকে দেখতে পাচ্ছ অনুর্বর, তারপর যখন আমরা তাতে বৃষ্টি বর্ষণ করি, তখন তা স্পন্দিত হয় ও ফোলে ওঠে, আর উৎপন্ন করে হরেক রকমের সুন্দর শাকসবজি।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmdci{এটি এই জন্য যে আল্লাহ্ -- তিনিই চিরসত্য, আর তিনিই তো মৃতকে জীবিত করেন, আর তিনিই সব কিছুর উপরে সর্বশক্তিমান,\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmdcii{আর এই জন্য যে ঘড়িঘন্টা আসন্ন, -- এতে কোনো সন্দেহ নেই, আর যেহেতু আল্লাহ্ পুনরুত্থিত করবেন তাদের যারা কবরের ভেতরে রয়েছে।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmdciii{আর মানুষদের মধ্যে এমনও আছে যে আল্লাহ্ সন্বন্ধে বিতর্ক করে কোনো জ্ঞান না রেখে আর কোনো পথনির্দেশ ছাড়া আর কোনো দীপ্তিদায়ক গ্রন্থ ব্যতিরেকে, --\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmdciv{তার ঘাড় ফিরিয়ে, যাতে সে বিপথে চালাতে পারে আল্লাহ্‌র পথ থেকে। তার জন্য এই দুনিয়াতে রয়েছে লাঞ্ছনা, আর কিয়ামতের দিনে আমরা তাকে আস্বাদন করাব জ্বলা-পোড়ার শাস্তি।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmdcv{''এ তার জন্য যা তোমার হাত দুখানা আগবাড়িয়েছে, আর আল্লাহ্ তো তাঁর বান্দাদের প্রতি একটুও অন্যায়কারী নন।’’\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmdcvi{আর লোকদের মধ্যে এমনও আছে যে আল্লাহ্‌র উপাসনা করে কিনারায় রয়ে, ফলে যদি তার প্রতি ভাল কিছু ঘটে সে তাতে সন্তষ্ট হয়, কিন্তু তার প্রতি যদি বিপর্যয় ঘটে সে তার মুখ ফিরিয়ে ঘুরে যায় -- সে ইহকাল হারায় আর পরকালও। এটিই তো এক সুস্পষ্ট ক্ষতি।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmdcvii{সে আল্লাহ্‌কে ছেড়ে দিয়ে তাকে ডাকে যে তার ক্ষতিসাধন করতে পারে না আর যে তার উপকারও করে না। এই হচ্ছে সুদূর বিপথগমন।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmdcviii{সে তাকে ডাকে যার ক্ষতিসাধন তার উপকারের চাইতে বেশী নিকটবর্তী। কত নিকৃষ্ট অভিভাবক ও কত মন্দ এ সহচর?\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmdcix{যারা ঈমান এনেছে ও সৎকাজ করছে আল্লাহ্ তাদের অবশ্যই প্রবেশ করাবেন স্বর্গোদ্যানে যার নিচ দিয়ে বয়ে চলেছে ঝরনারাজি। নিঃসন্দেহ আল্লাহ্ যা ইচ্ছা করেন তাই করে থাকেন।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmdcx{যেজন ভাবে যে আল্লাহ্ তাঁকে ইহলোকে ও পরলোকে কখনই সাহায্য করবেন না, সে তবে আকাশের দিকে তোলার উপায় খুঁজুক, তারপর সে কেটে ফেলুক, তখন সে দেখুক তার পরিকল্পনা তা বিদূরিত করে কি না যাতে সে আক্রোশ বোধ করে।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmdcxi{আর এইভাবে আমরা এটি অবতারণ করেছি -- সুস্পষ্ট নিদর্শন, আর অবশ্য আল্লাহ্‌পরিচালনা করেন তাকে যে কামনা করে।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmdcxii{নিঃসন্দেহ যারা ঈমান এনেছে আর যারা ইহুদী মত পোষণ করে, আর সাবেঈন ও খ্রীষ্টান ও মাজুস, এবং যারা অংশী দাঁড় করায়, -- আল্লাহ্ নিঃসন্দেহ তাদের মধ্যে ফয়সালা করে দেবেন কিয়ামতের দিনে। নিঃসন্দেহ আল্লাহ্ সমস্ত কিছুরই সাক্ষ্যদাতা।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmdcxiii{তুমি কি দেখ না যে নিশ্চয় আল্লাহ্ -- তাঁরই প্রতি সিজদা করে যারাই আছে মহাকাশমন্ডলীতে ও যারা আছে পৃথিবীতে, আর সূর্য ও চন্দ্র ও তারকারাজি এবং পাহাড়-পর্বত ও গাছপালা, আর জীবজন্ত ও বহুসংখ্যক লোকজন? আর অনেক আছে যাদের উপরে শাস্তি ন্যায়সংগত হয়েছে। আর যাকে আল্লাহ্ লাঞ্ছিত করেন তার জন্য তবে সম্মানদানের কেউ নেই। নিঃসন্দেহ আল্লাহ্ যা ইচ্ছা করেন তাই করে থাকেন।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmdcxiv{এরা হচ্ছে দুই প্রতিপক্ষ যারা তাদের প্রভু সন্বন্ধে বিতর্ক করে। তারপর যারা অবিশ্বাস পোষণ করে তাদের জন্যে আগুনের থেকে পোশাক তৈরি করা হয়েছে। তাদের মাথার উপর থেকে ফুটন্ত পানি ঢালা হবে,\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmdcxv{এর দ্বারা গলে যাবে যা কিছু আছে তাদের পেটের ভেতরে আর চামড়াটাও।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmdcxvi{আর তাদের জন্য রয়েছে লোহার চাবুক।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmdcxvii{যতবার তারা চাইবে এ থেকে বেরিয়ে আসতে -- জ্বালাযন্ত্রণা থেকে -- তাদের ফিরিয়ে দেওয়া হবে তারই মধ্যে, আর ''জ্বলে পোড়ার যন্ত্রণা আস্বাদ করো।’’\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmdcxviii{যারা ঈমান এনেছে ও সৎকাজ করছে আল্লাহ্ অবশ্যই তাদের প্রবেশ করাবেন স্বর্গোদ্যান সমূহে যাদের নিচ দিয়ে বয়ে চলে ঝরনারাজি, সেখানে তাদের ভূষিত করা হবে সোনার কংকণ ও মণি-মুক্তো দিয়ে। আর সেখানে তাদের পোশাক-পরিচ্ছদ হবে রেশমের।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmdcxix{আর তাদের পরিচালিত করা হয়েছে পবিত্র বাক্যালাপের প্রতি, আর তাদের চালিয়ে নেওয়া হয়েছে প্রশংসিত পথে।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmdcxx{নিঃসন্দেহ যারা অবিশ্বাস পোষণ করে আর ঠেকিয়ে রাখে আল্লাহ্‌র পথ থেকে ও পবিত্র মসজিদ থেকে যাকে আমরা বানিয়েছি সকল মানুষের জন্য সমানভাবে, -- সেখানকার বাসিন্দার ও বহিরাগতের জন্য। আর যে কেউ সেখানে অন্যায়ভাবে ধূর্তামি করতে চায় তাকে আমরা আস্বাদ করার মর্মন্তদ শাস্তি থেকে।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmdcxxi{আর স্মরণ করো! আমরা ইব্রাহীমের জন্য গৃহের স্থান স্থির করে দিয়েছিলাম এই বলে -- ''আমার সঙ্গে কোনো-কিছুকে অংশী করো না, আর আমার গৃহকে পবিত্র করো তওয়াফকারীদের জন্য এবং দন্ডায়মানদের ও রুকু-সিজদা-কারীদের জন্য।’’\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmdcxxii{আর লোকদের মধ্যে হজের কথা ঘোষণা ক’রে দাও, তারা তোমার কাছে আসবে পায়ে হেঁটে আর প্রত্যেক শীর্ণ উটের উপরে, প্রত্যেক দূর-দুরান্ত দেশ থেকে, --\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmdcxxiii{যাতে তারা প্রত্যক্ষ করে তাদের জন্য উপকারসমূহ, আর যেন তারা আল্লাহ্‌র নাম স্মরণ করতে পারে নির্ধারিত দিনগুলোতে চতুস্পদ গবাদি-পশুদের উপরে যেগুলো দিয়ে তিনি তাদের জীবিকা দিয়েছেন, তারপর যেন তোমরা তা থেকে খেতে পরো এবং দুঃস্থ ও নিঃস্বকে খাওয়াতে পারো।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmdcxxiv{তারপর তারা সমাধা করুক তাদের পরিস্কার-পরিচ্ছন্নতা, আর তাদের মানতগুলো তারা পূর্ণ করুক, আর তারা তওয়াফ করুক এই প্রাচীন গৃহের।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmdcxxv{এইটিই। আর যে কেউ আল্লাহ্‌র অনুষ্ঠানগুলোর সম্মান করে তাহলে সেটি তার প্রভুর কাছে তার জন্যে উত্তম। আর গবাদি- পশু তোমাদের জন্য বৈধ করা হয়েছে সে-সব ব্যতীত যা তোমাদের কাছে বিবৃত করা হয়েছে, সুতরাং তোমরা দেবদেবীর কদর্যতা পরিহার করো এবং বর্জন করো মিথ্যা কথাবার্তা, --\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmdcxxvi{আল্লাহ্‌র প্রতি একনিষ্ঠ হয়ে, তাঁর সঙ্গে কোনো অংশী আরোপ না ক’রে। আর যে কেউ আল্লাহ্‌র সঙ্গে অংশী দাঁড় করায় সে যেন তাহলে আকাশ থেকে পড়ল, তখন পাখিরা তাকে ছোঁ মেরে নিয়ে যায়, অথবা বায়ুপ্রবাহ তাকে উড়িয়ে নিয়ে যায় এক দূরবর্তী স্থানে।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmdcxxvii{এইটিই। আর যে কেউ আল্লাহ্‌র নিদর্শনসমূহকে সম্মান করে সেটি তাহলে নিশ্চয়ই হৃদয়ের ধর্মনিষ্ঠা থেকে উদ্ভূত।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmdcxxviii{এদের মধ্যে তোমাদের জন্য উপকার রয়েছে এক নির্দিষ্ট কাল পর্যন্ত, তারপর তাদের কুরবানির স্থান হচ্ছে প্রাচীন গৃহের সন্নিকটে।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmdcxxix{আর প্রত্যেক জাতির জন্য আমরা কুরবানির বিধান দিয়েছি, যেন তারা আল্লাহ্‌র নাম স্মরণ করে চতুস্পদ গবাদি-পশুদের যেগুলো দিয়ে তিনি তাদের রিযেক দিয়েছেন সে-সবের উপরে। বস্তুতঃ তোমাদের উপাস্য একক উপাস্য, সুতরাং তাঁরই নিকট তোমরা আ‌ত্মসমর্পণ করো। আর সুসংবাদ দাও বিনয়নম্রদের,\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmdcxxx{তাদের যাদের হৃদয় কাঁপতে থাকে যখন আল্লাহ্‌কে স্মরণ করা হয়, আর তাদের উপরে বিপদ ঘটা সত্ত্বেও যারা অধ্যবসায়ী, আর নামায কায়েমকারীদের, আর ওদের আমরা যে রিযেক দিয়েছি তা থেকে যারা খরচ করে থাকে তাদের।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmdcxxxi{আর উট, -- আমরা তাদের তোমাদের জন্য আল্লাহ্‌র নিদর্শনাবলীর অন্যতম বানিয়েছি, তোমাদের জন্য তাদের মধ্যে কল্যাণ নিহিত আছে। সেজন্য সারিবদ্ধ থাকাকালে তাদের উপরে আল্লাহ্‌র নাম উল্লেখ করো, তারপর তারা যখন তাদের পার্শ্বে পড়ে যায় তখন তা থেকে তোমরা খাও, এবং খাওয়াও তুষ্ট-দুঃস্থকে ও ভিক্ষুককে। এইভাবেই আমরা এদের তোমাদের অধীন করে দিয়েছি যেন তোমরা কৃতজ্ঞতা প্রকাশ কর।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmdcxxxii{তাদের মাংস কখনো আল্লাহ্‌র কাছে পৌঁছায় না আর তাদের রক্তও নয়, বরং তোমাদের থেকে ধর্মনিষ্ঠাই তাঁর কাছে পৌঁছায়। এইভাবেই তিনি তাদের তোমাদের অধীন করে দিয়েছেন যেন তোমরা আল্লাহ্‌র শ্রেষ্ঠত্ব ঘোষণা করতে পারো এজন্য যে তিনি তোমাদের পথ দেখিয়ে দিয়েছেন। আর সুসংবাদ দাও সৎকর্মপরায়ণদের।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmdcxxxiii{নিঃসন্দেহ আল্লাহ্ দফা রফা করে দেবেন তাদের থেকে যারা ঈমান এনেছে। নিঃসন্দেহ আল্লাহ ভালবাসেন না প্রত্যেক বিশ্বাসঘাতককে, অকৃতজ্ঞকে।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmdcxxxiv{অনুমতি দেওয়া গেল তাদের জন্য যাদের বিরুদ্ধে যুদ্ধ করা হচ্ছে, কেননা তারা অত্যাচারিত হয়েছে, আর অবশ্যই আল্লাহ্ তাদের সাহায্য করতে সক্ষম, --\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmdcxxxv{যাদের বহিস্কার করা হয়েছে তাদের বাড়িঘর থেকে ন্যায়সঙ্গত কারণ ছাড়াই, শুধু এইজন্য যে তারা বলে -- ''আমাদের প্রভু আল্লাহ্‌’’। আর যদি মানবজাতিকে তাদের এক দলের দ্বারা অন্য দলকে প্রতিহত করার ব্যবস্থা আল্লাহ্‌র না থাকতো তা হলে নিশ্চয়ই বিধবস্ত হয়ে যেত গির্জাগুলো ও মঠগুলি ও উপাসনালয় ও মসজিদ সমূহ যেখানে আল্লাহ্‌র নাম প্রচুরভাবে স্মরণ করা হয়! আর আল্লাহ্ নিশ্চয়ই সাহায্য করেন তাঁকে যে তাঁকে সাহায্য করে। নিঃসন্দেহ আল্লাহ্ তো মহাবলীয়ান, মহাশক্তিশালী।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmdcxxxvi{এরাই, -- আমরা যদি এদের পৃথিবীতে প্রতিষ্ঠা করি তাহলে এরা নামায কায়েম করবে ও যাকাত আদায় করবে ও সৎকাজের নির্দেশ দেবে ও অসৎ কাজ থেকে নিষেধ করবে। আর সব কাজের পরিণাম আল্লাহ্‌রই এখতিয়ারে।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmdcxxxvii{আর যদি তারা তোমাকে প্রত্যাখ্যান করে তবে তাদের আগেও প্রত্যাখ্যান করেছিল নূহের সম্প্রদায় ও 'আদের ও ছামূদের,\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmdcxxxviii{আর ইব্রাহীমের সম্প্রদায় এবং লূতের সম্প্রদায়,\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmdcxxxix{আর মাদিয়ানের বাসিন্দারা, আর মূসাকেও প্রত্যাখ্যান করা হয়েছিল, তথাপি আমি অবিশ্বাসীদের অবকাশ দিয়েছিলাম, তখন আমি তাদের পাকড়াও করলাম, সুতরাং কেমন হয়েছিল আমার শাস্তিদান!\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmdcxl{কাজেকাজেই কত যে জনপদ ছিল, -- আমরা সেটা ধ্বংস করেছি যেহেতু তা অত্যাচারী ছিল, ফলে তা তার ছাদসহ ভেঙ্গে-চুরে রয়েছে, আর কূয়ো পরিত্যক্ত হয়েছে আর সুদৃঢ় প্রাসাদ!\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmdcxli{তারা কি তবে দুনিয়াতে ভ্রমণ করে নি যার ফলে তাদের লাভ হয়েছে অন্তঃকরণ যা দিয়ে তারা হৃদয়ঙ্গম করতে পারে অথবা কান যা দিয়ে তারা শুনতে পারে? বস্তুতঃ চোখ তো আদৌ অন্ধ নয়, কিন্তু অন্ধ হচেছ হৃদয় যা রয়েছে বুকের ভেতরে।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmdcxlii{আর তারা তোমাকে শাস্তি ত্বরান্বিত করতে বলে, অথচ আল্লাহ্ তাঁর ওয়াদার কখনো খেলাফ করবেন না। আর নিঃসন্দেহ তোমার প্রভুর কাছে এক দিন তোমরা যা গণনা কর তার এক হাজার বছরের সমান।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmdcxliii{আর কত যে জনবসতি ছিল -- তার জুলুমবাজি সত্ত্বেও আমি তাকে অবকাশ দিয়েছিলাম, তারপর আমি তাকে পাকড়াও করলাম, আর আমারই কাছে প্রত্যাবর্তন।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmdcxliv{বলো -- ''ওহে মানবজাতি! আমি তো তোমাদের জন্য একজন সুস্পষ্ট সতর্ককারী মাত্র।’’\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmdcxlv{সেজন্য যারা ঈমান আনবে ও সৎকাজ করবে তাদের জন্য রয়েছে পরিত্রাণ ও সম্মানজনক জীবিকা।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmdcxlvi{আর যারা আমাদের নির্দেশাবলী বিফল করার চেষ্টা করে তারাই হচ্ছে জ্বলন্ত আগুনের বাসিন্দা।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmdcxlvii{আর তোমার আগে আমরা কোনো রসূল পাঠাই নি আর কোনো নবীও নয় এ ভিন্ন যে যখনি তিনি আকাঙ্খা করেছেন তখন শয়তান তাঁর আকাঙ্খা সম্পর্কে কুমন্ত্রণা দিয়েছে। কিন্তু আল্লাহ্ বাতিল করে দেন শয়তান যেসব কুমন্ত্রণা দেয়, তখন আল্লাহ্ তাঁর নির্দেশাবলী প্রতিষ্ঠিত করেন। আর আল্লাহ্ সর্বজ্ঞাতা, পরমজ্ঞানী,\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmdcxlviii{যেন শয়তান যে কুমন্ত্রণা দেয় সেটিকে তিনি করতে পারেন একটি পরীক্ষার বিষয় তাদের জন্য যাদের অন্তরে ব্যাধি রয়েছে, আর যাদের হৃদয় হয়েছে কঠিন। আর অত্যাচারীরা তো নিশ্চয়ই সুদূর প্রসারী বিচ্ছিন্নতায় রয়েছে, --\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmdcxlix{আর যেন যাদের জ্ঞান দেওয়া হয়েছে তারা জানতে পারে যে এটি তোমার প্রভুর কাছ থেকে সত্য, কাজেই তারা যেন এতে বিশ্বাস স্থাপন করে আর তাদের হৃদয় যেন তাঁর প্রতি বির্নত হতে পারে। আর নিঃসন্দেহ আল্লাহ্ তো সহজ-সঠিক পথের দিকে পরিচালক তাদের জন্য যারা ঈমান এনেছে।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmdcl{আর যারা অবিশ্বাস পোষণ করে তারা এ সন্বন্ধে সন্দেহ করা থেকে বিরত হবে না যতক্ষণ না ঘড়িঘন্টা অতর্কিতে তাদের উপরে এসে পড়ে, অথবা তাদের উপরে এসে পড়ে এক ধ্বংসা‌ত্মক দিনে শাস্তি।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mmdcli{''আজকের দিনে সর্বাধিনায়কত্ব হচ্ছে আল্লাহ্‌র।’’ তিনি তাদের মধ্যে বিচার করবেন। সুতরাং যারা ঈমান এনেছে ও সৎকাজ করছে তারাই থাকবে আনন্দময় উদ্যানে।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mmdclii{আর যারা অবিশ্বাস পোষণ করে ও আমাদের নির্দেশাবলী প্রত্যাখ্যান করে, তারাই তবে -- তাদের জন্য রয়েছে লাঞ্ছনাদায়ক শাস্তি।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mmdcliii{আর যারা আল্লাহ্‌র পথে হিজরত করে, তারপর নিহত হয় অথবা মৃত্যু বরণ করে, আল্লাহ্ অবশ্যই তাদের উত্তম জীবনোপকরণ উপভোগ করতে দেবেন। আর নিঃসন্দেহ আল্লাহ্ -- তিনিই তো জীবিকাদাতাদের মধ্যে সর্বশ্রেষ্ঠ।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mmdcliv{তিনি নিশ্চয়ই তাদের প্রবেশ করাবেন এমন একটি প্রবেশস্থলে যাতে তারা খুশি হবে। আর নিঃসন্দেহ আল্লাহ্ তো সর্বজ্ঞাতা, অতি অমায়িক।\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mmdclv{এই রকমেই। আর যে প্রতিশোধ লয় যতটা উৎপীড়ন তাকে করা হয়েছিল তার সমপরিমাণে, তারপর তার প্রতি অত্যাচার করা হয়, তাহলে আল্লাহ্ নিশ্চয়ই তাকে সাহায্য করবেন। নিঃসন্দেহ আল্লাহ্ তো পরম ক্ষমাশীল, পরিত্রাণকারী।\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mmdclvi{এমন করেই, কেননা আল্লাহ্ রাত্রিকে প্রবেশ করান দিনের মধ্যে আর দিনকে ঢুকান রাতের মধ্যে, আর আল্লাহ্‌ই তো সর্বশ্রোতা, সর্বদ্রষ্টা।\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mmdclvii{এ ধরনেই, কেননা নিঃসন্দেহ আল্লাহ্ -- তিনিই সত্য, আর তাঁকে ছেড়ে দিয়ে তারা যাকে ডাকে তা তো মিথ্যা আর নিঃসন্দেহ আল্লাহ্ -- তিনিই সমুচ্চ, মহামহিম।\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mmdclviii{তুমি কি দেখ না যে আল্লাহ্ আকাশ থেকে পাঠান পানি, তখন পৃথিবী সবুজ রঙ ধারণ করে? নিঃসন্দেহ আল্লাহ্ সদাশয় পূর্ণ ওয়াকিবহাল।\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mmdclix{যা কিছু আছে মহাকাশমন্ডলীতে ও যা কিছু আছে পৃথিবীতে সে-সমস্ত তাঁরই। আর নিঃসন্দেহ আল্লাহ্‌, -- তিনিই তো স্বয়ংসমৃদ্ধ, পরম প্রশংসিত।\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mmdclx{তুমি কি লক্ষ্য কর না যে পৃথিবীতে যা কিছু আছে আল্লাহ্ তা তোমাদের অধীন করেছেন, আর জাহাজগুলোও যা তাঁর নির্দেশে সমুদ্রে বিচরণ করছে। আর তিনি আকাশকে ঠেকিয়ে রাখেন তাঁর অনুমতি ব্যতিরেকে পৃথিবীর উপরে পড়া থেকে। নিঃসন্দেহ আল্লাহ্ মানুষদের প্রতি তো পরম স্নেহময়, অফুরন্ত ফলদাতা।\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mmdclxi{আর তিনিই সেইজন যিনি তোমাদের জীবন দান করেছেন, তারপর তিনি তোমাদের মৃত্যু ঘটাবেন, তারপর তিনি তোমাদের জীবিত করবেন। নিঃসন্দেহ মানুষগুলো বড় অকৃতজ্ঞ।\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mmdclxii{প্রত্যেক সম্প্রদায়ের জন্য আমরা নির্ধারিত করে দিয়েছি নিয়ম-কানুন যা তারা পালন করে, সুতরাং তারা যেন তোমার সঙ্গে এই ব্যাপারে বিতর্ক না করে, আর তোমার প্রভুর দিকে আহ্বান করো। নিঃসন্দেহ তুমিই তো রয়েছ সহজ-সঠিক পথের উপরে।\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mmdclxiii{আর যদি তোমার সঙ্গে তারা তর্ক-বিতর্ক করে তবে বল -- ''আল্লাহ ভাল জানেন যা তোমরা করছো।’’\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mmdclxiv{আল্লাহ্ তোমাদের মধ্যে কিয়ামতের দিনে বিচার-মীমাংসা করে দেবেন যে-সব বিষয়ে তোমরা মতভেদ করছিলে।\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mmdclxv{তুমি কি জান না যে মহাকাশে ও পৃথিবীতে যা-কিছু আছে সে-সবই আল্লাহ্ জানেন? নিঃসন্দেহ এটি আল্লাহর জন্যে সহজ ব্যাপার।\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@mmdclxvi{তারা আল্লাহকে ছেড়ে দিয়ে যার উপাসনা করে তার জন্য তিনি কোনো দলিল পাঠান নি এবং তাদের কাছে সে-বিষয়ে কোনো জ্ঞানও নেই। আর অন্যায়াচারীদের জন্য কোনো সাহায্যকারী নেই।\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@mmdclxvii{আর যখন তদের কাছে আমাদের সুস্পষ্ট নির্দেশাবলী পাঠ করা হয় তখন যারা অবিশ্বাস পোষণ করে তাদের চেহারাতে তুমি অস্বীকৃতির পরিচয় পাবে। তারা চায় যারা আমাদের বাণীসমূহ তাদের কাছে পড়ে শুনায় তাদের উপরে লাফিয়ে পড়তে। তুমি বল -- ''আমি কি তবে তোমাদের সংবাদ দেব এ-সবের চেয়েও মন্দ কিছুর?’’ আগুন। আল্লাহ্ এটি ওয়াদা করেছেন তাদেব জন্য যারা অবিশ্বাস পোষণ করে। আর কত মন্দ এ গন্তব্যস্থল!\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@mmdclxviii{ওহে মানবজাতি! একটি উপমা ছোঁড়া হচ্ছে, কাজেই তা শোনো। নিঃসন্দেহ আল্লাহ্‌কে ছেড়ে দিয়ে তোমরা যাদের ডাকো তারা কখনও একটি মাছিও সৃষ্টি করতে পারে না যদিও সেজন্য তারা সবাই একত্রিত হয়। আর যদি মাছিটি তাদের কাছ থেকে কিছু নিয়ে যায়, তারা ওর কাছ থেকে সেটি ফিরিয়ে আনতে পারবে না। দুর্বল সেই অণ্বেষণকারী আর অন্বেষিত।\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@mmdclxix{তারা আল্লাহ্‌কে মান-সম্মান করে না তাঁর যোগ্য মর্যাদায়। নিঃসন্দেহ আল্লাহ্ তো মহাবলীয়ান, মহাশক্তিশালী।\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@mmdclxx{আল্লাহ্ ফিরিশতাদের মধ্যে থেকে বাণীবাহকদের মনোনীত করেন, এবং মানুষের মধ্যে থেকেও। নিঃসন্দেহ আল্লাহ্ সর্বশ্রোতা, সর্বদ্রষ্টা।\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@mmdclxxi{তিনি অবগত আছেন যা-কিছু আছে তাদের সামনে আর যা-কিছু আছে তাদের পেছনে, আর আল্লাহ্‌র কাছেই সব ব্যাপার ফিরিয়ে আনা হয়।\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@mmdclxxii{ওহে যারা ঈমান এনেছ! তোমরা রুকু করো ও সিজদা করো, আর তোমাদের প্রভুর এবাদত করো এবং ভালকাজ করো যাতে তোমরা সফলকাম হতে পারো।\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@mmdclxxiii{আর আল্লাহ্‌র পথে জিহাদ করো যেভাবে তাঁর পথে জিহাদ করা কর্তব্য। তিনি তোমাদের মনোনীত করেছেন, তবে তিনি তোমাদের উপরে ধর্মের ব্যাপারে কোনো কাঠিন্য আরোপ করেন নি। তোমাদের পিতৃপুরুষ ইব্রাহীমের ধর্মমত। তিনি তোমাদের নামকরণ করেছেন 'মুসলিম’, -- এর আগেই আর এতেও, যেন এই রসূল তোমাদের জন্য একজন সাক্ষী হতে পারেন এবং তোমরাও জনগণের জন্য সাক্ষী হতে পার। অতএব তোমরা নামায কায়েম করবে ও যাকাত আদায় করবে এবং আল্লাহ্‌কে শক্ত ক’রে ধরে থাকবে। তিনিই তোমাদের অভিভাবক, সুতরাং কত উত্তম এই অভিভাবক এবং কত উত্তম এই সাহায্যকারী!\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@mmdclxxiv{\basmalahbn মুমিনরা অবশ্য সাফল্যলাভ করেই চলছে, --\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmdclxxv{যারা স্বয়ং তাদের নামাযে বিনয়-নম্র হয়,\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmdclxxvi{আর যারা অসার ক্রিয়াকলাপ থেকে নিজেরাই সরে থাকে,\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmdclxxvii{আর যারা স্বয়ং যাকাতদানে করিতকর্মা,\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmdclxxviii{আর যারা নিজেরাই তাদের আঙ্গিক কর্তব্যাবলী সম্পর্কে যত্নবান, --\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmdclxxix{তবে নিজেদের দম্পতি অথবা তাদের ডানহাতে যাদের ধরে রেখেছে তাদের ছাড়া, কেননা সেক্ষেত্রে তারা নিন্দনীয় নহে,\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmdclxxx{কিন্ত যে এর বাইরে যাওয়া কামনা করে তাহলে তারা নিজেরাই হবে সীমালংঘনকারী।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmdclxxxi{আর যারা স্বয়ং তাদের আমানত সন্বন্ধে ও তাদের অংগীকার সন্বন্ধে সজাগ থাকে,\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmdclxxxii{আর যারা নিজেরা তাদের নামায সন্বন্ধে সদা-যত্নবান।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmdclxxxiii{তারা নিজেরাই হবে পরম সেভাগ্যের অধিকারী, --\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmdclxxxiv{যারা উত্তরাধিকার করবে বেহেশত, তাতে তারা থাকবে স্থায়ীভাবে।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmdclxxxv{আর আমরা নিশ্চয়ই মানুষকে সৃষ্টি করেছি কাদার নির্যাস থেকে,\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmdclxxxvi{তারপর আমরা তাকে বানাই শুক্রকীট এক নিরাপদ অবস্থান স্থলে,\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmdclxxxvii{তারপর আমরা শুক্রকীটটিকে বানাই একটি রক্তপিন্ড, তারপর রক্তপিন্ডকে আমরা বানাই একটি মাংসের তাল, তারপর মাংসের তালে আমরা সৃষ্টি করি হাড়গোড়, তারপর হাড়গোড়কে আমরা ঢেকে দিই মাংসপেশী দিয়ে, তারপরে আমরা তাকে পরিণত করি অন্য এক সৃষ্টিতে। সেইজন্য আল্লাহ্‌রই অপার মহিমা, কত শ্রেষ্ঠ এই স্রষ্টা!\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmdclxxxviii{তারপর নিঃসন্দেহ তোমরা এর পরে তো মৃত্যু বরণ করবে।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmdclxxxix{তারপর তোমাদের অবশ্যই কিয়ামতের দিনে পুনরুত্থিত করা হবে।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmdcxc{আর আমরা নিশ্চয়ই তোমাদের উপরে সৃষ্টি করেছি সাতটি পথ, আর সৃষ্টি সন্বন্ধে আমরা কখনও উদাসীন নই।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmdcxci{আর আমরা আকাশ থেকে বর্ষণ করি পানি একটি পরিমাপ মতো, তারপর আমরা তাকে মাটিতে সংরক্ষিত করি, আর নিঃসন্দেহ আমরা তা সরিয়ে নিতেও সক্ষম।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmdcxcii{তারপর তার দ্বারা আমরা তোমাদের জন্য সৃষ্টি করি খেজুরের ও আঙুরের বাগানসমূহ। তোমাদের জন্য তাতে রয়েছে প্রচুর ফলফসল, আর তা থেকে তোমরা খাওয়া-দাওয়া করো।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmdcxciii{আর গাছ যা জন্মে সিনাই পাহাড়ে, তা উৎপাদন করে তেল ও জেলি আহারকারীদের জন্য।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmdcxciv{আর নিঃসন্দেহ গবাদি-পশুতে তোমাদের জন্য রয়েছে শিক্ষণীয় বিষয়। আমরা তোমাদের পান করতে দিই তাদের পেটের মধ্যে যা আছে তা থেকে, আর তাদের মধ্যে তোমাদের জন্য আছে প্রচুর উপকারিতা, আর তাদের থেকে তোমরা খাও,\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmdcxcv{আর তাদের উপরে এবং জাহাজে তোমাদের বহন করা হয়।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmdcxcvi{আর আমরা অবশ্যই নূহকে তাঁর স্বজাতিক কাছে পাঠিয়েছিলাম, তখন তিনি বলেছিলেন, ''হে আমার স্বজাতি! তোমরা আল্লাহ্‌র উপাসনা করো, তিনি ছাড়া তোমাদের জন্য অন্য কোন উপাস্য নেই। তোমরা কি তবুও ভক্তি-শ্রদ্ধা করবে না?’’\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmdcxcvii{তখন তাঁর স্বজাতির মধ্যে যারা অবিশ্বাস পোষণ করেছিল তাদের প্রধানরা বললে -- ''সে তো তোমাদের মতো একজন মানুষ ছাড়া আর কিছু নয়, সে তোমাদের উপরে প্রাধান্য প্রতিষ্ঠা করতে চাইছে। বস্তুতঃ আল্লাহ্ যদি চাইতেন তবে তিনি নিশ্চয়ই ফিরিশ্‌তাদের পাঠাতে পারতেন। আমরা তো পূর্ববর্তীকালের আমাদের পিতৃপুরুষদের মধ্যে এমনটা শুনি নি।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmdcxcviii{''সে তো একজন মানুষ মাত্র যাকে ভূতে ধরেছে, কাজেই কিছুকাল তাকে সহ্য ক’রে চল।’’\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmdcxcix{তিনি বললেন -- ''আমার প্রভু! আমাকে সাহায্য করো তারা আমার প্রতি যা মিথ্যারোপ করছে সেজন্য।’’\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmdcc{কাজেকাজেই আমরা তাঁর কাছে প্রত্যাদেশ পাঠালাম এই বলে -- ''আমাদের চোখের সামনে এবং আমাদের প্রত্যাদেশ মোতাবেক জাহাজটি তৈরি কর, তারপর আমাদের নির্দেশ যখন আসবে ও পানি উথলে উঠবে তখন তাতে উঠিয়ে নাও হরেক রকমের জোড়ায়- জোড়ায়, দুটি ক’রে, আর তোমার পরিবার পরিজনকে, -- তাদের মধ্যের যার বিরুদ্ধে বক্তব্য ঘোষিত হয়েছে তাকে ব্যতীত আর যারা অন্যায়াচরণ করেছে তাদের সন্বন্ধে তুমি আমার কাছে বলাবলি করো না। তারা তো নিমজ্জিত হবেই।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmdcci{''আর যখন তুমি জাহাজে আরোহণ করবে, তুমি ও যারা তোমার সাথে রয়েছে তারা তখন বলো -- 'সকল প্রশংসা আল্লাহ্‌র যিনি আমাদের উদ্ধার করেছেন অত্যাচারী জাতির থেকে।’\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmdccii{''আর বলো -- 'আমার প্রভু! আমাকে পুণ্যময় অবতরণ করতে দাও, কেননা অবতরণকারকদের মধ্যে তুমিই সর্বশ্রেষ্ঠ’।’’\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmdcciii{নিঃসন্দেহ এতে তো নিদর্শন রয়েছে, আর আমরা তো শৃঙ্খলাবদ্ধ করছিলাম।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmdcciv{তারপর আমরা তাদের পরে পত্তন করেছিলাম অন্য এক বংশকে।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmdccv{তখন আমরা তাদের মধ্যে পাঠিয়েছিলাম তাদেরই মধ্যে থেকে একজন রসূল এই বলে -- ''আল্লাহ্‌র উপাসনা করো, তিনি ব্যতীত তোমাদের জন্য অন্য উপাস্য নেই। তোমরা কি তবে ভক্তি-শ্রদ্ধা করবে না?’’\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmdccvi{আর তাঁর স্বজাতির মধ্যের প্রধানরা যারা অবিশ্বাস পোষণ করেছিল ও পরকালের মুলাকাতকে অস্বীকার করেছিল এবং এই দুনিয়ার জীবনে আমরা যাদের ভোগ-সার দিয়েছিলাম তারা বললে -- ''এ তো তোমাদের মতো একজন মানুষ ছাড়া আর কিছুই নয়, তোমরা যা থেকে খাও সেও তা থেকেই খায় এবং তোমরা যা পান কর সেও তা থেকেই পান করে।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmdccvii{''আর তোমরা যদি তোমাদের ন্যায় একজন মানুষেরই আজ্ঞা-পালন কর তাহলে তো তোমরা সেই মুহূর্তেই ক্ষতিগ্রস্ত হবে।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmdccviii{''সে কি তোমাদের প্রতি‌শ্রুতি দেয় যে যখন তোমরা মারা যাবে এবং তোমরা ধুলোমাটি ও হাড়পাঁজরাতে পরিণত হবে তখন তোমরা বহির্গত হবে?\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmdccix{''বহুদূর! তোমাদের যা ওয়াদা করা হচ্ছে তা বহুদূর।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmdccx{''আমাদের এই দুনিয়ার জীবন ছাড়া কিছুই তো নেই, আমরা মরব আর আমরা বেঁচে আছি, আর আমরা তো পুনরুত্থিত হব না।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmdccxi{''সে একজন মানুষ বৈ তো নয় যে আল্লাহ্ সন্বন্ধে মিথ্যা উদ্ভাবন করেছে, আর আমরা তো তার প্রতি আস্থাবান হতে পারছি না।’’\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmdccxii{তিনি বললেন -- ''আমার প্রভু! আমাকে তুমি সাহায্য করো যেহেতু তারা আমার প্রতি মিথ্যারোপ করছে।’’\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmdccxiii{তিনি বললেন -- ''অল্পক্ষণের মধ্যেই তারা আলবৎ অনুতাপ করতে থাকবে।’’\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmdccxiv{কাজেই এক মহাগর্জন তাদের পাকড়াও করল সঙ্গতভাবেই, আর আমরা তাদের বানিয়ে দিলাম আবর্জনা, তাই দূর হ’ল অত্যাচারী জাতি!\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmdccxv{তারপর আমরা তাদের পরে পত্তন করলাম অন্যান্য বংশদের।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmdccxvi{কোনো সম্প্রদায়ই তার নির্ধারিত কাল ত্বরান্বিত করতে পারবে না, আর তা বিলন্বিত করতেও পারবে না।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmdccxvii{তারপর আমরা একের পর এক আমাদের রসূলগণকে পাঠিয়েছিলাম। যখনই কোনো সম্প্রদায়ের কাছে তার রসূল এসেছিলেন, তাঁকে তারা প্রত্যাখ্যান করেছিল, তাই আমরা তাদের একদলকে অন্য দলের পশ্চাদ্ধাবন করিয়েছিলাম, আর তাদের বানিয়েছিলাম কাহিনী। সুতরাং দূর হ’ তেমন জাতি যারা ঈমান আনে না!\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmdccxviii{তারপর আমরা পাঠালাম মূসা ও তাঁর ভাই হারূনকে আমাদের নিদর্শনাবলী ও সুস্পষ্ট বিধান দিয়ে, --\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmdccxix{ফিরআউন ও তার পরিষদবর্গের কাছে, কিন্ত তারা অহংকার দেখিয়েছিল এবং তারা ছিল এক উদ্ধত জাতি।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmdccxx{কাজেই তারা বললে -- ''আমরা কি বিশ্বাস করব আমাদের ন্যায় দুজন মানুষকে, অথচ তাদের স্বজাতি আমাদেরই সেবারত?’’\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmdccxxi{সেজন্য তারা এদের দুজনকে প্রত্যাখ্যান করল, তার ফলে তারা ধ্বংসপ্রাপ্তদের অন্তর্ভুক্ত হ’ল।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmdccxxii{আর আমরা অবশ্যই মূসাকে গ্রন্থ দিয়েছিলাম যেন তারা সৎপথ অবলন্বন করতে পারে।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmdccxxiii{আর আমরা মরিয়ম-পুত্র ও তাঁর মাতাকে করেছিলাম এক নিদর্শন, এবং তাঁদের উভয়কে আমরা আশ্রয় দিয়েছিলাম তৃণাচ্ছাদিত ও ঝরনা-রাজিতে ভরা এক পার্বত্য-উপত্যকায়।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmdccxxiv{হে প্রিয় রসূলগণ! পবিত্র বস্তু থেকে তোমরা খাওয়া-দাওয়া করো আর ভাল কাজ করো। তোমরা যা করছ সে সন্বন্ধে আমি নিশ্চয়ই সর্বজ্ঞাতা।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmdccxxv{আর -- ''নিঃসন্দেহ তোমাদের এই সম্প্রদায় একই সম্প্রদায়, আর আমিই তোমাদের প্রভু, অতএব আমাকেই তোম রা ভক্তিশ্রদ্ধা করো।’’\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmdccxxvi{কিন্ত তারা নিজেদের মধ্যে তাদের অনুশাসন টুকরো-টুকরো ক’রে কেটে ফেলল। প্রত্যেক দলই তাদের কাছে যেসব রয়েছে তাতেই সন্তষ্ট।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmdccxxvii{সেজন্য তাদের থাকতে দাও তাদের বিভ্রান্তিতে কিছুকালের জন্য।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmdccxxviii{তারা কি ভাবে যে যেহেতু আমরা তাদের মাল-আসবাব ও সন্তান-সন্ততি দিয়ে যাচ্ছি, --\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mmdccxxix{আমরা তাদের জন্য মঙ্গলময় বস্তু ত্বরান্বিত করছি? না, তারা বুঝতে পারছে না।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mmdccxxx{নিঃসন্দেহ যারা খোদ তাদের প্রভুর ভয়ে ভীত-সন্ত্রস্ত,\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mmdccxxxi{আর যারা স্বয়ং তাদের প্রভুর নির্দেশাবলীতে বিশ্বাস স্থাপন করে,\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mmdccxxxii{আর যারা তাদের প্রভুর সঙ্গে শরিক করে না,\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mmdccxxxiii{আর যারা প্রদান করে যা দেবার আছে, আর তাদের হৃদয় ভীত-কম্পিত যেহেতু তারা তাদের প্রভুর কাছে প্রত্যাবর্তনকারী, --\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mmdccxxxiv{এরাই মঙ্গল সাধনে প্রতিযোগিতা করে, আর এরাই তো এতে অগ্রগামী হয়।\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mmdccxxxv{আর আমরা কোনো সত্ত্বাকে তার ক্ষমতার অতিরিক্ত কষ্ট দিই না, আর আমাদের কাছে আছে একটি গ্রন্থ যা হক কথা বলে দেয়, আর তাদের অন্যায় করা হয় না।\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mmdccxxxvi{কিন্ত তাদের হৃদয় এ ব্যাপারে তালগোল পাকানো অবস্থায় রয়েছে, আর এ ছাড়াও তাদের জন্য রয়েছে অন্যান্য কীর্তিকলাপ যে- সবে তারা করিতকর্মা।\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mmdccxxxvii{যে পর্যন্ত না আমরা তাদের মধ্যের সমৃদ্ধিশালী লোকদের শাস্তি দিয়ে পাকড়াও করি তখনই তারা আর্তনাদ ক’রে ওঠে।\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mmdccxxxviii{''আজ আর্তনাদ করো না, নিঃসন্দেহ তোমাদের ক্ষেত্রে -- আমাদের থেকে তোমাদের সাহায্য করা হবে না।\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mmdccxxxix{তোমাদের কাছে আমার বাণীসমূহ অবশ্যই পাঠ করা হত, কিন্ত তোমরা তোমাদের গোড়ালির উপরে মোড় ফিরে চলে যেতে --\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mmdccxl{''অহংকারের সাথে, এ ব্যাপারে সারারাত আবোল-তাবোল গল্পগুজব করতে করতে।’’\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mmdccxli{তবে কি তারা চিন্তা করে না এ বাণী সন্বন্ধে? অথবা তাদের কাছে কি এমন কিছু এসেছে যা তাদের পূর্ববর্তী বাপদাদাদের কাছে আসে নি?\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mmdccxlii{অথবা তারা কি তাদের রসূলকে চিনতে পারছে না যেজন্য তারা তাঁর প্রতি বিমুখ রয়েছে?\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mmdccxliii{অথবা তারা কি বলে যে তাঁকে জিন-ভূতে ধরেছে? বস্তুতঃ তিনি তাদের কাছে সত্য নিয়ে এসেছেন, কিন্ত তাদের অধিকাংশই সত্য-সন্বন্ধে উদাসীন।\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@mmdccxliv{আর যদি সত্য তাদের কামনার অনুসরণ করত তবে মহাকাশ-মন্ডলী ও পৃথিবী এবং তাদের মধ্যে যা আছে সবই বিশৃঙ্খল হয়ে পড়ত। পক্ষান্তরে আমরা তাদের কাছে তাদের স্মরণীয় বার্তা নিয়ে এসেছি, কিন্ত তারা তাদের স্মারক-গ্রন্থ থেকে বিমুখ থাকে।\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@mmdccxlv{অথবা তুমি কি তাদের কাছ থেকে কোনো প্রতিদান চাইছ। বস্তুতঃ তোমার প্রভুর প্রতিদানই সর্বোত্তম, আর রিযেক-দাতাদের মধ্যে তিনিই সর্বশ্রেষ্ঠ।\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@mmdccxlvi{আর নিঃসন্দেহ তুমি তো তাদের আহ্বান করছ সহজ-সঠিক পথের দিকে।\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@mmdccxlvii{আর যারা পরকালে বিশ্বাস করে না তারা নিঃসন্দেহ পথ থেকে তো বিপথগামী।\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@mmdccxlviii{আর আমরা যদি তাদের প্রতি দয়া করি ও দুঃখ-দৈন্যের যা কিছু তাদের রয়েছে তা দূর করে দিই তথাপি তারা তাদের বিভ্রান্তিতে লেগে থাকবে অন্ধ-চক্কর দিতে দিতে।\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@mmdccxlix{আর আমরা ইতিপূর্বেই তাদের শাস্তিদ্বারা পাকড়াও করেছি, তথাপি তারা তাদের প্রভুর কাছে বিনত হ’ল না, আর তারা কাকুতি- মিনতিও করল না।\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@mmdccl{শেষ পর্যন্ত যখন আমরা তাদের উপরে খুলে দিই কঠিন কঠিন শাস্তি থাকা দরজা তখন তারা হতাশ হয়ে পড়ে।\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@mmdccli{আর তিনিই সেইজন যিনি তোমাদের জন্য কান ও চোখ ও অন্তঃকরণ বানিয়ে দিয়েছেন। কিন্ত তোমরা তো অল্পই কৃতজ্ঞতা প্রকাশ কর।\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@mmdcclii{আর তিনিই সেইজন যিনি পৃথিবীতে তোমাদের বহুগুণিত করেছেন, আর তাঁরই কাছে তোমাদের একত্রিত করা হবে।\qt@no{(79)}}
\qt@newcmd\qurantrans@bn@mmdccliii{আর তিনিই সেইজন যিনি জীবনদান করেন ও মৃত্যু ঘটান, আর রাত ও দিনের বিবর্তন তাঁরই অধীনে রয়েছে। তবুও কি তোমরা বুঝবে না?\qt@no{(80)}}
\qt@newcmd\qurantrans@bn@mmdccliv{এতদসত্ত্বে পূর্ববর্তীরা যেমন বলত তেমনি এরাও বলাবলি করে।\qt@no{(81)}}
\qt@newcmd\qurantrans@bn@mmdcclv{তারা বললে -- ''কি! আমরা যখন মরে যাই এবং ধুলো-মাটি ও হাড়-পাঁজরাতে পরিণত হই, তখন কি আমরা ঠিকঠিকই পুনরুত্থিত হব?\qt@no{(82)}}
\qt@newcmd\qurantrans@bn@mmdcclvi{''অবশ্যই এর আগে এটি আমাদের ওয়াদা করা হয়েছিল -- আমাদের কাছে ও আমাদের বাপদাদাদের কাছে। নিঃসন্দেহ এটি সেকালের উপকথা বৈ তো নয়।’’\qt@no{(83)}}
\qt@newcmd\qurantrans@bn@mmdcclvii{তুমি বলো -- ''এই পৃথিবী ও এতে যারা আছে তারা কার, -- যদি তোমরা জানো?’’\qt@no{(84)}}
\qt@newcmd\qurantrans@bn@mmdcclviii{তারা তখন বলবে -- ''আল্লাহ্‌র!’’ তুমি বল -- ''কেন তবে তোমরা মনোনিবেশ করো না?’’\qt@no{(85)}}
\qt@newcmd\qurantrans@bn@mmdcclix{বল -- ''কে সাত আসমানের প্রভু ও কে আরশের অধিপতি?’’\qt@no{(86)}}
\qt@newcmd\qurantrans@bn@mmdcclx{তারা সঙ্গে সঙ্গে বলবে -- ''আল্লাহ্‌র।’’ তুমি বল -- ''তবে কেন তোমরা ভক্তিশ্রদ্ধা কর না?’’\qt@no{(87)}}
\qt@newcmd\qurantrans@bn@mmdcclxi{বল -- ''কে তিনি যাঁর হাতে সব-কিছুর কর্তৃত্ব রয়েছে, আর কে নিরাপত্তা প্রদান করেন অথচ তাঁকে নিরাপত্তা প্রদান করতে হয় না, যদি তোমরা জানো?’’\qt@no{(88)}}
\qt@newcmd\qurantrans@bn@mmdcclxii{তারা সঙ্গে সঙ্গে বলবে -- ''আল্লাহ্‌র।’’ তুমি বল -- ''তবে কেমন ক’রে তোমাদের সম্মোহন করা হচ্ছে?’’\qt@no{(89)}}
\qt@newcmd\qurantrans@bn@mmdcclxiii{বস্তুতঃ আমরা তাদের কাছে সত্য নিয়ে এসেছি, কিন্ত তারা তো নিশ্চয়ই মিথ্যাবাদী।\qt@no{(90)}}
\qt@newcmd\qurantrans@bn@mmdcclxiv{আল্লাহ্ কোনো সন্তান গ্রহণ করেন নি, আর তাঁর সঙ্গে অন্য কোনো উপাস্যও নেই, যদি থাকত তবে প্রত্যেক উপাস্য আলবৎ নিয়ে যেত যা-কিছু সে সৃষ্টি করেছে, আর তাদের কেউ-কেউ অন্যদের উপরে প্রাধান্য বিস্তার করত। সকল মহিমা আল্লাহ্‌র, তারা যা আরোপ করে তা থেকে তিনি উর্ধ্বে, --\qt@no{(91)}}
\qt@newcmd\qurantrans@bn@mmdcclxv{তিনি অদৃশ্য ও দৃশ্য সন্বন্ধে পরিজ্ঞাত, কাজেই তারা যা শরিক করে তিনি সে-সবের বহু উর্ধ্বে?\qt@no{(92)}}
\qt@newcmd\qurantrans@bn@mmdcclxvi{বলো -- ''আমার প্রভু! যদি তুমি আমাকে দেখতে দাও যা তাদের ওয়াদা করা হয়েছে, --\qt@no{(93)}}
\qt@newcmd\qurantrans@bn@mmdcclxvii{''আমার প্রভু! তাহলে আমাকে তুমি অত্যাচারী জাতির সঙ্গে স্থাপন করো না।’’\qt@no{(94)}}
\qt@newcmd\qurantrans@bn@mmdcclxviii{আর নিঃসন্দেহ তাদের আমরা যা ওয়াদা করেছি তা তোমাকে দেখাতে আমরা অবশ্যই সক্ষম।\qt@no{(95)}}
\qt@newcmd\qurantrans@bn@mmdcclxix{যা শ্রেষ্ঠ তাই দিয়ে মন্দ বিষয় প্রতিরোধ করো। আমরা ভাল জানি যা তারা আরোপ করে।\qt@no{(96)}}
\qt@newcmd\qurantrans@bn@mmdcclxx{আর বল -- ''আমার প্রভু! আমি তোমার কাছে আশ্রয় চাইছি শয়তানদের কুমন্ত্রণা থেকে,\qt@no{(97)}}
\qt@newcmd\qurantrans@bn@mmdcclxxi{''আর আমার প্রভু! তোমারই কাছে আমি আশ্রয় নিচ্ছি পাছে তারা আমার কাছে হাজির হয়।’’\qt@no{(98)}}
\qt@newcmd\qurantrans@bn@mmdcclxxii{যে পর্যন্ত না তাদের কারোর কাছে মৃত্যু উপস্থিত হয় তখন সে বলে -- ''আমার প্রভু! আমাকে ফেরত পাঠাও --\qt@no{(99)}}
\qt@newcmd\qurantrans@bn@mmdcclxxiii{''যেন আমি সৎকর্ম করতে পারি সেইখানে যা আমি ছেড়ে এসেছি।’’ কখনোই না! এ তো শুধু একটি মুখের কথা যা সে বলছে। আর তার সামনে রয়েছে 'বরযখ’ সেইদিন পর্যন্ত যখন তাদের পুনরুত্থান করা হবে।\qt@no{(100)}}
\qt@newcmd\qurantrans@bn@mmdcclxxiv{তারপর যখন শিঙায় ফুকে দেঁওয়া হবে, তখন তাদের মধ্যে সেইদিন কোনো আ‌ত্মীয়তার বন্ধন থাকবে না, আর তারা খোঁজ- খবরও নেবে না।\qt@no{(101)}}
\qt@newcmd\qurantrans@bn@mmdcclxxv{কাজেই যাদের পাল্লা ভারী হবে তারা নিজেরাই তবে হচ্ছে সফলকাম।\qt@no{(102)}}
\qt@newcmd\qurantrans@bn@mmdcclxxvi{আর যাদের পাল্লা হাল্কা হবে এরাই তবে তারা যারা নিজেদের ক্ষতিসাধন করেছে, তারা জাহান্নামে থাকবে দীর্ঘকাল।\qt@no{(103)}}
\qt@newcmd\qurantrans@bn@mmdcclxxvii{আগুন তাদের মুখ পুড়িয়ে দেবে। আর তারা সেখানে হবে বিকৃত-বীভৎস।\qt@no{(104)}}
\qt@newcmd\qurantrans@bn@mmdcclxxviii{''তোমরা কি এমন যে আমার বাণীসমূহ তোমাদের কাছে পাঠ করা হয় নি, যে-জন্যে তোমরা সে-সব প্রত্যাখ্যান করতে?’’\qt@no{(105)}}
\qt@newcmd\qurantrans@bn@mmdcclxxix{তারা বলবে -- ''আমাদের প্রভু! আমাদের দুর্দশা আমাদের উপরে প্রভাব বিস্তার করেছিল, এবং আমরা পথভ্রষ্ট জাতি হয়ে গিয়েছিলাম।\qt@no{(106)}}
\qt@newcmd\qurantrans@bn@mmdcclxxx{''আমাদের প্রভু! এখান থেকে আমাদের বের করে দাও, তখন যদি আমরা ফিরি তাহলে আমরা নিশ্চয়ই অন্যায়কারী হব।’’\qt@no{(107)}}
\qt@newcmd\qurantrans@bn@mmdcclxxxi{তিনি বললেন -- ''এর মধ্যেই তোমরা ঢোকে থাক। আর আমার সঙ্গে কথা বল না।\qt@no{(108)}}
\qt@newcmd\qurantrans@bn@mmdcclxxxii{''নিঃসন্দেহ আমার বান্দাদের মধ্যের একটি দল ছিল যারা বলত, 'আমার প্রভু! আমরা ঈমান এনেছি, কাজেই আমাদের পরিত্রাণ করো, যেহেতু তুমিই তো করুণাময়দের মধ্যে সর্বশ্রেষ্ঠ!’\qt@no{(109)}}
\qt@newcmd\qurantrans@bn@mmdcclxxxiii{''কিন্ত তোমরা তাদের হাসি-ঠাট্টার পাত্ররূপে গ্রহণ করেছিলে যে পর্যন্ত না এ-সব তোমাদের ভুলিয়ে দিয়েছিল আমাকে স্মরণ করা, আর তোমরা তাদের নিয়ে উপহাস করে চলেছ।\qt@no{(110)}}
\qt@newcmd\qurantrans@bn@mmdcclxxxiv{''নিঃসন্দেহ তারা যা অধ্যবসায় করত সেজন্য আজকের দিনে আমি তাদের পুরস্কার দান করছি, আর তারা তো নিজেরাই হচ্ছে সফলকাম।’’\qt@no{(111)}}
\qt@newcmd\qurantrans@bn@mmdcclxxxv{তিনি বলবেন -- ''তোমরা পৃথিবীতে বছর গুনতিতে কতকাল অবস্থান করেছিলে?’’\qt@no{(112)}}
\qt@newcmd\qurantrans@bn@mmdcclxxxvi{তারা বলবে -- ''আমরা অবস্থান করেছিলাম একটি দিন বা দিনের কিছু অংশ, আপনি না হয় জিজ্ঞাসা করুন গণনাকারীদের।’’\qt@no{(113)}}
\qt@newcmd\qurantrans@bn@mmdcclxxxvii{তিনি বলবেন -- ''তোমরা মাত্র অল্পকালই অবস্থান করেছিলে -- যদি তোমরা জানতে পারতে!’’\qt@no{(114)}}
\qt@newcmd\qurantrans@bn@mmdcclxxxviii{''তোমরা কি তবে মনে করেছিলে যে আমরা তোমাদের অনর্থক সৃষ্টি করেছি, এবং আমাদের কাছে তোমাদের ফিরিয়ে আনা হবে না?’’\qt@no{(115)}}
\qt@newcmd\qurantrans@bn@mmdcclxxxix{বস্তুতঃ আল্লাহ্ মহিমান্নিত, মহারাজাধিরাজ, চিরন্তন সত্য, তিনি ব্যতীত অন্য উপাস্য নেই, সম্মানিত আরশের অধিপতি তিনি।\qt@no{(116)}}
\qt@newcmd\qurantrans@bn@mmdccxc{আর যে কেউ আল্লাহ্‌র সঙ্গে অন্য উপাস্যকে ডাকে, -- যার জন্য তার কাছে কোনো সনদ নেই, -- তার হিসাবপত্র তবে নিশ্চয়ই তার প্রভুর কাছে রয়েছে। নিঃসন্দেহ অবিশ্বাসীদের সফলকাম করা হয় না।\qt@no{(117)}}
\qt@newcmd\qurantrans@bn@mmdccxci{বলো -- ''আমার প্রভু! পরিত্রাণ করো, আর দয়া করো, কেননা তুমিই তো করুণাময়দের মধ্যে সর্বশ্রেষ্ঠ।’’\qt@no{(118)}}
\qt@newcmd\qurantrans@bn@mmdccxcii{\basmalahbn একটি সূরাহ্ -- আমরা এটি অবতারণ করেছি এবং এটিকে অবশ্য-পালনীয় করেছি, আর এতে আমরা অবতারণ করেছি সুস্পষ্ট আয়াতসমূহ যেন তোমরা মনোনিবেশ করতে পার।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmdccxciii{ব্যভিচারিণী ও ব্যভিচারী -- তাদের দুজনের প্রত্যেককে একশ’ বেত্রাঘাতে চাবুক মার, আর আল্লাহ্‌র বিধান পালনে তাদের প্রতি অনুকম্পা যেন তোমাদের পাকড়াও না করে, যদি তোমরা আল্লাহ্‌তে ও আখেরাতের দিনে বিশ্বাস কর, আর মুমিনদের একটি দল যেন তাদের শাস্তি দেখতে পায়।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmdccxciv{ব্যভিচারী সহবাস করতে পারে না ব্যভিচারিণী অথবা বহুখোদাবাদিনী ব্যতীত, আর ব্যভিচারিণী -- তার সঙ্গে সহবাস করতে পারে না ব্যভিচারী অথবা বহুখোদাবাদী ব্যতীত। আর এটি মুমিনদের জন্য নিষিদ্ধ।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmdccxcv{আর যারা সতী- সাধ্বী নারীকে অপবাদ দেয় এবং চারজন সাক্ষী পেশ করে না, তাদের আশি বেত্রাঘাতে চাবুক মার, আর তাদের থেকে কখনও সাক্ষ্য গ্রহণ করবে না, কেননা তারা নিজেরাই তো সীমালংঘনকারী, --\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmdccxcvi{তাদের ক্ষেত্রে ব্যতীত যারা এর পরে তওবা করে ও শোধরে নেয়, কেননা আল্লাহ্ নিঃসন্দেহ পরিত্রাণকারী, অফুর ন্ত ফলদাতা।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmdccxcvii{আর যারা তাদের স্ত্রীদের প্রতি অপবাদ দেয় এবং তাদের জন্য তাদের নিজেদের ছাড়া অন্য সাক্ষী থাকে না, তাহলে তাদের একজনই আল্লাহ্‌র নামে চারবার সাক্ষ্যদানে সাক্ষীসাবুত খাড়া করবে যে সে নিশ্চয়ই সত্যবাদীদের মধ্যেকার, --\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmdccxcviii{আর পঞ্চমবারে যে আল্লাহ্‌র অভিশাপ তার উপরে পড়ুক যদি সে মিথ্যাবাদীদের একজন হয়।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmdccxcix{আর তার থেকে শাস্তি রোধ করা যাবে যদি সে আল্লাহ্‌র নামে চারবার সাক্ষ্যদানে সাক্ষী দেয় যে সে নিশ্চয়ই মিথ্যাবাদীদের মধ্যেকার, --\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmdccc{আর পঞ্চমবারে যে আল্লাহ্‌র ক্রোধ তার উপরে পড়ুক যদি সে সত্যবাদীদের একজন হয়।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmdccci{আর আল্লাহ্‌র অনুগ্রহ ও তাঁর করুণা যদি তোমাদের উপরে না থাকত, আর আল্লাহ্ যে তওবা কবুলকারী, পরমজ্ঞানী ।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmdcccii{যারা কুৎসা রটনা করেছিল তারা তো তোমাদেরই মধ্যেকার একটি দল। এটিকে তোমাদের জন্য অনিষ্টকর মনে করো না, বরং এটি তোমাদের জন্য কল্যাণকর। তাদের প্রত্যেক লোকের জন্য রয়েছে পাপের যা সে অর্জন করেছে, আর তদের মধ্যের যে এ ব্যাপারে প্রধান ভূমিকা নিয়েছিল তার জন্য রইছে কঠোর শাস্তি।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmdccciii{যখন তোমরা এটি শুনেছিল তখন কেন মুমিন পুরুষরা ও মুমিন নারীরা তাদের নিজেদের বিষয়ে সৎধারণা মনে আনে নি, আর বলে নি -- ''এ এক ডাহা মিথ্যা’’?\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmdccciv{কেন তারা এর জন্য চারজন সাক্ষী আনে নি? কাজেই তারা যেহেতু সাক্ষী আনতে পারে নি তাই তারাই তো আল্লাহ্‌র কাছে স্বয়ং মিথ্যাবাদী।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmdcccv{আর আল্লাহ্‌র অনুগ্রহ ও তাঁর করুণা যদি তোমাদের উপরে না থাকত এই দুনিয়াতে এবং পরকালে, তাহলে এই ব্যাপারে তোমরা যা রটাচ্ছিলে সেজন্য তোমাদের নিশ্চয়ই স্পর্শ করত এক কঠোর শাস্তি।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmdcccvi{বাঃ! তোমরা তোমাদের জিব দিয়ে এটি গ্রহণ করেছিলে, আর যে ব্যাপারে তোমাদের কোনো জ্ঞান নেই সেই নিয়ে তোমাদের মুখে মুখে তোমরা বলাবলি করছিলে, আর তোমরা একে ভেবেছিলে এক তুচ্ছ ব্যাপার, অথচ আল্লাহ্‌র কাছে এ ছিল গুরুতর বিষয়।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmdcccvii{আর যখন তোমরা এটি শুনেছিলে তখন কেন তেমরা বল নি -- ''এ আমাদের জন্য উচিত নয় যে আমরা এ বিষয়ে বলাবলি করি, তোমারই সব মহিমা, এ তো এক গুরুতর অপবাদ’’?\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmdcccviii{আল্লাহ্ তোমাদের উপদেশ দিচ্ছেন যে তোমরা এর মতো আচরণে কখনও ফিরে যাবে না, যদি তোমরা মুমিন হও।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmdcccix{আর আল্লাহ্ তোমাদের জন্য নির্দেশসমূহ সুস্পষ্ট করে দিয়েছেন। আর আল্লাহ্ সর্বজ্ঞাতা, পরমজ্ঞানী।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmdcccx{নিঃসন্দেহ যারা ভালবাসে যে যারা ঈমান এনেছে তাদের মধ্যে অশ্লীলতা প্রসার করুক তাদের জন্য রয়েছে মর্মন্তুদ শাস্তি এই দুনিয়াতে ও আখেরাতে। আর আল্লাহ্ জানেন, আর তোমরা জান না।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmdcccxi{আর যদি আল্লাহ্‌র অনুগ্রহ ও তাঁর করুণা তোমাদের উপরে না থাকত, আর আল্লাহ্ তো পরম স্নেহময়, অফুরন্ত ফলদাতা।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmdcccxii{ওহে যারা ঈমান এনেছ! তোমরা শয়তানের পদাঙ্ক অনুসরণ করো না। আর যে কেউ শয়তানের পদাঙ্ক অনুসরণ করে, সে তো তবে অশ্লীলতা ও মন্দ কাজের নির্দেশ দেয়। আর যদি আল্লাহ্‌র অনুগ্রহ ও তাঁর করুণা তোমাদের উপরে না থাকত তবে তোমাদের মধ্যের একজনও কদাপি পবিত্র হতে পারত না। কিন্ত আল্লাহ্ যাকে ইচ্ছা করেন তাকে পবিত্র করেন। আর আল্লাহ্ সর্বশ্রোতা।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmdcccxiii{আর তোমাদের মধ্যে যারা করুণাভান্ডারের ও প্রাচুর্যের অধিকারী তারা নিকট-আ‌ত্মীয়দের ও মিসকিনদের ও আল্লাহ্‌র পথে হিজরতকারীদের দান করার বিরুদ্ধে শপথ গ্রহণ না করুক, আর তারা ক্ষমা করুক ও উপেক্ষা করুক। তোমরা কি ভালবাস না যে আল্লাহ্ তোমাদের পরিত্রাণ করবেন? আল্লাহ্ বস্তুতঃ পরিত্রাণকারী, অফুরন্ত ফলদাতা।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmdcccxiv{নিঃসন্দেহ যারা সতী-সাধ্বী, নিরীহ, বিশ্বাসিনী নারীকে অপবাদ দেয় তাদের ইহলোকে ও পরলোকে অভিশাপ দেওয়া হবে, আর তাদের জন্য রইবে কঠোর শাস্তি, --\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmdcccxv{সেই দিনে যেদিন তাদের জিহ্বা ও তাদের হাত ও তাদের পা তাদের বিরুদ্ধে সাক্ষ্য দেবে যা তারা করে চলেছিল সে-সন্বন্ধে, --\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmdcccxvi{সেইদিন আল্লাহ্ তাদের প্রকৃত প্রাপ্য সম্পূর্ণ মিটিয়ে দেবেন, আর তারা জানতে পারবে যে আল্লাহ্ -- তিনিই প্রকাশ্য সত্য।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmdcccxvii{দুশ্চরিত্রা নারী দুশ্চরিত্র পুরুষের জন্য, আর দুশ্চরিত্র পুরুষ দুশ্চরিত্রা নারীর জন্য, আর সচ্চরিত্রা নারী সচ্চরিত্র পুরুষের জন্য, আর সচ্চরিত্র পুরুষ সচ্চরিত্রা নারীর জন্যে, -- তারা যা বলে এরা তা থেকে মুক্ত। তাদের জন্য রয়েছে পরিত্রাণ ও সম্মানজনক জীবিকা।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmdcccxviii{ওহে যারা ঈমান এনেছ! নিজেদের গৃহ ছাড়া তোমরা গৃহে প্রবেশ কর না যতক্ষণ না তোমরা অনুমতি নিয়েছ ও তাদের বাসিন্দাদের সালাম করেছ। এইটিই তোমাদের জন্য শ্রেয়, যেন তোমরা মনোযোগ দিতে পার।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmdcccxix{কিন্ত যদি তোমরা তাতে কাউকে না পাও তবে তাতে প্রবেশ কর না যতক্ষণ না তোমাদের অনুমতি দেওয়া হয়, আর যদি তোমাদের বলা হয় -- 'ফিরে যাও’, তবে ফিরে যেয়ো, -- এটিই তোমাদের জন্য উত্তম। আর তোমরা যা কর সে-বিষয়ে আল্লাহ্ সর্বজ্ঞাতা।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmdcccxx{তোমাদের উপরে কোনো অপরাধ হবে না যদি তোমরা এমন ঘরে প্রবেশ কর যেখানে কোনো বাসিন্দা নেই, তোমাদের জন্য সেখানে প্রয়োজন রয়েছে। আর আল্লাহ্ জানেন যা তোমরা প্রকাশ কর ও যা তোমরা গোপন রাখ।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmdcccxxi{তুমি মুমিন পুরুষদের বলো যে তারা তাদের দৃষ্টি অবনত করুক এবং তাদের আঙ্গিক কর্তব্যাবলীর হেফাজত করুক। এ তাদের জন্য পবিত্রতর। তারা যা করে আল্লাহ্ সে-বিষয়ে নিশ্চয়ই পূর্ণ ওয়াকিফহাল।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmdcccxxii{আর মুমিন নারীদের বলো যে তারা যেন তাদের দৃষ্টি অবনত রাখে, আর তাদের আঙ্গিক কর্তব্যাবলীর হেফাজত করে, আর তাদের অঙ্গশোভা যেন প্রদর্শন না করে শুধু তার মধ্যে যা প্রকাশ হয়ে থাকে তা ভিন্ন, আর যেন তারা তাদের মাথার কাপড় দিয়ে তাদের বুকের উপরটা ঢেকে রাখে, আর তারা যেন তাদের শোভা-সৌন্দর্য প্রদর্শন করে না শুধু তাদের স্বামীদের অথবা তাদের পিতাদের অথবা তাদের শ্বশুরদের অথবা তাদের পুত্রদের অথবা তাদের সৎপুত্রদের অথবা তাদের ভাইদের অথবা তাদের ভ্রাতুস্পুত্রদের অথবা তাদের ভাগনেদের অথবা তাদের পরিচারিকাদের অথবা তাদের ডান হাত যাদের ধরে রেখেছে, অথবা পুরুষ চাকর-নকর যাদের কাম-লালসা নেই, অথবা ছেলেপিলেদের যাদের নারীদের গোপন অঙ্গ সন্বন্ধে জ্ঞানবোধ হয় নি, এমন লোকদের ভিন্ন, আর তাদের পা দিয়ে যেন তারা আঘাত না করে যাতে তাদের অলংকারের যা লুকিয়ে আছে তা জানানো যায়। আর হে মুমিনগণ! তোমরা সকলে মিলে আল্লাহ্‌র দিকে ফেরো যেন তোমাদের সফলতা অর্জন হয়।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmdcccxxiii{আর বিয়ে দিয়ে দাও তোমাদের মধ্যের অবিবাহিতদের, আর তোমাদের দাসদের ও তোমাদের দাসীদের মধ্যের সচ্চরিত্রদের। যদি তারা অভাবগ্রস্ত হয় তবে আল্লাহ্ তাঁর করুণাভান্ডার থেকে তাদের সম্পদ দান করবেন। আর আল্লাহ্ মহাবদান্য, সর্বজ্ঞাতা।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmdcccxxiv{আর যারা বিবাহের পাত্রপাত্রী খোঁজে পায় না তারা যেন সংযত হয়ে চলে যতক্ষণ না আল্লাহ্ তাঁর করুণাভান্ডার থেকে তাদের সম্পদ দান করেন। আর তোমাদের ডানহাতে যাদের ধরে রেখেছে তাদের মধ্যের যারা নিখাপড়া চায় তাদের তবে লিখে দাও যদি তাদের মধ্যে কল্যাণকর কিছু থাকা সন্বন্ধে জানতে পার, আর তিনি তোমাদের যা দিয়েছেন আল্লাহ্‌র সেই ধন থেকে তাদের দান করো। আর তোমাদের দাসী-বাঁদীদের বেশ্যাবৃত্তিতে বাধ্য কর না পার্থিব জীবনের নশ্বর বস্তু কামনা ক’রে যদি তারা সচ্চরিত্র থাকা পছন্দ করে। আর যে কেউ তাদের বাধ্য করে সেক্ষেত্রে তাদের প্রতি জবরদস্তির পরে আল্লাহ্ নিশ্চয়ই ক্ষমাকারী, অফুরন্ত ফলদাতা।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmdcccxxv{আর আমরা নিশ্চয়ই ইতিমধ্যে তোমাদের কাছে সুস্পষ্ট নির্দেশাবলী অবতারণ করেছি, আর তোমাদের পূর্বে যারা গত হয়েছে তাদের উদাহরণ, আর ধর্মভীরুদের জন্য দিয়েছি উপদেশ।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmdcccxxvi{আল্লাহ্ হচ্ছেন মহাকাশমন্ডলী ও পৃথিবীর আলোক। তাঁর আলোকের উপমা হচ্ছে যেন একটি কুলঙ্গী যাতে আছে একটি প্রদীপ। প্রদীপটি রয়েছে একটি কাচের চিমনির ভেতরে। চিমনিটি যেন একটি উজ্জ্বল তারকা, যেটি জ্বালানো হয়েছে পবিত্র জয়তুন গাছ থেকে, -- পূর্বাঞ্চলীয় নয়, পাশ্চাত্যেরও নয়, তার তেলটা যেন প্রজ্জ্বলিত যদিও আগুন তাকে স্পর্শ করতে পারে না। আলোকের উপরে আলোক! আল্লাহ্ তাঁর আলোকের দিকে যাকে ইচ্ছে করেন পথ দেখিয়ে নেন। আর আল্লাহ্ মানুষের জন্য উপমাগুলো ছোঁড়েন। আর আল্লাহ্ সব-কিছু সন্বন্ধে সর্বজ্ঞাতা।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmdcccxxvii{সেইসব ঘরে যাকে আল্লাহ্ অনুমতি দিয়েছেন উন্নীত হতে এবং তাঁর নামে সে-সবে গুণ-কীর্তন হতে, সে-সবে তাঁর জপতপ করা হয় সকাল ও সন্ধ্যায়, --\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmdcccxxviii{ব্যক্তিবর্গ, -- ব্যবসা-বাণিজ্য ও বেচা-কেনা তাদের বিরত করতে পারে না আল্লাহ্‌র নাম-কীর্তন থেকে ও নামায কায়েম করা ও যাকাত আদায় করা থেকে, তারা ভয় করে সেই দিনকে যেদিন হৃদয় ও চোখ আন্দোলিত হবে, --\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmdcccxxix{যেন আল্লাহ্ তাদের প্রতিদান দিতে পারেন শ্রেষ্ঠ-সুন্দরভাবে যা তারা করেছে সেজন্য, আর তাঁর করুণাভান্ডার থেকে তাদের বাড়িয়েও দিতে পারেন। আর আল্লাহ্ বেহিসাব রিযেক দিয়ে থাকেন যাকে তিনি ইচ্ছে করেন।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmdcccxxx{পক্ষান্তরে যারা অবিশ্বাস পোষণ করে তাদের ক্রিয়াকর্ম মরুভূমির মরীচিকার ন্যায়, পিপাসার্ত তাকে পানি বলে মনে করে যে পর্যন্ত না সে তার কাছে আসে সে ঐটির কিছুই দেখতে পায় না, বরং সে আল্লাহকে তার সামনে দেখতে পাবে, সুতরাং তিনি তার হিসাব চুকিয়ে দেবেন। আর আল্লাহ্ হিসাব-নিকাশে তৎপর।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmdcccxxxi{অথবা গভীর সমুদ্রের তলার ঘোর অন্ধকারের ন্যায়, তাকে ঢেকে রাখে এক ঢেউ, তার উপরে আরেক ঢেউ, তার উপরে আছে মেঘ। ঘোর অন্ধকার -- যার একটি অপরটির উপরে। সে যখন তার হাত বাড়ায় সে তা যেন দেখতেই পায় না। আর যাকে আল্লাহ্ তার নিমিত্তে আলোক দেন নি তার জন্য তবে কোনো আলোক নেই।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmdcccxxxii{তুমি কি দেখ না যে আল্লাহ্ -- তাঁরই জপতপ করে যারাই আছে মহাকাশমন্ডলীতে ও পৃথিবীতে, আর পাখা-মেলে-থাকা পাখি? প্রত্যেকেই জেনে রেখেছে তার নামায ও তার নামজপ। আর তারা যা করে সে-সন্বন্ধে আল্লাহ্ সম্যক জ্ঞাতা।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmdcccxxxiii{আর মহাকাশমন্ডলী ও পৃথিবীর সার্বভৌম কর্তৃত্ব আল্লাহ্‌র, আর আল্লাহ্‌র প্রতিই হচ্ছে প্রত্যাবর্তনস্থল।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmdcccxxxiv{তুমি কি দেখতে পাচ্ছ না যে আল্লাহ্ মেঘমালাকে চালিয়ে নিয়ে যান, তারপর তিনি তাদের পরস্পরের মধ্যে জড় করেন, তারপর তাদের তিনি পুঞ্জীভূত করেন, তখন তুমি দেখতে পাও তার ভেতর থেকে বেরুচ্ছে বৃষ্টি? আর তিনি আকাশ থেকে পাহাড়গুলো হতে পাঠান তাতে থাকা শিলার রাশি, আর তা দিয়ে তিনি আঘাত করেন যাকে খুশি, এবং তা ফিরিয়ে রাখেন যাকে ইচ্ছা তার থেকে। তার বিদ্যুতের ঝলক দৃষ্টিশক্তি প্রায় নিয়েই নেয়।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmdcccxxxv{আল্লাহ্ রাত ও দিনকে বিবর্তন করেন। নিঃসন্দেহ এতে তো শিক্ষণীয় বিষয় রয়েছে দৃষ্টিসম্পন্নদের জন্য।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmdcccxxxvi{আর আল্লাহ্ সব জীবন্তজগতকে সৃষ্টি করেছেন পানি থেকে, সুতরাং তাদের মধ্যে রয়েছে যা তার পেটের উপরে চলে, আর তাদের মধ্যে আছে যা দুই পায়ে হাঁটে, আর তাদের মধ্যে রয়েছে যা চারখানায় চলে। আল্লাহ্ সৃষ্টি করে যান যা তিনি চান। নিঃসন্দেহ আল্লাহ্ সব বিষয়ে সর্বশক্তিমান।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmdcccxxxvii{আমরা নিশ্চয়ই সুস্পষ্ট নির্দেশাবলী অবতারণ করেছি, আর আল্লাহ্ সহজ-সঠিক পথের দিকে চালিত করেন যাকে তিনি ইচ্ছে করেন।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmdcccxxxviii{ফলে তারা বলে -- ''আমরা আল্লাহ্‌র প্রতি ও রসূলের প্রতি ঈমান এনেছি, আর আমরা আজ্ঞা পালন করি।’’ তারপর তাদের একদল এর পরেও ফিরে যায়। আর এই লোকগুলো মুমিন নয়।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmdcccxxxix{আর যখন তাদের ডাকা হয় আল্লাহ ও তাঁর রসূলের প্রতি যেন তিনি তাদের মধ্যে একটা মীমাংসা করতে পারেন, তখন দেখো, তাদের মধ্যের একদল ঘুরে যায়।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmdcccxl{আর যদি ন্যায়পরায়ণতা তাদের সপক্ষে হয় তবে তারা তাঁর কাছে আসে ঘাড় নুইয়ে।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmdcccxli{ওদের হৃদয়ে কি ব্যাধি আছে, না তারা সন্দেহ পোষণ করে, না তারা আশংকা করে যে আল্লাহ্ ও তাঁর রসূল তাদের প্রতি অন্যায় আচরণ করবেন? বস্তুতঃ তারা স্বয়ং অন্যায়াচারী।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmdcccxlii{নিঃসন্দেহ মুমিনদের কথা হচ্ছে -- যখন তাদের ডাকা হয় আল্লাহ্ ও তাঁর রসূলের প্রতি যেন তিনি তাদের মধ্যে বিচার করতে পারেন, তখন তারা বলে -- ''আমরা শুনি ও পালন করি।’’ আর তারা নিজেরাই হয় সফলকাম।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmdcccxliii{আর যে আল্লাহ্‌র ও তাঁর রসূলের আজ্ঞা পালন করে, আর আল্লাহ্‌কে ভয় করে ও তাঁকে ভক্তিশ্রদ্ধা করে, তাহলে তারা নিজেরাই বিজেতা হবে।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmdcccxliv{আর তারা তাদের সুদৃঢ় আস্থার সাথে আল্লাহ্‌র নামে কসম খায় যে যদি তুমি তাদের আদেশ করতে তাহলে তারা আলবৎ বেরিয়ে পড়ত। তুমি বলো, ''শপথ করো না, আনুগত্য তো জানাই আছে! তোমরা যা কর আল্লাহ্ নিশ্চয়ই সে-বিষয়ে ওয়াকিফহাল।’’\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmdcccxlv{বলো -- ''আল্লাহ্‌র আনুগত্য কর ও রসূলেরও আজ্ঞাপালন কর।’’ কিন্ত যদি তোমরা ফিরে যাও, তাহলে নিঃসন্দেহ তাঁর উপরে রয়েছে শুধু তাঁকে যে ভার দেওয়া হয়েছে, আর তোমাদের উপরে রয়েছে তোমাদের যে ভার দেওয়া হয়েছে। আর যদি তোমরা তাঁর আজ্ঞাপালন কর তবে তোমরা সৎপথ পাবে। আর রসূলের উপরে কোনো দায়িত্ব নেই সুস্পষ্টভাবে পৌঁছানো ছাড়া।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmdcccxlvi{তোমাদের মধ্যে যারা ঈমান এনেছে এবং সৎকর্ম করছে আল্লাহ্ তাদের ওয়াদা করছেন যে, তিনি নিশ্চয়ই তাদের পৃথিবীতে প্রতিনিধিত্ব দান করবেন, যেমন তিনি প্রতিনিধিত্ব দান করেছিলেন তাদের যারা ছিল এদের পূর্ববর্তী, আর অবশ্যই তিনি তাদের জন্য সুপ্রতিষ্ঠিত করবেন তাদের ধর্ম যা তিনি তাদের জন্য মনোনীত করেছেন, আর নিশ্চয়ই তাদের ভয়-ভীতির পরে তাদের জন্যে বদলে আনবেন নিরাপত্তা। তারা আমারই এবাদত করবে, আমার সঙ্গে অন্য কাউকে শরিক করবে না। আর যে কেউ এর পরে অকৃতজ্ঞতা দেখাবে -- তাহলে তারা নিজেরাই হচ্ছে সীমা-লংঘনকারী।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mmdcccxlvii{আর তোমরা নামায কায়েম কর ও যাকাত আদায় কর আর রসূলের আজ্ঞাপালন কর, যাতে তোমাদের প্রতি অনুগ্রহ করা হয়।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mmdcccxlviii{তুমি মনে করো না যে যারা অবিশ্বাস পোষণ করে তারা পৃথিবীতে এড়িয়ে যেতে পারবে, বরঞ্চ তাদের আবাসস্থল হচ্ছে আগুন। আর আলবৎ মন্দ সেই গন্তব্যস্থান।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mmdcccxlix{ওহে যারা ঈমান এনেছ! তোমাদের ডান হাত যাদের ধরে রেখেছে এবং তোমাদের মধ্যের যারা সাবালগত্বে পৌঁছায়নি তারা যেন তোমাদের অনুমতি নেয় তিনটি সময়ে, -- ফজরের নামাযের আগে, আর যখন তোমরা মধ্যাহ্নের গরমে তোমাদের জামাকাপড় ছেড়ে দাও, এবং ঈশার নামাযের পরে। এই তিন হচ্ছে তোমাদের জন্য গোপনীয়তা অবলন্বনের সময়। এইসব বাদ দিয়ে তোমাদের জন্য কোনো দোষ হবে না এবং তাদের জন্যও নয়। তোমাদের কাউকে অপরের কাছে তো ঘোরাঘুরি করতেই হয়। এইভাবেই আল্লাহ্ তোমাদের জন্য বাণীসমূহ সুস্পষ্ট করে দিয়েছেন। আর আল্লাহ্ সর্বজ্ঞাতা, পরমজ্ঞানী।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mmdcccl{আর তোমাদের মধ্যেকার ছেলেপিলেরা যখন সাবালগত্বে পৌঁছে যায় তখন তারাও যেন অনুমতি চায় যেমন অনুমতি চাইত তারা যারা এদের আগে রয়েছিল। এইভাবেই আল্লাহ্ তোমাদের জন্য তাঁর বাণীসমূহ সুস্পষ্ট করে দিয়েছেন। আর আল্লাহ্ সর্বজ্ঞাতা, পরমজ্ঞানী।\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mmdcccli{আর নারীদের মধ্যের প্রেঢ়ারা যারা বিয়ের আশা করে না, তাদের জন্যে তবে অপরাধ হবে না যদি তারা তাদের পোশাক খুলে রাখে শোভা-সৌন্দর্য প্রদর্শন না ক’রে। আর যদি তারা সংযত থাকে তবে তাদের জন্য বেশি ভাল। আর আল্লাহ্ সর্বশ্রতা, সর্বজ্ঞাতা।\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mmdccclii{অন্ধের উপরে কোনো দোষ নেই ও খোঁড়ার উপরেও নয়, যদি তোমরা আহার কর তোমাদের বাড়ি থেকে, অথবা তোমাদের পিতাদের বাড়িতে, কিংবা তোমাদের মায়েদের বাড়িতে, নয়ত তোমাদের ভাইদের বাড়িতে, না হয় তোমাদের বোনদের বাড়িতে, কিংবা তোমাদের চাচাদের বাড়িতে, অথবা তোমাদের ফুফুদের বাড়িতে, নয়ত তোমাদের মামাদের বাড়িতে, অথবা তোমাদের খালাদের বাড়িতে, কিংবা সেইসবে যার চাবি তোমাদের দখলে রয়েছে, অথবা তোমাদের বন্ধুদের। তোমাদের উপরে কোনো অপরাধ হবে না যদি তোমরা একসঙ্গে আহার কর অথবা আলাদাভাবে। সুতরাং যখন তোমরা বাড়িঘরে প্রবেশ কর তখন তোমাদের পরস্পরকে সালাম কর আল্লাহ্‌র তরফ থেকে কল্যাণময় পবিত্র সম্ভাষণে। এইভাবেই আল্লাহ্ তোমাদের জন্য বাণীসমূহ সুস্পষ্ট করে দিয়েছেন যেন তোমরা বুঝতে পার।\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mmdcccliii{তারাই কেবল মুমিন যারা আল্লাহ্‌তে ও তাঁর রসূলে ঈমান আনে, আর যখন তারা কোনো সমষ্টিগত ব্যাপারে তাঁর সঙ্গে থাকে তখন তারা চলে যায় না যতক্ষণ না তারা তাঁর থেকে অনুমতি নিয়েছে। নিঃসন্দেহ যারা তোমার অনুমতি প্রার্থনা করে তারাই হচ্ছে ওরা যারা আল্লাহ্‌তে ও তাঁর রসূলে ঈমান এনেছে, সুতরাং তারা যখন তাদের কোনো ব্যাপারের জন্য তোমার অনুমতি প্রার্থনা করে তখন অনুমতি দাও তাদের মধ্যের যাকে তুমি ইচ্ছা কর, আর তাদের জন্য আল্লাহ্‌র ক্ষমা প্রার্থনা কর। নিঃসন্দেহ আল্লাহ্ পরিত্রাণকারী, অফুরন্ত ফলদাতা।\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mmdcccliv{তোমাদের মধ্যে রসূলের আহ্বানকে তোমরা তোমাদের মধ্যের একে অন্যে আহ্বানের মতো গণ্য করো না। আল্লাহ্ অবশ্যই তাদের জানেন তোমাদের মধ্যের যারা চুপি চুপি সরে পড়ে, সেজন্য যারা তাঁর আদেশের বিরুদ্ধে যায় তারা সাবধান হোক পাছে কোনো বিপর্যয় তাদের উপরে পতিত হয়, অথবা কোনো মর্মন্তদ শাস্তি তাদের উপরে আপতিত হয়।\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mmdccclv{এটি কি নয় যে মহাকাশমন্ডলীতে ও পৃথিবীতে যা-কিছু আছে তা নিশ্চয়ই আল্লাহ্‌র? তিনি অবশ্য জানেন তোমরা যা-কিছুতে রয়েছ। আর যেদিন তাদের তাঁর কাছে ফেরত নেওয়া হবে সেদিন তাদের জানিয়ে দেওয়া হবে যা তারা করত। আর আল্লাহ্ সব- কিছু সন্বন্ধে সর্বজ্ঞাতা।\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mmdccclvi{\basmalahbn মহামহিম তিনি যিনি তাঁর দাসের কাছে অবতারণ করেছেন এই ফুরক্কান যেন তিনি বিশ্বমানবের জন্য একজন সতর্ককারী হতে পারেন।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmdccclvii{তিনিই -- মহাকাশমন্ডলী ও পৃথিবীর সার্বভৌমত্ব তাঁরই, আর তিনি কোনো সন্তান গ্রহণ করেন নি, আর সেই সাম্রাজ্যে তাঁর কোনো শরিকও নেই, আর তিনিই সব-কিছু সৃষ্টি করেছেন, তারপর তাকে বিশেষ পরিমাপে পরিমিত রূপ দিয়েছেন।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmdccclviii{তবুও তারা তাঁকে ছেড়ে দিয়ে অন্য উপাস্যদের গ্রহণ করেছে যারা কিছুই সৃষ্টি করে না, বরং তাদের নিজেদেরকেই সৃষ্টি করা হয়েছে, আর তারা নিজেদের জন্য অনিষ্ট করতে সামর্থ্য রাখে না, আর উপকার করতেও নয়, আর তারা মৃত্যু ঘটাতে ক্ষমতা রাখে না, আর জীবন দিতেও নয়, কিংবা পুনরুত্থানের ক্ষেত্রেও নয়।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmdccclix{আর যারা অবিশ্বাস পোষণ করে তারা বলে -- ''এইটি তো মিথ্যা বৈ নয় যা সে তৈরি করেছে এবং অন্যান্য লোকজন এ তে তাকে সাহায্য করেছে।’’ সুতরাং তারা অনাচার ও মিথ্যাচার নিয়ে এসেছে।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmdccclx{আর তারা বললে -- ''সেকালের উপকথা -- এ-সব সে লিখিয়ে নিয়েছে, আর এগুলো তার কাছে আবৃত্তি করা হয় সকালে ও সন্ধ্যায়।’’\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmdccclxi{তুমি বলো -- ''এটি অবতারণ করেছেন তিনি যিনি মহাকাশমন্ডলী ও পৃথিবীর রহস্য সব জানেন। তিনি অশ্যই পরিত্রাণকারী, অফুরন্ত ফলদাতা।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmdccclxii{আর তারা বলে -- ''এ কেমন ধরনের রসূল, সে খাবার খায় ও হাটে-বাজারে চলাফেরা করে? তার কাছে কেন একজন ফিরিশতা পাঠানো হ’ল না, যাতে সে তার সঙ্গে সতর্ককারী হতে পারতো?\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmdccclxiii{''অথবা তার কাছে ধনভান্ডার পাঠিয়ে দেওয়া হতো, অথবা তার জন্য একটি বাগান থাকত যা থেকে সে খেতো?’’ আর অন্যায়াচারীরা বলে -- ''তোমরা তো একজন জাদুগ্রস্ত লোককেই অনুসরণ করছ!’’\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmdccclxiv{দেখ, তারা কেমনভাবে তোমার প্রতি উপমা প্রয়োগ করে! সুতরাং তারা বিপথে গেছে, কাজেই তারা পথের দিশা পাচ্ছে না।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmdccclxv{মহামহিম তিনি যিনি ইচ্ছা করলে তোমার জন্য এর চেয়েও শ্রেষ্ঠ বস্তু তৈরি করতে পারেন -- বাগানসমূহ যাদের নিচ দিয়ে বয়ে চলে ঝরনারাজি, আর তোমার জন্য তৈরি করতে পারেন প্রাসাদ-সমূহ।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmdccclxvi{তথাপি তারা ঘড়িঘন্টাকে অস্বীকার করে, আর যে কেউ ঘড়িঘন্টাকে মিথ্যা বলে তার জন্য আমরা তৈরি রেখেছি এক জ্বলন্ত আগুন।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmdccclxvii{যখন এটি দূর জায়গা থেকে তাদের দেখতে পাবে তখন থেকেই তারা এর ত্রুদ্ধ গর্জন ও হুংকার শুনতে পাবে।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmdccclxviii{আর যখন তাদের শৃঙ্খলিত অবস্থায় এর মধ্যের এক সংকীর্ণ স্থানে নিক্ষেপ করা হবে তখন তারা সেইখানেই ধ্বংস হওয়া আহ্বান করবে।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmdccclxix{''আজকের দিনে তোমরা একবারের ধ্বংসের জন্য কামনা করো না, বরং বহুবার ধ্বংস হওয়ার দোয়া করতে থাক!’’\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmdccclxx{তুমি বলো -- ''এইটি কি ভাল, না চিরস্থায়ীস্বর্গোদ্যান যা ওয়াদা করা হয়েছে ধর্মনিষ্ঠদের জন্য?’’ তা হচ্ছে তাদের জন্য পুরস্কার ও গন্তব্যস্থল।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmdccclxxi{সেখানে তাদের জন্য রয়েছে যা তারা কামনা করে, তারা স্থায়ীভাবে অবস্থান করবে। এইটি তোমার প্রভুর উপরে ন্যস্ত ওয়াদা যা প্রার্থিত হবার যোগ্য।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmdccclxxii{আর সেইদিন তাদের তিনি একত্রিত করবেন আর আল্লাহ্‌কে বাদ দিয়ে যাদের তারা উপাসনা করত তাদেরও, তখন তিনি বললেন -- ''এ কি তোমরা! তোমরাই কি আমার এইসব বান্দাদের বিভ্রান্ত করেছিলে, না কি তারা স্বয়ং পথ ছেড়ে বিপথে গিয়েছিল?’’\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmdccclxxiii{তারা বলবে -- ''তোমারই সব মহিমা! এটি আমাদের জন্য সমীচীন নয় যে তোমাকে বাদ দিয়ে আমরা অন্যান্য অভিভাবকদের গ্রহণ করব। কিন্তু তুমি তাদের ও তাদের পিতৃপুরুষদের ভোগসম্ভার দিয়েছিলে, পরিণামে তারা ভুলে গিয়েছিল সাবধান-বাণী, ফলে তারা হয়েছিল একটি বিনষ্ট জাতি।’’\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmdccclxxiv{''সুতরাং তোমরা যা বলছ সে-সন্বন্ধে তারা তো তোমাদের মিথ্যা সাব্যস্ত করেছে, কাজেই তোমরা প্রতিরোধ করতে পারবে না, আর সাহায্যও পাবে না। আর তোমাদের মধ্যে যে কেউ অন্যায় করেছে তাকে আমরা বিরাট শাস্তি আস্বাদন করাব।’’\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmdccclxxv{আর তোমার আগে আমরা এমন কোনো রসূল পাঠাই নি যাঁরা নিঃসন্দেহ খাবার না খেয়েছেন ও হাটে-বাজারে চলাফেরা না করেছেন। আর আমরা তোমাদের কাউকে অপরদের জন্য পরীক্ষাস্বরূপ দাঁড় করিয়েছি। তোমরা কি অধ্যবসায় চালিয়ে যাবে? আর তোমার প্রভু সর্বদ্রষ্টা।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmdccclxxvi{আর যারা আমাদের সাথে মোলাকাতের কামনা করে না তারা বলে -- ''কেন আমাদের কাছে ফিরিশ্‌তাদের পাঠানো হয় না, অথবা আমাদের প্রভুকেই বা কেন আমরা দেখতে পাই না?’’ তারা তাদের নিজেদের সন্বন্ধে নিশ্চয়ই বড়াই করছে, আর বড় বাড় বেড়েছে।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmdccclxxvii{যেদিন তারা ফিরিশ্‌তাদের দেখতে পাবে সেইদিন অপরাধীদের জন্য কোনো খোশখবর থাকবে না, আর তারা বলবে -- ''অলঙ্ঘনীয় ব্যবধান হোক।’’\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmdccclxxviii{আর তারা কাজকর্মের যা করেছে তা আমরা বিবেচনা করব, তারপর তাকে বিক্ষিপ্ত ধূলিকণা বানিয়ে দেব।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmdccclxxix{স্বর্গোদ্যানের বাসিন্দারা সেদিন পাবে উৎকৃষ্ট বাসস্থান ও সুন্দরতর বিশ্রামস্থল।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmdccclxxx{আর সেই দিন আকাশ বিদীর্ণ হবে মেঘমালার সঙ্গে, আর ফিরিশতাদের পাঠানো হবে পাঠানোর মতো।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmdccclxxxi{সার্বভৌমত্ব সেইদিন সত্যি-সত্যি পরম করুণাময়ের। আর অবিশ্বাসীদের জন্য সেই দিনটি হবে বড় কঠিন!\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmdccclxxxii{আর সেইদিন অন্যায়কারী তার হাত কামড়াবে এই বলে -- ''হায় আমার দুর্ভোগ! আমি যদি রসূলের সঙ্গে পথ অবলন্বন করতাম!\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmdccclxxxiii{''হায়! কি আফসোস! আমি যদি এমন একজনকে বন্ধুরূপে গ্রহণ না করতাম!\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmdccclxxxiv{''আমাকে তো সে বিভ্রান্তিতে নিয়েই গেছে স্মারকগ্রন্থ থেকে তা আমার কাছে আসার পরে! আর শয়তান মানুষের জন্য সদা হতাশকারী।’’\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmdccclxxxv{আর রসূল বলছেন -- ''হে আমার প্রভু! নিঃসন্দেহ আমার স্বজাতি এই কুরআনকে পরিত্যজ্য বলে ধরে নিয়েছিল। ’’\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmdccclxxxvi{আর এইভাবেই আমরা প্রত্যেক নবীর জন্য শত্রু সৃষ্টি করেছি অপরাধীদের মধ্যে থেকে। আর তোমার প্রভুই পথপ্রদর্শক ও সহায়করূপে যথেষ্ট।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmdccclxxxvii{আর যারা অবিশ্বাস পোষণ করে তারা বলে -- ''তাঁর কাছে কুরআনখানা সমগ্রভাবে একেবারে অবতীর্ণ হ’ল না কেন?’’ এইভাবেই -- যেন এর দ্বারা তোমার হৃদয়কে আমরা সুপ্রতিষ্ঠিত করতে পারি, আর আমরা একে সাজিয়েছি সাজানোর মতো।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmdccclxxxviii{আর তারা তোমার কাছে নিয়ে আসতে পারবে না কোনো সমস্যা, আমরা কিন্তু তোমার নিকট নিয়ে আসব প্রকৃত-সত্য ও শ্রেষ্ঠ- সুন্দর ব্যাখ্যা।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmdccclxxxix{তাদের মুখ-থুবড়ে-পড়া অবস্থায় যাদের জাহান্নামের দিকে একত্রিত করা হবে তারাই হবে অবস্থার দিক দিয়ে অতি নিকৃষ্ট আর পথের দিক দিয়ে বড়ই পথভ্রষ্ট।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmdcccxc{আর ইতিপূর্বে আমরা মূসাকে ধর্মগ্রন্থ দিয়েছিলাম, আর তাঁর সঙ্গে তাঁর ভাই হারূনকে সহায়ক বানিয়েছিলাম।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmdcccxci{কাজেই আমরা বলেছিলাম -- ''তোমরা দুজনে চলে যাও সেই লোকদের কাছে যারা আমাদের নির্দেশাবলী প্রত্যাখ্যান করেছে।’’ পরিণামে আমরা তাদের ধ্বংস করেছিলাম পূর্ণ বিধ্বংসে।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmdcccxcii{আর নূহের স্বজাতি -- যখন তারা রসূলগণকে প্রত্যাখ্যান করেছিল তখন আমরা তাদের ডুবিয়ে দিয়েছিলাম, আর লোকদের জন্য তাদের এক নিদর্শন বানিয়েছিলাম। আর অন্যায়াচারীদের জন্য আমরা এক মর্মন্তুদ শাস্তি তৈরি করে রেখেছি।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmdcccxciii{আর 'আদ ও ছামূদ ও রস-এর অধিবাসীদের, আর তাদের মধ্যেকার বহুসংখ্যক বংশকেও।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmdcccxciv{আর প্রত্যেকেরই বেলায় -- আমরা তার জন্য দৃষ্টান্তগুলো প্রদান করেছিলাম। আর সকলকেই আমরা বিধবস্ত করেছিলাম পূর্ণবিধ্বংসে।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmdcccxcv{আর তারা তো সে জনপদের পাশ দিয়েই যাতায়াত করে যার উপরে আমরা বর্ষণ করেছিলাম এক অশুভ বৃষ্টি। তারা কি তবে এটি দেখতে পায় নি? না, তারা পুনরুত্থানের প্রত্যাশা করে না।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmdcccxcvi{আর তারা যখন তোমাকে দেখে তখন তারা তোমাকে ঠাট্টা-বিদ্রপের পাত্র ছাড়া অন্যভাবে গ্রহণ করে না। ''এ-ই কি সে যাকে আল্লাহ্ রসূল বানিয়েছেন?\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmdcccxcvii{''সে তো আমাদের দেব-দেবীদের থেকে আমাদের প্রায় সরিয়েই নিয়েছিল যদি না আমরা তাদের প্রতি অনুরাগ পোষণ করতাম!’’ আর শীঘ্রই তারা জানতে পারবে যখন তারা শাস্তি প্রত্যক্ষ করবে -- কে পথ থেকে অধিক পথভ্রষ্ট।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmdcccxcviii{তুমি কি তাকে দেখেছ যে তার কামনাকে তার উপাস্যরূপে গ্রহণ করেছে? তুমি কি তবে তার জন্য একজন কর্ণধার হবে?\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmdcccxcix{অথবা তুমি কি মনে কর যে তাদের অধিকাংশই শোনে অথবা বোঝে? তারা তো গরু-ছাগলের মতো ছাড়া আর কিছু নয়, বরং তারা পথ থেকে অধিক পথভ্রষ্ট।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmcm{তুমি কি প্রত্যক্ষ কর নি তোমার প্রভুর প্রতি -- কিভাবে তিনি ছায়া বিস্তার করেন? আর তিনি যদি চাইতেন তবে একে অনড় করে দিতেন। আমরা বরং সূর্যকে এর উপরে নির্দেশক বানিয়েছি।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmcmi{তারপর আমরা এটিকে আমাদের কাছে টেনে নিই আস্তে আস্তে টানতে টানতে।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmcmii{আর তিনিই সেইজন যিনি তোমাদের জন্য রাত্রিকে করেছেন আবরণী, আর ঘুমকে বিশ্রামস্বরূপ, আর দিনকে করেছেন জেগে ওঠার জন্য।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmcmiii{আর তিনিই সেইজন যিনি বাতাসকে পাঠান সুসংবাদদাতা-রূপে তাঁর করুণার প্রাক্কালে, আর আমরা আকাশ থেকে বর্ষণ করি বিশুদ্ধ পানি, --\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmcmiv{যেন আমরা তার দ্বারা মৃত ভূখন্ডকে জীবন দান করতে পারি, এবং তা পান করতে দিই বহুসংখ্যক গবাদি-পশুকে ও মানুষকে যাদের আমরা সৃষ্টি করেছি।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmcmv{আর আমরা নিশ্চয়ই এটিকে বিতরণ করি তাদের মধ্যে যেন তারা স্মরণ করতে পারে, কিন্ত অধিকাংশ লোকেই প্রত্যাখ্যান করা ছাড়া আর কিছুতে একমত হয় না।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmcmvi{আর যদি আমরা চাইতাম তাহলে প্রত্যেকটি জনপদে এক-একজন সতর্ককারী দাঁড় করাতাম।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmcmvii{অতএব অবিশ্বাসীদের আজ্ঞানুসরণ করো না, বরং তুমি এর সাহায্যে তাদের সঙ্গে জিহাদ করো কঠোর জিহাদে।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmcmviii{আর তিনিই সেইজন যিনি দুটি সাগরকে প্রবাহিত করছেন, -- একটি মিষ্ট, পিপাসা দমনকারক, আর একটি লবণাক্ত, তেতো স্বাদবিশিষ্ট, আর এ দুইয়ের মধ্যে তিনি সৃষ্টি করেছেন এক 'বরযখ’ ও এক অনতিক্রম্য ব্যবধান।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmcmix{আর তিনিই সেইজন যিনি মানুষকে সৃষ্টি করেছেন পানি থেকে, তারপর তার জন্য স্থাপন করেছেন রক্ত-সম্পর্ক ও বৈবাহিক সম্পর্ক। আর তোমার প্রভু অত্যন্ত ক্ষমতাশালী।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmcmx{আর তারা আল্লাহ্‌কে বাদ দিয়ে তার উপাসনা করে যে তাদের কোনো উপকার করতে পারে না, আর তাদের অপকারও করতে পারে না। আর অবিশ্বাসী রয়েছে তার প্রভুর বিরুদ্ধে পৃষ্ঠপোষক।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mmcmxi{আর আমরা তোমাকে সুসংবাদদাতা ও সতর্ককারীরূপে ভিন্ন অন্যভাবে পাঠাই নি।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mmcmxii{তুমি বল -- ''আমি তোমাদের কাছ থেকে এর জন্য কোনো মজুরি চাই না, শুধু এ-ই যে যে-কেউ ইচ্ছা করে সে যেন তার প্রভুর অভিমুখে পথ ধরে।’’\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mmcmxiii{আর তুমি নির্ভর কর চিরীবের উপরে যিনি মৃত্যু বরণ করেন না, আর তাঁর প্রশংসার সাথে জপতপ করো। আর তাঁর বান্দাদের পাপাচার সন্বন্ধে ওয়াকিফহালরূপে তিনিই যথেষ্ট, --\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mmcmxiv{যিনি সৃষ্টি করেছেন মহাকাশমন্ডলী ও পৃথিবী এবং এ দুইয়ের মধ্যের সবকিছুকে ছয় দিনে, তারপর তিনি অধিষ্ঠিত হলেন আরশের উপরে, -- তিনি পরম করুণাময়, অতএব তাঁর সন্বন্ধে জিজ্ঞাসা কর কোনো ওয়াকিফহালকে।\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mmcmxv{আর যখন তাদের বলা হয়, 'পরম করুণাময়কে সিজদা কর’, তারা বলে -- ''করুণাময় আবার কে? আমরা কি তাকেই সিজদা করব যার সন্বন্ধে তুমি আমাদের আদেশ কর?’’ আর এটি তাদের জন্য বাড়িয়ে দেয় বিতৃষ্ণা।\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mmcmxvi{মহামহিম তিনি যিনি মহাকাশে তারকারাজি সৃষ্টি করেছেন, আর তাতে বানিয়েছেন এক প্রদীপ ও এক চন্দ্র -- দীপ্তিদায়ক।\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mmcmxvii{আর তিনিই সেইজন যিনি রাত ও দিনকে বানিয়েছেন বিবর্তনক্রম তার জন্য যে চায় স্মরণ করতে, অথবা যে চায় কৃতজ্ঞতা জানাতে।\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mmcmxviii{আর পরম করুণাময়ের বান্দারা হচ্ছে তারা যারা পৃথিবীতে নম্রভাবে চলাফেরা করে, আর যখন অজ্ঞ লোকেরা তাদের সন্বোধন করে তখন বলে -- ''সালাম’’।\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mmcmxix{আর যারা রাত কাটিয়ে দেয় তাদের প্রভুর জন্য সিজদাবনত হয়ে ও দাঁড়িয়ে থেকে।\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mmcmxx{আর যারা বলে -- ''আমাদের প্রভু! আমাদের থেকে জাহান্নামের শাস্তি ফিরিয়ে রাখ, এর শাস্তি তো আলবৎ অপ্রতিহত --\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mmcmxxi{''নিঃসন্দেহ এটি বিশ্রামস্থল ও বাসস্থান বিসাবে কত নিকৃষ্ট!’’\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mmcmxxii{আর যারা যখন খরচপত্র করে তখন অমিতব্যয় করে না, আর কার্পণ্যও করে না, বরং তারা এ দুয়ের মধ্যস্থলে কায়েম রয়েছে।\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mmcmxxiii{আর যারা আল্লাহ্‌র সঙ্গে অন্য উপাস্যকে ডাকে না, আর ন্যায়ের প্রয়োজনে ব্যতীত যারা এমন কোনো লোককে হত্যা করে না যাকে আল্লাহ্ নিষেধ করেছেন, আর যারা ব্যভিচার করে না। আর যে এই করে সে পাপের শাস্তির সাক্ষাৎ পাবেই, --\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mmcmxxiv{আর কিয়ামতের দিনে তার জন্য শাস্তি বাড়িয়ে দেওয়া হবে, আর সেখানে সে হীন অবস্থায় স্থায়ী হয়ে রইবে, --\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mmcmxxv{সে ব্যতীত যে তওবা করে এবং ঈমান আনে ও পুণ্য-পবিত্র ক্রিয়াকর্ম করে। সুতরাং তারাই, -- আল্লাহ্ তাদের মন্দকাজকে সৎকাজ দিয়ে বদলে দেবেন। আর আল্লাহ্ সতত পরিত্রাণকারী, অফুরন্ত ফলদাতা।\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@mmcmxxvi{আর যে কেউ তওবা করে এবং সৎকর্ম করে সে-ই তো তবে আল্লাহ্‌র প্রতি ফেরার মতো ফেরে।\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@mmcmxxvii{আর যারা মিথ্যা ব্যাপারে সাক্ষ্য দেয় না, আব যখন তারা খেলো পরিবেশের পাশ দিয়ে যায় তখন তারা মর্যাদার সাথে পাশ কেটে যায়।\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@mmcmxxviii{আর যারা যখন তাদের প্রভুর নির্দেশসমূহ তাদের স্মরণ করিয়ে দেওয়া হয় তখন তারা তার উপরে ঝাঁপিয়ে পড়ে না বধির ও অন্ধ হয়ে।\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@mmcmxxix{আর যারা বলে -- ''আমাদের প্রভু! আমাদের স্ত্রীদের থেকে ও আমাদের সন্তান-সন্ততি থেকে চোখ-জোড়ানো আনন্দ আমাদের প্রদান করো, আর আমাদের তুমি বানিয়ে দাও ধর্মপরায়ণদের নেতৃস্থানীয়।’’\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@mmcmxxx{এইসব লোকেদের প্রতিদান দেওয়া হবে উচুঁ পদমর্যাদা দিয়ে যেহেতু তারা অধ্যবসায় করেছিল, আর সেখানে তাদের অভ্যর্থনা করা হবে অভিবাদন ও সালাম জানিয়ে, --\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@mmcmxxxi{সেখানে তারা স্থায়ীভাবে থাকবে, -- বিশ্রামস্থল ও বাসস্থান হিসাবে কত সুন্দর!\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@mmcmxxxii{বলো -- ''তোমাদের দোয়া না থাকলেও আমার প্রভুর কিছু যায় আসে না, কিন্তু তোমরা তো প্রত্যাখ্যানই করেছ, সেজন্য শীঘ্রই অনিবার্য শাস্তি আসছে।’’\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@mmcmxxxiii{\basmalahbn ত্বা, সীন, মীম।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmcmxxxiv{এসব হচ্ছে সুস্পষ্ট গ্রন্থের বাণীসমূহ।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmcmxxxv{তুমি হয়ত তোমার নিজেকে মেরেই ফেলবে যেহেতু তারা মুমিন হচ্ছে না।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmcmxxxvi{যদি আমরা ইচ্ছা করতাম তাহলে আমরা তাদের উপরে আকাশ থেকে একটি নিদর্শন পাঠাতে পারতাম, তখন এর কারণে তাদের ঘাড় নুইয়ে হেটঁ করে দেয়া হত।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmcmxxxvii{আর তাদের নিকট পরম করুণাময়ের কাছ থেকে কোনো নতুন স্মরণীয়-বার্তা আসতে না আসতেই তারা তা থেকে বিমুখ হয়ে যায়।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmcmxxxviii{তাহলে তারা প্রত্যাখ্যান করেই ফেলেছে, সুতরাং যা নিয়ে তারা ঠাট্টা-বিদ্রপ করত তার সংবাদ তাদের কাছে শীঘ্রই আসছে।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmcmxxxix{তারা কি পৃথিবীর দিকে চেয়ে দেখে না -- এতে আমরা প্রত্যেক উৎকৃষ্ট কল্পতরু কত যে জন্নিয়েছি?\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmcmxl{নিঃসন্দেহ এতে তো এক নিদর্শন রয়েছে, কিন্ত তাদের অধিকাংশই বিশ্বাসী নয়!\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmcmxli{আর নিঃসন্দেহ তোমার প্রভু -- তিনিই তো মহাশক্তিশালী, অফুরন্ত ফলদাতা।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmcmxlii{আর স্মরণ করো! তোমার প্রভু মূসাকে ডেকে বললেন -- ''তুমি অত্যাচারী লোকদের কাছে যাও, --\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmcmxliii{ফিরআউনের লোকদের কাছে। তারা কি ধর্মভীরুতা অবলন্বন করবে না?’’\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmcmxliv{তিনি বললেন -- ''আমার প্রভু! আমি অবশ্যই আশংকা করি যে তারা আমাকে প্রত্যাখ্যান করবে।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmcmxlv{''আমার বুক সংকুচিত হয়ে পড়েছে, আর আমার জিহ্বা বাক্‌পটু নয়, সেজন্য হারূনের প্রতিও ডাক পাঠাও।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmcmxlvi{''আর আমার বিরুদ্ধে এক অপরাধ তাদের তত্ত্বাবধানে রয়েছে, সেজন্য আমি ভয় করি যে তারা আমাকে কাতল করবে।’’\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmcmxlvii{তিনি বললেন -- ''কখনো না! অতএব তোমরা দুজনেই আমাদের নিদর্শন সমূহ নিয়ে যাও, নিশ্চয়ই আমরা তোমাদের সঙ্গে রয়েছি শুনতে থাকা অবস্থায়।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmcmxlviii{''সুতরাং তোমরা ফিরআউনের নিকট যাও আর বলো -- 'আমরা আলবৎ বিশ্বজগতের প্রভুর রসূল --\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmcmxlix{''যে ইসরাইলের বংশধরদের আমাদের সঙ্গে পাঠিয়ে দাও’।’’\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmcml{সে বললে -- ''তোমাকে কি ছেলেবেলায় আমাদের কাছেই লালনপালন করি নি, এবং তুমি কি আমাদেরই মধ্যে তোমার জীবনের বহু বৎসর কাটাও নি?\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmcmli{''আর তোমার কাজ যা তুমি করেছ তা তো করেইছ, তথাপি তুমি অকৃতজ্ঞদের মধ্যেকার!’’\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmcmlii{তিনি বললেন -- ''আমি এটি করেছিলাম যখন আমি পথভ্রষ্টদের মধ্যে ছিলাম।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmcmliii{''এরপর যখন আমি তোমাদের ভয় করেছিলাম তখন আমি তোমাদের থেকে ফেরার হলাম, তারপর আমার প্রভু আমাকে জ্ঞান দান করেছেন, আর তিনি আমাকে বানিয়েছেন রসূলদের অন্যতম।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmcmliv{''আর এই তো হচ্ছে সেই অনুগ্রহ যা তুমি আমার কাছে উল্লেখ করছ যার জন্যে তুমি ইসরাইলের বংশধরদের দাস বানিয়েছ!’’\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmcmlv{ফিরআউন বললে -- ''বিশ্বজগতের প্রভু আবার কি হয়?’’\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmcmlvi{তিনি বললেন -- ''মহাকাশমন্ডলী ও পৃথিবীর এবং তাদের মধ্যে যা-কিছু আছে তার প্রভু, -- যদি তোমরা দৃঢ়প্রত্যয়িত হও।’’\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmcmlvii{সে তার আশপাশে যারা আছে তাদের বললে -- ''তোমরা কি শুনছ না?’’\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmcmlviii{তিনি বললেন -- ''তোমাদের প্রভু এবং পূর্বকালের তোমাদের পিতৃপুরুষদেরও প্রভু।’’\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmcmlix{সে বললে -- ''তোমাদের রসূলটি যাকে তোমাদের কাছে পাঠানো হয়েছে সে তো বদ্ধ পাগল।’’\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmcmlx{তিনি বললেন -- ''তিনি পূর্ব ও পশ্চিমের এবং এ দুইয়ের মধ্যে যা আছে তারও প্রভু, যদি তোমরা বুঝতে পারতে।’’\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmcmlxi{সে বললে -- ''তুমি যদি আমাকে ছাড়া অন্য উপাস্য গ্রহণ কর তবে আমি আলবৎ তোমাকে কয়েদীদের অন্তর্ভুক্ত করব।’’\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmcmlxii{তিনি বললেন -- ''কী! আমি তোমার কাছে সুস্পষ্ট কিছু আনলেও?’’\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmcmlxiii{সে বললে -- ''তবে তা নিয়ে এস যদি তুমি সত্যবাদীদের একজন হও।’’\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmcmlxiv{সুতরাং তিনি তাঁর লাঠি নিক্ষেপ করলেন, তখন আশ্চর্য! এটি এক স্পষ্ট সাপ হয়ে গেল।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmcmlxv{আর তিনি তাঁর হাত বের করেলন, তখন দেখো! দর্শকদের কাছে তা সাদা হয়ে গেল।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmcmlxvi{সে তার আশপাশের প্রধানদের বললে -- ''এ তো নিশ্চয়ই এক ওস্তাদ জাদুকর, --\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmcmlxvii{''সে চাইছে তার জাদুর দ্বারা তোমাদের দেশ থেকে তোমাদের বের করে দিতে, কাজেই কী তোমরা উপদেশ দাও?’’\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmcmlxviii{তারা বললে -- ''তাকে ও তার ভাইকে অবকাশ দাও, আর শহরে শহরে সংগ্রাহকদের পাঠাও, --\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmcmlxix{''যেন তারা প্রত্যেক জ্ঞানী জাদুকরদের তোমার কাছে নিয়ে আছে।’’\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmcmlxx{সুতরাং জাদুকরদের একত্র করা হ’ল নির্দিষ্ট স্থানে বিজ্ঞাপিত দিনে,\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmcmlxxi{আর লোকদের বলা হ’ল -- ''তোমরা কি জমায়েৎ হচ্ছ, --\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmcmlxxii{''যেন আমরা জাদুকরদের অনুগমন করতে পারি যদি তারা নিজেরা বিজয়ী হয়?’’\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmcmlxxiii{তারপর যখন জদুকররা এল তারা ফিরআউনকে বললে -- ''আমাদের জন্য কি বিশেষ পুরস্কার থাকবে যদি আমরা খোদ বিজয়ী হই?’’\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmcmlxxiv{সে বললে -- ''হাঁ, আর সেক্ষেত্রে তোমরা নিশ্চয়ই অন্তরঙ্গ হবে।’’\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmcmlxxv{মূসা তাদের বললেন -- ''ছোড়ো যা তোমরা ছুড়ঁতে যাচ্ছ।’’\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmcmlxxvi{সুতরাং তাদের দড়িদড়া ও তাদের লাঠি-লগুড় তারা ছুড়ঁলো এবং বললে -- ''ফিরআউনের প্রভাবে আমরা তো নিজেরাই বিজয়ী হব।’’\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmcmlxxvii{তারপর মূসা তাঁর লাঠি নিক্ষেপ করলেন, তখন দেখো! এটি গিলে ফেলল যা তারা বুনেছিল।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmcmlxxviii{তখন জাদুকররা লুটিয়ে পড়ল সিজদাবনত হয়ে,\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmcmlxxix{তারা বললে, ''আমরা ঈমান আনলাম বিশ্বজগতের প্রভুর প্রতি, --\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmcmlxxx{''যিনি মূসা ও হারুনেরও প্রভু।’’\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmcmlxxxi{সে বললে -- ''তোমরা তার প্রতি বিশ্বাস স্থাপন করলে আমি তোমাদের অনুমতি দেবার আগেই? সে-ই নিশ্চয় তোমাদের গুরু যে তোমাদের জাদুবিদ্যা শিখিয়েছে। সুতরাং শীঘ্রই তোমরা টের পাবে। আমি নিশ্চয় তোমাদের হাত ও তোমাদের পা আড়াআড়ি- ভাবে কেটে ফেলবই, আর তোমাদের সবাইকে শূলে চড়াব।’’\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmcmlxxxii{তারা বললে -- ''কোনো ক্ষতি নেই, নিঃসন্দেহ আমরা আমাদের প্রভুর কাছে প্রত্যাবর্তনশীল।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmcmlxxxiii{''আমরা নিশ্চয়ই আশা করি যে আমাদের প্রভু আমাদের অপরাধসমূহ ক্ষমা করে দেবেন, যেহেতু আমরা মুমিনদের মধ্যে অগ্রণী।’’\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmcmlxxxiv{আর আমরা মূসাকে প্রত্যাদেশ দিয়েছিলাম এই বলে -- ''আমার বান্দাদের নিয়ে রাতের মধ্যে রওয়ানা হয়ে যাও, তোমাদের অবশ্য পশ্চাদ্ধাবন করা হবে।’’\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmcmlxxxv{তখন ফিরআউন শহরে-নগরে সংগ্রাহকদের পাঠাল --\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmcmlxxxvi{''নিঃসন্দেহ তারা একটি ছোটখাট দল,\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmcmlxxxvii{''আর নিঃসন্দেহ আমাদের জন্য তারা তো ক্রোধ উদ্রেককারী,\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mmcmlxxxviii{''আর আমরা তো নিশ্চয় সজাগ-সশস্ত্র জনতা।’’\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mmcmlxxxix{কাজেই আমরা তাদের বের ক’রে আনলাম বাগানসমূহ ও ঝরনারাজি থেকে,\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mmcmxc{আর ধনভান্ডার ও জমকালো বাড়িঘর থেকে, --\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mmcmxci{এইভাবেই। আর এইগুলো আমরা ইসরাইলের বংশধরদের উত্তরাধিকার করতে দিয়েছিলাম।\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mmcmxcii{তারপর তারা এদের পশ্চাদ্ধাবন করেছিল সূর্যোদয়কালে।\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mmcmxciii{অতঃপর যখন দুই দল পরস্পরকে দেখল তখন মূসার সঙ্গীরা বললে -- ''আমরা তো নিঃসন্দেহ ধরা পড়ে গেলাম।’’\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mmcmxciv{তিনি বললেন -- ''নিশ্চয়ই না, আমার সঙ্গে আলবৎ আমার প্রভু রয়েছেন, তিনি আমাকে অচিরেই পথ দেখাবেন।’’\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mmcmxcv{তখন আমরা মূসার নিকট প্রত্যাদেশ দিলাম এই বলে -- ''তোমার লাঠি দিয়ে সমুদ্রে আঘাত কর।’’ ফলে এটি বিভক্ত হয়ে গেল, সুতরাং প্রত্যেক দল এক-একটি বিরাট পাহাড়ের মতো হয়েছিল।\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mmcmxcvi{আর অন্যদেরকেও আমরা নিয়ে এলাম সেই অঞ্চলে।\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mmcmxcvii{আর মূসাকে ও তাঁর সঙ্গে যারা ছিল সে-সবাইকে আমরা উদ্ধার করেছিলাম।\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mmcmxcviii{তারপর অন্যদেরকে আমরা ডুবিয়ে দিয়েছিলাম।\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mmcmxcix{নিঃসন্দেহ এতে তো একটি নিদর্শন রয়েছে, কিন্ত তাদের অধিকাংশই বিশ্বাসী নয়।\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mmm{আর নিঃসন্দেহ তোমার প্রভু -- তিনিই তো মহাশক্তিশালী, অফুরন্ত ফলদাতা।\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mmmi{আর তুমি তাদের কাছে ইব্রাহীমের কাহিনী বর্ণনা করো।\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mmmii{স্মরণ করো! তিনি তাঁর পিতৃপুরুষকে ও তাঁর স্বজাতিকে বললেন -- ''তোমরা কিসের উপাসনা কর?’’\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@mmmiii{তারা বললে -- ''আমরা প্রতিমাদের পূজা করি, আর আমরা তাদের আরাধনায় নিষ্ঠাবান থাকব।’’\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@mmmiv{তিনি বললেন, ''তারা কি তোমাদের শোনে যখন তোমরা ডাকো?\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@mmmv{''অথবা তারা কি তোমাদের উপকার করতে পারে কিংবা অপকার করতে পারে?’’\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@mmmvi{তারা বললে -- ''না, আমাদের পিতৃপুরুষদের আমরা দেখতে পেয়েছি এইভাবে তারা করছে ।’’\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@mmmvii{তিনি বললেন -- ''তোমরা কি তবে ভেবে দেখেছ তোমরা কিসের উপাসনা করছ, --\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@mmmviii{''তোমরা ও তোমাদের পূর্বগামী পিতৃপুরুষরা?\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@mmmix{''অতএব তারা আলবৎ আমার শত্রু, কিন্ত ভূ-বিশ্বের প্রভু নন,\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@mmmx{''যিনি আমাকে সৃষ্টি করেছেন, তারপর তিনি আমাকে পথ দেখিয়েছেন,\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@mmmxi{''আর যিনি আমাকে আহার করান এবং পান করতে দেন,\qt@no{(79)}}
\qt@newcmd\qurantrans@bn@mmmxii{''আর যখন আমি রোগে ভোগি তখন তিনিই আমাকে আরোগ্য করেন,\qt@no{(80)}}
\qt@newcmd\qurantrans@bn@mmmxiii{''আর যিনি, আমার মৃত্যু ঘটাবেন তারপরে আমাকে পুনর্জীবন দেবেন,\qt@no{(81)}}
\qt@newcmd\qurantrans@bn@mmmxiv{''আর যিনি, আমি আশা করি, বিচারের দিনে আমার ভুলভ্রান্তিগুলো আমার জন্য ক্ষমা করে দেবেন।\qt@no{(82)}}
\qt@newcmd\qurantrans@bn@mmmxv{''আমার প্রভু! আমাকে জ্ঞান দান করো, আর আমাকে সৎকর্মীদের সঙ্গে যুক্ত করো।\qt@no{(83)}}
\qt@newcmd\qurantrans@bn@mmmxvi{''আর আমার জন্য পরবর্তীদের মধ্যে সদালাপন সৃষ্টি করো।\qt@no{(84)}}
\qt@newcmd\qurantrans@bn@mmmxvii{''আর আমাকে আনন্দময় উদ্যানের ওয়ারিশানের অন্তর্ভুক্ত করো।\qt@no{(85)}}
\qt@newcmd\qurantrans@bn@mmmxviii{''আর আমার পিতৃপুরুষকে পরিত্রাণ করো, কেননা সে তো পথভ্রান্তদের মধ্যেকার হয়ে গেছে।\qt@no{(86)}}
\qt@newcmd\qurantrans@bn@mmmxix{''আর আমাকে লাঞ্ছিত করো না তখন যেইদিন তাদের পুরুত্থিত করা হবে, --\qt@no{(87)}}
\qt@newcmd\qurantrans@bn@mmmxx{''যেদিন ধনসম্পদে কোনো কাজ দেবে না, সন্তানাদিতেও নয়,\qt@no{(88)}}
\qt@newcmd\qurantrans@bn@mmmxxi{''শুধু সে ব্যতীত যে নির্মল-নিস্পাপ অন্তর নিয়ে আল্লাহ্‌র কাছে আসবে।’’\qt@no{(89)}}
\qt@newcmd\qurantrans@bn@mmmxxii{আর স্বর্গোদ্যানকে ধর্মভীরুদের জন্য সন্নিকটে আনা হবে,\qt@no{(90)}}
\qt@newcmd\qurantrans@bn@mmmxxiii{আর দুযখকে খোলে দেওয়া হবে পথভ্রষ্টদের জন্য।\qt@no{(91)}}
\qt@newcmd\qurantrans@bn@mmmxxiv{আর তাদের বলা হবে -- ''কোথায় তারা যাদের তোমরা উপাসনা করতে --\qt@no{(92)}}
\qt@newcmd\qurantrans@bn@mmmxxv{''আল্লাহ্‌কে বাদ দিয়ে? তারা কি তোমাদের সাহায্য করছে, না তারা নিজেদেরই সাহায্য করতে পারছে?’’\qt@no{(93)}}
\qt@newcmd\qurantrans@bn@mmmxxvi{সুতরাং তাদের এর মধ্যে নিক্ষেপ করা হবে -- তাদের এবং পথভ্রান্তদের,\qt@no{(94)}}
\qt@newcmd\qurantrans@bn@mmmxxvii{আর ইবলীসের দলবল সকলকেও।\qt@no{(95)}}
\qt@newcmd\qurantrans@bn@mmmxxviii{তারা সেখানে তর্ক-বিতর্ক করতে করতে বলবে --\qt@no{(96)}}
\qt@newcmd\qurantrans@bn@mmmxxix{''আল্লাহ্‌র দিব্য, আমরা তো স্পষ্ট বিভ্রান্তিতেই ছিলাম, --\qt@no{(97)}}
\qt@newcmd\qurantrans@bn@mmmxxx{''যখন আমরা বিশ্বজগতের প্রভুর সঙ্গে তোমাদের এক-সমান গণ্য করেছিলাম।\qt@no{(98)}}
\qt@newcmd\qurantrans@bn@mmmxxxi{''আর অপরাধীরা ছাড়া অন্য কেউ আমাদের বিপথে নেয় নি।\qt@no{(99)}}
\qt@newcmd\qurantrans@bn@mmmxxxii{''সেজন্যে আমাদের জন্য সুপারিশকারীদের কেউ নেই,\qt@no{(100)}}
\qt@newcmd\qurantrans@bn@mmmxxxiii{''আর কোনো অন্তরঙ্গ বন্ধুও নেই।\qt@no{(101)}}
\qt@newcmd\qurantrans@bn@mmmxxxiv{''হায়! আমাদের জন্য যদি আকেরবার উপায় থাকত তাহলে আমরা মুমিনদের মধ্যেকার হতাম।’’\qt@no{(102)}}
\qt@newcmd\qurantrans@bn@mmmxxxv{নিঃসন্দেহ এতে তো এক নিদর্শন রয়েছে, কিন্ত তাদের অধিকাংশই বিশ্বাসী নয়।\qt@no{(103)}}
\qt@newcmd\qurantrans@bn@mmmxxxvi{আর নিঃসন্দেহ তোমার প্রভু, -- তিনিই তো মহাশক্তিশালী, অফুরন্ত ফলদাতা।\qt@no{(104)}}
\qt@newcmd\qurantrans@bn@mmmxxxvii{নূহের স্বজাতি রসূলগণকে প্রত্যাখ্যান করেছিল।\qt@no{(105)}}
\qt@newcmd\qurantrans@bn@mmmxxxviii{দেখো! তাদের ভাই নূহ তাদের বলেছিলেন -- ''তোমরা কি ধর্মপরায়ণতা অবলন্বন করবে না?\qt@no{(106)}}
\qt@newcmd\qurantrans@bn@mmmxxxix{''আমি নিশ্চয়ই তোমাদের জন্য একজন বিশ্বস্ত রসূল,\qt@no{(107)}}
\qt@newcmd\qurantrans@bn@mmmxl{''অতএব তোমরা আল্লাহ্‌কে ভয়-ভক্তি কর ও আমাকে মেনে চল।\qt@no{(108)}}
\qt@newcmd\qurantrans@bn@mmmxli{''আর আমি এর জন্য তোমাদের কাছে কোনো পারিশ্রমিক চাই না, আমার মজুরি তো বিশ্বজগতের প্রভুর কাছে ছাড়া অন্যত্র নয়।\qt@no{(109)}}
\qt@newcmd\qurantrans@bn@mmmxlii{''অতএব তোমরা আল্লাহ্‌কে ভক্তি-শ্রদ্ধা কর ও আমার আজ্ঞাপালন কর।’’\qt@no{(110)}}
\qt@newcmd\qurantrans@bn@mmmxliii{তারা বললে -- ''আমরা কি তোমার প্রতি ঈমান আনব যখন তোমাকে অনুসরণ করছে ইতরগোষ্ঠী?’’\qt@no{(111)}}
\qt@newcmd\qurantrans@bn@mmmxliv{তিনি বললেন -- ''তারা কী করত সে সন্বন্ধে আর আমার জ্ঞান থাকবার নয়।\qt@no{(112)}}
\qt@newcmd\qurantrans@bn@mmmxlv{''তাদের হিসাবপত্র আমার প্রভুর কাছে ছাড়া অন্যত্র নয়, যদি তোমরা বুঝতে!\qt@no{(113)}}
\qt@newcmd\qurantrans@bn@mmmxlvi{''আর আমি তো মুমিনদের তাড়িয়ে দেবার পাত্র নই।\qt@no{(114)}}
\qt@newcmd\qurantrans@bn@mmmxlvii{''আমি একজন স্পষ্ট সতর্ককারী ভিন্ন নই।’’\qt@no{(115)}}
\qt@newcmd\qurantrans@bn@mmmxlviii{তারা বললে -- ''হে নূহ! তুমি যদি না থামো তাহলে তোমাকে অবশ্যই প্রস্তরাঘাতে-নিহতদের অন্তর্ভুক্ত করা হবে।’’\qt@no{(116)}}
\qt@newcmd\qurantrans@bn@mmmxlix{তিনি বললেন -- ''আমার প্রভু! আমার স্বজাতি আমাকে প্রত্যাখ্যান করেছে।\qt@no{(117)}}
\qt@newcmd\qurantrans@bn@mmml{''অতএব আমার মধ্যে ও তাদের মধ্যে একটি সিদ্ধান্ত এনে মীমাংসা করে দাও, আর আমাকে ও আমার সাথে মুমিনদের যারা রয়েছে তাদের উদ্ধার করে দাও।’’\qt@no{(118)}}
\qt@newcmd\qurantrans@bn@mmmli{সুতরাং আমরা তাঁকে ও তাঁর সাথে যারা ছিল তাদের উদ্ধার করলাম বোঝাই করা জাহাজে।\qt@no{(119)}}
\qt@newcmd\qurantrans@bn@mmmlii{তারপর আমরা ডুবিয়ে দিলাম পরবর্তী অবশিষ্টদের।\qt@no{(120)}}
\qt@newcmd\qurantrans@bn@mmmliii{নিঃসন্দেহ এতে তো এক নিদর্শন রয়েছে, কিন্ত তাদের অধিকাংশই বিশ্বাসী নয়।\qt@no{(121)}}
\qt@newcmd\qurantrans@bn@mmmliv{আর নিঃসন্দেহ তোমার প্রভু, -- তিনিই তো মহাশক্তিশালী, অফুরন্ত ফলদাতা।\qt@no{(122)}}
\qt@newcmd\qurantrans@bn@mmmlv{আর 'আদ জাতি রসূলগণকে প্রত্যাখ্যান করেছিল।\qt@no{(123)}}
\qt@newcmd\qurantrans@bn@mmmlvi{দেখো, তাদের ভাই হূদ তাদের বলেছিলেন -- ''তোমরা কি ধর্মপরায়ণতা অবলন্বন করবে না?\qt@no{(124)}}
\qt@newcmd\qurantrans@bn@mmmlvii{''আমি নিশ্চয়ই তোমাদের জন্য একজন বিশ্বস্ত রসূল,\qt@no{(125)}}
\qt@newcmd\qurantrans@bn@mmmlviii{''অতএব তোমরা আল্লাহ্‌কে ভয় কর ও আমাকে মেনে চল।\qt@no{(126)}}
\qt@newcmd\qurantrans@bn@mmmlix{''আর আমি এ-জন্য তোমাদের কাছে কোনো মজুরি চাই না, আমার নজুরি তো ভূ-বিশ্বের প্রভুর কাছে ছাড়া অন্যত্র নয়।\qt@no{(127)}}
\qt@newcmd\qurantrans@bn@mmmlx{''তোমরা কি প্রত্যেক পাহাড়ে অযথা স্তম্ভ নির্মাণ করছ,\qt@no{(128)}}
\qt@newcmd\qurantrans@bn@mmmlxi{''আর দুর্গ তৈরি করছ যেন তোমরা চিরস্থায়ী হবে?’’\qt@no{(129)}}
\qt@newcmd\qurantrans@bn@mmmlxii{''আর যখন তোমরা পাকড়াও কর তখন জবরদস্তভাবে পাকড়াও করে থাক।\qt@no{(130)}}
\qt@newcmd\qurantrans@bn@mmmlxiii{''সুতরাং তোমরা আল্লাহ্‌কে ভক্তিশ্রদ্ধা কর ও আমার আজ্ঞাপালন কর।\qt@no{(131)}}
\qt@newcmd\qurantrans@bn@mmmlxiv{''আর ভয়-ভক্তি কর তাঁকে যিনি তোমাদের মদদ করেছেন যা তোমরা শিখেছ তা দিয়ে, --\qt@no{(132)}}
\qt@newcmd\qurantrans@bn@mmmlxv{''আর তিনি তোমাদের সাহায্য করেছেন গবাদি-পশু ও সন্তান-সন্ততি দিয়ে,\qt@no{(133)}}
\qt@newcmd\qurantrans@bn@mmmlxvi{''আর বাগানসমূহ ও ফোয়ারাগুলো দিয়ে।\qt@no{(134)}}
\qt@newcmd\qurantrans@bn@mmmlxvii{''নিঃসন্দেহ আমি আশংকা করছি তোমাদের উপরে এক মহাদিনের শাস্তির।’’\qt@no{(135)}}
\qt@newcmd\qurantrans@bn@mmmlxviii{তারা বললে -- ''তুমি উপদেশ দাও অথবা উপদেশদাতাদের মধ্যে তুমি নাই-বা হও আমাদের কাছে সবই সমান।\qt@no{(136)}}
\qt@newcmd\qurantrans@bn@mmmlxix{''এ তো সেকেলে আচরণ ছাড়া কিছুই নয়,\qt@no{(137)}}
\qt@newcmd\qurantrans@bn@mmmlxx{''আর আমরা শাস্তি পাবার নই।’’\qt@no{(138)}}
\qt@newcmd\qurantrans@bn@mmmlxxi{কাজেই তারা তাঁকে প্রত্যাখ্যান করল, সুতরাং আমরা তাদের ধ্বংস করেছিলাম। নিঃসন্দেহ এতে তো এক নিদর্শন রয়েছে, কিন্ত তাদের অধিকাংশই বিশ্বাসী নয়।\qt@no{(139)}}
\qt@newcmd\qurantrans@bn@mmmlxxii{আর নিঃসন্দেহ তোমার প্রভু, -- তিনিই তো মহাশক্তিশালী, অফুরন্ত ফলদাতা।\qt@no{(140)}}
\qt@newcmd\qurantrans@bn@mmmlxxiii{আর ছামূদ জাতি রসূলগণকে প্রত্যাখ্যান করেছিল।\qt@no{(141)}}
\qt@newcmd\qurantrans@bn@mmmlxxiv{দেখো, তাদের ভাই সালিহ্ তাদের বলেছিলেন -- ''তোমরা কি ধর্মভীরুতা অবলন্বন করবে না?\qt@no{(142)}}
\qt@newcmd\qurantrans@bn@mmmlxxv{''আমি নিশ্চয়ই তোমাদের জন্য একজন বিশ্বস্ত রসূল,\qt@no{(143)}}
\qt@newcmd\qurantrans@bn@mmmlxxvi{''অতএব তোমরা আল্লাহ্‌কে ভয়-ভক্তি কর ও আমাকে মেনে চল!\qt@no{(144)}}
\qt@newcmd\qurantrans@bn@mmmlxxvii{''আর আমি এর জন্য তোমাদের কাছে কোনো মজুরি চাই না, আমার মজুরি তো বিশ্বজগতের প্রভুর কাছে ছাড়া অন্যত্র নয়।\qt@no{(145)}}
\qt@newcmd\qurantrans@bn@mmmlxxviii{''এখানে যা আছে তাতে কি তোমাদের নিরাপদে রেখে দেওয়া হবে, --\qt@no{(146)}}
\qt@newcmd\qurantrans@bn@mmmlxxix{''বাগানসমূহে ও ফোয়ারাগুলোয়,\qt@no{(147)}}
\qt@newcmd\qurantrans@bn@mmmlxxx{''আর শস্যক্ষেত্রে ও খেজুর-বাগানে যার ছড়িগুলো ভারী?\qt@no{(148)}}
\qt@newcmd\qurantrans@bn@mmmlxxxi{''তোমরা তো পাহাড় খুদে বাড়িঘর তৈরি কর নিপুণভাবে।\qt@no{(149)}}
\qt@newcmd\qurantrans@bn@mmmlxxxii{''সুতরাং তোমরা আল্লাহ্‌কে ভক্তি-শ্রদ্ধা কর ও আমার আজ্ঞাপালন কর।\qt@no{(150)}}
\qt@newcmd\qurantrans@bn@mmmlxxxiii{''আর সীমালংঘনকারীদের নির্দেশ মেনে চল না, --\qt@no{(151)}}
\qt@newcmd\qurantrans@bn@mmmlxxxiv{''যারা দেশে অশান্তি সৃষ্টি করে আর শান্তিস্থাপন করে না।’’\qt@no{(152)}}
\qt@newcmd\qurantrans@bn@mmmlxxxv{তারা বললে -- ''তুমি তো নিঃসন্দেহ জাদুগ্রস্তদেরই একজন।\qt@no{(153)}}
\qt@newcmd\qurantrans@bn@mmmlxxxvi{''তুমি আমাদের মতো মানুষ ছাড়া আর কিছু নও, অতএব কোনো এক নিদর্শন নিয়ে এস যদি তুমি সত্যবাদীদের মধ্যেকার হও।’’\qt@no{(154)}}
\qt@newcmd\qurantrans@bn@mmmlxxxvii{তিনি বললেন -- ''এই একটি উষ্টী, তার জন্য পানীয় থাকবে আর তোমাদের জন্যও পানীয় থাকবে নির্ধারিত সময়ে।\qt@no{(155)}}
\qt@newcmd\qurantrans@bn@mmmlxxxviii{''আর তোমরা অনিষ্ট দিয়ে ওকে স্পর্শ করো না, পাছে এক ভয়ংকর দিনের শাস্তি তোমাদের পাকড়াও করে।’’\qt@no{(156)}}
\qt@newcmd\qurantrans@bn@mmmlxxxix{কিন্ত তারা এটিকে হত্যা করলে, পরিণামে সকাল-সকালই তারা পরিতাপকারী হল।\qt@no{(157)}}
\qt@newcmd\qurantrans@bn@mmmxc{সেজন্য শাস্তি তাদের পাকড়াও করল। নিঃসন্দেহ এতে তো এক নিদর্শন রয়েছে, কিন্ত তাদের অধিকাংশই বিশ্বাসী নয় ।\qt@no{(158)}}
\qt@newcmd\qurantrans@bn@mmmxci{আর নিঃসন্দেহ তোমার প্রভু -- তিনিই তো মহাশক্তিশালী, অফুরন্ত ফলদাতা।\qt@no{(159)}}
\qt@newcmd\qurantrans@bn@mmmxcii{আর লূতের লোকদল রসূলগণকে প্রত্যাখ্যান করেছিল।\qt@no{(160)}}
\qt@newcmd\qurantrans@bn@mmmxciii{দেখো! তাদের ভাই লূত তাদের বলেছিলেন -- ''তোমরা কি ধর্মভীরুতা অবলন্বন করবে না?\qt@no{(161)}}
\qt@newcmd\qurantrans@bn@mmmxciv{''আমি নিশ্চয়ই তোমাদের জন্য একজন বিশ্বস্ত রসূল,\qt@no{(162)}}
\qt@newcmd\qurantrans@bn@mmmxcv{''অতএব তোমরা আল্লাহ্‌কে ভয়ভক্তি কর ও আমাকে মেনে চল।\qt@no{(163)}}
\qt@newcmd\qurantrans@bn@mmmxcvi{''আর আমি এর জন্য তোমাদের কাছে কোনো মজুরি চাই না, আমার মজুরি তো বিশ্বজগতের প্রভুর কাছে ছাড়া অন্যত্র নয়।\qt@no{(164)}}
\qt@newcmd\qurantrans@bn@mmmxcvii{''তোমরা কি মানুষজাতীর মধ্যে পুরুষদের কাছেই এসে থাক,\qt@no{(165)}}
\qt@newcmd\qurantrans@bn@mmmxcviii{''আর পরিত্যাগ করছ তোমাদের স্ত্রীদের যাদের তোমাদের প্রভু তোমাদের জন্য সৃষ্টি করেছেন? না, তোমরা তো সীমালংঘনকারী জাতি।’’\qt@no{(166)}}
\qt@newcmd\qurantrans@bn@mmmxcix{তারা বললে -- ''হে লূত! তুমি যদি বিরত না হও তাহলে তুমি নিশ্চয়ই নির্বাসিতদের অন্তর্ভুক্ত হবে।’’\qt@no{(167)}}
\qt@newcmd\qurantrans@bn@mmmc{তিনি বললেন -- ''আমি অবশ্যই তোমাদের আচরণকে ঘৃণাকারীদেরই একজন।\qt@no{(168)}}
\qt@newcmd\qurantrans@bn@mmmci{''আমার প্রভু! তারা যা করে তা থেকে আমাকে ও আমার পরিবার পরিজনকে উদ্ধার করো।’’\qt@no{(169)}}
\qt@newcmd\qurantrans@bn@mmmcii{সুতরাং আমরা তাঁকে ও তাঁর পরিবারবর্গকে একই সঙ্গে উদ্ধার করলাম, --\qt@no{(170)}}
\qt@newcmd\qurantrans@bn@mmmciii{এক বুড়ীকে ছাড়া, যে পেছনে-পড়ে-থাকাদের মধ্যে রয়েছিল।\qt@no{(171)}}
\qt@newcmd\qurantrans@bn@mmmciv{তারপর আমরা অন্যান্যদের বিধ্বংস করেছিলাম।\qt@no{(172)}}
\qt@newcmd\qurantrans@bn@mmmcv{আর তাদের উপরে আমরা বর্ষণ করেছিলাম এক বৃষ্টি, -- সুতরাং কত মন্দ এই বৃষ্টি সতককৃতদের জন্য।\qt@no{(173)}}
\qt@newcmd\qurantrans@bn@mmmcvi{নিঃসন্দেহ এতে তো এক নিদর্শন রয়েছে, কিন্ত তাদের অধিকাংশই বিশ্বাসী নয়।\qt@no{(174)}}
\qt@newcmd\qurantrans@bn@mmmcvii{আর নিঃসন্দেহ তোমার প্রভু, -- তিনিই তো মহাশক্তিশালী, অফুরন্ত ফলদাতা।\qt@no{(175)}}
\qt@newcmd\qurantrans@bn@mmmcviii{আইকার অধিবাসীরা রসূলগণকে প্রত্যাখ্যান করেছিল।\qt@no{(176)}}
\qt@newcmd\qurantrans@bn@mmmcix{দেখো, শোআইব তাদের বলেছিলেন -- ''তোমরা কি ধর্মপরায়ণতা অবলন্বন করবে না?\qt@no{(177)}}
\qt@newcmd\qurantrans@bn@mmmcx{''আমি নিশ্চয়ই তোমাদের জন্য একজন বিশ্বস্ত রসূল,\qt@no{(178)}}
\qt@newcmd\qurantrans@bn@mmmcxi{''অতএব তোমরা আল্লাহ্‌কে ভয়ভক্তি কর ও আমাকে মেনে চল।\qt@no{(179)}}
\qt@newcmd\qurantrans@bn@mmmcxii{''আর আমি এর জন্য তোমাদের কাছে কোনো পারিশ্রমিক চাই না, আমার পারিশ্রমিক তো বিশ্বজগতের প্রভুর কাছে ছাড়া অন্যত্র নয়।\qt@no{(180)}}
\qt@newcmd\qurantrans@bn@mmmcxiii{''মাপে পুরোমাত্রায় দেবে, আর তোমরা মাপে-কম-করা লোকদের অন্তর্ভুক্ত হয়ো না।\qt@no{(181)}}
\qt@newcmd\qurantrans@bn@mmmcxiv{''সঠিক পাল্লায় ওজন করো।\qt@no{(182)}}
\qt@newcmd\qurantrans@bn@mmmcxv{''আর লোকজনের ক্ষতিসাধন করো না তাদের বিষয়বস্তু সন্বন্ধে, আর দুনিয়াতে বিপর্যয় ঘটিয়ো না অনিষ্টাচরণ ক’রে।\qt@no{(183)}}
\qt@newcmd\qurantrans@bn@mmmcxvi{''আর ভয়-ভক্তি করো তাঁকে যিনি তোমাদের সৃষ্টি করেছেন এবং পূর্ববর্তী লোকদেরও।’’\qt@no{(184)}}
\qt@newcmd\qurantrans@bn@mmmcxvii{তারা বললে -- ''তুমি তো আলবৎ জাদুগ্রস্তদের মধ্যেকার,’’\qt@no{(185)}}
\qt@newcmd\qurantrans@bn@mmmcxviii{''আর তুমি আমাদের ন্যায় একজন মানুষ ছাড়া আর কিছুই নও, আর আমরা তোমাকে মিথ্যাবাদীদের একজন বলেই তো গণনা করি।\qt@no{(186)}}
\qt@newcmd\qurantrans@bn@mmmcxix{''অতএব আকাশের একটি টুকরো আমাদের উপরে ফেলে দাও, যদি তুমি সত্যবাদীদের মধ্যেকার হও।’’\qt@no{(187)}}
\qt@newcmd\qurantrans@bn@mmmcxx{তিনি বললেন -- ''আমার প্রভু ভাল জানেন কী তোমরা কর।’’\qt@no{(188)}}
\qt@newcmd\qurantrans@bn@mmmcxxi{কিন্ত তারা তাঁকে প্রত্যাখ্যান করল, সেজন্যে এক অন্ধকার দিনের শাস্তি তাদের পাকড়াও করল। নিঃসন্দেহ এটি ছিল এক ভীষণ দিনে শাস্তি।\qt@no{(189)}}
\qt@newcmd\qurantrans@bn@mmmcxxii{নিঃসন্দেহ এতে তো এক নিদর্শন রয়েছে, কিন্ত তাদের অধিকাংশই বিশ্বাসী নয়।\qt@no{(190)}}
\qt@newcmd\qurantrans@bn@mmmcxxiii{আর নিঃসন্দেহ তোমার প্রভু, -- তিনিই তো মহাশক্তিশালী, অফুরন্ত ফলদাতা।\qt@no{(191)}}
\qt@newcmd\qurantrans@bn@mmmcxxiv{আর নিঃসন্দেহ এটি নিশ্চয়ই বিশ্বজগতের প্রভুর তরফ থেকে এক অবতারণ।\qt@no{(192)}}
\qt@newcmd\qurantrans@bn@mmmcxxv{রুহুল আমীন এটি নিয়ে অবতরণ করেছেন --\qt@no{(193)}}
\qt@newcmd\qurantrans@bn@mmmcxxvi{তোমার হৃদয়ের উপরে, যেন তুমি সতর্ককারীদের অন্যতম হতে পার, --\qt@no{(194)}}
\qt@newcmd\qurantrans@bn@mmmcxxvii{সুস্পষ্ট আরবী ভাষায়।\qt@no{(195)}}
\qt@newcmd\qurantrans@bn@mmmcxxviii{আর নিঃসন্দেহ এটি পূর্ববর্তীদের ধর্মগ্রন্থে রয়েছে ।\qt@no{(196)}}
\qt@newcmd\qurantrans@bn@mmmcxxix{একি তাদের জন্য একটি নিদর্শন নয় যে ইসরাইলের বংশধরদের পন্ডিতগণ এটি জানে?\qt@no{(197)}}
\qt@newcmd\qurantrans@bn@mmmcxxx{আর আমরা যদি এটি অবতারণ করতাম কোনো ভিন্ন দেশীয়ের কাছে,\qt@no{(198)}}
\qt@newcmd\qurantrans@bn@mmmcxxxi{আর সে এটি তাদের কাছে পাঠ করত, তাহলে তারা তাতে বিশ্বাসভাজন হতো না।\qt@no{(199)}}
\qt@newcmd\qurantrans@bn@mmmcxxxii{এইভাবেই আমরা এটিকে প্রবেশ করিয়েছি অপরাধীদের অন্তরে।\qt@no{(200)}}
\qt@newcmd\qurantrans@bn@mmmcxxxiii{তারা এতে বিশ্বাস করবে না যে পর্যন্ত না তারা মর্মন্তুদ শাস্তি প্রত্যক্ষ করে।\qt@no{(201)}}
\qt@newcmd\qurantrans@bn@mmmcxxxiv{সুতরাং এ তাদের কাছে আসবে আকস্মিকভাবে, আর তারা টের পাবে না।\qt@no{(202)}}
\qt@newcmd\qurantrans@bn@mmmcxxxv{তখন তারা বলবে -- ''আমরা কি অবকাশ প্রাপ্ত হব?’’\qt@no{(203)}}
\qt@newcmd\qurantrans@bn@mmmcxxxvi{কী, তারা কি এখনও আমাদের শাস্তি সন্বন্ধে তাড়াতাড়ি করতে চায়?\qt@no{(204)}}
\qt@newcmd\qurantrans@bn@mmmcxxxvii{তুমি কি তবে লক্ষ্য করেছ -- যদি আমরা তাদের বহু বছর ভোগ-বিলাস করতে দিই।\qt@no{(205)}}
\qt@newcmd\qurantrans@bn@mmmcxxxviii{তারপর তাদের কাছে এসে পড়ে যা তাদের ওয়াদা করা হয়েছিল --\qt@no{(206)}}
\qt@newcmd\qurantrans@bn@mmmcxxxix{তবু যা তাদের উপভোগ করতে দেওয়া হয়েছিল তা তাদের কোনো কাজে আসবে না?\qt@no{(207)}}
\qt@newcmd\qurantrans@bn@mmmcxl{আর আমরা কোনো জনপদ ধ্বংস করি নি যার সতর্ককারী ছিল না।\qt@no{(208)}}
\qt@newcmd\qurantrans@bn@mmmcxli{স্মারকগ্রন্থ, আর আমরা কখনও অন্যায়কারী নই।\qt@no{(209)}}
\qt@newcmd\qurantrans@bn@mmmcxlii{আর শয়তানরা এ নিয়ে অবতরণ করে নি,\qt@no{(210)}}
\qt@newcmd\qurantrans@bn@mmmcxliii{আর তাদের পক্ষে এ সমীচীন নয়, আর তারা সামর্থ্যও রাখে না।\qt@no{(211)}}
\qt@newcmd\qurantrans@bn@mmmcxliv{নিঃসন্দেহ শুনবার ক্ষেত্রে তারা তো অপারগ।\qt@no{(212)}}
\qt@newcmd\qurantrans@bn@mmmcxlv{সুতরাং তুমি আল্লাহ্‌র সাথে অন্য উপাস্যকে ডেকো না, পাছে তুমি শাস্তিপ্রাপ্তদের মধ্যেকার হয়ে যাও।\qt@no{(213)}}
\qt@newcmd\qurantrans@bn@mmmcxlvi{আর তোমার নিকটতম আ‌ত্মীয়দের সাবধান করে দাও,\qt@no{(214)}}
\qt@newcmd\qurantrans@bn@mmmcxlvii{আর তোমার ডানা আনত করো মুমিনদের যারা তোমাকে অনুসরণ করে তাদের প্রতি।\qt@no{(215)}}
\qt@newcmd\qurantrans@bn@mmmcxlviii{কিন্ত তারা যদি তোমার অবাধ্যতা করে তবে বলো -- ''আমি আলবৎ দায়মুক্ত তোমরা যা কর সে সন্বন্ধে।’’\qt@no{(216)}}
\qt@newcmd\qurantrans@bn@mmmcxlix{আর তুমি নির্ভর কর মহাশক্তিশালী, অফুরন্ত ফলদাতার উপরে, --\qt@no{(217)}}
\qt@newcmd\qurantrans@bn@mmmcl{যিনি তোমাকে দেখেন যখন তুমি দাঁড়াও,\qt@no{(218)}}
\qt@newcmd\qurantrans@bn@mmmcli{এবং সিজদাকারীদের সঙ্গে তোমার উঠা-বসা করতে।\qt@no{(219)}}
\qt@newcmd\qurantrans@bn@mmmclii{নিঃসন্দেহ তিনি -- তিনিই সর্বশ্রোতা, সর্বজ্ঞাতা।\qt@no{(220)}}
\qt@newcmd\qurantrans@bn@mmmcliii{আমি কি তোমাদের জানাব কাদের উপরে শয়তানরা অবতরণ করে?\qt@no{(221)}}
\qt@newcmd\qurantrans@bn@mmmcliv{তারা অবতরণ করে প্রত্যেক মিথ্যাবাদী পাপাচারীর উপরে,\qt@no{(222)}}
\qt@newcmd\qurantrans@bn@mmmclv{তারা কান পাতে, আর তাদের অধিকাংশই মিথ্যাবাদী।\qt@no{(223)}}
\qt@newcmd\qurantrans@bn@mmmclvi{আর কবিগণ, -- তাদের অনুসরণ করে ভ্রান্তপথগামীরা।\qt@no{(224)}}
\qt@newcmd\qurantrans@bn@mmmclvii{তুমি কি দেখ না যে তারা নিঃসন্দেহ প্রত্যেক উপত্যকায় লক্ষ্যহীনভাবে ঘুরে বেড়ায়,\qt@no{(225)}}
\qt@newcmd\qurantrans@bn@mmmclviii{আর তারা নিশ্চয়ই তাই বলে যা তারা করে না? --\qt@no{(226)}}
\qt@newcmd\qurantrans@bn@mmmclix{তবে তারা ব্যতীত যারা ঈমান আনে ও সৎকাজ করে, এবং আল্লাহ্‌কে খুব ক’রে স্মরণ করে, আর অত্যাচারিত হবার পরে প্রতিরক্ষা করে। আর যারা অন্যায় করে তারা অচিরেই জানতে পারবে কোন বিপর্যয়ের মধ্যে তারা প্রত্যাবর্তন করছে।\qt@no{(227)}}
\qt@newcmd\qurantrans@bn@mmmclx{\basmalahbn ত্বা, সীন। এ-সব হচ্ছে কুরআনের তথা সুস্পষ্ট গ্রন্থের বাণীসমূহ, --\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmclxi{মুমিনদের জন্য পথ-নির্দেশক এবং সুসংবাদবাহক, --\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmclxii{যারা নামায কায়েম করে ও যাকাত প্রদান করে, আর তারা আখেরাত সন্বন্ধে স্বয়ং দৃঢ়বিশ্বাস রাখে।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmclxiii{নিঃসন্দেহ যারা পরকালে বিশ্বাস করে না তাদের ক্রিয়াকর্মকে আমরা তাদের জন্য চিত্তাকর্যক করেছি, ফলে তারা অন্ধভাবে ঘুরে বেড়ায়।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmclxiv{এরাই তারা যাদের জন্য রয়েছে এক কষ্টকর শাস্তি, আর পরকালে তারা খোদ হবে সর্বাধিক ক্ষতিগ্রস্ত।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmclxv{আর অবশ্য তুমি, -- তোমাকেই তো কুরআন পাওয়ানো হয়েছে পরম জ্ঞানী সর্বজ্ঞাতার তরফ থেকে।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmclxvi{স্মরণ করো! মূসা তাঁর পরিজনকে বললেন -- ''নিঃসন্দেহ আমি আগুনের আভাস পাচ্ছি, আমি এখনি সেখান থেকে তোমাদের কাছে কোনো খবর নিয়ে আসছি, অথবা তোমাদের জন্য জ্বলন্ত আঙটা নিয়ে আসছি যাতে তোমরা নিজেদের গরম করতে পার।’’\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmclxvii{অতঃপর যখন তিনি এর কাছে এলেন তখন আওয়াজ হলো এই বলে -- ''ধন্য সেইজন যে আগুনের ভেতরে এবং যে এর আশেপাশে রয়েছে। আর সকল মহিমা বিশ্বজগতের প্রভু আল্লাহ্‌র!\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmclxviii{''হে মূসা! নিঃসন্দেহ এই তো আমি আল্লাহ্ -- মহাশক্তিশালী, পরমজ্ঞানী।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmclxix{''আর তোমার লাঠি ছুঁড়ে মার।’’ তারপর যখন তিনি এটিকে দেখলেন দৌড়ছে -- যেন এটি একটি সাপ, তিনি তখন পেছন দিকে ছুটলেন আর ঘুরে দেখলেন না। ''হে মূসা, ভয় করো না, নিঃসন্দেহ রসূলগণ আমার সামনে ভয় করে না,\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmclxx{''সে ব্যতীত যে অন্যায় করেছে তারপর মন্দ কাজের পরে বদলা করে ভাল কাজ, তাহলে আমি নিশ্চয়ই পরিত্রাণ কারী, অফুরন্ত ফলদাতা।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmclxxi{''আর তোমার হাত তোমার পকেটে ঢোকাও, এটি বেরিয়ে আসবে সাদা হয়ে কোনো দোষত্রুটি ছাড়া, -- ফিরআউন ও তার লোকদলের কাছে নয়টি নিদর্শনের অন্তর্গত। নিঃসন্দেহ তারা হচ্ছে সীমালংঘনকারী জাতি।’’\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmclxxii{তারপর যখন আমাদের নিদর্শনগুলো তাদের কাছে এল দর্শনীয়ভাবে, তারা বললে -- ''এ তো পরিস্কার জাদু।’’\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmclxxiii{আর তারা এসব প্রত্যাখ্যান করল অন্যায়ভাবে ও উদ্ধতভাবে, যদিও তাদের অন্তর এগুলোতে নিঃসংশয় ছিল। অতএব চেয়ে দেখো -- কেমন হয়েছিল বিপর্যয় সৃষ্টিকারীদের পরিণাম।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmclxxiv{আর অবশ্যই ইতিপূর্বে আমরা দাউদ ও সুলাইমানকে জ্ঞান দান করেছিলাম, আর তাঁরা উভয়ে বলেছিলেন -- ''সমস্ত প্রশংসা আল্লাহ্‌র জন্য যিনি আমাদের শ্রেষ্ঠত্ব দিয়েছেন তাঁর বহুসংখ্যক মুমিন বান্দাদের উপরে।’’\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmclxxv{আর সুলাইমান দাউদকে উত্তরাধিকার করলেন এবং বললেন -- ''ওহে জনগণ, আমাদের পক্ষি-বিজ্ঞান শেখানো হয়েছে, আর সব জিনিস থেকে আমাদের দেওয়া হয়েছে। নিঃসন্দেহ এটি -- এ অবশ্যই সুস্পষ্ট অনুগ্রহসামগ্রী।’’\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmclxxvi{আর সুলাইমানের সামনে সমবেত করা হয়েছিল তাঁর বাহিনীকে -- জিন ও মানুষ ও পাখিদের থেকে, আর তাদের কুচকাওয়াজ করানো হলো।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmclxxvii{তারপর যখন তাঁরা নমলদের উপত্যকায় এসেছিলেন তখন একজন নমল বললে -- ''ওহে নমলজাতি! তোমাদের বাড়িঘরে ঢোকে যাও, সুলাইমান ও তাঁর বাহিনী যেন তোমাদের পিষে না ফেলে যদিবা তারা বুঝতে না পারে।’’\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmclxxviii{সুতরাং তিনি তার কথায় বিস্মিত হয়ে মুচকি হাসলেন ও বললেন -- ''আমার প্রভু! তুমি আমাকে অনুমতি দাও যেন তুমি আমার প্রতি ও আমার পিতামাতার প্রতি যে নিয়ামত অর্পণ করেছ তোমার সেই আশিসের জন্য আমি কৃতজ্ঞতা জানাতে পারি, আর আমি যেন সৎকর্ম করতে পারি যা তুমি পছন্দ কর, আর তোমার অনুগ্রহ বশতঃ আমাকে তোমার সৎপথাবলন্বী বান্দাদের অন্তর্ভূক্ত করো।’’\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmclxxix{আর তিনি পাখিদের পর্যবেক্ষণ করলেন, তখন বললেন -- ''একি! হুদহুদকে দেখছি না কেন? সে কি গরহাজিরদের একজন?\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmclxxx{''আমি অবশ্যই তাকে কঠিন শাস্তি দেব, অথবা আমি নিশ্চয়ই তাকে জবাই করব, অথবা তাকে অবশ্যই আমার কাছে আসতে হবে সুস্পষ্ট অজুহাত নিয়ে।’’\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmclxxxi{তারপর তিনি অনতিবিলন্বকাল অপেক্ষা করলেন তখন সে বললে, ''আমি তার খোঁজ পেয়েছি যে-সন্বন্ধে আপনি অবগত নন, আর আমি সাবা’ থেকে আপনার কাছে আসছি সঠিক বার্তা নিয়ে।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmclxxxii{''আমি নিশ্চয়ই এক নারীকে দেখতে পেলাম তাদের উপর রাজত্ব করছে, আর তাকে সব-কিছু থেকে দেওয়া হয়েছে, আর তার রয়েছে এক মস্তবড় সিংহাসন।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmclxxxiii{''আর আমি তাকে ও তার লোকদের দেখতে পেলাম তারা আল্লাহ্‌কে বাদ দিয়ে সূর্যকে সিজদা করছে, আর শয়তান তাদের জন্য তাদের ক্রিয়াকলাপ চিত্তাকর্ষক করেছে, কাজেই পথ থেকে সে তাদের সরিয়ে রেখেছে, সুতরাং তারা সৎপথ পাচ্ছে না, --\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmclxxxiv{''তাইতো তারা আল্লাহ্‌কে সিজদা করে না যিনি মহাকাশমন্ডলী ও পৃথিবীর গুপ্ত বিষয়বস্তু প্রকাশ করে দেন, আর যিনি জানেন যা তোমরা লুকিয়ে রাখ এবং যা প্রকাশ কর।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmclxxxv{''আল্লাহ্‌, তিনি ছাড়া অন্য উপাস্য নেই, যিনি মহান আরশের অধিপতি।’’\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmclxxxvi{তিনি বললেন -- ''আমরা শীঘ্রই দেখব তুমি কি সত্য বলছ, না তুমি মিথ্যাবাদীদের মধ্যেকার?\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmclxxxvii{''আমার এই লিপি নিয়ে যাও আর এটি তাদের কাছে অর্পণ কর, তারপর তাদের থেকে চলে এস, আর দেখ কি তারা ফেরত পাঠায়।’’\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmclxxxviii{সে বললে -- ''ওহে প্রধানগণ! নিঃসন্দেহ আমার কাছে এক সম্মানিত লিপি পাঠানো হয়েছে।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmclxxxix{''এটি আলবৎ সুলাইমানের কাছে থেকে, আর এটি প্রধানতঃ এই -- 'আল্লাহ্‌র নাম নিয়ে, যিনি রহমান, রহীম, --\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmcxc{''আমার বিরুদ্ধে যেন হামবড়াই কর না, আর আমার কাছে এস মুসলিম হয়ে’।’’\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmcxci{সে বললে -- ''ওহে প্রধানগণ! আমার করণীয় সন্বন্ধে আমাকে উপদেশ দাও, আমি কোনো ব্যাপারে সিদ্ধান্ত গ্রহণকারী হই না যে পর্যন্ত না তোমরা আমার সাক্ষাতে থাকো।’’\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmcxcii{তারা বললে -- ''আমরা শক্তির অধিকারী এবং প্রবল বিক্রমেরও অধিকারী, আর হুকুম আপনারই কাছে, অতএব ভেবে দেখুন কী আপনি হুকুম করবেন।’’\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmcxciii{সে বললে -- ''নিঃসন্দেহ রাজা-বাদশারা যখন কোনো জনপদে প্রবেশ করে তখন তাকে বিপর্যস্ত করে দেয় এবং তার বাসিন্দাদের শ্রেষ্ঠ মর্যাদাসম্পন্নদের বানিয়ে দেয় চরম লাঞ্ছিত, আর এইভাবেই তারা করে থাকে।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmcxciv{''আর আমি অবশ্য তাদের কাছে পাঠাতে যাচ্ছি একটি উপহার, তারপর দেখতে চাই দূতরা কী নিয়ে ফেরে।’’\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmcxcv{তারপর যখন সুলাইমানের কাছে সে এল তখন তিনি বললেন -- ''কি! তোমরা কি আমাকে মাল-আসবাব দিয়ে মদদ করতে চাও? কিন্ত আল্লাহ্ আমাকে যা দিয়েছেন তা তোমাদের তিনি যা দিয়েছেন তার চাইতে শ্রেষ্ঠ। না, তোমাদের উপহার সন্বন্ধে তোমরাই গর্ববোধ করছ।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmcxcvi{''তাদের কাছে ফিরে যাও, আমরা অবশ্যই তাদের কাছে আসব সৈন্যবাহিনী নিয়ে যার মোকাবিলা করার ক্ষমতা তাদের নেই, আর আমরা অবশ্যই সেখান থেকে তাদের বহিস্কার করব লাঞ্ছনার সাথে, আর তারা বনবে ছোটলোক।’’\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmcxcvii{তিনি বললেন -- ''ওহে প্রধানগণ! তোমাদের মধ্যে কে আমার কাছে নিয়ে আসবে তার সিংহাসন আমার কাছে মুসলিমরূপে তাদের আসবার পূর্বে?’’\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmcxcviii{জিনদের এক জোয়ান বললে -- ''আমি এটি আপনার কাছে নিয়ে আসব আপনার আসন ছেড়ে ওঠবার আগেই, আর আমি অবশ্যই এ ব্যাপারে বিশেষ ক্ষমতাবান, বিশ্বস্ত।’’\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmcxcix{যার কাছে ধর্মগ্রন্থের জ্ঞান রয়েছে এমন একজন বললে -- ''আমি এটি আপনার কাছে নিয়ে আসব আপনার দৃষ্টি আপনার কাছে ফিরে আসার আগেই।’’ তারপর যখন তিনি এটি দেখতে পেলেন তাঁর পার্শ্বে স্থাপিত হয়েছে তখন বললেন -- ''এ আমার প্রভুর করুণাভান্ডার থেকে, যাতে তিনি আমাকে পরীক্ষা ক’রে দেখতে পারেন আমি কৃতজ্ঞতা জ্ঞাপন করি, না অকৃতজ্ঞতা পোষণ করি। আর যে কেউ কৃতজ্ঞতা প্রকাশ করে সে অবশ্যই কৃতজ্ঞতা জানায় তার নিজের জন্য, আর যে কেউ অকৃতজ্ঞতা পোষণ করে -- আমার প্রভু নিশ্চয়ই মহাবিত্তবান, মহানুভব।’’\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmcc{তিনি বললেন -- ''তার সিংহাসনখানা তারজন্য বদলে দাও, আমরা দেখতে চাই সে সৎপথ অবলন্বন করে, না সে তাদের দলের হয় যারা সৎপথে চলে না।’’\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmcci{তারপর যখন সে এল তখন বলা হ’ল -- ''তোমার সিংহাসন কি এই রকমের?’’ সে বললে, ''এটিই যেন তাই।’’ ''আর আমাদের জ্ঞান দেওয়া হয়েছে তার আগে, আর আমরা মুসলিম ছিলাম।’’\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmccii{আর আল্লাহ্‌কে বাদ দিয়ে সে যার পূজা করত তাই তাকে নিবৃত্ত করেছিল, নিঃসন্দেহ সে ছিল অবিশ্বাসী লোকদের মধ্যেকার।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmcciii{তাকে বলা হ’ল -- ''দরবার-ঘরে প্রবেশ করো।’’ কিন্ত যখন সে তা দেখল সে এটিকে মনে করল এক বিশাল জলাশয়, আর সে তার কাপড় টেনে তুললো। তিনি বললেন -- ''এটিই দরবার ঘর, মসৃণ করা হয়েছে কাচ দিয়ে ।’’ সে বললে -- ''আমার প্রভু! আমি নিঃসন্দেহ আমার আ‌ত্মার প্রতি অন্যায় করেছি, আর আমি সুলাইমানের সঙ্গে বিশ্বজগতের প্রভু আল্লাহ্‌র প্রতি আত্নসমর্পণ করছি।’’\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmcciv{আর আমরা অবশ্যই ছামূদ জাতির কাছে তাদের ভাই সালিহ্‌কে পাঠিয়েছিলাম এই বলে -- ''তোমরা আল্লাহ্‌র এবাদত কর।’’ কিন্তু দেখো! তারা দুই দল হয়ে গেল -- পরস্পরে বিবাদ করতে লাগল।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmmccv{তিনি বললেন -- ''হে আমার স্বজাতি, তোমরা কেন মন্দকে ত্বরান্বিত করতে চাইছ ভালর আগে? কেন তোমরা আল্লাহর পরিত্রাণ খোঁজো না যাতে তোমাদের করুণা করা হয়?’’\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmmccvi{তারা বললে -- ''তোমাকে ও তোমার সঙ্গে যারা আছে তাদের আমরা অমঙ্গলময় মনে করি।’’ তিনি বললেন -- তোমাদের অমঙ্গল-কামনা আল্লাহ্‌র এখতিয়ারে, বস্তুতঃ তোমরা হচ্ছ এক গোষ্ঠী যাদের পরীক্ষা করা হচ্ছে।’’\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmmccvii{আর সে শহরে ছিল নয়জন লোক যারা দেশে গন্ডগোল সৃষ্টি করত, আর তারা শান্তি স্থাপন করত না।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmmccviii{তারা বললে -- ''আল্লাহ্‌র নামে তোমরা কসম খাও যে আমরা অবশ্যই তাকে ও তার পরিজনবর্গকে রাত্রিকালে আক্রমণ করব, তারপর তার দাবিদারকে আমরা আলবৎ বলব -- 'আমরা তার পরিজনবর্গের হত্যাকান্ড দেখতে পাই নি, আর আমরা তো নিঃসন্দেহ সত্যবাদী।’’\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmmccix{আর তারা এক ষড়যন্ত্রের চক্রান্ত করেছিল, আর আমারও এক পরিকল্পনা উদ্ভাবন করেছিলাম, কিন্ত তারা বুঝতেও পারে নি।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmmccx{অতএব চেয়ে দেখো, তাদের ষড়যন্ত্রের পরিণাম কী হয়েছিল, -- নিঃসন্দেহ আমরা তাদের এবং তাদের স্বজাতিকে সাকল্যে ধ্বংস করেছিলাম।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmmccxi{সুতরাং এই তো তাদের ঘরবাড়িসব -- ভেঙেচুরে রয়েছে যেহেতু তারা অন্যায়াচরণ করেছিল। নিঃসন্দেহ এতে তো এক নিদর্শন রয়েছে সেই লোকদের জন্য যারা জানে।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmmccxii{আর আমরা উদ্ধার করেছিলাম তাদের যারা ঈমান এনেছিল ও ভয়ভক্তি করে চলত।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmmccxiii{আর লূত, স্মরণ কর! তিনি তাঁর জাতিকে বলেছিলেন -- ''তোমরা কি অশ্লীলতা করতেই থাকবে, অথচ তোমরা দেখতে পাচ্ছ?\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmmccxiv{''তোমরা কি নারীদের বাদ দিয়ে কামতৃপ্তির জন্য পুরুষেই উপগত হবে? না, তোমরা একটি সম্প্রদায় যারা মূর্খামি করছ।’’\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mmmccxv{কিন্ত তাঁর লোকদের জবাব আর কিছু ছিল না এই ভিন্ন যে তারা বললে -- ''তোমাদের জনপদ থেকে লূতের পরিজনবর্গকে বের করে দাও, এরা তো এমন লোক যারা পবিত্র সাজতে চায়!’’\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mmmccxvi{আমরা তখন তাঁকে ও তাঁর পরিজনবর্গকে উদ্ধার করেছিলাম তাঁর স্ত্রী ব্যতীত, আমরা তাকে ধার্য করেছিলাম পেছনে রয়ে যাওয়াদের অন্তর্ভুক্ত।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mmmccxvii{আর তাদের উপরে আমরা বর্ষণ করেছিলাম এক বৃষ্টি, অতএব বড় মন্দ ছিল সতর্কীকৃতদের বর্ষণ!\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mmmccxviii{বলো -- ''সমস্ত প্রশংসা আল্লাহ্‌র, আর শান্তি তাঁর বান্দাদের উপরে যাদের তিনি মনোনীত করেছেন। আল্লাহ্ শ্রেষ্ঠ, না যাদের তারা শরিক করেছে?\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mmmccxix{আচ্ছা! কে মহাকাশমন্ডলী ও পৃথিবী সৃষ্টি করেছেন, আর তোমাদের জন্য আকাশ থেকে পানি বর্ষণ করেন? তারপর আমরা তা দিয়ে উৎপন্ন করি শোভাময় বাগানসমূহ, -- তোমাদের পক্ষে এটি সম্ভবপর নয় যে তোমরা এগুলোর গাছপালা বাড়িয়ে তুলবে। আল্লাহ্‌র সঙ্গে কি অন্য উপাস্য আছে? তবুও তারা সত্য ত্যাগ করে এমন এক জাতি।\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mmmccxx{আচ্ছা! কে পৃথিবীটাকে আবাসস্থল করেছেন, আর এর ফাঁক-চিড়গুলোকে বানিয়েছেন নদীনালা, আর এর জন্য দাঁড় করিয়েছেন পাহাড়-পর্বত, আর দুটি সমুদ্রের মধ্যখানে তৈরি করেছেন এক ব্যবধান? আল্লাহ্‌র সঙ্গে কি অন্য উপাস্য আছে? তবুও তাদের অধিকাংশই জানে না।\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mmmccxxi{আচ্ছা! কে সাড়া দেন বিপদগ্রস্তের প্রতি যখন সে তাঁকে ডাকে আর বিপদ-আপদ দূর করে দেন, আর তোমাদের বানিয়েছেন পৃথিবীতে প্রতিনিধি? আল্লাহ্‌র সঙ্গে কি অন্য উপাস্য আছে? অল্পই যা তোমরা মনোনিবেশ কর।\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mmmccxxii{আচ্ছা! কে তোমাদের পথ দেখিয়ে দেন স্থলদেশের ও সমুদ্রের অন্ধকারে, আর কে পাঠিয়ে থাকেন বায়ুপ্রবাহ তাঁর করুণা-বিজড়িত সুসংবাদদাতারূপে? আল্লাহ্‌র সঙ্গে কি অন্য উপাস্য আছে? তারা যে-সব অংশী দাঁড় করায় তা থেকে আল্লাহ্ বহু ঊর্ধ্বে!\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mmmccxxiii{আচ্ছা! কে সৃষ্টির সূচনা করেন তারপর তার পুনরাবর্তন ঘটান, আর কে তোমাদের আকাশ ও পৃথিবী থেকে রিযেক দান করেন? আল্লাহ্‌র সঙ্গে কি অন্য উপাস্য আছে? বলো -- ''নিয়ে এস তোমাদের দলিল-দস্তাবেজ যদি তোমরা সত্যবাদী হও।’’\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mmmccxxiv{বলো -- ''মহাকাশমন্ডলীর ও পৃথিবীর কেউই গায়েব সন্বন্ধে জানে না আল্লাহ্ ছাড়া।’’ আর তারা জানে না কখন তাদের পুনরুত্থিত করা হবে।\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mmmccxxv{বস্তুতঃ তাদের জ্ঞান পরলোকে সীমিত হয়ে গেছে, বরং তারা এ বিষয়ে সন্দেহে রয়েছে, বস্তুতঃ এ সন্বন্ধে তারা অন্ধ।\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mmmccxxvi{আর যারা অবিশ্বাস করে তারা বলে -- ''যখন আমরা ধূলো-মাটি হয়ে যাব এবং আমাদের পিতৃপুরুষরাও, -- আমরা কি তখন ঠিকঠিকই বহির্গত হব?\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mmmccxxvii{''অবশ্যই ইতিপূর্বে এটি আমাদের ওয়াদা করা হয়েছিল -- আমাদের আর আগেরকালে আমাদের পিতৃপুরুষদেরও, নিঃসন্দেহ এটি সেকালের উপকথা বৈ তো নয়!’’\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mmmccxxviii{বলো -- ''পৃথিবীতে পরিভ্রমণ করো, তারপর দেখো কেমন হয়েছিল অপরাধীদের পরিণাম!’’\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mmmccxxix{আর তাদের কারণে তুমি দুঃখ করো না, আর তারা যা ষড়যন্ত্র করছে সেজন্য তুমি মনঃক্ষুন্ন হয়ো না।\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@mmmccxxx{আর তারা বলে -- ''কখন এই ওয়াদা হবে, যদি তোমরা সত্যবাদী হও?’’\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@mmmccxxxi{তুমি বলো -- ''হতে পারে তোমরা যার জন্য তাড়াতাড়ি করছ তার কতকটা তোমাদের নিকটেই এসে গেছে।’’\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@mmmccxxxii{আর তোমার প্রভু নিশ্চয়ই তো মানুষের প্রতি করুণাসিন্ধুর মালিক, কিন্ত তথাপি তাদের অধিকাংশই কৃতজ্ঞতা জানায় না।\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@mmmccxxxiii{আর নিঃসন্দেহ তোমার প্রভু অবশ্যই জানেন তাদের বুক যা লুকিয়ে রাখে আর যা তারা প্রকাশ করে।\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@mmmccxxxiv{আর মহাকাশে ও পৃথিবীতে কোনো গুপ্ত বিষয় নেই যা সুস্পষ্ট গ্রন্থে নয়।\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@mmmccxxxv{নিঃসন্দেহ এই কুরআন ইসরাইলের বংশধরদের কাছে যে-সব বিষয়ে তারা মতভেদ করে তার অধিকাংশই বিবৃত করে দিয়েছে।\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@mmmccxxxvi{আর এটি আলবৎ মুমিনদের জন্য এক পথনির্দেশ ও করুণা।\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@mmmccxxxvii{নিঃসন্দেহ তোমার প্রভু তাঁর হুকুম মোতাবেক তাদের মধ্যে মীমাংসা করে দেবেন, আর তিনিই মহাশক্তিশালী, সর্বজ্ঞাতা।\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@mmmccxxxviii{সুতরাং তুমি আল্লাহ্‌র উপরে নির্ভর কর। নিঃসন্দেহ তুমিই হচ্ছ সুস্পষ্ট সত্যের উপরে।\qt@no{(79)}}
\qt@newcmd\qurantrans@bn@mmmccxxxix{তুমি নিশ্চয়ই মৃতকে শোনাতে পারবে না আর বধিরকেও আহ্বান শোনাতে পারবে না, যখন তারা ফিরে যায় পিছু হটে।\qt@no{(80)}}
\qt@newcmd\qurantrans@bn@mmmccxl{আর অন্ধদের তাদের পথভ্রষ্টতা থেকে তুমি পথ-প্রদর্শক হতে পারবে না। তুমি তো শোনাতে পার শুধু তাকে যে আমাদের বাণীসমূহ বিশ্বাস করে, ফলে তারা মুসলিম হয়।\qt@no{(81)}}
\qt@newcmd\qurantrans@bn@mmmccxli{আর যখন তাদের উপরে উক্তিটি বর্তাবে তখন তাদের জন্য আমরা বের ক’রে আনব মাটির কীট যেটি তাদের সঙ্গে বাক্যালাপ করবে, কেননা মানুষগুলো আমাদের নির্দেশাবলীতে দৃঢ় বিশ্বাস পোষণ করে নি।\qt@no{(82)}}
\qt@newcmd\qurantrans@bn@mmmccxlii{আর সেইদিন -- প্রত্যেক সম্প্রদায় থেকে আমরা এক একটি ফৌজকে সমবেত করব যারা আমাদের নির্দেশসমূহ প্রত্যাখ্যান করত, তারপর তাদের শ্রেণীবদ্ধ করা হবে।\qt@no{(83)}}
\qt@newcmd\qurantrans@bn@mmmccxliii{তারপর যখন তারা এসে পেছঁবে তখন তিনি বলবেন -- ''তোমরা কি আমার নির্দেশসমূহ প্রত্যাখ্যান করেছিলে যখন তোমরা জ্ঞানে তার ধারণা করতে পার নি? অথবা কী তা যা তোমরা করে চলেছিলে?’’\qt@no{(84)}}
\qt@newcmd\qurantrans@bn@mmmccxliv{আর তাদের উপরে উক্তিটি বর্তাবে যেহেতু তারা অন্যায়াচরণ করেছিল। তখন তারা বাদানুবাদ করতে পারবে না।\qt@no{(85)}}
\qt@newcmd\qurantrans@bn@mmmccxlv{তারা কি দেখে না যে আমরা অবশ্যই রাতকে সৃষ্টি করেছি যেন তারা এতে বিশ্রাম করে, আর দিনকে দৃশ্যমান? নিশ্চয় এতে তো এক নিদর্শন রয়েছে সেই জাতির জন্য যারা বিশ্বাস করে।\qt@no{(86)}}
\qt@newcmd\qurantrans@bn@mmmccxlvi{আর যেদিন শিঙায় ফুৎকার দেওয়া হবে তখন যে কেউ আছে মহাকাশমন্ডলে ও যে কেউ আছে পৃথিবীতে তারা ভীতিগ্রস্ত হবে সে ব্যতীত যাকে আল্লাহ্ ইচ্ছা করেন। আর সবাই তাঁর কাছে আসবে বিনত অবস্থায়।\qt@no{(87)}}
\qt@newcmd\qurantrans@bn@mmmccxlvii{আর তুমি পাহাড়গুলোকে দেখছ, তাদের ভাবছ অচল-অনড়, কিন্ত তারা চলে যাবে মেঘমালার চলে যাবার ন্যায়। এ আল্লাহরই হাতের কাজ যিনি সব কিছুই সুনিপুণভাবে করেছেন। তোমরা যা কর সে-সন্বন্ধে নিঃসন্দেহ তিনি পূর্ণ-ওয়াকিফহাল।\qt@no{(88)}}
\qt@newcmd\qurantrans@bn@mmmccxlviii{যে কেউ একটি সৎকাজ নিয়ে আসে, তার জন্য তবে থাকবে এর চেয়েও ভাল, আর তারা সেই দিনের ভীতি থেকে নিরাপদ থাকবে।\qt@no{(89)}}
\qt@newcmd\qurantrans@bn@mmmccxlix{আর যে কেউ একটি মন্দ কাজ নিয়ে আসে, তাদের তবে তাদের মুখের উপরে নিক্ষেপ করা হবে আগুনের মধ্যে। ''তোমরা যা করে চলেছিলে তা ছাড়া অন্য কিছু কি তোমাদের প্রতিদান দেওয়া হচ্ছে?’’\qt@no{(90)}}
\qt@newcmd\qurantrans@bn@mmmccl{''আমাকে অবশ্য আদেশ করা হয়েছে যে আমি উপাসনা করব এই শহরের প্রভুকে যেটিকে তিনি পবিত্র করেছেন, আর তাঁরই হচ্ছে সব-কিছু। আর আমাকে আদেশ করা হয়েছে যে আমি মুসলিমদেরই একজন হব, --\qt@no{(91)}}
\qt@newcmd\qurantrans@bn@mmmccli{''আর যেন আমি কুরআন পাঠ করতে পারি।’’ সুতরাং যে কেউ সৎপথ অনুসরণ করে, সে তবে নিঃসন্দেহ সৎপথে চলে তার নিজেরই জন্যে, আর যে কেউ বিপথে যায় তবে বলো -- ''আমি তো কেবল সতর্ককারীদেরই একজন।’’\qt@no{(92)}}
\qt@newcmd\qurantrans@bn@mmmcclii{আর বলো -- ''সকল প্রশংসা আল্লাহ্‌র, তিনি শীঘ্রই তোমাদের দেখাবেন তাঁর নিদর্শনসমূহ, তখন তোমরা সে-সব চিনতে পারবে।’’ আর তোমার প্রভু অমনোযোগী নন তোমরা যা কর সে-সন্বন্ধে।\qt@no{(93)}}
\qt@newcmd\qurantrans@bn@mmmccliii{\basmalahbn ত্বা, সীন, মীম।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmccliv{এসব হচ্ছে সুস্পষ্ট গ্রন্থের বাণীসমূহ।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmcclv{আমরা তোমার কাছে মূসা ও ফিরআউনের কাহিনী থেকে যথাযথভাবে বিবৃত করছি সেই লোকদের জন্য যারা বিশ্বাস করে।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmcclvi{নিঃসন্দেহ ফিরআউন দেশে খুব উদ্ধত হয়েছিল, আর এর বাসিন্দাদের সে দলবিভক্ত করেছিল, সে তাদের একদলকে দুর্বল বানিয়েছিল, -- সে তাদের বেটাছেলেদের হত্যা করত ও বাঁচতে দিত তাদের মেয়েছেলেদের। নিঃসন্দেহ সে ছিল বিপর্যয় সৃষ্টিকারীদের অন্যতম।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmcclvii{আর আমরা চেয়েছিলাম যাদের পৃথিবীতে দুর্বল বানানো হয়েছিল তাদের প্রতি অনুগ্রহ করতে। আর তাদের নেতা করতে আর তাদের উত্তরাধিকারী করতে,\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmcclviii{আর দেশে তাদের প্রতিষ্ঠা করতে, আর ফিরআউন ও হামান ও তাদের সেনাবাহিনীকে আমরা তা দেখাতে যা তারা তাদের থেকে আশংকা করত।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmcclix{আর আমরা মূসার মাতার কাছে অনুপ্রেরণা দিলাম এই বলে -- ''এটিকে স্তন্যদান করো, তারপর যখন তার সন্বন্ধে আশংকা কর তখন তাকে পানিতে ফেলে দাও, আর ভয় করো না ও দুঃখও করো না। নিঃসন্দেহ আমরা তাকে ফিরিয়ে দেব তোমার কাছে, আর তাকে বানিয়ে তুলব রসূলগণের একজন ক’রে।’’\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmcclx{''তারপর তাঁকে তোলে নিল ফিরআউনের পরিজনবর্গ যেন তিনি তাদের জন্য হতে পারেন একজন শত্রু ও দুঃখ। নিঃসন্দেহ ফিরআউন ও হামান ও তাদের সৈন্যসামন্ত ছিল দোষী।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmcclxi{''আর ফিরআউনের স্ত্রী বলল -- ''এ আমার জন্য ও তোমার জন্য এক চোখ-জোড়ানো আনন্দ! একে কাতল করো না, হতে পারে সে আমাদের উপকারে আসবে, অথবা তাকে আমরা পুত্ররূপে গ্রহণ করব।’’ আর তারা বুঝতে পারল না।’’\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmcclxii{আর পরক্ষণেই মূসার মায়ের হৃদয় মুক্ত হ’ল। সে হয়ত এটি প্রকাশ করেই ফেলত যদি না আমরা তার হৃদয়ে বল দিতাম, যেন সে মুমিনদের মধ্যেকার হয়।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmcclxiii{আর সে তাঁর বোনকে বলল -- ''এর পেছনে পেছনে যাও।’’ কাজেই সে তাঁর প্রতি লক্ষ্য রেখেছিল দূর থেকে, আর তারা বুঝতে পারে নি।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmcclxiv{আর আমরা আগে থেকেই স্তন্যপান তাঁর জন্য নিষিদ্ধ করেছিলাম। তখন সে বললে, ''আমি কি আপনাদের এমন কোনো ঘরের লোকের বিষয়ে বলে দেব যারা আপনাদের জন্য তাকে লালন-পালন করতেও পারে, আর তারা এর শুভাকাঙ্খী হবে?’’\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmcclxv{তখন আমরা তাঁকে ফিরিয়ে দিলাম তাঁর মায়ের কাছে, যেন তার চোখ জুড়িয়ে যায় আর যেন সে দুঃখ না করে, আর যেন সে জানতে পারে যে আল্লাহ্‌র ওয়াদা ধ্রুবসত্য। কিন্তু তাদের অধিকাংশই জানে না।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmcclxvi{আর যখন তিনি তাঁর যৌবনে পৌঁছলেন ও পূর্ণবয়স্ক হলেন, আমরা তখন তাঁকে জ্ঞান ও বিদ্যা দান করলাম। আর এইভাবেই আমরা সৎকর্মীদের প্রতিদান দিই।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmcclxvii{আর তিনি শহরে প্রবেশ করলেন যে সময়ে এর অধিবাসীরা অসতর্ক ছিল, তখন তিনি সেখানে দেখতে পেলেন দুজন লোক মারামারি করছে, -- একজন তাঁর দলের আর একজন তাঁর শত্রুপক্ষের, তখন যে ব্যক্তি তাঁর দলীয় সে তাঁর সাহায্যের জন্য চীৎকার করল তার বিরুদ্ধে যে তাঁর শত্রুপক্ষীয়, সুতরাং মূসা তাকে ঘুষি মারলেন, তখন তিনি তাকে খতম করে ফেললেন। তিনি বললেন -- ''এইটি শয়তানের কাজের ফলে। নিঃসন্দেহ সে এক শত্রু -- প্রকাশ্যভাবে বিভ্রান্তকারী।’’\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmcclxviii{তিনি বললেন -- ''আমার প্রভু! আমি নিঃসন্দেহ আমার নিজের প্রতি অত্যাচার করে ফেলেছি, সেজন্য আমাকে পরিত্রাণ করো।’’ সুতরাং তিনি তাঁকে পরিত্রাণ করলেন। নিঃসন্দেহ তিনি -- তিনিই পরিত্রাণকারী, অফুরন্ত ফলদাতা।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmcclxix{তিনি বললেন -- ''আমার প্রভু! যেহেতু তুমি আমার প্রতি অনুগ্রহ করেছ, তাই আমি কখনো অপরাধীদের পৃষ্ঠপোষক হবো না।’’\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmcclxx{তারপর তিনি সকালবেলায় ভীত-সন্ত্রস্ত অবস্থায় শহরটিতে বেরুলেন সতর্ক দৃষ্টি ফেলে, তখন হঠাৎ যে আগের দিনে তাঁর সাহায্য চেয়েছিল সে তাঁর প্রতি চীৎকার করল। মূসা তাকে বললেন -- ''তুমি তো স্পষ্টই একজন ঝগড়াটে।’’\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmcclxxi{তারপর যখন তিনি পাকড়াতে চাইলেন তাকে যে তাঁদের উভয়েরই শত্রু তখন সে বললে -- ''হে মূসা! তুমি কি আমাকে মেরে ফেলতে চাও যেমন তুমি একজনকে গতকাল মেরে ফেলেছ, তুমি তো চাইছ কেবল দেশে জবরদস্ত বনতে, আর তুমি চাও না শান্তিস্থাপনকারীদের অন্তর্ভুক্ত হতে।’’\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmcclxxii{আর একজন লোক শহরের দূরপ্রান্ত থেকে ছুটতে ছুটতে এল। সে বললে -- ''হে মূসা! নিঃসন্দেহ প্রধানরা তোমার সন্বন্ধে পরামর্শ করছে তোমাকে হত্যা করতে, কাজেই বেরিয়ে যাও, নিঃসন্দেহ আমি তোমার জন্য মঙ্গলাকাঙ্খীদের একজন ।’’\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmcclxxiii{সুতরাং তিনি সেখান থেকে বেরিয়ে গেলেন ভীতসন্ত্রস্তভাবে সতর্ক দৃষ্টি মেলে। তিনি বললেন -- ''আমার প্রভু! আমাকে অত্যাচারীগোষ্ঠী থেকে উদ্ধার করো।’’\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmcclxxiv{আর তিনি যখন মাদয়ান অভিমুখে যাত্রা করলেন তখন বললেন -- ''হতে পারে আমার প্রভু আমাকে ঠিক পথে চালিয়ে নেবেন।’’\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmcclxxv{আর যখন তিনি মাদয়ানের জলাশয়ের কাছে এলেন তখন তিনি তাতে দেখলেন একদল লোক পানি খাওয়াচ্ছে, আর তাদের পাশে তিনি দেখতে পেলেন দুজন মহিলা আগলে রেখেছে। তিনি বললেন -- ''তোমাদের দুজনের কি ব্যাপার?’’ তারা বললে -- ''আমরা পানি খাওয়াতে পারছি না যে পর্যন্ত না রাখালরা সরিয়ে নিয়ে যায়, আর আমাদের আব্বা খুব বুড়ো মানুষ।’’\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmcclxxvi{সুতরাং তিনি তাদের দুজনের জন্য পানি খাওয়ালেন, তারপর ছায়ার দিকে ফিরে গেলেন আর বললেন -- ''আমার প্রভু! তুমি আমার প্রতি যে কোনো অনুগ্রহ পাঠাবে আমি তারই জন্যে ভিখারী হয়ে আছি।’’\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmcclxxvii{তারপরে সেই দুইজন মহিলার একজন তাঁর নিকটে লাজুকভাবে হেঁটে এল। সে বললে -- ''আমার আব্বা আপনাকে আমন্ত্রণ করেছেন আপনি যে আমাদের জন্য পানি খাইয়েছেন সেজন্য আপনাকে পারিশ্রমিক প্রদান করতে।’’ তারপর যখন তিনি তার কাছে এলেন এবং তার কাছে বৃত্তান্ত বর্ণনা করলেন তখন সে বলল -- ''ভয় করো না, তুমি অত্যাচারী লোকদের কবল থেকে রক্ষা পেয়েছ।’’\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmcclxxviii{মেয়ে দুজনের একজন বলল -- ''হে আমার আব্বা! তুমি একে কর্মচারী ক’রে নাও, তুমি যাদের নিযুক্ত করতে পার তাদের মধ্যে সে-ই সব চাইতে ভাল যে বলবান, বিশ্বস্ত।’’\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmcclxxix{সে বলল -- ''আমি তো চাইছি আমার এই দুই মেয়ের একটিকে তোমার সাথে বিয়ে দিতে এই শর্তে যে তুমি আমার জন্য চাকরি করবে আট হজ, আর যদি তুমি দশ পূর্ণ কর তাহলে সে তোমার ইচ্ছা, আর আমি চাই না যে আমি তোমার উপরে কঠোর হব। তুমি শীঘ্রই, ইন-শা-আল্লাহ্‌, আমাকে দেখতে পাবে ন্যায়পরায়ণদের একজন।’’\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmcclxxx{তিনি বললেন -- ''এই-ই আমার মধ্যে ও আপনার মধ্যে রইল। এ দুটি মিয়াদের যে কোনোটি আমি যদি পূর্ণ করি তাহলে আমার বিরুদ্ধে কোনো অভিযোগ থাকবে না। আর আমরা যা কথা বলছি তার উপরে আল্লাহ্ কার্যনির্বাহক রইলেন।’’\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmcclxxxi{তারপর মূসা যখন মিয়াদ পূর্ণ করেলন এবং তাঁর পরিবারবর্গসহ যাত্রা করলেন, তখন তিনি পাহাড়ের কিনার থেকে আগুনের আভাস পেলেন। তিনি তাঁর পরিজনদের বললেন -- ''তোমরা অপেক্ষা কর, আমি আগুনের আভাস পাচ্ছি, সম্ভবতঃ আমি সেখান থেকে তোমাদের জন্য কোনো খবর নিয়ে আসতে পারব অথবা আগুনের একটি আঙটা যাতে তোমরা নিজেদের গরম করতে পার।’’\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmcclxxxii{তারপর যখন তিনি তার কাছে এলেন তখন একটি আওয়াজ উঠল উপত্যকার ডান দিকের ঝোপঝাড়ের পুণ্য স্থান থেকে এই বলে -- ''হে মূসা! নিঃসন্দেহ আমিই আল্লাহ্‌, বিশ্বজগতের প্রভু।’’\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmcclxxxiii{আর এই বলে -- ''তোমার লাঠি ছুঁড়ে মার।’’ তারপর যখন তিনি এটিকে দেখলেন দৌড়ছে -- যেন এটি একটি সাপ, তখন তিনি পিছু হটলেন ছুটতে ছুটতে আর ঘুরে দেখলেন না। ''ওহ মূসা! সামনে এসো, আর ভয় করো না, নিঃসন্দেহ তুমি নিরাপদ লোকদের অন্তর্ভুক্ত।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmcclxxxiv{''তোমার হাত তোমার পকেটে ঢোকাও, এটি বেরিয়ে আসবে সাদা হয়ে কোনো দোষত্রুটি ছাড়া, আর তোমার পাখনা তোমার প্রতি চেপে ধর ভয়ের থেকে। সুতরাং এ দুটি হচ্ছে তোমার প্রভুর কাছ থেকে ফিরআউন ও তার প্রধানদের কাছে দুই প্রমাণ। নিঃসন্দেহ তারা হচ্ছে সীমালংঘনকারী জাতি।’’\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmcclxxxv{তিনি বললেন -- ''আমার প্রভু! আমি তো তাদের একজনকে হত্যা করে ফেলেছিলাম, কাজেই আমি ভয় করছি তারা আমাকে মেরে ফেলবে।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmcclxxxvi{''আর আমার ভাই হারূন, সে আমার থেকে কথাবার্তায় বেশী বাক্‌পটু, সেজন্য তাকে আমার সঙ্গে অবলন্বনস্বরূপ পাঠিয়ে দাও যাতে সে আমার সত্যতা সমর্থন করে। আমি অবশ্য আশংকা করছি যে তারা আমাকে প্রত্যাখ্যান করবে।’’\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmcclxxxvii{তিনি বললেন -- ''আমরা শীঘ্রই তোমার বাহু শক্তিশালী করব তোমার ভাইকে দিয়ে, আর তোমাদের উভয়ের জন্য আমরা ক্ষমতা দেবো, কাজেই তারা তোমাদের নাগাল পাবে না, -- আমাদের নিদর্শনাবলী নিয়ে, -- তোমরা দুজন ও যারা তোমাদের অনুসরণ করে তারা বিজয়ী হবে।’’\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmcclxxxviii{তারপর মূসা যখন তাদের কাছে এলেন আমাদের সুস্পষ্ট নিদর্শনগুলো নিয়ে, তারা বলল -- ''এ তো বানানো ভেলকিবাজি ছাড়া আর কিছুই নয়, আর একরম আমাদের পূর্ববর্তী বাপদাদার আমলেও আমরা শুনি নি।’’\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmcclxxxix{আর মূসা বললেন -- ''আমার প্রভু ভাল জানেন কে তাঁর কাছ থেকে পথনির্দেশ নিয়ে এসেছে আর কার জন্য হবে চরমোৎকর্ষ আবাস। এটি নিশ্চিত যে অত্যাচারীদের সফলকাম করা হবে না।’’\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmccxc{আর ফিরআউন বলল -- ''ওহে প্রধানগণ! তোমাদের জন্য আমি ছাড়া আর কোনো উপাস্য আছে বলে তো আমি জানি না! সুতরাং, হে হামান, তুমি আমার জন্য ইট পোড়াও, তারপর আমার জন্য একটি উঁচু দালান তৈরী কর, হয়ত আমি মূসার উপাস্যের সন্নিকটে উঠতে পারব। তবে আমি অবশ্য তাকে মিথ্যাবাদীদের একজন বলেই জ্ঞান করি।’’\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmccxci{আর সে ও তার সাঙ্গোপাঙ্গ অসঙ্গতভাবে দুনিয়াতে গর্ব করেছিল, আর তারা ভেবেছিল যে আমাদের কাছে তাদের ফিরিয়ে আনা হবে না।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmccxcii{সেজন্য আমরা তাকে ও তার সাঙ্গোপাঙ্গদের পাকড়াও করেছিলাম, আর তাদের নিক্ষেপ করেছিলাম সমুদ্রে। অতএব দেখ, কেমন হয়েছিল অত্যাচারীদের পরিণাম!\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmccxciii{আর আমরা তাদের বানিয়েছিলাম সর্দার, -- তারা আহ্বান করত আগুনের দিকে, আর কিয়ামতের দিনে তাদের সাহায্য করা হবে না।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmccxciv{আর এই দুনিয়াতে আমরা অসন্তষ্টিকে তাদের পিছু ধরিয়েছিলাম, আর কিয়ামতের দিনে তারা হবে ঘৃণিতদের মধ্যেকার।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmccxcv{আর আমরা আলবৎ মূসাকে ধর্মগ্রন্থ দিয়েছিলাম -- পূর্ববর্তী বংশদের আমরা ধ্বংস করে ফেলার পরে -- মানুষদের জন্য দৃষ্টি- উন্মোচক, আর পথপ্রদর্শক, আর একটি করুণা, -- যেন তারা মনোযোগ দিতে পারে।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmccxcvi{আর তুমি পশ্চিম প্রান্তে ছিলে না যখন আমরা মূসার কাছে বিধান দিয়েছিলাম, আর তুমি প্রতক্ষদর্শীদের মধ্যেও ছিলে না।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmccxcvii{বস্তুতঃ আমরা বহু মানববংশের উদ্ভব করেছিলাম, তারপর জীবনটা তাদের কাছে সুদীর্ঘ মনে হয়েছিল। আর তুমি মাদয়ানের অধিবাসীদের সঙ্গে বসবাসকারী ছিলে না তাদের কাছে আমাদের বাণীসমূহ আবৃত্তি করা অবস্থায়, কিন্তু আমরাই তো রসূল প্রেরণ করতে রয়েছিলাম।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmmccxcviii{আর তুমি পাহাড়ের নিকটে ছিলে না যখন আমরা আহ্বান করেছিলাম, কিন্তু এটি তোমার প্রভু থেকে এক করুণা, যাতে তুমি সতর্ক করতে পার এমন এক বংশকে যাদের কাছে তোমার আগে সতর্ককারীদের কেউ আসেন নি, যেন তারা মনোযোগ দিতে পারে।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmmccxcix{আর পক্ষান্তরে যদি কোনো বিপদ তাদের পাকড়াত তাদের হাত যা আগবাড়িয়েছে সেজন্য তাহলে তারা বলতে পারত -- ''আমাদের প্রভু! কেন তুমি আমাদের কাছে কোনো রসূল পাঠাও নি তাহলে তো আমরা তোমার নির্দেশাবলী অনুসরণ করতে পারতাম এবং আমরা মুমিনদের অন্তর্ভুক্ত হতে পারতাম?’’\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmmccc{কিন্তু যখন আমাদের তরফ থেকে তাদের কাছে সত্য এসেছে তারা বলছে -- ''মুসাকে যেমন দেওয়া হয়েছিল তাকে কেন তেমনটা দেওয়া হ’ল না?’’ কী! মূসাকে ইতিপূর্বে যা দেওয়া হয়েছিল তাতে কি তারা অবিশ্বাস করে নি? তারা বলে -- ''দুখানা জাদু -- একে অন্যের পৃষ্ঠপোষকতা করছে।’’ আর তারা বলে -- ''আমরা আলবৎ সবটাতেই অবিশ্বাসী।’’\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmmccci{তুমি বলো -- ''তবে আল্লাহ্‌র কাছ থেকে একখানা ধর্মগ্রন্থ নিয়ে এস যা এই দুইখানার চাইতেও ভাল পথনির্দেশক, আমিও তা অনুসরণ করব, যদি তোমরা।’’\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmmcccii{কিন্তু যদি তারা তোমার জবাব না দেয়, তাহলে জেনে রেখো, তারা অবশ্যই তাদের খেয়াল-খুশির অনুসরণ করছে। আর কে বেশী পথভ্রান্ত তার চাইতে যে তার খেয়াল-খুশির অনুসরণ করে আল্লাহ্‌র কাছ থেকে পথনির্দেশ ব্যতিরেকে? নিঃসন্দেহ অন্যায়কারী লোককে আল্লাহ্ পথ দেখান না।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmmccciii{আর আমরা অবশ্যই তাদের কাছে বাণী পৌঁছিয়ে দিয়েছি যেন তারা মনোযোগ দিতে পারে।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmmccciv{যাদের কাছে আমরা এর আগে ধর্মগ্রন্থ দিয়েছিলাম তারা স্বয়ং এতে বিশ্বাস করে।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmmcccv{আর যখন এটি তাদের কাছে পাঠ করা হয় তারা বলে -- ''আমরা এতে ঈমান আনলাম, নিঃসন্দেহ এটি আমাদের প্রভু র কাছ থেকে সত্য, নিঃসন্দেহ আমরা এর আগেও মুসলিম ছিলাম।’’\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmmcccvi{এদের দুইবার তাদের প্রতিদান দেওয়া হবে যেহেতু তারা অধ্যবসায় করেছিল, এবং তারা ভালো দিয়ে মন্দকে প্রতিরোধ করে, আর আমরা তাদের যে রিযেক দিয়েছি তা থেকে তারা খরচ করে থাকে।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmmcccvii{আর যখন তারা বাজে কথা শোনে তখন তারা তা থেকে সরে যায় এবং বলে -- ''আমাদের জন্য আমাদের কাজ আর তোমাদের জন্য তোমাদের কাজ, তোমাদের প্রতি 'সালাম’। অজ্ঞদের আমরা কামনা করি না।’’\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mmmcccviii{নিঃসন্দেহ তুমি যাকে ভালবাস তাকে তুমি ধর্মপথে আনতে পারো না, কিন্তু আল্লাহ্‌ই পথ দেখান যাকে তিনি ইচ্ছা করেন। আর তিনিই ভাল জানেন সৎপথপ্রাপ্তদের।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mmmcccix{আর তারা বলে -- ''আমরা যদি তোমার সঙ্গে ধর্মপথ অনুসরণ করি তাহলে আমাদের দেশ থেকে আমাদের উৎখাত করা হবে।’’ আমরা কি তাদের জন্য এক নিরাপদ পুণ্যস্থান প্রতিষ্ঠিত করি নি যেখানে আনা হয় হরেক রকমের ফল-ফসল, আমাদের তরফ থেকে রিযেকস্বরূপে? কিন্তু তাদের অধিকাংশই জানে না।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mmmcccx{আর জনপদদের কতটাকে যে আমরা ধ্বংস করেছি যে গর্ব করেছিল তার প্রাচুর্যের জন্য! আর এইসব তাদের ঘরবাড়ি, -- তাদের পরে অল্প কতক ব্যতীত সেগুলোতে বসবাস করা হয় নি। আর আমরা, খোদ আমরা হচ্ছি উত্তরাধিকারী।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mmmcccxi{আর তোমার প্রভু কখনো জনপদগুলোর ধ্বংসকারক নন যে পর্যন্ত না তিনি তাদের মাতৃভূমিতে একজন রসূল উত্থাপন করেছেন তাদের কাছে আমাদের বাণীসমূহ বিবৃত করতে, আর আমরা কখনো জনপদসমূহের ধ্বংসকারী নই যদি না তাদের অধিবাসীরা সীমালংঘনকারী হয়।\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mmmcccxii{আর বিষয়-আশয়ের যা কিছু তোমাদের দেওয়া হয়েছে তা তো এই দুনিয়ার জীবনের ভোগসম্ভার ও এরই শোভা- সৌন্দর্য, আর যা কিছু আল্লাহ্‌র কাছে রয়েছে সে-সব আরো ভাল ও আরো স্থায়ী। তোমরা কি তবু বুঝবে না?\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mmmcccxiii{যাকে আমরা প্রতি‌শ্রুতি দিয়েছি উত্তম প্রতি‌শ্রুতিতে যা সে পেতে যাচ্ছে, সে কি তবে তার মতো যাকে দেওয়া হয়েছে এই দুনিয়ার জীবনের ভোগসম্ভার, তারপর কিয়ামতের দিনে সে হবে অভিযুক্তদের মধ্যেকার?\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mmmcccxiv{আর সেদিন তাদের তিনি ডাকবেন ও বলবেন -- ''কোথায় আমার শরীকরা যাদের তোমরা উদ্ভাবন করতে?’’\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mmmcccxv{যাদের বিরুদ্ধে বক্তব্য সত্যপ্রতিপন্ন হয়েছে তারা বলল -- ''আমাদের প্রভু! এরাই তারা যাদের আমরা বিপথে নিয়েছিলাম, আমরা তাদের বিপথে নিয়েছিলাম যেমন আমরা নিজেরা বিপথে গিয়েছিলাম। আমরা তোমার কাছে আমাদের দোষ স্খালন করছি। এটি নয় যে তারা আমাদেরই পূজা করত।’’\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mmmcccxvi{আর বলা হবে -- ''তোমাদের শরীকান-দেবতাদের ডাকো।’’ সুতরাং তারা তাদের প্রতি সাড়া দেবে না, আর তারা শাস্তি দেখতে পাবে। আহা! যদি তারা সৎপথ অনুসরণ করত!\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mmmcccxvii{আর সেইদিন যখন তিনি তাদের ডাকবেন ও বলবেন -- ''তোমরা প্রেরিত-পুরুষদের কী জবাব দিয়েছিলে?’’\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mmmcccxviii{তখন বক্তব্যগুলো সেইদিন তাদের কাছ ঝাপসা হয়ে যাবে, কাজেই তারা পরস্পরকে জিজ্ঞাসাবাদও করতে পারবে না।\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mmmcccxix{কিন্তু তার ক্ষেত্রে -- যে তওবা করে এবং ঈমান আনে ও সৎকর্ম করে, তাহলে হয়ত সে সফলতাপ্রাপ্তদের অন্তর্ভুক্ত হবে।\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mmmcccxx{আর তোমার প্রভু যা ইচ্ছা করেন তাই সৃষ্টি করেন আর মনোনয়ন করেন, তাদের কোনো এখতিয়ার নেই। আল্লাহ্‌রই সব মহিমা, আর তারা যা অংশী আরোপ করে তা থেকে তিনি বহু ঊর্ধ্বে।\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mmmcccxxi{আর তোমার প্রভু ভাল জানেন যা তাদের অন্তর লুকিয়ে রাখে আর যা তারা প্রকাশ করে।\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mmmcccxxii{আর তিনিই আল্লাহ্‌, তিনি ব্যতীত অন্য উপাস্য নেই। তাঁরই সমস্ত স্তুতি আগে ও পরে, আর বিধান তাঁরই, আর তাঁরই কাছে তোমাদের ফিরিয়ে আনা হবে।\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@mmmcccxxiii{বল -- ''তোমরা কি ভেবে দেখেছ -- আল্লাহ্ যদি তোমাদের উপরে রাত্রি স্থায়ী করতেন কিয়ামতের দিন পর্যন্ত তাহলে আল্লাহ্ ছাড়া এমন কোন উপাস্য আছে যে তোমাদের জন্য প্রদীপ নিয়ে আসবে? তোমরা কি তবুও শুনবে না।’’\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@mmmcccxxiv{বল -- ''তোমরা কি ভেবে দেখেছ -- আল্লাহ্ যদি তোমাদের জন্য দিনকে কিয়ামতের দিন পর্যন্ত স্থায়ী করতেন তাহলে আল্লাহ্ ব্যতীত এমন কোন উপাস্য আছে যে তোমাদের জন্য রাত্রিকে নিয়ে আসবে যার মধ্যে তোমরা বিশ্রাম করতে পার? তোমরা কি তবুও দেখবে না?’’\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@mmmcccxxv{বস্তুতঃ তাঁর দয়া থেকেই তিনি তোমাদের জন্য রাত ও দিন বানিয়েছেন যেন তাতে তোমরা বিশ্রাম করতে পার এবং তাঁর করুণাভান্ডারের সন্ধান করতে পার, আর যেন তোমরা কৃতজ্ঞতা প্রকাশ করতে পার।\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@mmmcccxxvi{আর সেইদিন তিনি ওদের ডাকবেন ও বলবেন -- ''কোথায় আমার অংশীদাররা যাদের তোমরা উদ্ভাবন করতে?’’\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@mmmcccxxvii{আর আমরা প্রত্যেক সম্প্রদায় থেকে বের করব একজন সাক্ষী, তখন আমরা বলব -- ''তোমাদের প্রমাণ নিয়ে এস।’’ তখন তারা জানতে পারবে যে সত্য আল্লাহ্‌রই, আর তারা যা কিছু উদ্ভাবন করত তা তাদের থেকে বিদায় নেবে।\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@mmmcccxxviii{নিঃসন্দেহ ক্কারূন ছিল মূসার স্বজাতিদের মধ্যেকার, কিন্তু সে তাঁদের বিরুদ্ধে বিদ্রোহ করল। আর আমরা তাকে ধনভান্ডারের এতসব দিয়েছিলাম যে তার চাবিগুলো একদল বলবান লোকের বোঝা হয়ে যেত। দেখো! তার লোকেরা তাকে বললে -- ''গর্ব করো না, নিঃসন্দেহ আল্লাহ্ দাম্ভিকদের ভালবাসেন না।\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@mmmcccxxix{''আর আল্লাহ্ তোমাকে যা দিয়েছেন তা দিয়ে তুমি পরকালের আবাস অণ্বেষণ করো, আর ইহকালে তোমার ভাগ ভুলে যেয়ো না, আর ভাল কর যেমন আল্লাহ্ তোমার ভাল করেছেন, আর দুনিয়াতে ফেসাদ বাধাতে চেয়ো না। নিঃসন্দেহ আল্লাহ্ ফেসাদে লোকদের ভালবাসেন না।’’\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@mmmcccxxx{সে বলল -- ''আমাকে এ-সব দেওয়া হয়েছে আমার মধ্যে যে জ্ঞান রয়েছে সেজন্য।’’ সে কি জানত না যে তার আগে বহু মানবগোষ্ঠীকে আল্লাহ্ ধ্বংস করে ফেলেছেন যারা ছিল তার চেয়েও শক্তিতে অধিক প্রবল এবং একাট্টাকরণে আরো প্রাচুর্যময়? আর অপরাধীদের তাদের পাপ সন্বন্ধে প্রশ্ন করা হবে না।\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@mmmcccxxxi{কাজেকাজেই সে তার স্বজাতির সামনে তার জাঁকজমকের সাথে বাহির হয়েছিল। যারা এই দুনিয়ার জীবন কামনা করেছিল তারা বলত -- ''হায়! ক্কারূনকে যা দেওয়া হয়েছে তার মতো যদি আমাদেরও থাকতো! নিঃসন্দেহ সে বিরাট সৌভাগ্যের অধিকারী!’’\qt@no{(79)}}
\qt@newcmd\qurantrans@bn@mmmcccxxxii{আর যাদের জ্ঞান দেওয়া হয়েছিল তারা বলল -- ''ধিক্ তোমাদের! যে ঈমান আনে ও সৎকাজ করে তার জন্য আল্লাহ্‌র পুরস্কার বেশি ভাল। আর ধৈর্যশীলদের ছাড়া অন্যে এর সাক্ষাৎ পাবে না।’’\qt@no{(80)}}
\qt@newcmd\qurantrans@bn@mmmcccxxxiii{অতঃপর আমরা পৃথিবীকে দিয়ে তাকে ও তার প্রাসাদকে গ্রাস করিয়েছিলাম, তখন তার জন্য এমন কোনো দল ছিল না যারা আল্লাহ্‌র বিরুদ্ধে তাকে সাহায্য করতে পারত, আর সে আ‌ত্মপক্ষকে সাহায্যকারীদের অন্তর্ভুক্ত ছিল না।\qt@no{(81)}}
\qt@newcmd\qurantrans@bn@mmmcccxxxiv{আর আগের দিন যারা তার অবস্থার জন্য কামনা করত তারা সাত-সকালে বলতে লাগল -- ''আহা দেখো! আল্লাহ্ তাঁরে বান্দাদের মধ্যে যাকে ইচ্ছা করেন তার প্রতি রিযেক প্রসারিত করেন এবং মেপেজোখে দেন। আল্লাহ্ যদি আমাদের উপরে সদয় না হতেন তবে আমাদেরও গ্রাস করাতেন। আহা দেখো! অবিশ্বাসীরা কখনো সফলকাম হয় না।’’\qt@no{(82)}}
\qt@newcmd\qurantrans@bn@mmmcccxxxv{এই পরলোকের আবাস, -- আমরা এটি নির্ধারিত করেছি তাদের জন্য যারা পৃথিবীতে বাড়াবাড়ি করতে চায় না এবং ফেসাদও বাধায় না। আর শুভ-পরিণাম হচ্ছে ধর্মপরায়ণদের জন্য।\qt@no{(83)}}
\qt@newcmd\qurantrans@bn@mmmcccxxxvi{যে কেউ ভাল নিয়ে আসে তার জন্য তবে এর চেয়েও ভাল রয়েছে, আর যে মন্দ নিয়ে আসে -- তাহলে যারা মন্দ কাজ করে তাদের প্রতিদান দেওয়া হবে না তারা যা করত তা ব্যতীত।\qt@no{(84)}}
\qt@newcmd\qurantrans@bn@mmmcccxxxvii{নিঃসন্দেহ যিনি তোমার উপরে কুরআন বিধান করেছেন তিনি আলবৎ তোমাকে ফিরিয়ে আনবেন প্রত্যাবর্তনস্থলে। বলো -- ''আমার প্রভু ভাল জানেন কে পথনির্দেশ নিয়ে এসেছে আর কে হচ্ছে স্বয়ং সুস্পষ্ট বিভ্রান্তির মধ্যে।’’\qt@no{(85)}}
\qt@newcmd\qurantrans@bn@mmmcccxxxviii{আর তুমি তো আশা কর নি যে তোমার সঙ্গে গ্রন্থখানার পরিচয় করিয়ে দেওয়া হবে, কিন্তু এটি তোমার প্রভুর কাছ থেকে একটি করুণা, সুতরাং তুমি কখনো অবিশ্বাসীদের পৃষ্ঠপোষক হয়ো না।\qt@no{(86)}}
\qt@newcmd\qurantrans@bn@mmmcccxxxix{আর তারা যেন আল্লাহ্‌র নির্দেশাবলী থেকে নিবৃত্ত না করে সে-সব তোমার কাছে অবতীর্ণ হবার পরে, বরঞ্চ তুমি ডাকো তোমার প্রভুর প্রতি, আর তুমি কখনো মুশরিকদের দলভুক্ত হয়ো না।\qt@no{(87)}}
\qt@newcmd\qurantrans@bn@mmmcccxl{আর আল্লাহ্‌র সঙ্গে অন্য কোনো উপাস্যকে ডেকো না। তিনি ব্যতীত অন্য কোনো উপাস্য নেই। তাঁর অবয়ব ব্যতীত আর সব কিছু ধ্বংসশীল। বিধান তাঁরই, আর তাঁর কাছেই তোমাদের ফিরিয়ে আনা হবে।\qt@no{(88)}}
\qt@newcmd\qurantrans@bn@mmmcccxli{\basmalahbn আলিফ, লাম, মীম।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmcccxlii{লোকেরা কি মনে করে যে তাদের ছেড়ে দেওয়া হবে যদি তারা বলে -- ''আমরা ঈমান এনেছি’’, আর তাদের পরীক্ষা করা হবে না?\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmcccxliii{আর এদের পূর্বে যারা ছিল তাদের আমরা ইতিপূর্বে অবশ্যই পরীক্ষা করেছিলাম, এইভাবেই আল্লাহ্ জানতে পারেন তাদের যারা সত্যপরায়ণতা অবলন্বন করে, আর জানতে পারেন মিথ্যাচারীদের।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmcccxliv{আথবা, যারা পাপাচার করে তারা কি ভাবে যে তারা আমাদের এড়িয়ে যেতে পারবে? তারা যা সিদ্ধান্ত করে তা কত মন্দ!\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmcccxlv{যারাই আল্লাহ্‌র সঙ্গে মোলাকাতের কামনা করে আল্লাহ্‌র নির্ধারিত কাল তবে নিশ্চয়ই আগতপ্রায়। আর তিনি সর্বশ্রোতা, সর্বজ্ঞাতা।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmcccxlvi{আর যে কেউ জিহাদ করে, সে তাহলে নিশ্চয়ই সংগ্রাম করে তার নিজেরই জন্যে। আল্লাহ্ নিঃসন্দেহ বিশ্বজগতের উপরে অনন্য- নির্ভর।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmcccxlvii{আর যারা ঈমান আনে ও সৎকর্ম করে আমরা তাদের থেকে তাদের দোষত্রুটিগুলো অবশ্যই দূর করে দেব, আর তারা যা করত সেজন্য উত্তমভাবে আমরা অবশ্যই তাদের প্রতিদান দেব।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmcccxlviii{আর আমরা মানুষকে তার পিতামাতার প্রতি সদ্ব্যবহারের নির্দেশ দিয়েছি। কিন্তু তারা যদি তোমার সঙ্গে জেদ করে যেন তুমি আমার সাথে এমন কিছু শরিক কর যার সন্বন্ধে তোমার কাছে কোনো জ্ঞান নেই, তাহলে তুমি তাদের আজ্ঞাপালন করো না। আমারই কাছে তোমাদের প্রত্যাবর্তন, তখন আমি তোমাদের জানিয়ে দেব যা কিছু তোমরা করছিলে।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmcccxlix{বস্তুতঃ যারা ঈমান এনেছে ও সৎকর্ম করছে আমরা নিশ্চয়ই তাদের প্রবেশ করাব সৎকর্মীদের মধ্যে।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmcccl{আর লোকেদের মধ্যে এমনও রয়েছে যে বলে -- ''আমরা আল্লাহ্‌তে ঈমান এনেছি’’, কিন্তু যখন তাকে আল্লাহ্‌র পথে কষ্ট দেওয়া হয় তখন সে লোকদের উৎপীড়নকে আল্লাহ্‌র শাস্তি বলে জ্ঞান করে। আর যদি তোমার প্রভুর নিকট থেকে কোনো সাহায্য আসে তবে তারা অবশ্যই বলবে -- ''আমরা নিঃসন্দেহ তোমাদের সাথে ছিলাম।’’ এ কি নয় যে আল্লাহ্‌ই ভাল জানেন যা কিছু বিশ্ববাসীর হৃদয়ে রয়েছে?\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmcccli{আর আল্লাহ্ অবশ্যই জানিয়ে দেবেন তাদের যারা ঈমান এনেছে, আর জানিয়ে দেবেন মুনাফিকদের।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmccclii{আর যারা অবিশ্বাস করে তারা যারা বিশ্বাস করেছে তাদের বলে -- ''আমাদের পথ অনুসরণ কর, তাহলে আমরা তোমাদের পাপ বহন করব।’’ বস্তুত তারা তো ওদের পাপের থেকে কিছুরই ভারবাহক হবে না। নিঃসন্দেহ তারাই তো মিথ্যাবাদী।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmcccliii{আর তারা তাদের বোঝা অবশ্যই বইবে, আর তাদের বোঝার সঙ্গে অন্য বোঝাও। আর কিয়ামতের দিনে তাদের অবশ্যই প্রশ্ন করা হবে যা তারা উাবন করেছিল সে-সন্বন্ধে।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmcccliv{আর ইতিপূর্বে আমরা অবশ্যই নূহ্‌কে পাঠিয়েছিলাম তাঁর লোকদের কাছে, তিনি তখন তাদের মধ্যে অবস্থান করেছিলেন পঞ্চাশ বছর কম এক হাজার বৎসর। তখন মহাপ্লাবন তাদের পাকড়াও করল, যেহেতু তারা ছিল অত্যাচারী।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmccclv{তখন আমরা তাঁকে ও জাহাজের আরোহীদের উদ্ধার করেছিলাম, আর একে আমরা বিশ্ববাসীর জন্য একটি নিদর্শন বানিয়েছিলাম।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmccclvi{আর ইব্রাহীমকে, -- স্মরণ করো! তিনি তাঁর লোকদের বলেছিলেন -- ''আল্লাহ্‌র এবাদত কর ও তাঁকে ভয়ভক্তি কর, এটিই তোমাদের জন্য শ্রেয়, যদি তোমরা জানতে।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmccclvii{''আল্লাহ্‌কে বাদ দিয়ে তোমরা তো শুধু প্রতিমাদের পূজা করছ, আর তোমরা একটি মিথ্যা উদ্ভাবন করেছ। নিঃসন্দেহ তোমরা আল্লাহ্‌কে বাদ দিয়ে যাদের আরাধনা করছ তারা তোমাদের জন্য জীবিকার উপরে কোনো কর্তৃত্ব রাখে না, কাজেই আল্লাহ্‌র কাছে জীবিকা অণ্বেষণ কর ও তাঁরই উপাসনা কর, আর তাঁর প্রতি কৃতজ্ঞতা জ্ঞাপন কর, তাঁর কাছেই তো তোমাদের ফিরিয়ে আনা হবে।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmccclviii{''আর যদি তোমরা প্রত্যাখ্যান কর তবে তোমাদের পূর্বযুগের সম্প্রদায়গুলোও প্রত্যাখ্যান করেছিল। আর রসূলের উপরে পরিস্কারভাবে পৌঁছে দেওয়া ছাড়া আর কিছু নয়।’’\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmccclix{তারা কি তবে দেখে নি কেমন ক’রে আল্লাহ্ সৃষ্টি শুরু করেন, তারপর তা পুনরুৎপাদন করেন। নিঃসন্দেহ এ আল্লাহ্‌র কাছে সহজসাধ্য।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmccclx{বলো -- ''পৃথিবীতে তোমরা ভ্রমণ কর আর দেখ কিভাবে তিনি সৃষ্টি শুরু করেছিলেন, তারপর আল্লাহ্ পরবর্তী সৃষ্টিকে সৃজন করেন।’’ নিশ্চয় আল্লাহ্ সব-কিছুর উপরে সর্বশক্তিমান।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmccclxi{তিনি শাস্তি দেন যাকে তিনি ইচ্ছা করেন এবং করুণা করেন যাকে তিনি ইচ্ছা করেন, আর তাঁর দিকেই তো তোমাদের ফেরানো হবে।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmccclxii{আর তোমরা এড়িয়ে যাবার লোক হবে না এই পৃথিবীতে আর মহাকাশেও নয়, আর আল্লাহ্‌কে বাদ দিয়ে তোমাদের জন্য কোনো অভিভাবক নেই এবং সাহায্যকারীও নেই।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmccclxiii{আর যারা আল্লাহ্‌র নির্দেশাবলী ও তাঁর সঙ্গে মোলাকাত হওয়া অস্বীকার করে তারা আমার করুণা থেকে নিরাশ হয়েছে, আর তারা -- তাদেরই জন্য রয়েছে মর্মন্তুদ শাস্তি।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmccclxiv{সেজন্য তাঁর লোকদের জবাব এ ভিন্ন আর কিছু ছিল না যে তারা বলল -- ''তাকে কাতল কর অথবা তাকে পুড়িয়ে ফেল।’’ কিন্তু আল্লাহ্ তাঁকে উদ্ধার করলেন আগুন থেকে। নিঃসন্দেহ এতে তো এক নিদর্শন রয়েছে সেই লোকদের জন্য যারা বিশ্বাস করে।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmccclxv{আর তিনি বলেছিলেন -- ''তোমরা তো আল্লাহ্‌কে ছেড়ে দিয়ে প্রতিমা-গুলোকে গ্রহণ করে, তোমাদের মধ্যে বন্ধুত্ব এই দুনিয়ার জীবনেই, তারপর কিয়ামতের দিনে তোমাদের একপক্ষ অপর পক্ষকে অস্বীকার করবে এবং তোমাদের একে অপরকে অভিশাপ দেবে, আর তোমাদের আবাস হবে আগুন, আর তোমাদের জন্য সাহায্যকারীদের কেউ থাকবে না।’’\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmccclxvi{অতএব লূত তাঁর প্রতি বিশ্বাস করেছিলেন। আর তিনি বলেছিলেন -- ''আমি তো আমার প্রভুর উদ্দেশ্যে দেশত্যাগ করছি। নিঃসন্দেহ তিনি স্বয়ং মহাশক্তিশালী, পরমজ্ঞানী।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmccclxvii{আর আমরা তাঁকে দিয়েছিলাম ইসহাক ও ইয়াকুবকে, আর তাঁর বংশধরদের মধ্যে আমরা প্রতিষ্ঠা করেছিলাম নবুওৎ ও ধর্মগ্রন্থ, আর আমরা তাঁর পুরস্কার দুনিয়াতেই তাঁকে প্রদান করেছিলাম, আর পরকালে তিনি আলবৎ হবেন সৎকর্মীদেরই অন্তর্ভুক্ত।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmccclxviii{আর লূতকে। স্মরণ করো! তিনি তাঁর লোকদের বলেছিলেন -- ''নিঃসন্দেহ তোমরা তো অশ্লীল আচরণে আকৃষ্ট হয়েছ যা বিশ্ববাসীর মধ্যে কেউই তোমাদের আগে করত না।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmccclxix{কী! তোমরা তো নিশ্চয়ই পুরুষদের কাছে এসে থাক, রাজপথগুলো বিচ্ছিন্ন করে থাক, আর তোমাদের জনসভাসমূহে জঘন্য কাজ করে থাক।’’ কিন্তু তাঁর লোকদের উত্তর অন্য কিছু ছিল না এ ভিন্ন যে তারা বলেছিল -- ''আমাদের উপরে আল্লাহ্‌র শাস্তি নিয়ে এস যদি তুমি সত্যবাদীদের মধ্যেকার হও।’’\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmccclxx{তিনি বললেন -- ''আমার প্রভু! আমাকে ফেসাদ সৃষ্টিকারী লোকদের বিরুদ্ধে সাহায্য করো।’’\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmccclxxi{আর যখন আমাদের বাণীবাহকরা ইব্রাহীমের কাছে এসেছিল সুসংবাদ নিয়ে তখন তারা বলল -- ''আমরা এই শহরের বাসিন্দাদের নিশ্চয়ই ধ্বংস করতে যাচ্ছি, কেননা এর বাসিন্দারা অন্যায়াচারী হয়ে রয়েছে।’’\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmccclxxii{তিনি বললেন -- ''এর মধ্যে তো লূতও রয়েছেন।’’ তারা বলল -- ''আমরা ভাল জানি কারা সেখানে রয়েছে। আমরা অবশ্যই তাঁকে ও তাঁর পরিবারবর্গকে উদ্ধার করব -- তাঁর স্ত্রী ব্যতীত, সে হচ্ছে পেছনে-পড়েথাকাদের দলের।’’\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmccclxxiii{আর যখন আমাদের বাণীবাহকরা লূতের কাছে এসেছিল, তিনি তাদের জন্য দুঃখিত হয়েছিলেন এবং তাদের জন্য অসমর্থ মনে করলেন। কিন্তু তারা বলেছিল -- ''ভয় করো না আর দুঃখও করো না। আমরা আলবৎ তোমাকে উদ্ধার করব আর তোমার পরিজনবর্গকেও -- তোমার স্ত্রীকে ব্যতীত, সে হচ্ছে পেছনে পড়ে থাকাদের দলের।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmccclxxiv{''আমরা নিশ্চয়ই এই জনপদের বাসিন্দাদের উপরে অবতীর্ণ করতে যাচ্ছি আকাশ থেকে এক দুর্যোগ, যেহেতু তারা সীমালংঘন করে চলেছিল।’’\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmccclxxv{আর আমরা নিশ্চয়ই এতে এক সুস্পষ্ট নিদর্শন রেখে গেছি সেই লোকদের জন্য যারা বুঝতে পারে।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmccclxxvi{আর মাদয়ানবাসীদের কাছে তাদের ভাই শোআইবকে। সুতরাং তিনি বলেছিলেন -- ''হে আমার স্বজাতি! আল্লাহ্‌র উপাসনা কর, আর শেষ দিনকে ভয় কর, আর পৃথিবীতে বিপর্যয় ঘটিয়ে ঘোরাঘুরি করো না।’’\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmccclxxvii{কিন্তু তারা তাঁকে প্রত্যাখ্যান করল সেজন্য এক ভূমিকম্প তাদের পাকড়ালো, কাজেই অচিরেই তারা নিজেদের বাড়িঘরে নিথরদেহী হয়ে গেল।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmccclxxviii{আর 'আদ ও ছামূদকে, তাদের বাড়িঘর থেকে তোমাদের জন্য সুস্পষ্ট করা হয়েছে। আর শয়তান তাদের কাছে তাদের কাজ- কর্মকে চিত্তাকর্ষক করেছিল, এইভাবেই সে তাদের পথ ঠেকিয়ে রেখেছিল, যদিও তারা ছিল তীক্ষদৃষ্টিসম্পন্ন।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmccclxxix{আর ক্কারূন ও ফিরআউন ও হামানকে! আর তাদের কাছে তো মূসা এসেই ছিলেন সুস্পষ্ট প্রমাণাবলী নিয়ে, কিন্তু তারা দেশে আস্ফালন করত, তাই তারা এড়িয়ে যাবার ছিল না।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmccclxxx{সুতরাং প্রত্যেককেই তার পাপের কারণে আমরা পাকড়াও করেছিলাম। অতএব তাদের মধ্যে কেউ রয়েছে যার উপরে আমরা পাঠিয়েছিলাম, এক প্রচন্ড ঝড়, আর তাদের মধ্যে কেউ রয়েছে যাকে পাকড়াও করেছিল এক মহাগর্জন, আর তাদের মধ্যে কেউ আছে যাকে আমরা পৃথিবীকে দিয়ে গ্রাস করিয়েছিলাম, আর তাদের মধ্যে কাউকে আমরা ডুবিয়ে মেরেছিলাম। আর আল্লাহ্ তাদের প্রতি জুলুম করার পাত্র নন, কিন্তু তারা তাদের নিজেদের প্রতি অন্যায়াচরণ করে চলেছিল।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmccclxxxi{যারা আল্লাহকে বাদ দিয়ে অন্য অভিভাবক গ্রহণ করে তাদের উপমা হচ্ছে মাকড়সার দৃষ্টান্তের ন্যায়, -- সে নিজের জন্য ঘর বানায়, অথচ নিঃসন্দেহ সবচেয়ে ঠুনকো বাসা হচ্ছে মাকড়সারই বাসা, -- যদি তারা জানত।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmccclxxxii{নিঃসন্দেহ আল্লাহ্ জানেন তাঁকে বাদ দিয়ে তারা বিষয়বস্তুর যা-কিছু আহ্বান করে। আর তিনিই তো মহাশত্তি শালী, পরমজ্ঞানী।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmccclxxxiii{আর এই উপমাগুলো, লোকদের জন্য আমরা এগুলো দিয়ে থাকি, আর বিজ্ঞজন ব্যতীত অন্য কেউ এগুলো বুঝতে পারে না।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmccclxxxiv{মহাকাশমন্ডলী ও পৃথিবীকে আল্লাহ্ সৃষ্টি করেছেন সত্যের সাথে। নিঃসন্দেহ এতে তো এক নিদর্শন রয়েছে মুমিনদের জন্য।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmccclxxxv{তুমি পাঠ কর ধর্মগ্রন্থ থেকে যা তোমার কাছে প্রত্যাদিষ্ট করা হয়েছে, আর নামায কায়েম কর। নিঃসন্দেহ নামায অশালীনতা ও অন্যায়াচরণ থেকে বিরত রাখে। আর আল্লাহ্‌র স্মরণই তো সর্বোত্তম। আর আল্লাহ্ জানেন তোমরা যা কর।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmmccclxxxvi{আর গ্রন্থধারীদের সঙ্গে তর্কবিতর্ক করো না যা সুন্দর সেইভাবে ব্যতীত -- তাদের ক্ষেত্রে ছাড়া যারা তাদের মধ্যে অন্যায়াচরণ করে, আর বলো -- ''আমরা বিশ্বাস করি তাতে যা আমাদের কাছে অবতীর্ণ হয়েছে আর তোমাদের কাছেও অবতীর্ণ হয়েছে, আর আমাদের উপাস্য ও তোমাদের উপাস্য একই, আর আমরা তাঁরই প্রতি আ‌ত্মসমর্পিত রয়েছি।’’\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmmccclxxxvii{আর এইভাবে আমরা তোমার কাছে গ্রন্থখানা অবতারণ করেছি। সুতরাং যাদের কাছে আমরা গ্রন্থ দিয়েছিলাম তারা এতে বিশ্বাস কবে, আর এদের মধ্যেও রয়েছে যারা এতে বিশ্বাস করে। আর অবিশ্বাসীদের ব্যতীত অন্যে আমাদের নির্দেশাবলীকে অস্বীকার করে না।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmmccclxxxviii{আর তুমি তো এর আগে কোনো গ্রন্থ থেকে পাঠ কর নি, আর তোমার ডান হাত দিয়ে তা লেখও নি, তেমন হলে ঝুটা আখ্যাদাতারা সন্দেহ করতে পারত।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmmccclxxxix{বস্তুত এটি হচ্ছে সুস্পষ্ট নির্দেশাবলী তাদের হৃদয়ে যাদের জ্ঞান দেওয়া হয়েছে। আর অন্যায়কারীরা ব্যতীত অন্য কেউ আমাদের নির্দেশাবলী অস্বীকার করে না।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmmcccxc{আর তারা বলে -- ''কেন তার প্রভুর কাছ থেকে তার নিকটে নিদর্শনসমূহ অবতীর্ণ হয় না?’’ তুমি বলো -- ''নিঃসন্দেহ নিদর্শনসমূহ কেবল আল্লাহ্‌র কাছে রয়েছে। আর আমি তো একজন স্পষ্ট সতর্ককারী মাত্র।’’\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmmcccxci{আচ্ছা, এটি কি তবে তাদের জন্য যথেষ্ট নয় যে আমরাই তো তোমার কাছে গ্রন্থখানা পাঠিয়েছি যা তাদের কাছে পাঠ করা হচ্ছে? নিঃসন্দেহ এতে রয়েছে করুণা ও স্মরণীয় বার্তা সেই লোকদের জন্য যারা ঈমান এনেছে।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmmcccxcii{তুমি বলো -- ''আমার মধ্যে ও তোমাদের মধ্যে সাক্ষী হিসেবে আল্লাহ্‌ই যথেষ্ট, তিনি জানেন যা-কিছু রয়েছে মহাকাশমন্ডলীতে ও পৃথিবীতে। আর যারা মিথ্যায় বিশ্বাস করে ও আল্লাহ্‌তে অবিশ্বাস করে তারা নিজেরাই হচ্ছে ক্ষতিগ্রস্ত।’’\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmmcccxciii{আর তারা তোমার কাছে শাস্তির জন্যে তাড়াহুড়ো করে। আর যদি না একটি নির্ধারিত কাল সাব্যস্ত থাকতো তাহলে তাদের প্রতি শাস্তি এসেই পড়তো। আর তাদের উপরে এটি অতর্কিতে এসেই পড়বে, আর তারা টেরও পাবে না!\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmmcccxciv{তারা তোমার কাছে শাস্তির জন্যে তাড়াহুড়ো করে। আর বস্তুত জাহান্নাম তো অবিশ্বাসীদের ঘিরেই রয়েছে।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmmcccxcv{সেইদিন শাস্তি তাদের লেপটে ফেলবে তাদের উপর থেকে ও তাদের পায়ের নিচে থেকে, তখন তিনি বলবেন -- ''তোমরা যা করে যাচ্ছিলে তা আস্বাদন করো।’’\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mmmcccxcvi{হে আমার বান্দারা যারা ঈমান এনেছ! আমার পৃথিবী আলবৎ প্রশস্ত, সুতরাং কেবলমাত্র আমারই তবে তোমরা উপাসনা করো।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mmmcccxcvii{প্রত্যেক সত্ত্বাই মৃত্যু আস্বাদনকারী, তারপর আমাদেরই কাছে তোমাদের ফিরিয়ে আনা হবে।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mmmcccxcviii{আর যারা ঈমান এনেছে ও সৎকর্ম করছে আমরা অবশ্যই তাদের বসবাস করাব স্বর্গোদ্যানের মাঝে উঁচু প্রাসাদে, যার নিচ দিয়ে বয়ে চলে ঝরনারাজি, তাতে তারা রইবে চিরকাল। কত উত্তম কর্তাদের পুরস্কার, --\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mmmcccxcix{যারা অধ্যবসায় অবলন্বন করে এবং তাদের প্রভুর উপরে নির্ভর করে!\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mmmcd{আর কত না জীবজন্তু রয়েছে যারা তাদের জীবিকা বহন করে না, আল্লাহ্‌ই তাদের রিযেক দান করেন এবং তোমাদেরও, আর তিনিই সর্বশ্রোতা, সর্বজ্ঞাতা।\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mmmcdi{আর তুমি যদি তাদের জিজ্ঞাসা কর -- 'কে সৃষ্টি করেছেন মহাকাশমন্ডলী ও পৃথিবী, আর সূর্য ও চন্দ্রকে নিয়ন্ত্রণ করেছেন?’ -- তারা নিশ্চয়ই বলেবে -- ''আল্লাহ্‌।’’ তাহলে কোথায় তারা ফিরে যাচ্ছে?\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mmmcdii{আল্লাহ্ তাঁর বান্দাদের মধ্যের যাকে ইচ্ছা করেন তার জন্য রিযেক প্রসারিত করেন, আর তার জন্য সঙ্কুচিতও করেন। নিঃসন্দেহ আল্লাহ্ সব বিষয়ে সর্বজ্ঞাতা।\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mmmcdiii{আর যদি তুমি তাদের জিজ্ঞাসা কর -- 'কে আকাশ থেকে পানি বর্ষণ করেন ও তার দ্বারা পৃথিবীকে তার মৃত্যুর পরে সঞ্জীবিত করেন?’ -- তারা নিশ্চয়ই বলবে -- ''আল্লাহ।’’ তুমি বলো -- ''সকল প্রশংসা আল্লাহ্‌র জন্য। কিন্তু তাদের অধিকাংশই বুঝতে পারে না।\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mmmcdiv{আর দুনিয়ার এই জীবনটা আমোদ-প্রমোদ ও খেলাধূলো বৈ তো নয়। আর নিশ্চয়ই পরকালের আবাস -- তাই তো জীবন। যদি তারা জানত!\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mmmcdv{সুতরাং তারা যখন জাহাজে আরোহণ করে তখন তারা আল্লাহ্‌কে ডাকে ধর্মবিশ্বাসে তাঁর প্রতি একনিষ্ঠ হয়ে, কিন্তু যখন তিনি ডাঙার দিকে তাদের উদ্ধার করেন তখন দেখো! তারা শরিক করে, --\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mmmcdvi{ফলে আমরা তাদের যা দান করেছিলাম তারা যেন তা অস্বীকার করতে পারে এবং ভোগবিলাসে মেতে উঠতে পারে। সুতরাং অচিরেই তারা জানতে পারবে।\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mmmcdvii{তারা কি তবে দেখে না যে আমরা পবিত্র স্থানকে নিরাপদ বানিয়েছি, তথাপি লোকদের ছিনিয়ে নেওয়া হচ্ছে এই সবের আশপাশ থেকে? তারা কি তবুও ঝুটাতেই বিশ্বাস করবে, এবং অবিশ্বাস করবে আল্লাহ্‌র অনুগ্রহে?\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mmmcdviii{আর কে বেশী অন্যায়কারী তার চাইতে যে আল্লাহ্ সন্বন্ধে মিথ্যা রচনা করে, অথবা সত্যকে প্রত্যাখ্যান করে যখন তার কাছে তা আসে? অবিশ্বাসীদের জন্য কি জাহান্নামে কোনো আবাসস্থল নেই?\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mmmcdix{পক্ষান্তরে যারা আমাদের জন্য সংগ্রাম করে, আমরা অবশ্যই তাদের পরিচালিত করব আমাদের পথগুলোয়। আর আল্লাহ্ নিশ্চয়ই সৎকর্মীদের সাথেই রয়েছেন।\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mmmcdx{\basmalahbn আলিফ, লাম, মীম।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmcdxi{রোমানজাতি পরাজিত হয়েছে --\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmcdxii{নিকটবর্তী দেশে, কিন্তু তাদের এ পরাজয়ের পরে তারা শীঘ্রই বিজয়লাভ করবে, --\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmcdxiii{বছর কয়েকের মধ্যেই। বিধান হচ্ছে আল্লাহ্‌রই -- আগেরবারে এবং পরেরবারে। আর সেইদিন মুমিনরা হর্ষোল্লাস করবে --\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmcdxiv{আল্লাহ্‌র সাহায্যের ফলে। তিনি সাহায্য করেন যাকে তিনি ইচ্ছা করেন। আর তিনি মহাশক্তিশালী, অফুরন্ত ফলদাতা।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmcdxv{এ আল্লাহ্‌র প্রতি‌শ্রুতি। আল্লাহ্ তাঁর ওয়াদার খেলাপ করেন না, কিন্তু অধিকাংশ লোকেই জানে না।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmcdxvi{তারা দুনিয়ার জীবনের বাহিরটাই জানে, কিন্তু আখেরাত সন্বন্ধে তারা নিজেরাই সম্পূর্ণ বেখেয়াল রয়েছে।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmcdxvii{তারা কি তবু নিজেদের অন্তরে ভেবে দেখে না -- আল্লাহ্ মহাকাশমন্ডলী ও পৃথিবী এবং এ দুইয়ের মধ্যে যা কিছু রয়েছে তা সৃষ্টি করেন নি বাস্তবতা ব্যতীত আর একটি নির্ধারিত কালের জন্য। আর বস্তুত লোকেদের মধ্যে অনেকেই তাদের প্রভুর সাথে মোলাকাত সন্বন্ধে সত্যিই অবিশ্বাসী।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmcdxviii{তারা কি তবে পৃথিবীতে পরিভ্রমণ করে না, তাহলে তারা দেখতে পেতো কেমন হয়েছিল তাদের পরিণাম যারা তাদের আগেকার ছিল? তারা এদের চাইতেও শক্তিতে প্রবল ছিল, আর মাটি খুড়ঁতো, আর তারা এতে এমারত গড়তো যা এরা এতে গড়েছিল তার চাইতেও বেশি, আর তাদের রসূলগণ তাদের কাছে এসেছিলেন সুস্পষ্ট প্রমাণ নিয়ে। কাজেই এটি আল্লাহ্‌র কাজ নয় যে তিনি তাদের প্রতি অন্যায় করবেন, কিন্তু তারা তাদের নিজেদেরই প্রতি অন্যায় করে যাচ্ছিল।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmcdxix{অতঃপর তাদের পরিণাম হয়েছিল মন্দ যারা মন্দ কাজ করেছিল, যেহেতু তারা আল্লাহ্‌র নির্দেশাবলী প্রত্যাখ্যান করেছিল, আর তা নিয়ে তারা হাসাহাসি করত।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmcdxx{আল্লাহ্ সৃষ্টির সূচনা করেন, তারপর তিনি তা পুনঃসৃষ্টি করেন, তারপর তাঁরই কাছে তোমাদের ফিরিয়ে আনা হবে।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmcdxxi{আর সেইদিন যখন ঘড়িঘন্টা এসে দাঁড়াবে তখন অপরাধীরা হতাশ হয়ে পড়বে।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmcdxxii{আর তাদের জন্য তাদের অংশী-দেবতাদের থেকে কোনো সুপারিশকারী থাকবে না, আর তাদের অংশীদেবতাদের সন্বন্ধে তারা অস্বীকারকারী হবে।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmcdxxiii{আর সেদিন যখন ঘড়ি-ঘন্টা এসে দাঁড়াবে তখনকার দিনে তারা আলাদা হয়ে যাবে।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmcdxxiv{সুতরাং যারা ঈমান এনেছে এবং সৎকাজ করেছে তারা তবে তৃণভূমিতে পরমানন্দ ভোগ করবে।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmcdxxv{আর যারা অবিশ্বাস পোষণ করেছিল এবং আমাদের নির্দেশাবলীতে মিথ্যারোপ করেছিল ও পরকালের মোলাকাতকেও, তাদেরই তবে শাস্তির মাঝে হাজির করা হবে।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmcdxxvi{সেজন্য আল্লাহ্‌র মহিমা ঘোষিত হোক যখন তোমরা বিকেল প্রাপ্ত হও এবং যখন তোমরা ভোরে পৌঁছাও।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmcdxxvii{আর তাঁরই জন্য সকল প্রশংসা মহাকাশমন্ডলীতে ও পৃথিবীতে, আর নিশাকালে এবং যখন তোমরা মধ্যাহ্নে পৌঁছো।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmcdxxviii{তিনি জীবন্তদের বের করে আনেন মৃতদের থেকে আর মৃতদের বের করে আনেন জীবন্তদের থেকে, আর পৃথিবীকে তিনি সঞ্জীবিত করেন তার মৃত্যুর পরে। আর এইভাবেই তোমাদের বের করে আনা হবে।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmcdxxix{আর তাঁর নিদর্শনাবলীর মধ্যে হচ্ছে যে তিনি তোমাদের সৃষ্টি করেছেন মাটি থেকে, তারপর দেখো! তোমরা হয়ে গেলে মানুষ -- ছড়িয়ে রয়েছ।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmcdxxx{আর তাঁর নিদর্শনাবলীর মধ্যে হচ্ছে যে তিনি তোমাদের মধ্যে থেকে তোমাদের জন্য সৃষ্টি করেছেন যুগলদের, যেন তোমরা তাদের মধ্যে স্বস্তি পেতে পার, আর তিনি তোমাদের মধ্যে প্রেম ও করুণা সৃষ্টি করেছেন। নিঃসন্দেহ এতে তো নিদর্শনাবলী রয়েছে সেই লোকদের জন্য যারা চিন্তা করে।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmcdxxxi{আর তাঁর নিদর্শনাবলীর মধ্যে হচ্ছে মহাকাশমন্ডলী ও পৃথিবীর সৃষ্টি, আর তোমাদের ভাষা ও তোমাদের বর্ণের বৈচিত্র। নিঃসন্দেহ এতে তো নিদর্শনাবলী রয়েছে জ্ঞানী লোকদের জন্য।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmcdxxxii{আর তাঁর নিদর্শনগুলোর মধ্যে হচ্ছে রাতে ও দিনে তোমাদের ঘুম, আর তাঁর করুণাভান্ডার থেকে তোমাদের অন্বেষণ। নিঃসন্দেহ এতে তো নিদর্শনাবলী রয়েছে সেই লোকদের জন্য যারা শোনে।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmcdxxxiii{আর তাঁর নিদর্শনগুলোর মধ্যে হচ্ছে -- তিনি তোমাদের বিদ্যুৎ দেখান ভয় ও আশারূপে, আর তিনি আকাশ থেকে পানি বর্ষণ করেন, তারপর তা দিয়ে পৃথিবীকে তার মৃত্যুর পরে সঞ্জীবিত করেন। নিঃসন্দেহ এতে তো নিদর্শনাবলী রয়েছে সেই লোকদের জন্য যারা বুদ্ধিশুদ্ধি রাখে।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmcdxxxiv{আর তাঁর নিদর্শনগুলোর মধ্যে হচ্ছে যে আকাশ ও পৃথিবী অটুট রয়েছে তাঁরই আদেশে। তারপর তিনি যখন তোমাদের এক ডাক দিয়ে ডাকেন, মাটি থেকে, তখন তোমরা বেরিয়ে আসছ।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmcdxxxv{আর যারা রয়েছে মহাকাশমন্ডলীতে ও পৃথিবীতে তারা তাঁরই। সবাই তাঁর প্রতি আজ্ঞাবহ।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmcdxxxvi{আর তিনিই সেইজন যিনি সৃষ্টির সূচনা করেছেন, তারপর তিনি তা পুনঃসৃষ্টি করেন, আর এটি তাঁর জন্য অতি সহজ। আর তাঁরই হচ্ছে সর্বোচ্চ আদর্শ মহাকাশমন্ডলীতে ও পৃথিবীতে, আর তিনিই হচ্ছেন মহাশক্তিশালী, পরমজ্ঞানী।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmcdxxxvii{তিনি তোমাদের কাছে তোমাদের মধ্যে থেকেই একটি দৃষ্টান্ত ছুড়ঁছেন -- তোমাদের ডান হাত যাদের ধরে রেখেছে তাদের মধ্যে থেকে কি তোমাদের জন্য অংশীদার রয়েছে আমরা তোমাদের যা জীবনোপকরণ দিয়েছি তাতে, -- ফলে তোমরা এতে একসমান, আর তাদের ক্ষেত্রে তোমরা ভাবনা-চিন্তা কর তোমার নিজেদের সন্বন্ধে তোমাদের ভাবনা-চিন্তার ন্যায়? এইভাবেই আমরা নির্দেশাবলী ব্যাখ্যা করি সেই লোকদের জন্য যারা বুদ্ধিশুদ্ধি রাখে।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmcdxxxviii{বস্তুত যারা অন্যায়াচরণ করে তারা জ্ঞানহীনতা বশতঃ তাদের কামনার অনুসরণ করে। সেজন্যে যাকে আল্লাহ্ পথভ্রষ্ট করেন তাকে কে সৎপথে চালিত করবে? আর তাদের জন্য সাহায্যকারীদের কেউ নেই।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmcdxxxix{অতএব তোমার মুখ ধর্মের প্রতি একনিষ্ঠভাবে কায়েম করো। আল্লাহ্‌র প্রকৃতি -- যার উপরে তিনি মানুষকে প্রতিষ্ঠিত করেছেন। আল্লাহ্‌র সৃষ্টিতে কোনো পরিবর্তন নেই। এটিই হচ্ছে সুপ্রতিষ্ঠিত ধর্ম, কিন্তু অধিকাংশ লোকেই জানে না।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmcdxl{তাঁরই দিকে একান্ত মনোযোগী হও, আর তাঁকেই ভয়ভক্তি করো, আর নামায কায়েম করো, আর মুশরিকদের অন্তর্ভুক্ত হয়ো না --\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmcdxli{তাদের দলের যারা তাদের ধর্মকে বিভক্ত করেছে আর তারা হয়ে গেছে নানা দলীয়। প্রত্যেক দলই যা তাদের কাছে রয়েছে তাতেই উল্লসিত।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmcdxlii{আর মানুষকে যখন দুঃখকষ্ট স্পর্শ করে তখন তারা তাদের প্রভুকে আহ্বান করে তাঁর প্রতি একান্ত মনোযোগী হয়ে, তারপর যখন তিনি তাদের তাঁর তরফ থেকে অনুগ্রহ আস্বাদন করান তখন দেখো! তাদের মধ্যের একদল তাদের প্রভুর সঙ্গে অংশী দাঁড় করায়, --\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmcdxliii{যেন তারা অস্বীকার করতে পারে যা আমরা তাদের প্রদান করেছিলাম। সুতরাং ''ভোগ করে নাও, কেননা শীঘ্রই তোমরা জানতে পারবে।’’\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmcdxliv{অথবা, আমরা কি তাদের কাছে কোনো দলিল পাঠিয়েছি যাতে সেটি ওরা তাঁর সঙ্গে যে অংশী দাঁড় করায় সে সন্বন্ধে কথা বলে?\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmcdxlv{আর যখন আমরা মানুষকে অনুগ্রহ আস্বাদন করাই তারা তাতে আনন্দ করে, কিন্তু তাদের উপরে যদি এসে পড়ে কোনো দুর্দশা যা তাদের হাত আগবাড়িয়েছে, দেখো! তারা হতাশ হয়ে পড়ে।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmcdxlvi{তারা কি তবে দেখে না যে আল্লাহ্ রিযেক প্রসারিত করেন যার জন্য তিনি ইচ্ছা করেন এবং সঙ্কুচিতও করেন। নিঃসন্দেহ এতে তো নিদর্শনাবলী রয়েছে সেই লোকদের জন্য যারা বিশ্বাস করে।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmcdxlvii{কাজেই নিকট আ‌ত্মীয়কে তার প্রাপ্য প্রদান করো, আর নিঃস্বকে ও পথচারীকেও। এটি তাদের জন্য শ্রেয় যারা আল্লাহ্‌র চেহারা কামনা করে, আর এরাই স্বয়ং হচ্ছে সফলকাম।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmcdxlviii{আর যা-কিছু তোমরা সুদে দিয়ে থাক যেন এটি বাড়তে পারে, -- তা কিন্তু আল্লাহ্‌র সমক্ষে বাড়বে না। আর যা তোমরা দিয়ে থাক যাকাতে আল্লাহ্‌র চেহারা কামনা করে, তাহলে এরাই স্বয়ং বহুগুণিত লাভবান হবে।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmcdxlix{আল্লাহ্‌ই সেইজন যিনি তোমাদের সৃষ্টি করেছেন, তারপর তোমাদের জীবিকা দিয়েছেন, তারপর তিনি তোমাদের মৃত্যু ঘটাবেন, তারপর তিনি তোমাদের জীবনদান করবেন। তোমাদের অংশীদারদের মধ্যে কি কেউ আছে যে করতে পারে এগুলোর মধ্যের কোনো কিছু? সকল মহিমা তাঁরই, আর তারা যে-সব অংশী দাঁড় করায় সে-সব থেকে তিনি বহু ঊর্ধ্বে।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmcdl{বিপর্যয় দেখা দিয়েছিল স্থলে ও জলে মানুষের হাত যা অর্জন করেছিল তার ফলে, যেন তিনি তাদের আস্বাদন করাতে পারেন যা তারা করেছিল তার কিছুটা, যাতে তারা হয়তো ফিরে আসতে পারে।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmcdli{বলো -- ''তোমরা পৃথিবীতে পরিভ্রমণ করো এবং দেখো কেমন হয়েছিল তাদের পরিণাম যারা পূর্বে অধিষ্ঠিত ছিল। তাদের অধিকাংশই ছিল মুশরিক।’’\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmcdlii{অতএব তোমার মুখ সুপ্রতিষ্ঠিত রাখ শাশ্বত ধর্মের প্রতি, সেইদিন আসার আগে -- আল্লাহ্‌র কাছ থেকে যার কোনো প্রতিরোধ নেই, সেইদিন তারা বিচ্ছিন্ন হয়ে যাবে।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmcdliii{যে কেউ অবিশ্বাস করে, তার উপরেই তবে তার অবিশ্বাস, আর যে কেউ সৎকর্ম করে, তাহলে তাদের নিজেদের জন্যেই তারা সুখশয্যা পাতে, --\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmcdliv{যেন তিনি তাঁর করুণাভান্ডার থেকে পুরস্কৃত করতে পারেন তাদের যারা ঈমান এনেছে ও সৎকাজ করছে। তিনি অবিশ্বাসীদের নিশ্চয়ই ভালবাসেন না।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmmcdlv{আর তাঁর নিদর্শনগুলোর মধ্যে হচ্ছে যে তিনি বায়ুপ্রবাহ পাঠান সুসংবাদদাতারূপে, যেন তিনি তোমাদের আস্বাদন করাতে পারেন তাঁর অনুগ্রহ থেকে, আর যেন জাহাজগুলি বিচরণ করতে পারে তাঁর বিধানে, আর যেন তোমরা অন্বেষণ করতে পার তাঁর করুণাভান্ডার থেকে, যেন তোমরা কৃতজ্ঞতা জ্ঞাপন করতে পার।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmmcdlvi{আর আমরা তো নিশ্চয়ই তোমার আগে রসূলগণকে পাঠিয়েছিলাম তাঁদের স্বজাতির কাছে, সুতরাং তাঁরা তাদের কাছে এসেছিলেন সুস্পষ্ট প্রমাণাবলী নিয়ে, তারপর যারা অপরাধ করেছিল তাদের থেকে আমরা পরিণতি নিয়েছিলাম। আর আমাদের উপরে দায়িত্ব বর্তেছে মুমিনদের সাহায্য করা।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmmcdlvii{আল্লাহ্‌ই তিনি যিনি বায়ুপ্রবাহ পাঠান। তারপর তারা মেঘ সঞ্চার করে, তখন তিনি যেমন ইচ্ছা করেন তা ছড়িয়ে দেন আকাশের মধ্যে, তারপর একে তিনি টুকরো টুকরো করেন, ফলে তোমরা দেখতে পাও তার নিচে থেকে বৃষ্টি বেরিয়ে আসছে, অতঃপর যখন তিনি তা পড়তে দেন তাঁর বান্দাদের যাকে তিনি ইচ্ছা করেন তার উপরে, দেখো! তারা উল্লাস করে, --\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmmcdlviii{যদিও ইতিপূর্বে এটি তাদের উপরে বর্ষণের আগে পর্যন্ত তারা ছিল নিশ্চিত নিরাশ।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmmcdlix{অতএব তাকিয়ে দেখ আল্লাহ্‌র অনুগ্রহের চিহগুলোর প্রতি -- কেমন ক’রে তিনি পৃথিবীকে সঞ্জীবিত করেন তার মৃত্যুর পরে। নিঃসন্দেহ এইভাবে তিনি নিশ্চয়ই মৃতের জীবন-দাতা। আর তিনি সব কিছুতেই সর্বশক্তিমান।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmmcdlx{আর যদি আমরা বায়ুপ্রবাহ পাঠাই আর তারা তা দেখে হলদে হয়ে গেছে, তার পরেও তারা অবিশ্বাস করতেই থাকবে।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmmcdlxi{সুতরাং তুমি নিশ্চয়ই মৃতকে শোনাতে পারবে না, আর বধিরকেও তুমি আহ্বান শোনাতে পারবে না, যখন তারা ফিরে যায় পিছু হটে।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmmcdlxii{আর তুমি অন্ধদেরও তাদের পথভ্রষ্টতা থেকে পথপ্রদর্শক হতে পারবে না। তুমি তো শোনাতে পার শুধু তাকে যে আমাদের বাণীসমূহে বিশ্বাস করে, ফলে তারা মুসলিম হয়।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmmcdlxiii{আল্লাহ্‌ই তিনি যিনি তোমাদের সৃষ্টি করেছেন শক্তিহীন দশা থেকে, তার পরে তিনি শক্তিহীনতার পরে দিয়েছেন শক্তি, তার পর শক্তিলাভের পরে তিনি দিয়েছেন শক্তিহীনতা ও পাকাচুল। তিনি যা চান তাই সৃষ্টি করেন, আর তিনিই সর্বজ্ঞাতা, পরম ক্ষমতাবান।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmmcdlxiv{আর যেদিন ঘড়িঘন্টা সংস্থাপিত হবে তখন অপরাধীরা শপথ করে বলবে যে এক ঘড়ি ব্যতীত তারা অবস্থান করে নি। এইভাবেই তারা প্রতারিত হয়ে চলেছে।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mmmcdlxv{আর যাদের জ্ঞান ও বিশ্বাস দেওয়া হয়েছে তারা বলবে -- ''তোমরা তো আল্লাহ্‌র বিধান অনুসারে অবস্থান করেছিলে পুনরুত্থানের দিন পর্যন্ত, -- সেজন্য এই-ই হচ্ছে পুনরুত্থানের দিন, কিন্তু তোমরা না-জানা অবস্থায় রয়েছ।’’\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mmmcdlxvi{সুতরাং সেইদিন যারা অন্যায় করেছিল তাদের ওজর আপত্তি কোনো কাজে আসবে না, আর তাদের সদয়ভাবে লওয়াও হবে না।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mmmcdlxvii{আর আমরা নিশ্চয়ই লোকেদের জন্য এই কুরআনে সব রকমের দৃষ্টান্ত থেকেই প্রস্তাবনা করেছি। আর তুমি যদি তাদের কাছে একটি নিদর্শন নিয়েও আস তথাপি যারা অবিশ্বাস করে তারা অবশ্যই বলবে -- ''তুমি ঝুটো বৈ তো নও।’’\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mmmcdlxviii{এইভাবে আল্লাহ্ একটি মোহর মেরে দেন তাদের হৃদয়ে যারা জানে না।\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mmmcdlxix{অতএব তুমি অধ্যবসায় চালিয়ে যাও, নিঃসন্দেহ আল্লাহ্‌র ওয়াদা ধ্রুব-সত্য। আর যারা দৃঢ়বিশ্বাস রাখে না তারা যেন তোমাকে বিচলিত করতে না পারে।\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mmmcdlxx{\basmalahbn আলিফ, লাম, মীম।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmcdlxxi{এগুলো হচ্ছে জ্ঞানগর্ভ গ্রন্থের আয়াতসমূহ, --\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmcdlxxii{এক পথনির্দেশ ও করুণা সৎকর্মশীলদের জন্য, --\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmcdlxxiii{যারা নামায কায়েম করে, ও যাকাত আদায় করে, আর তারা আখেরাত সন্বন্ধে দৃঢ়বিশ্বাস রাখে।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmcdlxxiv{এরাই হচ্ছে তাদের প্রভুর কাছ থেকে হেদায়তের উপরে আর এরা নিজেরাই হচ্ছে সফলকাম।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmcdlxxv{আর লোকদের মধ্যে কেউ-কেউ আছে যে খোশগল্পের বেচা-কেনা করে যেন সে আল্লাহ্‌র পথ থেকে বিচ্যুত করতে পারে কোনো জ্ঞান না রেখেই, আর যেন সে এগুলোকে ঠাট্টাবিদ্রূপ আকারে গ্রহণ করে। এরাই -- এদেরই জন্য রয়েছে লাঞ্ছনাদায়ক শাস্তি।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmcdlxxvi{আর তার কাছে যখন আমাদের নির্দেশাবলী পাঠ করা হয় তখন সে গর্বভরে ফিরে যায় যেন সে এসব শুনতে পায় নি, যেন তার কান দুটোয় ভারী বস্তু রয়েছে। অতএব তাকে মর্মন্তুদ শাস্তির খোশখবর দাও।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmcdlxxvii{নিঃসন্দেহ যারা ঈমান এনেছে ও সৎকর্ম করছে তাদের জন্য রয়েছে আনন্দময় উদ্যানসমূহ --\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmcdlxxviii{সেখানে তারা স্থায়ীভাবে অবস্থান করবে। এ আল্লাহ্‌র একান্ত সত্য ওয়াদা। আর তিনিই হচ্ছেন মহাশক্তিশালী, পরমজ্ঞানী।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmcdlxxix{তিনি মহাকাশমন্ডলীকে সৃষ্টি করেছেন কোনো খুঁটি ছাড়াই, -- তোমরা তা দেখতেই পাচ্ছ, আর তিনি পৃথিবীতে স্থাপন করেছেন পর্বতমালা পাছে এটি তোমাদের নিয়ে ঢলে পড়ে, আর এতে তিনি ছড়িয়ে দিয়েছেন হরেক রকমের জীবজন্তু। আর আকাশ থেকে তিনি বর্ষণ করেন পানি, তারপর তিনি এতে উৎপাদন করেন সব রকমের হিতকর জোড়া।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmcdlxxx{এইসব আল্লাহ্‌র সৃষ্টি! সুতরাং আমাকে দেখাও তো কী সৃষ্টি করতে পেরেছে তিনি ব্যতীত অন্যেরা। বস্তুত অন্যায়কারীরা তো স্পষ্ট বিভ্রান্তিতে রয়েছে।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmcdlxxxi{আর ইতিপূর্বে আমরা লুকমানকে জ্ঞান দান করেছিলাম এই বলে -- ''আল্লাহ্‌র প্রতি কৃতজ্ঞতা প্রকাশ করো। আর যে, কেউ কৃতজ্ঞতা প্রকাশ করে সে তো কৃতজ্ঞতা দেখায় নিজেরই জন্যে, আর যে-কেউ অকৃতজ্ঞতা দেখায় আল্লাহ্ তো তবে স্বয়ংসমৃদ্ধ, পরম প্রশংসিত।’’\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmcdlxxxii{আর স্মরণ করো! লুকমান তাঁর ছেলেকে বললেন যখন তিনি তাকে উপদেশ দিচ্ছিলেন -- ''হে আমার পুত্র, আল্লাহ্‌র সঙ্গে তুমি শরিক করো না, নিঃসন্দেহ বহুখোদাবাদ তো গুরুতর অপরাধ।’’\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmcdlxxxiii{আর আমরা মানুষকে তার পিতামাতার সম্পর্কে নির্দেশ দিয়েছি -- তার মাতা তাকে গর্ভে ধারণ করেছিলে কষ্টের উপরে কষ্ট ক’রে, আর তার লালন-পালনে দুটি বছর, -- এই বলে -- ''আমার প্রতি ও তোমার পিতামাতার প্রতি কৃতজ্ঞতা জ্ঞাপন করো। আমারই নিকটে প্রত্যাবর্তনস্থান।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmcdlxxxiv{''কিন্তু যদি তারা তোমার সঙ্গে পীড়া-পীড়ি করে যেন তুমি আমার সাথে অংশী দাঁড় করাও যে সন্বন্ধে তোমার কাছে কোনো জ্ঞান নেই, তাহলে তাদের উভয়ের আজ্ঞাপালন করো না, তবে তাদের সঙ্গে এই দুনিয়াতে সদ্ভাবে বসবাস করো। আর তার পথ অবলন্বন করো যে আমার প্রতি বিনয়াবনত হয়েছে, অতঃপর আমারই কাছে তোমাদের প্রত্যাবর্তনস্থান, তখন আমি তোমাদের জানিয়ে দেব যা তোমরা করে যাচ্ছিলে।’’\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmcdlxxxv{''হে আমার পুত্র, এটি নিশ্চিত যে যদি সরষের একটি দানার ওজন-পরিমাণও কোনো কিছু রয়ে থাকে আর এটি যদি থাকে কোনো শিলাগর্ভে অথবা মহাকাশমন্ডলের মধ্যে কিংবা পৃথিবীর অভ্যন্তরে, আল্লাহ্ এটিকে নিয়ে আসবেন। নিঃসন্দেহ আল্লাহ্ গুপ্ত বিষয়ে জ্ঞাতা, পূর্ণ ওয়াকিফহাল।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmcdlxxxvi{''হে আমার পুত্র, নামায কায়েম করো, আর সৎকাজের নির্দেশ দিয়ো ও অসৎকাজে নিষেধ করো, আর তোমার উপরে যাই ঘটুক তা সত্ত্বেও অধ্যবসায় চালিয়ে যাও। নিঃসন্দেহ এটিই হচ্ছে দৃঢ়সংকল্পজনক কার্যাবলীর মধ্যেকার।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmcdlxxxvii{''আর মানুষের প্রতি তোমার চিবুক ঘুরিয়ে নিও না, আর পৃথিবীতে গর্বভরে চলাফেরা কর না। নিঃসন্দেহ আল্লাহ্ প্রত্যেকটি উদ্ধত অহংকারীকে ভালবাসেন না।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmcdlxxxviii{''বরং তোমার চলাফেরায় তুমি সুসংযত থেকো, আর তোমার কন্ঠস্বর তুমি নিচু রেখো। নিঃসন্দেহ সমস্ত আওয়াজের মধ্যে সর্বাপেক্ষা কর্কশ হচ্ছে গাধারই আওয়াজ।’’\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmcdlxxxix{তোমরা কি দেখতে পাও নি যে আল্লাহ্ তোমাদের জন্য অনুগত করে দিয়েছেন যা কিছু রয়েছে মহাকাশমন্ডলীতে ও যা কিছু আছে পৃথিবীতে, আর তোমাদের প্রতি তিনি পূর্ণমাত্রায় অর্পণ করেছেন তাঁর অনুগ্রহসামগ্রী -- প্রকাশ্য ও অপ্রকাশ্য? আর লোকেদের মধ্যে এমনও আছে যে আল্লাহ্ সন্বন্ধে বাক্‌-বিতন্ডা করে কোনো জ্ঞান ছাড়াই ও কোনো পথনির্দেশ ব্যতীত এবং উজ্জ্বল গ্রন্থ ব্যতিরেকে।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmcdxc{আর যখন তাদের বলা হয় -- ''আল্লাহ্ যা অবতারণ করেছেন তা অনুসরণ করো’’, তারা বলে -- ''না, আমরা অনুসরণ করব আমাদের বাপদাদাদের যাতে পেয়েছি তার।’’ কি, যদিও শয়তান তাদের ডেকে নিয়ে যায় জ্বলন্ত আগুনের শাস্তির দিকে?\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmcdxci{আর যে তার মুখ আল্লাহ্‌র প্রতি পূর্ণ সমর্পণ করে আর সে সৎকর্মপরায়ণ হয়, তাহলে তো সে এক মজবুত হাতল পাকড়ে ধরেছে। আর আল্লাহ্‌র কাছেই রয়েছে সকল বিষয়ের পরিণাম।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmcdxcii{আর যে অবিশ্বাস পোষণ করে তার অবিশ্বাস তবে যেন তোমাকে কষ্ট না দেয়। আমাদেরই কাছে তাদের প্রত্যাবর্তন, কাজেই আমরা তাদের জানিয়ে দেব যা তারা করত। নিঃসন্দেহ অন্তরের অভ্যন্তরে যা রয়েছে আল্লাহ্ সে সন্বন্ধে সর্বজ্ঞাতা।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmcdxciii{আমরা তাদের অল্পসময়ের জন্য উপভোগ করতে দেব, তাদের তাড়িয়ে নেব প্রচন্ড শাস্তির দিকে।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmcdxciv{আর তুমি যদি তাদের জিজ্ঞাসা করো -- ''কে মহাকাশমন্ডলী ও পৃথিবী সৃষ্টি করেছেন?’’ -- তারা নিশ্চয় বলবে -- ''আল্লাহ্‌।’’ তুমি বলো -- ''সকল প্রশংসা আল্লাহ্‌র।’’ কিন্তু তাদের অধিকাংশই জানে না।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmcdxcv{মহাকাশমন্ডলীতে ও পৃথিবীতে যা-কিছু আছে তা আল্লাহ্‌রই। নিঃসন্দেহ আল্লাহ্‌, -- তিনিই স্বয়ং-সমৃদ্ধ, পরম প্রশংসার্হ।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmcdxcvi{আর যদি গাছপালার যা-কিছু পৃথিবীতে আছে তা কলম হয়ে যেত, আর সমুদ্র -- এর পরে সাত সমুদ্র এর সাথে যোগ করে দেওয়া হত, আল্লাহ্‌র কলিমাহ শেষ করা যাবে না। নিঃসন্দেহ আল্লাহ্ মহাশক্তিশালী, পরমজ্ঞানী।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmcdxcvii{তোমাদের সৃষ্টি এবং তোমাদের পুনরুত্থান একজনমাত্র লোকের অনুরূপ বৈ তো নয়। নিঃসন্দেহ আল্লাহ্ সর্বশ্রোতা, সর্বদ্রষ্টা।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmcdxcviii{তুমি কি দেখ নি যে তিনি রাতকে দিনের ভেতরে ঢুকিয়ে দেন এবং দিনকে ঢুকিয়ে দেন রাতের ভেতরে, এবং সূর্য ও চন্দ্রকে তিনি অনুগত করেছেন, প্রত্যেকটিই এক নির্দিষ্ট কাল পর্যন্ত বিচরণ করে, আর তোমরা যা কর সে-সন্বন্ধে আল্লাহ্ নিশ্চয়ই পূর্ণ ওয়াকিফহাল?\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmcdxcix{এটিই, কেননা নিঃসন্দেহ আল্লাহ্ -- তিনিই চরম সত্য, আর কেননা তাঁকে বাদ দিয়ে তারা যাকে ডাকে তা মিথ্যা, আর কেননা আল্লাহ্‌, -- তিনিই সমুচ্চ, মহামহিম।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmd{তুমি কি দেখছ না যে জাহাজগুলো সমুদ্রে ভেসে চলে আল্লাহ্‌রই অনুগ্রহে, যেন তিনি তোমাদের দেখাতে পারেন তাঁর নিদর্শনগুলো থেকে? নিঃসন্দেহ এতে তো নিদর্শনাবলী রয়েছে প্রত্যেক অধ্যবসায়ী কৃতজ্ঞদের জন্য।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmdi{আর যখন কোনো ঢেউ তাদের ঢেকে ফেলে ঢাকনার ন্যায় তখন তারা আল্লাহ্‌কে ডাকে তাঁর প্রতি আনুগত্যে বিশুদ্ধাচিত্ত হয়ে। কিন্তু যখন তিনি তাদের উদ্ধার করেন তীরের দিকে, তখন তাদের মধ্যে কেউ কেউ মধ্যম পন্থায় থাকে। আর আমাদের নিদর্শনাবলী নিয়ে কেউ বচসা করে না প্রত্যেক বিশ্বাসঘাতক অকৃতজ্ঞ ব্যতীত।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmdii{ওহে মানবজাতি! তোমাদের প্রভুকে ভয়-ভক্তি করো, আর সেই দিনকে ভয় করো যখন কোনো পিতা তার সন্তানের কোনো কাজে আসবে না, আর না কোনো সন্তানের ক্ষেত্রেও যে সে কোনোও ব্যাপারে কার্যকর হবে তার পিতামাতার জন্যে। নিঃসন্দেহ আল্লাহ্‌র ওয়াদা চিরন্তন সত্য, সেজন্যে এই দুনিয়ার জীবন যেন তোমাদের প্রবঞ্চনা না করুক।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmdiii{নিঃসন্দেহ আল্লাহ্ -- তাঁর কাছেই রয়েছে ঘড়িঘন্টার জ্ঞান, আর তিনি বর্ষণ করেন বৃষ্টি, আর তিনি জানেন কি আছে জরায়ুর ভেতরে। আর কোনো সত্ত্বা জানে না কী সে অর্জন করবে আগামীকাল। আর কোনো সত্ত্বা জানে না কোন দেশে সে মারা যাবে। নিঃসন্দেহ আল্লাহ্ সর্বজ্ঞাতা, পূর্ণ-ওয়াকিফহাল।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmdiv{\basmalahbn আলিফ, লাম, মীম।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmdv{গ্রন্থখানার অবতারণ, এতে কোনো সন্দেহ নেই, বিশ্বজগতের প্রভুর কাছ থেকে।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmdvi{না কি তারা বলে যে তিনি এটি রচনা করেছেন? না, এটি মহাসত্য তোমার প্রভুর কাছ থেকে যেন তুমি সতর্ক করতে পার এমন এক জাতিকে যাদের কাছে তোমরা আগে কোনো সতর্ককারী আসেন নি, যাতে তারা সৎপথে চলতে পারে।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmdvii{আল্লাহ্‌ই তিনি যিনি মহাকাশমন্ডলী ও পৃথিবী এবং এ দুইয়ের মধ্যবর্তী সব-কিছু সৃষ্টি করেছেন ছয় দিনে, তারপর তিনি অধিষ্ঠিত হলেন আরশের উপরে। তাঁকে বাদ দিয়ে তোমাদের জন্য অভিভাবক কেউ নেই আর সুপারিশকারীও নেই। তবুও কি তোমরা মনোযোগ দেবে না?\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmdviii{মহাকাশ থেকে পৃথিবী পর্যন্ত বিষয়-কর্ম তিনি পরিচালনা করেন, তারপর এটি তাঁর দিকে উঠে আসবে একদিন যার পরিমাপ হচ্ছে তোমরা যা গণনা কর তার এক হাজার বছর।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmdix{এজনই হচ্ছেন অদৃশ্যের ও প্রকাশ্যের পরিজ্ঞাতা, মহাশক্তিশালী, অফুরন্ত ফলদাতা, --\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmdx{যিনি সুন্দর করেছেন প্রত্যেকটি জিনিস যা তিনি সৃষ্টি করেছেন, আর তিনি মানুষ সৃষ্টির সূচনা করেছেন কাদা থেকে।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmdxi{তারপর তার বংশধর সৃষ্টি করলেন এক তুচ্ছ তরল পদার্থের নির্যাস থেকে।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmdxii{তারপর তিনি তাকে সুঠাম করলেন, এবং তাতে ফুঁকে দিলেন তাঁর আ‌ত্মা থেকে, আর তোমাদের জন্য তৈরি করলেন শ্রবণশক্তি ও দর্শনশক্তি ও অন্তঃকরণ। অল্পমাত্রায়ই তোমরা কৃতজ্ঞতা জ্ঞাপন কর।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmdxiii{আর তারা বলে -- ''কি, যখন আমরা মাটিতে মিলিয়ে যাই, তখন কি আমরা নতুন সৃষ্টিতে পৌঁছব?’’ বস্তুত তারা তাদের প্রভুর সাথে মুলাকাত হওয়া সন্বন্ধে অবিশ্বাসী।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmdxiv{তুমি বলো -- ''মালাকুল মউত যার উপরে তোমাদের কার্যভার দেওয়া হয়েছে সে-ই তোমাদের মৃত্যু ঘটাবে, তারপর তোমাদের প্রভুর কাছেই তোমাদের ফিরিয়ে আনা হবে।’’\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmdxv{আর তুমি যদি দেখতে পেতে যখন অপরাধীরা তাদের মাথা হেঁট করবে তাদের প্রভুর সামনে -- ''আমাদের প্রভু! আমরা দেখতে পাচ্ছি ও শুনতে পাচ্ছি, সুতরাং আমাদের ফেরত পাঠিয়ে দাও, আমরা সৎকর্ম করব, নিঃসন্দেহ আমরা সুনিশ্চিত।’’\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmdxvi{আর আমরা যদি চাইতাম তবে আমরা প্রত্যেক ব্যক্তিকে দিতাম তার পথনির্দেশ, কিন্তু আমার থেকে বক্তব্য ন্যায়সংগত হয়েছে -- 'আমি আলবৎ জাহান্নামকে ভর্তি করবো একই সঙ্গে জিনদের ও মানুষদের থেকে।’\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmdxvii{সেজন্য -- ''আস্বাদন করো, যেহেতু তোমাদের এই দিনটির সাক্ষাৎ পাওয়াকে তোমারা ভুলে গিয়েছিলে। আমরাও তাইতো তোমাদের ভুলে গেছি, কাজেই তোমরা দীর্ঘস্থায়ী শাস্তি আস্বাদন করো যা তোমরা করে চলেছিলে সেজন্য।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmdxviii{কেবল তারাই আমাদের নির্দেশাবলীতে বিশ্বাস করে যারা, যখন তাদের এসব স্মরণ করিয়ে দেওয়া হয়, সিজদারত হয়ে লুটিয়ে পড়ে, আর তাদের প্রভুর প্রশংসার সাথে জপতপ করে, আর তারা গর্ববোধ করে না।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmdxix{তারা বিছানা থেকে তাদের পার্শ্ব ত্যাগ করে তাদের প্রভুকে ডাকতে ডাকতে ভয়ে ও আশায়, আর আমরা তাদের যা রিযেক দিয়েছি তা থেকে তারা খরচ করে।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmdxx{সুতরাং কোনো সত্ত্বা জানে না চোখজুড়ানো কী তাদের জন্য লুকোনো রয়েছে, -- একটি পুরস্কার যা তারা করে যাচ্ছিল তার জন্য।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmdxxi{তাহলে কি যে মুমিন সে তার মতো যে সত্যত্যাগী? তারা সমতুল্য নয়।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmdxxii{যারা বিশ্বাস করেছে ও সৎকর্ম করছে তাদের জন্য তবে রয়েছে চির-উপভোগ্য উদ্যান -- একটি প্রীতি-সংবর্ধনা যা তারা করে যাচ্ছিল তার জন্য।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmdxxiii{কিন্তু তাদের ক্ষেত্রে যারা সীমালংঘন করেছে তাদের আবাস হচ্ছে আগুন। যতবার তারা সেখান থেকে বেরিয়ে আসতে চাইবে তাদের তাতে ফিরিয়ে আনা হবে, আর তাদের বলা হবে -- ''আগুনের শাস্তি আস্বাদন করো যেটিকে তোমরা মিথ্যা বলতে।’’\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmdxxiv{আর আমরা অবশ্যই লঘু শাস্তি থেকে তাদের আস্বাদন করাব বৃহত্তর শাস্তির উপরি, যেন তারা ফিরে আসে।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmdxxv{আর কে তার চাইতে বেশী অন্যায়কারী যাকে তার প্রভুর নির্দেশাবলী দ্বারা উপদেশ দেওয়া হয়েছে, তথাপি সে তা থেকে ফিরে যায়? নিঃসন্দেহ অপরাধীদের থেকে আমরা পরিণতি আদায় করেই থাকি।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmdxxvi{আর আমরা নিশ্চয়ই মূসাকে ধর্মগ্রন্থ দিয়েছিলাম, কাজেই তাঁর প্রাপ্তি সন্বন্ধে তুমি সন্দেহের মধ্যে থেকো না, আর আমরা এটিকে বানিয়েছিলাম ইসরাইলের বংশধরদের জন্য এক পথনির্দেশ।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmdxxvii{আর আমরা তাদের মধ্যে থেকে নেতা দাঁড় করিয়েছিলাম যাঁরা আমাদের নির্দেশের দ্বারা পথনির্দেশ দিতেন যতদিন তারা অধ্যবসায় করত, আর তারা আমাদের নির্দেশাবলী সন্বন্ধে দৃঢ়বিশ্বাস রাখত।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmdxxviii{নিঃসন্দেহ তোমার প্রভু -- তিনি কিয়ামতের দিনে তাদের মধ্যে ফয়সালা করবেন সেই বিষয়ে যাতে তারা মতবিরোধ করত।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmdxxix{এটি কি তাদের জন্য পথনির্দেশ করে না -- তাদের পূর্বে মানবগোষ্ঠীর মধ্যে কত যে আমরা ধ্বংস করেছি যাদের বাড়িঘরের মধ্যে তারা চলাফেরা করেছে? নিঃসন্দেহ এতে তো নিদর্শনাবলী রয়েছে। তবুও কি তারা শুনবে না?\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmdxxx{তারা কি তথাপি দেখে না যে আমরা পানি প্রবাহিত করে নিই অনুর্বর মাটিতে, তখন তার সাহায্যে আমরা উদগত করি ফসল যা থেকে আহার করে তাদের গবাদি-পশু ও তারা নিজেরা? তবুও কি তারা দেখবে না?\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmdxxxi{আর তারা বলে -- ''কখন এই বিজয় ঘটবে, যদি তোমরা সত্যবাদী হও?’’\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmdxxxii{বলো -- ''বিজয়ের দিনে যারা অবিশ্বাস পোষণ করে তাদের বিশ্বাসে কোনো উপকার হবে না, আর তাদের প্রতীক্ষা করতে হবে না।’’\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmdxxxiii{অতএব তাদের থেকে তুমি ফিরে এস এবং ইন্তাজার কর, নিঃসন্দেহ তারাও প্রতীক্ষারত রয়েছে।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmdxxxiv{\basmalahbn হে প্রিয় নবী! আল্লাহ্‌কে ভয়-ভক্তি করো আর অবিশ্বাসীদের ও মুনাফিকদের আজ্ঞাপালন করো না। নিঃসন্দেহ আল্লাহ্ সর্বজ্ঞাতা, পরমজ্ঞানী।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmdxxxv{আর তুমি অনুসরণ করো তোমার প্রভুর কাছ থেকে তোমার নিকট যা প্রত্যাদেশ করা হয়েছে। নিশ্চয়ই তোমরা যা কর সে-সন্বন্ধে আল্লাহ্ পূর্ণ ওয়াকিফহাল।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmdxxxvi{আর আল্লাহ্‌র উপরে নির্ভর করো। বস্তুত কর্ণধাররূপে আল্লাহ্‌ই যথেষ্ট।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmdxxxvii{আল্লাহ্ কোনো মানুষের জন্য তার ধড়ের মধ্যে দুটি হৃদয় বানান নি, আর তোমাদের স্ত্রীদেরও যাদের থেকে তোমরা 'যিহার’ ক’রে ফিরে গেছ তাদের তিনি তোমাদের মা বানান নি, আর তোমাদের পোষ্য-সন্তানদেরও তোমাদের সন্তান বানান নি। এ-সব হচ্ছে তোমাদের মুখ দিয়ে তোমাদের কথা। আর আল্লাহ্‌ই সত্যকথা বলেন, আর তিনিই পথে পরিচালিত করেন।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmdxxxviii{তোমরা তাদের সন্বোধন কর তাদের বাপেদের নামে, এটিই আল্লাহ্‌র কাছে বেশি ন্যায়সংগত। কিন্তু যদি তোমরা তাদের পিতাদের না জানো তাহলে তারা তোমাদের ধর্ম-ভাই ও তোমাদের বন্ধুবান্ধব। আর তোমাদের উপরে কোনো অপরাধ হবে না সে-সবে যাতে তোমরা ভুল কর, কিন্তু যা তোমাদের হৃদয় মতলব আঁটে। আর আল্লাহ্ পরিত্রাণকারী, অফুরন্ত ফলদাতা।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmdxxxix{এই নবী মুমিনদের কাছে তাদের নিজেদের চেয়েও অধিক অন্তরঙ্গ, আর তাঁর পত্নীগণ হচ্ছেন তাদের মাতা। আর গর্ভজাত সম্পর্কধারীরা -- তারা আল্লাহ্‌র বিধানে একে অন্যে অধিকতর নিকটবর্তী মুমিনদের ও মুহাজিরদের চাইতে, তবে তোমরা যেন তোমাদের বন্ধুবর্গের প্রতি সদাচার করো। এমনটাই গ্রন্থে লিপিবদ্ধ রয়েছে।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmdxl{আর স্মরণ কর! আমরা নবীদের থেকে তাঁদের অঙ্গীকার গ্রহণ করেছিলাম, আর তোমার কাছ থেকেও, আর নূহ ও ইব্রাহীম ও মূসা ও মরিয়ম-পুত্র ঈসার কাছ থেকে, আর তাঁদের কাছ থেকে আমরা গ্রহণ করেছিলাম এক জোরালো অংগীকার --\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmdxli{যেন তিনি সত্যবাদীদের জিজ্ঞাসা করতে পারেন তাঁদের সত্যবাদিতা সন্বন্ধে, আর অবিশ্বাসীদের জন্য তিনি প্রস্তুত রেখেছেন মর্মন্তুদ শাস্তি।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmdxlii{ওহে যারা ঈমান এনেছ! তোমাদের উপরে আল্লাহ্‌র অনুগ্রহ স্মরণ কর, যখন তোমাদের উপরে সৈন্যদল এসে পড়েছিল, তখন আমরা তাদের বিরুদ্ধে পাঠালাম এক ঝড়-ঝঞ্চা, আর এক বাহিনী যা তোমরা দেখতে পাও নি। আর তোমরা যা করছিলে সে-সন্বন্ধে আল্লাহ্ সর্বদ্রষ্টা।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmdxliii{স্মরণ করো! তারা তোমাদের উপরে এসে পড়েছিল তোমাদের উপর থেকে এবং তোমাদের চেয়ে নিচে থেকে, আর যখন চোখগুলো বিারিত হয়েছিল আর হৃৎপিন্ডগুলো পৌঁছেগিয়েছিল গলদেশে, আর তোমরা আল্লাহ্‌র সন্বন্ধে নানান ভুল ধারণা ধারণ করেছিলে।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmdxliv{সেখানে মুমিনদের পরীক্ষা করা হয়েছিল, আর তাদের ঝাঁকানো হয়েছিল কঠিন ঝাঁকানিতে।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmdxlv{আর স্মরণ করো! মুনাফিকরা ও যাদের হৃদয়ে ব্যাধি রয়েছে তারা বলছিল -- ''আল্লাহ্ ও তাঁর রসূল আমাদের কাছে প্রতারণা করা ছাড়া অন্য ওয়াদা করেন নি।’’\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmdxlvi{আর স্মরণ করো! তাদের মধ্যের একদল বলেছিল -- ''হে ইয়াছরিব-এর বাসিন্দারা! তোমাদের জন্য দাঁড়াবার জায়গা নেই, সেজন্য ফিরে যাও।’’ আর তাদের মধ্যের কোনো দল নবীর কাছে অনুমতি চাইছিল এই বলে -- ''আমাদের বাড়িঘর নিশ্চয়ই অনাবৃত।’’ কিন্তু সেগুলো অনাবৃত ছিল না। তারা তো চাইছিল কেবল পালিয়ে যেতে।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmdxlvii{আর যদি এর সীমানা থেকে তাদের উপরে অনুপ্রবেশ হত এবং তাদের বলা হত বিদ্রোহ করতে, তাহলে তারা অবশ্যই তাতে এসে পড়ত, আর তারা সেখানে অবস্থান করত না অল্পক্ষণ ছাড়া।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmdxlviii{আর ইতিপূর্বে তো তারা আল্লাহ্‌র কাছে ওয়াদা করেছিল যে তারা পিঠ ফেরাবে না। আর আল্লাহ্‌র সঙ্গের অংগীকার সন্বন্ধে সওয়াল করা হবে।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmdxlix{বলো -- ''পালিয়ে যাওয়া কখনো তোমাদের লাভবান করবে না, যদিও তোমরা মৃত্যু অথবা কাতল হওয়া থেকে পলায়ন কর, আর সে-ক্ষেত্রে তোমরা উপভোগ করতে পারবে না অল্পক্ষণ ছাড়া।’’\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmdl{তুমি বলো -- ''কে আছে যে তোমাদের আল্লাহ্‌র থেকে বাধা দিতে পারে যদি তিনি তোমাদের জন্য অনিষ্ট ইচ্ছা করেন অথবা তোমাদের জন্য অনুগ্রহ চান?’’ আর তাদের জন্য আল্লাহ্‌কে বাদ দিয়ে তারা পাবে না কোনো অভিভাবক, আর না কোনো সাহায্যকারী।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmdli{আল্লাহ্ আলবৎ জেনে গেছেন তোমাদের মধ্যের বাধাদান-কারীদের, আর যারা তাদের ভাই-বিরাদরের প্রতি বলে -- ''আমাদের সঙ্গে এখানে চলে এসো।’’ আর তারা যুদ্ধে আসে না অল্প কয়জন ছাড়া, --\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmdlii{তোমাদের প্রতি ঈর্ষান্বিত হয়ে। কিন্তু যখন কোনো বিপদ আসে তখন তুমি তাদের দেখতে পাবে তারা তোমার দিকে চেয়ে আছে, -- তাদের চোখ ঘুরছে তার মতো যে মৃত্যুর কারণে মূর্চ্ছা গেছে। তারপর যখন বিপদ চলে যায় তখন তারা তোমাদের আঘাত করে তীক্ষ জিহবা দিয়ে সৌভাগ্যের জন্য ঈর্ষান্বিত হয়ে। এরা বিশ্বাস করে নি, সেজন্য আল্লাহ্ তাদের কীর্তিকলাপ বিফল করেছেন। আর এটি তো আল্লাহ্‌র জন্য সহজ।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmdliii{তারা ভেবেছিল যে জোট-বাঁধা ফৌজ চলে যাচ্ছে না, আর যদি জোট-বাধাঁ ফৌজ আসত তবে তারা কামনা করত -- যদি তারা আরবের বেদুইন হয়েও জিজ্ঞাসাবাদ করতে পারত তোমাদের খোঁজখবর সন্বন্ধে। আর যদি তারা তোমাদের সঙ্গেও থাকে তবু তারা যুদ্ধ করত না অল্প একটু ছাড়া।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmdliv{তোমাদের জন্য নিশ্চয়ই আল্লাহ্‌র রসূলের মধ্যে রয়েছে এক অত্যুৎকৃষ্ট দৃষ্টান্ত তার জন্য যে আল্লাহ্‌কে ও আখেরাতের দিনকে কামনা করে আর আল্লাহ্‌কে প্রচুর পরিমাণে স্মরণ করে!\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmdlv{আর যখন মুমিনগণ জোট-বাঁধা ফৌজের দেখা পেল তারা বললে -- ''এটিই তো তাই যার কথা আল্লাহ্ ও তাঁর রসূল আমাদের কাছে পূর্বাভাস দিয়েছিলেন, আর আল্লাহ্ ও তাঁর রসূল সত্যকথাই বলেছিলেন। আর এটি তাদের বিশ্বাস ও আনুগত্য ব্যতীত অন্য কিছু বাড়ায় নি।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmdlvi{মুমিনদের মধ্যে এমন লোক রয়েছে যারা আল্লাহ্‌র সঙ্গে তারা যা ওয়াদা করেছে সে-সন্বন্ধে সত্যপরায়ণতা অবলন্বন করে, সেজন্যে তাদের মধ্যে কেউ-কেউ তার ব্রত পূর্ণ করেছে, আর তাদের মধ্যে কেউ-কেউ প্রতীক্ষা করছে, আর তারা কোনো বদলানো বদলায় নি, --\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmdlvii{যেন আল্লাহ্ পুরস্কৃত করতে পারেন সত্যপরায়ণদের তাদের সত্যনিষ্ঠার জন্যে, আর তিনি ইচ্ছা করলে মুনাফিকদের শাস্তি দিতে পারেন অথবা তাদের প্রতি ফিরতেও পারেন। নিঃসন্দেহ আল্লাহ্ পরিত্রাণকারী, অফুরন্ত ফলদাতা।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmdlviii{আর আল্লাহ্ প্রতিহত করেছিলেন তাদের যারা তাদের আক্রোশবশত অবিশ্বাস পোষণ করেছিল, তারা ভাল কিছুই লাভ করতে পারে নি। আর যুদ্ধে মুমিনদের জন্য আল্লাহ্ যথেষ্ট ছিলেন। আর আল্লাহ্ হচ্ছেন মহাবলীয়ান, মহাশক্তিশালী।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmdlix{আর গ্রন্থধারীদের মধ্যের যারা তাদের পৃষ্ঠপোষকতা করেছিল তাদের তিনি নামিয়ে এনেছিলেন তাদের দুর্গ থেকে, আর তাদের হৃদয়ে ভীতি সঞ্চার করেছিলেন, একদলকে তোমরা হত্যা করেছিলে ও বন্দী করেছিলে আরেক দলকে।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmdlx{আর তিনি তোমাদের উত্তরাধিকার করতে দিলেন তাদের জমিজমা ও তাদের বাড়িঘর ও তাদের ধনসম্পত্তি এবং এক দেশ যেখানে তোমরা অভিযান চালাও নি। আর আল্লাহ্ সব-কিছুর উপরেই পরম ক্ষমতাবান।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmdlxi{হে প্রিয় নবী! তোমার স্ত্রীগণকে বলো -- ''তোমরা যদি দুনিয়ার জীবনটা ও তার শোভা- সৌন্দর্য কামনা কর তাহলে এসো, আমি তোমাদের ভোগ্যবস্তুর ব্যবস্থা করে দেব এবং তোমাদের বিদায় দেব সৌজন্যময় বিদায়দানে।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmdlxii{আর যদি তোমরা আল্লাহ্‌কে ও তাঁর রসূলকে এবং আখেরাতে আবাস কামনা করে থাক তাহলে আল্লাহ্ নিশ্চয়ই তোমাদের মধ্যের সৎকর্মশীলদের জন্য প্রস্তুত করেছেন এক বিরাট প্রতিদান।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmdlxiii{হে নবীর পত্নীগণ! তোমাদের মধ্যের কেউ যদি স্পষ্ট অশালীনতা নিয়ে আসে, তারজন্য শাস্তিকে দ্বিগুণে বর্ধিত করা হবে। আর এটি আল্লাহ্‌র জন্যে সহজ।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmdlxiv{আর তোমাদের মধ্যে যে কেউ আল্লাহ্‌র প্রতি ও তাঁর রসূলের প্রতি অনুগত হবে এবং সৎকর্ম করবে, আমরা তার প্রতিদান তাকে দেব দুই দফায়, আর আমরা তার জন্য প্রস্তুত রেখেছি এক সম্মানজনক জীবিকা।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmdlxv{হে নবীর স্ত্রীগণ! তোমরা অন্য কোন স্ত্রীলোকদের মতন নও, যদি তোমরা ধর্মভীরুতা অবলন্বন কর তবে কথাবার্তায় তোমরা কোমল হয়ো না, পাছে যার অন্তরে ব্যাধি রয়েছে সে প্রলুব্ধ হয়, আর তোমরা বলো উত্তম কথাবার্তা।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmdlxvi{আর তোমাদের বাড়িতে তোমরা অবস্থান করবে, আর পূর্ববর্তী অজ্ঞানতার যুগের প্রদর্শনীর ন্যায় প্রদর্শন করো না, আর নামায কায়েম করো ও যাকাত আদায় করো, আর আল্লাহ্‌র ও তাঁর রসূলের আজ্ঞা পালন করো। নিঃসন্দেহে আল্লাহ্ চান, হে গৃহবাসিনীগণ! তোমাদের পবিত্র করতে পবিত্রতার দ্বারা।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmdlxvii{আর স্মরণ রাখো তোমাদের ঘরে যা পাঠ করা হয় আল্লাহ্‌র নির্দেশাবলী ও জ্ঞানভান্ডার থেকে। নিঃসন্দেহ আল্লাহ্ হচ্ছেন গুপ্ত বিষয়ে জ্ঞাতা, পূর্ণ ওয়াকিফহাল।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmdlxviii{নিশ্চয়ই মুসলিম পুরুষ ও মুসলিম নারী এবং মুমিন পুরুষ ও মুমিন নারী, এবং অনুগত পুরুষ ও অনুগত নারী, আর সত্যনিষ্ট পুরুষ ও সত্যনিষ্ট নারী, আর অধ্যবসায়ী পুরুষ ও অধ্যবসায়ী নারী, আর বিনয়ী পুরুষ ও বিনয়ী নারী আর দানশীল পুরুষ ও দানশীল নারী, আর রোযাদার পুরুষ ও রোযাদার নারী, আর নিজেদের আবরুরক্ষাকারী পুরুষ ও রক্ষাকারী নারী, আর আল্লাহ্‌কে বহুলভাবে স্মরণকারী পুরুষ ও স্মরণকারী নারী -- আল্লাহ্ এদের জন্য ব্যবস্থা করেছেন পরিত্রাণ ও এক বিরাট প্রতিদান।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmdlxix{আর একজন মুমিনের পক্ষে উচিত নয় বা একজন মুমিন নারীরও নয় যে যখন আল্লাহ্ ও তাঁর রসূল কোনো বিষয়ে সিদ্ধান্ত নিয়েছেন তখন তাদের সে ব্যাপারে তাদের জন্য কোনো মতামত থাকে। আর যে কেউ আল্লাহ্‌কে ও তাঁর রসূলকে অমান্য করে সে তাহলে নিশ্চয়ই বিপথে গেছে স্পষ্ট বিপথ গমনে।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmdlxx{আর স্মরণ করো! তুমি তাকে বলেছিলে যার প্রতি আল্লাহ্ অনুগ্রহ করেছেন ও যার প্রতি তুমি অনুগ্রহ করেছ -- ''তোমার স্ত্রীকে তোমার কাছেই রাখো, আর আল্লাহ্‌কে ভয়ভক্তি করো, আর তুমি তোমার অন্তরে যা লুকিয়ে রেখেছিলে আল্লাহ্ তা প্রকাশ করে দিচ্ছেন, আর তুমি মানুষকে ভয় করেছিলে, অথচ আল্লাহ্‌রই বেশী অধিকার যে তুমি তাঁকেই ভয় করবে।’’ কিন্তু যায়েদ যখন তার থেকে বিবাহবন্ধন সন্বন্ধে মীমাংসা করে ফেলল তখন আমরা তাকে তোমার সাথে বিবাহ দিলাম -- যাতে মুমিনদের উপরে কোন বাধা না থাকে তাদের পালকপুত্রদের স্ত্রীদের ব্যাপারে, যখন তারা তাদের থেকে বিবাহবন্ধন সন্বন্ধে মীমাংসা করে ফেলে। আর আল্লাহ্‌র নির্দেশ প্রতিপালিত হয়েই থাকে।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmdlxxi{নবীর জন্য কোনো বাধা নেই তাতে যা তাঁর জন্য আল্লাহ্ বিধিবদ্ধ করেছেন। আল্লাহ্‌র নিয়মনীতি তাদের ক্ষেত্রে যারা এর আগে গত হয়ে গেছে। আর আল্লাহ্‌র বিধান হচ্ছে সুনির্দিষ্টভাবে নির্ধারিত, --\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmdlxxii{যারা আল্লাহ্‌র বাণী পৌঁছে দেয় এবং তাঁকে ভয় করে, আর আল্লাহ্ ছাড়া আর কাউকেও ভয় করে না। আর আল্লাহ্‌ই যথেষ্ট হিসাব-রক্ষকরূপে।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmdlxxiii{মুহাম্মদ তোমাদের লোকেদের মধ্যের কোন একজনেরও পিতা নন, বরং তিনি হচ্ছেন আল্লাহ্‌র একজন রসূল, আর নবীগণের সীলমোহর। আর আল্লাহ্ হচ্ছেন সব-কিছুতেই সর্বজ্ঞাতা।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmdlxxiv{ওহে যারা ঈমান এনেছ! আল্লাহ্‌কে স্মরণ করো প্রচুর স্মরণে,\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmdlxxv{আর তাঁর মহিমা কীর্তন করো সকালে ও সন্ধ্যায়।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmdlxxvi{তিনিই সেইজন যিনি তোমাদে প্রতি আশীর্বাদ করেছেন আর তাঁর ফিরিশ্‌তাগণও, যেন তিনি তোমাদের বের করে আনেন অন্ধকার থেকে আলোকের দিকে। আর তিনি মুমিনদের প্রতি অফুরন্ত ফলদাতা।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmdlxxvii{যেদিন তারা তাঁর সঙ্গে মোলাকাত করবে সেদিন তাদের সম্ভাষণ হবে ''সালাম’’! আর তাদের জন্য তিনি তৈরী রেখেছেন এক মহান প্রতিদান।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmdlxxviii{হে প্রিয় নবী! আমরা নিশ্চয়ই তোমাকে পাঠিয়েছি একজন সাক্ষীরূপে, আর একজন সুসংবাদদাতারূপে, আর একজন সতর্ককারীরূপে,\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmmdlxxix{আর আল্লাহর প্রতি তাঁর অনুমতিক্রমে একজন আহবায়করূপে, আর একটি উজ্জ্বল প্রদীপরূপে।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmmdlxxx{আর মুমিনদের তুমি সুসংবাদ দাও যে তাদের জন্য আল্লাহ্‌র কাছ থেকে রয়েছে এক বিরাট করুণাভান্ডার।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmmdlxxxi{আর তুমি অবিশ্বাসীদের ও মুনাফিকদের আজ্ঞাপালন করো না, আর ওদের বিরক্তিকর ব্যবহার উপেক্ষা করো এবং আল্লাহর উপরে তুমি নির্ভর করো। আর আল্লাহই কর্ণধাররূপে যথেষ্ট।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmmdlxxxii{ওহে যারা ঈমান এনেছ! তোমরা যখন মুমিন নারীদের বিবাহ করো এবং তাদের স্পর্শ করার আগেই যদি তাদের তোমরা তালাক দিয়ে দাও, তাহলে তোমাদের জন্য তাদের উপরে ইদ্দতের কোনো-কিছু নির্ধারণ করবার থাকবে না, কিন্তু তাদের জন্য সংস্থান করো এবং তাদের বিদায় দিয়ো সৌজন্যময় বিদায়দানে।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmmdlxxxiii{হে প্রিয় নবী! আমরা তোমার জন্য তোমার স্ত্রীদের বৈধ করেছি যাদের তুমি তাদের দেনমোহর আদায় করেছ, আর যাদের তোমার ডান হাত ধরে রেখেছে, তাদের মধ্য থেকে যাদের আল্লাহ্ তোমাকে যুদ্ধের দানরূপে দিয়েছেন, আর তোমার চাচার মেয়েদের ও তোমার ফুফুর মেয়েদের এবং তোমার মামার মেয়েদের ও তোমার মাসীর মেয়েদের -- যারা তোমার সঙ্গে হিজরত করেছে, আর কোনো মুমিন নারী যদি সে নবীর কাছে নিজেকে সমর্পণ করে, যদি নবীও তাকে বিবাহ করতে চান -- এটি বিশেষ করে তোমার জন্য, মুমিনগণকে বাদ দিয়ে। আমরা অবশ্যই জানি তাদের জন্য আমরা কী বিধান দিয়েছি তাদের স্ত্রীদের সন্বন্ধে আর তাদের ডান হাত যাদের ধরে রেখেছে তাদের সন্বন্ধে, যেন তোমার উপরে বাধা না থাকে। আর আল্লাহ্ হচ্ছেন পরিত্রাণকারী, অফুরন্ত ফলদাতা।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmmdlxxxiv{তাদের মধ্য থেকে যাকে তুমি চাও মুলতুবী রাখতে পার এবং যাকে তুমি চাও তোমার কাছে গ্রহণ করতে পার, আর যাদের তুমি দূরে রেখেছিলে তাদের মধ্যের যাকে তুমি কামনা কর, তাতে তোমার কোনো দোষ হবে না। এটিই বেশী ভাল যেন তাদের চোখ হর্ষোৎফুল্ল হতে পারে ও তারা দুঃখ না করে, আর তারা সন্তষ্ট থাকে তুমি যা তাদের দিচ্ছ তাতে -- তাদের সব-ক’জনকে। আর আল্লাহ্ জানেন যা তোমাদের অন্তরে রয়েছে। আর আল্লাহ্ হচ্ছেন সর্বজ্ঞাতা, অতি অমায়িক।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmmdlxxxv{এরপরে নারীরা তোমার জন্য বৈধ নয়, আর তাও নয় যে তাদের স্থলে অন্য স্ত্রীদের তুমি বদলে নিতে পারবে, যদিও বা তাদের সৌন্দর্য তোমাকে তাজ্জব বানিয়ে দেয় -- তোমার ডান হাতে যাদের ধরে রেখেছে তাদের ব্যতীত। আর আল্লাহ্ হচ্ছেন সব-কিছুর উপরে তীক্ষদৃষ্টিধারী।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmmdlxxxvi{ওহে যারা ঈমান এনেছ! তোমরা নবীর ঘরগুলোয় প্রবেশ করো না তোমাদের খানাপিনার জন্য অনুমতি না দেওয়া হলে -- রান্নাবান্না শেষ হবার অপেক্ষা না করে, বরং যখন তোমাদের ডাকা হয় তখন তোমরা প্রবেশ করো, তারপর যখন তোমরা খেয়ে নিয়েছ তখন চলে যেও, এবং গড়িমসি করো না বাক্যালাপের জন্য। নিঃসন্দেহ এইসব নবীকে কষ্ট দিয়ে থাকে, অথচ তিনি সংকোচ বোধ করেন তোমাদের জন্য, কিন্তু আল্লাহ্ সত্য সন্বন্ধে সংকোচ করেন না। আর যখন তোমরা তাদের কাছে কোনো-কিছু চাও তখন পর্দার আড়াল থেকে তাদের কাছে চাইবে। এটিই অধিকতর পবিত্র তোমাদের হৃদয়ের জন্য এবং তাদের হৃদয়ের জন্যেও। এটি তোমাদের জন্য নয় যে তোমার নবীকে উত্ত্যক্ত করবে, আর এটিও নয় যে তার পরে তোমরা কখনো তাঁর পত্নীদের বিবাহ করবে। নিঃসন্দেহে এটি আল্লাহ্‌র কাছে গুরুতর ব্যাপার!\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmmdlxxxvii{তোমরা যদি কোনো-কিছু প্রকাশ কর অথবা তা গোপনই রাখ, আল্লাহ্ কিন্তু নিশ্চয়ই সব-কিছু সন্বন্ধে সর্বজ্ঞাতা।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmmdlxxxviii{তাদের জন্য কোনো অপরাধ নেই তাদের পিতাদের ক্ষেত্রে, আর তাদের পুত্রদের বেলায়ও নয়, আর তাদের ভাইদের ক্ষেত্রেও নয়, আর ভাইদের পুত্রদেরও নয়, আর তাদের বোনদের পুত্রদের সঙ্গেও নয়, আর তাদের মেয়েলোকদের ক্ষেত্রেও নয়, আর তাদের ডান হাত যাদের ধরে রেখেছ তাদেরও নয়, আর আল্লাহ্‌কে ভয়ভক্তি করো। নিশ্চয় আল্লাহ্ সব-কিছুর উপরেই প্রত্যক্ষদর্শী।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mmmdlxxxix{নিঃসন্দেহ আল্লাহ্ ও তাঁর ফিরিশ্‌তাগণ নবীর উপরে শুভেচ্ছা জ্ঞাপন করেন। ওহে যারা ঈমান এনেছ! তোমরাও তাঁর প্রতি শুভেচ্ছা নিবেদন করো এবং সালাম জানাও সশ্রদ্ধভাবে।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mmmdxc{নিঃসন্দেহ যারা আল্লাহ্ ও তাঁর রসূল-সন্বন্ধে মন্দ কথা বলে, আল্লাহ্ তাদের ধিক্কার দিয়েছেন ইহলোকে ও পরলোকে, আর তাদের জন্য তৈরি করেছেন লাঞ্ছনাদায়ক শাস্তি।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mmmdxci{আর যারা মুমিন পুরুষ ও মুমিন নারীদের গালমন্দ করে তারা তা অর্জন না করলেও, তারা তাহলে কুৎসা রটনার ও স্পষ্ট অপরাধের বোঝা বহন করে।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mmmdxcii{হে প্রিয় নবী! তোমার স্ত্রীগণকে ও কন্যাদের ও মুমিন-লোকের স্ত্রীলোকদের বলো যে তারা যেন তাদের বহির্বাস থেকে তাদের উপরে টেনে রাখে। এটিই বেশী ভাল হয় যেন তাদের চেনা যায়, তাহলে তাদের উত্ত্যক্ত করা হবে না। আর আল্লাহ্ পরিত্রাণকারী, অফুরন্ত ফলদাতা।\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mmmdxciii{যদি মুনাফিকরা ও যাদের অন্তরে ব্যাধি রয়েছে তারা, আর শহরে গুজব রটনাকারীরা না থামে তাহলে আমরা নিশ্চয়ই তোমাকে তাদের উপরে ক্ষমতা দেব, তখন তারা সেখানে তোমার প্রতিবেশী হয়ে থাকবে না অল্পকাল ছাড়া --\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mmmdxciv{অভিশপ্ত অবস্থায়, যেখানেই তাদের পাওয়া যাবে তাদের পাকড়াও করা হবে এবং হত্যা করা হবে হত্যার মতো।\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mmmdxcv{আল্লাহ্‌র নিয়ম-নীতি এর আগে যারা গত হয়ে গেছে তাদের ক্ষেত্রে। আর তুমি কখনো আল্লাহ্‌র বিধানে পরিবর্তন পাবে না।\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mmmdxcvi{লোকে তোমাকে ঘড়িঘন্টা সন্বন্ধে জিজ্ঞাসা করছে। তুমি বলো -- ''তার জ্ঞান তো কেবল আল্লাহ্‌রই কাছে।’’ আর কেমন করে তোমাকে বোঝানো যাবে -- হতে পারে সেই ঘড়িঘন্টা নিকটবর্তী হয়ে গেছে?\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mmmdxcvii{আল্লাহ্ নিশ্চয়ই অবিশ্বাসীদের ধিক্কার দিয়েছেন আর তাদের জন্য প্রস্তুত করেছেন এক জ্বলন্ত আগুন --\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mmmdxcviii{যাতে তারা থাকবে সুদীর্ঘকাল, তারা পাবে না কোনো অভিভাবক, আর না কোনো সহায়ক।\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mmmdxcix{সেইদিন যখন তাদের মুখ আগুনের মধ্যে উল্টানো পাল্টানো হবে তারা বলবে -- ''হায় আমাদের দুর্ভোগ! আমরা যদি আল্লাহ্‌কে মেনে চলতাম ও রসূলের আজ্ঞাপালন করতাম!’’\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mmmdc{তারা আরো বলবে -- ''আমাদের প্রভু! আমরা তো আমাদের নেতাদের ও আমাদের বড়লোকদের আজ্ঞাপালন করেছিলাম, সুতরাং তারা আমাদের পথ থেকে বিপথে নিয়েছিল।\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mmmdci{''আমাদের প্রভু! দ্বিগুণ পরিমাণ শাস্তি তাদের প্রদান করো, আর তাদের ধিক্কার দাও বিরাট ধিক্কারে।’’\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mmmdcii{ওহে যারা ঈমান এনেছ! তাদের মতো হয়ো না যারা মূসার নিন্দা করেছিল, কিন্তু আল্লাহ্ তাঁকে নির্দোষ ঠাওরে ছিলেন তারা যা বলেছিল তা থেকে। আর তিনি আল্লাহ্‌র সমক্ষে সম্মানিত ছিলেন।\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mmmdciii{ওহে যারা ঈমান এনেছ! আল্লাহ্‌কে ভয়-ভক্তি করো, আর সরল-সঠিক কথা বলো,\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@mmmdciv{তিনি তোমাদের জন্য তোমাদের ক্রিয়াকর্ম সুসম্পাদিত করতে পারেন আর তোমাদের দোষত্রুটি তোমাদের জন্য ক্ষমা করতে পারেন। আর যে কেউ আল্লাহ্‌কে ও তাঁর রসূলকে মেনে চলে সে তাহলে অবশ্যই অর্জন করেছে বিরাট মুনাফা।\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@mmmdcv{নিঃসন্দেহ আমরা আমানত অর্পণ করেছিলাম মহাকাশমন্ডলী ও পৃথিবী ও পর্বতমালার উপরে, কাজেই তারা এটি অমান্য করতে অস্বীকার করেছিল এবং এতে ভয় করছিল, কিন্তু মানুষ এটিকে অস্বীকার করছে। নিঃসন্দেহে সে হচ্ছে অত্যন্ত অন্যায়াচারী, বড়ই অজ্ঞ, --\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@mmmdcvi{সেজন্য আল্লাহ্ শান্তি দেবেন মুনাফিক পুরুষ ও মুনাফিক নারীদের, এবং বহুখোদাবাদী পুরুষ ও বহুখোদাবাদী নারীদের আর আল্লাহ্ ফিরবেন মুমিন পুরুষ ও মুমিন নারীদের প্রতি। আর আল্লাহ্ হচ্ছেন পরিত্রাণকারী, অফুরন্ত ফলদাতা।\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@mmmdcvii{\basmalahbn সমস্ত প্রশংসা আল্লাহ্‌র, তিনিই যাঁর অধীনে রয়েছে যা-কিছু আছে মহাকাশমন্ডলীতে ও যা-কিছু আছে পৃথিবীতে, আর তাঁরই সব প্রশংসা পরলোকে। আর তিনিই পরমজ্ঞানী, পূর্ণ ওয়াকিফহান।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmdcviii{তিনি জানেন যা মাটির ভেতরে প্রবেশ করে আর যা তা থেকে বেরিয়ে আসে, আর যা আকাশ থেকে নেমে আসে আর যা তাতে উঠে যায়। আর তিনিই অফুরন্ত ফলদাতা, পরিত্রাণকারী।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmdcix{আর যারা অবিশ্বাস পোষণ করে তারা বলে -- ''ঘড়িঘন্টা আমাদের উপরে আসবে না।’’ তুমি বলো -- ''হাঁ, আমার প্রভুর কসম, এটি অবশ্যই তোমাদের উপরে এসে পড়বে, তিনি অদৃশ্য সন্বন্ধে পরিজ্ঞাত। এক অণুর ওজন পরিমাণও তাঁর থেকে লুকোনো যাবে না মহাকাশমন্ডলীতে, আর পৃথিবীতেও নয়, আর তার থেকে আরো ছোটও নেই এবং বড়ও নেই, -- বরং তা লিপিবদ্ধ রয়েছে এক সুস্পষ্ট গ্রন্থে, --\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmdcx{''যেন তিনি প্রতিদান দিতে পারেন তাদের যারা ঈমান এনেছে ও সৎকাজ করেছে । এরাই -- এদেরই জন্য রয়েছে পরিত্রাণ এবং এক সম্মানিত জীবিকা।’’\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmdcxi{আর যারা আমাদের নির্দেশাবলীকে ব্যর্থ করার প্রচেষ্টা চালায়, এরাই -- এদেরই জন্য রয়েছে এক মর্মন্তুদ দুর্দশার শাস্তি।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmdcxii{আর যাদের জ্ঞান দেওয়া হয়েছে তারা দেখতে পায় যে তোমার কাছে তোমার প্রভুর কাছ থেকে যা অবতারণ করা হয়েছে তাই সত্য, আর তা পরিচালিত করে মহাশক্তিশালী পরম প্রশংসিতের পথে।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmdcxiii{আর যারা অবিশ্বাস করে তারা বলে -- ''আমরা কি তোমাদের সন্ধান দেব এমন এক ব্যক্তির যে তোমাদের জানায় যে যখন তোমরা চুরমার হয়ে গেছো পুরোপুরি চূর্ণবিচূর্ণ অবস্থায়, তখনও তোমরা কিন্তু নতুন সৃষ্টি লাভ করবে?\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmdcxiv{''সে আল্লাহ্‌র বিরুদ্ধে হয় মিথ্যা রচনা করেছে, নয়তো তার মধ্যে রয়েছে জিনভূত।’’ বস্তুতঃ যারা পরকালে বিশ্বাস করে না তারা আছে শাস্তিতে ও সুদূরপ্রসারী বিভ্রান্তিতে।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmdcxv{তারা কি তবে দেখে না তাদের সামনে কী রয়েছে আর কী রয়েছে তাদের পেছনে -- মহাকাশে ও পৃথিবীতে। আমরা যদি চাইতাম তবে তাদের সঙ্গে পৃথিবীকে ধসিয়ে দিতাম, অথবা তাদের উপরে আকাশ থেকে একটি চাঙড় ফেলে দিতাম। নিঃসন্দেহ এতে তো এক নিদর্শন রয়েছে প্রত্যাবৃত প্রত্যেক বান্দার জন্য।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmdcxvi{আর আমরা নিশ্চয়ই দাউদকে আমাদের কাছ থেকে দিয়েছিলাম করুণাভান্ডার। ''হে পাহাড়গুলো! তাঁর সঙ্গে একমুখো হও, আর পাখীরাও।’’ আর লোহাকেও আমরা তাঁর জন্য গলিয়েছিলাম,\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmdcxvii{এই বলে -- ''তুমি চওড়া বর্ম তৈরি কর, আর আংটাসমূহে যথাযথ পরিমাপ দাও, আর তোমরা সৎকর্ম কর। নিঃসন্দেহ তোমরা যা করছ আমি তার সম্যক দ্রষ্টা।’’\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmdcxviii{আর সুলাইমানের জন্য বায়ূপ্রবাহ। এর সকালবেলাকার গতি একমাস এবং এর বিকেলবেলার গতি একমাস, আর আমরা তার জন্য তামার নদী বইয়ে দিয়েছিলাম। আর তাদের মধ্যের যে কেউ আমাদের নির্দেশ থেকে সরে যেত তাকে আমরা আস্বাদন করাতাম জ্বলন্ত আগুনের শাস্তি থেকে।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmdcxix{তারা তাঁর জন্য তৈরি করত যা তিনি চাইতেন, যথা দুর্গপ্রাসাদ ও ভাস্কর্য-প্রতিমূর্তি, আর গামলার ন্যায় থালা, আর অনড়-হয়ে- বসা ডেগ। ''হে দাউদের পরিবার! কৃতজ্ঞতার সাথে কাজ করে যাও।’’ আর আমার বান্দাদের মধ্যে অল্পকয়জনই কৃতজ্ঞ।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmdcxx{তারপর যখন আমরা তাঁর প্রতি মৃত্যুবিধান করেছিলাম তখন কিছুই তাদের কাছে তাঁর মৃত্যু সন্বন্ধে জানতে দেয় নি শুধু এক মাটির কীট ব্যতীত, সে খেয়ে ফেলেছিল তাঁর শাঁস। তারপর যখন তার পতন ঘটল তখন জিনেরা পরিস্কারভাবে বুঝলো যে যদি তারা অদৃশ্যটা জানতো তাহলে তারা লাঞ্ছনাদায়ক শাস্তিতে অবস্থান করত না।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmdcxxi{সাবা’র জন্য তাদের বাসভূমিতে নিশ্চয়ই একটি নিদর্শন ছিল -- দুইটি বাগান, ডান দিকে ও বাঁয়ে। ''তোমাদের প্রভুর রিযেক থেকে আহার করো ও তাঁর প্রতি কৃতজ্ঞতা প্রকাশ করো। এক উৎকৃষ্ট ভূখন্ড এবং একজন পরিত্রাণকারী প্রভু।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmdcxxii{কিন্তু তারা বিমুখ হয়েছিল, তাই আমরা তাদের উপরে পাঠিয়েছিলাম আল্‌-আরিমের বন্যা, আর তাদের জন্য আমরা বদলে দিয়েছিলাম তাদের দুই বাগানের স্থলে দুই বাগান যাতে ফলে বিস্বাদ ফলমূল আর ঝোপঝাড় ও কিছু-কিছু বন্যফল।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmdcxxiii{এইটিই আমরা তাদের প্রতিদান দিয়েছিলাম যেহেতু তারা অবিশ্বাস করেছিল। আর আমরা কি প্রাপ্য শোধ করি অকৃতজ্ঞদের ব্যতীত।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmdcxxiv{আর তাদের ও সেই শহরগুলোর যাতে আমরা অনুগ্রহ অর্পণ করেছিলাম, তাদের মাঝে আমরা স্থাপন করেছিলাম দৃশ্যমান জনবসতি, আর তাদের মধ্যে ভ্রমণস্তর ঠিক করে দিয়েছিলাম, -- ''তোমরা এসবে রাতে ও দিনে নিরাপদে পরিভ্রমণ কর।’’\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmdcxxv{কিন্তু তারা বললে -- ''আমাদের প্রভু! আমাদের পর্যটন-স্তরগুলোর মধ্যে দূরত্ব বাড়িয়ে দাও।’’ আর তাদের নিজেদেরই প্রতি তারা অন্যায় করেছিল, ফলে আমরা তাদের বানিয়েছিলাম কাহিনীর বিষয়বস্তু, আর আমরা তাদের ভেঙ্গেচুরে দিয়েছিলাম পুরোপুরি চুরমার করে। নিঃসন্দেহ এতে তো নিদর্শনসমূহ রয়েছে প্রত্যেক অধ্যবসায়ী কৃতজ্ঞের জন্য।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmdcxxvi{আর ইবলিস নিশ্চয়ই তার অনুমানকে সঠিক ঠাওরেছিল, কেননা মুমিনদের একটি দল ব্যতীত তারা তার অনুসরণ করেছিল।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmdcxxvii{কিন্তু তাদের উপরে আধিপত্যের কোনো অস্তিত্ব তার জন্য নেই এই ব্যতীত যে আমরা যেন জানতে পারি তাকে যে পরকালে বিশ্বাস করে তার থেকে যে সে-সন্বন্ধে সন্দেহের মধ্যে রয়েছে। আর তোমার প্রভু সব-কিছুর উপরে হেফাজতকারী।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmdcxxviii{তুমি বলো -- ''আল্লাহ্‌কে বাদ দিয়ে যাদের তোমরা কল্পনা করেছ তাদের ডাকো, তারা অণুর পরিমাপেও কোনো ক্ষমতা রাখে না মহাকাশমন্ডলীতে আর পৃথিবীতেও নয়, আর তাদের জন্য এই দুইয়ের মধ্যে কোনো একটা শরিকানাও নেই, আর তাদের মধ্যে থেকে তার জন্য কোনো পৃষ্ঠপোষকতাও নেই।’’\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmdcxxix{আর তাঁর কাছে সুপারিশে কোনো সুফল দেবে না, তার ক্ষেত্রে ব্যতীত যাকে তিনি অনুমতি দিয়েছেন, যে পর্যন্ত না তাদের অন্তর থেকে ভয়-ভাবনা দূর হয়ে যাবে, তারা বলবে -- ''কি সেটা যা তোমাদের প্রভু বলেছিলেন?’’ তারা বলবে -- ''সত্য। আর তিনিই মহোচ্চ, মহামহিম।’’\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmdcxxx{বলো -- ''কে তোমাদের রিষেক দান করেন মহাকাশমন্ডলী ও পৃথিবী থেকে?’’ তুমি বলে দাও -- ''আল্লাহ্‌। আর নিঃসন্দেহ আমরা অথবা তোমরা নিশ্চয়ই সঠিক পথে রয়েছি, নয়তো স্পষ্ট বিভ্রান্তিতে আছি।’’\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmdcxxxi{বলো -- ''তোমাদের জবাবদিহি করতে হবে না আমরা যা অপরাধ করেছি সেজন্য, আর আমাদেরও জবাবদিহি করতে হবে না তোমরা যা কর সে-সন্বন্ধে।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmdcxxxii{তুমি বলো -- ''আমাদের প্রভু আমাদের পরস্পরের সঙ্গে সমবেত করবেন, তারপর তিনি আমাদের মধ্যে মীমাংসা করবেন ন্যায়ের সাথে। আর তিনিই শ্রেষ্ঠ বিচাকর, পরমজ্ঞানী।’’\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmdcxxxiii{তুমি বলো -- ''আমাকে তাদের দেখাও যাদের তোমরা তাঁর সঙ্গে অংশী স্থির করেছ। কখনও না! বরং তিনিই আল্লাহ্ -- মহাশক্তিশালী, পরমজ্ঞানী।’’\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmdcxxxiv{আর আমরা তোমাকে পাঠাই নি সমগ্র মানবজাতির জন্য সুসংবাদদাতা ও সতর্ককারীরূপে ভিন্ন, কিন্তু অধিকাংশ লোকেই জানে না।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmdcxxxv{আর তারা বলে -- ''কখন এই ওয়াদা হবে, যদি তোমরা সত্যবাদী হও?’’\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmdcxxxvi{তুমি বলো -- ''তোমাদের জন্য একটি দিনের মেয়াদ ধার্য রয়েছে যা থেকে তোমরা এক ঘড়ির জন্যেও পিছিয়ে থাকতে পারবে না, আর এগিয়েও আসতে পারবে না!’’\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmdcxxxvii{আর যারা অবিশ্বাস করে তারা বলে -- ''আমরা কিছুতেই এই কুরআনে বিশ্বাস করব না, আর এর আগে যা রয়েছে তাতেও না।’’ আর তুমি যদি দেখতে যখন অন্যায়াচারীদের দাঁড় করানো হবে তাদের প্রভুর সামনে! তাদের কেউ কেউ অপরদের প্রতি বাক্যবান ফিরিয়ে দিতে থাকবে! যাদের দুর্বল করা হয়েছিল তারা তখন বলবে তাদের যারা মাতব্বরি করেছিল -- ''তোমাদের জন্য না হলে আমরা নিশ্চয়ই বিশ্বাসী হতাম।’’\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmdcxxxviii{যারা মাতব্বরি করেছিল তারা বলবে তাদের যাদের দুর্বল করা হয়েছিল -- ''আমরা কি তোমাদের বাধা দিয়েছিলাম পথনির্দেশ থেকে এটি তোমাদের কাছে আসার পরে? বরং তোমারই তো ছিলে অপরাধী?’’\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmdcxxxix{আর যাদের দুর্বল করা হয়েছিল তারা বলবে তাদের যারা গর্ব করছিল -- ''বস্তুত রাত ও দিনের চক্রান্ত, যখন তোমরা আমাদের হুকুম করতে যেন আমরা আল্লাহ্‌কে অবিশ্বাস করি এবং তাঁর সঙ্গে অংশী স্থাপন করি।’’ আর তারা যখন শাস্তি প্রত্যক্ষ করবে তখন তারা আফসোসে আকুল হবে। আর যারা অবিশ্বাস পোষণ করত তাদের গলায় আমরা শিকল পরাব। তাদের কি প্রতিদান দেওয়া হচ্ছে তারা যা করে চলেছিল তা ছাড়া অন্য কিছু দিয়ে।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmdcxl{আর আমরা কোনো জনপদে সতর্ককারীদের কাউকেও পাঠাই নি যার বিত্তবান লোকেরা না বলেছে -- ''নিঃসন্দেহ তোমাদের যা দিয়ে পাঠানো হয়েছে তাতে আমরা অবিশ্বাসী!’’\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmdcxli{আর তারা বলত -- ''আমরা ধনসম্পত্তি ও সন্তানসন্ততিতে সংখ্যাগরিষ্ঠ, সুতরাং আমরা তো শাস্তি পাবার পাত্র নই।’’\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmdcxlii{তুমি বলো -- ''আমার প্রভু যার জন্য ইচ্ছা করেন জীবিকা বাড়িয়ে দেন এবং সীমিতও করেন, কিন্তু অধিাকাংশ লোকেই জানে না।’’\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmdcxliii{আর না তোমাদের ধনদৌলত ও না তোমাদের সন্তানসন্ততি এমন জিনিস যা আমাদের কাছে তোমাদের মর্যাদায় নৈকট্য দেবে, বরং যে ঈমান এনেছে ও সৎকাজ করেছে। সুতরাং এরাই -- এদেরই জন্য রয়েছে দ্বিগুণ পুরস্কার যা তারা করেছে সেজন্য, আর তারা বাগান-বাড়িতে নিরাপদে রইবে।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmdcxliv{পক্ষান্তরে যারা আমাদের নির্দেশাবলীর বিরুদ্ধাচরণে প্রচেষ্টা চালায় এদেরই হাজির করা হবে শাস্তির মাঝে।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmdcxlv{বলো, ''নিঃসন্দেহ আমার প্রভু জীবিকা বাড়িয়ে দেন তাঁর বান্দাদের মধ্যের যার জন্য তিনি ইচ্ছা করেন, আর তার জন্য সীমিতও করেন। আর যা-কিছু তোমরা ব্যয় কর তিনি তো তার প্রতিদান দেন, কেননা তিনিই জীবিকাদাতাদের মধ্যে সর্বশ্রেষ্ঠ।’’\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmdcxlvi{আর সেইদিন তিনি তাদের একত্রিত করবেন সমবেতভাবে, তখন তিনি ফিরিশ্‌তাদের বলবেন -- ''এরাই কি তোমাদের পূজা করে থাকতো?’’\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmdcxlvii{তারা বলবে -- ''তোমারই মহিমা হোক! তুমিই আমাদের মনিব, তারা নয়, বরং তারা উপাসনা করত জিনদের, তাদের অধিকাংশই ছিল ওদের প্রতি বিশ্বাসী।’’\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmdcxlviii{সুতরাং সেইদিন তোমাদের কেউ অপর কারোর জন্য উপকার করার ক্ষমতা রাখবে না, অপকার করারও নয়। আর যারা অন্যায়াচরণ করেছিল তাদের আমরা বলব -- ''আগুনের শাস্তি আস্বাদন কর যেটি তোমরা মিথ্যা বলতে!’’\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmdcxlix{আর যখন তাদের কাছে আমাদের সুস্পষ্ট নির্দেশাবলী আবৃত্তি করা হয় তখন তারা বলে -- ''এ তো একজন মানুষ ছাড়া আর কেউ নয় যে তোমাদের ফিরিয়ে রাখতে চায় তা থেকে যার উপাসনা করত তোমাদের পিতৃপুরুষরা।’’ আর তারা বলে -- ''এ একটি বানানো মিথ্যা ব্যতীত আর কিছু নয়।’’ আর যারা অবিশ্বাস পোষণ করে তারা সত্য-সন্বন্ধে, এটি যখন তাদের কাছে আসে তখন, বলে -- ''এ স্পষ্ট জাদু বৈ তো নয়।’’\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmdcl{আর আমরা গ্রন্থাবলীর কোনো-কিছু তাদের দিই নি যেটি তারা পড়তে পাবে, আর তোমার পূর্বে তাদের কাছে আমরা সতর্ককারীদের কাউকেও পাঠাই নি।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmdcli{আর এদের পূর্বে যারা ছিল তারাও মিথ্যারোপ করেছিল, আর আমরা তাদের যা দিয়েছিলাম তার এক দশমাংশেও এরা পৌঁছায় নি, তারপর তারা আমার রসূলগণকে প্রত্যাখ্যান করেছিল, ফলে কেমন হয়েছিল আমার বিতৃষ্ণা!\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmmdclii{তুমি বলো -- ''আমি তো তোমাদের একটি বিষয়ে উপদেশ দিচ্ছি -- তোমরা যেন আল্লাহ্‌র উদ্দেশ্যে দুজন করে অথবা একা একা উঠে দাঁড়াও, তারপর ভেবে দেখো -- তোমাদের সঙ্গীর মধ্যে কোনো জিন-ভূত নেই।’’ তিনি তোমাদের জন্য একজন সতর্ককারী বৈ তো নন, আসন্ন কঠোর শাস্তি সম্পর্কে।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmmdcliii{তুমি বলো -- ''যা-কিছু পারিশ্রমিক আমি তোমাদের কাছে চেয়েছি, সে তো তোমাদেরই জন্য! আমার পারিশ্রমিক আল্লাহ্‌র কাছে বৈ তো নয়, কেননা তিনি সব-কিছুর উপরে প্রত্যক্ষদশ।’’\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmmdcliv{তুমি বলো -- ''নিঃসন্দেহ আমার প্রভু সত্য ছুঁড়ে থাকেন, তিনি অদৃশ্য বিষয়ে পরিজ্ঞাত।’’\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmmdclv{তুমি বলো -- ''সত্য এসেই গেছে, আর মিথ্যার উৎপত্তি হবে না, আর এর পুনরুদ্ভবও হবে না।’’\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmmdclvi{তুমি বলো -- ''যদি আমি বিপথে যাই তাহলে আমি তো আমার নিজেরই বিরুদ্ধে বিপথে গেছি, আর আমি যদি সৎপথে চলি তাহলে সেটি আমার প্রভু আমার কাছে যা প্রত্যাদেশ করেছিলেন তার জন্য। নিশ্চয় তিনি সর্বশ্রোতা, অতি নিকটবর্তী।’’\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmmdclvii{আর তুমি যদি দেখতে পেতে যখন তারা ভীত-বিহল হয়ে পড়বে, তখন কোনো নিস্তার থাকতে না, আর তাদের পাকড়ানো হবে নিকটবর্তী স্থান থেকেই,\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmmdclviii{আর তারা বলবে -- ''আমরা এতে বিশ্বাস করি।’’ কিন্তু কেমন করে সুদূর স্থান থেকে তাদের জন্য পুনরাগমন সম্ভব হবে?\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmmdclix{আর তারা এর আগেই তো এতে অবিশ্বাস করেছিল। আর অদৃশ্য সন্বন্ধে তারা অনুমান করত সুদূর স্থান থেকে।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmmdclx{আর তাদের মধ্যে ও তারা যা কামনা করে তার মধ্যে এক বেড়া খাড়া করা হবে, -- যেমন করা হয়েছিল ইতিপূর্বে এদের সমগোত্রীয়দের ক্ষেত্রে। নিঃসন্দেহ তারা এক ঘোর সন্দেহে রয়েছে ।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmmdclxi{\basmalahbn সমস্ত প্রশংসা আল্লাহ্‌র -- মহাকাশমন্ডলী ও পৃথিবীর আদিস্রষ্টা, ফিরিশ্‌তাদের সৃষ্টিকর্তা বাণীবাহকরূপে -- দুই বা তিন বা চারখানা ডানা সংযুক্ত। তিনি সৃষ্টির সঙ্গে বাড়াতে থাকেন যা-কিছু তিনি চান। নিঃসন্দেহ আল্লাহ্ সব-কিছুর উপরে সর্বশক্তি মান।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmdclxii{আল্লাহ্ লোকেদের জন্য করুণা থেকে যা খুলে ধরেন সেটি তবে রোধ করবার কেউ থাকবে না, আর যা তিনি রোধ করে রাখেন সেটি তবে এরপরে পাঠানোর কেউ থাকবে না। আর তিনি মহাশক্তিশালী, পরমজ্ঞানী।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmdclxiii{ওহে মানবগোষ্ঠী! তোমাদের উপরে আল্লাহ্‌র অনুগ্রহ স্মরণ করো। আল্লাহ্ ছাড়া কি অন্য স্রষ্টা রয়েছে যে মহাকাশ ও পৃথিবী থেকে তোমাদের জীবিকা দান করে? তিনি ব্যতীত অন্য উপাস্য নেই, সুতরাং কোথা থেকে তোমাদের ফেরানো হচ্ছে!\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmdclxiv{আর যদি তারা মিথ্যা আরোপ করে তবে তোমার আগেও রসূলগণ অবশ্য মিথ্যাবাদী আখ্যায়িত হয়েছিলেন। আর আল্লাহ্‌র তরফেই সব ব্যাপারকে ফিরিয়ে নেওয়া হবে।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmdclxv{ওহে মানবগোষ্ঠী! নিঃসন্দেহ আল্লাহ্‌র ওয়াদা ধ্রুব সত্য, কাজেই এই দুনিয়ার জীবন তোমাদের যেন কিছুতেই প্রবঞ্চনা না করে।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmdclxvi{নিঃসন্দেহ শয়তান তোমাদের শত্রু, কাজেই তাকে শত্রু হিসেবে গ্রহণ কর! সে তো তার সাঙ্গোপাঙ্গকে কেবলই আহ্বান করে যেন তারা জ্বলন্ত আগুনের বাসিন্দা হয়।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmdclxvii{যারা অবিশ্বাস পোষণ করে তাদের জন্য আছে কঠোর শাস্তি। পক্ষান্তরে যারা ঈমান এনেছে ও সৎকাজ করেছে তাদের জন্য রয়েছে পরিত্রাণ ও এক বিরাট প্রতিদান।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmdclxviii{কাউকেও যদি তার মন্দ কাজকে তার কাছে চিত্তাকর্ষক করা হয় এবং সেও এটি ভাল বলে দেখে সে কি তবে? সুতরাং আল্লাহ্ অবশ্য বিপথে চলতে দেন যাকে তিনি ইচ্ছা করেন, আর সৎপথে পরিচালিত করেন যাকে তিনি ইচ্ছা করেন। অতএব তুমি তাদের জন্য আক্ষেপের দ্বারা তোমার নিজেকে বিনাশ হতে দিয়ো না। নিঃসন্দেহ তারা যা করে সে সন্বন্ধে আল্লাহ্ সর্বজ্ঞাতা।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmdclxix{আর আল্লাহ্‌ই তিনি যিনি বায়ুপ্রবাহ পাঠান, ফলে এটি মেঘমালা সঞ্চালিত করে, তারপর আমরা তাকে নিয়ে যাই মৃত ভূখন্ডের দিকে, ফলে তার দ্বারা আমরা পৃথিবীকে তার মৃত্যুর পরে জীবনদান করি। এইভাবেই পুনরুত্থান হয়।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmdclxx{যে কেউ মানসম্মান চায় সমস্ত মানসম্মান তো আল্লাহ্‌র। তাঁরই দিকে উত্থিত হয় সকল খাঁটি বাক্যালাপ, আর পূণ্যময় কাজ -- তিনি তার উন্নতি সাধন করেন। আর যারা মন্দ কাজের ফন্দি আঁটে তাদের জন্য আছে কঠিন শাস্তি। আর এদের ফন্দি -- তা ব্যর্থ হবেই।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmdclxxi{আর আল্লাহ্ তোমাদের সৃষ্টি করেছেন মাটি থেকে, তারপর শুক্রকীট থেকে, তারপরে তিনি তোমাদের বানিয়েছেন যুগল। আর কোনো নারী গর্ভধারণ করে না অথবা প্রসব করে না তাঁর জানার বাইরে। আর কোনো বয়স্ক লোকের বয়েস বাড়ে না এবং তার বয়েস থেকে কিছু কমেও না, বরং তা রয়েছে কিতাবে। এটি নিশ্চয়ই আল্লাহ্‌র পক্ষে সহজসাধ্য।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmdclxxii{আর দুটি সাগর একসমান নয়, এই একটি বিশুদ্ধ, তৃষ্ণানিবারক, যার পানকরণ সুমিষ্ট, আর এইটি লোনা, বিস্বাদ। তবুও তাদের প্রত্যেকটি থেকে তোমরা টাটকা মাংস খাও, আর বের করে আনো অলংকার যা তোমরা পরো। আর তুমি দেখতে পাও জাহাজগুলো তাতে বুকচিরে চলছে যেন তোমরা তাঁর করুণাভান্ডার থেকে রোজগার করতে পারো, আর যেন তোমরা কৃতজ্ঞতা জ্ঞাপন করো।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmdclxxiii{তিনি রাতকে দিনের মধ্যে প্রবেশ করান ও দিনকে প্রবেশ করান রাতের মধ্যে, আর তিনি সূর্য ও চন্দ্রকে নিয়ন্ত্রণাধীন করেছেন -- প্রত্যেকটিই ভেসে চলে এক নির্দিষ্টকালের জন্য। এই হচ্ছেন আল্লাহ্‌, তোমাদের প্রভু, তাঁরই হচ্ছে সার্বভৌমত্ব। কিন্তু তাঁকে বাদ দিয়ে যাদের তোমরা ডাক তারা তো তুচ্ছ কিছুরও ক্ষমতা রাখে না।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmdclxxiv{যদি তোমরা তাদের ডাক তারা তোমাদের ডাক শুনবে না, আর তারা যদিও শুনতে পায় তবু তারা তোমাদের প্রতি সাড়া দেবে না। আর কিয়ামতের দিনে তারা অস্বীকার করবে তোমাদের শরীক করার কথা। আর কেউ তোমাকে জানাতে পারে না পূর্ণ- ওয়াকিফহালের।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmdclxxv{ওহে মানবজাতি! তোমরা তো আল্লাহ্‌র মুখাপেক্ষী, -- আর আল্লাহ্‌, তিনি স্বয়ংসমৃদ্ধ, পরম প্রশংসিত।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmdclxxvi{যদি তিনি চান তবে তিনি তোমাদের গত করে দেবেন এবং নিয়ে আসবেন এক নতুন সৃষ্টি, --\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmdclxxvii{আর এটি আল্লাহ্‌র জন্যে মোটেই কঠিন নয়।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmdclxxviii{আর কোনো বোঝা বহনকারী অন্যের বোঝা বইবে না। আর গুরুভারে পীড়িত কেউ যদি তার বোঝার জন্যে ডাকে, তা থেকে কিছুই বয়ে নেওয়া হবে না, যদিও সে নিকটা‌ত্মীয় হয়। তুমি তো সাবধান করতে পার কেবলমাত্র তাদের যারা তাদের প্রভুকে ভয় করে আড়ালে, আর নামায কায়েম করে। আর যে কেউ নিজেকে পবিত্র করে, সে তো তবে পবিত্র করে তার নিজেরই জন্যে। আর আল্লাহ্‌র কাছেই প্রত্যাবর্তন।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmdclxxix{আর অন্ধ ও চক্ষুষ্মান একসমান নয়,\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmdclxxx{আর অন্ধকার ও আলোকও নয়,\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmdclxxxi{আর ছায়া ও উত্তপ্ত নৈশ-বায়ুপ্রবাহও নয়।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmdclxxxii{আর জীবন্ত এবং মৃতও একসমান নয়। নিঃসন্দেহ আল্লাহ্ যাকে ইচ্ছা করেন তাকে শুনিয়ে থাকেন, আর যারা কবরে রয়েছে তাদের তুমি শোনাতে সক্ষম নও।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmdclxxxiii{তুমি একজন সতর্ককারী বৈ তো নও।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmdclxxxiv{নিঃসন্দেহ আমরা তোমাকে পাঠিয়েছি সত্যের সঙ্গে -- সুসংবাদদাতারূপে ও সতর্ককারীরূপে। আর এমন কোন সম্প্রদায় নেই যাদের মধ্যে একজন সতর্ককারী না গেছেন।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmdclxxxv{আর এরা যদি তোমার প্রতি মিথ্যা আরোপ করে তাহলে এদের আগে যারা ছিল তারাও মিথ্যা আরোপ করেছিল, তাদের কাছে তাদের রসূলগণ এসেছিলেন সুস্পষ্ট প্রমাণাবলী নিয়ে, আর ধর্মগ্রন্থাবলী নিয়ে ও উজ্জ্বল গ্রন্থ নিয়ে।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmdclxxxvi{তারপর আমি তাদের পাকড়াও করলাম যারা অবিশ্বাস পোষণ করেছিল, সুতরাং কেমন হয়েছিল তাদের প্রতি আমার বিতৃষ্ণা!\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmdclxxxvii{তুমি কি দেখতে পাও নি যে নিঃসন্দেহ আল্লাহ্ আকাশ থেকে পানি বর্ষণ করেন? তারপর আমরা তার দ্বারা উৎপাদন করি ফলফসল -- যার রঙচঙ নানান ধরনের। আর পাহাড়গুলোতে আছে স্তর, সাদা ও লাল, বিচিত্র তার বর্ণ, আর নিকষ কালো।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmdclxxxviii{আর লোকেদের ও জীবজন্তুর ও গবাদি-পশুর মধ্যেও তাদের রঙচঙে এ ধরনের বৈচিত্র রয়েছে। নিঃসন্দেহ তাঁর বান্দাদের মধ্যের আলীম-পন্ডিত ব্যক্তিবর্গ আল্লাহ্‌কে ভয় করে। আল্লাহ্ নিশ্চয়ই মহাশক্তিশালী, পরিত্রাণকারী।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmdclxxxix{নিঃসন্দেহ যারা আল্লাহ্‌র গ্রন্থ পাঠ করে আর নামায কায়েম করে, আর আমরা তাদের যে জীবনোপকরণ দান করেছি তা থেকে তারা গোপনে ও প্রকাশ্যভাবে খরচ করে থাকে, তারা এমন একটি বাণিজ্যের আশা রাখে যা কখনো বিনষ্ট হবে না, --\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmdcxc{যেন তিনি তাদের পারিশ্রমিক পুরোপুরি তাদের দিতে পারেন এবং তাঁর করুণাভান্ডার থেকে তাদের বাড়িয়ে দিতে পারেন। নিঃসন্দেহ তিনি পরিত্রাণকারী, গুণগ্রাহী।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmdcxci{আর আমরা তোমার কাছে গ্রন্থ থেকে যা প্রত্যাদিষ্ট করেছি তা সত্য, সমর্থন করছে যা এর আগে রয়েছে। নিঃসন্দেহ আল্লাহ্ তাঁর বান্দাদের সন্বন্ধে পূর্ণ-ওয়াকিবহাল, সর্বদ্রষ্টা।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmdcxcii{তারপর আমরা গ্রন্থখানা উত্তরাধিকার করতে দিয়েছি তাদের যাদের আমরা নির্বাচন করেছি আমাদের দাসদের মধ্য থেকে, তবে তাদের মধ্যে কেউ নিজেদের অন্তরা‌ত্মার প্রতি অন্যায়কারী, আর তাদের মধ্যে কেউ হচ্ছে মধ্যমপন্থী, আর তাদের মধ্যে রয়েছে আল্লাহ্‌র অনুমতিক্রমে ভালোকাজে অগ্রগামী। এইটিই হচ্ছে মহান অনুগ্রহ প্রাচুর্য্য।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmdcxciii{নন্দন কানন -- তারা এটিতে প্রবেশ করবে, সেখানে তাদের অলঙ্কৃত করানো হবে সোনা ও মুক্তোর কঙ্কন দিয়ে, আর তাদের পোশাক-পরিচ্ছদ সেখানে হবে রেশমের।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmdcxciv{আর তারা বলবে -- ''সকল প্রশংসা আল্লাহ্‌র, যিনি আমাদের থেকে দুঃখ-দুর্দশা দূর করে দিয়েছেন। আমাদের প্রভু অবশ্যই পরিত্রাণকারী, গুণগ্রাহী, --\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmdcxcv{''যিনি তাঁর অনুগ্রহপ্রাচুর্য বশতঃ আমাদের বসবাস করিয়েছেন স্থায়ী বাসস্থানে, সেখানে পরিশ্রম আমাদের স্পর্শ করবে না, আর সেখানে আমাদের স্পর্শ করবে না পরিশ্রান্তি।’’\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmdcxcvi{পক্ষান্তরে যারা অবিশ্বাস পোষণ করে তাদের জন্য রয়েছে জাহান্নামের আগুন, তা নিঃশেষ হয়ে যাবে না তাদের জন্যে, যার ফলে তারা মরে যেতে পারে, আর তাদের উপর থেকে এর শাস্তির কিছুটাও কমানো হবে না! এইভাবেই আমরা প্রতিদান দিই প্রত্যেক অবিশ্বাসীকে।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmdcxcvii{আর সেখানে তারা আর্তনাদ করবে -- ''আমাদের প্রভু! আমাদের বের করে আনো, আমরা ভালো কাজ করব, -- তা ব্যতীত যা আমরা করতাম।’’ ''আমরা কি তোমাদের দীর্ঘজীবন দিই নি যেন, যে মনোযোগ দিতে চায় সে সেখানে মনোযোগ দিতে পারে, আর তোমাদের কাছে সতর্ককারীও এসেছিলেন? তাই আস্বাদন কর, আর অন্যায়কারীদের জন্য কোনো সাহায্যকারী নেই।’’\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmdcxcviii{আল্লাহ্ নিশ্চয়ই মহাকাশমন্ডলী ও পৃথিবীর অদৃশ্য বিষয়-বস্তুর সম্যক জ্ঞাতা। তিনি বুকের ভেতরে যা রয়েছে সে-সন্বন্ধে সর্বজ্ঞাতা।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmdcxcix{তিনিই সেইজন যিনি পৃথিবীতে তোমাদের প্রতিনিধি বানিয়েছেন। সুতরাং যে অস্বীকার করে তার বিরুদ্ধেই তাহলে যাবে তার অবিশ্বাস। আর অবিশ্বাসীদের জন্য তাদের অবিশ্বাস তাদের প্রভুর নজরে কিছুই বাড়ায় না বিতৃষ্ণা ব্যতীত, আর অবিশ্বাসীদের জন্য তাদের অবিশ্বাস ক্ষতি ব্যতীত আর কিছুই বাড়ায় না।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmdcc{তুমি বলো -- ''তোমরা কি ভেবে দেখেছ তোমাদের অংশীদেবতাদের কথা যাদের তোমরা আল্লাহ্‌কে বাদ দিয়ে ডাক? আমাকে দেখাও তো পৃথিবীর কোনো অংশ তারা সৃষ্টি করেছে, না কি তাদের কোনো শরিকানা রয়েছে মহাকাশমন্ডলে?’’ না কি আমরা তাদের এমন কোনো গ্রন্থ দিয়েছি যার থেকে তারা স্পষ্ট প্রমাণের উপরে রয়েছে? না, অন্যায়াচারীরা তাদের একে অন্যকে প্রতারণা করা ব্যতীত অন্য প্রতি‌শ্রুতি দেয় না।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmdcci{আল্লাহ্ আলবৎ মহাকাশমন্ডলী ও পৃথিবীকে ধরে রেখেছেন পাছে তারা কক্ষচ্যুত হয়, আর যদি বা তারা কক্ষচ্যুত হয় তাহলে তিনি ব্যতীত তাদের ধরে রাখবার মতো কেউ নেই। নিঃসন্দেহ তিনি অতি অমায়িক, পরিত্রাণকারী।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmdccii{আর তারা আল্লাহ্‌র নামে শপথ খায় তাদের সব চাইতে জোরালো শপথের দ্বারা যে যদি তাদের কাছে একজন সতর্ককারী আসতেন তাহলে তারা নিশ্চয়ই অন্যান্য সম্প্রদায়ের যে কোনোটির চেয়ে অধিকতর সৎপথাবলন্বী হতো। কিন্তু যখন তাদের কাছে একজন সতর্ককারী এলেন তখন তাতে বিতৃষ্ণা ব্যতীত তাদের আর কিছুই বাড়লো না, --\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmdcciii{উদ্ধত ব্যবহারে এই পৃথিবীতে ও কুটিল ষড়যন্ত্রে। আর কুটিল ষড়যন্ত্র অন্য কাউকে ঘেরাও করে না তার কর্তাদের ব্যতীত। কাজেই তারা কি পূর্ববর্তীদের নজির ছাড়া আর কিছুর প্রতীক্ষা করে? কিন্তু তুমি তো আল্লাহ্‌র বিধানের কোনো পরিবর্তন কখনও পাবে না, আর তুমি কখনো আল্লাহ্‌র বিধানের কোনো ব্যতিক্রম পাবে না।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmdcciv{তারা কি তবে পৃথিবীতে পরিভ্রমণ করে না, তাহলে তারা দেখতে পেতো কেমন হয়েছিল তাদের পরিণাম যারা ছিল এদের অগ্রগামী, আর তারা ছিল এদের চেয়েও শক্তিতে প্রবল? আর আল্লাহ্ এমন নন যে তাঁর থেকে কোন-কিছু এড়িয়ে যেতে পারে মহাকাশমন্ডলীতে, আর পৃথিবীতেও নয়। নিঃসন্দেহ তিনি হচ্ছেন সর্বজ্ঞাতা, পরম ক্ষমতাবান।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmdccv{আর আল্লাহ্ যদি লোকেদের পাকড়াও করতেন তারা যা অর্জন করেছে সেজন্য, তাহলে এর পিঠে তিনি জীবজন্তুদের কাউকেও ছাড়তেন না, কিন্তু তিনি এক নির্ধারিত কাল পর্যন্ত তাদের অবকাশ দিয়ে থাকেন। সুতরাং যখন তাদের নির্ধারিত কাল এসে যায় তখন আল্লাহ্ আলবৎ তাঁর বান্দাদের প্রতি সর্বদ্রষ্টা।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmmdccvi{\basmalahbn ইয়া সীন!\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmdccvii{জ্ঞানগর্ভ কুরআনের শপথ, --\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmdccviii{নিঃসন্দেহ তুমি তো প্রেরিত পুরুষদের অন্যতম, --\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmdccix{সহজ-সঠিক পথে অধিষ্ঠিত রয়েছে।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmdccx{মহাশক্তিশালী, অফুরন্ত ফলদাতার থেকে এক অবতারণ, --\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmdccxi{যেন তুমি সতর্ক করতে পার সেই জাতিকে যাদের পিতৃপুরুষদের সতর্ক করা হয় নি, যার ফলে তারা অজ্ঞ রয়ে গেছে।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmdccxii{সুনিশ্চিত যে বক্তব্যটি তাদের অনেকের সন্বন্ধে সত্য প্রতিপন্ন হয়েছে, তাই তারা বিশ্বাস করছে না।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmdccxiii{আমরা নিশ্চয় তাদের গলায় বেড়ি পরিয়ে দিয়েছি, আর তা পৌঁছেছে চিবুক পর্যন্ত, ফলে তারা মাথা চড়ানো অবস্থায় রয়েছে।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmdccxiv{আর আমরা তাদের সামনে স্থাপন করেছি এক বেড়া আর তাদের পেছনেও এক বেড়া, ফলে আমরা তাদের ঢেকে ফেলেছি, সুতরাং তারা দেখতে পায় না।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmdccxv{এটি তাদের কাছে একাকার -- তুমি তাদের সতর্ক কর অথবা তুমি তাদের সতর্ক নাই কর, তারা বিশ্বাস করবে না।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmdccxvi{নিঃসন্দেহ তুমি তো সতর্ক করতে পার তাকে যে উপদেশ অনুসরণ করে চলে, আর পরম করুণাময়কে নিভৃতে ভয় করে। সুতরাং তাকে তুমি সুসংবাদ দাও পরিত্রাণের এবং এক মহান প্রতিদানের।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmdccxvii{নিঃসন্দেহ আমরা -- আমরা নিজেরাই মৃতকে জীবন্ত করি, আর আমরা লিখে রাখি যা তারা আগবাড়ায় আর তাদের পদচিহ্নসমূহ। আর সমস্ত ব্যাপার-স্যাপার -- আমরা তা সংরক্ষিত রেখেছি এক সুস্পষ্ট গ্রন্থে।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmdccxviii{আর তাদের জন্য উপমা ছোঁড়ো এক জনপদের অধিবাসীদের -- যখন সেখানে রসূলগণ এসেছিলেন।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmdccxix{দেখো! আমরা তাদের কাছে দুজনকে পাঠিয়েছিলাম, কিন্তু তারা এদের দুজনেরই প্রতি মিথ্যারোপ করেছিল, তখন আমরা তৃতীয় জনকে দিয়ে শক্তিবৃদ্ধি করি। সুতরাং তাঁরা বলেছিলেন -- ''নিঃসন্দেহ তোমাদের কাছে আমরা প্রেরিত হয়েছি।’’\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmdccxx{তারা বলেছিল -- ''তোমরা তো আমাদের ন্যায় মানুষ ছাড়া আর কিছু নও, আর পরম করুণাময় কোনো কিছুই অবতারণ করেন নি, তোমরা তো কেবল মিথ্যা কথা বলছ।’’\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmdccxxi{তাঁরা বলেছিলেন -- ''আমাদের প্রভু জানেন যে আমরা নিশ্চয়ই তোমাদের কাছে প্রেরিতপুরুষই বটে।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmdccxxii{''আর আমাদের উপরে হচ্ছে স্পষ্টভাবে পৌঁছে দেওয়া ছাড়া অন্য কিছু নয়।’’\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmdccxxiii{তারা বললে, ''তোমাদের থেকে আমরা অবশ্যই অমঙ্গল আশঙ্কা করি, যদি তোমরা বিরত না হও তবে আমরা অবশ্যই তোমাদের পাথর মেরে মেরে ফেলব, আর আমাদের থেকে মর্মন্তুদ শাস্তি তোমাদের স্পর্শ করবে।’’\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmdccxxiv{তাঁরা বললেন, ''তোমাদের পাখিগুলো তোমাদের সঙ্গেই রয়েছে। তোমাদের তো স্মরণ করিয়ে দেয়া হয়েছে! বস্তুতঃ তোমরা হচ্ছ অমিতাচারী জাতি।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmdccxxv{আর শহরের দূর প্রান্ত থেকে একজন লোক দেড়ে এল, সে বললে -- ''হে আমার স্বজাতি! প্রেরিতপুরুষগণকে অনুসরণ করো, --\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmdccxxvi{''অনুসরণ করো তাঁদের যারা তোমাদের কাছ থেকে কোনো পারিশ্রমিকের সওয়াল করেন না, আর তাঁরা হচ্ছেন সৎপথে চালিত।’’\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmdccxxvii{''আর আমার কি হয়েছে যে আমি তাঁর উপাসনা করব না, যিনি আমাকে সৃজন করেছেন, আর তাঁরই কাছে তোমাদের ফিরিয়ে নেয়া হবে?\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmdccxxviii{''আমি কি তাঁকে বাদ দিয়ে অন্য উপাস্যদের গ্রহণ করব, পরম করুণাময় যদি আমাকে দুঃখ-দুর্দশা দিতে চাইতেন তবে তাদের সুপারিশ আমার কোনো কাজে আসবে না, আর তারা আমাকে উদ্ধার করতেও পারবে না?\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmdccxxix{''এমন ক্ষেত্রে আমি তো নিশ্চয় স্পষ্ট ভুলের মধ্যে পড়ব।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmdccxxx{''আমি আলবৎ তোমাদের প্রভুর প্রতি ঈমান এনেছি, সেজন্য আমার কথা শোনো।’’\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmdccxxxi{বলা হলো -- ''জান্নাতে প্রবেশ কর।’’ তিনি বললেন -- ''হায় আফসোস! আমার স্বজাতি যদি জানতে পারত, --\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmdccxxxii{''কি কারণে আমার প্রভু আমাকে পরিত্রাণ করেছেন, আর আমাকে সম্মানিতদের অন্তর্ভুক্ত করেছেন।’’\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmdccxxxiii{আর তাঁর পরে তাঁর লোকদের প্রতি আমরা আকাশ থেকে কোনো বাহিনী পাঠাই নি, আর আমরা কখনো প্রেরণকারী নই।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmdccxxxiv{এটি অবশ্য একটিমাত্র মহাগর্জন বৈ তো নয়, তখন দেখো, তারা নিথরদেহী হয়ে গেল!\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmdccxxxv{হায় আফসোস বান্দাদের জন্য! তাদের কাছে এমন কোনো রসূল আসেন নি যাঁকে নিয়ে তারা ঠাট্টা-বিদ্রূপ না করেছে!\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmdccxxxvi{তারা কি দেখে নি তাদের পূর্বে কত মানবগোষ্ঠীকে আমরা ধ্বংস করেছি, কেননা তারা তাঁদের প্রতি ফিরতো না?\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmdccxxxvii{আর নিশ্চয়ই সবাইকে, -- আলবৎ সব ক’জনকে, আমাদের সামনে হাজির করা হবে।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmdccxxxviii{আর তাদের জন্য একটি নিদর্শন হচ্ছে মৃত ভূখন্ড, আমরা তাতে প্রাণ সঞ্চার করি, আর তা থেকে উৎপন্ন করি শস্য, ফলে সেটি থেকে তারা আহার করে।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmdccxxxix{আর আমরা তাতে বানিয়েছি খেজুর ও আঙুরের বাগানসমূহ, আর তার মাঝে আমরা উৎসারিত করি প্রস্রবণ,\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmdccxl{যেন তারা এর ফলমূল থেকে আহার করতে পারে, অথচ তাদের হাতে এটি বানায় নি। তবু কি তারা কৃতজ্ঞতা প্রকাশ করবে না?\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmdccxli{সকল মহিমা তাঁর যিনি জোড়ায়-জোড়ায় সৃষ্টি করেছেন -- পৃথিবী যা উৎপাদন করে তার মধ্যের সব-কিছু, আর তাদের নিজেদের মধ্যেও, আর তারা যার কথা জানে না তাদের মধ্যেও।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmdccxlii{আর তাদের কাছে একটি নিদর্শন হচ্ছে রাত্রি, তা থেকে আমরা বের করে আনি দিনকে, তারপর দেখো! তারা অন্ধকারাচ্ছন্ন হয়ে থাকে!\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmdccxliii{আর সূর্য তার গন্তব্য পথে বিচরণ করে। এটিই মহাশক্তিশালী সর্বজ্ঞাতার নির্ধারিত বিধান।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmdccxliv{আর চন্দ্রের বেলা -- আমরা এর জন্য বিধান করেছি বিভিন্ন অবস্থান, শেষপর্যন্ত তা শুকনো পুরোনো খেজুরবৃন্তের ন্যায় হয়ে যায়।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmdccxlv{সূর্যের নিজের সাধ্য নেই চন্দ্রকে ধরার, আর রাতেরও নেই দিনকে অতিক্রম করার। আর সবক’টিই কক্ষপথে ভাসছে।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmdccxlvi{আর তাদের জন্য একটি নিদর্শন হচ্ছে এই যে আমরা তাদের সন্তান-সন্ততিকে বহন করি বোঝাই করা জাহাজে, --\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmdccxlvii{আর তাদের জন্য আমরা বানিয়েছি এগুলোর অনুরূপ অন্যান্য যা তারা চড়বে।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmdccxlviii{আর আমরা যদি ইচ্ছা করি তবে তাদের ডুবিয়েও দিতে পারি, তখন তাদের জন্য কোনো সাহায্যকারী থাকবে না, আর তাদের উদ্ধার করাও হবে না, --\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmdccxlix{আমাদের থেকে করুণা ব্যতীত, আর কিছুকালের জন্য জীবনোপভোগকরণ মাত্র।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmdccl{আর যখন তাদের বলা হয় -- ''ভয় করো যা তোমাদের সামনে রয়েছে আর যা তোমাদের পেছনে রয়েছে, যেন তোমাদের প্রতি করুণা করা হয়।’’\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmmdccli{আর তাদের প্রভুর বাণীসমূহের মধ্যে থেকে এমন কোনো বাণী তাদের কাছে আসে নি যা থেকে তারা বরাবর ফিরে না গেছে।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmmdcclii{আর যখন তাদের বলা হয় -- ''আল্লাহ্ তোমাদের যা রিযেক দিয়েছেন তা থেকে খরচ করো।’’ তখন যারা অবিশ্বাস পোষণ করে তারা বলে তাদের যারা বিশ্বাস করেছে -- ''আমরা কি তাদের খাওয়াব যাদের, আল্লাহ্ যদি চাইতেন তবে তিনিই খাওয়াতে পারতেন? তোমরা স্পষ্ট ভুলের মধ্যে ছাড়া আর কোথাও তো নও।’’\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmmdccliii{আর তারা বলে -- ''সেই ওয়াদা কখন পূর্ণ হবে, যদি তোমরা সত্যবাদী হও?’’\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmmdccliv{তারা একটিমাত্র মহাগর্জন ছাড়া আর কিছুর অপেক্ষা করছে না, এটি তাদের আঘাত করবে যখন তারা কথা কাটাকাটি করছে।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmmdcclv{তখন তারা ওসিয়ৎ করতেও সমর্থ হবে না, আর তারা তাদের পরিবারবর্গের কাছে ফিরতেও পারবে না।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmmdcclvi{আর শিঙায় ফুৎকার দেওয়া হবে, তখন দেখো! তারা কবরগুলো থেকে তাদের প্রভুর দিকে ছুটে আসবে।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmmdcclvii{তারা বলবে -- ''হায় ধিক্ আমাদের! কে আমাদের উঠিয়ে দিলে আমাদের ঘুমানোর স্থান থেকে? এটিই হচ্ছে যা পরম করুণাময় ওয়াদা করেছিলেন, আর রসূলগণ সত্য কথাই বলেছিলেন।’’\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmmdcclviii{সেটি একটিমাত্র মহাগর্জন বৈ তো নয়, তখন দেখো! তাদের সমবেতভাবে আমাদের সামনে হাজির করা হবে।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmmdcclix{সুতরাং সেইদিন কোনো লোকের প্রতি কিছুমাত্রও অবিচার করা হবে না, আর তোমরাও যা করে থাকতে তা ছাড়া তোমাদের অন্য প্রতিদান দেওয়া হবে না।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmmdcclx{নিঃসন্দেহ জান্নাতের বাসিন্দারা সেইদিন আনন্দের মাঝে কালাতিপাত করবে।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mmmdcclxi{তারা ও তাদের সঙ্গিনীরা স্নিগ্ধ ছায়ায় উঁচু আসনের উপরে হেলান দিয়ে বসবে।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mmmdcclxii{তাদের জন্য সেখানে থাকবে ফলফসল, আর তাদের জন্য রইবে যা তারা কামনা করে।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mmmdcclxiii{অফুরন্ত ফলদাতা প্রভুর তরফ থেকে সম্ভাষণ হচ্ছে -- ''সালাম’’।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mmmdcclxiv{আর ''আজ বিচ্ছিন্ন হয়ে যাও, হে অপরাধিগণ!\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mmmdcclxv{''হে আদম-সন্তানগণ! আমি কি তোমাদের নির্দেশ দিই নি যে তোমরা শয়তানের আরাধনা করবে না, নিঃসন্দেহ সে তোমাদের জন্য প্রকাশ্য শত্রু, --\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mmmdcclxvi{''বরং তোমরা আমারই উপাসনা করো? এটিই তো শুদ্ধ-সঠিক পথ।\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mmmdcclxvii{''আর তোমাদের মধ্যের অনেক বড়বড় দলকে সে বিভ্রান্ত করেই ফেলেছে। তবুও কি তোমরা বুঝেসুঝে চলবে না?\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mmmdcclxviii{''এটিই হচ্ছে জাহান্নাম যে-সন্বন্ধে তোমাদের ওয়াদা করা হয়েছিল।\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mmmdcclxix{''এতে তোমরা প্রবেশ করো আজকের দিনে যেহেতু তোমরা অবিশ্বাস করেছিলে।’’\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mmmdcclxx{সেইদিন আমরা তাদের মুখের উপর মোহর মেরে দেব, বরং তাদের হাত আমাদের সাথে কথা বলবে, আর তাদের পা সাক্ষ্য দেবে যা তারা অর্জন করত সে-সন্বন্ধে।\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mmmdcclxxi{আর আমরা যদি চাইতাম তবে আমরা তাদের চোখের উপরে দৃষ্টিহীনতা এনে দিতাম, তখন তারা পথের দিকে ধাওয়া করত, কিন্তু কেমন করে তারা দেখতে পাবে?\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mmmdcclxxii{আর আমরা যদি চাইতাম তবে আমরা তাদের বাড়িগুলোতেই তাদের নিশ্চল-নিস্তব্ধ করে দিতাম, তখন তারা এগিয়ে যেতে সক্ষম হবে না, ফিরে আসতেও পারবে না।\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mmmdcclxxiii{আর যাকে আমরা দীর্ঘ জীবন দান করি তাকে তো আমরা সৃষ্টিতে ঘুরিয়ে দিই। তবুও কি তারা বুঝে না।\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mmmdcclxxiv{আর আমরা তাঁকে কবিত্ব শেখাই নি, আর তা তাঁর পক্ষে সমীচীনও নয়। এটি স্মারক গ্রন্থ ও সুস্পষ্ট কুরআন বৈ তো নয়, --\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mmmdcclxxv{যেন তিনি সাবধান করতে পারেন তাকে যে জীবন্ত রয়েছে, আর অবিশ্বাসীদের বিরুদ্ধে রায় ন্যায়সঙ্গত হয়েছে।\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@mmmdcclxxvi{তারা কি লক্ষ্য করে নি যে আমরাই তো তাদের জন্য সৃষ্টি করেছি আমাদের হাত যা বানিয়েছে তা থেকে গবাদি-পশুগুলো, তারপর তারাই এগুলোর মালিক হয়ে যায়?\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@mmmdcclxxvii{আর এগুলোকে আমরা তাদের বশীভূত করে দিয়েছি, ফলে এদের মধ্যের কিছু তাদের বাহন আর এদের কিছু তারা খায়।\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@mmmdcclxxviii{আর তাদের জন্য এগুলোতে রয়েছে উপকারিতা, আর পানীয় বস্তু। তবুও কি তারা কৃতজ্ঞতা প্রকাশ করবে না?\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@mmmdcclxxix{আর তারা আল্লাহ্‌কে বাদ দিয়ে উপাস্যদের গ্রহণ করেছে যাতে তাদের সাহায্য করা হয়।\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@mmmdcclxxx{ওরা কোনো ক্ষমতা রাখে না তাদের সাহায্য করার, বরং তারা হবে এদের জন্য এক বাহিনী যাদের হাজির করা হবে।\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@mmmdcclxxxi{সুতরাং তাদের কথাবার্তা তোমাকে যেন কষ্ট না দেয়। আমরা নিশ্চয়ই জানি যা তারা লুকিয়ে রাখে আর যা তারা প্রকাশ করে।\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@mmmdcclxxxii{আচ্ছা, মানুষ কি দেখে না যে আমারা তাকে নিশ্চয়ই এক শুক্রকীট থেকে সৃষ্টি করেছি? তারপর, কি আশ্চর্য! সে একজন প্রকাশ্য বিতর্ককারী হয়ে যায়।\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@mmmdcclxxxiii{আর সে আমাদের সদৃশ বানায়, আর ভুলে যায় তার নিজের সৃষ্টির কথা। সে বলে -- ''হাড়-গোড়ের মধ্যে কে প্রাণ দেবে যখন তা গলে-পচে যাবে?’’\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@mmmdcclxxxiv{তুমি বলো -- ''তিনিই তাতে প্রাণ সঞ্চার করবেন যিনি প্রথমবারে তাদের সৃজন করেছিলেন। আর তিনি প্রত্যেকটি সৃষ্টি সন্বন্ধে সর্বজ্ঞাতা, --\qt@no{(79)}}
\qt@newcmd\qurantrans@bn@mmmdcclxxxv{যিনি তোমাদের জন্য সবুজ গাছ থেকে আগুন তৈরি করেন, তারপর দেখো! তোমরা তা দিয়ে আগুন জ্বালো।\qt@no{(80)}}
\qt@newcmd\qurantrans@bn@mmmdcclxxxvi{আচ্ছা, যিনি মহাকাশমন্ডলী ও পৃথিবী সৃষ্টি করেছেন তিনি কি তাদের অনুরূপ সৃষ্টি করতে সক্ষম নন? হাঁ, বস্তুতঃ তিনিই তো মহাস্রষ্টা, সর্বজ্ঞাতা।\qt@no{(81)}}
\qt@newcmd\qurantrans@bn@mmmdcclxxxvii{যখন তিনি কোনো-কিছু ইচ্ছা করেন তখন তাঁর নির্দেশ হল যে তিনি সে-সন্বন্ধে শুধু বলেন -- ''হও’’, আর তা হয়ে যায়।\qt@no{(82)}}
\qt@newcmd\qurantrans@bn@mmmdcclxxxviii{সুতরাং সকল মহিমা তাঁরই যাঁর হাতে রয়েছে সমস্ত কিছুর শাসনভার, আর তাঁরই নিকট তোমাদের ফিরিয়ে আনা হবে।\qt@no{(83)}}
\qt@newcmd\qurantrans@bn@mmmdcclxxxix{\basmalahbn ভেবে দেখো তাদের যারা কাতারে কাতারে সারিবদ্ধভাবে দাঁড়িয়ে রয়েছে,\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmdccxc{আর যারা বিতাড়িত করে প্রবল বিতাড়নে,\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmdccxci{আর যারা স্মারকগ্রন্থ পাঠ করে!\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmdccxcii{নিঃসন্দেহ তোমাদের উপাস্য মাত্র একজন,\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmdccxciii{যিনি মহাকাশমন্ডলী ও পৃথিবীর এবং এদের উভয়ের মধ্যবর্তী সমস্ত কিছুর প্রভু, আর যিনি উদয়স্থল সমূহেরও প্রভু,\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmdccxciv{নিঃসন্দেহ আমরা নিকটবর্তী আকাশকে তারকারাজির শোভা দিয়ে সুশোভিত করেছি, --\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmdccxcv{আর প্রতিরক্ষা প্রত্যেক বিদ্রোহাচারী শয়তান থেকে।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmdccxcvi{তারা কান পাততে পারে না ঊর্ধ্ব এলাকার দিকে, আর তাদের প্রতি নিক্ষেপ করা হয় সব দিক থেকে, --\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmdccxcvii{বিতাড়িত, আর তাদের জন্য রয়েছে নিরবচ্ছিন্ন শাস্তি, --\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmdccxcviii{সে ব্যতীত যে ছিনিয়ে নেয় একটুকুন ছিনতাই, কিন্তু তাকে অনুসরণ করে একটি জ্বলন্ত অগ্নিশিখা।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmdccxcix{সুতরাং তাদের জিজ্ঞাসা করো, -- গঠনে তারা কি বেশী বলিষ্ঠ না যাদের আমরা সৃষ্টি করেছি? নিঃসন্দেহ তাদের আমরা সৃষ্টি করেছি আঠালো কাদা থেকে।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmdccc{বস্তুতঃ তুমি তো তাজ্জব হচ্ছো, আর তারা করছে মস্করা।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmdccci{আর যখন তাদের স্মরণ করিয়ে দেওয়া হয় তারা মনোযোগ দেয় না,\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmdcccii{আর যখন তারা কোনো নিদর্শন দেখতে পায় তারা ঠাট্টাবিদ্রূপ করে,\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmdccciii{আর বলে -- ''এটি স্পষ্ট জাদু বৈ তো নয়’’,\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmdccciv{''কী! যখন আমরা মারা যাব এবং ধূলোমাটি ও হাড়গোড় হয়ে যাব তখন কি আমরা ঠিকঠিকই পুনরুত্থিত হব?’’\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmdcccv{''আর কি পুরাকালের আমাদের পিতৃপুরুষরাও?’’\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmdcccvi{তুমি বলো -- ''হাঁ, আর তোমরা লাঞ্ছিত হবে।’’\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmdcccvii{তখন সেটি কিন্তু একটিমাত্র মহাগর্জন হবে, তখন দেখো! তারা চেয়ে থাকবে।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmdcccviii{আর তারা বলবে -- ''হায় ধিক্‌, আমাদের! এটিই তো বিচারের দিন!’’\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmdcccix{''এইটিই ফয়সালা করার দিন যেটি সন্বন্ধে তোমরা মিথ্যা আখ্যা দিতে।’’\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmdcccx{''যারা অনাচার করেছিল তাদের একত্র করো, আর তাদের সহচরদের, আর তাদেরও যাদের তারা উপাসনা করত --\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmdcccxi{''আল্লাহ্‌কে বাদ দিয়ে, তারপর তাদের পরিচালিত করো দুযখের পথে।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmdcccxii{''আর তাদের থামাও, তারা অবশ্যই জিজ্ঞাসিত হবে,\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmdcccxiii{''তোমাদের কি হল, তোমরা পরস্পরকে সাহায্য করছ না?’’\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmdcccxiv{বস্তুতঃ সেদিন তারা আ‌ত্মসমর্পিত হবে।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmdcccxv{আর তাদের কেউ কেউ অন্যদের দিকে এগিয়ে যাবে পরস্পরকে প্রশ্ন করে --\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmdcccxvi{তারা বলবে -- ''তোমরাই তো নিশ্চয়ই আমাদের কাছে আসতে ডান দিকে থেকে।’’\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmdcccxvii{তারা বলবে -- ''না, তোমরা তো বিশ্বাসীই ছিলে না,\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmdcccxviii{''আর তোমাদের উপরে আমাদের কোনো আধিপত্য ছিল না, বরং তোমরাই ছিলে উচ্ছৃঙ্খল লোক।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmdcccxix{''সেজন্যে আমাদের বিরুদ্ধে আমাদের প্রভুর বাণী সত্য প্রতিপন্ন হয়েছে, আমরা নিশ্চয়ই আস্বাদন করতে যাচ্ছি।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmdcccxx{''বস্তুত আমরা তোমাদের বিপথে নিয়েছিলাম, কেননা আমরা নিজেরাই বিপথগামী ছিলাম।’’\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmdcccxxi{সুতরাং সেইদিন তারা নিশ্চয়ই শাস্তিতে একে অন্যের শরিক হবে।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmdcccxxii{নিঃসন্দেহ এইরূপই আমরা অপরাধীদের প্রতি করে থাকি।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmdcccxxiii{নিঃসন্দেহ যখন তাদের বলা হতো -- 'আল্লাহ্ ছাড়া অন্য উপাস্য নেই’, তখন তারা হামবড়াই করত,\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmdcccxxiv{আর তারা বলত -- ''কী! আমরা কি আমাদের উপাস্যদের সত্যিই ত্যাগ করব একজন পাগলা কবির কারণে?’’\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmdcccxxv{বস্তুত তিনি সত্য নিয়ে এসেছেন, আর রসূলগণকে তিনি সত্য প্রতিপন্ন করেছেন।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmdcccxxvi{তোমরা নিশ্চয়ই মর্মন্তুদ শাস্তি আস্বাদন করতেই যাচ্ছ,\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmdcccxxvii{আর তোমাদের প্রতিদান দেওয়া হবে না তোমরা যা করতে তা ব্যতীত, --\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmdcccxxviii{আল্লাহ্‌র নিষ্ঠাবান বান্দারা ব্যতীত।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmdcccxxix{এরাই -- এদের জন্য রয়েছে সুপরিচিত রিযেক,\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmdcccxxx{ফলমূল, আর তারা হবে সম্মানিত --\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmdcccxxxi{আনন্দময় উদ্যানে,\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmdcccxxxii{তখতের উপরে মুখোমুখি হয়ে রইবে।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmdcccxxxiii{তাদের কাছে ঘুরে ফিরে পরিবেশন করা হবে নির্মল ফোয়ারা থেকে এক শরবতের পাত্র, --\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmmdcccxxxiv{সাদা সুস্বাদু পানকারীদের জন্য।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmmdcccxxxv{এতে মাথাব্যথা নেই, আর তারা এ থেকে মাতালও হবে না।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmmdcccxxxvi{আর তাদের কাছে থাকবে সলাজ-নম্র আয়তলোচন, --\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmmdcccxxxvii{যেন তারা সুরক্ষিত ডিম।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmmdcccxxxviii{তখন তাদের কেউ কেউ অন্যদের দিকে এগিয়ে যাবে পরস্পরকে জিজ্ঞাসাবাদ করে।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmmdcccxxxix{তাদের মধ্যে কোনো এক বক্তা বলবে -- ''আমার অবশ্য এক বন্ধু ছিল,\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmmdcccxl{''সে বলত, 'তুমি কি নিশ্চয়ই সমর্থনকারীদের মধ্যেকার?\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmmdcccxli{''কী! যখন আমরা মরে যাব এবং ধূলোমাটি ও হাড়গোড় হয়ে যাব, তখন কি আমরা ঠিকঠিকই প্রতিফল ভোগ করব’?’’\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmmdcccxlii{সে বলবে -- ''তোমরা কি উঁকি দিয়ে দেখবে?’’\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmmdcccxliii{তখন সে উঁকি দেবে আর ওকে দুযখের কেন্দ্রস্থলে দেখতে পাবে।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mmmdcccxliv{সে বলবে -- ''আল্লাহ্‌র কসম! তুমি তো আমাকে প্রায় ধ্বংস করেছিলে,\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mmmdcccxlv{''আর আমার প্রভুর অনুগ্রহ যদি না থাকত তবে আমিও নিশ্চয় উপস্থিতদের অন্তর্ভুক্ত হতাম।’’\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mmmdcccxlvi{''তবে কি আমরা মরতে যাচ্ছি না, --\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mmmdcccxlvii{''আমাদের প্রথমবারের মৃত্যু ব্যতীত, আর আমরা শাস্তি পেতে যাচ্ছি না।\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mmmdcccxlviii{''নিশ্চয়ই এই -- এটিই তো মহাসাফল্য!’’\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mmmdcccxlix{এর অনুরূপ অবস্থার জন্য তবে কর্মীরা কাজ করে যাক।\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mmmdcccl{এইটিই অধিক ভাল আপ্যায়ন, না যাক্কুম গাছ?\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mmmdcccli{নিঃসন্দেহ আমরা এটিকে সৃষ্টি করেছি দুরাচারীদের জন্য পরীক্ষা স্বরূপ।\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mmmdccclii{নিঃসন্দেহ এটি এমন এক গাছ যা দুযখের তলায় --\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mmmdcccliii{এর ফলফসল যেন শয়তানদের মুন্ডু।\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mmmdcccliv{তারা তখন নিশ্চয় এ থেকে আহার করবে আর এর দ্বারা পেট ভর্তি করবে।\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mmmdccclv{তারপর অবশ্য তাদের জন্য এর উপরে থাকবে ফুটন্ত জলের পানীয়।\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mmmdccclvi{তারপর নিশ্চয়ই তাদের প্রত্যাবর্তনস্থল হবে ভয়ঙ্কর আগুনের প্রতি।\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mmmdccclvii{তারা আলবৎ তাদের পিতৃপুরুষদের পথভ্রষ্টরূপেই পেয়েছিল,\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mmmdccclviii{তাই তারা তাদের পদচিহ্নের অন্ধ অনুসরণ করেছিল,\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@mmmdccclix{আর তাদের আগে অধিকাংশ পূর্ববর্তীরা বিপথে গিয়েছিল,\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@mmmdccclx{অথচ আমরা তাদের মধ্যে ইতিপূর্বে সতর্ককারীদের পাঠিয়েছিলাম,\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@mmmdccclxi{সুতরাং চেয়ে দেখো কেমন হয়েছিল সতর্কীকৃতদের পরিণাম,\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@mmmdccclxii{শুধু আল্লাহ্‌র খাস বান্দাদের ব্যতীত।\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@mmmdccclxiii{আর ইতিপূর্বে অবশ্য নূহ আমাদের আহ্বান করেছিলেন, আর আমরা কত উত্তম উত্তরদাতা।\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@mmmdccclxiv{আর আমরা তাঁকে ও তাঁর পরিজনকে ভীষণ সংকট থেকে উদ্ধার করেছিলাম,\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@mmmdccclxv{আর তাঁর সন্তান-সন্ততিকে আমরা বানিয়েছিলাম প্রকৃত টিকে থাকা দল,\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@mmmdccclxvi{আর তাঁর জন্য পরবর্তীদের মধ্যে আমরা রেখেছিলাম --\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@mmmdccclxvii{সমগ্র বিশ্বজগতের মধ্যে নূহের প্রতি সালাম!\qt@no{(79)}}
\qt@newcmd\qurantrans@bn@mmmdccclxviii{নিঃসন্দেহ এইভাবেই আমরা সৎকর্মশীলদের প্রতিদান দিয়ে থাকি।\qt@no{(80)}}
\qt@newcmd\qurantrans@bn@mmmdccclxix{তিনি অবশ্যই আমাদের বিশ্বাসী বান্দাদের অন্তর্ভুক্ত ছিলেন।\qt@no{(81)}}
\qt@newcmd\qurantrans@bn@mmmdccclxx{আর আমরা অন্যান্যদের ডুবিয়ে দিয়েছিলাম।\qt@no{(82)}}
\qt@newcmd\qurantrans@bn@mmmdccclxxi{আর নিশ্চয়ই তাঁর পশ্চাদবর্তীদের মধ্যে ছিলেন ইব্রাহীম।\qt@no{(83)}}
\qt@newcmd\qurantrans@bn@mmmdccclxxii{স্মরণ কর! তিনি তাঁর প্রভুর কাছে এসেছিলেন বিশুদ্ধ চিত্ত নিয়ে, --\qt@no{(84)}}
\qt@newcmd\qurantrans@bn@mmmdccclxxiii{যখন তাঁর পিতৃপুরুষকে ও তাঁর স্বজাতিকে তিনি বলেছিলেন -- ''তোমরা কিসের উপাসনা করছ?\qt@no{(85)}}
\qt@newcmd\qurantrans@bn@mmmdccclxxiv{''তোমরা আল্লাহকে বাদ দিয়ে কি এক মিথ্যা উপাস্যকেই কামনা কর?\qt@no{(86)}}
\qt@newcmd\qurantrans@bn@mmmdccclxxv{''তাহলে বিশ্বজগতের প্রভু সন্বন্ধে কী তোমাদের ধারণা?’’\qt@no{(87)}}
\qt@newcmd\qurantrans@bn@mmmdccclxxvi{তারপর তারকারাজির দিকে তিনি একনজর তাকালেন,\qt@no{(88)}}
\qt@newcmd\qurantrans@bn@mmmdccclxxvii{তখন তিনি বললেন -- ''আমি যারপর নাই বিরক্ত!’’\qt@no{(89)}}
\qt@newcmd\qurantrans@bn@mmmdccclxxviii{সুতরাং তারা তাঁর কাছ থেকে বিমুখ হয়ে ফিরে গেল।\qt@no{(90)}}
\qt@newcmd\qurantrans@bn@mmmdccclxxix{তারপর তিনি তাদের উপাস্যদের কাছে ফিরে গেলেন এবং বললেন -- ''তোমরা খাও না কেন?\qt@no{(91)}}
\qt@newcmd\qurantrans@bn@mmmdccclxxx{''তোমাদের কী হয়েছে যে তোমরা কথা বলছ না?’’\qt@no{(92)}}
\qt@newcmd\qurantrans@bn@mmmdccclxxxi{কাজেই তিনি তাদের উপরে লাফিয়ে পড়লেন ডানহাতে আঘাত করে।\qt@no{(93)}}
\qt@newcmd\qurantrans@bn@mmmdccclxxxii{তখন তারা তাঁর দিকে ছুটে এল হতবুদ্ধি হয়ে।\qt@no{(94)}}
\qt@newcmd\qurantrans@bn@mmmdccclxxxiii{তিনি বললেন -- ''তোমরা কি তার উপাসনা কর যা তোমরা কেটে বানাও,\qt@no{(95)}}
\qt@newcmd\qurantrans@bn@mmmdccclxxxiv{''অথচ আল্লাহ্ তোমাদের সৃষ্টি করেছেন আর তোমরা যা তৈরি কর তাও?’’\qt@no{(96)}}
\qt@newcmd\qurantrans@bn@mmmdccclxxxv{তারা বললে -- ''এর জন্য এক কাঠামো তৈরি কর, তারপর তাকে নিক্ষেপ কর সেই ভয়ঙ্কর আগুনে।’’\qt@no{(97)}}
\qt@newcmd\qurantrans@bn@mmmdccclxxxvi{কাজেই তারা তাঁর বিরুদ্ধে এক চক্রান্ত ফাঁদলো, কিন্তু আমরা তাদের হীন বানিয়ে দিলাম।\qt@no{(98)}}
\qt@newcmd\qurantrans@bn@mmmdccclxxxvii{আর তিনি বললেন -- ''আমি নিশ্চয়ই আমার প্রভুর দিকে যাত্রাকারী, তিনি আমাকে অচিরেই পরিচালিত করবেন।’’\qt@no{(99)}}
\qt@newcmd\qurantrans@bn@mmmdccclxxxviii{''আমার প্রভু! আমার জন্য সৎকর্মীদের থেকে দান করো।’’\qt@no{(100)}}
\qt@newcmd\qurantrans@bn@mmmdccclxxxix{সেজন্য আমরা তাঁকে সুসংবাদ দিলাম এক অমায়িক পুত্রসন্তানের।\qt@no{(101)}}
\qt@newcmd\qurantrans@bn@mmmdcccxc{তারপর যখন সে তাঁর সঙ্গে কাজ করার যোগ্যতায় উপনীত হল তখন তিনি বললেন -- ''হে আমার পুত্রধন! নিঃসন্দেহ আমি স্বপ্নে দেখলাম যে আমি তোমাকে কুরবানি করছি, অতএব ভেবে দেখো -- কী তুমি দেখছো ।’’ তিনি বললেন -- ''হে আমার আব্বা! আপনি তাই করুন যা আপনাকে আদেশ করা হয়েছে। ইন-শা-আল্লাহ্ আপনি এখনি আমাকে পাবেন অধ্যবসায়ীদের অন্তর্ভুক্ত।\qt@no{(102)}}
\qt@newcmd\qurantrans@bn@mmmdcccxci{সুতরাং তাঁরা উভয়ে যখন আ‌ত্মসমর্পণ করলেন এবং তিনি তাঁকে ভূপাতিত করলেন কপালের জন্য,\qt@no{(103)}}
\qt@newcmd\qurantrans@bn@mmmdcccxcii{তখনই আমরা তাঁকে ডেকে বললাম -- ''হে ইব্রাহীম!\qt@no{(104)}}
\qt@newcmd\qurantrans@bn@mmmdcccxciii{''তুমি তো স্বপ্নাদেশ সত্যই পালন করলে। নিঃসন্দেহ এইভাবেই আমরা সৎকর্মশীলদের পুরস্কার দিয়ে থাকি।\qt@no{(105)}}
\qt@newcmd\qurantrans@bn@mmmdcccxciv{''নিশ্চয়ই এটি -- এইটিই তো ছিল এক স্পষ্ট পরীক্ষা।’’\qt@no{(106)}}
\qt@newcmd\qurantrans@bn@mmmdcccxcv{আর আমরা তাঁকে বদলা দিয়েছিলাম এক মহান কুরবানি।\qt@no{(107)}}
\qt@newcmd\qurantrans@bn@mmmdcccxcvi{আর আমরা তাঁর জন্য পরবর্তীদের মধ্যে রেখেছিলাম --\qt@no{(108)}}
\qt@newcmd\qurantrans@bn@mmmdcccxcvii{ইব্রাহীমের প্রতি ''সালাম’’।\qt@no{(109)}}
\qt@newcmd\qurantrans@bn@mmmdcccxcviii{এইভাবেই আমরা প্রতিদান দিই সৎকর্মশীলদের।\qt@no{(110)}}
\qt@newcmd\qurantrans@bn@mmmdcccxcix{নিঃসন্দেহ তিনি ছিলেন আমাদের মুমিন বান্দাদের মধ্যেকার।\qt@no{(111)}}
\qt@newcmd\qurantrans@bn@mmmcm{আর আমরা তাঁকে সুসংবাদ দিয়েছিলাম ইসহাকের -- একজন নবী সৎপথাবলন্বীদের মধ্যেকার।\qt@no{(112)}}
\qt@newcmd\qurantrans@bn@mmmcmi{আর আমরা আশীর্বাদ বর্ষণ করেছিলাম তাঁর উপরে ও ইসহাকের উপরে। আর তাঁদের দুজনের বংশধরদের মধ্যে থেকে কেউ হচ্ছেন সৎকর্মশীল, আর কেউ হচ্ছে তাদের নিজেদের প্রতি স্পষ্টভাবে অন্যায়াচারী।\qt@no{(113)}}
\qt@newcmd\qurantrans@bn@mmmcmii{আর নিশ্চয় আমরা মূসা ও হারূনের প্রতি অনুগ্রহ করেই ছিলাম,\qt@no{(114)}}
\qt@newcmd\qurantrans@bn@mmmcmiii{আর তাঁদের দুজনকে ও তাঁদের লোকদলকে আমরা ভীষণ সংকট থেকে উদ্ধার করেছিলাম।\qt@no{(115)}}
\qt@newcmd\qurantrans@bn@mmmcmiv{আর আমরা তাঁদের সাহায্য করেছিলাম, সেজন্য তাঁরা খোদ বিজয়ী হয়েছিলেন।\qt@no{(116)}}
\qt@newcmd\qurantrans@bn@mmmcmv{আর তাঁদের উভয়কে আমরা দিয়েছিলাম এক স্পষ্ট গ্রন্থ,\qt@no{(117)}}
\qt@newcmd\qurantrans@bn@mmmcmvi{আর তাঁদের উভয়কে আমরা পরিচালিত করেছিলাম সরল-সঠিক পথে,\qt@no{(118)}}
\qt@newcmd\qurantrans@bn@mmmcmvii{আর তাদের জন্য আমরা পরবর্তীদের মধ্যে রেখেছিলাম --\qt@no{(119)}}
\qt@newcmd\qurantrans@bn@mmmcmviii{মূসা ও হারূনের প্রতি ''সালাম’’।\qt@no{(120)}}
\qt@newcmd\qurantrans@bn@mmmcmix{এইভাবেই আমরা অবশ্য প্রতিদান দিই সৎকর্মশীলদের।\qt@no{(121)}}
\qt@newcmd\qurantrans@bn@mmmcmx{নিশ্চয় তাঁরা ছিলেন আমাদের মুমিন বান্দাদের মধ্যেকার।\qt@no{(122)}}
\qt@newcmd\qurantrans@bn@mmmcmxi{আর নিশ্চয়ই ইল্‌য়াস রসূলগণের মধ্যেকার ছিলেন।\qt@no{(123)}}
\qt@newcmd\qurantrans@bn@mmmcmxii{স্মরণ করো, তিনি তাঁর স্বজাতিকে বলেছিলেন -- ''তোমরা কি ধর্মভীরুতা অবলন্বন করবে না?\qt@no{(124)}}
\qt@newcmd\qurantrans@bn@mmmcmxiii{''তোমরা কি বা’লকে ডাকবে, আর পরিত্যাগ করবে সৃষ্টিকর্তাদের সর্বশ্রেষ্ঠজনকে,\qt@no{(125)}}
\qt@newcmd\qurantrans@bn@mmmcmxiv{আল্লাহ্‌কে -- তোমাদের প্রভু এবং পূর্বকালীন তোমাদের পিতৃপুরুষদেরও প্রভু?’’\qt@no{(126)}}
\qt@newcmd\qurantrans@bn@mmmcmxv{কিন্তু তারা তাঁর প্রতি মিথ্যারোপ করল, সেজন্য তাদের নিশ্চয়ই হাজির করা হবে,\qt@no{(127)}}
\qt@newcmd\qurantrans@bn@mmmcmxvi{শুধু আল্লাহ্‌র একনিষ্ঠ বান্দাদের ব্যতীত।\qt@no{(128)}}
\qt@newcmd\qurantrans@bn@mmmcmxvii{আর তাঁর জন্য আমরা পরবর্তীদের মধ্যে রেখেছিলাম --\qt@no{(129)}}
\qt@newcmd\qurantrans@bn@mmmcmxviii{ইল্‌য়াসীনের উপরে ''সালাম’’।\qt@no{(130)}}
\qt@newcmd\qurantrans@bn@mmmcmxix{নিঃসন্দেহ এইভাবেই আমরা সৎকর্মশীলদের পুরস্কার দিয়ে থাকি।\qt@no{(131)}}
\qt@newcmd\qurantrans@bn@mmmcmxx{তিনি নিশ্চয়ই ছিলেন আমাদের মুমিন বান্দাদের অন্যতম।\qt@no{(132)}}
\qt@newcmd\qurantrans@bn@mmmcmxxi{আর অবশ্যই লূত ছিলেন রসূলগণের মধ্যেকার।\qt@no{(133)}}
\qt@newcmd\qurantrans@bn@mmmcmxxii{স্মরণ কর! তাঁকে ও তাঁর পরিজনকে উদ্ধার করেছিলাম, সব ক’জনকেই --\qt@no{(134)}}
\qt@newcmd\qurantrans@bn@mmmcmxxiii{এক বৃদ্ধাকে ব্যতীত, যে ছিল পেছনে রয়ে যাওয়া দলের।\qt@no{(135)}}
\qt@newcmd\qurantrans@bn@mmmcmxxiv{তারপর আমরা অবশিষ্টদের সম্পূর্ণরূপে ধ্বংস করেছিলাম।\qt@no{(136)}}
\qt@newcmd\qurantrans@bn@mmmcmxxv{আর নিঃসন্দেহ তোমরা তো তাদের অতিক্রম করে থাক সকালবেলায়,\qt@no{(137)}}
\qt@newcmd\qurantrans@bn@mmmcmxxvi{এবং রাত্রিকালে। তবুও কি তোমরা বুঝবে না।\qt@no{(138)}}
\qt@newcmd\qurantrans@bn@mmmcmxxvii{আর নিশ্চয়ই ইউনুস ছিলেন রসূলগণের অন্যতম।\qt@no{(139)}}
\qt@newcmd\qurantrans@bn@mmmcmxxviii{স্মরণ করো! তিনি বোঝাই করা জাহাজে গিয়ে উঠেছিলেন।\qt@no{(140)}}
\qt@newcmd\qurantrans@bn@mmmcmxxix{তাই তিনি লটারী খেলেছিলেন, কিন্তু তিনিই হয়ে গেলেন নিক্ষিপ্তদের একজন।\qt@no{(141)}}
\qt@newcmd\qurantrans@bn@mmmcmxxx{তখন একটি মাছ তাঁকে মুখে তুলে নিল, যদিও তিনি দোষী সাব্যস্ত হয়েছিলেন।\qt@no{(142)}}
\qt@newcmd\qurantrans@bn@mmmcmxxxi{আর তিনি যদি মহিমা জপতপে রত না থাকতেন --\qt@no{(143)}}
\qt@newcmd\qurantrans@bn@mmmcmxxxii{তাহলে তিনি তার পেটে রয়ে যেতেন পুনরুত্থান দিন পর্যন্ত।\qt@no{(144)}}
\qt@newcmd\qurantrans@bn@mmmcmxxxiii{তারপর আমরা তাঁকে এক বৃক্ষলতা শূন্য উপকূলে ফেলে দিলাম, আর তিনি ছিলেন অসুস্থ।\qt@no{(145)}}
\qt@newcmd\qurantrans@bn@mmmcmxxxiv{তখন তাঁর উপরে আমরা জন্মিয়েছিলাম লাউজাতীয় গাছ,\qt@no{(146)}}
\qt@newcmd\qurantrans@bn@mmmcmxxxv{আর আমরা তাঁকে পাঠিয়েছিলাম এক লাখ বা আরো বেশী লোকের কাছে,\qt@no{(147)}}
\qt@newcmd\qurantrans@bn@mmmcmxxxvi{তখন তারা বিশ্বাস করেছিল, সেজন্য আমরা তাদের উপভোগ করতে দিয়েছিলাম কিছুকালের জন্য।\qt@no{(148)}}
\qt@newcmd\qurantrans@bn@mmmcmxxxvii{সুতরাং তাদের জিজ্ঞাসা করো -- তোমার প্রভুর জন্য কি কন্যাসন্তান রয়েছে, আর তাদের জন্য পুত্রসন্তান?\qt@no{(149)}}
\qt@newcmd\qurantrans@bn@mmmcmxxxviii{অথবা, আমরা কি ফিরিশ্‌তাদের নারীরূপে সৃষ্টি করেছিলাম, আর তারা সাক্ষী ছিল?\qt@no{(150)}}
\qt@newcmd\qurantrans@bn@mmmcmxxxix{এটি কি নয় যে তারা আলবৎ তাদের মিথ্যা থেকেই তো কথা বলছে, --\qt@no{(151)}}
\qt@newcmd\qurantrans@bn@mmmcmxl{আল্লাহ্ জন্ম দিয়েছিলেন? আর তারা তো নিশ্চয়ই মিথ্যাবাদী।\qt@no{(152)}}
\qt@newcmd\qurantrans@bn@mmmcmxli{তিনি কি কন্যাদের পছন্দ করেছেন পুত্রদের পরিবর্তে?\qt@no{(153)}}
\qt@newcmd\qurantrans@bn@mmmcmxlii{তোমাদের কি হয়েছে? কিভাবে তোমরা বিচার করো?\qt@no{(154)}}
\qt@newcmd\qurantrans@bn@mmmcmxliii{তোমরা কি তবে মনোযোগ দেবে না?\qt@no{(155)}}
\qt@newcmd\qurantrans@bn@mmmcmxliv{নাকি তোমাদের কাছে কোনো স্পষ্ট দলিল-প্রমাণ রয়েছে?\qt@no{(156)}}
\qt@newcmd\qurantrans@bn@mmmcmxlv{তেমন হলে তোমাদের গ্রন্থ নিয়ে এস, যদি তোমরা সত্যবাদী হও।\qt@no{(157)}}
\qt@newcmd\qurantrans@bn@mmmcmxlvi{আর তারা তাঁর মধ্যে ও জিনদের মধ্যে একটা সম্পর্ক দাঁড় করিয়েছে। আর জিনরা তো জেনেই ফেলেছে যে তাদের অবশ্যই উপস্থাপিত করা হবে।\qt@no{(158)}}
\qt@newcmd\qurantrans@bn@mmmcmxlvii{আল্লাহ্‌রই সব মহিমা! তারা যা আরোপ করে তা থেকে বহু ঊর্ধ্বে, --\qt@no{(159)}}
\qt@newcmd\qurantrans@bn@mmmcmxlviii{আল্লাহ্‌র নিষ্ঠাবান বান্দারা ব্যতীত।\qt@no{(160)}}
\qt@newcmd\qurantrans@bn@mmmcmxlix{অতএব নিশ্চয়ই তোমরা ও যাদের তোমরা উপাসনা কর তারা --\qt@no{(161)}}
\qt@newcmd\qurantrans@bn@mmmcml{তোমরা তাঁর বিরুদ্ধে বিভ্রান্তকারী হতে পারবে না, --\qt@no{(162)}}
\qt@newcmd\qurantrans@bn@mmmcmli{তাকে ব্যতীত যে জ্বলন্ত আগুনে পুড়তে চায়।\qt@no{(163)}}
\qt@newcmd\qurantrans@bn@mmmcmlii{আর ''আমাদের মধ্যে এমন কেউ নেই যার জন্যে নির্ধারিত আবাস নেই,\qt@no{(164)}}
\qt@newcmd\qurantrans@bn@mmmcmliii{''আর নিশ্চয়ই আমরা, আমরাই তো সারিবদ্ধভাবে দাঁড়াব,\qt@no{(165)}}
\qt@newcmd\qurantrans@bn@mmmcmliv{''আর অবশ্য আমরা, আলবৎ আমরা জপ করতে থাকব।’’\qt@no{(166)}}
\qt@newcmd\qurantrans@bn@mmmcmlv{আর নিশ্চয়ই তারা বলতে থাকতো --\qt@no{(167)}}
\qt@newcmd\qurantrans@bn@mmmcmlvi{''যদি আমাদের কাছে পূর্ববর্তীদের কাছ থেকে কোনো স্মরণীয় গ্রন্থ থাকতো,\qt@no{(168)}}
\qt@newcmd\qurantrans@bn@mmmcmlvii{''তাহলে আমরা আল্লাহ্‌র নিষ্ঠাবান বান্দা হতে পারতাম।’’\qt@no{(169)}}
\qt@newcmd\qurantrans@bn@mmmcmlviii{কিন্তু তারা এতে অবিশ্বাস পোষণ করে, কাজেই শীঘ্রই তারা জানতে পারবে।\qt@no{(170)}}
\qt@newcmd\qurantrans@bn@mmmcmlix{আর অবশ্যই আমাদের বক্তব্য আমাদের বান্দাদের -- প্রেরিত পুরুষদের, জন্য সাব্যস্ত হয়েই গেছে, --\qt@no{(171)}}
\qt@newcmd\qurantrans@bn@mmmcmlx{নিঃসন্দেহ তাঁরা -- তাঁরাই তো হবে সাহায্যপ্রাপ্ত,\qt@no{(172)}}
\qt@newcmd\qurantrans@bn@mmmcmlxi{আর নিঃসন্দেহ আমাদের সেনাদল -- তারাই তো হবে বিজয়ী।\qt@no{(173)}}
\qt@newcmd\qurantrans@bn@mmmcmlxii{অতএব তাদের থেকে ফিরে থেকো কিছুকালের জন্য,\qt@no{(174)}}
\qt@newcmd\qurantrans@bn@mmmcmlxiii{আর তাদের প্রতি লক্ষ্য রাখো, কেননা তারাও শীঘ্রই দেখতে পাবে।\qt@no{(175)}}
\qt@newcmd\qurantrans@bn@mmmcmlxiv{তারা কি তবে আমাদের শাস্তি ত্বরান্বিত করতে চায়?\qt@no{(176)}}
\qt@newcmd\qurantrans@bn@mmmcmlxv{কিন্তু যখন তা তাদের আঙিনায় অবতরণ করবে তখন সতর্কীকৃতদের প্রভাত হবে কত মন্দ!\qt@no{(177)}}
\qt@newcmd\qurantrans@bn@mmmcmlxvi{আর তুমি তাদের থেকে ফিরে থেকো কিছুকালের জন্য,\qt@no{(178)}}
\qt@newcmd\qurantrans@bn@mmmcmlxvii{আর লক্ষ্য রাখো, কেননা তারাও শীঘ্রই দেখতে পাবে।\qt@no{(179)}}
\qt@newcmd\qurantrans@bn@mmmcmlxviii{মহিমা কীর্তিত হোক তোমার প্রভুর -- পরম মর্যাদা সম্পন্ন প্রভুর, তারা যা-কিছু আরোপ করে তা থেকে বহু ঊর্ধ্বে।\qt@no{(180)}}
\qt@newcmd\qurantrans@bn@mmmcmlxix{আর 'সালাম’ প্রেরিতপুরুষদের উপরে।\qt@no{(181)}}
\qt@newcmd\qurantrans@bn@mmmcmlxx{আর সকল প্রশংসা আল্লাহ্‌রই জন্য -- বিশ্বজগতের প্রভু!\qt@no{(182)}}
\qt@newcmd\qurantrans@bn@mmmcmlxxi{\basmalahbn ছোয়াদ! উপদেশ পরিপূর্ণ কুরআনের শপথ।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmcmlxxii{কিন্ত যারা অবিশ্বাস পোষণ করে তারা আ‌ত্মাভিমানে ও দলপাকানোয় মগ্ন রয়েছে।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmcmlxxiii{এদের পূর্বে মানবগোষ্ঠীর কতকে যে আমরা ধ্বংস করেছি! তখন তারা চীৎকার করেছিল। কিন্ত সেই সময়ে পরিত্রাণের আর উপায় ছিল না।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmcmlxxiv{আর তারা আশ্চর্য হয় যে তাদের মধ্য থেকেই তাদের কাছে একজন সতর্ককারী এসেছেন, আর অবিশ্বাসীরা বলে -- ''এ তো একজন জাদুকর, ধোকাবাজ।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmcmlxxv{''কী! সে কি উপাস্যগণকে একইজন উপাস্য বানিয়েছে? এ তো নিশ্চয়ই এক আজব ব্যাপার!’’\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmcmlxxvi{আর তাদের মধ্যের প্রধানরা সরে পড়ে এই বলে -- ''তোমরা যাও এবং তোমাদের উপাস্যদের প্রতি আকঁড়ে থাকো। নিঃসন্দেহ এটি হচ্ছে অভিসন্ধিমূলক ব্যাপার।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmcmlxxvii{''আমরা শেষের ধর্মবিধানে এমন কথা শুনি নি, এটি মনগড়া উক্তি বৈ তো নয়।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmcmlxxviii{''কী! আমাদের মধ্য থেকে বুঝি তারই কাছে স্মারক-গ্রন্থ অবতীর্ণ হল?’’ বস্তুতঃ তারা আমার স্মারক গ্রন্থ সন্বন্ধে সন্দেহের মধ্যেই রয়েছে? প্রকৃতপক্ষে তারা এখনও আমার শাস্তি আস্বাদন করে নি।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmcmlxxix{অথবা তাদের কাছে কি রয়েছে তোমার প্রভুর করুণার ভান্ডার -- মহাশক্তিশালী, মহাদাতা?\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmcmlxxx{অথবা তাদের কি সার্বভৌমত্ব আছে মহাকাশমন্ডলীর ও পৃথিবীর এবং এই দুইয়ের মধ্যে যা-কিছু আছে তার? তাহলে তারা মাল- আসবাবের মধ্যে উঠতে থাকুক।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmcmlxxxi{এখানেই সম্মিলিত সৈন্যদলের এক বাহিনী পরাজিত হবে।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmcmlxxxii{এদের আগে নূহের ও 'আদের ও বহু শিবিরের মালিক ফিরআউনের লোকদল মিথ্যারোপ করেছিল,\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmcmlxxxiii{আর ছামুদজাতি ও লুতের স্বজাতি ও অরণ্যের বাসিন্দারা। ওরাও ছিল বিশাল বাহিনী।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmcmlxxxiv{সকলেই রসূলগণের প্রতি মিথ্যারোপ করেছিল বৈ তো নয়, সেজন্য আমার শাস্তিদান ছিল ন্যায়সঙ্গত।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmcmlxxxv{আর এরা তো প্রতীক্ষা করে না একটিমাত্র মহাগর্জন ব্যতীত আর কিছুর, তা থেকে কোনো অবকাশ থাকবে না।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmcmlxxxvi{আর তারা বলে -- ''আমাদের প্রভু! হিসেব-নিকেশের দিনের আগেই আমাদের অংশ আমাদের জন্য ত্বরান্বিত কর।’’\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmcmlxxxvii{তারা যা বলে তা সত্ত্বেও তুমি অধ্যবসায় চালিয়ে যাও, আর আমাদের বান্দা হাত থাকা দাউদকে স্মরণ কর, তিনি নিশ্চয়ই সতত ফিরতেন!\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmcmlxxxviii{আমরা তো পাহাড়গুলোকে বশীভূত করেছিলাম তাঁর সঙ্গে জপ করতে রাত্রিকালে ও সূর্যোদয়ে, --\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmcmlxxxix{আর পাখীরা সমবেত হতো। সবাই ছিল তাঁর প্রতি অনুগত।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmcmxc{আর আমরা তাঁর সাম্রাজ্যকে সুদৃঢ় করেছিলাম, আর তাঁকে দিয়েছিলাম জ্ঞান ও বিচারক্ষমতাসম্পন্ন সংবিধান।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmcmxci{আর তোমার কাছে কি দুশমনের কাহিনী এসে পৌঁছেছে? কেমন করে তারা রাজকক্ষে বেয়ে উঠল?\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmcmxcii{যখন তারা দাউদের সামনে ঢুকে পড়ল তখন তিনি তাদের সন্বন্ধে সন্ত্রস্থ হলেন। তারা বললে -- ''ভয় করবেন না, দুজন দুশমন, আমাদের একজন অন্যজনের প্রতি শত্রুতা করেছে, অতএব আমাদের মধ্যে ন্যায়ের সাথে বিচার করে দিন, আর অন্যায় করবেন না, আর আমাদের সঠিক পথে পরিচালিত করুন।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmcmxciii{''এইজন অবশ্য আমার ভাই, তার রয়েছে নিরানব্বুইটি ভেড়ী আর আমার আছে একটিমাত্র ভেড়ী, কিন্ত সে বলে -- 'ওটি আমাকে দিয়ে দাও’, আর সে আমাকে তর্কাতর্কিতে হারিয়ে দিয়েছে।’’\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmcmxciv{তিনি বললেন -- ''তোমার ভেড়ীকে তার ভেড়ীদের সঙ্গে দাবি করে সে তোমার প্রতি আলবৎ অন্যায় করেছে। নিঃসন্দেহ অংশীদারদের মধ্যের অনেকেই -- তাদের কেউ কেউ অন্যের প্রতি শত্রুতা করে, তারা ব্যতীত যারা ঈমান এনেছে ও সৎকাজ করছে, আর যারা তেমন তারা অল্পসংখ্যক।’’ আর দাউদ ভেবেছিলেন যে আমরা নিশ্চয়ই তাঁকে পরীক্ষা করছিলাম, সেজন্য তিনি তাঁর প্রভুর কাছে পরিত্রাণ খুজঁছিলেন, আর তিনি লুটিয়ে পড়লেন আনত হয়ে এবং বারবার ফিরতে থাকলেন।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmcmxcv{কাজেই এই ব্যাপারে আমরা তাঁকে পরিত্রাণ করেছিলাম। আর নিশ্চয়ই তাঁর জন্য আমাদের কাছে তো নৈকট্য রয়েছে, আর রয়েছে এক সুন্দর গন্তব্যস্থল।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmcmxcvi{''হে দাউদ! আমরা তোমাকে পৃথিবীতে খলিফা বানিয়েছি, সেজন্য তুমি লোকজনের মধ্যে বিচার করো ন্যায়সঙ্গতভাবে, আর খেয়ালখুশীর অনুসরণ করো না, পাছে তা তোমাকে আল্লাহ্‌র পথ থেকে ভ্রষ্ট করে ফেলে। নিঃসন্দেহ যারা আল্লাহ্‌র পথ থেকে বিপথে যায় তাদের জন্য রয়েছে কঠোর শাস্তি। কেননা তারা ভুলে গিয়েছিল হিসেব-নিকেশের দিনের কথা।’’\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmcmxcvii{আর আমরা মহাকাশ ও পৃথিবী এবং এ দুয়ের মধ্যে যা-কিছু আছে তা বৃথা সৃষ্টি করি নি। এরকম ধারণা হচ্ছে তাদের যারা অবিশ্বাস পোষণ করে। সুতরাং আগুনের কারণে ধিক্ তাদের জন্য যারা অবিশ্বাস পোষণ করে।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmcmxcviii{যারা ঈমান এনেছে ও সৎকাজ করছে তাদের কি আমরা পৃথিবীতে ফ্যাসাদ-সৃষ্টিকারীদের ন্যায় গণ্য করব? অথবা ধর্মভীরুদের কি আমরা জ্ঞান করব পাপিষ্ঠদের ন্যায়?\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmcmxcix{একখানা গ্রন্থ -- আমরা এটি তোমার কাছে অবতারণ করছি, কল্যাণময়, যেন তারা এর আয়াতগুলো সন্বন্ধে ভাবতে পারে, আর বুদ্ধিশুদ্ধি থাকা লোকেরা যেন উপদেশ গ্রহণ করতে পারে।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmm{আর আমরা দাউদের জন্য সুলাইমানকে দিয়েছিলাম। অতি উত্তম বান্দা! নিঃসন্দেহ তিনি বারবার ফিরতেন।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmi{দেখো! বিকেলবেলা তাঁর সমক্ষে দ্রতগামী ঘোড়াদের হাজির করা হল,\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmmii{তখন তিনি বললেন -- ''আমি অবশ্য ভালবস্তুর ভাললাগাকে ভাল পেয়ে গেছি আমার প্রভুকে স্মরণ রাখার জন্যে,’’ -- যে পর্যন্ত না তারা পর্দার আড়ালে অদৃশ্য হয়ে গেল।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmmiii{''ওদের আমার কাছে নিয়ে এসো।’’ তখন তিনি পা ও ঘাড় মালিশ করতে লাগলেন।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmmiv{আর আমরা নিশ্চয়ই সুলাইমানকে পরীক্ষা করেছিলাম, আর তাঁর সিংহাসনে আমরা স্থাপন করেছিলাম একটি দেহ মাত্র, তখন তিনি ফিরলেন।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmmv{তিনি বললেন -- ''আমার প্রভু! আমাকে পরিত্রাণ করো আর আমাকে এমন এক সাম্রাজ্য প্রদান করো যা আমার পরে আর করোর জন্যে যোগ্য না হয়। নিঃসন্দেহ তুমি -- তুমিই মহাদাতা।’’\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmmvi{তারপর আমরা বাতাসকে তাঁর জন্য অনুগত করে দিলাম, তাঁর আদেশে তা স্বচ্ছন্দগতিতে চলত যেখানে তিনি পাঠাতেন,\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmmvii{আর শয়তানদের -- সবক’টি মিস্ত্রী ও ডুবুরী,\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmmviii{আর অন্যদের শৃঙ্খলাবদ্ধ অবস্থায়।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmmix{''এ হচ্ছে আমাদের দান, অতএব তুমি দান কর বা রেখে দাও -- কোনো হিসাবপত্র লাগবে না।’’\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmmx{আর নিঃসন্দেহ তাঁর জন্য আমাদের কাছে তো নৈকট্য অবধারিত রয়েছে, আর রয়েছে এক সুন্দর গন্তব্যস্থান।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmmxi{আর আমাদের বান্দা আইয়ূবকে স্মরণ করো। দেখো, তিনি তাঁর প্রভুকে ডেকে বলেছিলেন -- ''শয়তান আমাকে পীড়ন করছে ক্লান্তি ও কষ্ট দিয়ে।’’\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmmxii{''তোমার পা দিয়ে আঘাত করো, এটি এক ঠান্ডা গোসলের জায়গা ও পানীয়।’’\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmmxiii{আর আমরা তাঁকে দিয়েছিলাম তাঁর পরিজনবর্গ আর তাদের সঙ্গে তাদের মতো অন্যদের, -- আমাদের তরফ থেকে অনুগ্রহস্বরূপ এবং বোধশক্তির অধিকারীদের জন্য উপদেশ-স্বরূপ!\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmmxiv{আর ''তোমার হাতে একটি ডাল নাও এবং তা দিয়ে আঘাত করো, আর তুমি সংকল্প ত্যাগ করো না।’’ নিঃসন্দেহ আমরা তাঁকে পেয়েছিলাম অধ্যবসায়ী। কত উত্তম বান্দা! তিনি নিশ্চয়ই বারবার ফিরতেন।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmmxv{আর স্মরণ করো আমাদের দাস ইব্রাহীম ও ইসহাক ও ইয়াকুবকে, তাঁরা ছিলেন ক্ষমতার ও অন্তদৃষ্টির অধিকারী।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmmmxvi{নিঃসন্দেহ আমরা তাঁদের বানিয়েছিলাম এক অকৃত্রিম গুণে নিষ্ঠাবান -- বাসস্থানের স্মরণ।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmmmxvii{আর তাঁরা নিশ্চয়ই আমাদের কাছে ছিলেন মনোনীত ও সজ্জনদের অন্তর্ভুক্ত।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmmmxviii{আর স্মরণ কর ইসমাইল ও ইয়াসাআ ও যুল-কিফলকে, কারণ তাঁরা সবাই ছিলেন সজ্জনদের অন্যতম।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmmmxix{এ এক স্মারকগ্রন্থ, আর নিশ্চয়ই ধর্মভীরুদের জন্য তো রয়েছে উত্তম গন্তব্যস্থল, --\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmmmxx{নন্দন কানন, তাদের জন্য খোলা রয়েছে দরজাগুলো।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmmmxxi{সেখানে তারা হেলান দিয়ে সমাসীন হবে, আহ্বান করবে সেখানে প্রচুর ফলমূল ও পানীয় দ্রব্যের জন্য।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmmmxxii{তার তাদের কাছে থাকবে সলাজ-নম্র আয়তলোচন, সমবয়স্ক।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmmmxxiii{''এটিই সেই যা তোমাদের ওয়াদা করা হয়েছিল হিসেব-নিকেশের দিনের জন্য।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmmmxxiv{''এইই আলবৎ আমাদের দেওয়া রিযেক, এর কোনো নিঃশেষ নেই।’’\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmmmxxv{এটিই! আর নিঃসন্দেহ সীমালংঘনকারীদের জন্য তো রয়েছে নিকৃষ্ট গন্তব্যস্থল, --\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mmmmxxvi{জাহান্নাম, তারা তাতে প্রবেশ করবে, সুতরাং কত মন্দ সেই বিশ্রামস্থান!\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mmmmxxvii{এই-ই! অতএব তারা এটি আস্বাদন করুক -- ফুটন্ত-গরম ও হিমশীতল, --\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mmmmxxviii{আর অন্যান্য রয়েছে এই ধরনের -- জোড়ায়-জোড়ায়।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mmmmxxix{''এই এক বাহিনী -- তোমাদের সঙ্গে দিগ্বিদিগ্‌জ্ঞানশূন্য হয়ে ছুটছে, তাদের জন্য কোনো অভিনন্দন নেই? তারা নিশ্চয়ই আগুনে পুড়বে।’’\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mmmmxxx{তারা বলবে -- ''বরং তোমরা, তোমাদের জন্যও তো কোনো অভিনন্দন নেই! তোমরাই স্বয়ং আমাদের জন্য এটি আগবাড়িয়েছ, সুতরাং কত নিকৃষ্ট এ আবাসস্থল!’’\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mmmmxxxi{তারা বলবে -- ''আমাদের প্রভু! যে-ই আমাদের জন্য এটি আগবাড়িয়েছে, তাকে তবে শাস্তি বাড়িয়ে দাও -- আগুনের মধ্যে দ্বিগুণ।’’\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mmmmxxxii{আর তারা বলবে -- ''আমাদের কি হলো, আমরা সেই লোকদের দেখছি না যাদের আমরা দুষ্টদের অন্তর্ভুক্ত বলে গণনা করতাম?\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mmmmxxxiii{''আমরা কি তাদের হাসিতামাশার পাত্র ভাবতাম, না কি দৃষ্টি তাদের থেকে অপারগ হয়ে গেছে?’’\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mmmmxxxiv{এটিই তো আলবৎ সত্য, আগুনের বাসিন্দাদের বাদপ্রতিবাদ।\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mmmmxxxv{তুমি বলো -- ''আমি তো একজন সতর্ককারী মাত্র, আর আল্লাহ্ ব্যতীত অন্য কোনো উপাস্য নেই -- একক, সর্বজয়ী, --\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mmmmxxxvi{''মহাকাশমন্ডলী ও পৃথিবীর এবং এ দুইয়ের মধ্যে যা-কিছু আছে তার প্রভু -- মহাশক্তিশালী, পরিত্রাণকারী।’’\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mmmmxxxvii{বলো -- ''এ এক বিরাট সংবাদ, --\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mmmmxxxviii{''এ থেকে তোমরা বিমুখ হচ্ছ।\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mmmmxxxix{''ঊর্ধ্বলোকের প্রধানদের সন্বন্ধে আমার কোন জ্ঞান নেই যখন তারা বাদানুবাদ করে।\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mmmmxl{''আমার কাছে প্রত্যাদিষ্ট হয়েছে এটি বৈ তো নয় যে, আমি তো একজন স্পষ্ট সতর্ককারী মাত্র।’’\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@mmmmxli{স্মরণ করো! তোমার প্রভু ফিরিশ্‌তাদের বললেন -- ''আমি নিশ্চয়ই কাদা থেকে মানুষ সৃষ্টি করতে যাচ্ছি।\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@mmmmxlii{''তারপর আমি যখন তাকে সুঠাম করব এবং আমার রূহ্ থেকে তাতে দম দেব তখন তার প্রতি সিজদাবনত হয়ে লুটিয়ে পড়ো।’’\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@mmmmxliii{তখন ফিরিশ্‌তারা সিজদা করল, তাদের সবাই একই সঙ্গে, --\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@mmmmxliv{ইবলিস ব্যতীত। সে অহংকার করল, আর সে ছিল অবিশ্বাসীদের অন্তর্গত।\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@mmmmxlv{তিনি বললেন -- ''হে ইবলিস, কী তোমাকে নিষেধ করলে তাকে সিজদা করতে, যাকে আমি আমার দুই হাতে সৃষ্টি করেছি? তুমি কি গর্ববোধ করলে, না কি তুমি উচ্চমর্যাদাসম্পন্নদের একজন হয়ে গেছ?\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@mmmmxlvi{সে বললে -- ''আমি তার চেয়েও শ্রেষ্ঠ। আমাকে তুমি আগুন থেকে সৃষ্টি করেছ, আর তাকে সৃষ্টি করেছ কাদা থেকে।”\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@mmmmxlvii{তিনি বললেন -- ''তবে এখান থেকে তুমি বেরিয়ে যাও, কেননা তুমি অবশ্যই বিতাড়িত,\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@mmmmxlviii{''আর নিঃসন্দেহ তোমার উপরে তো আমার অসন্তষ্টি রইবে মহাবিচারের দিন পর্যন্ত।’’\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@mmmmxlix{সে বললে -- ''আমার প্রভু! তবে আমাকে অবকাশ দাও তাদের পুনরুত্থান করানোর দিন পর্যন্ত।’’\qt@no{(79)}}
\qt@newcmd\qurantrans@bn@mmmml{তিনি বললেন -- ''তুমি তাহলে নিশ্চয়ই অবকাশপ্রাপ্তদের অন্তর্ভুক্ত --\qt@no{(80)}}
\qt@newcmd\qurantrans@bn@mmmmli{''সেই জানিয়ে দেওয়া সময়টির দিন পর্যন্ত।’’\qt@no{(81)}}
\qt@newcmd\qurantrans@bn@mmmmlii{সে বললে -- ''তবে তোমার মহিমা দ্বারা, আমি আলবৎ তাদের সবক’জনকে বিপথে নিয়ে যাব,\qt@no{(82)}}
\qt@newcmd\qurantrans@bn@mmmmliii{''কেবলমাত্র তাদের মধ্যের তোমার খাঁটি বান্দাদের ব্যতীত।’’\qt@no{(83)}}
\qt@newcmd\qurantrans@bn@mmmmliv{তিনি বললেন -- ''তবে এটাই সত্য, আর সত্যই আমি বলছি,\qt@no{(84)}}
\qt@newcmd\qurantrans@bn@mmmmlv{''আমি অবশ্যই জাহান্নামকে পূর্ণ করব তোমাকে দিয়ে ও তাদের মধ্যের যারা তোমাকে অনুসরণ করে তাদের সব ক’জনকে দিয়ে।’’\qt@no{(85)}}
\qt@newcmd\qurantrans@bn@mmmmlvi{তুমি বল -- ''আমি তোমাদের কাছ থেকে এর জন্য কোনো পারিশ্রমিক চাইছি না, আর আমি প্রবঞ্চকদেরও মধ্যেকার নই।\qt@no{(86)}}
\qt@newcmd\qurantrans@bn@mmmmlvii{''এটি জগদ্বাসীদের জন্য স্মরণীয় বার্তা বৈ তো নয়।\qt@no{(87)}}
\qt@newcmd\qurantrans@bn@mmmmlviii{''আর তোমরা অবশ্যই এর বৃত্তান্ত সন্বন্ধে কিছুকাল পরেই জানতে পারবে।’’\qt@no{(88)}}
\qt@newcmd\qurantrans@bn@mmmmlix{\basmalahbn এ গ্রন্থের অবতারণ আল্লাহ্‌র কাছে থেকে, মহাশক্তিশালী, পরমজ্ঞানী।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmlx{নিঃসন্দেহ আমরা তোমার কাছে গ্রন্থখানা অবতারণ করেছি সত্যের সাথে, কাজেই আল্লাহ্‌র এবাদত করো তাঁর প্রতি ধর্মে বিশুদ্ধচিত্ত হয়ে।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmlxi{খাঁটি ধর্ম কি আল্লাহ্‌রই জন্য নয়? আর যারা তাঁকে বাদ দিয়ে অন্যকে অভিভাবকরূপে গ্রহণ করে -- ''আমরা তাদের উপাসনা করি না শুধু এজন্য ছাড়া যে তারা আমাদের আল্লাহ্‌র নিকটবর্তী অবস্থায় এনে দেবে।’’ নিঃসন্দেহ আল্লাহ্ তাদের মধ্যে বিচার করবেন সেই বিষয়ে যাতে তারা মতভেদ করছিল। নিঃসন্দেহ আল্লাহ্ তাকে সৎপথে পরিচালিত করেন না যে খোদ মিথ্যাবাদী অবিশ্বাসী।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmlxii{আল্লাহ্ যদি কোনো সন্তান গ্রহণ করতে চাইতেন তাহলে তিনি যাদের সৃষ্টি করেছেন তাদের থেকে যাকে তিনি ইচ্ছা করেন তাকেই তো তিনি পছন্দ করতে পারতেন। সকল মহিমা তাঁরই। তিনিই আল্লাহ্‌, -- একক, সর্ববিজয়ী।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmlxiii{তিনিই মহাকাশমন্ডলী ও পৃথিবী সৃষ্টি করেছেন সত্যের সাথে। তিনি রাতকে দিয়ে দিনের উপরে ছাউনি বানান আর দিনকে ছাউনি বানান রাতের উপরে, এবং সূর্য ও চন্দ্রকে তিনি বশীভূত করেছেন, -- প্রত্যেকেই নির্ধারিত গতিপথে ধাবিত হচ্ছে। তিনিই কি মহাশক্তিশালী পরম ক্ষমাশীল নন?\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmlxiv{তিনি তোমাদের সৃষ্টি করেছেন একই সত্ত্বা থেকে, তারপর তা থেকে তিনি বানিয়েছেন তার সঙ্গিনী। আর তিনি তোমাদের জন্য পাঠিয়েছেন গবাদি-পশুর মধ্যে আটটি জোড়ায় জোড়ায়। তিনি তোমাদের সৃষ্টি করেছেন তোমাদের মায়েদের পেট থেকে -- এক সৃষ্টির পরে অন্য সৃষ্টির মাধ্যমে, -- তিন স্তর অন্ধকারে। ইনিই হচ্ছেন আল্লাহ্‌, তোমাদের প্রভু, তাঁরই হচ্ছে সার্বভৌমত্ব তিনি ব্যতীত কোনো উপাস্য নেই, সুতরাং কোথা থেকে তোমরা ফিরে যাচ্ছ?\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmlxv{তোমরা যদি অকৃতজ্ঞতা দেখাও, তবে আল্লাহ্ নিশ্চয়ই তোমাদের সম্পর্কে অনন্যনির্ভর। কিন্তু তিনি তাঁর বান্দাদের জন্য অকৃতজ্ঞতা পছন্দ করেন না। আর যদি তোমরা কৃতজ্ঞতা প্রকাশ কর তবে তাতে তিনি তোমাদের প্রতি প্রসন্ন হবেন। আর কোনো ভারবাহী অন্যের বোঝা বহন করবে না। তারপর তোমাদের প্রভুর নিকটেই তোমাদের প্রত্যাবর্তন, তখন তিনি তোমাদের জানিয়ে দেবেন যা তোমরা করে যাচ্ছিলে। নিঃসন্দেহ বুকের ভেতরে যা আছে সে-সন্বন্ধে তিনি সম্যক অবগত।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmlxvi{আর যখন মানুষকে দুঃখকষ্ট স্পর্শ করে সে তখন তার প্রভুকে ডাকে তাঁর প্রতি নিষ্ঠাবান হয়ে, তারপর যখন তিনি তাকে তাঁর থেকে অনুগ্রহ প্রদান করেন, সে তখন ভুলে যায় যার জন্য সে ইতিপূর্বে তাঁকে ডেকেছিল, আর সে আল্লাহ্‌র সঙ্গে প্রতিদ্বন্দ্বী দাঁড় করায় যেন সে তাঁর পথ থেকে পথভ্রষ্ট করতে পারে। বলো -- ''তোমার অকৃতজ্ঞতার মাঝে কিছুকাল সুখভোগ করে নাও, তুমি তো আগুনের বাসিন্দাদের দলভুক্ত।’’\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmlxvii{সে কি যে রাতের প্রহরগুলোতে সিজদাবনত হয়ে ও দাঁড়িয়ে আনুগত্য করে, পরকাল সন্বন্ধে সাবধানতা অবলন্বন করে এবং তার প্রভুর অনুগ্রহ কামনা করে? বলো -- ''যারা জানে আর যারা জানে না তারা কি একসমান? নিঃসন্দেহ বোধশক্তিসম্পন্ন লোকেরাই শুধু মনোযোগ দেয়।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmlxviii{তুমি বলে দাও -- ''হে আমার বান্দারা যারা ঈমান এনেছ! তোমাদের প্রভুকে ভয়ভক্তি করো। যারা এই দুনিয়াতে ভালো কাজ করে তাদের জন্য ভাল রয়েছে। আর আল্লাহ্‌র পৃথিবী সুপ্রসারিত। নিঃসন্দেহ অধ্যবসায়ীদের তাদের পারিশ্রমিক দেওয়া হবে হিসাবপত্র ব্যতিরেকে।’’\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmlxix{বলো -- ''নিঃসন্দেহ আমাকে আদেশ করা হয়েছে আমি যেন আল্লাহ্‌র উপাসনা করি তাঁর প্রতি ধর্মকে পূতপবিত্র করে,\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmlxx{''আর আমাকে আদেশ করা হয়েছে যেন আমি আ‌ত্ম-সমর্পণকারীদের অগ্রণী হতে পারি।’’\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmlxxi{তুমি বলো -- ''আমি আলবৎ ভয় করি, যদি আমি আমার প্রভুর অবাধ্যাচরণ করি তবে এক কঠিন দিনের শাস্তি।’’\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmlxxii{বলো -- ''আমি আল্লাহ্‌রই আরাধনা করি তাঁর প্রতি আমার ধর্ম বিশুদ্ধ করে।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmlxxiii{''অতএব তাঁকে বাদ দিয়ে তোমরা যাকে ইচ্ছা কর, তার উপাসনা কর।’’ বলো -- ''নিঃসন্দেহ ক্ষতিগ্রস্ত তারা যারা কিয়ামতের দিনে ক্ষতিসাধন করেছে তাদের নিজেদের ও তাদের পরিজনদের। এটিই কি খোদ স্পষ্ট ক্ষতি নয়?”\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmlxxiv{তাদের জন্য তাদের উপর থেকে থাকবে আগুনের আচ্ছাদনী আর তাদের নীচে থেকে থাকবে এক আবরণী। এইভাবে আল্লাহ্ তাঁর বান্দাদের এর দ্বারা ভয় দেখান, অতএব আমাকে ভয়ভক্তি করো, হে আমার বান্দারা!\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmlxxv{আর যারা তাগুতকে এড়িয়ে চলে তাদের পূজাঅর্চনা থেকে, আর আল্লাহ্‌র দিকে অনুগত হয় তাদেরই জন্য রয়েছে সুসংবাদ, সেজন্য সুসংবাদ দাও আমার বান্দাদের --\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmlxxvi{যারা বক্তব্য শোনে এবং তার ভালগুলোর অনুসরণ করে -- এরাই তারা যাদের আল্লাহ্ সৎপথে পরিচালিত করেছেন, আর এরাই স্বয়ং বোধশক্তিসম্পন্ন।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmlxxvii{তবে কি যার উপরে শাস্তির রায় সাব্যস্ত হয়েছে? তুমি কি তবে তাকে উদ্ধার করতে পার যে আগুনের মধ্যে রয়েছে?\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmlxxviii{পক্ষান্তরে যারা তাদের প্রভুকে ভয়-ভক্তি করে তাদের জন্য রয়েছে উঁচু আবাসস্থল, তাদের উপরে উঁচু আবাসস্থল সুপ্রতিষ্ঠিত, তাদের নীচ দিয়ে বয়ে চলেছে ঝরনারাজি। আল্লাহ্‌র ওয়াদা, আল্লাহ্ ওয়াদার খেলাপ করেন না।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmlxxix{তুমি কি দেখ না যে আল্লাহ্ আকাশ থেকে পানি বর্ষণ করেন, তারপর তাকে মাটিতে স্রোতরূপে প্রবাহিত করেন, তারপর তার দ্বারা তিনি উৎপাদন করেন গাছপালা যাদের বর্ণ বিবিধ ধরনের, তারপর তা শুকিয়ে যায়, ফলে তুমি তাকে হলদে হয়ে যেতে দেখতে পাও, তারপর তিনি তাকে খড় কুটো বানিয়ে ফেলেন। নিঃসন্দেহ এতে তো উপদেশ রয়েছে বোধশক্তি-সম্পন্নদের জন্য।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmlxxx{যার বুক আল্লাহ্ ইসলামের প্রতি প্রশস্ত করেছেন, ফলে সে তার প্রভুর কাছ থেকে এক আলোকে রয়েছে, সে কি --? সুতরাং ধিক্ তাদের জন্য যাদের হৃদয় আল্লাহ্‌র স্মরণে সুকঠিন! এরাই রয়েছে স্পষ্ট বিভ্রান্তিতে।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmlxxxi{আল্লাহ্ অবতারণ করেছেন শ্রেষ্ঠ বিবৃতি -- একখানা গ্রন্থ, সুবিন্যস্ত, পুনরাবৃত্তিময়, এতে যারা তাদের প্রভুকে ভয় করে তাদের চামড়া শিউরে ওঠে, তারপর তাদের ছাল ও তাদের দিল নরম হয় আল্লাহ্‌র স্মরণে। এটিই আল্লাহ্‌র পথ-নির্দেশ, এর দ্বারা তিনি পথ দেখিয়ে থাকেন যাকে তিনি ইচ্ছা করেন। যাকে আল্লাহ্ পথভ্রষ্ট হতে দেন, তার জন্য তবে হেদায়তকারীদের কেউ নেই।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmlxxxii{যে তার মুখ দিয়ে ঠেকাতে চাইবে কিয়ামতের দিনের কঠোর শাস্তি সে কি --? আর অন্যায়কারীদের বলা হবে -- ''তোমরা যা অর্জন করেছিলে তা আস্বাদন করো।’’\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmlxxxiii{তাদের পূর্বে যারা ছিল তারাও প্রত্যাখ্যান করেছিল, সেজন্য শাস্তি তাদের কাছে এসে পড়েছিল এমন দিক থেকে যা তারা বুঝতে পারে নি।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmlxxxiv{ফলে আল্লাহ্ তাদের এই দুনিয়ার জীবনেই লাঞ্ছনা আস্বাদ করিয়েছিলেন, আর পরকালের শাস্তি তো আরো বিরাট। তারা যদি জানতো!\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmlxxxv{আর আমরা অবশ্যই এই কুরআনে মানুষের জন্য হরেক রকমের দৃষ্টান্ত ছোঁড়ে মেরেছি, যেন তারা উপদেশ গ্রহণ করতে পারে, --\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmlxxxvi{আরবী কুরআন, কোনো জটিলতা বিহীন, যেন তারা ধর্মভীরুতা অবলন্বন করতে পারে।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmlxxxvii{আল্লাহ্ একটি দৃষ্টান্ত ছোড়ে মারছেন -- একজন লোক, তার সঙ্গে রয়েছে অনেক অংশী-দেবতা, পরস্পরের সঙ্গে বিবাদ-রত, আর একজন লোক, একজনের সঙ্গেই অনুরক্ত। এদের দু’জন কি অবস্থার ক্ষেত্রে একসমান? সমস্ত প্রশংসা আল্লাহ্‌র, কিন্তু তাদের অনেকেই জানে না।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmlxxxviii{তুমি তো নিশ্চয় মৃত্যুবরণ করবে, আর তারাও নিশ্চয়ই মৃত্যুমুখে পড়বে।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmlxxxix{তারপর কিয়ামতের দিনে নিশ্চয়ই তোমাদের প্রভুর সামনে তোমরা একেঅন্যে বাকবিতন্ডা করবে।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmmxc{তবে তার চাইতে কে বেশী অন্যায়কারী যে আল্লাহ্‌র বিরুদ্ধে মিথ্যা কথা বলে এবং সত্য প্রত্যাখ্যান করে যখন তা তার কাছে আসে? জাহান্নামে কি অবিশ্বাসীদের জন্য একটি আবাসস্থল নেই?\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmmxci{আর যারা সত্য নিয়ে এসেছে ও একে সত্য বলে স্বীকার করেছে এরাই খোদ মুত্তাকী।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmmxcii{তাদের জন্য তাদের প্রভুর কাছে রয়েছে তারা যা চায় তাই। এটিই হচ্ছে সৎকর্মীদের পুরস্কার, --\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmmxciii{কাজেই তারা যা করেছিল তার মন্দতম আল্লাহ্ তাদের থেকে মুছে দেবেন, আর তারা যা করে চলেছে তার জন্য তিনি তাদের পারিশ্রমিক শ্রেষ্ঠতমভাবে তাদের প্রদান করবেন।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmmxciv{আল্লাহ্ কি তাঁর বান্দাদের জন্য যথেষ্ট নন? তথাপি তারা তোমাকে ভয় দেখাতে চায় তাঁকে বাদ দিয়ে অন্যদের দ্বারা। আর যাকে আল্লাহ্ পথভ্রষ্ট হতে দেন তার জন্য তবে হেদায়তকারী কেউ নেই।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmmxcv{আর আল্লাহ্ যাকে পথ দেখান তার জন্য তবে পথভ্রষ্টকারী কেউ নেই। আল্লাহ্ কি মহাশক্তিশালী, শেষ-পরিণতির অধিকর্তা নন?\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmmxcvi{আর তুমি যদি তাদের জিজ্ঞেস কর 'কে মহাকাশমন্ডলী ও পৃথিবী সৃষ্টি করেছেন,’ তারা নিশ্চয়ই বলবে 'আল্লাহ্‌’। তুমি বলো -- ''তোমরা কি তবে ভেবে দেখেছ -- তোমরা আল্লাহ্‌কে বাদ দিয়ে যাদের উপাসনা করছ, যদি আল্লাহ্ আমার জন্য দুঃখকষ্ট চেয়ে থাকেন তবে কি তারা তাঁর কষ্ট দূর করতে পারবে, অথবা তিনি যদি আমার জন্য করুণা চেয়ে থাকেন তবে কি তারা তাঁর অনুগ্রহকে রোধ করতে পারবে? বলো -- ''আল্লাহ্‌ই আমার জন্য যথেষ্ট। তাঁরই উপরে নির্ভর করুক নির্ভরশীল সব।’’\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmmxcvii{বলো -- ''হে আমার লোকদল! তোমাদের স্থানে কাজ করে যাও, আমিও নিঃসন্দেহ কাজ করে যাচ্ছি। সুতরাং শীঘ্রই তোমরা জানতে পারবে --\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmmxcviii{''কে সে যার কাছে আসছে শাস্তি যা তাকে লাঞ্ছিত করবে, আর কার উপরে বিধেয় হয়েছে স্থায়ী শাস্তি।’’\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmmxcix{নিঃসন্দেহ আমরা তোমার কাছে গ্রন্থখানা অবতারণ করেছি মানবজাতির জন্য সত্যের সাথে, সুতরাং যে-কেউ সৎপথ অবলন্বন করে সে তো তবে তার নিজের জন্যে, এবং যে কেউ ভ্রান্ত পথে চলে, সে তো বিভ্রান্ত হয় তার নিজেরই বিরুদ্ধে। আর তুমি তো তাদের উপরে কর্ণধার নও।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmmc{আল্লাহ্ আ‌ত্মাগুলো গ্রহণ করেন তাদের মৃত্যুর সময়ে, আর যারা মরে না তাদের ঘুমের মধ্যে, তারপর তিনি রেখে দেন তাদের ক্ষেত্রে যাদের উপরে মৃত্যু অবধারিত করেছেন, আর অন্যগুলো ফেরত পাঠান একটি নির্ধারিত কাল পর্যন্ত। নিঃসন্দেহ এতে তো নিদর্শনাবলী রয়েছে সেই লোকদের জন্য যারা চিন্তা করে।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmmci{অথবা তারা কি আল্লাহ্‌কে বাদ দিয়ে সুপারিশকারীদের ধরেছে? তুমি বলো -- ''কি! যদিও তারা হচ্ছে এমন যে তারা কোনো- কিছুতেই কোনো ক্ষমতা রাখে না আর কোনো জ্ঞানবুদ্ধিও রাখে না?’’\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmmcii{বলো -- ''সুপারিশ সর্বতোভাবে আল্লাহ্‌রই জন্যে। মহাকাশমন্ডলী ও পৃথিবীর সার্বভৌমত্ব তাঁরই, তারপর তাঁরই কাছে তোমাদের ফিরিয়ে আনা হবে।’’\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmmciii{আর যখন আল্লাহ্‌র, তাঁর একত্বের উল্লেখ করা হয় তখন, যারা পরকালে বিশ্বাস করে না তাদের হৃদয় সংকূচিত হয়, পক্ষান্তরে যখন তাঁকে বাদ দিয়ে অন্য যারা রয়েছে, তাদের উল্লেখ করা হয় তখন দেখো! তারা উল্লাস করে।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmmmciv{তুমি বলো -- ''হে আল্লাহ্‌! মহাকাশমন্ডলী ও পৃথিবীর আদি-স্রষ্টা! অদৃশ্য ও প্রকাশ্যের পরিজ্ঞাতা! তোমার বান্দাদের মধ্যে তুমি বিচার করে দাও সেই বিষয়ে যাতে তারা মতবিরোধ করছিল।’’\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmmmcv{আর যারা অন্যায়াচরণ করছিল তাদের জন্য যদি পৃথিবীতে যা আছে সে-সবটাই থাকত এবং তার সঙ্গে এর সমান আরও, তারা এর দ্বারা পরিত্রাণ পেতে চাইত কিয়ামতের দিনের শাস্তির ভীষণতা থেকে। আর আল্লাহ্‌র কাছ থেকে এমন তাদের সামনে পরিস্ফুট হবে যা তারা কখনো হিসেব করে দেখে নি।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmmmcvi{আর তারা যা অর্জন করেছিল তার মন্দ তাদের কাছে প্রকাশ হয়ে পড়বে, আর যা নিয়ে তারা বিদ্রূপ করত তা তাদের ঘিরে ফেলবে।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmmmcvii{কিন্তু যখন কোনো দুঃখকষ্ট মানুষকে স্পর্শ করে তখন সে আমাদের ডাকে, তারপর যখন আমরা তাকে আমাদের থেকে অনুগ্রহ প্রদান করি, সে বলে -- ''আমাকে তো এ দেওয়া হয়েছে জ্ঞানের দরুন।’’ বস্তুতঃ এ এক পরীক্ষা, কিন্তু তাদের অধিকাংশই জানে না।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmmmcviii{তাদের আগে যারা ছিল তারাও এটাই বলে থাকত, কিন্তু তারা যা অর্জন করেছিল তা তাদের কোনো কাজে আসে নি।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmmmcix{কাজেই তারা যা অর্জন করেছিল তার মন্দ তাদের পাকড়াও করল। আর এদের মধ্যে যারা অন্যায়াচরণ করছে তাদের উপরেও তারা যা অর্জন করেছে তার মন্দ অচিরেই আপতিত হবে, আর তারা এড়িয়ে যাবার পাত্র নয়।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmmmcx{তারা কি জানে না যে আল্লাহ্ রিযেক বাড়িয়ে দেন যার জন্য তিনি ইচ্ছা করেন এবং মেপে-জোখেও দেন। নিশ্চয় এতে তো নিদর্শনাবলী রয়েছে ঈমান আনে এমন লোকদের জন্য।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmmmcxi{তুমি বলে দাও -- ''হে আমার বান্দারা যারা নিজেদের বিরুদ্ধে অমিতাচার করেছ! তোমরা আল্লাহ্‌র করুণা হতে নিরাশ হয়ো না। নিঃসন্দেহ আল্লাহ্ সমুদয় পাপ ক্ষমা করেও দেন। নিঃসন্দেহ তিনি নিজেই পরিত্রাণকারী, অফুরন্ত ফলদাতা।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmmmcxii{''আর তোমাদের প্রভুর দিকে ফেরো এবং তোমাদের উপরে শাস্তি আসার আগেভাগে তাঁর প্রতি পূর্ণ আ‌ত্মসমর্পণ করো, তখন আর তোমাদের সাহায্য করা হবে না।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmmmcxiii{''আর তোমাদের প্রভুর কাছ থেকে তোমাদের নিকট যা শ্রেষ্ঠ অবতীর্ণ হয়েছে তার অনুসরণ করো তোমাদের উপরে অতর্কিতভাবে শাস্তি এসে পড়ার আগেই, যখন তোমরা খেয়াল করছ না --\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mmmmcxiv{''পাছে কোনো সত্ত্বাকে বলতে হয় -- 'হায় আফসোস আমার জন্য যে আল্লাহ্‌র প্রতি কর্তব্যে আমি অবহেলা করছিলাম! আর আমি তো ছিলাম বিদ্রূপকারীদের দলের’,\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mmmmcxv{'অথবা তাকে বলতে হয় -- - 'আল্লাহ্ যদি আমাকে সৎপথ দেখাতেন তাহলে আমি নিশ্চয়ই ধর্মভীরুদের মধ্যেকার হতাম’,\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mmmmcxvi{''অথবা বলতে হয় যখন সে শাস্তি প্রত্যক্ষ করে -- 'যদি আমার জন্য আরেকটা সুযোগ হতো তাহলে আমি সৎকর্মশীলদের অন্তর্ভুক্ত হতাম’।’’\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mmmmcxvii{''না, তোমার কাছে তো আমার বাণীসমূহ এসেই ছিল, কিন্তু তুমি সে-সব প্রত্যাখ্যান করেছিলে আর তুমি হামবড়াই করেছিলে, আর তুমি হয়েছিলে অবিশ্বাসীদের একজন।’’\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mmmmcxviii{আর কিয়ামতের দিনে তুমি দেখতে পাবে তাদের যারা আল্লাহ্‌কে প্রত্যাখ্যান করেছিল, তাদের মুখমন্ডল কালিমাচ্ছন্ন। জাহান্নামে কি গর্বিতদের জন্য আবাসস্থল নেই?\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mmmmcxix{আর যারা ধর্মভীরুতা অবলন্বন করে তাদের আল্লাহ্ উদ্ধার করবেন তাদের সাফল্যময় স্থানসমূহে, মন্দ তাদের স্পর্শ করবে না, আর তারা দুঃখও করবে না।\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mmmmcxx{আল্লাহ্ সব-কিছুর স্রষ্টা, আর তিনি সব-কিছুর উপরে কর্ণধার।\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mmmmcxxi{মহাকাশমন্ডলী ও পৃথিবীর চাবিকাঠি তাঁরই নিকট। আর যারা আল্লাহ্‌র নির্দেশসমূহে অবিশ্বাস করে তারাই স্বয়ং ক্ষতিগ্রস্ত।\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mmmmcxxii{তুমি বলো -- ''তবে কি তোমরা আমাকে আদেশ করছ যে আমি আল্লাহ্ ছাড়া অন্যের উপাসনা করি, ওহে মূর্খজনেরা!’’\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mmmmcxxiii{আর তোমার কাছে ও তোমার আগে যারা ছিলেন তাঁদের কাছে নিশ্চয়ই ইতিপূর্বে প্রত্যাদিষ্ট হয়েছে -- ''যদি তুমি শরিক কর তাহলে তোমার কাজকর্ম নিশ্চয়ই নিষ্ফল হয়ে যাবে এবং তুমি নিশ্চয়ই হয়ে যাবে ক্ষতিগ্রস্তদের মধ্যেকার।’’\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mmmmcxxiv{না, তুমি সতত আল্লাহ্‌রই উপাসনা করবে, আর কৃতজ্ঞদের অন্তর্ভুক্ত রইবে।\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mmmmcxxv{আর তারা আল্লাহ্‌কে সম্মান করে না তাঁর যথোচিত সম্মানের দ্বারা, অথচ সমস্ত পৃথিবীটাই তাঁর মুঠোয় থাকবে কিয়ামতের দিনে, আর মহাকাশমন্ডলীটা গুটিয়ে নেয়া হবে তাঁর ডান হাতে। সকল মহিমা তাঁরই আর তারা যেসব অংশী দাঁড় করায় তা থেকে তিনি বহু ঊর্ধ্বে।\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mmmmcxxvi{আর শিঙায় ফুঁকা হবে, ফলে মহাকাশমন্ডলীতে যারা আছে ও পৃথিবীতে যারা রয়েছে তারা মূর্চ্ছা যাবে -- তারা ব্যতীত যাদের সন্বন্ধে আল্লাহ্ ইচ্ছা করেন। তারপর তাতে পুনরায় ফুৎকার দেওয়া হবে, তখন দেখো! তারা উঠে দাঁড়াবে বিস্ফরিত নয়নে।\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mmmmcxxvii{আর পৃথিবী উদ্ভাসিত হবে তার প্রভুর জ্যোতিতে, আর গ্রন্থ উপস্থাপিত করা হবে, আর নবীগণকে ও সাক্ষীগণকে নিয়ে আসা হবে, আর তাদের মধ্যে বিচার-মীমাংসা করা হবে সততার সঙ্গে, আর তাদের প্রতি অন্যায় করা হবে না।\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mmmmcxxviii{আর প্রত্যেক সত্ত্বাকে সে যা করেছে তার পূর্ণ প্রতিদান দেওয়া হবে, আর তিনি ভাল জানেন তারা যা করে সে-সম্পর্কে।\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@mmmmcxxix{আর যারা অবিশ্বাস পোষণ করে তাদের জাহান্নামের দিকে তাড়িয়ে নিয়ে যাওয়া হবে দলবদ্ধভাবে। যেতে যেতে যখন তারা তার কাছে আসবে তখন এর দরজাগুলো খুলে দেওয়া হবে আর তার রক্ষকরা তাদের বলবে -- ''তোমাদের কাছে কি তোমাদের মধ্যে থেকে রসূলগণ আসেন নি যাঁরা তোমাদের কাছে বিবৃত করতেন তোমাদের প্রভুর বাণীসমূহ এবং তোমাদের সাবধান করে দিতেন তোমাদের এই দিনটির সাক্ষাৎ পাওয়া সন্বন্ধে?’’ তারা বলবে -- ''হ্যাঁ।’’ আর বস্তুতঃ অবিশ্বাসীদের উপর শাস্তিদানের রায় বাস্তবায়িত হয়েছে।\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@mmmmcxxx{বলা হবে -- ''তোমরা জাহান্নামের দরজাগুলো দিয়ে ঢুকে পড় সেখানে দীর্ঘকাল অবস্থানের জন্য। সুতরাং কত মন্দ গর্বিতদের এই অবস্থানস্থল!’’\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@mmmmcxxxi{আর যারা তাদের প্রভুকে ভয়ভক্তি করে তাদের নিয়ে যাওয়া হবে দলবদ্ধভাবে জান্নাতের দিকে। যেতে যেতে যখন তারা তার কাছে আসবে ও এর দরজাগুলো খুলে দেওয়া হবে তখন তার রক্ষীরা তাদের বলবে, ''সালাম তোমাদের উপরে! তোমরা পবিত্র-চরিত্র, সুতরাং তোমরা এতে চিরস্থায়ীভাবে প্রবেশ করো।’’\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@mmmmcxxxii{আর তারা বলবে -- ''সকল প্রশংসা আল্লাহ্‌র যিনি তাঁর ওয়াদা আমাদের কাছে পরিপূর্ণ করেছেন, আর তিনি পৃথিবীটা আমাদের উত্তরাধিকার করতে দিয়েছেন, আমরা এই জান্নাতে বসবাস করব যেখানে আমরা চাইব।’’ সুতরাং কর্মীদের এই পারিশ্রমিক কত উত্তম!\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@mmmmcxxxiii{আর তুমি দেখতে পাবে যে ফিরিশ্‌তারা আরশের চতুর্দিক ঘিরে রয়েছে, তাদের প্রভুর প্রশংসায় জপতপ করে চলেছে, আর তাদের মধ্যে বিচার-মীমাংসা করা হবে সততার সাথে, আর বলা হবে -- ''সকল প্রশংসা আল্লাহ্‌রই জন্য যিনি বিশ্বজগতের প্রভু।’’\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@mmmmcxxxiv{\basmalahbn হা, মীম!\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmcxxxv{এই গ্রন্থের অবতারণ মহাশক্তিশালী, সর্বজ্ঞাতা আল্লাহ্‌র কাছ থেকে,\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmcxxxvi{পাপ থেকে পরিত্রাণকারী ও তওবা কবুলকারী, প্রতিফলদানে কঠোর, উদারতার অধীশ্বর। তিনি ছাড়া অন্য উপাস্য নেই, তাঁরই কাছে শেষ-আগমন।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmcxxxvii{আল্লাহ্‌র নির্দেশাবলী সন্বন্ধে কেউ বচসা করে না, কেবল তারা ছাড়া যারা অবিশ্বাস করে, সুতরাং শহরে-নগরে তাদের চলাফেরা যেন তোমাকে প্রতারিত না করে।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmcxxxviii{এদের আগে নূহের স্বজাতি প্রত্যাখ্যান করেছিল, আর তাদের পরের অন্যান্য দলও, আর প্রত্যেক সম্প্রদায়ই তাদের রসূল সন্বন্ধে মতলব করেছিল তাঁকে ধরে আনতে, আর তারা তর্কাতর্কি করত মিথ্যার সাহায্যে যেন তার দ্বারা তারা সত্যকে পঙ্গু করে ফেলতে পারে, ফলে আমি তাদের পাকড়াও করলাম, সুতরাং কেমন ছিল আমার শাস্তিদান!\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmcxxxix{আর এভাবেই তোমার প্রভুর বাণী সত্য প্রমাণিত হয়েছিল তাদের বিরুদ্ধে যারা অবিশ্বাস করেছিল -- যে তারাই হচ্ছে আগুনের বাসিন্দা।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmcxl{যারা আরশ বহন করে আর যারা এর চারপাশে রয়েছে তারা তাদের প্রভুর প্রশংসায় জপতপ করছে আর তাঁর প্রতি বিশ্বাস করছে, আর পরিত্রাণ প্রার্থনা করছে তাদের জন্য যারা বিশ্বাস করেছে -- ''আমাদের প্রভু! তুমি সব-কিছুকে পরিবেষ্টন করে রয়েছ করুণার ও জ্ঞানের দ্বারা, কাজেই তুমি পরিত্রাণ করো তাদের যারা ফিরেছে ও তোমার পথ অনুসরণ করেছে, আর তাদের রক্ষা করো জ্বলন্ত আগুনের শাস্তি থেকে।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmcxli{''আমাদের প্রভু! আর তাদের প্রবেশ করাও নন্দন-কাননে যা তুমি ওয়াদা করেছিলে তাদের জন্য, আর যারা সৎকর্ম করেছে -- তাদের বাপদাদাদের ও তাদের পতি-পত্নীদের ও তাদের সন্তান-সন্ততিদের মধ্যে থেকে। নিঃসন্দেহ তুমি নিজেই মহাশক্তিশালী, পরমজ্ঞানী।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmcxlii{''আর তাদের রক্ষা করো মন্দ থেকে। আর সেইদিন যাকে তুমি মন্দ থেকে রক্ষা করবে তাকে তো তুমি আলবৎ করুণা করেছ। আর এইটিই খোদ মহাসাফল্য।’’\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmcxliii{নিঃসন্দেহ যারা অবিশ্বাস পোষণ করে তাদের ঘোষণা করা হবে -- ''আল্লাহ্‌র বিরূপতা তোমাদের নিজেদের প্রতি তোমাদের বিরক্তির চেয়েও অনেক বেশী ছিল, কেননা ধর্মবিশ্বাসের প্রতি তোমাদের আহ্বান করা হচ্ছিল অথচ তোমরা প্রত্যাখ্যান করছিলে!’’\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmcxliv{তারা বলবে -- ''আমাদের প্রভু! তুমি দুইবার আমাদের মৃত্যুমুখে ফেলেছ, আর তুমি আমাদের দুইবার জীবন দান করেছ, কাজেই আমরা আমাদের অপরাধ স্বীকার করছি সুতরাং বেরুনোর কোনো পথ আছে কী?’’\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmcxlv{''এটিই তোমাদের, কেননা যখন আল্লাহ্‌কে তাঁর একত্ব সন্বন্ধে ঘোষণা করা হতো তখন তোমরা অবিশ্বাস করতে, আর যদি তাঁর সঙ্গে অংশী দাঁড় করানো হতো তাহলে তোমরা বিশ্বাস করতে। বস্তুতঃ হুকুম আল্লাহ্‌র -- মহোচ্চ, মহামহিম।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmcxlvi{তিনিই সেইজন যিনি তোমাদের তাঁর নিদর্শনাবলী দেখিয়ে থাকেন এবং তোমাদের জন্য আকাশ থেকে পাঠিয়ে থাকেন রিযেক। আর কেউ মনোনিবেশ করে না সে ব্যতীত যে ফেরে।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmcxlvii{সুতরাং আল্লাহ্‌কেই আহ্‌বান করো তাঁর প্রতি ধর্মে বিশুদ্ধচিত্ত হয়ে, যদিও অবিশ্বাসীরা বিরূপ হয়।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmcxlviii{তিনি স্তরে স্তরে উন্নয়ণকারী, আরশের অধিপতি। তিনি তাঁর আদেশক্রমে রূহ পাঠিয়ে থাকেন তাঁর বান্দাদের মধ্যের যার প্রতি তিনি ইচ্ছা করে থাকেন, যেন সে সতর্ক করতে পারে মহামিলনের দিন সম্পর্কে --\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmcxlix{যেদিন তারা বের হয়ে পড়বে, আল্লাহ্‌র সমক্ষে তাদের সন্বন্ধে কিছুই লুকোনো থাকবে না। ''আজকের দিনে কার রাজত্ব?’’ ''একক সার্বভৌম কর্তৃত্বশীল আল্লাহ্‌র।’’\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmcl{সেইদিন প্রত্যেক সত্ত্বাকে প্রতিদান দেওয়া হবে যা সে অর্জন করেছে তার দ্বারা। সেইদিন কোনো অবিচার হবে না। নিঃসন্দেহ আল্লাহ্ হিসাব গ্রহণে তৎপর।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmcli{আর তুমি তাদের সাবধান করে দাও আসন্ন দিন সম্পর্কে যখন হৃৎপিন্ডগুলো দুঃখকষ্টে কন্ঠাগত হবে। অন্যায়াচারীদের জন্য কোনো বন্ধু থাকবে না, আর থাকবে না কোনো সুপারিশকারী শুনবার মতো।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmclii{তিনি জানেন চোখগুলোর চুপিসারে চাওয়া আর যা বুকগুলো লুকিয়ে রাখে।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmcliii{আর আল্লাহ্ বিচার করেন সঠিকভাবে, কিন্ত তাঁকে বাদ দিয়ে যাদের তারা আহ্বান করে তারা কোনো কিছুরই সমাধান করতে পারে না। নিঃসন্দেহ আল্লাহ্ -- তিনিই সর্বশ্রোতা, সর্বদ্রষ্টা।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmcliv{এরা কি দুনিয়াতে পরিভ্রমণ করে নি, করলে দেখত কেমন হয়েছিল তাদের পরিণাম যারা ছিল এদের পূর্ববর্তী? তারা তো ছিল বলবিক্রমে এদের চেয়েও প্রবল আর দুনিয়াদারির কৃতিত্বেও, কিন্ত আল্লাহ্ তাদের পাকড়াও করলেন তাদের অপরাধের জন্য, আর তাদের জন্য আল্লাহ্‌র থেকে কোনো রক্ষাকারী নেই।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmclv{এমনটাই! কেন না তাদের ক্ষেত্রে -- তাদের রসূলগণ তাদের কাছে এসেছিলেন সুস্পষ্ট প্রমাণাবলী নিয়ে, কিন্ত তারা অবিশ্বাস করেছিল, কাজেই আল্লাহ্ তাদের পাকড়াও করলেন। নিঃসন্দেহ তিনি মহাশক্তিশালী, প্রতিফলদানে কঠোর।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmclvi{আর আমরা নিশ্চয়ই মূসাকে পাঠিয়েছিলাম আমাদের নির্দেশাবলী ও স্পষ্ট কর্তৃত্ত্ব দিয়ে,\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmclvii{ফিরআউন ও হামান ও ক্কারূনের কাছে, কিন্ত তারা বলল -- ''একজন জাদুকর, মিথ্যাবাদী।’’\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmclviii{তারপর যখন তিনি আমাদের তরফ থেকে সত্য নিয়ে তাদের কাছে এলেন তখন তারা বলল, ''তার সঙ্গে যারা বিশ্বাস করেছে তাদের ছেলেদের কোতল করো ও বাঁচতে দাও তাদের মেয়েদের।’’ বস্তুতঃ অবিশ্বাসীদের চক্তান্ত ব্যর্থ বৈ তো নয়।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmclix{আর ফিরআউন বলল -- ''আমাকে ছেড়ে দাও যাতে আমি মূসাকে বধ করতে পারি, আর সে তার প্রভুকে ডাকতে থাকুক, নিঃসন্দেহ আমি আশঙ্কা করছি যে সে তোমাদের ধর্মমত বদলে দেবে, অথবা সে দেশের মধ্যে বিপর্যয়ের প্রসার করবে।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmclx{আর মূসা বললেন -- ''আমি নিশ্চয়ই আমার প্রভুর ও তোমাদের প্রভুর আশ্রয় চাইছি প্রত্যেক অহংকারী থেকে যে হিসেব- নিকেশের দিনের প্রতি বিশ্বাস করে না।’’\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmclxi{আর ফিরআউনের লোকদের থেকে একজন বিশ্বাসী ব্যক্তি যে তার ঈমান লুকিয়ে রেখেছিল, বলল -- ''তোমরা কি একজন লোককে হত্যা করবে যেহেতু তিনি বলেন, 'আমার প্রভু আল্লাহ্‌’, আর নিঃসন্দেহ তিনি তোমাদের প্রভুর কাছ থে কে স্পষ্ট প্রমাণ নিয়ে তোমাদের কাছে এসেছেন? আর তিনি যদি মিথ্যাবাদী হতেন তাহলে তিনি তোমাদের যে-সবের ভয় দেখান তার কতকটা তোমাদের উপরে আপতিত হবে। নিঃসন্দেহ আল্লাহ্ তাকে সৎপথে পরিচালিত করেন না যে অমিতাচারী, প্রত্যাখ্যানকারী।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmclxii{''হে আমার স্বজাতি! তোমাদেরই আজ রাজত্ব চলছে, তোমরা দেশে সর্বপ্রধান, কিন্ত কে আমাদের সাহায্য করবে আল্লাহ্‌র দুর্যোগ থেকে যদি তা আমাদের উপরে এসে পড়ে?’’ ফিরআউন বলল -- ''আমি তোমাদের দেখাই না যা আমি না দেখি, আর আমি তোমাদের পরিচালিত করি না সঠিক পথে ছাড়া।’’\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmclxiii{আর যে বিশ্বাস করেছিল সে বলল -- ''হে আমার স্বজাতি! আমি নিশ্চয়ই তোমাদের জন্য আশঙ্কা করছি যেমনটা ঘটেছিল সম্মিলিতগোষ্ঠীর দিনে,\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmclxiv{''যেমন ধরনে নূহ-এর ও 'আদ-এর ও ছামুদের সম্প্রদায়ের উপরে, আর যারা ছিল তাদের পরবর্তী। আর আল্লাহ্ বান্দাদের প্রতি কোনো জুলুম চান না।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmmclxv{''আর হে আমার স্বজাতি! আমি নিঃসন্দেহ তোমাদের জন্য আশঙ্কা করছি পরস্পর ডাকাডাকির দিন সন্বন্ধে --\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmmclxvi{''সেইদিন তোমরা ফিরবে পলায়নপর হয়ে, আল্লাহ্‌র থেকে তোমাদের জন্য কোনো রক্ষাকারী থাকবে না। আর যাকে আল্লাহ্ পথভ্রষ্ট হতে দেন তার জন্য তবে কোনো পথপ্রদর্শক থাকবে না।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmmclxvii{''আর নিশ্চয়ই তোমাদের কাছে এর আগে ইউসুফ এসেছিলেন স্পষ্ট প্রমাণাবলী নিয়ে, কিন্ত তোমরা বরাবর সন্দেহের মধ্যে ছিলে তিনি যা নিয়ে তোমাদের কাছে এসেছিলেন সে-সন্বন্ধে। কিন্ত যখন তিনি মৃতুবরণ করলেন তখন তোমরা বললে -- 'আল্লাহ্ কখনো তাঁর পরে কোনো রসূল দাঁড় করাবেন না।’ এইভাবেই আল্লাহ্ পথভ্রষ্ট হতে দেন তাকে যে স্বয়ং অমিতাচারী, সন্দেহভাজন --\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmmclxviii{''যারা তর্ক করে আল্লাহ্‌র বাণী সন্বন্ধে তাদের কাছে কোনো দলিল-প্রমাণের আগমন ব্যতীত। এটি খুবই ঘৃণিত আল্লাহ্‌র কাছে ও যারা ঈমান এনেছে তাদের কাছে। এইভাবেই আল্লাহ্ মোহর মেরে দেন প্রত্যেক গর্বিত স্বৈরাচারীর হৃদয়ের উপরে।’’\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmmclxix{আর ফিরআউন বলল -- ''হে হামান! আমার জন্য একটি মিনার তৈরি কর যাতে আমি পথ পেতে পারি --\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmmclxx{''মহাকাশমন্ডলীর পথ, যাতে আমি মূসার উপাস্যের প্রতি দৃষ্টিপাত করতে পারি, কিন্ত আমি নিঃসন্দেহ তাকে মিথ্যাবাদী মনে করি।’’ আর এইভাবেই ফিরআউনের জন্য চিত্তাকর্ষক করা হয়েছিল তার কাজের মন্দদিকটা, আর তাকে নিবৃত্ত করা হয়েছিল পথ থেকে। আর ফিরআউনের ফন্দি ধ্বংসের মধ্যে ছাড়া আর কিছু নয়।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmmclxxi{আর যে ঈমান এনেছিল সে বলল -- ''হে আমার স্বজাতি! তোমরা আমার অনুসরণ করো, আমি তোমাদের চালিয়ে নিয়ে যাব সঠিক পথ ধরে।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmmclxxii{''হে আমার স্বজাতি! নিশ্চয় দুনিয়ার এই জীবনটা সুখভোগ মাত্র, আর অবশ্য পরকাল -- সেটি হচ্ছে চিরস্থায়ী আবাস।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmmclxxiii{''যে কেউ মন্দ কাজ করে তাকে তবে প্রতিদান দেওয়া হবে না তার সমান-সমান ব্যতীত, আর যে কেউ ভাল কাজ করে -- সে পুরুষ হোক বা নারী, আর সে মুমিন হয় -- তাহলে তারাই জান্নাতে প্রবেশ করবে, সেখানে তাদের বেহিসাব রিযেক দেওয়া হবে।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmmclxxiv{''আর হে আমার স্বজাতি! আমার কী হয়েছে যে আমি তোমাদের আহ্বান করছি মুক্তির দিকে, অথচ তোমরা আমাকে ডাকছো আগুনের দিকে?\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmmclxxv{''তোমরা আমাকে আহ্বান করছ যেন আমি আল্লাহ্‌কে অবিশ্বাস করি ও তাঁর সঙ্গে শরীক করি তাকে যার সন্বন্ধে আমার কোনো জ্ঞান নেই, পক্ষান্তরে আমি তোমাদের ডাকছি মহাশক্তিশালী, পরিত্রাণকারীর দিকে।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmmclxxvi{''কোনো সন্দেহ নেই যে তোমরা আমাকে যার প্রতি আহ্বান করছ তার কোনো দাবি এই দুনিয়াতে নেই এবং পরকালেও নেই, আর আমাদের প্রত্যাবর্তন তো আল্লাহ্‌রই কাছে, আর নিশ্চয় সীমালংঘনকারীরা -- তারাই আগুনের বাসিন্দা।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmmclxxvii{''সেজন্য অচিরেই তোমরা স্মরণ করবে আমি তোমাদের যা বলছি, আর আমার কাজের ভার আল্লাহ্‌তে অর্পণ করছি। নিশ্চয় আল্লাহ্ বান্দাদের সম্পর্কে সর্বদ্রষ্টা।’’\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmmclxxviii{তারপর আল্লাহ্ তাঁকে তারা যা ফন্দি এটেছিলঁ তার অনিষ্ট থেকে রক্ষা করেছিলেন, আর ফিরআউনের লোকদের জন্য এক ভীষণ শাস্তি ঘেরাও করেছিল, --\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmmmclxxix{আগুন -- তাদের এর কাছে আনা হবে সকালে ও সন্ধ্যায়, আর যেদিন ঘড়িঘন্টা এসে দাঁড়াবে -- ''ফিরআউনের লোকদের প্রবেশ করাও কঠোরতম শাস্তিতে।’’\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmmmclxxx{আর দেখো! তারা আগুনের মধ্যে পরস্পর তর্কাতর্কি করবে, তখন দুর্বলেরা বলবে তাদের যারা হামবড়াই করত -- ''অবশ্য আমরা তো তোমাদেরই তাঁবেদার ছিলাম, সুতরাং তোমরা কি আমাদের থেকে আগুনের কিছুটা অংশ সরিয়ে নেবে?’’\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmmmclxxxi{যারা হামবড়াই করত তারা বলবে -- ''আমরা তো সব-ক’জনই এর মধ্যে রয়েছি। নিঃসন্দেহ আল্লাহ্ বিচার-মীমাংসা করে ফেলেছেন বান্দাদের মধ্যে।’’\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmmmclxxxii{আর যারা আগুনের মধ্যে রয়েছে তারা জাহান্নামের রক্ষীদের বলবে -- ''তোমাদের প্রভুকে ডেকে বল তিনি যেন একটা দিন আমাদের থেকে শাস্তির কিছুটা লাঘব করে দেন।’’\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmmmclxxxiii{তারা বলবে, ''এমনটি কি তোমাদের ক্ষেত্রে নয় যে তোমাদের রসূলগণ তোমাদের কাছে স্পষ্ট প্রমাণাবলী নিয়ে এসেছিলেন?’’ তারা বলবে, ''হ্যাঁ।’’ তারা বলবে -- ''তাহলে ডাকতে থাকো, বস্তুতঃ অবিশ্বাসীদের আর্তনাদ ব্যর্থতায় বৈ তো নয়।’’\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmmmclxxxiv{নিঃসন্দেহ আমরা অবশ্যই আমাদের রসূলগণকে ও যারা ঈমান এনেছে তাদের সাহায্য করে থাকি এই দুনিয়ার জীবনে আর সেইদিন যখন সাক্ষীরা দাঁড়াবে, --\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmmmclxxxv{সেদিন অন্যায়াচারীদের কোনো উপকারে লাগবে না তাদের অজুহাতগুলো, আর তাদের জন্য থাকবে ধিক্কার, আর তাদের জন্য রয়েছে নিকৃষ্ট আবাস।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmmmclxxxvi{আর আমরা ইতিপূর্বে মূসাকে পথনির্দেশ দিয়েছিলাম, এবং ইসরাইলের বংশধরদের উত্তরাধিকার করতে দিয়েছিলাম ধর্মগ্রন্থ --\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmmmclxxxvii{পথনির্দেশ ও স্মরণীয় বার্তা বুদ্ধিবিবেচনা থাকা লোকদের জন্য।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmmmclxxxviii{সুতরাং তুমি অধ্যবসায় চালিয়ে যাও, নিঃসন্দেহ আল্লাহ্‌র ওয়াদা ধ্রুবসত্য। আর তুমি তোমার দোষত্রুটির জন্য পরিত্রাণ খুঁজো এবং তোমার প্রভুর প্রশংসার সাথে রাত্রি ও প্রভাতে জপতপ করো।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mmmmclxxxix{নিঃসন্দহ যারা আল্লাহ্‌র বাণীসমূহ নিয়ে তর্কবিতর্ক করে তাদের কাছে কোনো দলিল-প্রমাণের আগমন ব্যতিরেকে, তাদের অন্তরে রয়েছে হামবড়াই বৈ তো নয়, যা তারা কখনো লাভ করতে পারবে না। সুতরাং আল্লাহ্‌র কাছে আশ্রয় চাও। নিঃসন্দেহ তিনি স্বয়ং সর্বশ্রোতা, সর্বদ্রষ্টা।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mmmmcxc{মহাকাশমন্ডলী ও পৃথিবীর সৃষ্টি নিশ্চয়ই মানুষের সৃষ্টির চেয়ে কঠিনতর, কিন্ত অধিকাংশ লোকেই জানে না।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mmmmcxci{আর অন্ধ ও চক্ষুষ্মান একসমান নয়, আর যারা ঈমান এনেছে ও সৎকাজ করছে এবং দুস্কর্মকারীরাও নয়। সামান্যই তা যা তোমরা মনোনিবেশ করে থাকো!\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mmmmcxcii{নিঃসন্দেহ ঘড়িঘন্টা প্রায় এসেই গেছে, এতে কোনো সন্দেহ নাই। কিন্ত অধিকাংশ লোকই বিশ্বাস করে না।\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mmmmcxciii{আর তোমাদের প্রভু বলেন -- ''তোমরা আমাকে আহ্বান করো, আমি তোমাদের প্রতি সাড়া দেব। নিঃসন্দেহ যারা আমাকে উপাসনা করার বেলা অহংকার বোধ করে তারা অচিরেই জাহান্নামে প্রবেশ করবে লাঞ্ছিত অবস্থায়।’’\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mmmmcxciv{আল্লাহ্‌ই তিনি যিনি তোমাদের জন্য রাতকে সৃষ্টি করেছেন যেন তোমরা তাতে বিশ্রাম করতে পারো, আর দিনকে দেখবার জন্য। নিঃসন্দেহ আল্লাহ্ তো মানুষের প্রতি করুণাভান্ডারের অধিকারী, কিন্ত অধিকাংশ লোকই কৃতজ্ঞতা প্রকাশ করে না।\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mmmmcxcv{এইই আল্লাহ্‌, তোমাদের প্রভু, সব-কিছুর সৃষ্টিকর্তা, তিনি ছাড়া অন্য উপাস্য নেই, সুতরাং কার কাছ থেকে তোমরা ফিরে যাচ্ছ?\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mmmmcxcvi{এইভাবেই ফিরে যাচ্ছিল তারা যারা আল্লাহ্‌র নির্দেশাবলীকে প্রত্যাখ্যান করছিল।\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mmmmcxcvii{আল্লাহ্‌ই তিনি যিনি তোমাদের জন্য পৃথিবীকে বাসোপযোগী বানিয়েছেন আর আকাশকে একটি চাঁদোয়া, আর তিনি তোমাদের আকৃতি গঠন করেছেন, সুতরাং তিনি তোমাদের আকৃতি কত সুন্দর করেছেন! আর তিনি তোমাদের জীবিকা দিয়েছেন উৎকৃষ্ট বস্তু থেকে। এইই হচ্ছেন আল্লাহ্ -- তোমাদের প্রভু। অতএব সকল মহিমার পাত্র আল্লাহ্ -- বিশ্বজগতের প্রভু।\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mmmmcxcviii{তিনি সদাজীবিত, তিনি ছাড়া অন্য উপাস্য নেই, সুতরাং ধর্মে তাঁর প্রতি একনিষ্ঠচিত্তে তাঁকেই ডাকো। সমস্ত প্রশংসা আল্লাহ্‌র যিনি বিশ্বজগতের প্রভু।\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mmmmcxcix{বলো -- ''নিঃসন্দেহ আমাকে নিষেধ করা হয়েছে তাদের উপাসনা করতে যাদের তোমরা উপাসনা কর আল্লাহ্‌কে বাদ দিয়ে, -- যখন আমার কাছে আমার প্রভুর কাছ থেকে স্পষ্ট প্রমাণাবলী এসেছে, আর আমাকে নির্দেশ দেওয়া হয়েছে যেন আমি বিশ্বজগতের প্রভুর প্রতি আ‌ত্মসমর্পণ করি।\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mmmmcc{''তিনিই সেইজন যিনি তোমাদের সৃষ্টি করেছেন মাটি থেকে, তারপর শুক্রকীট থেকে, তারপর রক্তপিন্ড থেকে, তারপর তিনি তোমাদের বের করে আনেন শিশুরূপে, তারপর যেন তোমরা বাড়তে পারো তোমাদের পূর্ণযৌবনে, তারপর যেন তোমরা বৃদ্ধ হতে পারো, আর তোমাদের মধ্যে কাউকে মরতে দেওয়া হয় আগেই, -- কাজেকাজেই তোমরা যেন নির্ধারিত সময়সীমায় পৌঁছুতে পারো, আর যেন তোমরা বুঝতে-সুঝতে পারো।\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mmmmcci{''তিনিই সেইজন যিনি জীবনদান করেন ও মৃত্যু ঘটান, সুতরাং তিনি যখন কোনো ব্যাপারের বিধান করেন তখন শুধুমাত্র তিনি সে-সন্বন্ধে বলেন -- 'হও’, ফলে তা হয়ে যায়।’’\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mmmmccii{তুমি কি তাদের দিকে চেয়ে দেখো নি যারা আল্লাহ্‌র নির্দেশাবলী নিয়ে বিতর্ক করে? ওরা কেমন করে ফিরে যাচ্ছে --\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mmmmcciii{যারা গ্রন্থখানাকে প্রত্যাখ্যান করছে, আর যা দিয়ে আমরা আমাদের রসূলগণকে পাঠিয়েছিলাম? কিন্ত শীগগিরই তারা বুঝতে পারবে --\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@mmmmcciv{যখন তাদের গলায় বেড়ি হবে আর হবে শিকল। তাদের টেনে নিয়ে যাওয়া হবে --\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@mmmmccv{ফুটন্ত পানির মধ্যে, তারপর তাদের জ্বলতে দেওয়া হবে আগুনের মধ্যে।\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@mmmmccvi{তখন তাদের বলা হবে -- ''কোথায় আছে তারা যাদের তোমরা শরিক করতে --\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@mmmmccvii{আল্লাহ্‌কে বাদ দিয়ে?’’ তারা বলবে, ''তারা আমাদের থেকে উধাও হয়েছে, বস্তুতঃ আমরা ইতিপূর্বে এমন কিছুকে আহ্বান করে চলি নি।’’ এভাবেই আল্লাহ্ পথভ্রষ্ট হতে দেন অবিশ্বাসীদের।\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@mmmmccviii{এমনটাই তোমাদের জন্য কেননা তোমরা দুনিয়াতে বেপরোয়া ব্যবহার করতে কোনো যুক্তি ব্যতীত, আর যেহেতু তোমরা হামবড়াই করতে।\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@mmmmccix{''তোমরা জাহান্নামের দরজাগুলো দিয়ে প্রবেশ করো তাতে অবস্থানের জন্য। সুতরাং গর্বিতদের আবাসস্থল কত নিকৃষ্ট!’’\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@mmmmccx{কাজেই তুমি অধ্যবসায় চালিয়ে যাও, নিশ্চয় আল্লাহ্‌র ওয়াদা সত্য। সুতরাং তাদের যা ওয়াদা করা হয়েছে আমরা যদি তার কিছুটা তোমাকে দেখিয়েই দিই অথবা তোমার মৃত্যুই ঘটাই, সর্বাবস্থায় আমাদেরই কাছে তাদের ফিরিয়ে আনা হবে।\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@mmmmccxi{আর নিশ্চয়ই আমরা তোমার আগে রসূলগণকে পাঠিয়ে দিয়েছি, তাঁদের মধ্যের কারো কারো সন্বন্ধে তোমার কাছে আমরা বিবৃত করেছি, আর তাদের মধ্যের অন্যদের সন্বন্ধে আমরা তোমার কাছে বিবৃত করি নি। আর কোনো রসূলেরই কাজ নয় যে তিনি আল্লাহ্‌র অনুমতি ব্যতীত কোনো নিদর্শন নিয়ে আসবেন, কিন্ত যখন আল্লাহ্‌র নির্দেশ এসে যাবে, তখন মীমাংসা হয়ে যাবে ন্যায়সংগতভাবে, আর বাতিল করার প্রচেষ্টাকারীরা তখন তখনই নাজেহাল হবে।\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@mmmmccxii{আল্লাহই তিনি যিনি তেমাদের জন্য গবাদি-পশু সৃষ্টি করেছেন যেন তোমরা তাদের কতকগুলোয় চড়তে পরো ও তাদের কতকটা তোমরা খেতে পারো,\qt@no{(79)}}
\qt@newcmd\qurantrans@bn@mmmmccxiii{আর তোমাদের জন্য তাদের মধ্যে রয়েছে মুনাফা, আর যেন তাদের সাহায্যে তোমরা পূরণ করতে পারো তোমাদের অন্তরের বাসনা, আর তাদের উপরে ও জাহাজের উপরে তোমাদের বহন করা হয়।\qt@no{(80)}}
\qt@newcmd\qurantrans@bn@mmmmccxiv{আর তিনি তোমাদের দেখিয়ে থাকেন তাঁর নিদর্শনসমূহ। সুতরাং আল্লাহ্‌র নিদর্শনাবলীর কোনটি তোমরা প্রত্যাখ্যান করবে?\qt@no{(81)}}
\qt@newcmd\qurantrans@bn@mmmmccxv{ওরা কি তবে পৃথিবীতে পরিভ্রমণ করে নি, তাহলে ওরা দেখতে পেতো কেমন হয়েছিল তাদের পরিণাম যারা ওদের পূর্ববর্তী ছিল? তারা ওদের চেয়ে অধিকসংখ্যক ছিল আর শক্তিতে প্রবলতর ও দুনিয়াতে কীর্তিস্থাপনে ছিল পারদর্শী। কিন্ত তারা যা অর্জন করে চলেছিল তা তাদের কোনো কাজে আসে নি।\qt@no{(82)}}
\qt@newcmd\qurantrans@bn@mmmmccxvi{তারপর যখন তাদের রসূলগণ তাদের কাছে স্পষ্ট প্রমাণাবলী নিয়ে এসেছিলেন তখন তাদের কাছে জ্ঞানের যা রয়েছে সেজন্য তারা বেপরোয়া থাকতো, আর ওরা যা নিয়ে ঠাট্টা-বিদ্রপ করত তাই তাদের ঘেরাও করল।\qt@no{(83)}}
\qt@newcmd\qurantrans@bn@mmmmccxvii{সুতরাং তারা যখন আমাদের দুর্যোগ দেখতে পেল তখন বলল, ''আমরা আল্লাহ্‌তে, তাঁর একত্বে, বিশ্বাস করছি, আর যাদের আমরা তাঁর সঙ্গে শরীক করেছিলাম তাদের আমরা অস্বীকার করছি।’’\qt@no{(84)}}
\qt@newcmd\qurantrans@bn@mmmmccxviii{কিন্ত যখন তারা আমাদের দুর্যোগ প্রত্যক্ষ করেছে তখন তাদের বিশ্বাসস্থাপনা তাদের কোনো উপকারে আসবে না। আল্লাহর রীতি যেটি বলবৎ হয়ে রয়েছে তাঁর বান্দাদের মধ্যে, আর অবিশ্বাসীরা তখনই নাস্তানাবুদ হবে।\qt@no{(85)}}
\qt@newcmd\qurantrans@bn@mmmmccxix{\basmalahbn হা মীম!\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmccxx{পরম করুণাময় অফুরন্ত ফলদাতার কাছ থেকে এ এক অবতারণ --\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmccxxi{একটি গ্রন্থ যার আয়াতসমূহ স্পষ্টভাবে বিবৃত, আরবী কুরআন সেই লোকদের জন্য যারা জানে --\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmccxxii{সুসংবাদবাহক ও সতর্ককারী; কিন্ত তাদের অনেকেই সরে যায়, কাজেই তারা শোনে না।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmccxxiii{আর তারা বলে -- ''তুমি যার প্রতি আমাদের ডাকছ তা থেকে আমাদের হৃদয় ঢাকনির ভেতরে রয়েছে, আর আমাদের কানে রয়েছে বধিরতা, আর আমাদের মধ্যে ও তোমার মধ্যে রয়েছে একটি পর্দা কাজ করে যাও, আমরাও অবশ্য কাজ করে চলেছি।’’\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmccxxiv{বলো, ''আমি তো তোমাদের মতো একজন মানুষ মাত্র, আমার কাছে প্রত্যাদেশ হয়েছে যে তোমাদের উপাস্য নিশ্চয়ই একক উপাস্য, সুতরাং তাঁর দিকে সোজাসুজি পথ ধরো, আর তাঁরই কাছে পরিত্রাণ খোঁজো।’’ আর ধিক্ বহুখোদাবাদীদের প্রতি --\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmccxxv{যারা যাকাত প্রদান করে না, আর আখেরাত সম্পর্কে তারা স্বয়ং অবিশ্বাসী।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmccxxvi{পক্ষান্তরে যারা ঈমান এনেছে ও সৎকর্ম করছে তাদের জন্য রয়েছে বাধাহীন প্রতিদান।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmccxxvii{বলো -- ''তোমরা কি ঠিকঠিকই তাঁকে অস্বীকার করছ যিনি পৃথিবী সৃষ্টি করেছেন দুই দিনে, আর তোমরা কি তাঁর সঙ্গে সমকক্ষ দাঁড় করাও? এমনজনই হচ্ছেন বিশ্বজগতের প্রভু।’’\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmccxxviii{আর তার মধ্যে তার বহির্ভাগে তিনি স্থাপন করেছেন পর্বতমালা, আর তাতে তিনি অনুগ্রহ অর্পণ করেছেন, আর তাতে তিনি ব্যবস্থা করেছেন এর খাদ্যসামগ্রী -- চার দিনে। অনুসন্ধানকারীদের জন্য সমভাবে প্রযোজ্য।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmccxxix{তারপর তিনি ফিরলেন আকাশের দিকে আর সেটি ছিল এক ধূম্রজাল। অনন্তর তিনি এটিকে ও পৃথিবীকে বললেন -- ''তোমরা উভয়ে এসো স্বেচ্ছায় অথবা অনিচ্ছায়।’’ তারা বললে -- ''আমরা আসছি অনুগত হয়ে।’’\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmccxxx{তারপর তিনি তাদের সম্পূর্ণ করলেন সাত আসমানে, দুই দিনে, আর প্রত্যেক আকাশে তিনি আদেশ করেছেন তার করণীয়। আর আমরা নিকটবর্তী আকাশকে শোভিত করেছি প্রদীপমালা দিয়ে, আর সুরক্ষিত অবস্থায়। এটিই মহাশক্তিশালী সর্বজ্ঞাতার বিধান।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmccxxxi{এর পরেও তারা যদি ফিরে যায় তাহলে তুমি বলো -- ''আমি তোমাদের হুশিয়াঁর করে দিচ্ছি 'আদ ও ছামূদের বজ্রাঘাতের ন্যায় এক বজ্রাঘাত সন্বন্ধে।’’\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmccxxxii{স্মরণ করো! রসূলগণ তাদের কাছে এসেছিলেন তাদের সামনে থেকে ও তাদের পেছন থেকে এই বলে -- ''আল্লাহ্ ব্যতীত কারো উপাসনা করো না।’’ তারা বলেছিল -- ''আমাদের প্রভু যদি ইচ্ছা করতেন তাহলে তিনি নিশ্চয়ই ফিরিশ্‌তাদের পাঠাতে পারতেন, সেজন্য তোমাদের যা দিয়ে পাঠানো হয়েছে আমরা আলবৎ তাতে অবিশ্বাসী।’’\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmccxxxiii{বস্তুতঃ 'আদ-এর ক্ষেত্রে -- তারা তখন পৃথিবীতে যুক্তি ব্যতিরেকে অহঙ্কার করত, আর বলত -- ''আমাদের চেয়ে বলবিক্রমে বেশী শক্তিশালী কে আছে?’’ তারা কি তবে দেখতে পায় নি যে, আল্লাহ্ যিনি তাদের সৃষ্টি করেছেন তিনি তাদের চেয়ে বলবিক্রমে অধিক বলীয়ান? আর তারা আমাদের নির্দেশাবলী সন্বন্ধে বাদ-প্রতিবাদ করত।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmccxxxiv{সেজন্য আমরা তাদের উপরে পাঠিয়েছিলাম এক ভয়ংকর ঝড়তুফান অশুভ দিনে, যেন আমরা পার্থিব জীবনেই তাদের আস্বাদন করাতে পারি লাঞ্ছনাদায়ক শাস্তি। আর আখেরাতের শাস্তি নিশ্চয়ই আরো বেশী লাঞ্ছনাদায়ক, আর তাদের সাহায্য করা হবে না।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmccxxxv{আর ছামূদের ক্ষেত্রে -- আমরা তো তাদের পথ দেখিয়েছিলাম কিন্ত তারা পথ দেখার পরিবর্তে অন্ধত্ব ভালবেসেছিল, কাজেই তারা যা অর্জন করেছিল সেজন্য এক লাঞ্ছনাদায়ক শাস্তির বজ্রাঘাত তাদের পাকড়াও করেছিল।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmccxxxvi{আর আমরা উদ্ধার করেছিলাম তাদের যারা বিশ্বাস করেছিল এবং ভয়ভক্তি পোষণ করত।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmccxxxvii{আর সেই দিন যখন আল্লাহ্‌র শত্রুদের সমবেত করা হবে আগুনের দিকে, ফলে ওদের দল বাঁধা হবে, --\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmccxxxviii{পরিশেষে যখন তারা এর কাছে আসবে তখন তাদের কান ও তাদের চোখ ও তাদের ছাল-চামড়া তাদের বিরুদ্ধে সাক্ষ্য দেবে তারা যা করত সে-সন্বন্ধে।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmccxxxix{আর তারা নিজেদের ছাল-চামড়াকে বলবে -- ''তোমরা কেন আমাদের বিরুদ্ধে সাক্ষ্য দিলে?’’ তারা বলবে -- আল্লাহ্ যিনি সব- কিছুকে কথা বলান, তিনিই আমাদের কথা বলিয়েছেন।’’ আর তিনি তোমাদের প্রথমবারে সৃষ্টি করেছেন, আর তাঁরই কাছে তোমাদের ফিরিয়ে আনা হবে।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmccxl{আর তোমাদের কান তোমাদের বিরুদ্ধে সাক্ষ্য দেবার ব্যাপারে তোমরা কিছুই গোপন রাখতে না, আর তোমাদের চোখের থেকেও নয়, আর তোমাদের ছাল-চামড়া থেকেও নয়, উপরন্তু তোমরা মনে করতে যে তোমরা যা করেছিলে তার অধিকাংশই আল্লাহ্ জানেন না।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmccxli{আর তোমাদের এমনতর ভাবনাটাই যা তোমরা ভাবতে তোমাদের প্রভু সন্বন্ধে তা-ই তোমাদের ধ্বংস করেছে, ফলে সকালসকালই তোমরা ক্ষতিগ্রস্তদের অন্তর্ভুক্ত হয়েছ।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmccxlii{কাজেই তারা যদি অধ্যবসায় করে তাহলে আগুনই হবে তাদের অবস্থানস্থল, আর যদি তারা সদয়তা চায় তাহলে তারা নুগ্রহপ্রাপ্তদের অন্তর্ভুক্ত হবে না।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmccxliii{আর আমরা তাদের জন্য সঙ্গী বানিয়েছিলাম, তাই তাদের জন্য তারা চিত্তাকর্ষক করেছিল যা তাদের সম্মুখে ছিল আর যা তাদের পশ্চাতে ছিল, আর তাদের বিরুদ্ধে বাণী সত্য প্রতিপন্ন হয়েছে, -- জিনদের ও মানুষদের মধ্যের যারা তাদের পূর্বে গত হয়ে গেছে সেই সম্প্রদায়ের মধ্যে, নিঃসন্দেহ তারা ছিল ক্ষতিগ্রস্ত।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmccxliv{আর যারা অবিশ্বাস করে তারা বলে -- ''এই কুরআন শুনো না, আর এতে শোরগোল করো, যাতে তোমরা দমন করতে পারো।’’\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmccxlv{সেজন্য যারা অবিশ্বাস করে তাদের আমরা অবশ্যই কঠিন শাস্তি আস্বাদন করাব, আর তাদের অবশ্যই প্রতিদান দেব তারা যা গর্হিত কাজ করত তাই দিয়ে।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmccxlvi{এই হচ্ছে আল্লাহ্‌র শত্রুদের পরিণাম -- আগুন, তাদের জন্য এখানে রয়েছে দীর্ঘস্থায়ী আবাস। আমাদের নির্দেশাবলী তারা অস্বীকার করত বলেই এটি হচ্ছে প্রতিফল।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmccxlvii{আর যারা অবিশ্বাস করে তারা বলবে -- ''আমাদের প্রভু! জিন ও মানুষদের যারা আমাদের বিপথে চালিয়েছিল তাদের আমাদের দেখিয়ে দাও, আমাদের পায়ের তলায় আমরা তাদের মাড়াবো, যাতে তারা অধমদের অন্তর্ভুক্ত হয়।’’\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmccxlviii{পক্ষান্তরে যারা বলে -- ''আমাদের প্রভু আল্লাহ’’, তারপর তারা কায়েম থাকে, তাদের নিকট ফিরিশ্‌তারা অবতরণ করে এই বলে -- ''ভয় করো না আর দুঃখ করো না, বরঞ্চ সুসংবাদ শুনো জান্নাতের যার জন্য তোমাদের প্রতি‌শ্রুতি দেওয়া হয়েছিল।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmccxlix{''আমরা তোমাদের বন্ধু এই দুনিয়ার জীবনে ও পরকালে, আর তোমাদের জন্য এতে রয়েছে তোমাদের অন্তর যা-কিছু কামনা করে তাই, আর তোমাদের জন্য তাতে রয়েছে যা তোমরা চেয়ে পাঠাও।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmmccl{''পরিত্রাণকারী অফুরন্ত ফলদাতার তরফ থেকে এক আপ্যায়ন।’’\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmmccli{আর কে তার চাইতে কথাবার্তায় বেশী ভাল যে আল্লাহ্‌র প্রতি আহ্বান করে এবং সৎকর্ম করে আর বলে -- ''আমি তো নিশ্চয়ই মুসলিমদের মধ্যেকার?’’\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmmcclii{আর ভাল জিনিস ও মন্দ জিনিস একসমান হতে পারে না। প্রতিহত করো তাই দিয়ে যা অধিকতর উৎকৃষ্ট, ফলে দেখো! তোমার মধ্যে ও তার মধ্যে শত্রুতা থাকলেও সে যেন ছিল অন্তরঙ্গ বন্ধু।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmmccliii{আর কেউ এটি পেতে পারে না তারা ব্যতীত যারা অধ্যবসায় করে, আর কেউ এটি পেতে পারে না মহান সৌভাগ্যবান ব্যতীত।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmmccliv{আর শয়তান থেকে কোনো খোঁচা যদি তোমাকে খোঁচা দেয় তাহলে তুমি আল্লাহ্‌র কাছে আশ্রয় চাও। নিঃসন্দেহ তিনি স্বয়ং সর্বশ্রোতা, সর্বজ্ঞাতা।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmmcclv{আর তাঁর নিদর্শনাবলীর মধ্যে রয়েছে রাত ও দিন আর সূর্য ও চন্দ্র। তোমরা সূর্যের প্রতি সিজদা করো না আর চন্দ্রের প্রতিও নয়, বরং তোমরা সিজ্‌দা করো আল্লাহ্‌র প্রতি যিনি এগুলোকে সৃষ্টি করেছেন, যদি তোমরা তাঁকেই উপাসনা করতে চাও।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmmcclvi{কিন্ত যদি তারা গর্ববোধ করে, বস্তুতঃ যারা তোমার প্রভুর সান্নিধ্যে রয়েছে তারা তাঁর জপতপ করছে দিন ও রাতভর, আর তারা ক্লান্তিবোধ করে না।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmmcclvii{আর তাঁর নিদর্শনগুলোর মধ্যে হচ্ছে যে, তুমি পৃথিবীটাকে দেখতে পাচ্ছ শুকনো, তারপর যখন তার উপরে আমরা বর্ষণ করি বৃষ্টি তখন তা চঞ্চল হয় ও ফেঁপে ওঠে। নিঃসন্দেহ যিনি এটিকে জীবনদান করেন তিনিই তো মৃতের প্রাণদাতা। তিনি নিশ্চয়ই সব- কিছুর উপরে সর্বশক্তিমান।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmmcclviii{নিঃসন্দেহ যারা বেঁকে বসে আমাদের নির্দেশাবলীসন্বন্ধে তারা আমাদের থেকে লুকিয়ে থাকা নয়। তবে কি যাকে আগুনে নিক্ষেপ করা হবে সে অধিকতর ভাল, না সে, যে কিয়ামতের দিনে নিরাপত্তার সাথে হাজির হবে? তোমরা যা চাও করে যাও, নিঃসন্দেহ তোমরা যা করছ সে-সন্বন্ধে তিনি সর্বদ্রষ্টা।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmmcclix{নিঃসন্দেহ যারা স্মারকগ্রন্থকে প্রত্যাখ্যান করে তাদের কাছে তা আসার পরে। আর এটি তো নিশ্চয়ই এক সুমহান গ্রন্থ, --\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmmcclx{এতে মিথ্যা কথা আসতে পারবে না এর সামনে থেকে, আর এর পেছন থেকেও নয়। এ হচ্ছে একটি অবতারণ মহাজ্ঞানী পরম প্রশংসিতের কাছ থেকে।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmmcclxi{তোমার প্রতি এমন কিছু বলা হয়নি তা ব্যতীত যা বলা হতো তোমার পূর্ববর্তী রসূলগণের সন্বন্ধে। নিঃসন্দেহ তোমার প্রভু নিশ্চয়ই পরিত্রাণে ক্ষমতাবান, এবং কঠোর প্রতিফল দিতে সক্ষম।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmmcclxii{আর যদি আমরা এটিকে একটি আ'জমী ভাষণ বানাতাম তাহলে তারা নিশ্চয়ই বলত -- ''এর আয়াতগুলো কেন পরিস্কারভাবে বলা হয় নি? কী! একটি আ'জমী এবং একজন আরবীয়!’’ বলো -- ''যারা বিশ্বাস করে তাদের জন্য এটি এক পথনির্দেশ ও এক আরোগ্য-বিধান।’’ আর যারা বিশ্বাস করে না তাদের কানের মধ্যে রয়েছে বধিরতা, আর তাদের জন্য এটি অন্ধকারাচ্ছন্ন। এরা -- এদের ডাকা হয় বহু দূরের জায়গা থেকে।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmmcclxiii{আর আমরা তো ইতিপূর্বে মূসাকে ধর্মগ্রন্থ দিয়েছিলাম, কিন্ত এতে মতভেদ ঘটানো হয়েছিল। আর যদি না তোমার প্রভুর কাছ থেকে একটি বাণী ইতিপূর্বে ধার্য হয়ে থাকত তাহলে তাদের মধ্যে মীমাংসা হয়ে যেত। আর নিঃসন্দেহ এ-সন্বন্ধে তা রা এক অস্বস্তিকর সন্দেহের মাঝে রয়েছে।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmmmcclxiv{যে কেউ সৎকর্ম করে থাকে, সেটি তো তার নিজের জন্যেই, আর যে কেউ মন্দকাজ করে সেটি তো তারই বিরুদ্ধে। আর তোমার প্রভু দাসদের প্রতি আদৌ অন্যায়কারী নন।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmmmcclxv{তাঁর কাছেই হাওয়ালা দেওয়া হয় ঘড়িঘন্টার জ্ঞান সন্বন্ধে। আর ফল-ফসলের কোনোটিই তার থোড়ের মধ্যে থেকে বেরিয়ে আসে না, আর নারীদের কেউ গর্ভধারণ করে না ও সন্তান প্রসবও করে না তাঁর জ্ঞানের বাইরে। আর সেইদিন তিনি তাদের ডেকে বলবেন -- ''কোথায় আমার শরিকান?’’ তারা বলবে -- ''আমরা তোমার কাছে ঘোষণা করছি, আমাদের মধ্যে কেউই সাক্ষী নই।’’\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmmmcclxvi{আর এর আগে যাদের তারা ডাকত তারা তাদের থেকে অদৃশ্য হয়ে যাবে, আর তারা বুঝবে যে তাদের জন্য কোনো আশ্রয় নেই।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmmmcclxvii{মানুষ ভালর জন্যে প্রার্থনায় ক্লান্তি বোধ করে না, কিন্ত যদি দুঃখকষ্ট তাকে স্পর্শ করে সে তখন ধৈর্যহারা হয়ে যায়।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmmmcclxviii{আর দুঃখদুর্দশা তাকে স্পর্শ করার পরে আমরা যদি তাকে আমাদের থেকে করুণা আস্বাদ করাই, সে নিশ্চয়ই বলবে -- ''এটি আমারই জন্যে, আর আমি মনে করি না যে ঘড়িঘন্টা কায়েম হবে, আর যদিই বা আমাকে আমার প্রভুর কাছে নিয়ে যাওয়া হয় তবে আমার জন্য তাঁর কাছে কল্যাণই থাকবে।’’ কিন্ত যারা অবিশ্বাস পোষণ করে তাদের আমরা অবশ্যই জানিয়ে দেব কী তারা করেছিল এবং তাদের আমরা অবশ্যই আস্বাদন করাব কঠোর শাস্তি থেকে।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmmmcclxix{আর যখন আমরা মানুষের উপরে অনুগ্রহ বর্ষণ করি সে মুখ ফিরিয়ে নেয় ও এর আশপাশ থেকে দূরে সরে যায়, কিন্ত যখন দুঃখকষ্ট তাকে স্পর্শ করে তখন দেখো! সে দীর্ঘ প্রার্থনায় রত হয়।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmmmcclxx{তুমি বলো -- ''তোমরা কি ভেবে দেখেছ, যদি এটি আল্লাহ্‌র কাছ থেকে হ’য়ে থাকে এবং তোমরা এতে অবিশ্বাস কর, তাহলে তার চাইতে কে বেশী পথভ্রান্ত যে সুদূরব্যাপী বিরুদ্ধাচরণে রয়েছে?’’\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmmmcclxxi{আমরা অচিরেই তাদের দেখাব আমাদের নিদর্শনাবলী দিগদিগন্তে এবং তাদের নিজেদের মধ্যেও, যে পর্যন্ত না তাদের কাছে স্পষ্ট হয়ে যায় যে এটি নিঃসন্দেহ ধ্রুবসত্য। এটি কি যথেষ্ট নয় যে তোমার প্রভু -- তিনিই তো সব-কিছুর উপরে সাক্ষী রয়েছেন?\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmmmcclxxii{এটি কি নয় যে তারা আলবৎ সন্দেহের মাঝে রয়েছে তাদের প্রভুর সাথে সাক্ষাৎকার সন্বন্ধে? এটি কি নয় যে তিনি নিশ্চয় সব- কিছুরই পরিবেষ্টনকারী?\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmmmcclxxiii{\basmalahbn হা মীম!\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmcclxxiv{'আইন সীন ক্কাফ।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmcclxxv{এইভাবেই তোমার কাছে ও তোমার পূর্বে যাঁরা ছিলেন তাঁদের কাছে প্রত্যাদেশ দিয়েছিলেন -- মহাশক্তিশালী পরমজ্ঞানী আল্লাহ্‌।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmcclxxvi{যা-কিছু আছে মহাকাশমন্ডলীতে ও যা-কিছু আছে পৃথিবীতে সে-সবই তাঁর। আর তিনি মহোচ্চ, মহিমান্বিত।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmcclxxvii{মহাকাশমন্ডলী তাদের উপর থেকে ভেঙ্গে পড়ার উপক্রম হয়েছে, কিন্ত ফিরিশ্‌তারা তাদের প্রভুর প্রশংসায় জপতপ করে এবং পৃথিবীতে যারা আছে তাদের জন্য পরিত্রাণ খোঁজে। এটি কি নয় যে নিঃসন্দেহ আল্লাহ্‌, তিনি পরম ক্ষমাশীল, অফুরন্ত ফলদাতা?\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmcclxxviii{আর যারা তাঁকে বাদ দিয়ে অন্যদের অভিভাবকরূপে গ্রহণ করে, -- আল্লাহ্ তাদের উপরে পর্যবেক্ষক, আর তুমি তাদের উপরে কর্ণধার নও।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmcclxxix{আর এইভাবে আমরা তোমার প্রতি প্রত্যাদেশ দিয়েছি এই ভাষণ আরবীতে যেন তুমি নগর-জননী ও তার আশেপাশে যারা রয়েছে তাদের সতর্ক করতে পার, আর যেন তুমি সতর্ক করতে পার জমায়েৎ হওয়ার দিন সম্পর্কে -- যাতে কোনো সন্দেহ নেই। একদল জান্নাতে ও আরেক দল জ্বলন্ত আগুনে।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmcclxxx{আর আল্লাহ্ যদি চাইতেন তাহলে তিনি তাদের একই সম্প্রদায় করতে পারতেন, কিন্ত তিনি তাঁর করুণার মধ্যে প্রবেশ করান যাকে তিনি ইচ্ছে করেন। আর অনাচারীরা -- তাদের জন্যে কোনো অভিভাবক নেই আর কোনো সাহায্যকারীও নেই।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmcclxxxi{অথবা তারা কি তাঁকে বাদ দিয়ে অন্যদের অভিভাবকরূপে গ্রহণ করেছে? কিন্ত আল্লাহ্ -- তিনিই তো মনিব, আর তিনি মৃতকে জীবন দান করেন, আর তিনি সব-কিছুর উপরে সর্বশক্তিমান।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmcclxxxii{আর তোমরা যে কোনো বিষয়েই মতভেদ কর না কেন তার রায় তো আল্লাহ্‌রই নিকট। ''ইনিই আল্লাহ্‌, আমার প্রভু, তাঁরই উপরে আমি নির্ভর করি, আর তাঁরই দিকে আমি ফিরি।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmcclxxxiii{''তিনি মহাকাশমন্ডলী ও পৃথিবীর আদিস্রষ্টা। তিনি তোমাদের জন্য তোমাদেরই মধ্যে থেকে জোড়া সৃষ্টি করেছেন, আর গবাদি- পশুর মধ্যেও জোড়া, এর মধ্যে থেকেই তিনি তোমাদের বংশ বিস্তার করেন। কিছুই তাঁর সদৃশ নয়। আর তিনি সর্বশ্রোতা, সর্বদ্রষ্টা।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmcclxxxiv{''মহাকাশমন্ডলী ও পৃথিবীর চাবিকাঠি তাঁরই কাছে, তিনি যাকে ইচ্ছা করেন তার প্রতি রিযেক সম্প্রসারিত করেন আর মেপেজোখেও দেন। নিঃসন্দেহ তিনি সর্ববিষয়ে সর্বজ্ঞাতা।’’\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmcclxxxv{তিনি তোমাদের জন্য সেই ধর্ম থেকে বিধান দিচ্ছেন যার দ্বারা তিনি নূহকে নির্দেশ দিয়েছিলেন, আর যা আমরা তোমার কাছে প্রত্যাদেশ করছি, আর যার দ্বারা আমরা ইব্রাহীমকে ও মূসাকে ও ঈসাকে নির্দেশ দিয়েছিলাম এই বলে -- ''ধর্মকে কায়েম করো, আর এতে একে-অন্যে বিচ্ছিন্ন হয়ো না।’’ মুশরিকদের জন্য এ বড় কঠিন ব্যাপার যার প্রতি তুমি তাদের আহ্‌বান করছ! আল্লাহ্ যাকে ইচ্ছা করেন তাকে তাঁর কারণে নির্বাচিত করেন, আর তাঁর দিকে পরিচালিত করেন তাকে যে ফেরে।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmcclxxxvi{আর তারা নিজেদের কাছে জ্ঞান আসার পরেও বিচ্ছিন্ন হয়ে যেত না যদি-না নিজেদের মধ্যে ঈর্ষা-বিদ্বেষ থাকত। আর যদি তোমার প্রভুর কাছ থেকে একটি নির্ধারিত কাল পর্যন্ত একটি বাণী ইতিপূর্বে ধার্য হয়ে না থাকত তাহলে নিশ্চয়ই তাদের মধ্যে হেস্তনেস্ত হয়ে যেত। আর তাঁদের পরে যারা ধর্মগ্রন্থ উত্তরাধিকার করেছিল তারা তো এটি সন্বন্ধে বিভ্রান্তিকর সন্দেহে রয়েছে।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmcclxxxvii{কাজেই এর প্রতি তুমি তবে আহ্বান করতে থাকো, আর তোমাকে যেমন আদেশ করা হয়েছে তেমনিভাবে তুমি অটল থাকো, আর তাদের খেয়ালখুশির অনুগমন করো না, বরং বলো -- ''আমি বিশ্বাস করি তাতে যা আল্লাহ্ অবতারণ করেছেন এ গ্রন্থ থেকে, আর আমাকে আদেশ করা হয়েছে তোমাদের মধ্যে ন্যায়বিচার করতে। আল্লাহ্ আমাদের প্রভু এবং তোমাদেরও প্রভু। আমাদের কাজ হবে আমাদের জন্য এবং তোমাদের কাজ হবে তোমাদের জন্য। আমাদের মধ্যে ও তোমাদের মধ্যে কোনো বিবাদ-বিসংবাদ নেই। আল্লাহ্ আমাদের একত্রিত করবেন। আর তাঁর কাছেই তো প্রত্যাবর্তন।’’\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmcclxxxviii{আর যারা আল্লাহ্ সন্বন্ধে তর্ক করে তাঁর কথায় সাড়া দেবার পরেও, তাদের তর্কবিতর্ক তাদের প্রভুর কাছে অসার, আর তাদের উপরে ক্রোধ, আর তাদের জন্য রয়েছে ভীষণ শাস্তি।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmcclxxxix{আল্লাহ্‌ই তিনি যিনি সত্যসহ এই গ্রন্থ অবতারণ করেছেন আর দাঁড়িপাল্লা। আর কী তোমাকে জানাতে পারে -- সম্ভবতঃ ঘড়িঘন্টা আসন্ন।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmccxc{যারা এতে বিশ্বাস করে না তারাই এটি ত্বরান্বিত করতে চায়, কিন্ত যারা বিশ্বাস করে তারা এ সন্বন্ধে ভীত-সন্ত্রস্ত, এবং তারা জানে যে এটি নিঃসন্দেহ সত্য। এটি কি নয় যে যারা ঘড়িঘন্টা সন্বন্ধে বাক্‌-বিতন্ডা করে তারাই তো সুদূর প্রসারী ভ্রান্তি তে রয়েছে?\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmccxci{আল্লাহ্ তাঁর বান্দাদের প্রতি পরম দয়ালু, তিনি যাকে ইচ্ছা করেন রিযেক দান করেন, আর তিনি মহাবলীয়ান, মহাশক্তিশালী।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmccxcii{যে কেউ পরলোকের শস্যক্ষেত্র চায়, আমরা তার জন্য তার চাষ-আবাদ বাড়িয়ে দিই, আর যে কেউ এই দুনিয়ার চাষ-আবাদ চায় তাকে আমরা তা থেকেই দিয়ে থাকি, আর তার জন্য পরলোকে কোনো ভাগ থাকবে না।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmccxciii{অথবা তাদের কারণে কি অংশীদাররা রয়েছে যারা তাদের এমন এক ধর্মের বিধান দেয় যার জন্য আল্লাহ্ কোনো অনুমতি দেন নি? আর যদি একটি সিদ্ধান্তপূর্ণ বাণী না থাকত তাহলে নিশ্চয় তাদের মধ্যে মীমাংসা হয়েই যেত। আর অবশ্য অনাচারীরা -- তাদের জন্য রয়েছে মর্মন্তুদ শাস্তি।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmccxciv{তুমি দেখতে পাবে অন্যায়কারীরা ভীত-সন্ত্রস্ত রয়েছে তারা যা অর্জন করেছে সে জন্য, আর তা তাদের উপরে পড়তেই যাচ্ছে। পক্ষান্তরে যারা ঈমান এনেছে ও সৎকর্ম করছে জান্নাতের ফুলময় ময়দানে, -- তাদের জন্য তাদের প্রভুর কাছে রয়েছে তারা যা চায় তাই। এইটি -- এইই তো হচ্ছে বিরাট করুণাভান্ডার।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmccxcv{এইটি যার সুসংবাদ আল্লাহ্ দিচ্ছেন তাঁর বান্দাদের -- যারা ঈমান এনেছে ও সৎকাজ করছে। তুমি বলো -- ''আমি তোমাদের থেকে এর জন্যে নিকটা‌ত্মীয়দের মধ্যে ভালবাসা ব্যতীত অন্য কোনো প্রতিদান চাইছি না।’’ আর যে কেউ ভাল কাজ অর্জন করে আমরা তার জন্য এতে আরো ভাল যোগ দিই। নিঃসন্দেহ আল্লাহ্ পরিত্রাণকারী, গুণগ্রাহী।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmccxcvi{অথবা তারা কি বলে -- ''সে আল্লাহ্ সম্পর্কে এক মিথ্যা উদ্ভাবন করেছে?’’ কিন্ত আল্লাহ্ যদি চাইতেন তাহলে তোমার হৃদয়ে তিনি মোহর মেরে দিতেন। বস্তুত আল্লাহ্ মিথ্যাকে মুছে ফেলেন এবং সত্যকে সত্য প্রতিপন্ন করবেন তাঁর বাণীর দ্বারা। নিঃসন্দেহ তাদের অন্তরে যা রয়েছে সে-সন্বন্ধে তিনি সম্যক জ্ঞাতা।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmccxcvii{আর তিনিই সেইজন যিনি তাঁর বান্দাদের থেকে তওবা কবুল করেন, আর মন্দ ক্রিয়াকলাপ থেকে ক্ষমা করেন, আর তোমরা যা কর তিনি তা জানেন।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmccxcviii{আর তিনি সাড়া দেন তাদের প্রতি যারা ঈমান আনে ও সৎকর্ম করে, আর তাদের তিনি বাড়িয়ে দেন তাঁর করুণাভান্ডার থেকে। আর অবিশ্বাসীরা -- তাদের জন্য রয়েছে ভীষণ শাস্তি।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmccxcix{আর যদি আল্লাহ্ তাঁর বান্দাদের প্রতি রিযেক বাড়িয়ে দিতেন তাহলে তারা অবশ্যই দুনিয়াতে বিদ্রোহ করত, কিন্ত তিনি পাঠান যেমন তিনি চান তেমন পরিমাপ মতো। নিঃসন্দেহ তিনি তাঁর বান্দাদের প্রতি পূর্ণ ওয়াকিফহাল, সর্বদ্রষ্টা।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmccc{আর তিনিই সেইজন যিনি বৃষ্টি বর্ষণ করেন তারা হতাশ হয়ে পড়ার পরে, আর প্রসারিত করেন তাঁর করুণা। আর তিনিই মুরব্বী, পরম প্রশংসিত।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmccci{আর তাঁর নিদর্শনগুলোর মধ্যে হচ্ছে মহাকাশমন্ডলী ও পৃথিবীর সৃষ্টি, আর এ দুইয়ের মধ্যে জীবজন্তুর যে-সব তিনি ছড়িয়ে দিয়েছেন সেগুলি। আর যখন তিনি চান তখনই তাদের জমায়েৎ করণে তিনি পরম ক্ষমতাবান।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmcccii{আর বিপদ-আপদের যা তোমাদের আঘাত করে তা তো তোমার হাত যা অর্জন করেছে সে-জন্য, আর তিনি অনেকটা ক্ষমা করে দেন।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmccciii{আর তোমরা পৃথিবীতে এড়িয়ে যেতে পারবে না। আর আল্লাহ্‌কে বাদ দিয়ে তোমাদের জন্য কোনো অভিভাবক নেই আর সাহায্যকারীও নেই।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmmccciv{আর তাঁর নিদর্শনাবলীর মধ্যে হচ্ছে সমুদ্রে পাহাড়ের মতো জাহাজগুলো --\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmmcccv{তিনি যদি ইচ্ছা করেন তবে তিনি বাতাসকে নিশ্চল করে দিতে পারেন, ফলে তারা তার পিঠে নিশ্চল হয়ে পড়ে। এতে তো অবশ্যই নিদর্শনাবলী রয়েছে প্রত্যেক অধ্যবসায়ী কৃতজ্ঞের জন্য।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmmcccvi{অথবা তারা যা অর্জন করেছে সে-জন্য তিনি সেগুলো ভেঙেচুরে ফেলেন, আর তিনি অনেকের থেকে মাফও করে দেন, --\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmmcccvii{আর যেন যারা আমাদের নিদর্শনগুলো সন্বন্ধে তর্কবিতর্ক করে তারা জানতে পারে। তাদের জন্য কোনো আশ্রয়স্থল নেই।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmmcccviii{বস্তুতঃ তোমাদের যা-কিছু দেওয়া হয়েছে তা তো এই দুনিয়ার জীবনের ভোগবিলাস, আর যা আল্লাহ্‌র কাছে রয়েছে তা বেশী ভাল ও দীর্ঘস্থায়ী তাদের জন্য যারা ঈমান এনেছে এবং তাদের প্রভুর উপরে নির্ভর করে থাকে, --\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmmcccix{আর যারা এড়িয়ে চলে পাপাচারের বড়গুলো এবং অশ্লীল আচরণ, আর যারা যখন রেগে যায় তখন তারা ক্ষমা করে দেয়,\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmmcccx{আর যারা তাদের প্রভুর প্রতি সাড়া দেয়, এবং নামায কায়েম করে, আর তাদের কাজকর্ম হয় নিজেদের মধ্যে পরামর্শক্রমে, আর আমরা তাদের যা রিযেক দিয়েছি তা থেকে তারা খরচ করে থাকে,\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmmcccxi{আর যারা তাদের প্রতি যখন বিদ্রোহ আঘাত হানে তারা তখন আ‌ত্মরক্ষা করে।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmmcccxii{আর মন্দের প্রতিফল তার অনুরূপ মন্দ, কিন্ত যে কেউ ক্ষমা করে আর সদ্ভাব সৃষ্টি করে, তাহলে তার পুরস্কার রয়েছে আল্লাহ্‌র নিকটে। নিঃসন্দেহ অন্যায়কারীদের তিনি ভালবাসেন না।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmmcccxiii{তবে যে কেউ আ‌ত্মরক্ষা করে তার প্রতি অত্যাচার হবার পরে -- তবে তারাই, তাদের বিরুদ্ধে কোনো রাস্তা নেই।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmmcccxiv{পথ কেবল তাদেরই বিরুদ্ধে যারা লোকজনের উপরে অত্যাচার করে এবং দুনিয়াতে বিদ্রোহ করে ন্যায়সঙ্গত কারণ ব্যতিরেকে। এরাই -- এদেরই জন্য রয়েছে মর্মন্তুদ শাস্তি।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmmcccxv{আর যে কেউ অধ্যবসায় অবলন্বন করে ও ক্ষমা করে দেয়, তাহলে তাই তো হচ্ছে বীরত্বজনক কাজের মধ্যের অন্যতম।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmmcccxvi{আর আল্লাহ্ যাকে ভ্রান্তপথে যেতে দেন তার জন্যে তবে তাঁর বাহিরে কোনো অভিভাবক নেই। আর তুমি অন্যায়াচারীদের দেখতে পাবে -- যখন তারা শাস্তি প্রত্যক্ষ করবে -- তারা বলতে থাকবে -- ''ফিরে যাবার মতো কোনো পথ আছে কি?’’\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmmcccxvii{আর তুমি তাদের দেখতে পাবে এর সামনে আনা হয়েছে লাঞ্ছনার ফলে বিনত অবস্থায়, তাকিয়ে রয়েছে ভীত-সন্ত্রস্ত চোখে। আর যারা ঈমান এনেছে তারা বলবে -- ''নিঃসন্দেহ ক্ষতিগ্রস্ত তো তারা যারা কিয়ামতের দিনে তাদের নিজেদের ও তাদের পরিবারবর্গের ক্ষতি সাধন করেছে। এটি কি নয় যে অন্যাযাচারীরা দীর্ঘস্থায়ী শাস্তিতে রয়েছে?’’\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmmmcccxviii{আর তাদের সাহায্য করার কারণে আল্লাহ্‌কে বাদ দিয়ে তাদের জন্য অভিভাবকদের কেউ থাকবে না। আর যাকে আল্লাহ্ ভুলপথে চলতে দেন তার জন্য তবে কোনো গতি থাকবে না।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmmmcccxix{তোমাদের প্রভুর প্রতি সাড়া দাও সেইদিন আসার আগে যাকে আল্লাহ্‌র কাছ থেকে ফেরানো যাবে না। তোমাদের জন্য সেইদিন কোনো আশ্রয়স্থল থাকবে না, আর তোমাদের জন্য রইবে না কোনো ধরনের অস্বীকারকরণ।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmmmcccxx{কিন্ত তারা যদি বিমুখ হয় তবে আমরা তোমাকে তো তাদের উপরে একজন রক্ষাকারীরূপে পাঠাই নি। তোমার উপরে তো শুধু বাণী পৌঁছে দেওয়া। আর অবশ্য আমরা যখন মানুষকে আমাদের কাছ একে করুণা আস্বাদন করাই তখন সে এতে আনন্দ করে, কিন্ত তাদের হাত যা আগবাড়িয়েছে সেজন্য যদি কোনো মন্দ তাদের আঘাত করে, তবে মানুষ নিশ্চয়ই হয়ে যায় অকৃতজ্ঞ।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmmmcccxxi{আল্লাহরই হচ্ছে মহাকাশমন্ডলী ও পৃথিবীর সার্বভৌমত্ব। তিনি যা চান তাই সৃষ্টি করেন। তিনি যাকে চান কন্যাসন্তান দান করেন, আর যাকে ইচ্ছা করেন পুত্রসন্তান দেন,\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmmmcccxxii{অথবা তিনি তাদের জোড়ে দেন পুত্রসন্তান ও কন্যা-সন্তান, আবার যাকে চান তাকে তিনি বন্ধ্যা বানিয়ে দেন। নিঃসন্দেহ তিনি সর্বজ্ঞাতা, সর্বশক্তিমান।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmmmcccxxiii{আর কোনো মানবের জন্যে এটি নয় যে আল্লাহ্ তার সাথে কথা বলবেন ওহী ব্যতীত, অথবা পর্দার আড়ালে থেকে, অথবা তিনি কোনো বাণীবাহককে পাঠান ফলে সে তাঁর নির্দেশ অনুযায়ী যা তিনি চান তা প্রত্যাদেশ করে। নিঃসন্দেহ তিনি সর্বোন্নত, পরমজ্ঞানী।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmmmcccxxiv{আর এইভাবে আমরা তোমার কাছে আমাদের নির্দেশক্রমে প্রত্যাদেশ করেছি অনুপ্রাণিত গ্রন্থ। তুমি তো জানতে না গ্রন্থখানা কেমনতর, আর ধর্মবিশ্বাসও নয়, কিন্ত আমরা এটিকে বানিয়েছি এক আলোক, -- এর দ্বারা আমরা পথ দেখাচ্ছি আমাদের বান্দাদের যাদের আমরা ইচ্ছা করছি। আর তুমি তো নিশ্চয়ই পথ দেখাচ্ছ সঠিক পথের দিকে --\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmmmcccxxv{আল্লাহ্‌র পথ, যিনি তাঁর দখলে রেখেছেন মহাকাশমন্ডলীতে যা-কিছু আছে এবং যা-কিছু আছে পৃথিবীতে। এটি কি নয় যে সব ব্যাপারই আল্লাহ্‌র কাছে পেছে যাঁয়?\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmmmcccxxvi{\basmalahbn হা মীম!\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmcccxxvii{সুস্পষ্ট গ্রন্থখানা সন্বন্ধে ভেবে দেখো --\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmcccxxviii{নিঃসন্দেহ আমরা এটিকে এক আরবী ভাষণ করেছি যেন তোমরা বুঝতে পারো।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmcccxxix{আর নিঃসন্দেহ এটি রয়েছে আমাদের কাছে আদিগ্রন্থে, মহোচ্চ, জ্ঞানসমৃদ্ধ।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmcccxxx{কী! আমরা কি তোমাদের থেকে স্মারক গ্রন্থখানা সর্বতোভাবে সরিয়ে নেব যেহেতু তোমরা হচ্ছ এক সীমালংঘনকারী জাতি?\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmcccxxxi{আর নবীদের কতজনকে যে আমরা পূর্ববর্তীদের কাছে পাঠিয়েছিলাম?\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmcccxxxii{আর নবীদের এমন কেউ তাদের কাছে আসেন নি যাঁকে তারা বিদ্রূপ না করত।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmcccxxxiii{তারপর এদের চাইতে বলবীর্যে বেশী শক্তিশালীদেরও আমরা ধ্বংস করেছিলাম, আর পূর্ববর্তীদের দৃষ্টান্ত অতীতে রয়েছে।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmcccxxxiv{আর তুমি যদি তাদের জিজ্ঞাসা কর -- ''কে মহাকাশমন্ডলী ও পৃথিবী সৃষ্টি করেছেন?’’ -- তারা নিশ্চয়ই বলবে -- ''এগুলো সৃষ্টি করেছেন মহাশক্তিশালী সর্বজ্ঞাতা --\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmcccxxxv{যিনি তোমাদের জন্য পৃথিবীকে করেছেন এক খাটিয়া, আর এতে তৈরী করেছেন তোমাদের কারণে পথসমূহ, যাতে তোমরা পথের দিশা পেতে পার,\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmcccxxxvi{আর যিনি আকাশ থেকে পানি বর্ষণ করেন পরিমাপ মতো, তারপর তা দিয়ে আমরা প্রাণবন্ত করি মৃত দেশকে, এইভাবেই তোমাদের পুনরুত্থিত করা হবে।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmcccxxxvii{আর যিনি সমস্ত-কিছু জোড়ায়-জোড়ায় সৃষ্টি করেছেন, আর তোমাদের জন্য নৌকা-জাহাজ ও গবাদি-পশুর মধ্যে বানিয়েছেন সেগুলো যা তোমরা চড়ো, --\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmcccxxxviii{যেন তোমরা তাদের পিঠের উপরে মজবুত হয়ে বসতে পার, তারপর তোমাদের প্রভুর অনুগ্রহ স্মরণ করো যখন তোমরা তাদের উপরে বস, আর বলো -- ''সকল মহিমা তাঁর যিনি এদের আমাদের বশ করেছেন, অথচ আমরা এতে সমর্থ ছিলাম না,\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmcccxxxix{''আর অবশ্য আমরা আমাদের প্রভুর দিকেই তো ফিরে যাব।’’\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmcccxl{তথাপি তারা তাঁর বান্দাদের মধ্যে থেকে তাঁর সঙ্গে অংশীদার বানিয়েছে। নিঃসন্দেহ মানুষ তো স্পষ্টই অকৃতজ্ঞ।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmcccxli{তিনি যা সৃষ্টি করেছেন তার মধ্যে থেকে কি তিনি কন্যাদের গ্রহণ করেছেন আর তোমাদের জন্য নির্ধারিত করেছেন পুত্রদের?\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmcccxlii{আর যখন তাদের কাউকে সুসংবাদ দেওয়া হয় তাই দিয়ে যার দৃষ্টান্ত সে স্থাপন করে পরম করুণাময়ের প্রতি, তার চেহারা তখন কালো হয়ে যায় আর সে অতিমাত্রায় ক্ষুদ্ধ্ব হয়।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmcccxliii{তবে কি যে গহনাগাটিতে রক্ষিত আর যে বিতর্ককালে স্পষ্টবাদিতা বিহীন?\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmcccxliv{আর তারা ফিরিশতাদের, যারা খোদ পরম করুণাময়ের দাস, কন্যা বানায়। কী! এদের সৃষ্টি কি তারা দেখেছিল? তাদের সাক্ষ্য শীঘ্রই লিপিবদ্ধ করা হবে এবং তাদের জিজ্ঞাসাবাদ করা হবে।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmcccxlv{আর তারা বলে -- ''পরম করুণাময় যদি চাইতেন তবে আমরা এ-সবের উপাসনা করতাম না।’’ তাদের এ ব্যাপারে কোনো জ্ঞান নেই, তারা তো শুধু ঝুটা আন্দাজই করছে।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmcccxlvi{অথবা তাদের কি এর আগে আমরা কোনো গ্রন্থ দিয়েছি, ফলে তারা তাতে আকঁড়ে রয়েছে?\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmcccxlvii{না, তারা বলে -- ''আমরা তো আমাদের পিতৃপুরুষদের একটি সম্প্রদায়ভুক্ত পেয়েছি, আর আমরা নিঃসন্দেহে তাদেরই পদচিহ্নের উপরে পরিচালিত হয়েছি।’’\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmcccxlviii{আর এইভাবেই তোমার আগে কোনো জনপদে আমরা সতর্ককারীদের কাউকেও পাঠাই নি, যার বড়লোকেরা না বলেছে -- ''আমরা নিশ্চয়ই আমাদের পিতৃপুরুষদের একটি সম্প্রদায়ভুক্ত পেয়েছি, আর আমরা আলবৎ তাদেরই পদাংকের অনুসারী।’’\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmcccxlix{তিনি বলেছিলেন -- ''কী! যদিও আমি তোমাদের কাছে তার চাইতেও ভালো পথনির্দেশ নিয়ে এসেছি যার উপরে তোমরা তোমাদের পিতৃপুরুষদের পেয়েছিলে?’’ তারা বললে, ''তোমাদের যা দিয়ে পাঠানো হয়েছে আমরা তাতে নিশ্চয়ই অবিশ্বাসী।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmcccl{সুতরাং আমরা তাদের পরিণতি দিয়েছিলাম, অতএব চেয়ে দেখো -- কেমন হয়েছিল মিথ্যাচারীদের পরিণাম!\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmcccli{আর স্মরণ করো! ইব্রাহীম তাঁর পিতৃকে ও তাঁর স্বজাতিকে বললেন, ''তোমরা যার পূজা কর তা থেকে আমি অবশ্যই মুক্ত,\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmccclii{''তাঁকে ব্যতীত যিনি আমাকে আদিতে সৃষ্টি করেছেন, কাজেই নিশ্চয় তিনি শীঘ্রই আমাকে পথ দেখাবেন।’’\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmcccliii{আর তিনি এটিকে তাঁর বংশধরদের মধ্যে একটি চিরন্তন বাণী বানিয়েছিলেন, যেন তারা ফিরতে পারে।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmcccliv{বস্তুতঃ আমি এদের ও এদের পূর্বপুরুষদের উপভোগ করতে দিয়েছিলাম, যে পর্যন্ত না তাদের কাছে এসেছিল মহাসত্য ও একজন স্পষ্ট প্রতীয়মান রসূল।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmccclv{আর এখন যেহেতু তাদের কাছে মহাসত্য এসেই গেছে, তারা বলছে, ''এ এক জাদু, আর আমরা অবশ্যই এতে অবিশ্বাসী।’’\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmccclvi{আর তারা বলে, ''এই কুরআনখানা দুটো জনপদের মধ্যের কোনো এক প্রভাবশালী ব্যক্তির কাছে কেন অবতীর্ণ হল না?’’\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmmccclvii{তারাই কি তোমার প্রভুর করুণা ভাগ-বাঁটা করে? আমরাই এই দুনিয়ার জীবনে তাদের জীবিকা তাদের মধ্যে ভাগবাটোয়ারা করে দিই, এবং তাদের কাউকে অপরের উপরে মর্যাদায় উন্নত করি, যেন তাদের কেউ-কেউ অপরকে সেবারত করে নিতে পারে। আর তোমার প্রভুর করুণা বেশি ভাল তার চাইতে যা তারা জমা করে।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmmccclviii{আর মানুষ যদি একই সম্প্রদায়ের হয়ে না যেতো তাহলে যারা পরম করুণাময়কে অস্বীকার করে তাদের জন্য আমরা নিশ্চয় বানাতাম -- তাদের ঘরগুলোর জন্য রূপোর ছাদ ও সিড়ি যাঁ দিয়ে তারা ওঠে,\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmmccclix{আর তাদের ঘরবাড়ির জন্য দরজাগুলো ও পালংক যার উপরে তারা শয়ন করে,\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmmccclx{আর সোনাদানা। আর এ সমস্তই এই দুনিয়ার জীবনের ভোগসম্ভার বৈ তো নয়। আর পরকাল তোমার প্রভুর কাছে ধর্মভীরুদের জন্যেই।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmmccclxi{আর যে পরম করুণাময়ের স্মরণ থেকে বেখেয়াল হয় তার জন্য আমরা ধার্য করি একজন শয়তান, ফলে সে হয় তার জন্য একটি সহচর।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmmccclxii{আর নিঃসন্দেহ তারা তাদের পথ থেকে অবশ্যই ফিরিয়ে রাখে, অথচ তারা মনে করে যে তারা সৎপথে চালিত হচ্ছে, --\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmmccclxiii{যে পর্যন্ত না সে আমাদের কাছে আসে তখন সে বলবে -- ''হায় আফসোস! আমার মধ্যে ও তোমার মধ্যে যদি দূরত্ব হতো দুটি পূর্বাঞ্চলের! সুতরাং কত নিকৃষ্ট সহচর!’’\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmmccclxiv{আর -- ''যেহেতু তোমরা অন্যায়াচরণ করেছিলে তাই শাস্তিভোগের মধ্যে তোমরা অংশীদার হওয়া সত্ত্বেওে আজকের দিনে তোমাদের কোনো ফায়দা হবে না।’’\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmmccclxv{কি! তুমি কি তবে বধিরকে শোনাতে পারবে, অথবা অন্ধকে এবং যে স্পষ্ট বিভ্রান্তিতে রয়েছে তাকে পথ দেখাতে পারবে?\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmmccclxvi{কিন্ত আমরা যদি তোমাকে নিয়ে নিই, আমরা তবুও তাদের থেকে শেষ-পরিণতি আদায় করব,\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmmccclxvii{অথবা আমরা নিশ্চয় তোমাকে দেখিয়ে দেব যা আমরা তাদের ওয়াদা করেছিলাম, কেননা আমরা আলবৎ তাদের উপরে ক্ষমতাবান।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmmccclxviii{সেজন্য তোমার কাছে যা প্রত্যাদেশ দেওয়া হচ্ছে তাতে আঁকড়ে ধরো। নিঃসন্দেহ তুমি সরল-সঠিক পথের উপরে রয়েছো।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmmccclxix{আর এইটি নিশ্চয়ই তো একটি স্মরণীয় গ্রন্থ তোমার জন্য ও তোমার লোকদের জন্য, আর শীঘ্রই তোমাদের জিজ্ঞাসা করা হবে।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmmccclxx{আর তোমার আগে আমাদের রসূলদের মধ্যের যাঁদের আমরা পাঠিয়েছিলাম তাঁদের জিজ্ঞেস করো -- আমরা কি পরম করুণাময়কে বাদ দিয়ে উপাসনার জন্য উপাস্যদের দাঁড় করিয়েছিলাম?\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmmmccclxxi{আর আমরা নিশ্চয় মূসাকে আমাদের নির্দেশাবলী দিয়ে পাঠিয়ে দিয়েছিলাম ফির'আউন ও তার প্রধানদের কাছে, কাজেই তিনি বলেছিলেন -- ''আমি নিশ্চয় বিশ্বজগতের প্রভুর বাণীবাহক।’’\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmmmccclxxii{কিন্ত যখন তিনি আমাদের নির্দেশাবলী নিয়ে তাদের কাছে এলেন তখন দেখো, তারা এসব নিয়ে হাসিঠাট্টা করতে লাগল।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmmmccclxxiii{আর আমরা তাদের এমন কোনো নিদর্শন দেখাই নি যা ছিল না তার ভগিনী থেকে আরো বড়, আর আমরা তাদের পাকড়াও করেছিলাম শাস্তি দিয়ে যেন তারা ফিরে আসে।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmmmccclxxiv{আর তারা বলেছিল -- ''ওহে জাদুকর! তোমার প্রভুকে আমাদের জন্য ডাকো যেমন তিনি তোমার কাছে অংগীকার করেছিলেন, আমরা অবশ্যই তখন সৎপথাবলন্বী হব।’’\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmmmccclxxv{তারপর আমরা যখন তাদের থেকে শাস্তিটা সরিয়ে নিলাম তখন দেখো! তারা অংগীকার ভঙ্গ করে বসল।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmmmccclxxvi{আর ফির'আউন তার লোকদলের মধ্যে ঘোষণা করে বললে -- ''হে আমার স্বজাতি! মিশরের রাজ্য কি আমার নয়, আর এইসব নদনদী যা আমার নিচে দিয়ে প্রবাহিত হচ্ছে? তোমরা কি তবে দেখতে পাচ্ছ না?\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmmmccclxxvii{''বস্তুতঃ আমি বেশি ভাল এর চেয়ে যে স্বয়ং হীন-ঘৃণ্য, ও স্পষ্টবাদিতার যার ক্ষমতা নেই।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmmmccclxxviii{''তবে কেন সোনার কঙ্কন তার প্রতি ছোড়া হল না, অথবা তার সঙ্গে কেন ফিরিশতারা এল না সারিবদ্ধভাবে।’’\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmmmccclxxix{এইভাবে সে তার স্বজাতিকে ধাপ্পা দিয়েছিল, ফলে তারা তাকে মেনে চলল। নিঃসন্দেহ তারা ছিল সীমালংঘনকারী জাতি।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmmmccclxxx{অতএব তারা যখন আমাদের রাগিয়ে তুললো তখন আমরা তাদের থেকে শেষ-পরিণতি গ্রহণ করলাম, ফলে তাদের একসঙ্গে ডুবিয়ে দিয়েছিলাম।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mmmmccclxxxi{সুতরাং আমরা তাদের বানিয়ে দিয়েছিলাম এক অতীত ইতিহাস এবং পরবর্তীদের জন্য এক দৃষ্টান্ত।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mmmmccclxxxii{আর যখন মরিয়মের পুত্রের দৃষ্টান্ত ছোঁড়া হয় তখন দেখো, তোমার স্বজাতি তাতে শোরগোল তোলে।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mmmmccclxxxiii{আর তারা বলে -- ''আমাদের দেবদেবীরা অধিকতর ভাল, না সে? তারা তোমার কাছে এ কথা তোলে না তর্কবিতর্ক করার জন্যে ব্যতীত? বস্তুত তারা হচ্ছে বিবাদপ্রিয় জাতি।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mmmmccclxxxiv{তিনি একজন বান্দা বৈ তো নন যাঁর প্রতি আমরা অনুগ্রহ করেছি, এবং তাঁকে আমরা ইসরাঈলের বংশধরদের জন্য আদর্শস্বরূপ বানিয়েছিলাম।\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mmmmccclxxxv{আর আমরা যদি চাইতাম তবে নিশ্চয়ই আমরা তোমাদের মধ্যে ফিরিশ্‌তাদের নিয়োগ করতাম পৃথিবীতে প্রতিনিধি হবার জন্য!\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mmmmccclxxxvi{আর নিঃসন্দেহ এ-ই হচ্ছে ঘড়িধন্টা সন্বন্ধে নিশ্চিত জ্ঞান; সুতরাং এ-সন্বন্ধে তোমরা সন্দেহ করো না, আর আমাকে অনুসরণ করো। এটিই হচ্ছে সহজ-সঠিক পথ।\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mmmmccclxxxvii{আর শয়তান যেন তোমাদের কিছুতেই ফিরিয়ে না দেয়, নিঃসন্দেহ সে হচ্ছে তোমাদের জন্য প্রকাশ্য শত্রু।\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mmmmccclxxxviii{আর যখন ঈসা স্পষ্ট প্রমাণাবলী নিয়ে এলেন তখন তিনি বললেন -- ''আমি তোমাদের কাছে জ্ঞান নিয়ে এসেছি, আর তোমরা যে-সব বিষয়ে মতভেদ করছ তার কোনো কোনোটি তোমাদের জন্য সুস্পষ্ট করে দিতে, সুতরাং তোমরা আল্লাহ্‌কে ভয়-ভক্তি করো ও আমাকে মেনে চল।\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mmmmccclxxxix{''নিঃসন্দেহ আল্লাহ্ -- তিনি আমার প্রভু ও তোমাদেরও প্রভু, সেজন্য তাঁরই উপাসনা কর। এটিই সহজ-সঠিক পথ।’’\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mmmmcccxc{কিন্ত বিভিন্ন দল নিজেদের মধ্যে মতভেদ সৃষ্টি করল, কাজেই ধিক্ তাদের প্রতি যারা অন্যায়াচরণ করেছিল -- এক মর্মন্তুদ দিনের শাস্তির কারণে!\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mmmmcccxci{তারা কি চেয়ে রয়েছে শুধু ঘড়িঘান্টার জন্য যেন তাদের উপরে এটি এসে পড়ে আকস্মিকভাবে যখন তারা টেরও না পায়।\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mmmmcccxcii{সেইদিন বন্ধুরা -- তাদের কেউ-কেউ অপরের শত্রু হয়ে পড়বে, তবে ধর্মপরায়ণরা ব্যতীত।\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mmmmcccxciii{''হে আমার বান্দারা! আজকের দিনে তোমাদের জন্য কোনো ভয় নেই আর তোমরা দুঃখও করবে না, --\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mmmmcccxciv{''যারা আমাদের নির্দেশাবলীতে বিশ্বাস করেছিলে এবং মুসলিম হয়েছিলে, --\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mmmmcccxcv{''তোমরা বেহেশতে প্রবেশ করো -- তোমরা ও তোমাদের সঙ্গিনীরা তোমাদের আনন্দিত করা হবে।’’\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@mmmmcccxcvi{তাদের সামনে পরিবেশন করা হবে সোনার খাঞ্চা ও পানপাত্র, আর তাতে থাকবে যা অন্তর কামনা করে ও চোখ তৃপ্ত হয়, আর তোমরা তাতে স্থায়ীভাবে অবস্থান করবে।\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@mmmmcccxcvii{আর এইটিই সেই জান্নাত, তোমাদের এটি উত্তরাধিকার করতে দেওয়া হয়েছে তোমরা যা করতে তার জন্যে।\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@mmmmcccxcviii{তোমাদের জন্য সেখানে রয়েছে প্রচুর ফলমূল, তা থেকে তোমরা আহার করবে।\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@mmmmcccxcix{অপরাধীরা নিশ্চয় জাহান্নামের শাস্তির মধ্যে অবস্থান করবে,\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@mmmmcd{তাদের থেকে তা লাঘব করা হবে না, আর তাতে তারা হতাশ হয়ে পড়বে।\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@mmmmcdi{আর আমরা তাদের প্রতি অন্যায় করি নি, বরঞ্চ তারা নিজেরাই অন্যায় করেছিল।\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@mmmmcdii{আর তারা ডেকে বলবে -- ''হে মালিক! তোমার প্রভু আমাদের নিঃশেষ করে ফেলুন।’’ সে বলবে -- ''তোমরা নিশ্চয় অপেক্ষা করবে।’’\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@mmmmcdiii{''আমরা তো তোমাদের কাছে সত্য নিয়েই এসেছিলাম, কিন্ত তোমাদের অধিকাংশই সত্যের প্রতি বিমুখ ছিলে।’’\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@mmmmcdiv{অথবা তারা কি কোনো ব্যাপারে সিদ্ধান্ত করে ফেলেছে? কিন্ত বাস্তবে আমরাই সিদ্ধান্তকারী।\qt@no{(79)}}
\qt@newcmd\qurantrans@bn@mmmmcdv{অথবা তারা কি মনে করে যে আমরা তাদের লুকোনো বিষয় ও তাদের গোপন আলোচনা শুনি না? অবশ্যই, আর আমাদের দূতরা তাদের সঙ্গে থেকে লিখে চলেছে।\qt@no{(80)}}
\qt@newcmd\qurantrans@bn@mmmmcdvi{তুমি বলো -- ''যদি পরম করুণাময়ের কোনো সন্তান থাকত তবে আমিই হচ্ছি উপাসনাকারীদের মধ্যে অগ্রণী।’’\qt@no{(81)}}
\qt@newcmd\qurantrans@bn@mmmmcdvii{সকল মহিমা হোক মহাকাশমন্ডলী ও পৃথিবীর প্রভুর! তিনি আরশের প্রভু, তারা যা আরোপ করে তা থেকে তিনি বহু ঊর্ধ্বে।\qt@no{(82)}}
\qt@newcmd\qurantrans@bn@mmmmcdviii{সুতরাং তাদের ছেড়ে দাও আঁকুপাঁকু করতে ও ছেলেখেলা খেলতে যে পর্যন্ত না তারা তাদের দিনের মুখোমুখি হয় যেটি সন্বন্ধে তাদের ওয়াদা করা হয়েছিল।\qt@no{(83)}}
\qt@newcmd\qurantrans@bn@mmmmcdix{আর তিনিই সেইজন যিনি মহাকাশে উপাস্য আর দুনিয়াতেও উপাস্য। আর তিনিই পরমজ্ঞানী, সর্বজ্ঞাতা।\qt@no{(84)}}
\qt@newcmd\qurantrans@bn@mmmmcdx{আর পুণ্যময় তিনি যাঁর অধিকারে রয়েছে মহাকাশমন্ডলী ও পৃথিবীর সার্বভৌমত্ব আর যা-কিছু রয়েছে এ দুইয়ের মধ্যে, আর তাঁরই কাছে রয়েছে ঘড়িঘান্টার জ্ঞান, আর তাঁর কাছেই তোমাদের ফিরিয়ে নেওয়া হবে।\qt@no{(85)}}
\qt@newcmd\qurantrans@bn@mmmmcdxi{আর তাঁকে বাদ দিয়ে তারা যাদের ডাকে তাদের কোনো ক্ষমতা নেই সুপারিশ করার, তিনি ব্যতীত যিনি সত্যের সাথে সাক্ষ্য দেন, আর তারা জানে।\qt@no{(86)}}
\qt@newcmd\qurantrans@bn@mmmmcdxii{আর তুমি যদি তাদের জিজ্ঞাসা কর -- কে তাদের সৃষ্টি করেছেন, তারা নিশ্চয়ই বলবে -- ''আল্লাহ্‌’’। তাহলে কোথায়-কেমনে তারা ফিরে যাচ্ছে!\qt@no{(87)}}
\qt@newcmd\qurantrans@bn@mmmmcdxiii{আর তাঁর উক্তি -- ''হে আমার প্রভু! তারা তো এক জাতি যারা ঈমান আনছে না।’’\qt@no{(88)}}
\qt@newcmd\qurantrans@bn@mmmmcdxiv{''সুতরাং তুমি তাদের থেকে ফিরে যাও এবং বলো -- 'সালাম!’ তারপর শীঘ্রই তারা জানতে পারবে।’’\qt@no{(89)}}
\qt@newcmd\qurantrans@bn@mmmmcdxv{\basmalahbn হা মীম!\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmcdxvi{সুস্পষ্ট গ্রন্থের কথা ভেবে দেখো --\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmcdxvii{নিঃসন্দেহ আমরা এটি অবতারণ করেছি এক পবিত্র রাত্রিতে, নিঃসন্দেহ আমরা চির-সতর্ককারী।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmcdxviii{এতে প্রত্যেক বিষয় সুস্পষ্ট করা হয় জ্ঞানভান্ডার দিয়ে,\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmcdxix{আমাদের তরফ থেকে এক নির্দেশনামা। নিঃসন্দেহ আমরা সতত প্রেরণকারী, --\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmcdxx{তোমার প্রভু কাছ থেকে এ এক অনুগ্রহ। নিঃসন্দেহ তিনি, তিনিই সর্বশ্রোতা, সর্বজ্ঞাতা, --\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmcdxxi{মহাকাশমন্ডলী ও পৃথিবীর এবং এ দুইয়ের মধ্যে যা আছে তার প্রভু, -- যদি তোমরা সুনিশ্চিত হও।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmcdxxii{তিনি ব্যতীত অন্য উপাস্য নেই, তিনি জীবন দান করেন ও মৃত্যু ঘটান। তোমাদের প্রভু এবং পূর্বকালীন তোমাদের পিতৃপুরষদেরও প্রভু।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmcdxxiii{বস্তুতঃ তারা সন্দেহের মাঝে ছেলেখেলা খেলছে।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmcdxxiv{সুতরাং তুমি অপেক্ষা কর সেই দিনের যখন আকাশ নেমে আসবে প্রকাশ্য ধোঁয়া নিয়ে, --\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmcdxxv{মানুষকে জড়িয়ে ফেলে। এ এক মর্মন্তদ শাস্তি।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmcdxxvi{''আমাদের প্রভু! আমাদের থেকে শাস্তি সরিয়ে নাও, নিঃসন্দেহ আমরা বিশ্বাসী হচ্ছি।’’\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmcdxxvii{কেমন ক’রে তাদের জন্য উপদেশ-গ্রন্থ হবে, অথচ তাদের কাছে একজন প্রকাশ্য রসূল এসেই গেছেন?\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmcdxxviii{কিন্ত তারা তখন তাঁর থেকে ফিরে গিয়েছিল আর বলেছিল -- ''শেখানো, পাগল।’’\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmcdxxix{আমরা না হয় কিছুকালের জন্য শাস্তি স্থগিতই রাখব, কিন্ত তোমরা তো ফিরে যাবে।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmcdxxx{যেদিন আমরা পাকড়াবো বিরাট ধড়পাকড়ে, সেদিন আমরা নিশ্চয়ই শেষ-পরিণতি দেখাব।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmcdxxxi{আর তাদের আগে আমরা তো ফির'আউনের লোকদলকে পরীক্ষা করেইছিলাম, আর তাদের নিকট এক সম্মানিত রসূল এসেছিলেন,\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmcdxxxii{এই বলে -- ''আল্লাহ্‌র বান্দাদের আমার নিকট ফেরত দাও, নিঃসন্দেহ আমি তোমাদের প্রতি একজন বিশ্বস্ত বাণীবাহক,\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmcdxxxiii{''আর যেন তোমরা আল্লাহ্‌র উপরে উঠতে যেও না, নিঃসন্দেহ আমি তোমাদের কাছে নিয়ে এসেছি এক সুস্পষ্ট দলিল।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmcdxxxiv{''আর আমি আলবৎ আশ্রয় চাইছি আমার প্রভু ও তোমাদের প্রভুর কাছে, পাছে তোমরা আমাকে পাথর মে’রে মেরে ফেল।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmcdxxxv{''আর যদি তোমরা আমাতে বিশ্বাস না কর তাহলে আমাকে যেতে দাও।’’\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmcdxxxvi{তারপর তিনি তাঁর প্রভুকে ডেকে বললেন -- ''এরা হচ্ছে এক অপরাধী জাতি।’’\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmcdxxxvii{''তাহলে আমার বান্দাদের নিয়ে রাত্রিকালে রওয়ানা হও, তোমরা অবশ্যই পশ্চাদ্ধাবিত হবে,\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmcdxxxviii{আর সমুদ্রকে পেছনে রেখে যাও শান্ত অবস্থায়। নিঃসন্দেহ তারা হচ্ছে এমন এক বাহিনী যারা নিমজ্জিত হবে।’’\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmcdxxxix{তারা পেছনে ফেলে এসেছে কত যে বাগান ও ঝরনা,\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmcdxl{আর খেত-খামার ও মনোরম বাসস্থান,\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmcdxli{আর ভোগসামগ্রী যাতে তারা অবস্থান করত।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmcdxlii{এইভাবেই, আর এইসব আমরা অন্য এক জাতিকে উত্তরাধিকার করতে দিয়েছিলাম।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmcdxliii{তারপর মহাকাশ ও পৃথিবী তাদের জন্য কাঁদে নি, আর তারা অবকাশপ্রাপ্তও হয়নি।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmcdxliv{আর আমরা নিশ্চয়ই ইসরাইলের বংশধরদের উদ্ধার করে দিয়েছিলাম লাঞ্ছনা-দায়ক শাস্তি থেকে --\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmcdxlv{ফির'আউনের থেকে। নিঃসন্দেহ সে ছিল মহাউদ্ধত, সীমালংঘনকারীদের অন্তর্ভুক্ত।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmmcdxlvi{আর আমরা অবশ্য জেনে-শুনেই তাদের নির্বাচন করেছিলাম লোকজনের উপরে,\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmmcdxlvii{আর তাদের দিয়েছিলাম কতক নিদর্শনাবলী যার মধ্যে ছিল এক সুস্পষ্ট পরীক্ষা।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmmcdxlviii{নিঃসন্দেহ এরা তো বলেই থাকে --\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmmcdxlix{''এইটি আমাদের প্রথমবারের মৃত্যু বৈ তো নয়, কাজেই আমরা তো আর পুনরুত্থিত হবো না।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmmcdl{''তাহলে আমাদের পিতৃপুরুষদের নিয়ে এস, যদি তোমরা সত্যবাদী হও।’’\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmmcdli{এরাই কি ভাল, না তুব্বার লোকেরা, এবং যারা এদের পূর্ববর্তী ছিল? আমরা তাদের ধ্বংস করেছিলাম, কারণ তারা ছিল অপরাধী।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmmcdlii{আর আমরা মহাকাশমন্ডলী ও পৃথিবী আর এ দুইয়ের মধ্যে যা-কিছু আছে তা ছেলে-খেলার জন্য সৃষ্টি করি নি।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmmcdliii{আমরা এদুটিকে সত্যের জন্য ভিন্ন সৃষ্টি করি নি, কিন্ত তাদের অধিকাংশই জানে না।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmmcdliv{নিঃসন্দেহ ফয়সালার দিন হচ্ছে তাদের সবার নির্ধারিত দিনকাল,\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmmcdlv{যেদিন এক বন্ধু আরেক বন্ধুর থেকে কোনো প্রকারে লাভবান হবে না, আর তাদের সাহায্যও করা হবে না, --\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmmcdlvi{তারা ব্যতীত যাদের প্রতি আল্লাহ্ করুণা করেছেন। নিঃসন্দেহ তিনি, তিনিই তো মহাশক্তিশালী, অফুরন্ত ফলদাতা।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmmcdlvii{নিঃসন্দেহ যিক্কুম বৃক্ষ,\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmmcdlviii{পাপীদের খাদ্য, --\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmmcdlix{গলিত পিতলের মতো, -- পেটের ভেতরে,\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmmmcdlx{ফুটন্ত পানির টগবগ করার মতো।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxi{''তাকে পাকড়ো, তারপর তাকে টেনে নিয়ে যাও ভয়ংকর আগুনের মাঝখানে,\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxii{''তারপর তার মাথার উপরে ঢেলে দাও ফুটন্ত পানির শাস্তি,\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxiii{''আস্বাদ কর, তুমি তো ছিলে মহাশক্তিশালী, পরম সম্মানিত!’\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxiv{''আলবৎ এ হচ্ছে সেই যে-সন্বন্ধে তোমরা সন্দেহ করতে।’’\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxv{অবশ্য ধর্মভীরুরা থাকবে নিরাপদ স্থানে --\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxvi{বাগানের ও ঝরনার মধ্যে,\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxvii{তারা পরিধান করবে মিহি রেশম ও পুরু জরিদার পোশাক, পরস্পরের মুখোমুখি হয়ে।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxviii{এইভাবেই! আমরা তাদের জোড় মিলিয়ে দেব আয়তলোচন হূরদের সাথে।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxix{সেখানে তারা আনতে বলবে বিবিধ ফলফসল, নিরাপত্তার সাথে।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxx{তারা সেখানে মৃত্যু আস্বাদন করবে না প্রথমবারের মৃত্যু ব্যতীত; আর তিনি তাদের রক্ষা করবেন ভয়ংকর আগুনের শাস্তি থেকে --\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxxi{তোমার প্রভুর কাছ থেকে এ এক করুণা। এটি খোদ এক বিরাট সাফল্য।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxxii{সুতরাং আমরা নিশ্চয় এটিকে তোমার ভাষায় সহজ করে দিয়েছি যেন তারা মনোনিবেশ করতে পারে।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxxiii{সুতরাং তুমি প্রতীক্ষা কর, নিঃসন্দেহ তারাও অপেক্ষমাণ রয়েছে।\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxxiv{\basmalahbn হা মীম!\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxxv{এ গ্রন্থের অবতারণ আল্লাহ্‌র কাছ থেকে, যিনি মহাশক্তিশালী, পরমজ্ঞানী।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxxvi{নিঃসন্দেহ মহাকাশমন্ডলীতে ও পৃথিবীতে তো নিদর্শনাবলী রয়েছে মুমিনদের জন্য।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxxvii{আর তোমাদের সৃষ্টির মধ্যে এবং জীবজন্তুর মধ্যে যা তিনি ছড়িয়ে দিয়েছেন তাতে নিদর্শনাবলী রয়েছে সুনিশ্চিত লোকেদের জন্য,\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxxviii{আর রাত ও দিনের বিবর্তনে, আর আল্লাহ্ আকাশ থেকে জীবনোপকরণের মধ্যের যা-কিছু পাঠান ও যার দ্বারা পৃথিবীকে সঞ্জীবিত করেন তার মৃত্যুর পরে, আর বায়ু প্রবাহের পরিবর্তনে নিদর্শনাবলী রয়েছে সেই লোকদের জন্য যারা জ্ঞান-বুদ্ধি রাখে।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxxix{এইসব হচ্ছে আল্লাহ্‌র নির্দেশাবলী যা আমরা তোমার কাছে আবৃত্তি করছি যথাযথভাবে, সুতরাং আল্লাহ্ ও তাঁর নির্দেশাবলীর পরে কোন ধর্মোপদেশে তারা বিশ্বাস করবে?\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxxx{ধিক্ প্রত্যেক মিথ্যাবাদী পাপিষ্ঠের প্রতি।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxxxi{যে আল্লাহ্‌র বাণীসমূহ তার কাছে পঠিত হতে শোনে, তারপর সে অহংকারের মধ্যে অটল থাকে যেন সে সে-সব শোনেই নি। সেজন্য তাকে সুসংবাদ দাও মর্মন্তুদ শাস্তির।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxxxii{আর যখন সে আমাদের বাণীগুলো থেকে কোনো কিছু জানতে পারে সে সে-সবকে তামাশা ব’লে গ্রহণ করে। এরাই -- এদেরই জন্য রয়েছে লাঞ্ছনাদায়ক শাস্তি।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxxxiii{তাদের সামনের দিকে রয়েছে জাহান্নাম, আর তারা যা অর্জন করেছে তা তাদেরকে কোনোভাবেই লাভবান করবে না, আল্লাহ্‌কে বাদ দিয়ে যাদের তারা অভিভাবকরূপে গ্রহণ করেছিল তারাও না, আর তাদের জন্য রয়েছে কঠোর শাস্তি।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxxxiv{এই হচ্ছে পথনির্দেশ, আর যারা তাদের প্রভুর বাণীসমূহ প্রত্যাখ্যান করে তাদের জন্য রয়েছে কলুষতার দরুন মর্মন্তুদ শাস্তি।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxxxv{আল্লাহ্‌ই তিনি যিনি সমুদ্রকে তোমাদের অধীন করে দিয়েছেন যাতে তাঁর বিধান অনুযায়ী জাহাজগুলো তাতে চলতে পারে, আর যেন তোমরা তাঁর করুণাভান্ডার থেকে অনুসন্ধান করতে পার, আর তোমরা যেন কৃতজ্ঞতা প্রকাশ করতে পার।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxxxvi{আর তিনি তোমাদের অধীন করে দিয়েছেন মহাকাশমন্ডলীতে যা-কিছু আছে আর যা-কিছু রয়েছে পৃথিবীতে, -- এ সমস্ত তাঁর কাছ থেকে। নিঃসন্দেহ এতে তো নিদর্শনাবলী রয়েছে সেই লোকদের জন্য যারা চিন্তা করে।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxxxvii{যারা বিশ্বাস করে তাদের তুমি বলো যে তারা ক্ষমা করুক তাদের যারা আল্লাহ্‌র দিনগুলোর প্রত্যাশা করে না, এই জন্য যে তিনি লোকদের যেন প্রতিদান দিতে পারেন যা তারা অর্জন করছিল সেজন্য।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxxxviii{যে কেউ সৎকর্ম করে তা তবে তার নিজের জন্যে, আর যে মন্দ করে তা তবে তারই বিরুদ্ধে, তারপর তোমাদের প্রভুর তরফেই তোমাদের ফিরিয়ে আনা হবে।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxxxix{আর আমরা অবশ্য ইসরাইলের বংশধরদের দিয়েইছিলাম গ্রন্থ ও জ্ঞান-বিজ্ঞান ও পয়গন্বরত্ব, আর আমরা তাদের জীবিকা দিয়েছিলাম উত্তম জিনিস থেকে, আর তাদের শ্রেষ্ঠত্ব দিয়েছিলাম জনগণের উপরে।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmcdxc{আর আমরা তাদের দিয়েছিলাম বিষয়টি সন্বন্ধে সুস্পষ্ট প্রমাণাবলী, কিন্ত তাদের কাছে জ্ঞান আসার পরেও তারা মতভেদ করে নি নিজেদের মধ্যে ঈর্ষা বিদ্বেষ ব্যতীত। নিঃসন্দেহ তোমার প্রভু তাদের মধ্যে কিয়ামতের দিনে বিচার-মীমাংসা করে দেবেন যে বিষয়ে তারা মতভেদ করত সে-সন্বন্ধে।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmcdxci{এরপর আমরা তোমাকে ব্যাপারটিতে এক সংবিধানের উপরে প্রতিষ্ঠিত করেছি, কাজেই তুমি তা অনুসরণ করো, আর তুমি তাদের খেয়াল-খুশির অনুসরণ কর না যারা জানে না।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmcdxcii{নিঃসন্দেহ তারা আল্লাহ্‌র কাছ থেকে কোনো কিছুতেই তোমাকে আদৌ লাভবান করবে না। আর আলবৎ অন্যায়াচারীরা -- তাদের কেউ-কেউ অপর কারোর বন্ধু, আর আল্লাহ্ হচ্ছেন ধর্মভীরু-দের বান্ধব।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmcdxciii{এই হচ্ছে মানবজাতির জন্য দৃষ্টিদায়ক, আর পথপ্রদর্শক ও করুণা সেই লোকদের জন্য যারা সুনিশ্চিত।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmcdxciv{যারা দুস্কর্ম করেছে তারা কি ভাবে যে আমরা তাদের বানিয়ে দেব তাদের মতো যারা ঈমান এনেছে ও সৎকর্ম করছে -- তাদের জীবন ও তাদের মরণ কি এক সমান? কত নিকৃষ্ট যা তারা সিদ্ধান্ত করে!\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmcdxcv{আর আল্লাহ্ মহাকাশমন্ডলী ও পৃথিবী সৃষ্টি করেছেন সত্যের সাথে, আর যাতে প্রত্যেক সত্ত্বাকে প্রতিফল দেওয়া হয় সে যা অর্জন করেছে তাই দিয়ে, আর তাদের প্রতি অন্যায় করা হবে না।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmcdxcvi{তুমি কি তবে তাকে লক্ষ্য করেছ যে তার খেয়াল-খুশিকে তার উপাস্যরূপে গ্রহণ করেছে? আর আল্লাহ্ জেনে-শুনেই তাকে পথভ্রষ্ট হতে দিয়েছেন, আর তিনি মোহর মেরে দিয়েছেন তার শ্রবণেন্দ্রিয়ে ও তার হৃদয়ে, আর তার দর্শনেন্দ্রিয়ের উপরে তিনি বানিয়ে দিয়েছেন একটি পর্দা। কাজেই আল্লাহ্‌র পরে আর কে তাকে পথ দেখাবে? তবুও কি তোমরা মনোযোগ দেবে না?\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmcdxcvii{আর তারা বলে -- ''আমাদের দুনিয়ার জীবন ছাড়া এইটি আর কিছুই নয়, আমরা মরি আর আমরা বেঁচে থাকি, আর কিছুই আমাদের ধ্বংস করে না সময় ব্যতীত।’’ আর এ বিষয়ে তাদের কোনো জ্ঞান নেই। তারা অনুমান করছে বৈ তো নয়।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmcdxcviii{আর যখন তাদের কাছে আমাদের সুস্পষ্ট বাণীসমূহ পাঠ করা হয় তখন তাদের বিতর্ক আর কিছু নয় এ ভিন্ন যে তারা বলে, ''আমাদের পূর্বপুরুষদের নিয়ে এস যদি তোমরা সত্যবাদী হও।’’\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmcdxcix{তুমি বলো -- ''আল্লাহ্‌ই তোমাদের জীবন দান করেন, তারপর তোমাদের মৃত্যু ঘটান, তারপর তিনি তোমাদের একত্রিত করবেন কিয়ামতের দিনে -- তাতে কোনো সন্দেহ নেই, কিন্ত অধিকাংশ লোকেই জানে না।’’\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmd{আর আল্লাহ্‌রই হচ্ছে মহাকাশমন্ডলী ও পৃথিবীর সার্বভৌমত্ব। আর যেদিন ঘড়িঘন্টা দাঁড়িয়ে যাবে, সেইদিন বাতিল- আখ্যাদানকারীরা ক্ষতিগ্রস্ত হবে।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmdi{আর তুমি দেখতে পাবে প্রত্যেক সম্প্রদায় নতজানু হতে, প্রত্যেক সম্প্রদায়কে ডাকা হবে তার কিতাবের প্রতি। ''আজকের দিনে তোমাদের প্রতিদান দেওয়া হচ্ছে তোমরা যা করতে তাই দিয়ে।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmdii{''এইটি আমাদের কিতাব যা তোমাদের বিরুদ্ধে যথাযথভাবে বর্ণনা করে। নিঃসন্দেহ আমরা লিপিবদ্ধ করে যাচ্ছি যা তোমরা করে চলেছ।’’\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmdiii{সুতরাং যারা ঈমান এনেছে ও সৎকর্ম করছে তাদের প্রভু তাদের প্রবেশ করাবেন তাঁর করুণায়। এইটিই হচ্ছে প্রকাশ্য সাফল্য।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmdiv{পক্ষান্তরে যারা অবিশ্বাস পোষণ করে -- ''এমনটা কি নয় যে আমার বাণীসমূহ তোমাদের কাছে পঠিত হয়েছে? কিন্ত তোমরা গর্ববোধ করছিলে, আর তোমরা ছিলে এক অপরাধী সম্প্রদায়।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmmdv{''আর যখন বলা হয় -- 'নিঃসন্দেহ আল্লাহ্‌র ওয়াদা সত্য, আর ঘড়িঘন্টা -- এতে কোনো সন্দেহ নেই’, তোমরা তখন বলে থাক -- 'আমরা জানি না কী সেই ঘড়ি, আমরা বিবেচনা করি কাল্পনিক বৈ তো নয়, আর আমরা আদে সুনিশ্চিত নই’ ।’’\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmmdvi{আর তারা যা করেছিল তার দুস্কর্মগুলো তাদের নিকট প্রকাশ হয়ে পড়বে, আর যা নিয়ে তারা ঠাট্টা-বিদ্রূপ করত তা তাদের পরিবেষ্টন করবে।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmmdvii{আর বলা হবে -- ''আজ আমরা তোমাদের ভুলে থাকব যেমন তোমরা তোমাদের এই দিনটির সাক্ষাৎ পাওয়াকে ভুলে থাকতে, ফলত তোমাদের আশ্রয়স্থল হচ্ছে আগুন, আর তোমাদের জন্য সাহায্যকারীদের কেউ থাকবে না।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmmdviii{''এইটিই! কেননা তোমরা আল্লাহ্‌র বাণীসমূহকে তামাশা বলে গণ্য করেছিলে, ফলস্বরূপে এই দুনিয়ার জীবন তোমাদের প্রতারিত করেছিল।’’ সেজন্য আজকের দিনটায় সেখান থেকে তাদের বের করা হবে না, আর তাদের প্রতি সদয়তাও দেখানো হবে না।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmmdix{অতএব আল্লাহ্‌রই জন্য সমস্ত প্রশংসা, তিনি মহাকাশমন্ডলীর প্রভু ও পৃথিবীরও প্রভু, -- সমস্ত বিশ্বজগতের প্রভু।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmmdx{আর তাঁরই হচ্ছে সমস্ত গৌরব-গরিমা মহাকাশমন্ডলীতে ও পৃথিবীতে, আর তিনি হচ্ছেন মহাশক্তিশালী, পরমজ্ঞানী।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmmdxi{\basmalahbn হা মীম!\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmdxii{এ গ্রন্থের অবতারণ আল্লাহ্‌র কাছ থেকে, যিনি মহাশক্তিশালী, পরমজ্ঞানী।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmdxiii{আমরা মহাকাশমন্ডলী ও পৃথিবী এবং এ দুইয়ের মধ্যে যা-কিছু রয়েছে তা সত্যের সাথে এবং একটি নির্দিষ্ট কালের জন্য ছাড়া সৃষ্টি করি নি। কিন্তু যারা অবিশ্বাস পোষণ করে তারা ফিরে দাঁড়ায় তা থেকে যে-সন্বন্ধে তাদের সতর্ক করা হয়।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmdxiv{তুমি বলো -- ''আল্লাহ্‌কে বাদ দিয়ে যাদের তোমরা ডাক তাদের কথা কি তোমরা ভেবে দেখেছ? পৃথিবীর কোন জিনিস তারা সৃষ্টি করেছে আমাকে দেখাও তো? অথবা তাদের কি কোনো অংশ আছে মহাকাশমন্ডলীতে? আমার কাছে এর আগের কোনো গ্রন্থ অথবা জ্ঞানের কোনো প্রামাণ্য চিহ নিয়ে এস, যদি তোমরা সত্যবাদী হও।’’\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmdxv{আর কে বেশি বিপথে গেছে তাদের চাইতে যারা আল্লাহ্‌কে বাদ দিয়ে তাকে ডাকে যে তাদের প্রতি সাড়া দেয় না কিয়ামতের দিন পর্যন্ত, আর তারা এদের আহ্বান সন্বন্ধেই বেখেয়াল থাকে?\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmdxvi{আর যখন মানবগোষ্ঠীকে সমবেত করা হবে তখন তারা তাদের শত্রু হয়ে দাঁড়াবে, আর তাদের যে উপাসনা করা হয়েছিল সে কথাতেই তারা অস্বীকারকারী হবে।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmdxvii{আর যখন আমাদের সুস্পষ্ট বাণীসমূহ তাদের কাছে পঠিত হয় তখন যারা অবিশ্বাস করে তারা সত্য সন্বন্ধে বলে, যখন তা তাদের কাছে আসে -- ''এতো স্পষ্ট জাদু।’’\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmdxviii{অথবা তারা বলে -- ''সে এটি জাল করেছে।’’ তুমি বলো -- ''আমি যদি এটি জাল করে থাকি তাহলে তোমরা তো আল্লাহ্‌র তরফ থেকে কিছুই আমার জন্য আয়ত্ত কর না। তিনি ভাল জানেন তোমরা এ বিষয়ে যা বলাবলি কর। তিনিই এ ব্যাপারে আমার মধ্যে ও তোমাদের মধ্যে সাক্ষী হিসেবে যথেষ্ট। আর তিনি পরিত্রাণকারী, অফুরন্ত ফলদাতা।’’\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmdxix{তুমি বলো -- ''আমি রসূলগণের মধ্যে প্রারম্ভিক নই, আর আমি ধারণা করতে পারি না আমার প্রতি কি করা হবে এবং তোমাদের সম্পর্কেও নয়। আমি শুধু অনুসরণ করি আমার কাছে যা প্রত্যাদিষ্ট হয়েছে তা বৈ তো নয়, আর আমি একজন সুস্পষ্ট সতর্ককারী ব্যতীত আর কিছুই নই।’’\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmdxx{তুমি বলে যাও -- ''তোমরা কি ভেবে দেখেছ -- এটি যদি আল্লাহ্‌র কাছ থেকে হয়ে থাকে আর তোমরা এতে অবিশ্বাস কর, অথচ ইসরাইলের বংশধরদের থেকে একজন সাক্ষ্যদাতা তাঁর অনুরূপ সন্বন্ধে সাক্ষ্য দেন, ফলে তিনি বিশ্বাস করেন, কিন্তু তোমরা গর্ববোধ কর? নিঃসন্দেহ আল্লাহ্ অন্যায়াচারী জাতিকে সৎপথে চালান না।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmdxxi{আর যারা অবিশ্বাস পোষণ করে তারা তাদের সন্বন্ধে বলে যারা ঈমান এনেছে, ''এটি যদি ভাল হতো তাহলে তারা এর প্রতি আমাদের পাঠ শেখাত না।’’ আর যেহেতু তারা এর দ্বারা সৎপথের দিশা পায় নি তাই তারা তো বলবেই, ''এটি এক পুরনো মিথ্যা।’’\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmdxxii{আর এর আগে ছিল মুসার গ্রন্থ -- অগ্রদূত ও করুণাস্বরূপ। আর এখানা হচ্ছে সত্যসমর্থনকারী কিতাব, আরবী ভাষায়, যেন এটি সতর্ক করতে পারে তাদের যারা অন্যায়াচরণ করছে, এবং সৎকর্মশীলদের জন্য হতে পারে সুসংবাদ স্বরূপ।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmdxxiii{নিঃসন্দেহ যারা বলে -- ''আমাদের প্রভু হচ্ছেন আল্লাহ্‌’’, তারপর কায়েম থাকে, তাদের উপর তবে কোনো ভয় নেই, আর তারা নিজেরা অনুতাপও করবে না।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmdxxiv{এরাই হচ্ছে বেহেশতের বাসিন্দা, তাতেই তারা স্থায়ীভাবে থাকবে, -- তারা যা করে চলত সেজন্য এক প্রতিদান।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmdxxv{আর আমরা মানুষকে তার মাতাপিতার সম্পর্কে ভাল ব্যবহারের নির্দেশ দিয়েছি। তার মাতা কষ্ট করে তাকে গর্ভে ধারণ করেছিলেন আর কষ্ট করে তাকে জন্ম দিয়েছিলেন। আর তাকে গর্ভে ধারণ করতে ও তার লালন-পালনে লেগেছিল ত্রিশটি মাস। তারপর সে যখন তার যৌবনে পৌঁছে এবং চল্লিশ বছরে পৌঁছে যায় তখন সে বলে -- ''আমার প্রভু! তুমি আমাকে জাগরিত করো যেন আমি কৃতজ্ঞতা জানাতে পারি তোমার সেই অনুগ্রহের জন্য যা তুমি অর্পণ করেছ আমার উপরে ও আমার মাতাপিতার উপরে, আর যেন আমি সৎকর্ম করতে পারি যা তোমাকে খুশি করে, আর আমার প্রতি কল্যাণ করো আমার সন্তানসন্ততিদের সম্পর্কে। আমি অবশ্যই তোমার দিকে ফিরেছি, আর আমি নিশ্চয় মুসলিমদের মধ্যেকার।’’\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmdxxvi{এরাই তারা যাদের থেকে আমরা গ্রহণ করে থাকি তারা যা করেছিল তার শ্রেষ্ঠ এবং উপেক্ষা করি তাদের মন্দ কার্যাবলী -- জান্নাতের বাসিন্দাদের অন্তর্ভুক্ত। প্রামাণিক প্রতি‌শ্রুতি যা তাদের কাছে ওয়াদা করা হত।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmdxxvii{আর যে তার মাতাপিতাকে বলে -- ''ধুত্তোর তোমাদের জন্য! তোমরা কি আমাকে ভয় দেখাচ্ছ যে আমাকে বের করা হবে, অথচ আমার আগে বহু মানববংশ গত হয়েই গেছে? আর তারা দুজনে আল্লাহ্‌র সাহায্য কামনা করবে -- ''ধিক্ তোমার জন্য! ঈমান আনো, আল্লাহ্‌র ওয়াদা অবশ্যই সত্য।’’ কিন্তু সে বলে -- ''এতো অতীতকালের উপকথা ছাড়া আর কিছুই নয়।’’\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmdxxviii{এরাই তারা যাদের উপরে উক্তি সত্য প্রতিপন্ন হয়েছে -- জিন ও মানুষের মধ্যের সেইসব সম্প্রদায়দের ক্ষেত্রে যারা তাদের আগে গত হয়ে গেছে। নিঃসন্দেহ তারাই তো ক্ষতিগ্রস্ত।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmdxxix{আর প্রত্যেকেরই জন্য রয়েছে তারা যা কাজ করেছে তার থেকে বহু স্তর, আর যেন তাদের ক্রিয়াকলাপের জন্য তিনি তাদের প্রতিফল দিতে পারেন, আর তাদের আদৌ অন্যায় করা হবে না।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmdxxx{আর সেই দিন যারা অবিশ্বাস পোষণ করেছিল তাদের সমাগত করা হবে আগুনের নিকটে, ''তোমরা তো তোমাদের ভাল জিনিসসব তোমাদের দুনিয়ার জীবনেই যেতে দিয়েছিলে, আর তোমরা সেখানে ভোগবিলাসই চেয়েছিলে, সুতরাং আজ তোমাদের প্রতিদান দেওয়া হবে এক লাঞ্ছনাকর শাস্তি, যেহেতু তোমরা দুনিয়াতে যথার্থ কারণ ব্যতীত বড়মানষি করতে, আর যেহেতু তোমরা সীমালংঘন করতে।’’\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmdxxxi{আর তুমি স্মরণ কর 'আদ-দের ভাইকে। দেখো! তিনি তাঁর স্বজাতিকে সতর্ক করেছিলেন বালুর পাহাড় অঞ্চলে, আর সতর্ককারীরা তো তাঁর আগে ও তাঁর পরে গত হয়েই ছিলেন, এই বলে -- ''আল্লাহ্ ছাড়া অন্যের উপাসনা করো না, আমি নিঃসন্দেহ তোমাদের উপরে এক ভয়ংকর দিনের শাস্তির আশংকা করছি।’’\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmdxxxii{তারা বললে -- ''তুমি কি আমাদের কাছে এসেছ আমাদের দেবদেবীর থেকে আমাদের ফিরিয়ে রাখতে? তাহলে আমাদের কাছে নিয়ে এস তো যা দিয়ে তুমি আমাদের ভয় দেখাচ্ছ, -- যদি তুমি সত্যবাদীদের অন্তর্ভুক্ত হয়ে থাক।’’\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmdxxxiii{তিনি বলেছিলেন -- ''জ্ঞান তো আল্লাহ্‌রই কাছে রয়েছে, আর আমি তোমাদের কাছে পৌঁছে দিচ্ছি যা দিয়ে আমাকে পাঠানো হয়েছে, কিন্তু আমি তোমাদের দেখতে পাচ্ছি মূর্খামি করছ এমন এক লোকদল।’’\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmdxxxiv{অতঃপর যখন তারা তা দেখতে পেল -- এক ঘন-মেঘ তাদের উপত্যকাগুলোর নিকটবর্তী হচ্ছে, তখন তারা বললে -- ''এ এক ঘন কালো মেঘ যা আমাদের জন্য বৃষ্টি বর্ষণ করবে।’’ না, এ হচ্ছে যা তোমরা ত্বরান্বিত করতে চেয়েছিল, -- এ এক ঝড়-ঝা যাতে রয়েছে মর্মন্তুদ শাস্তি।’’\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmdxxxv{এ তার প্রভুর নির্দেশে সব-কিছুই ধ্বংস করে দিয়েছিল, ফলে অচিরেই তাদের ঘরবাড়ি ছাড়া আর কিছু দেখা যাচ্ছিল না। এইভাবেই আমরা প্রতিদান দিই অপরাধী লোকদের।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmdxxxvi{আর আমরা তো তাদের যেমন প্রতিষ্ঠা করে দিয়েছিলাম তেমনভাবে তোমাদের আমরা প্রতিষ্ঠিত করি নি, আর আমরা তাদের দিয়েছিলাম শ্রবণেন্দ্রিয় ও দর্শনেন্দ্রিয় ও অন্তঃকরণ। কিন্তু তাদের শ্রবণেন্দ্রিয় তাদের কোনোভাবেই লাভবান করে নি, আর তাদের দর্শনেন্দ্রিয়ও না আর তাদের অন্তঃকরণও নয়, যেহেতু তারা আল্লাহ্‌র বাণীসমূহ নিয়ে বাজে বিতর্ক করত, কাজেই যা নিয়ে তারা ঠাট্টা- বিদ্রপ করত তাই তাদের পরিবেষ্টন করেছিল।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmdxxxvii{আর আমরা নিশ্চয় ধ্বংস করে দিয়েছিলাম জনপদগুলোকে যারা তোমাদের আশপাশে ছিল, আর আমার নির্দেশাবলী বারবার বিবৃত করেছি যাতে তারা ফিরে আসে।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmdxxxviii{তাহলে আল্লাহ্‌কে বাদ দিয়ে যাদের তারা উপাস্যরূপে গ্রহণ করেছিল সান্নিধ্য লাভের জন্য তারা কেন তাদের সাহায্য করল না? বস্তুতঃ তারা তাদের থেকে অন্তর্ধান করল, আর এটিই ছিল তাদের মিথ্যা এবং যা তারা উদ্ভাবন করত।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmdxxxix{আর স্মরণ করো! আমরা তোমার কাছে জিনদের একদলকে ঝুঁকিয়ে দিয়েছিলাম যারা কুরআন শুনেছিল, তারপর তারা যখন এর সামনে হাজির হল, তারা বললে -- ''চুপ করো।’’ তারপর যখন তা শেষ করা হল, তারা তাদের স্বজাতির কাছে ফিরে গেল সতর্ককারীরূপে।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmdxl{তারা বললে -- ''হে আমার স্বজাতি! নিঃসন্দেহ আমরা এমন এক গ্রন্থ শুনেছি যা মূসার পরে অবতীর্ণ হয়েছে, সমর্থন করছে এর আগে যেটি রয়েছে, আর পরিচালনা করছে সত্যের দিকে ও সহজ-সঠিক পন্থার দিকে।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmdxli{''হে আমাদের স্বজাতি! সাড়া দাও আল্লাহ্‌র দিকে আহবায়কের প্রতি, আর তাঁর প্রতি ঈমান আনো, তিনি তোমাদের অপরাধগুলো থেকে তোমাদের পরিত্রাণ করবেন, আর তোমাদের রক্ষা করবেন মর্মন্তুদ শাস্তি থেকে।’’\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmmdxlii{আর যে আল্লাহ্‌র আহবায়কের প্রতি সাড়া দেয় না, সে তবে পৃথিবীতে কিছুতেই এড়িয়ে যাবার পাত্র নয়, আর তাঁকে বাদ দিয়ে তার জন্য কোনো বন্ধুবান্ধবও থাকবে না। এরাই সুস্পষ্ট বিভ্রান্তিতে রয়েছে।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmmdxliii{তারা কি সত্যিই লক্ষ্য করে নি যে আল্লাহ্‌ই তিনি যিনি মহাকাশমন্ডলী ও পৃথিবী সৃষ্টি করেছেন, এবং যিনি এ-সবের সৃষ্টিতে কোনো ক্লান্তি বোধ করেন নি, তিনিই তো মৃতকে জীবিত করতেও সক্ষম? হ্যাঁ, তিনি নিশ্চয়ই সব-কিছুর উপরে সর্বশক্তিমান।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmmdxliv{আর যারা অবিশ্বাস করেছে তাদের সেইদিন আগুনের নিকটে উপস্থিত করা হবে। ''এইটি কি চরম-সত্য নয়?’’ তারা বলবে -- ''হাঁ, আমাদের প্রভুর কসম?’’ তিনি বলবেন -- ''তাহলে শাস্তিটা আস্বাদন কর, যেহেতু তোমরা অবিশ্বাস পোষণ করতে।’’\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmmdxlv{অতএব তুমি ধৈর্যধারণ করো যেমন ধৈর্যধারণ করেছিলেন রসূলগণের মধ্যে যাঁরা ছিলেন দৃঢ়-প্রতিজ্ঞ, আর তাদের জন্য তাড়াহুড়ো করো না। তাদের যা ওয়াদা করা হয়েছিল তা যেদিন তারা দেখবে সেদিন তার যেন দিনমানের এক ঘড়ির বেশি অবস্থান করে নি। যথেষ্ট পৌঁছানো হয়েছে! সুতরাং সীমালংঘনকারী লোকদল ব্যতীত আর কাকেই বা বিধ্বংস করা হবে?\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmmdxlvi{\basmalahbn যারা অবিশ্বাস পোষণ করে এবং আল্লাহ্‌র পথ থেকে ফিরিয়ে রাখে, তিনি তাদের ক্রিয়াকলাপ ব্যর্থ করে দেবেন।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmdxlvii{আর যারা ঈমান এনেছে ও সৎকর্ম করছে, আর বিশ্বাস করছে তাতে যা মুহাম্মদের কাছে অবতীর্ণ হয়েছে -- আর সেটিই হচ্ছে তাদের প্রভুর কাছ থেকে আগত মহাসত্য -- তিনি তাদের মন্দ কার্যাবলী তাদের থেকে দূর করে দেবেন, আর ভাল করে দেবেন তাদের অবস্থা।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmdxlviii{এইটিই, কেননা নিঃসন্দেহ যারা অবিশ্বাস পোষণ করে তারা মিথ্যার অনুসরণ করে, আর যেহেতু যারা ঈমান এনেছে তারা তাদের প্রভুর কাছ থেকে আসা সত্যের অনুগমন করে। এইভাবে আল্লাহ্ লোকেদের জন্য তাদের দৃষ্টান্তগুলো স্থাপন করেন।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmdxlix{সেজন্য যারা অবিশ্বাস পোষণ করে তাদের সাথে যখন তোমরা মোকাবিলা কর তখন গর্দান মারা, পরিশেষে যখন তোমরা তাদের পরাজিত করবে তখন মজবুত করে বাঁধবে, তখন এরপরে হয় সদয়ভাবে মুক্তিদান, না হয় মুক্তিপণ গ্রহণ -- যতক্ষণ না যুদ্ধ তার অস্ত্রভার নামিয়ে দেয়, এমনটাই। আর আল্লাহ্ যদি চাইতেন তাহলে তিনিই তাদের থেকে প্রতিশোধ গ্রহণ করতে পারতেন, কিন্ত এইজন্য যে তোমাদের কারোকে যেন অপরের দ্বারা তিনি সুনিয়ন্ত্রিত করতে পারেন। আর যাদের আল্লাহ্‌র পথে শহীদ করা হয় তাদের ক্রিয়াকর্মকে তিনি কখনো লক্ষ্যহারা হতে দেবেন না।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmdl{তিনি তাদের পথপ্রদর্শন করবেন এবং তাদের অবস্থা ভালো করবেন।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmdli{আর তাদের প্রবেশ করাবেন স্বর্গোদ্যানসমূহে, তিনি তাদের কাছে এটি পরিচয় করিয়ে দিয়েছেন।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmdlii{ওহে যারা ঈমান এনেছ! যদি তোমরা আল্লাহকে সাহায্য কর তবে তিনিও তোমাদের সাহায্য করবেন, আর তিনি তোমাদের পদক্ষেপ সুদৃঢ় করবেন।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmdliii{আর যারা অবিশ্বাস পোষণ করে তাদের জন্য দুর্ভোগ রয়েছে, আর তাদের ক্রিয়া-কলাপকে তিনি ব্যর্থ করে দেবেন।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmdliv{এমনটাই, কেননা আল্লাহ্ যা অবতারণ করেছেন তারা তা বিতৃষ্ণার সাথে প্রত্যাখ্যান করে, কাজেই তিনি তাদের ক্রিয়াকলাপ নিষ্ফল করে দিয়েছেন।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmdlv{তারা কি তবে পৃথিবীতে পরিভ্রমণ করে নি? তাহলে তারা দেখতে পেত কেমন হয়েছিল তাদের পরিণাম যারা এদের আগে ছিল। আল্লাহ্ তাদের ঘায়েল করেছিলেন, আর অবিশ্বাসীদের জন্য রয়েছে এর অনুরূপ।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmdlvi{এমনটাই, কেননা যারা ঈমান এনেছে তাদের অভিভাবক নিশ্চয়ই আল্লাহ্‌, আর অবিশ্বাসীদের ক্ষেত্রে তো -- তাদের জন্য কোনো মুরব্বী নেই।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmdlvii{নিঃসন্দেহ যারা ঈমান এনেছে ও সৎকাজে করছে আল্লাহ্ তাদের প্রবেশ করাবেন স্বর্গোউদ্যানসমূহে যাদের নিচে দিয়ে বয়ে চলছে ঝরনারাজি। আর যারা অবিশ্বাস পোষণ করে তারা ভোগ-বিলাস করে ও খায়দায় যেমন জন্তু জানোয়াররা খেয়ে থাকে, আর আগুনই তাদের আবাসস্থল।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmdlviii{আর জনপদগুলোর কতটা যে -- যা ছিল আরো বেশি শক্তিশালী তোমার জনবসতির চাইতে যেটি তোমাকে বহিস্কার করেছে -- আমরা তাদের ধ্বংস করে দিয়েছিলাম, আর তাদের জন্য কোনো সাহায্যকারী ছিল না।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmdlix{যে তার প্রভুর কাছ থেকে এক স্পষ্ট প্রমাণের উপরে রয়েছে সে কি তবে তার মতো যার কাছে তার মন্দ কার্যকলাপকে চিত্তাকর্ষক করা হয়েছে? ফলে তারা নিজেদের কামনা-বাসনারই অনুসরণ করে।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmdlx{ধর্মভীরুদের জন্য যে জান্নাতের ওয়াদা করা হয়েছে তার উপমা হচ্ছে -- তাতে রয়েছে ঝরনারাজি এমন পানির যা পরিবর্তিত হয় না, আর দুধের নদীসমূহ যার স্বাদ বদলায় না, আর সুরার স্রোত যা পানকারীদের জন্য সুস্বাদু, আর ছাঁকা মধুর নদীগুলো। আর তাদের জন্য সে-সবে রয়েছে সব রকমের ফলফসল, আর তাদের প্রভুর কাছ থেকে রয়েছে পরিত্রাণ। তার মতো যে আগুনের মধ্যে অবস্থানকারী, অথবা যাদের পান করানো হবে ফুটন্ত পানি, ফলে তাদের নাড়িভুঁড়ি তা ছিড়ে ফেলবে?\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmdlxi{আর তাদের মধ্যে কিছু লোক আছে যারা তোমার কথা শোনে, তারপর তারা যখন তোমার কাছ থেকে বেরিয়ে যায় তখন যাদের জ্ঞান দেওয়া হয়েছে তাদের বলে, ''সে এইমাত্র কী বললে!’’ এরাই তারা যাদের হৃদয়ের উপরে আল্লাহ্ মোহর মেরে দিয়েছেন, আর তারা নিজেদের খেয়ালখুশিরই অনুসরণ করে।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmdlxii{আর যারা সৎপথে চলে, তিনি তাদের জন্য পথ প্রদর্শন করা বাড়িয়ে দেন, আর তাদের প্রদান করেন তাদের ধর্মনিষ্ঠা।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmdlxiii{তারা কি তবে তাকিয়ে রয়েছে শুধু ঘড়ির জন্য যাতে এটি তাদের উপরে এসে পড়ে অতর্কিতভাবে? তবে তো এর লক্ষণগুলো এসেই পড়েছে। সুতরাং কেমন হবে তাদের ব্যাপার যখন তাদের স্মরণ করিয়ে দেওয়া হবে?\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmdlxiv{অতএব তুমি জেনে রাখ যে আল্লাহ্ ব্যতীত অন্য উপাস্য নেই, আর তোমার ভুল-ভ্রান্তির জন্যে তুমি পরিত্রাণ খোঁজো, আর মুমিন পুরুষ ও মুমিন নারীদের জন্যেও। আর আল্লাহ্ জানেন তোমাদের গতিবিধি এবং তোমাদের অবস্থান।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmdlxv{আর যারা ঈমান এনেছে তারা বলে -- ''একটি সূরা কেন অবতীর্ণ হয় না?’’ কিন্ত যখন একটি সিদ্ধান্তমূলক সূরা অবতীর্ণ হয় আর তাতে যুদ্ধের উল্লেখ থাকে তখন যাদের হৃদয়ে ব্যাধি রয়েছে তাদের তুমি দেখতে পাবে তোমার দিকে তাকাচ্ছে মৃত্যুর কারণে মুর্চ্ছিত লোকের দৃষ্টির ন্যায়। সুতরাং ধিক্ তাদের জন্য!\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmdlxvi{আনুগত্য ও সদয়বাক্য! অতএব যখন ব্যাপারটি সন্বন্ধে সিদ্ধান্ত নেওয়া হয়ে যায় তখন তারা যদি আল্লাহ্‌র প্রতি সত্যনিষ্ঠ থাকে তাহলে সেটিই তো তাদের জন্য মঙ্গলজনক।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmdlxvii{কিন্ত যদি তোমাদের শাসনভার দেওয়া যায় তাহলে তোমাদের থেকে তো আশা করা যাবে যে তোমরা অবশ্যই দেশে ফসাদ সৃষ্টি করবে এবং তোমাদের রক্ত-সম্পর্ক ছিন্ন করবে।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmdlxviii{এরাই তারা যাদের প্রতি আল্লাহ্ ধিক্কার দিয়েছেন, ফলে তিনি তাদের বধির বানিয়েছেন এবং তাদের দৃষ্টি অন্ধ করে দিয়েছেন।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmdlxix{কি! তারা কি তবে কুরআন সন্বন্ধে ভাববে না, না কি হৃদয়ের উপরে সেগুলোর তালা দেয়া রয়েছে?\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmdlxx{নিঃসন্দেহ যারা তাদের পিঠ ফিরিয়ে ঘুরে যায় তাদের কাছে সৎপথ সুস্পষ্ট হবার পরেও, শয়তান তাদের জন্য হাল্কা করে দিয়েছে এবং তাদের জন্য সুদীর্ঘ করেছে।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmdlxxi{এইটাই! কেননা আল্লাহ্ যা অবতারণ করেছেন তাতে যারা ঘৃণা করে তাদের কাছে তারা বলে, ''আমরা তোমাদের মেনে চলব কোনো-কোনো ব্যাপারে।’’ আর আল্লাহ্ জানেন তাদের গোপনীয়তা।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmdlxxii{কিন্ত কেমন হবে যখন ফিরিশ্‌তারা তাদের মুখে ও তাদের পিঠে আঘাত হানতে হানতে তাদের মৃত্যু ঘটাবে?\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmdlxxiii{এইটিই! কেননা আল্লাহ্‌কে যা অসন্তষ্ট করে তারা তারই অনুসরণ করে আর তাঁর সন্তষ্টিলাভকে তারা অপছন্দ করে, সেজন্য তিনি তাদের ক্রিয়াকলাপ ব্যর্থ করে দেন।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmdlxxiv{অথবা, যাদের অন্তরে ব্যাধি রয়েছে তারা কি ভাবে যে আল্লাহ্ কদাপি তাদের বিদ্বেষভাব প্রকাশ করবেন না?\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmdlxxv{আর আমরা যদি চাইতাম তবে আমরা নিশ্চয়ই তোমাকে তাদের দেখাতাম, তখন তুমি আলবৎ তাদের চিনতে পারতে তাদের চেহারার দ্বারা। আর তুমি তো অবশ্যই তাদের চিনতে পারবে তাদের কথার ধরনে। আর আল্লাহ্ জানেন তোমাদের কাজকর্ম।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmdlxxvi{আর আমরা নিশ্চয়ই তোমাদের যাচাই করব যতক্ষণ না আমরা জানতে পারি তোমাদের মধ্যের কঠোর সংগ্রামশীলদের ও অধ্যবসায়ীদের, আর তোমাদের খবর আমরা পরীক্ষা করেছি।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmmdlxxvii{নিঃসন্দেহ যারা অবিশ্বাস পোষণ করে ও আল্লাহ্‌র পথ থেকে সরিয়ে রাখে এবং রসূলের বিরুদ্ধাচরণ করে তাদের কাছে সৎপথ সুস্পষ্ট হবার পরেও, তারা কখনো আল্লাহ্‌র কোনো ক্ষতি করতে পারবে না। আর অচিরেই তিনি তাদের ক্রিয়াকলাপ নিষ্ফল করে দেবেন।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmmdlxxviii{ওহে যারা ঈমান এনেছ! আল্লাহ্‌কে মেনে চলো ও রসূলের আজ্ঞা পালন করো, আর তোমাদের ক্রিয়াকর্ম বিফল করো না।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmmdlxxix{নিঃসন্দেহ যারা অবিশ্বাস পোষণ করে ও আল্লাহ্‌র পথ থেকে সরিয়ে রাখে, তারপর মারা যায় অথচ তারা অবিশ্বাসী থাকে, সে- ক্ষেত্রে আল্লাহ্ কখনো তাদের পরিত্রাণ করবেন না।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmmdlxxx{অতএব তোমরা ঢিলেমি করো না এবং শান্তির প্রতি আহ্বান করো, আর তোমরাই তো উপরহাত হবে, আর আল্লাহ্ তোমাদের সঙ্গে রয়েছেন, আর তিনি কখনো তোমাদের কার্যাবলী তোমাদের জন্য ব্যাহত করবেন না।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmmdlxxxi{নিঃসন্দেহ এই দুনিয়ার জীবন শুধু খেলাধূলা ও আমোদ-প্রমোদ। আর যদি তোমরা ঈমান আনো ও ধর্মভীরুতা অবলন্বন কর তবে তিনি তোমাদের প্রদান করবেন তোমাদের পুরস্কার, আর তিনি তোমাদের থেকে তোমাদের ধনসম্পদ চাইবেন না।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmmdlxxxii{যদি তিনি তোমাদের কাছ থেকে তা চাইতেন এবং তোমাদের চাপ দিতেন, তাহলে তোমরা কার্পণ্য করবে, আর তিনি প্রকাশ করে দিচ্ছেন তোমাদের বিদ্বেষ।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmmdlxxxiii{দেখো, তোমরাই তো তারা যাদের আহ্বান করা হচ্ছে যেন তোমরা আল্লাহ্‌র পথে ব্যয় কর, কিন্ত তোমাদের মধ্যে রয়েছে তারা যারা কৃপণতা করছে, বস্তুতঃ যে কার্পণ্য করে সে তো বখিলি করছে তার নিজেরই বিরুদ্ধে। আর আল্লাহ্ ধনবান, এবং তোমরা অভাবগ্রস্ত। আর তোমরা যদি ফিরে যাও তবে তিনি তোমাদের স্থলে অন্য লোকদের বদলে আনবেন, তখন তারা তোমাদের মতন হবে না।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmmdlxxxiv{\basmalahbn আমরা নিশ্চয় তোমাকে বিজয় দিয়েছি একটি উজ্জ্বল বিজয়, --\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmdlxxxv{এ জন্য যে আল্লাহ্ যেন তোমাকে মুক্তি দিতে পারেন তোমার সেই সব অপরাধ থেকে যা গত হয়ে গেছে ও যা রয়ে গেছে, আর যেন তোমার উপরে তাঁর অনুগ্রহ পূর্ণাঙ্গ করতে পারেন, আর যেন তোমাকে পরিচালিত করতে পারেন সহজ-সঠিক পথ দিয়ে, --\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmdlxxxvi{আর যেন আল্লাহ্ তোমাকে সাহায্য করতে পারেন এক বলিষ্ঠ সাহায্যে।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmdlxxxvii{তিনিই সেইজন যিনি মুমিনদের অন্তরে প্রশান্তি বর্ষণ করেছেন যেন তিনি তাদের বিশ্বাসের সঙ্গে বিশ্বাস বাড়িয়ে দিতে পারেন। আর মহাকাশমন্ডলীর ও পৃথিবীর বাহিনীসমূহ আল্লাহরই, আর আল্লাহ্ হচ্ছেন সর্বজ্ঞাতা, পরমজ্ঞানী, --\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmdlxxxviii{যেন তিনি মুমিন পুরুষদের ও মুমিন নারীদের প্রবেশ করাতে পারেন জান্নাতে যাদের নিচে দিয়ে বয়ে চলেছে ঝরনারাজি, তারা সে- সবে অবস্থান করবে, আর তিনি তাদের থকে তাদের দোষত্রুটি মোচন করবেন। আর এটি আল্লাহ্‌র কাছে এক মহাসাফল্য, --\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmdlxxxix{আর যেন তিনি শাস্তি দিতে পারেন মুনাফিক পুরুষদের ও মুনাফিক নারীদের এবং মুশরিক পুরুষদের ও মুশরিক নারীদের -- যারা আল্লাহ্ সন্বন্ধে ভ্রান্ত ধারণা ধারণ করে থাকে। তাদের বিরুদ্ধে দুস্কর্ম ঘুরে আসবে, আর আল্লাহ্ তাদের উপরে রাগ করেছেন এবং তাদের ধিক্কার দিয়েছেন, আর তাদের জন্য তিনি জাহান্নাম তৈরি করেছেন। আর কত নিকৃষ্ট গন্তব্যস্থল?\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmdxc{আর মহাকাশমন্ডলী ও পৃথিবীর বাহিনীসমূহ আল্লাহর। আর আল্লাহ্ হচ্ছেন মহাশক্তিশালী, পরমজ্ঞানী।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmdxci{আমরা নিশ্চয়ই তোমাকে পাঠিয়েছি একজন সাক্ষীরূপে, আর সুসংবাদদাতা ও সতর্ককারীরূপে, --\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmdxcii{যেন তোমরা আল্লাহ্‌র প্রতি ও তাঁর রসূলের প্রতি ঈমান আনতে পার, এবং তাঁকে সাহায্য করতে ও সম্মান করতে পার, আর যেন তোমরা তাঁর নামজপ করতে পার ভোরে ও সন্ধ্যায়।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmdxciii{নিঃসন্দেহ যারা তোমার কাছে আনুগত্যের শপথ গ্রহণ করে তারা নিশ্চয় আনুগত্যের শপথ নিচ্ছে আল্লাহ্‌র কাছে, -- আল্লাহ্‌র হাত ছিল তাদের হাতের উপরে। সুতরাং যে কেউ ভঙ্গ করে সে তো তবে ভঙ্গ করছে তার নিজেরই বিরুদ্ধে। আর যে কেউ পূরণ করে যে ওয়াদা সে আল্লাহ্‌র সঙ্গে করেছে তা, তাকে তবে তিনি প্রদান করবেন এক বিরাট প্রতিদান।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmdxciv{বেদুইনদের মধ্যের যারা পেছনে রয়ে গিয়েছিল তারা শীঘ্রই তোমাকে বলবে -- ''আমাদের ধনসম্পত্তি ও আমাদের পরিবার- পরিজন আমাদের মশগুল করে রেখেছিল, সেজন্য আমাদের জন্য আপনি ক্ষমা প্রার্থনা করুন।’’ তারা তাদের জিব দিয়ে এমন সব বলে যা তাদের অন্তরে নেই। তুমি বল -- ''কে তবে আল্লাহ্‌র বিরুদ্ধে তোমাদের জন্য কিছু করবার ক্ষমতা রাখে যদি তিনি তোমাদের অপকার করতে চান অথবা তোমাদের উপকার করতে চান? বস্তুত তোমরা যা কর সে-সন্বন্ধে আল্লাহ্ পূর্ণ ওয়াকিফহাল।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmdxcv{''না, তোমরা ভেবেছিলে যে রসূল ও মুমিনগণ আর কখনো তাদের পরিবারবর্গের কাছে ফিরে আসতে পারবে না, আর এইটি তোমাদের অন্তরে প্রীতিকর মনে হয়েছিল, আর তোমরা ভ্রান্তধারণা ধারণা করেছিল, আর তোমরা তো ছিলে এক ধ্বংসমুখী জাতি।’’\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmdxcvi{আর যে কেউ আল্লাহ্‌তে ও তাঁর রসূলের প্রতি বিশ্বাস করে না আমরা তো অবশ্যই অবিশ্বাসীদের জন্য তৈরি করেছি জ্বলন্ত আগুন।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmdxcvii{আর মহাকাশমন্ডলী ও পৃথিবীর সার্বভৌমত্ব আল্লাহ্‌র। তিনি যাকে ইচ্ছা করেন পরিত্রাণ করেন এবং শাস্তি দেন যাকে ইচ্ছা করেন। আর আল্লাহ্ পরম ক্ষমাশীল, অফুরন্ত ফলদাতা।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmdxcviii{তোমরা যখন যুদ্ধলব্ধ সম্পদের উদ্দেশ্যে যাত্রা কর তা হস্তগত করার জন্যে তখন পেছনে-পড়ে-থাকা লোকেরা সঙ্গে সঙ্গে বলবে -- ''আমাদের অনুমতি দাও যাতে আমরা তোমাদের অনুগমন করতে পারি।’’ তারা আল্লাহ্‌র কালাম বদলাতে চায়। তুমি বলো -- ''তোমরা কিছুতেই আমাদের অনুগমন করবে না, আল্লাহ্ ইতিপূর্বেও এমনটাই বলেছিলেন।’’ তাতে তারা সঙ্গে সঙ্গে বলবে -- ''বরং তোমরা আমাদের ঈর্ষা করছ।’’ বস্তুত তারা যৎসামান্য ছাড়া বোঝে না।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmdxcix{বেদুইনদের যারা পেছনে রয়ে গিয়েছিল তাদের বল -- ''শীঘ্রই তোমাদের ডাক দেওয়া হবে এক প্রবল পরাক্রান্ত জাতির বিরুদ্ধে, তোমরা তাদের সঙ্গে যুদ্ধ করবে যতক্ষণ না তারা আ‌ত্মসমর্পণ করে, তখন যদি তোমরা আজ্ঞাপালন কর, তাহলে আল্লাহ্ তোমাদের প্রদান করবেন এক উত্তম প্রতিদান। কিন্তু যদি তোমরা ফিরে যাও যেমন আগের দিনে তোমরা ফিরে যেতে, তাহলে তিনি তোমাদের শায়েস্তা করবেন মর্মন্তুদ শাস্তিতে।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmdc{অন্ধের জন্য কোনো অপরাধ নেই, আর খোঁড়ার জন্যেও কোনো অপরাধ নেই, আর রোগীর জন্যেও কোনো দোষ নেই। আর যে কেউ আল্লাহ্‌র ও তাঁর রসূলের আজ্ঞাপালন করে তাদের তিনি প্রবেশ করাবেন বাগানসমূহে যাদের নিচে দিয়ে বয়ে চলেছে ঝরনারাজি, কিন্তু যে কেউ ফিরে যায় তিনি তাকে শায়েস্তা করবেন মর্মন্তুদ শাস্তিতে।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmdci{আল্লাহ্ তো মুমিনদের প্রতি সন্তষ্ট হয়েই ছিলেন যখন তারা গাছতলাতে তোমার আনুগত্যের শপথ গ্রহণ করল, আর তাদের অন্তরে যা ছিল তা তিনি জানতেন, সেজন্য তাদের উপরে তিনি প্রশান্তি বর্ষণ করলেন, আর তিনি তাদের পুরস্কার দিয়েছিলেন এক আসন্ন বিজয়, --\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmdcii{আর প্রচুর যুদ্ধেলব্ধ সম্পদ, তারা তা হস্তগত করবে। আর আল্লাহ্ হচ্ছেন মহাশক্তিশালী, পরমজ্ঞানী।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmdciii{আল্লাহ্ তোমাদের জন্য ওয়াদা করছেন প্রচুর যুদ্ধেলব্ধ সম্পদ, তোমরা তা হস্তগত করবে, আর তোমাদের জন্য তিনি ত্বরান্বিত করেছেন এইটি, ফলে লোকেদের হাত তোমাদের থেকে তিনি ঠেকিয়ে রেখেছেন, আর যেন এটি মুমিনদের জন্য একটি নিদর্শন হতে পারে, আর যাতে তিনি তোমাদের পরিচালিত করতে পারেন সহজ-সঠিক পথে, --\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmdciv{আর অন্যান্য যে গুলোর উপরে তোমরা এখনও কবজা করতে পার নি, আল্লাহ্ এগুলোকে ঘিরে রেখেছেন। আর আল্লাহ্ সব- কিছুর উপরে সর্বশক্তিমান ।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmdcv{আর যারা অবিশ্বাস পোষণ করে তারা যদিও বা তোমাদের সঙ্গে যুদ্ধ করে তবে নিশ্চয় তারা পিঠ ফেরাবে, তারপরে তারা পাবে না কোনো বন্ধুবান্ধব, আর না কোনো সাহায্যকারী।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmdcvi{আল্লাহ্‌র নিয়ম-নীতি যা ইতিপূর্বে গত হয়ে গেছে, আর আল্লাহ্‌র নিয়ম-নীতিতে তোমরা কখনো কোনো পরিবর্তন পাবে না।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmdcvii{আর তিনিই সেইজন যিনি মক্কা উপত্যকায় তাদের হাতগুলো তোমাদের থেকে আর তোমাদের হাতগুলো তাদের থেকে ঠেকিয়ে রেখেছিলেন, তাদের উপরে তিনি তোমাদের বিজয় দান করার পরে। আর তোমরা যা করছ আল্লাহ্ সে-সবের সম্যক দ্রষ্টা।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmdcviii{এরাই তারা যারা অবিশ্বাস পোষণ করেছিল এবং তোমাদের বাধা দিয়েছিল পবিত্র মসজিদ থেকে, আর উৎসর্গীকৃত পশুদের বাধা দিয়েছিল তাদের গন্তব্যস্থলে পৌঁছতে। আর মুমিন পুরুষ ও মুমিন নারীরা যদি না থাকতো তাহলে তাদের তোমরা না-জেনে তাদের দলিত করতে, ফলে তাদের কারণে অজানিতভাবে এক নিন্দনীয় অপরাধ তোমাদের পাকড়াতো, এ-জন্য যে আল্লাহ্ যেন যাকে ইচ্ছা করেন তাঁর করুণার মধ্যে দাখিল করতে পারেন। তারা যদি আলাদা হয়ে থাকত তাহলে তাদের মধ্যের যারা অবিশ্বাস পোষণ করে তাদের আমরা নিশ্চয় শাস্তি দিতাম মর্মন্তুদ শাস্তিতে।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmdcix{যারা অবিশ্বাস পোষণ করে তারা যখন তাদের অন্তরে গোঁ ধরেছিল -- অজ্ঞতার যুগের গোঁয়ার্তুমি -- তখন আল্লাহ্ তাঁর প্রশান্তি বর্ষণ করেছিলেন তাঁর রসূলের উপরে ও মুমিনদের উপরে, আর ধর্মনিষ্ঠার নীতিতে তাদের সুপ্রতিষ্ঠিত রাখলেন, বস্তুত তারা এর জন্য নায্য দাবিদার ছিল ও এর উপযুক্ত ছিল, আর আল্লাহ্ সর্ববিষয়ে সর্বজ্ঞাতা।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmdcx{আল্লাহ্ আলবৎ তাঁর রসূলের জন্য দৈবদর্শনটি যথাযথভাবে বাস্তবায়িত করেছেন। তোমরা সুনিশ্চিত পবিত্র মসজিদে ইন-শা আল্লাহ্ প্রবেশ করবে নিরাপত্তার সাথে, তোমাদের মস্তক মুন্ডন ক’রে ও চুল কেটে, তোমরা ভয় না ক’রে। কিন্তু তিনি জানেন যা তোমরা জান না, সেজন্য এইটি ছাড়াও তিনি সংঘটিত করেছেন এক আসন্ন বিজয়।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmdcxi{তিনিই সেইজন যিনি তাঁর রসূলকে পাঠিয়েছেন পথনির্দেশ ও সত্য ধর্মের সাথে যেন তিনি একে প্রাধান্য দিতে পারেন ধর্মের -- তাদের সবক’টির উপরে। আর সাক্ষীরূপে আল্লাহ্‌ই যথেষ্ট।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmdcxii{মুহাম্মদ আল্লাহ্‌র রসূল, আর যারা তাঁর সঙ্গে রয়েছেন তারা অবিশ্বাসীদের প্রতি কঠোর, নিজেদের মধ্যে কোমলভাবাপন্ন, তুমি তাদের দেখতে পাবে তারা আল্লাহ্‌র কাছ থেকে করুণাভান্ডার ও সন্তষ্টি কামনা ক’রে রুকু করছে সিজদা করছে। তাদের পরিচায়ক হচ্ছে তাদের মুখমন্ডলের উপরে সিজদার ছাপের মধ্যে। এমনটাই তাদের উদাহরণ তওরাতে এবং তাদের উদাহরণ ইঞ্জিলেও, -- বপন করা শস্যবীজের মতো যা তার অঙ্কুর উদগত করে, তারপর তাকে শক্ত করে, তারপর তা পুষ্ট হয়, তারপর তা খাড়া হয় তার কান্ডের উপরে, -- বপনকারীদের আনন্দবর্ধন করে, তিনি যেন তাদের কারণে অবিশ্বাসীদের অন্তর্জালা সৃষ্টি করেন। যারা ঈমান এনেছে ও সৎকর্ম করছে আল্লাহ্ তাদের মধ্যের লোকজনকে ওয়াদা করেছেন পরিত্রাণ ও এক মহান প্রতিদান।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmdcxiii{\basmalahbn ওহে যারা ঈমান এনেছ! আল্লাহ্ ও তাঁর রসূলের সামনে তোমরা আগবাড়বে না, আর আল্লাহ্‌কে ভয়ভক্তি করো। নিঃসন্দেহ আল্লাহ্ সর্বশ্রোতা, সর্বজ্ঞাতা।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmdcxiv{ওহে যারা ঈমান এনেছ! তোমাদের গলার আওয়াজ নবীর আওয়াজের উপরে চড়িয়ো না, আর তাঁর সঙ্গে কথা বলতে চিৎকার করো না যেমন তোমাদের কেউ-কেউ অপরের সঙ্গে চিল্লাচিল্লি করে, পাছে তোমাদের কাজ-কর্ম বৃথা হয়ে যায়, অথচ তোমরা বুঝতেও পার না।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmdcxv{নিঃসন্দেহ যারা আল্লাহ্‌র রসূলের সামনে তাদের আওয়াজ নিচু করে, এরাই হচ্ছে তারা যাদের হৃদয় ধর্ম পরায়ণতার জন্য আল্লাহ্ পরীক্ষা করেছেন। তাদেরই জন্য রয়েছে পরিত্রাণ ও এক মহান প্রতিদান।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmdcxvi{নিঃসন্দেহ যারা বাসগৃহগুলোর পেছন থেকে তোমাকে ডাকে তাদের অধিকাংশই বুদ্ধিসুদ্ধি রাখো না।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmdcxvii{আর যদি তারা ধৈর্য ধরত যতক্ষণ না তুমি তাদের কাছে বেরিয়ে আস তাহলে তাদের জন্য তা বেশি ভাল হতো । আর আল্লাহ্ পরিত্রাণকারী, অফুরন্ত ফলদাতা।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmdcxviii{ওহে যারা ঈমান এনেছ! যদি কোনো সত্যত্যাগী কোনো খবর নিয়ে তোমাদের কাছে আসে তখন তোমরা যাচাই করে দেখবে, পাছে অজানতে তোমরা কোনো লোকদলকে আঘাত করে বস, আর পরক্ষণেই দুঃখ কর তোমরা যা করেছ সেজন্য।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmdcxix{আর জেনে রেখো যে তোমাদের মধ্যে আল্লাহ্‌র রসূল রয়েছেন। তাঁকে যদি অধিকাংশ বিষয়ে তোমাদের মেনে চলতে হয়, তাহলে তোমরা নির্ঘাত বিপাকে পড়বে, কিন্তু আল্লাহ্ ধর্মবিশ্বাসকে তোমাদের কাছে প্রিয় করেছেন এবং তোমাদের হৃদয়ে এইটিকে চিত্তাকর্ষক করেছেন, আর তোমাদের কাছে অপ্রিয় করেছেন অবিশ্বাস ও সত্যত্যাগ ও অবাধ্যতা। এরা নিজেরাই সত্যানুগামী --\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmdcxx{আল্লাহ্‌র তরফ থেকে বদান্যতা ও অনুগ্রহ! আর আল্লাহ্ সর্বজ্ঞাতা, পরমজ্ঞানী।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmdcxxi{আর যদি মুমিনদের দুই দল লড়াই করে তাহলে তাদের উভয়ের মধ্যে শান্তি স্থাপন করো। কিন্তু তাদের একদল যদি অন্যদের বিরুদ্ধে বিবাদ করে তবে তোমরা লড়াই করবে তার সঙ্গে যে বিবাদ করছে, যে পর্যন্ত না তারা আল্লাহ্‌র নির্দেশের প্রতি ফিরে আসে। তারপর যখন তারা ফেরে তখন তাদের উভয়ের মধ্যে শান্তিস্থাপন করো ন্যায়বিচারের সাথে, আর নিরপেক্ষতা অবলন্বন করবে। নিঃসন্দেহ আল্লাহ্ নিরপেক্ষতা-অবলন্বনকারীদের ভালবাসেন।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmdcxxii{নিঃসন্দেহ মুমিনরা ভাই-ভাই, সুতরাং তোমাদের ভাইদের মধ্যে তোমরা শান্তিস্থাপন করবে, আর তোমরা আল্লাহ্‌কে ভয়-ভক্তি করবে যেন তোমাদের অনুগ্রহ করা হয়।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmdcxxiii{ওহে যারা ঈমান এনেছ! কোনো লোকদল অন্য লোকদলকে উপহাস করবে না, হয়তো তারা এদের চাইতে বেশি ভাল, আর কোনো নারীরাও অন্য নারীদের করবে না, হয়তো তারা এদের চাইতে বেশী ভাল, আর তোমরা তোমাদের নিজের লোকদের নিন্দা করো না, আর তোমরা পরস্পরকে উপনামে ডেকো না। ঈমান আনার পরে অধার্মিকতার নাম কামানো বড়ই মন্দ। আর যে কেউ না ফেরে, তবে তারাই খোদ অত্যাচারী।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmdcxxiv{ওহে যারা ঈমান এনেছ! অধিকাংশ ক্ষেত্রে সন্দেহ এড়িয়ে চল, কেননা কোনো কোনো সন্দেহ নিশ্চয়ই পাপজনক। আর তোমরা গুপ্তচরবৃত্তি করো না, আর তোমাদের কেউ-কেউ অন্যদের আড়ালে নিন্দা করো না। তোমাদের কেউ কি চায় যে সে তার মৃত ভাইয়ের মাংস খাবে? নিশ্চিত তোমরা এটি ঘৃণা কর। আর আল্লাহ্‌কে ভয়-ভক্তি করো। নিঃসন্দেহ আল্লাহ্ বারবার প্রত্যাবর্তনকারী, অফুরন্ত ফলদাতা।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmdcxxv{ওহে মানবজাতি! নিঃসন্দেহ আমরা তোমাদের সৃষ্টি করেছি পুরুষ ও নারী থেকে, আর আমরা তোমাদের বানিয়েছি নানান জাতি ও গোত্র যেন তোমরা চিনতে পার। নিশ্চয় আল্লাহ্‌র কাছে তোমাদের মধ্যে সব-চাইতে সম্মানিত সেইজন যে তোমাদের মধ্যে সব- চাইতে বেশি ধর্মভীরু। নিঃসন্দেহ আল্লাহ্ সর্বজ্ঞাতা, পূর্ণ-ওয়াকিফহাল।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmdcxxvi{বেদুইনরা বলে -- ''আমরা ঈমান এনেছি।’’ তুমি বলো -- ''তোমরা বিশ্বাস স্থাপন করো নি, বরং তোমাদের বলা উচিত -- 'আমরা ইসলাম কবুল করেছি’, কেননা তোমাদের অন্তরে ঈমান এখনও প্রবেশ করে নি। আর যদি তোমরা আল্লাহ্‌র ও তাঁর রসূলের আজ্ঞাপালন কর তাহলে তিনি তোমাদের ক্রিয়াকর্ম থেকে কিছুই তোমাদের জন্য কমাবেন না।’’ নিঃসন্দেহ আল্লাহ্ পরিত্রাণকারী, অফুরন্ত ফলদাতা।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmdcxxvii{নিঃসন্দেহ মুমিন তারাই যারা আল্লাহ্‌তে ও তাঁর রসূলের প্রতি ঈমান এনেছে, তারপরে তারা সন্দেহ পোষণ করেনা, আর তাদের ধনসম্পদ ও তাদের জানপ্রাণ দিয়ে আল্লাহ্‌র পথে জিহাদ করে। এরাই খোদ সত্যনিষ্ঠ।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmdcxxviii{তুমি বলো -- ''কী! তোমরা কি আল্লাহ্‌কে জানাতে চাও তোমাদের ধর্ম সম্পর্কে, অথচ আল্লাহ্ সব-কিছু সন্বন্ধে সর্বজ্ঞাতা।’’\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmdcxxix{তারা তোমার প্রতি অনুগ্রহ করেছে যেহেতু তারা মুসলিম হয়েছে। তুমি বল -- ''তোমাদের ইসলাম আমার প্রতি কোনো অনুগ্রহ বলে ভেবো না, বরং আল্লাহ্‌ই তোমাদের প্রতি অনুগ্রহ করেছেন যেহেতু তিনি ধর্মবিশ্বাসের প্রতি তোমাদের পরিচালিত করেছেন, যদি তোমরা সত্যপরায়ণ হও।’’\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmdcxxx{নিঃসন্দেহ আল্লাহ মহাকাশমন্ডলী ও পৃথিবীর অদৃশ্য বিষয়গুলো জানেন। আর তোমরা যা করছ সে-সবের তো তিনি সর্বদ্রষ্টা।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmdcxxxi{\basmalahbn ক্কাফ। ভেবে দেখো মহিমান্বিত কুরআনখানা।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmdcxxxii{বস্তুত তারা আশ্চর্য হচ্ছে যে তাদের কাছে তাদেরই মধ্যে থেকে একজন সতর্ককারী এসেছেন, তাই অবিশ্বাসীরা বলছে -- ''এ তো এক আজব ব্যাপার!’’\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmdcxxxiii{''কী! আমরা যখন মরে যাব এবং ধুলো-মাটি হয়ে যাব? এ তো বহু দূর থেকে ফিরে আসা।’’\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmdcxxxiv{আমরা আলবৎ জানি তাদের মধ্যের কতটুকু পৃথিবী হ্রাস করে ফেলে, আর আমাদের কাছে রয়েছে সুরক্ষিত গ্রন্থ।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmdcxxxv{বস্তুত তারা সত্য প্রত্যাখ্যান করেছিল যখন তাদের কাছে তা এসেছিল, সেজন্য তারা সংশয়াকুল অবস্থায় রয়েছে।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmdcxxxvi{তারা কি তবে তাদের উপরকার আকাশের দিকে তাকিয়ে দেখে না -- আমরা কেমন ক’রে তা তৈরি করেছি এ বং তাকে সুশোভিত করেছি, আর তাতে কোনো ফাটলও নেই?\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmdcxxxvii{আর পৃথিবী -- তাকে আমরা প্রসারিত করেছি আর তাতে স্থাপন করেছি পাহাড়-পর্বত, আর তাতে আমরা জন্মিয়েছি হরেক রকমের মনোরম বস্তু --\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmdcxxxviii{দেখার মতো ও মনোনিবেশ করার মতো বিষয় প্রত্যেক অনুরাগী বান্দার জন্য।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmdcxxxix{আর আমরা আকাশ থেকে বর্ষণ করি আশীর্বাদসূচক জল, তারপর তার দ্বারা আমরা জন্মাই বাগানসমূহ ও খাদ্যশস্য যা তোলা হয়,\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmdcxl{আর লন্বা লন্বা খেজুর গাছ যাতে আছে গোছা গোছা কাঁদি, --\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmdcxli{দাসদের জন্য জীবিকাস্বরূপ, আর এর দ্বারা আমরা মৃত ভূখন্ডে প্রাণ সঞ্চার করি। এইভাবেই হবে পুনরুত্থান।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmdcxlii{এদের আগে নূহ-এর স্বজাতি প্রত্যাখ্যান করেছিল, আর রস্‌-এর অধিবাসীরা ও ছামুদ জাতি,\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmdcxliii{আর 'আদ ও ফিরআউন ও লূত-এর ভাই-বন্ধুরা,\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmdcxliv{আর আইকার অধিবাসীরা ও তুব্বার লোকদল; -- সবাই রসূলগণকে প্রত্যাখ্যান করেছিল, সুতরাং আমার ওয়াদা সত্য বর্তেছিল।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmdcxlv{আমরা কি তবে ক্লান্ত হয়ে পড়েছি প্রথমবারের সৃষ্টি করেই? না, তারা নতুন সৃষ্টি সন্বন্ধে সন্দেহের মাঝে রয়েছে।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmdcxlvi{আর আমরা তো নিশ্চয় মানুষ সৃষ্টি করেছি, আর আমরা জানি তার অন্তর তাকে কী মন্ত্রণা দেয়, আর আমরা কন্ঠশিরার চেয়েও তার আরো নিকটে রয়েছি।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmdcxlvii{স্মরণ রেখো, দুইজন গ্রহণকারী গ্রহণ করে চলেছেন ডাইনে ও বাঁয়ে বসে।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmdcxlviii{সে কোনো কথাই উচ্চারণ করে না যার জন্য তার নিকটেই এক তৎপর প্রখর প্রহরী নেই।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmdcxlix{আর মৃত্যুকালীন মূর্ছা সত্যি-সত্যি আসবে, -- ''এইটিই তো তাই যা থেকে তুমি অব্যাহতি চাও।’’\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmdcl{আর শিঙ্গায় ফুৎকার দেওয়া হবে, ''এইটিই সেই প্রতি‌শ্রুত দিন।’’\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmdcli{তখন প্রত্যেক সত্ত্বা চলে আসবে, তার সঙ্গে থাকবে এক চালক ও এক সাক্ষী।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmdclii{''তুমি তো অবশ্য এ সন্বন্ধে গাফিলতিতে ছিলে, কিন্ত এখন আমরা তোমার থেকে তোমার আবরণী সরিয়ে দিয়েছি ফলে তোমার দৃষ্টি আজ তীক্ষ্ণ হয়েছে।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmdcliii{আর তার সঙ্গী বলবে -- ''এই তো যা আমার কাছে তৈরি রয়েছে।’’\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmdcliv{''তোমরা দুজনে জাহান্নামে ফেলে দাও প্রত্যেক অবিশ্বাসীকে, বিদ্রোহাচারীকে, --\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmdclv{''ভালো কাজে নিষেধকারীকে, সীমালংঘনকারীকে, সন্দেহকারীকে --\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmdclvi{''যে আল্লাহ্‌র সঙ্গে অন্য উপাস্য দাঁড় করিয়েছিল, অতএব তোমরা উভয়ে তাকে নিক্ষেপ করো ভীষণ শাস্তিতে।’’\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmdclvii{আর তার সাঙ্গাত বলবে -- ''আমাদের প্রভু! আমি তো তাকে বিদ্রোহী বানাই নি, কিন্ত সে নিজেই ছিল সুদূর বিভ্রান্তিতে।’’\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmdclviii{তিনি বলবেন -- ''আমার সামনে তোমরা তর্কাতর্কি করো না, আর আমি তো তোমাদের কাছে ইতিপূর্বেই আমার ওয়াদা আগবাড়িয়েছি।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmdclix{''আমার কাছে কথার রদবদল হয় না, এবং আমি আমার বান্দাদের প্রতি আদৌ অন্যায়াচারী নই।’’\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmdclx{সেইদিন আমরা জাহান্নামকে বলব -- ''তুমি কি পূর্ণ হয়ে গিয়েছ?’’ আর সে বলবে -- ''আরো বেশি আছে কি?’’\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmdclxi{আর বেহেশতকে আনা হবে ধর্মভীরুদের নিকটে -- অদূরে।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmmdclxii{''এইটিই তা যার প্রতি‌শ্রুতি তোমাদের দেওয়া হয়েছিল প্রত্যেক জন বারবার প্রত্যাবর্তনকারী হেফাজতকারীর জন্য --\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmmdclxiii{''যে পরম করুণাময়কে ভয় করত সংগোপনে, আর উপস্থিত হত বিনয়-নম্র হৃদয় নিয়ে।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmmdclxiv{''এতে প্রবেশ করো প্রশান্তির সাথে। এই তো চিরস্থায়ী দিন।’’\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmmdclxv{এদের জন্য থাকবে তারা সেখানে যা চাইবে তাই, তার আমাদের কাছে রয়েছে আরো বেশি।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmmdclxvi{আর তাদের আগে আমরা কত মানবগোষ্ঠীকে ধ্বংস করেছি, তারা এদের চাইতে ছিল শক্তিতে বেশি প্রবল, ফলে তারা দেশে- বিদেশে অভিযান চালাত। কোনো আশ্রয়স্থল আছে কি?\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmmdclxvii{নিঃসন্দেহ এতে নিশ্চয়ই উপদেশ রয়েছে তার জন্য যার হৃদয় আছে, অথবা যে কান দেয়, আর সে সাক্ষ্য বহন কবে ।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmmdclxviii{আর আমরা অবশ্য মহাকাশমন্ডলী ও পৃথিবী এবং এ দুইয়ের মধ্যে যা-কিছু আছে তা সৃষ্টি করেছি ছয় দিনে, আর কোনো ক্লান্তি আমাদের স্পর্শ করে নি।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmmdclxix{অতএব ওরা যা বলে তা সত্ত্বেও তুমি অধ্যবসায় চালিয়ে যাও এবং তোমার প্রভুর প্রশংসায় জপতপ করো সূর্য উদয়ের আগে ও অস্ত যাবার আগে,\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmmdclxx{আর রাতের বেলাতেও তাঁর জপতপ করো, আর এই সিজদাগুলোর পরেও,\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmmdclxxi{আর শোনো সেইদিন যখন একজন ঘোষণাকারী আহ্বান করবেন নিকটবর্তী স্থান থেকে, --\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmmdclxxii{সেইদিন তারা সত্যি-সত্যি মহাগর্জন শুনতে পাবে। এইটিই বেরিয়ে আসার দিন।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmmdclxxiii{নিঃসন্দেহ আমরা স্বয়ং জীবন দান করি এবং আমরাই মৃত্যু ঘটাই, আর আমাদের কাছেই শেষ-আগমন, --\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmmdclxxiv{সেইদিন পৃথিবী বিদীর্ণ হয়ে যাবে তাদের থেকে স্ত্রস্ত-ব্যস্তভাবে, এই হচ্ছে মহাসমাবেশ -- আমাদের জন্য সহজ ব্যাপার।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmmdclxxv{ওরা যা বলে আমরা তা ভাল জানি, আর তুমি তাদের উপরে জবরদস্তি করার লোক নও। অতএব তুমি কুরআন নিয়ে স্মরণ করিয়ে চলো তার প্রতি যে আমার প্রতি‌শ্রুতিকে ভয় করে।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmmmdclxxvi{\basmalahbn ভাবো -- বিক্ষেপকারীদের বিক্ষেপের কথা, --\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmdclxxvii{তারপর বহনকারীদের বোঝার কথা, --\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmdclxxviii{তারপর চলমানদের স্বচ্ছন্দগমনের কথা, --\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmdclxxix{তারপর বিতরণকারীদের কাজকর্মের কথা, --\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmdclxxx{নিঃসন্দেহ তোমাদের প্রতি যা ওয়াদা করা হয়েছিল তা অবশ্যই সত্য, --\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmdclxxxi{আর নিঃসন্দেহ ন্যায়বিচার অবশ্যাম্ভাবী।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmdclxxxii{ভাবো আকাশের কথা -- অজস্র পথ বিশিষ্ট,\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmdclxxxiii{তোমরা তো নিশ্চয়ই পরস্পর বিরোধী কথায় রয়েছ,\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmdclxxxiv{যে মুখ ফিরিয়ে থাকে তাকে এ থেকে ফিরিয়েই রাখা হয়।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmdclxxxv{কোতল হোক মিথ্যারচনাকারীরা --\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmdclxxxvi{যারা খোদ গহবরে, বেখেয়াল!\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmdclxxxvii{তারা জিজ্ঞাসা করে -- ''কবে আসবে বিচারের দিন?’’\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmdclxxxviii{সেই দিনটাতে আগুনে তাদের পরীক্ষা করা হবে।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmdclxxxix{''তোমাদের অত্যাচার তোমরা আস্বাদন কর। এইটিই সেই যেটি তোমরা ত্বরান্বিত করতে চেয়েছিল।’’\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmdcxc{নিঃসন্দেহ ধর্মভীরুরা থাকবে স্বর্গোউদ্যানসমূহে ও ঝরনা-রাজিতে, --\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmdcxci{তাদের প্রভু যা তাদের দেবেন তারা তা গ্রহণ করতে থাকবে। তারা এর আগে নিশ্চয়ই ছিল সৎকর্মশীল।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmdcxcii{তারা রাতের সামান্য সময়ই ঘুমিয়ে কাটাত।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmdcxciii{আর নিশিভোরে তারা পরিত্রাণ খুঁজত।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmdcxciv{আর তাদের ধনসম্পদের মধ্যে ভিখারীর জন্য ও বঞ্চিতের জন্য হক্ রেখেছে।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmdcxcv{আর পৃথিবীতে নিদর্শনাবলী রয়েছে নিশ্চিত-বিশ্বাসীদের জন্য, --\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmdcxcvi{আর তোমাদের নিজেদের মধ্যে। তবুও কি তোমরা চেয়ে দেখবে না?\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmdcxcvii{আর আকাশে রয়েছে তোমাদের জীবিকা, আর যা তোমাদের ওয়াদা করা হয়েছে।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmdcxcviii{অতএব মহাকাশ ও পৃথিবীর প্রভুর শপথ -- নিঃসন্দেহ এ আলবৎ সত্য, যেমনটা তোমরা বস্তুত বাক্যালাপ কর।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmdcxcix{তোমার কাছে ইব্রাহীমের সম্মানিত অতিথিদের সংবাদ এসেছে কি?\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmdcc{তারা যখন তাঁর দরবারে প্রবেশ করল তারা তখন বললে -- ''সালাম’’। তিনিও বললেন -- ''সালাম’’, অপরিচিত লোক।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmdcci{তিনি তখন তাঁর পরিবারের কাছে নীরবে ছুটলেন এবং একটি পুষ্ট বাছুর নিয়ে এলেন,\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmdccii{তারপর তিনি এটি তাদের সামনে এগিয়ে দিলেন, তিনি বললেন -- ''আপনারা কি খাবেন না?’’\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmdcciii{সুতরাং তাদের সম্পর্কে তিনি ভয় অনুভব করলেন। তারা বললে -- ''ভয় করো না।’’ পক্ষান্তরে তারা তাঁকে সুসংবাদ দিল এক জ্ঞানবান ছেলের।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmdcciv{তারপর তাঁর স্ত্রী এগিয়ে এলেন বিলাপ করতে-করতে, আর তিনি তাঁর গালে চাপড় মারছেন এবং বলছেন, ''এক বুড়ি, বন্ধ্যা!’’\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmdccv{তারা বললে -- ''এমনটাই হবে, তোমার প্রভু বলেছেন।’’ নিঃসন্দেহ তিনি স্বয়ং পরমজ্ঞানী, সর্বজ্ঞাতা।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmdccvi{তিনি বললেন -- ''তাহলে তোমাদের বিশেষ বার্তা কি, হে বার্তাবাহকগণ?’’\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmmdccvii{তারা বললে -- ''আমাদের অবশ্য প্রেরণ করা হয়েছে এক অপরাধী লোকদের প্রতি, --\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmmdccviii{''যেন তাদের উপরে আমরা বর্ষণ করতে পারি মাটির পাথর,\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmmdccix{''যা অমিতাচারীদের জন্য নির্ধারিত রয়েছে তোমার প্রভুর কাছে।’’\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmmdccx{তারপর মুমিনদের মধ্যের যারা সেখানে রয়েছিল তাদের আমরা বের করে আনলাম,\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmmdccxi{কিন্ত আমরা সেখানে মুসলিমদের একটি পরিবার ব্যতীত আর কাউকে পাইনি।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmmdccxii{আর আমরা সেখানে রেখে দিয়েছিলাম এক নিদর্শন তাদের জন্য যারা মর্মন্তুদ শাস্তিকে ভয় করে।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmmdccxiii{আর মূসার মধ্যেও। দেখো! আমরা তাঁকে পাঠিয়েছিলাম ফিরআউনের কাছে সুস্পষ্ট কর্তৃত্ব দিয়ে।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmmdccxiv{কিন্ত সে ফিরে গিয়েছিল তার শক্তিমত্তার দিকে এবং বলেছিল -- ''একজন জাদুকর অথবা একজন পাগল।’’\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmmdccxv{তখন আমরা তাকে ও তার দলবলকে পাকড়াও করলাম এবং তাদের নিক্ষেপ করলাম অথৈ জলে, আর সে ছিল দোষী।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmmdccxvi{আর 'আদ জাতির ক্ষেত্রেও। দেখো! আমরা তাদের বিরুদ্ধে পাঠিয়েছিলাম এক বিধ্বংসী ঝড়।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmmdccxvii{এ যার উপরে এসে পড়েছিল তার কোনো কিছুই রেখে যায় নি, এটিকে তা করে দিয়েছিল ছাইয়ের মতো।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmmdccxviii{আর ছামুদ-জাতির ক্ষেত্রেও। দেখো! তাদের বলা হয়েছিল -- ''কিছুকাল উপভোগ করে নাও।’’\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmmdccxix{তথাপি তাদের প্রভুর আদেশের বিরুদ্ধে তারা দাঁড়িয়েছিল, ফলে এক বজ্রনাদ তাদের পাকড়ালো, আর তারা তাকিয়ে রয়েছিল।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmmdccxx{তাদের আর দাঁড়াবার ক্ষমতা রইল না, আর তারা সাহায্যপ্রাপ্ত হতেও পারে নি।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmmmdccxxi{আর পূর্বকালীন নূহের লোকদলকেও। নিঃসন্দেহ তারা ছিল সত্যত্যাগী জাতি।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmmmdccxxii{আর মহাকাশমন্ডল -- আমরা তা নির্মাণ করেছি হাতে, আর আমরাই বিশালতার নির্মাতা।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmmmdccxxiii{আর পৃথিবী -- আমরা একে বিছিয়ে দিয়েছি, কাজেই কত সুন্দর এই বিস্তারকারী!\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmmmdccxxiv{আর প্রত্যেক বস্তুর মধ্যে আমরা জোড়া-জোড়া সৃষ্টি করেছি, যেন তোমরা মনোনিবেশ করো।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmmmdccxxv{''অতএব তোমরা বেগে আল্লাহ্‌র দিকে ছুটো। আমি নিশ্চয়ই তোমাদের নিকট তাঁর কাছ থেকে একজন সুস্পষ্ট সতর্ককারী।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmmmdccxxvi{''আর আল্লাহ্‌র সাথে অন্য কোনো উপাস্য দাঁড় করো না। নিঃসন্দেহ আমি তোমাদের নিকট তাঁর কাছ থেকে এক জন সুস্পষ্ট সতর্ককারী।’’\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmmmdccxxvii{এইভাবেই। এদের আগে যারা ছিল তাদের কাছে এমন কোনো রসূল আসেন নি যাঁকে তারা না বলেছিল -- ''একজন জাদুকর, না হয় একজন পাগল।’’\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmmmdccxxviii{এরা কি এটিকেই মৌরুসি বিষয় বানিয়েছে? না, তারা হচ্ছে সীমালংঘনকারী জাতি।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmmmdccxxix{অতএব তাদের থেকে তুমি মুখ ফিরিয়ে নাও, কেননা তুমি তো দোষী নও।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmmmdccxxx{তবুও তুমি উপদেশ দিতে থাকো, কেননা নিঃসন্দেহ উপদেশদান মুমিনদের উপকার করবে।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mmmmdccxxxi{আর আমি জিন ও মানুষকে, তারা আমাকে উপাসনা করুক -- এইজন্য ছাড়া সৃষ্টি করি নি।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mmmmdccxxxii{আমি তাদের থেকে কোনো জীবিকা চাই না, আর আমি চাই না যে তারা আমাকে খাওয়াবে।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mmmmdccxxxiii{বরঞ্চ আল্লাহ -- তিনিই বিরাট রিযেকদাতা, ক্ষমতার অধিকারী, শক্তিমান।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mmmmdccxxxiv{সুতরাং যারা অন্যায়াচরণ করেছে তাদের জন্য অবশ্যই রয়েছে এক ঝুড়ি তাদের সাঙ্গোপাঙ্গদের ঝুড়ির ন্যায়, সেজন্য তারা যেন আমার কাছে তড়িঘড়ি না করে।\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mmmmdccxxxv{অতএব ধিক্ তাদের জন্য যারা অবিশ্বাস পোষণ করে -- তাদের সেই দিনটির কারণে যেটি তাদের ওয়াদা করা হয়েছে!\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mmmmdccxxxvi{\basmalahbn ভাবো পাহাড়ের কথা,\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmdccxxxvii{আর লিখিত গ্রন্থের,\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmdccxxxviii{এক খোলামেলা পাতায়,\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmdccxxxix{আর ভাবো ঘনঘন গমনাগমনের গৃহের কথা,\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmdccxl{আর সমুন্নত ছাদের,\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmdccxli{আর উচ্ছলিত সমুদ্রের কথা,\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmdccxlii{নিঃসন্দেহ তোমার প্রভুর শাস্তি অবশ্যাবী --\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmdccxliii{এটির জন্য কোনো প্রতিরোধকারী নেই;\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmdccxliv{যেদিন আকাশ আলোড়ন করবে আলোড়নে,\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmdccxlv{আর পাহাড়গুলো চলে যাবে চলে যাওয়ায়।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmdccxlvi{অতএব ধিক্ সেইদিন প্রত্যাখ্যানকারীদের জন্য --\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmdccxlvii{যারা বৃথা তর্কবিতর্কে খেলা খেলছে।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmdccxlviii{সেইদিন তাদের ধাক্কা দিয়ে নেওয়া হবে জাহান্নামের আগুনের দিকে ধাক্কা দিতে দিতে।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmdccxlix{''এইটিই সেই আগুন যেটিকে তোমরা মিথ্যা বলতে।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmdccl{''এটি কি তবে জাদু? না কি তোমরা দেখতে পাচ্ছ না?\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmdccli{''ঢুকে পড় এতে! অতঃপর তোমরা ধৈর্য ধর অথবা ধৈর্য না-ধর, তোমাদের জন্য একসমান। তোমাদের প্রতিফল দেওয়া হচ্ছে শুধুমাত্র তোমরা যা করতে তারই।’’\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmdcclii{নিঃসন্দেহ মুত্তকীরা থাকবে জান্নাতে ও পরমানন্দে, --\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmdccliii{তাদের প্রভু যা তাদের দিয়েছেন সেজন্য তারা সুখভোগ করতে থাকবে, আর তাদের প্রভু তাদের রক্ষা করবেন ভয়ংকর আগুনের শাস্তি থেকে।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmdccliv{''তোমরা যা করে থাকতে সেজন্য তৃপ্তির সাথে খাওদাও ও পান করো।’’\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmdcclv{তারা হেলান দিয়ে বসবে সারি-সারি সিংহাসনের উপরে, আর আমরা তাদের জোড় মিলিয়ে দেব আয়তলোচন হূরদের সাথে।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmdcclvi{আর যারা ঈমান আনে, এবং যাদের সন্তানসন্ততি ধর্মবিশ্বাসে তাদের অনুসরণ করে -- আমরা তাদের সঙ্গে মিলন ঘটাব তাদের ছেলেমেয়েদের, আর আমরা তাদের ক্রিয়াকর্ম থেকে কোনো কিছুই তাদের জন্য কমিয়ে দেব না। প্রত্যেক ব্যক্তিই সে যা অর্জন করেছে সেজন্য দায়ী।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmdcclvii{আর আমরা তাদের প্রচুর পরিমাণে প্রদান করব ফলফসল ও মাছমাংস -- যা তারা পছন্দ করে তা থেকে।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmdcclviii{তারা সেখানে একটি পানপাত্র পরস্পরের মধ্যে আদান-প্রদান করবে, তাতে থাকবে না কোনো খেলো আচরণ, না কোনো পাপ।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmdcclix{আর তাদের চারিদিকে ঘুরবে তাদের কিশোররা, -- তারা যেন সুরক্ষিত মুক্তো!\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmdcclx{আর তাদের কেউ-কেউ অপরের দিকে জিজ্ঞাসাবাদ ক’রে এগিয়ে যাবে --\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxi{তারা বলবে -- ''নিঃসন্দেহ আমরা ইতিপূর্বে আমাদের পরিজনদের সম্পর্কে ভীত ছিলাম।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxii{''তবে আল্লাহ আমাদের প্রতি অনুগ্রহ করেছেন, আর আমাদের রক্ষা করেছেন তাপপীড়িত বায়ুপ্রবাহের শাস্তি থেকে।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxiii{''আমরা অবশ্য এর আগেও তাঁকে ডাকতে থাকতাম। নিঃসন্দেহ তিনি খোদ অতি সদাশয়, অফুরন্ত ফলদাতা।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxiv{অতএব তুমি উপদেশ দান করতে থাকো, কেননা তোমার প্রভুর অনুগ্রহে তুমি তো গনৎকার নও এবং মাথা-পাগলাও নও।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxv{অথবা তারা কি বলে -- ''একজন কবি, আমরা বরং তার জন্য অপেক্ষা করি কালের কবলে পড়ার দরুন?\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxvi{তুমি বলো -- ''তোমরা অপেক্ষা করতে থাকো, আমিও তবে অবশ্য তোমাদের সঙ্গে অপেক্ষাকারীদের মধ্যে রয়েছি।’’\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxvii{অথবা তাদের বোধশক্তি কি এ-বিষয়ে তাদের নির্দেশ দিয়ে থাকে? অথবা তারা কি এক সীমালংঘনকারী জাতি?\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxviii{অথবা তারা কি বলে যে এটি সে বর্ণনা করেছে? না, তারা বিশ্বাস করে না।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxix{তাহলে তারা এর সমতুল্য এক রচনা নিয়ে আসুক, -- যদি তারা সত্যবাদী হয়।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxx{অথবা তাদের কি সৃষ্টি করা হয়েছে কেউ না-থাকা থেকে, না তারাই সৃষ্টিকর্তা?\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxxi{অথবা তারা কি সৃষ্টি করেছিল মহাকাশমন্ডল ও পৃথিবী? না, তারা দৃঢ়বিশ্বাস রাখে না।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxxii{অথবা তাদের কাছেই কি রয়েছে তোমার প্রভুর ধনভান্ডার, না তারাই নিয়ন্তা?\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxxiii{অথবা তাদের কাছে কি রয়েছে সিড়ি যাঁর সাহায্যে তারা শোনে নেয়? তাহলে তাদের শ্রবণকারী নিয়ে আসুক এক সুস্পষ্ট প্রমাণ।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxxiv{অথবা তাঁর কারণে কি রয়েছে কন্যারাসব, আর তোমাদের জন্য রয়েছে পুত্ররা?\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxxv{অথবা তুমি কি তাদের কাছে পারিশ্রমিক চাইছ, যার ফলে তারা দেনায় ভারাক্রান্ত হয়ে গেছে?\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxxvi{অথবা অদৃশ্য কি তাদের কাছে রয়েছে যার ফলে তারা লিখে ফেলতে পারে?\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxxvii{অথবা তারা কি ষড়যন্ত্র করতে চায়? কিন্ত যারা অবিশ্বাস পোষণ করে তারা নিজেরাই ষড়যন্ত্রে জড়িয়ে পড়বে।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxxviii{অথবা আল্লাহ্ ছাড়া তাদের কি অন্য উপাস্য রয়েছে? আল্লাহ্‌রই সব মহিমা -- তারা যা শরিক করে তিনি তার বাইরে।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxxix{আর যদি তারা দেখে আকাশের এক টুকরো ভেঙ্গে পড়ছে, তাহলে তারা বলবে -- ''এক পুঞ্জীভূত মেঘমালা।’’\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxxx{অতএব তাদের ছেড়ে দাও যে পর্যন্ত না তারা তাদের সেই দিনটির সাক্ষাৎ পায় যখন তারা হতভন্ব হয়ে যাবে, --\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxxxi{সেইদিন তাদের চাল-চক্রান্ত তাদের কোনো কাজে আসবে না, আর তাদের সাহায্যও করা হবে না।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxxxii{আর যারা অন্যায়াচার করেছে তাদের জন্য এ ছাড়া আরো শাস্তি রয়েছে, কিন্ত তাদের অধিকাংশই জানে না।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxxxiii{অতএব তোমার প্রভুর বিচারের জন্য ধৈর্য ধরে থেকো, বস্তুত তুমি নিশ্চয়ই আমাদের চোখের সামনে রয়েছ। কাজেই তোমার প্রভুর প্রশংসায় জপতপ করো যখন তুমি উঠে দাঁড়াও,\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxxxiv{আর রাতের বেলায়ও তবে তাঁর জপতপ করো এবং তারাগুলো ঝিমিয়ে যাবার সময়েও।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxxxv{\basmalahbn ভাবো তারকার কথা, যখন তা অস্ত যায়!\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxxxvi{তোমাদের সঙ্গী দোষ-ত্রুটি করেন না, আর তিনি বিপথেও যান না,\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxxxvii{আর তিনি ইচ্ছামত কোনো কথা বলেন না।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxxxviii{এইখানা প্রত্যাদিষ্ট হওয়া প্রত্যাদেশবাণী বৈ তো নয়, --\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxxxix{তাঁকে শিখিয়েছেন বিরাট শক্তিমান --\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmdccxc{বলবীর্যের অধিকারী। কাজেই তিনি পরিপূর্ণতায় পৌঁছলেন।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmdccxci{আর তিনি রয়েছেন ঊর্ধ্ব দিগন্তে।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmdccxcii{তারপর তিনি সন্নিকটে এলেন, অতঃপর তিনি অবনত করলেন,\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmdccxciii{তখন তিনি দুই ধনুকের ব্যবধানে রইলেন, অথবা আরও কাছে।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmdccxciv{তখন তিনি তাঁর বান্দার কাছে প্রত্যাদেশ করলেন যা তিনি প্রত্যাদেশ করেন।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmdccxcv{হৃদয় অস্বীকার করে নি যা তিনি দেখেছিলেন তাতে।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmdccxcvi{তোমরা কি তবে তাঁর সঙ্গে বিতর্ক করবে যা তিনি দেখেছেন সে-সন্বন্ধে?\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmdccxcvii{আর তিনি নিশ্চয়ই তাঁকে দেখেছিলেন অন্য এক অবতরণে --\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmdccxcviii{দূরদিগন্তের সিদরাহ্‌-গাছের কাছে,\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmdccxcix{তার কাছে আছে চির-উপভোগ্য উদ্যান।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmdccc{দেখো! যা আচ্ছাদন করে তা ঢেকে দিয়েছিল সিদরাহ্‌-গাছকে,\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmdccci{দৃষ্টি বিভ্রান্ত হয় নি এবং তা সীমা ছাড়িয়েও যায় নি।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmdcccii{তিনি নিশ্চয়ই তাঁর প্রভুর শ্রেষ্ঠ নিদর্শনগুলোর মধ্যে চেয়ে দেখেছিলেন।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmdccciii{তোমরা কি তবে ভেবে দেখেছ লাত ও 'উযযা,\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmdccciv{এবং মানাত, -- তৃতীয় আরেকটি?\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmdcccv{তোমাদের জন্য পুত্রসন্তান আর তাঁর জন্য কন্যা!\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmdcccvi{এ তো বড়ই অসংগত বন্টন!\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmdcccvii{তারা নামাবলী বৈ তো নয়, যা তোমরা নামকরণ করেছ -- তোমরা ও তোমাদের পূর্বপুরুষরা, যাদের জন্য আল্লাহ্ কোনো সনদ পাঠান নি। তারা তো শুধু অনুমানের এবং যা তাদের অন্তর কামনা করে তারই অনুসরণ করে। অথচ তাদের প্রভুর কাছ থেকে তাদের কাছে পথনির্দেশ অবশ্যই এসে গেছে।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmdcccviii{অথবা মানুষের জন্য কি তাই থাকবে যা সে কামনা করে?\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmdcccix{কিন্ত শেষটা তো আল্লাহ্‌র, আর প্রথমটাও।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmdcccx{আর মহাকাশমন্ডলে কত যে ফিরিশ্‌তা রয়েছে যাদের সুপারিশ কোনো কাজে আসবে না যতক্ষণ না আল্লাহ্ অনুমতি দেন তার জন্য যাকে তিনি ইচ্ছা করেন ও তিনি সন্তষ্ট হয়েছেন।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxi{নিঃসন্দেহ যারা পরকালে বিশ্বাস করে না তারা ফিরিশ্‌তাদের নাম দেয় মেয়েদের নামে।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxii{আর এ বিষয়ে তাদের কোনো জ্ঞান নেই। তারা তো অনুমানেরই অনুসরণ করছে, আর নিঃসন্দেহ সত্যের বিরুদ্ধে অনুমানে কোনো লাভ হয় না।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxiii{সেজন্য তাকে উপেক্ষা করো যে আমাদের উপদেশ থেকে ফিরে যায় আর দুনিয়ার জীবন ছাড়া আর কিছু চায় না।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxiv{এইটিই তাদের জ্ঞানের শেষসীমা। নিঃসন্দেহ তোমার প্রভু -- তিনিই ভাল জানেন তাকে যে তার পথ থেকে ভ্রষ্ট হয়েছে, আর তিনিই ভাল জানেন যে সৎপথপ্রাপ্ত।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxv{আর মহাকাশমন্ডলে যা-কিছু আছে এবং যা-কিছু আছে পৃথিবীতে তা আল্লাহ্‌রই, যেন যারা মন্দ কাজ করেছে তাদের তিনি প্রতিফল দিতে পারেন যা তারা করেছে সেজন্য, আর যারা সৎকাজ করেছে তাদের তিনি ভালভাবে প্রতিদান দিতে পারেন।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxvi{যারা বর্জন করে বড় বড় পাপাচার ও অশ্লীল কাজ -- মুখোমুখি হওয়া ভিন্ন -- তোমার প্রভু পরিত্রাণে নিশ্চয়ই অপরিসীম। তিনি তোমাদের ভালো জানেন যখন থেকে তিনি তোমাদের সৃষ্টির সূচনা করেছেন মাটি থেকে, আর যখন তোমরা ছিলে তোমাদের মায়ের পেটে ভ্রণরূপে। অতএব তোমরা তোমাদের নিজেদের গুণগান করো না। তিনিই ভালো জানেন তাকে যে ধর্মভীরুতা অবলন্বন করে।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxvii{তুমি কি তবে তাকে দেখেছ যে ফিরে যায়,\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxviii{আর যৎসামান্য দান করে এবং নির্দয়তা দেখায়?\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxix{তার কাছে কি অদৃশ্য সম্পর্কে জ্ঞান রয়েছে ফলে সে দেখত পাচ্ছে?\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxx{অথবা তাকে কি সংবাদ দেওয়া হয় নি মূসার গ্রন্থে যা আছে সে-সন্বন্ধে,\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxxi{এবং ইব্রাহীম সন্বন্ধে যিনি সম্পূর্ণরূপে প্রতিপালন করেছিলেন --\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxxii{যথা কোনো ভারবাহী অন্যের বোঝা বহন করবে না,\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxxiii{আর এই যে মানুষের জন্য কিছুই থাকবে না যার জন্য সে চেষ্টা না ক’রে,\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxxiv{আর এই যে, তার প্রচেষ্টা অচিরেই দৃষ্টিগোচর হবে,\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxxv{তারপর তাকে প্রতিদান দেওয়া হবে পরিপূর্ণ প্রতিদানে,\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxxvi{আর এই যে, তোমার প্রভুর দিকেই হচ্ছে শেষ-সীমা,\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxxvii{আর এই যে, তিনিই হাসান আর তিনিই কাঁদান,\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxxviii{আর এই যে, তিনিই মারেন ও তিনিই বাঁচান।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxxix{আর এই যে, তিনিই সৃষ্টি করেছেন জোড়ায়-জোড়ায় নর ও নারী, --\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxxx{শুক্রকীট থেকে যখন তাকে বিন্যাস করা হয়,\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxxxi{আর এই যে, তাঁর উপরেই রয়েছে পুনরায় উত্থানের দায়িত্ব,\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxxxii{আর এই যে, তিনিই ধনদৌলত দেন ও সুখ-সমৃদ্ধি প্রদান করেন,\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxxxiii{আর এই যে, তিনিই শি'রা নক্ষত্রের প্রভু,\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxxxiv{আর এই যে, তিনিই ধ্বংস করেছিলেন প্রাচীনকালের 'আদ-জাতিকে,\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxxxv{আর ছামূদ-জাতিও, তাই তিনি বাকী রাখেন নি,\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxxxvi{আর নূহ-এর লোকদলও এর আগে। নিঃসন্দেহ তারা ছিল -- তারাই তো ছিল অত্যন্ত অত্যাচারী ও বেজায় অবাধ্য।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxxxvii{আর উলটে ফেলা শহরগুলো -- তিনি ধ্বংস করেছিলেন,\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxxxviii{ফলে তাদের তিনি ঢেকে দিয়েছিলেন যা ঢেকে দেয়।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxxxix{অতএব তোমার প্রভুর কোন অনুগ্রহ সম্পর্কে তুমি বাদানুবাদ করবে?\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxl{প্রাচীনকালের সতর্ককারীদের মধ্যে থেকে ইনি হচ্ছেন একজন সতর্ককারী।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxli{আসন্ন ঘটনা সমাগত,\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxlii{এটি দূর করবার মতো আল্লাহ্ ছাড়া আর কেউ নেই।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxliii{এই বিবৃতিতে তোমরা কি তাজ্জব হচ্ছ?\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxliv{আর তোমরা কি হাসছ, তোমরা কি আর কাঁদবে না?\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxlv{আর তোমরা তো হেলাফেলা করছ।\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxlvi{অতএব আল্লাহ্‌র প্রতি সিজদা করো এবং উপাসনা করো।\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxlvii{\basmalahbn ঘড়িঘন্টা সমাগত, আর চন্দ্র দ্বিখন্ডিত হয়েছে।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxlviii{আর যদি তারা কোনো নিদর্শন দেখে, তারা ফিরে যায় ও বলে -- ''এক জবরদস্ত জাদু।’’\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxlix{আর তারা প্রত্যাখ্যান করে এবং তারা তাদের খেয়ালখুশির অনুসরণ করে, অথচ প্রত্যেক বিষয়েরই নিস্পত্তি হয়েই গেছে।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmdcccl{আর তাদের কাছে অবশ্য কিছুটা সংবাদ এসেই গেছে যাতে রয়েছে প্রতিষেধক --\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmdcccli{এক সুপরিণত জ্ঞান, কিন্তু এ সতর্কীকরণ কোনো কাজে আসে না।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmdccclii{কাজেই তাদের থেকে ফিরে এস। একদিন আহ্বানকারী আহ্বান করবেন এক অপ্রীতিকর ব্যাপারের প্রতি --\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmdcccliii{তাদের চোখ অবনত অবস্থায়, তারা বেরিয়ে আসতে থাকবে কবর থেকে যেন তারা ছড়িয়ে পড়া পঙ্গপাল --\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmdcccliv{ওরা আহবায়কের প্রতি ছুটে আসবে। অবিশ্বাসীরা বলবে -- ''এইটি বড় কঠিন দিন!’’\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmdccclv{এদের আগে নূহ-এর লোকদল সত্যপ্রত্যাখ্যান করেছিল, ফলে তারা আমাদের বান্দাকে প্রত্যাখ্যান করল ও বললে -- ''এক টি পাগল’’! আর তাঁকে অবজ্ঞা করা হয়েছিল।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmdccclvi{সেজন্য তিনি তাঁর প্রভুকে ডেকে বললেন -- ''আমি তো পরাভূত হয়ে পড়েছি, অতএব তুমি সাহায্য করো।’’\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmdccclvii{তখন আমরা আসমানের দরজাগুলো খুলে দিলাম বর্ষণশীল পানির দ্বারা,\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmdccclviii{আর জমিনকে উৎক্ষেপ করতে দিলাম ঝরনাধারায়, ফলে পানি মিলিত হয়ে গেল এক পূর্বনির্ধারিত ব্যাপারে,\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmdccclix{আর আমরা তাঁকে বহন করলাম তাতে যা ছিল তক্তা ও পেরেক সন্বলিত, --\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmdccclx{তা ভেসে চলেছিল আমাদের চোখের সামনে, -- এক প্রতিদান তাঁর জন্য যাঁকে প্রত্যাখ্যান করা হয়েছিল।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxi{আর আমরা অবশ্য এটিকে রেখে দিয়েছি এক নিদর্শনরূপে। কিন্তু কেউ কি রয়েছে উপদেশপ্রাপ্তদের অন্তর্ভুক্ত?\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxii{সুতরাং কেমন হয়েছিল আমার শাস্তি ও আমার সতর্কীকরণ!\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxiii{আর আমরা তো অবশ্যই কুরআনকে উপদেশগ্রহণের জন্য সহজবোধ্য করে দিয়েছি, কিন্তু কেউ কি আছে যে উপদেশপ্রাপ্তদের মধ্যেকার?\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxiv{আর 'আদ-জাতি সত্যপ্রত্যাখ্যান করেছিল, কাজেই কেমন হয়েছিল আমার শাস্তি ও আমার সতর্কীকরণ!\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxv{নিঃসন্দেহ আমরা তাদের উপরে এক চরম দুর্ভাগ্যের দিনে পাঠিয়েছিলাম এক প্রচন্ড ঝড়-তোফান,\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxvi{যা মানুষকে উড়িয়ে নিয়েছিল, যেন তারা ছিল উৎপাটিত খেজুরগাছের গুঁড়ি।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxvii{সুতরাং কেমন হয়েছিল আমার শাস্তি ও আমার সতর্কীকরণ?\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxviii{কাজেই আমরা আলবৎ কুরআনকে উপদেশ গ্রহণের জন্য সহজবোধ্য করে দিয়েছি, কিন্তু কেউ কি হবে উপদেশপ্রাপ্তদের অন্তর্ভুক্ত?\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxix{ছামুদ-জাতিও সতর্কীকরণ প্রত্যাখ্যান করেছিল।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxx{কাজেই তারা বলেছিল -- ''কী! আমাদের মধ্যেকার মানুষই একজন, তাকেই কি আমরা অনুসরণ করব? সেক্ষেত্রে আমরা তো নিশ্চয়ই বিপথগামী হব ও পাগলামিতে পড়ব।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxxi{''আমাদের মধ্যে থেকে স্মারক কি তার উপরেই পতিত হল? বস্তুত সে একজন ডাহা মিথ্যাবাদী, দাম্ভিক।’’\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxxii{কালকেই তারা ত্বরায় জানতে পারবে কে মিথ্যুক, কে দাম্ভিক।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxxiii{নিঃসন্দেহ আমরা একটি উষ্ট্রিকে পাঠাতে যাচ্ছি তাদের জন্য পরীক্ষাস্বরূপ, সেজন্য তাদের প্রতি লক্ষ্য রাখো এবং ধৈর্যধারণ করো।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxxiv{আর তাদের জানিয়ে দাও যে পানির ক্ষেত্রে তাদের মধ্যে ভাগাভাগি রয়েছে, প্রত্যেক জলপানে হাজিরা থাকবে।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxxv{কিন্তু তারা তাদের সেঙাৎকে ডাক দিল, তখন সে ধরল ও কেটে ফেলল।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxxvi{পরিণামে কেমন হয়েছিল আমার শাস্তি ও আমার সতর্কীকরণ!\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxxvii{আমরা অবশ্যই তাদের উপরে পাঠিয়েছিলাম একটিমাত্র মহাগর্জন, ফলে তারা হয়ে গেল খোঁয়াড়-প্রস্তুতকারীর শুকনো-ভাঙ্গা ডালপালার ন্যায়।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxxviii{আর আমরা নিশ্চয়ই কুরআনকে উপদেশ-গ্রহণের জন্য সহজবোধ্য করে দিয়েছি, কিন্তু কেউ কি রয়েছে উপদেশপ্রাপ্তদের অন্যতম?\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxxix{লুত-এর লোকদলও সতর্কীকরণ প্রত্যাখ্যান করেছিল।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxxx{নিঃসন্দেহ আমরা তাদের উপরে পাঠিয়েছিলাম এক পাথর বর্ষণকারী ঝড়, -- লুত-এর পরিজনদের ব্যতীত, আমরা তাদের উদ্ধার করেছিলাম শেষরাতে --\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxxxi{আমাদের তরফ থেকে এক অনুগ্রহ। এইভাবেই আমরা পুরস্কার দিই যে কৃতজ্ঞতা দেখায় তাকে।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxxxii{আর তিনি তো ইতিপূর্বেই তাদের সতর্ক করে দিয়েছিলেন আমাদের ভীষণভাবে পাকড়ানো সম্পর্কে, কিন্তু তারা আমার সতর্কীকরণ সন্বন্ধে কথা-কাটাকাটি করছিল।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxxxiii{আর তারা অবশ্য তাঁর কাছ থেকে তাঁর অতিথিদের চেয়েছিল, তখন আমরা তাদের চোখগুলোকে শেষ করে দিয়েছিলাম, ''অতএব আমার শাস্তি আস্বাদন কর আমার সতর্কীকরণের পরে।’’\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxxxiv{আর অবশ্য নির্ধারিত শাস্তি ভোরবেলাতে তাদের উপরে পড়েছিল।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxxxv{''আমার শাস্তি এখন আস্বাদন কর আমার সতর্কীকরণের পরে?’’\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxxxvi{আর আমরা তো নিশ্চয়ই কুরআনকে উপদেশ গ্রহণের জন্য সহজবোধ্য করে দিয়েইছি, কিন্তু কে আছে যে উপদেশপ্রাপ্তদের মধ্যেকার?\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxxxvii{আর অবশ্য ফিরআউনের লোকদের কাছে সতর্কীকরণ এসেছিল।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxxxviii{তারা আমাদের নিদর্শনসমূহ -- তাদের সবক’টি, প্রত্যাখ্যান করেছিল, সেজন্য আমরা তাদের পাকড়াও করেছিলাম মহাশক্তিশালী পরমক্ষমতাবানের পাকড়ানোর দ্বারা।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxxxix{তোমাদের অবিশ্বাসীরা কি এদের চাইতে ভাল, না তোমাদের জন্য অব্যাহতি রয়েছে ধর্মগ্রন্থের মধ্যে?\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxc{অথবা তারা কি বলে -- ''আমরা পরস্পরের সাহায্যকারী আস্ত একটা দল’’?\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxci{শীঘ্রই এ লোকদল বিধবস্ত হবে এবং পৃস্প্রদর্শন করে ফিরে যাবে।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxcii{বস্তুত ঘড়িঘন্টাই তাদের নির্ধারিত স্থানকাল, আর সেই ঘড়িঘন্টা হবে অতি কঠোর ও বড় তিক্ত।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxciii{নিঃসন্দেহ অপরাধীরা বিভ্রান্ত ও বিকারগ্রস্ত হবে।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxciv{সেই দিন তাদের মুখ হেচঁড়ে তাদের টেনে নিয়ে যাওয়া হবে আগুনের মধ্যে -- ''জ্বালাময় আগুনের স্পর্শ আস্বাদন করো!’’\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxcv{নিঃসন্দেহ প্রত্যেকটি জিনিস -- আমরা এটি সৃষ্টি করেছি পরিমাপ অনুসারে।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxcvi{আর আমাদের আদেশ একবার বৈ তো নয়, চোখের পলকের ন্যায়।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxcvii{আর আমরা তো তোমাদের সেঙাৎদের ধ্বংস করে দিয়েছিলাম, কিন্তু কেউ কি রয়েছে উপদেশপ্রাপ্তদের মধ্যেকার?\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxcviii{আর তারা যা করেছে তার সব-কিছুই নথিপত্রে রয়েছে।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxcix{আর ছোট ও বড় প্রত্যেকটি বিষয় লিপিবদ্ধ আছে।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmmmcm{ধর্মভীরুরা অবশ্যই থাকবে ঝরনাবেষ্টিত জান্নাতে --\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmmmcmi{সত্যের আসনে সর্বশক্তিমান রাজাধিরাজের সমক্ষে!\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mmmmcmii{\basmalahbn আর-রাহমান!\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmcmiii{তিনি কুরআন শিক্ষা দিয়েছেন।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmcmiv{তিনিই সৃষ্টি করেছেন মানুষকে,\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmcmv{তিনি তাকে শিখিয়েছেন সুস্পষ্ট ভাষা।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmcmvi{সূর্য ও চন্দ্র হিসেব মতো চলেছে।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmcmvii{আর তৃণলতা ও গাছপালা আনুগত্য করছে।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmcmviii{আর আকাশকে, -- তিনি তাকে সমুচ্চ করেছেন, আর তিনি স্থাপন করেছেন দাঁড়িপাল্লা।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmcmix{যেন তোমরা মাপকাঠিতে উল্লঙ্ঘন না করো।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmcmx{আর ওজন সঠিকভাবে কায়েম করো, আর মাপজোখে কমতি করো না।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmcmxi{আর পৃথিবী, -- তিনি এটিকে প্রসারিত করেছেন জীবজন্তুর জন্যে,\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmcmxii{তাতে রয়েছে ফলফসল ও গোছাবিশিষ্ট খেজুর গাছ,\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmcmxiii{আর আছে খোসা ও সুগন্ধি দানা-থাকা শস্য।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmcmxiv{অতএব তোমাদের উভয়ের প্রভুর কোন্ অনুগ্রহ তোমরা উভয়ে অস্বীকার করবে?\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmcmxv{তিনি মানুষকে সৃষ্টি করেছেন খনখনে মাটি দিয়ে মাটির বাসনের মতো,\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmcmxvi{আর তিনি জিনকে সৃষ্টি করেছেন আগুনের শিখা দিয়ে।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmcmxvii{সুতরাং তোমাদের প্রভুর কোন্ অনুগ্রহ তোমরা উভয়ে অস্বীকার করবে?\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmcmxviii{তিনি দুই পূর্বের প্রভু, আর দুই পশ্চিমেরও প্রভু।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmcmxix{সুতরাং তোমাদের প্রভুর কোন্ অনুগ্রহ তোমরা উভয়ে অস্বীকার করবে?\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmcmxx{তিনি প্রবাহিত করেছেন দুই জলরাশিকে --\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmcmxxi{তাদের উভয়ের মধ্যে রয়েছে এক ব্যবধান যা তারা অতিক্রম করতে পারে না।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmcmxxii{সুতরাং তোমাদের প্রভুর কোন্ অনুগ্রহ তোমরা উভয়ে অস্বীকার করবে?\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmcmxxiii{তাদের দুইয়ের মধ্যে থেকে বেরিয়ে আসে মুক্তো ও প্রবাল।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmcmxxiv{অতএব তোমাদের প্রভুর কোন্ অনুগ্রহ তোমরা উভয়ে অস্বীকার করবে?\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmcmxxv{আর তাঁরই হচ্ছে সমুদ্রে ভাসমান পর্বততুল্য জাহাজগুলো।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmcmxxvi{সুতরাং তোমাদের প্রভুর কোন্ অনুগ্রহ তোমরা উভয়ে অস্বীকার করবে?\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmcmxxvii{এর উপরে যারাই আছে তা বিনাশশীল,\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmcmxxviii{তবে বাকি থাকবে তোমার প্রভুর চেহারা -- পরম মহিমা ও মহানুভবতার অধিকারী।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmcmxxix{সুতরাং তোমাদের প্রভুর কোন্ অনুগ্রহ তোমরা উভয়ে অস্বীকার করবে?\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmcmxxx{মহাকাশমন্ডলে ও পৃথিবীতে যারা রয়েছে তারা তাঁরই কাছে প্রার্থনা জানায়। প্রতি নিয়ত তিনি মর্যাদায় বিরাজমান।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmcmxxxi{সুতরাং তোমাদের প্রভুর কোন্ অনুগ্রহ তোমরা উভয়ে অস্বীকার করবে?\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmcmxxxii{অবিলন্বে আমরা তোমাদের বিষয়ে হিসেব-নিকেশ নেব, হে দুই বৃহৎশক্তিবর্গ!\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmmcmxxxiii{সুতরাং তোমাদের প্রভুর কোন্ অনুগ্রহ তোমরা উভয়ে অস্বীকার করবে?\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmmcmxxxiv{হে জিন ও মানুষের সমবেতগোষ্ঠি! যদি তোমরা মহাকাশ-মন্ডল ও পৃথিবীর সীমারেখা থেকে বেরিয়ে যাবার ক্ষমতা রাখ তাহলে বেরিয়ে যাও। তোমরা অতিক্রম করতে পারবে না নির্দেশ ব্যতীত।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmmcmxxxv{অতএব তোমাদের প্রভুর কোন্ অনুগ্রহ তোমরা উভয়ে অস্বীকার করবে?\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmmcmxxxvi{তোমাদের উভয়ের জন্য পাঠানো হবে আগুনের শিখা ও তামার স্ফুলিঙ্গ, তখন তোমরা সাহায্য পেতে পারবে না।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmmcmxxxvii{তাই তোমাদের প্রভুর কোন্ অনুগ্রহ তোমরা উভয়ে অস্বীকার করবে?\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmmcmxxxviii{আর যখন আকাশ বিদীর্ণ হবে এবং হয়ে যাবে রংকরা চামড়ার মতো লাল, --\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmmcmxxxix{সুতরাং তোমাদের প্রভুর কোন্ অনুগ্রহ তোমরা উভয়ে অস্বীকার করবে? --\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmmcmxl{অতএব সেদিন কোনো মানুষকেই প্রশ্ন করা হবে না তার অপরাধ সন্বন্ধে, না কোনো জিনকে।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmmcmxli{সুতরাং তোমাদের প্রভুর কোন্ অনুগ্রহ তোমরা উভয়ে অস্বীকার করবে?\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmmcmxlii{অপরাধীদের চেনা যাবে তাদের চেহারার দ্বারা, কাজেই তাদের পাকড়ানো হবে চুলের ঝুঁটিতে ও ঠেঙ্গগুলোয়।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmmcmxliii{অতএব তোমাদের প্রভুর কোন্ অনুগ্রহ তোমরা উভয়ে অস্বীকার করবে?\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmmcmxliv{এইটিই জাহান্নাম যেটিকে অপরাধীরা মিথ্যা বলত।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmmcmxlv{তারা ছুটাছুটি করবে এর ও ফুটন্ত পানির চারিদিকে।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmmcmxlvi{তাই তোমাদের প্রভুর কোন্ অনুগ্রহ তোমরা উভয়ে অস্বীকার করবে?\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmmmcmxlvii{আর যে তার প্রভুর সামনে দাঁড়াবার ভয় রাখে তার জন্য রয়েছে দুটি স্বর্গোউদ্যান --\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmmmcmxlviii{অতএব তোমাদের প্রভুর কোন্ অনুগ্রহ তোমরা উভয়ে অস্বীকার করবে?\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmmmcmxlix{দুটোই ঘন ডালপালাবিশিষ্ট।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmmmcml{সুতরাং তোমাদের প্রভুর কোন্ অনুগ্রহ তোমরা উভয়ে অস্বীকার করবে?\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmmmcmli{তাদের মধ্যে বয়ে চলেছে দুটি নদী।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmmmcmlii{সুতরাং তোমাদের প্রভুর কোন্ অনুগ্রহ তোমরা উভয়ে অস্বীকার করবে?\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmmmcmliii{এ দুটোয় রয়েছে প্রত্যেক ফলমূলের জোড়া জোড়া।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmmmcmliv{অতএব তোমাদের প্রভুর কোন্ অনুগ্রহ তোমরা উভয়ে অস্বীকার করবে?\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmmmcmlv{তারা হেলান দিয়ে বসবে গালিচার উপরে যার আস্তর কারুকার্যময় রেশমের। আর উভয় জান্নাতের ফল ঝুলতে থাকবে।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmmmcmlvi{সুতরাং তোমাদের প্রভুর কোন্ অনুগ্রহ তোমরা উভয়ে অস্বীকার করবে?\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mmmmcmlvii{তাদের মধ্যে রয়েছে সলাজ-নম্র আয়তলোচন, -- এদের আগে কোনো মানুষ তাদের স্পর্শ করে নি, আর জিনও নয়।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mmmmcmlviii{সুতরাং তোমাদের প্রভুর কোন্ অনুগ্রহ তোমরা উভয়ে অস্বীকার করবে?\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mmmmcmlix{তারা যেন চুনি ও প্রবাল।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mmmmcmlx{অতএব তোমাদের প্রভুর কোন্ অনুগ্রহ তোমরা উভয়ে অস্বীকার করবে?\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxi{ভালোর পুরস্কার কি ভাল ছাড়া অন্য কিছু হবে?\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxii{সুতরাং তোমাদের প্রভুর কোন্ অনুগ্রহ তোমরা উভয়ে অস্বীকার করবে?\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxiii{আর এই দুটি ব্যতীত দুটি জান্নাত রয়েছে।\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxiv{সুতরাং তোমাদের প্রভুর কোন্ অনুগ্রহ তোমরা উভয়ে অস্বীকার করবে?\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxv{দুটোই গাঢ়-সবুজ।\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxvi{ফলে তোমাদের প্রভুর কোন্ অনুগ্রহ তোমরা উভয়ে অস্বীকার করবে?\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxvii{উভয়ের মধ্যে রয়েছে দুই উচ্ছলিত প্রস্রবণ।\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxviii{অতএব তোমাদের প্রভুর কোন্ অনুগ্রহ তোমরা উভয়ে অস্বীকার করবে?\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxix{উভয়ের মধ্যে রয়েছে ফলমূল ও খেজুর ও ডালিম।\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxx{ফলে তোমাদের প্রভুর কোন্ অনুগ্রহ তোমরা উভয়ে অস্বীকার করবে?\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxxi{সে দুটোতে রয়েছে সুশীলা সুন্দরীরা --\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxxii{সুতরাং তোমাদের প্রভুর কোন্ অনুগ্রহ তোমরা উভয়ে অস্বীকার করবে?\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxxiii{হূরগণ, -- তাঁবুর ভেতরে অন্তঃপুরবাসিনী।\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxxiv{সুতরাং তোমাদের প্রভুর কোন্ অনুগ্রহ তোমরা উভয়ে অস্বীকার করবে?\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxxv{এদের আগে কোনো মানুষ তাদের স্পর্শ করে নি, আর জিনও নয়।\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxxvi{অতএব তোমাদের প্রভুর কোন্ অনুগ্রহ তোমরা উভয়ে অস্বীকার করবে?\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxxvii{তারা হেলান দিয়ে বসে থাকবে সবুজ তাকিয়াতে ও মনোরম গালিচার উপরে।\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxxviii{সুতরাং তোমাদের প্রভুর কোন্ অনুগ্রহ তোমরা উভয়ে অস্বীকার করবে?\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxxix{কত কল্যাণময় তোমার প্রভুর নাম, তিনি অপার মহিমার ও বিপুল করুণার অধিকারী।\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxxx{\basmalahbn যখন বিরাট ঘটনাটি ঘটবে, --\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxxxi{এর সংঘটনকে মিথ্যা বলার কেউ থাকবে না।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxxxii{এটি লাঞ্ছিত করবে, এটি করবে সমুন্নত।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxxxiii{যখন পৃথিবী আলোড়িত হবে আলোড়নে,\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxxxiv{আর পাহাড়গুলো ভেঙ্গে পড়বে চূর্ণ-বিচূর্ণ হয়ে --\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxxxv{ফলে তা হয়ে যাবে বিক্ষিপ্ত ধূলিকণা,\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxxxvi{আর তোমরা হয়ে পড়বে তিনটি শ্রেণীতে --\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxxxvii{যথা ডান দিকের দল, -- কেমনতর এই ডানদিকের দল!\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxxxviii{আর বাঁদিকের দল, -- কেমনতর এই বাঁদিকের দল!\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxxxix{আর অগ্রগামীগণ তো অগ্রগামী,\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmcmxc{এরাই হবে নৈকট্যপ্রাপ্ত,\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmcmxci{আনন্দময় উদ্যানে।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmcmxcii{প্রথমকালীনদের থেকে অধিক সংখ্যায়,\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmcmxciii{আর পরবর্তীকালীনদের থেকে অল্প সংখ্যায়।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmcmxciv{কারুকার্যময় সিংহাসনে,\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmcmxcv{তাতে তারা হেলান দিয়ে আসন গ্রহণ করবে পরস্পর মুখোমুখি হয়ে।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmcmxcvi{তাদের চারিদিকে ঘুরে বেড়াবে চিরনবীন তরুণেরা --\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmcmxcvii{পানপাত্র ও সোরাই নিয়ে ও নির্মল পানীয়ের পেয়ালা।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmcmxcviii{তাদের মাথা ধরবে না তাতে, আর তাদের নেশাও ধরবে না।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmcmxcix{আর ফল-মূল যা তারা পছন্দ করে;\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmm{আর পাখির মাংস যা তারা কামনা করে,\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmmi{আর আয়তলোচন হূরগণ --\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmmii{আবৃত মুক্তার উদাহরণের ন্যায়; --\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmmiii{যা তারা করতো তার পুরস্কার।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmmiv{তারা সেখানে শুনবে না কোনো খেলোকথা, না কোনো পাপবাক্য, --\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmmv{শুধু এই কথা ছাড়া -- ''সালাম! সালাম!’’\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmmvi{আর ডানদিকের দল, -- কেমনতর এই ডানদিকের দল!\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmmvii{কাঁটা বিহীন সিদরাহ-গাছের নীচে,\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmmviii{আর সারি সারি সাজানো কলাগাছ,\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmmix{আর সুদূরবিস্তৃত ছায়া,\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmmx{আর উছলে ওঠা পানি,\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmmmxi{আর প্রচুর পরিমাণে ফলমূল,\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmmmxii{ব্যাহত হবার নয় এবং নিষিদ্ধ হবারও নয়।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmmmxiii{আর উঁচুদরের গালিচা।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmmmxiv{নিঃসন্দেহ আমরা ওদের সৃষ্টি করেছি বিশেষ সৃষ্টিতে;\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmmmxv{আর তাদের বানিয়েছি চিরকুমারী,\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmmmxvi{সোহাগিনী, সমবয়স্কা, --\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmmmxvii{দক্ষিণপন্থী লোকদের জন্য।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmmmxviii{প্রথমকালীনদের থেকে অধিক সংখ্যায়,\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmmmxix{আর পরবর্তীকালীনদের মধ্যে থেকেও অধিক সংখ্যায়।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmmmxx{কিন্তু বামপন্থীদল -- কেমনতর এই বামপন্থী দল।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmmmxxi{উত্তপ্ত বাতাসে ও ফুটন্ত পানিতে,\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmmmxxii{আর কালো ধোঁয়ার ছায়ায়,\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmmmxxiii{শীতল নয় এবং সম্মানজনকও নয়।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmmmxxiv{অথচ তারা তো এর আগে ছিল ভোগবিলাসে মগ্ন,\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmmmmxxv{আর তারা ঘোরতর পাপাচারে জেদ ধরে থাকত,\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmmmmxxvi{আর তারা বলত -- ''কী! আমরা যখন মরে যাব ও মাটি ও হাড্ডি হয়ে যাব তখন কি আমরা আদৌ পুনরুত্থিত হব, --\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmmmmxxvii{এবং আমাদের পূর্ববর্তী পিতৃপুরুষরাও?\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmmmmxxviii{তুমি বলো -- ''নিঃসন্দেহ পূর্ববর্তীরা এবং পরবর্তীরা --\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmmmmxxix{''অবশ্যই সবাইকে একত্রিত করা হবে এক সুবিদিত দিনের নির্ধারিত স্থানে-ক্ষণে,\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmmmmxxx{''তখন নিঃসন্দেহ তোমরাই, হে পথভ্রষ্ট মিথ্যাআরোপকারিগণ!\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmmmmxxxi{''তোমরা আলবৎ আহার করবে যিক্কুমের গাছের থেকে,\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmmmmxxxii{''এবং তাই দিয়ে তোমরা উদর পূর্ণ করবে,\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmmmmxxxiii{''তারপর তোমরা তার উপরে পান করবে উত্তপ্ত পানি,\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmmmmxxxiv{''আর তোমরা পান করবে তৃষ্ণার্ত উটের পান করার ন্যায়।’’\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mmmmmxxxv{এই হবে তাদের আপ্যায়ন বিচারের দিনে।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mmmmmxxxvi{আমরাই তো তোমাদের সৃষ্টি করেছি, তবে কেন তোমরা সত্য বলে স্বীকার কর না?\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mmmmmxxxvii{তোমরা কি তবে ভেবে দেখেছ -- যা তোমরা স্খলন কর?\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mmmmmxxxviii{তোমরা বুঝি ওকে সৃষ্টি করেছ, না আমরা সৃষ্টিকর্তা?\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mmmmmxxxix{আমরাই তোমাদের মধ্যে মৃত্যু ধার্য করে রেখেছি, আর আমরা প্রতিহত হব না, --\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mmmmmxl{যেন আমরা বদলে দিতে পারি তোমাদের অনুকরণে, এবং তোমাদের রূপান্তরিত করতে পারি তাতে যা তোমরা জান না।\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mmmmmxli{আর তোমরা অবশ্য প্রথম অভ্যুত্থান সন্বন্ধে অবগত হয়েছ, তবে কেন তোমরা ভেবে দেখ না?\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mmmmmxlii{তোমরা কি ভেবে দেখেছ যা তোমরা বপন কর?\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mmmmmxliii{তোমরা কি তা গজিয়ে তুলো, না আমরা বর্ধনকারী?\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mmmmmxliv{আমরা যদি চাইতাম তবে আমরা আলবৎ তাকে খড়-কুটোয় পরিণত করতে পারতাম, তখন তোমরা হাহুতাশ করতে থাকবে,\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mmmmmxlv{''আমরা তো নিশ্চয় ঋণগ্রস্ত হলাম,\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mmmmmxlvi{''বরং আমরা বঞ্চিত হলাম।’’\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mmmmmxlvii{তোমরা যে পানি পান কর সে-সন্বন্ধে তোমরা কি ভেবে দেখেছ?\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mmmmmxlviii{তোমরাই কি তা মেঘ থেকে নামিয়ে আন, না আমরা বর্ষণকারী?\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mmmmmxlix{আমরা যদি চাইতাম তাহলে আমরা তাকে লোনা করে দিতে পারতাম, কেন তবে তোমরা কৃতজ্ঞতা প্রকাশ কর না?\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@mmmmml{তোমরা যে আগুন জ্বালাও তা কি তোমরা লক্ষ্য করেছ?\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@mmmmmli{তোমরাই কি তার গাছকে জন্মইয়েছ, না আমরা উৎপাদনকারী?\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@mmmmmlii{আমরাই তাকে বানিয়েছি এক নিদর্শনসামগ্রী এবং মরুচারীদের জন্য এক প্রয়োজনসামগ্রী।\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@mmmmmliii{অতএব তোমার সর্বশক্তিমান প্রভুর নামের জপতপ করো।\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@mmmmmliv{না, আমি কিন্তু শপথ করছি নক্ষত্ররাজির অবস্থানের, --\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@mmmmmlv{আর নিঃসন্দেহ এটি তো এক বিরাট শপথ, যদি তোমরা জানতে, --\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@mmmmmlvi{নিঃসন্দেহ এটি তো এক সম্মানিত কুরআন,\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@mmmmmlvii{এক সুরক্ষিত গ্রন্থে।\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@mmmmmlviii{কেউ তা স্পর্শ করবে না পূত-পবিত্র ছাড়া।\qt@no{(79)}}
\qt@newcmd\qurantrans@bn@mmmmmlix{এটি এক অবতারণ বিশ্বজগতের প্রভুর কাছ থেকে।\qt@no{(80)}}
\qt@newcmd\qurantrans@bn@mmmmmlx{তা সত্ত্বেও কি সেই বাণীর প্রতি তোমরা তুচ্ছতাচ্ছিল্য ভাবাপন্ন,\qt@no{(81)}}
\qt@newcmd\qurantrans@bn@mmmmmlxi{এবং তোমাদের জীবিকা বানিয়ে নিয়েছ যে তোমরা মিথ্যা আখ্যা দেবে?\qt@no{(82)}}
\qt@newcmd\qurantrans@bn@mmmmmlxii{তবে কেন যখন কন্ঠাগত হয়ে যায়,\qt@no{(83)}}
\qt@newcmd\qurantrans@bn@mmmmmlxiii{এবং তোমরা যে-সময়ে তাকিয়ে থাকো,\qt@no{(84)}}
\qt@newcmd\qurantrans@bn@mmmmmlxiv{আমরা তখন তোমাদের চাইতে তার বেশী নিকটবর্তী কিন্তু তোমরা দেখতে পাও না।\qt@no{(85)}}
\qt@newcmd\qurantrans@bn@mmmmmlxv{যদি তোমরা আজ্ঞাধীন না হয়ে থাক তবে কেন তোমরা পার না --\qt@no{(86)}}
\qt@newcmd\qurantrans@bn@mmmmmlxvi{তাকে ফিরিয়ে দিতে, যদি তোমরা সত্যবাদী হও?\qt@no{(87)}}
\qt@newcmd\qurantrans@bn@mmmmmlxvii{আর পক্ষান্তরে যদি সে নৈকট্যপ্রাপ্তদের অন্তর্ভুক্ত হয়।\qt@no{(88)}}
\qt@newcmd\qurantrans@bn@mmmmmlxviii{তাহলে আয়েশ-আরাম ও সৌরভ, এবং আনন্দময় উদ্যান।\qt@no{(89)}}
\qt@newcmd\qurantrans@bn@mmmmmlxix{আর অপরপক্ষে সে যদি দক্ষিণপন্থীদের মধ্যেকার হয়,\qt@no{(90)}}
\qt@newcmd\qurantrans@bn@mmmmmlxx{তাহলে দক্ষিণপন্থীদের দলের থেকে -- ''তোমার প্রতি সালাম।’’\qt@no{(91)}}
\qt@newcmd\qurantrans@bn@mmmmmlxxi{আর পক্ষান্তরে সে যদি প্রত্যাখ্যানকারী পথভ্রষ্টদের অন্তর্ভুক্ত হয়ে থাকে, --\qt@no{(92)}}
\qt@newcmd\qurantrans@bn@mmmmmlxxii{তাহলে আপ্যায়ন হবে ফুটন্ত পানি দিয়ে,\qt@no{(93)}}
\qt@newcmd\qurantrans@bn@mmmmmlxxiii{এবং প্রবেশস্থল হবে ভয়ংকর আগুন!\qt@no{(94)}}
\qt@newcmd\qurantrans@bn@mmmmmlxxiv{নিঃসন্দেহ এটি অবশ্য সুনিশ্চিত সত্য।\qt@no{(95)}}
\qt@newcmd\qurantrans@bn@mmmmmlxxv{সুতরাং তোমার সর্বশক্তিমান প্রভুর নামের জপতপ করো।\qt@no{(96)}}
\qt@newcmd\qurantrans@bn@mmmmmlxxvi{\basmalahbn মহাকাশমন্ডলে ও পৃথিবীতে যা-কিছু আছে তা আল্লাহ্‌র জপতপ করে, আর তিনি মহাশক্তিশালী, পরমজ্ঞানী।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmlxxvii{তাঁরই হচ্ছে মহাকাশমন্ডল ও পৃথিবীর সার্বভৌমত্ব তিনি জীবন দান করেন ও মৃত্যু ঘটান, আর তিনিই সব-কিছুর উপরে সর্বশক্তিমান।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmlxxviii{তিনিই আদি ও অন্ত আর প্রকাশ্য ও গুপ্ত, কেননা তিনিই সব-কিছু সন্বন্ধে সর্বজ্ঞাতা।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmlxxix{তিনিই সেইজন যিনি মহাকাশমন্ডল ও পৃথিবী সৃষ্টি করেছেন ছয় দিনে, তারপর তিনি সমারোহণ করলেন আরশের উপরে। তিনি জানেন যা পৃথিবীর ভেতরে প্রবেশ করে এবং যা তা থেকে বেরিয়ে আসে, আর যা আকাশ থেকে নেমে আসে এবং যা তাতে উঠে যায়। আর তিনি তোমাদের সঙ্গে রয়েছেন যেখানেই তোমরা থাক না কেন। আর তোমরা যা কর সে-সন্বন্ধে আল্লাহ্ সম্যক দ্রষ্টা।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmlxxx{তাঁরই হচ্ছে মহাকাশমন্ডল ও পৃথিবীর সার্বভৌমত্ব আর আল্লাহ্‌রই প্রতি ব্যাপার-স্যাপারগুলো ফিরিয়ে নেওয়া হয়।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmlxxxi{তিনি রাতকে দিনের মধ্যে প্রবেশ করিয়ে দেন এবং দিনকে প্রবেশ করান রাতের মধ্যে। আর বুকের ভেতরে যা-কিছু আছে সে- সন্বন্ধে তিনি সর্বজ্ঞাতা।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmlxxxii{আল্লাহ্‌র ও তাঁর রসূলের প্রতি ঈমান আনো, এবং খরচ করো তা থেকে যা দিয়ে তিনি এতে তোমাদের উত্তরাধিকারী বানিয়েছেন। সুতরাং তোমাদের মধ্যের যারা ঈমান আনে ও খরচ করে, তাদের জন্য রয়েছে এক বিরাট প্রতিদান।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmlxxxiii{আর তোমাদের কি হয়েছে যে তোমরা আল্লাহ্‌তে বিশ্বাস করছ না, অথচ রসূল তোমাদের আহ্বান করছেন যেন তোমরা তোমাদের প্রভুর প্রতি বিশ্বাস স্থাপন করো, এবং তিনিও ইতিপূর্বেই তোমাদের থেকে অঙ্গীকার গ্রহণ করেছেন, -- যদি তোমরা বিশ্বাসী হয়ে থাকো?\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmlxxxiv{তিনিই সেইজন যিনি তাঁর বান্দার কাছে সুস্পষ্ট নির্দেশাবলী অবতারণ করছেন যেন তিনি তোমাদের বের কবে আনতে পারেন অন্ধকার থেকে আলোকের মধ্যে। আর আল্লাহ্ নিশ্চয়ই তোমাদের প্রতি তো পরম স্নেহময়, অফুরন্ত ফলদাতা।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmlxxxv{আর তোমাদের কি হয়েছে যে তোমরা আল্লাহ্‌র পথে খরচ কর না, অথচ আল্লাহ্‌রই হচ্ছে মহাকাশমন্ডল ও পৃথিবীর উত্তরাধিকার? তোমাদের মধ্যে তারা সমতুল্য নয় যারা সেই বিজয়ের পূর্বে খরচ করেছিল ও যুদ্ধ করেছিল। এরা শ্রেণীবিভাগে উচ্চতর তাদের থেকে যারা পরবর্তীকালে খরচ করে ও যুদ্ধ করে, আর প্রত্যেককেই আল্লাহ্ ওয়াদা করেছেন কল্যাণের। কেননা তোমরা যা কর সে-সন্বন্ধে আল্লাহ্ পূর্ণ ওয়াকিফহাল।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmlxxxvi{কে সেইজন যে আল্লাহ্‌কে কর্জ দেয় উত্তম কর্জ, ফলে তিনি এটিকে তারজন্য বহুগুণিত করে দেন, আর তার জন্য রয়েছে সম্মানিত পুরস্কার?\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmlxxxvii{সেইদিন তুমি বিশ্বাসীদের ও বিশ্বাসিনীদের দেখতে পাবে -- তাদের আলোক ধাবিত হয়েছে তাদের সম্মুখে ও তাদের ডানদিক দিয়ে, -- ''তোমাদের জন্য আজ সুসংবাদ -- স্বর্গোউদ্যানসমূহে যাদের নীচে দিয়ে বয়ে চলেছে ঝরনারাজি, সেখানে অবস্থান করবে।’’ এটিই হচ্ছে বিরাট সাফল্য।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmlxxxviii{সেই দিন যখন কপটাচারী ও কপটাচারিণীরা বলবে তাদের যারা বিশ্বাস করেছে -- ''আমাদের দিকে দেখো তো, তোমাদের আলোক থেকে যেন আমরা নিতে পারি।’’ বলা হবে -- ''তোমরা তোমাদের পেছনে ফিরে যাও এবং আলোর খোঁজ কর।’’ তারপর তাদের মধ্যে একটি দেওয়াল দাঁড় করানো হবে যাতে থাকবে একটি দরজা। তার ভেতরের দিকে, সেখানে রয়েছে করুণা, আর তার বাইরের দিকে, তার সামনেই রয়েছে শাস্তি।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmlxxxix{তারা তাদের ডেকে বলবে -- ''আমরা কি তোমাদের সঙ্গে ছিলাম না?’’ তারা বলবে -- ''হাঁ, কিন্ত তোমরা তোমাদের নিজেদের প্রলুব্ধ করেছিলে, আর প্রতীক্ষা করেছিলে, আর বৃথা কামনা তোমাদের প্রতারিত করেছিল যে পর্যন্ত না আল্লাহ্‌র বিধান এসেছিল, আর আল্লাহ্ সম্পর্কে মহাপ্রতারক তোমাদের প্রতারণা করেছিল।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmxc{''সেজন্য আজকের দিনে তোমাদের থেকে কোনো মুক্তিপণ গ্রহণ করা হবে না, আর যারা অবিশ্বাস করেছিল তাদের থেকেও নয়। তোমাদের আবাসস্থল হচ্ছে জাহান্নাম, এই-ই তোমাদের মুরব্বী, আর কত নিকৃষ্ট গন্তব্যস্থল!’’\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmxci{এখনও কি সময় হয় নি তাদের জন্য যে যারা বিশ্বাস করে তাদের হৃদয় বিনত হবে আল্লাহ্‌র স্মরণে এবং সত্যের যা অবতীর্ণ হয়েছে? আর তারা ওদের মতো না হোক যাদের পূর্ববর্তীকালে গ্রন্থ দেওয়া হয়েছিল, কিন্ত সময় তাদের জন্য সুদীর্ঘ মনে হয়েছিল, ফলে তাদের হৃদয় কঠিন হয়ে পড়েছিল। আর তাদের মধ্যের অনেকেই হয়েছিল সত্যত্যাগী।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmxcii{তোমরা জেনে রাখো যে আল্লাহ্ পৃথিবীটাকে তার মৃত্যুর পরে প্রাণ সঞ্চার করেন। আমরা তো তোমাদের জন্য নির্দেশাবলী সুস্পষ্ট করে দিয়েছি যেন তোমরা বুঝতে পার।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmxciii{নিঃসন্দেহ দানশীল পুরুষ ও দানশীলা নারীরা আর যারা আল্লাহ্‌কে উত্তম ঋণ দান করে -- তাদের জন্য তা বহুগুণিত করা হবে, আর তাদের জন্য রয়েছে সম্মানিত পুরস্কার।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmxciv{আর যারা আল্লাহ্‌র প্রতি ও তাঁর রসূলের প্রতি ঈমান এনেছে, তারাই খোদ সত্যপরায়ণ এবং তাদের প্রভুর সমক্ষে সাক্ষ্যদাতা। তাদের জন্য রয়েছে তাদের প্রতিদান ও তাদের আলোক। পক্ষান্তরে যারা অবিশ্বাস করে ও আমাদের নির্দেশাবলী প্রত্যাখ্যান করে, তারাই হচ্ছে ভয়ংকর আগুনের বাসিন্দা।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmmxcv{তোমরা জেনে রাখো যে পার্থিব জীবনটা তো খেলা-ধূলো ও আমোদ-প্রমোদ ও জাঁকজমক ও তোমাদের নিজেদের মধ্যে হামবড়াই এবং ধনদৌলত ও সন্তানসন্ততির প্রতিযোগিতা মাত্র। এটি বৃষ্টির উপমার মতো যার উৎপাদন চাষীদের চমৎকৃত করে, তারপর তা শুকিয়ে যায়, তুমি তখন তা দেখতে পাও হলদে হয়ে গেছে, অবশেষে তা খড়কুটো হয়ে যায়! আর পরকালে রয়েছে কঠোর শাস্তি, পক্ষান্তরে রয়েছে আল্লাহ্‌র কাছ থেকে পরিত্রাণ ও সন্তষ্টি। আর পার্থিব জীবন ছলনাময় ভোগবিলাস বৈ তো নয়।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmmxcvi{তোমরা প্রতিযোগিতা করো তোমাদের প্রভুর কাছ থেকে পরিত্রাণ লাভের জন্য এবং এমন এক জান্নাতের জন্য যার বিস্তার হচ্ছে মহাকাশ ও পৃথিবীর বিস্তৃতির মতো, -- এটি তৈরি করা হয়েছে তাদের জন্য যারা আল্লাহ্‌তে ও তাঁর রসূলের প্রতি ঈমান আনে। এ হচ্ছে আল্লাহ্‌র অনুগ্রহ প্রাচুর্য, তিনি তা প্রদান করেন যাকে তিনি ইচ্ছা করেন। বস্তুত আল্লাহ্ বিরাট করুণাভান্ডারের অধিকারী।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmmxcvii{এমন কোনো বিপর্যয় পৃথিবীতে পতিত হয় না আর তোমাদের নিজেদের উপরেও নয় যা আমরা ঘটাবার আগে একটি কিতাবে না রয়েছে। নিঃসন্দেহ এটি আল্লাহ্‌র জন্যে সহজ।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmmxcviii{এজন্য যে তোমরা যেন দুঃখ করো না যা তোমাদের থেকে হারিয়ে যায়, এবং তোমরা যেন উল্লাস না করো যা তিনি তোমাদের প্রদান করেন সেজন্য। আর আল্লাহ্ ভালবাসেন না সমূদয় অবিবেচক অহংকারীকে, --\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmmxcix{যারা কার্পণ্য করে, আর লোকেদেরও কার্পণ্যের নির্দেশ দেয়। আর যে কেউ ফিরে যায়, তবে নিশ্চয় আল্লাহ, তিনিই ধনবান, প্রশংসার্হ।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmmc{আমরা তো আমাদের রসূলগণকে পাঠিয়ে দিয়েছিলাম সুস্পষ্ট প্রমাণাদি দিয়ে, আর তাঁদের সঙ্গে আমরা অবতারণ করেছিলাম ধর্মগ্রন্থ ও মানদন্ড যাতে লোকেরা ন্যায়বিচার প্রতিষ্ঠা করতে পারে, আর আমরা লোহা পাঠিয়েছি যাতে রয়েছে বিরাট শক্তিমত্তা ও মানুষের জন্য উপকারিতা, আর যেন আল্লাহ্ জানতে পারেন কে তাঁকে ও তাঁর রসূলগণকে অগোচরেও সাহায্য করে। নিঃসন্দেহ আল্লাহ্ মহাবলীয়ান, মহাশক্তিশালী।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmmci{আর আমরা ইতিপূর্বে নূহ্‌কে ও ইব্রাহীমকে পাঠিয়েছিলাম, আর তাঁদের বংশধরদের মধ্যে নবুওৎ ও গ্রন্থ সংস্থাপন করেছিলাম, কাজেই তাদের কেউ-কেউ ছিল সৎপথপ্রাপ্ত, কিন্ত তাদের অধিকাংশই ছিল সত্যত্যাগী।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmmcii{তারপর আমাদের রসূলগণকে তাঁদের পদচিহ্নে চলতে দিয়েছিলাম, আর মরিয়ম-পুত্র ঈসাকে আমরা অনুসরণ করিয়েছিলাম ও তাঁকে আমরা ইনজীল দিয়েছিলাম, আর যারা তাঁর অনুসরণ করেছিল তাদের অন্তরে আমরা সদয়তা ও করুণা দিয়েছিলাম। কিন্ত সন্ন্যাসবাদ -- তারাই এটি আবিস্কার করেছিল, আমরা তাদের প্রতি এটি লিপিবদ্ধ করি নি, শুধু আল্লাহ্‌র সন্তষ্টির অনুসন্ধান করা, কিন্ত তারা এটি পালন করে নি যেমনটা এটি পালনের যোগ্য ছিল। ফলে তাদের মধ্যের যারা ঈমান এনেছিল তাদের আমরা দিয়েছিলাম তাদের প্রতিদান, কিন্ত তাদের অধিকাংশই ছিল সত্যত্যাগী।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmmciii{ওহে যারা ঈমান এনেছ! আল্লাহ্‌কে ভয়ভক্তি করো এবং তাঁর রসূলের প্রতি বিশ্বাসস্থাপন করো, তিনি তাঁর করুণা থেকে দুটি অংশ তোমাদের প্রদান করবেন, আর তোমাদের জন্য তিনি একটি আলোক স্থাপন করবেন যার মধ্যে তোমরা পথ চলতে পারো, এবং তিনি তোমাদের পরিত্রাণ করতে পারেন। আর আল্লাহ্ পরিত্রাণকারী, অফুরন্ত ফলদাতা --\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmmciv{গ্রন্থধারীরা হয়ত নাও জানতে পারে যে তারা আল্লাহ্‌র করুণাভান্ডারের মধ্যের কোনো কিছুতেই ক্ষমতা রাখে না, আর এই যে করুণাভান্ডার তো আল্লাহ্‌রই হাতে রয়েছে, তিনি এটি প্রদান করেন যাকে তিনি ইচ্ছা করেন। বস্তুত আল্লাহ্ বিরাট করুণাভান্ডারের অধিকারী।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmmcv{\basmalahbn আল্লাহ্ আলবৎ তার কথা শুনেছেন যে তার স্বামী সন্বন্ধে তোমার কাছে অনুযোগ করছে আর আল্লাহ্‌র নিকট ফরিয়াদ করছে, আর আল্লাহ্ তোমাদের দুজনের কথোপকথন শুনেছেন। নিশ্চয় আল্লাহ্ সর্বশ্রোতা, সম্যক দ্রষ্টা।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmcvi{তোমাদের মধ্যের যারা তাদের স্ত্রীদের থেকে 'যিহার’ করে, -- তারা তাদের মা নয়। তাদের মায়েরা তো শুধু যারা তাদের জন্মদান করেছে তারা বৈ তো নয়। আর তারা তো নিঃসন্দেহ কথা বলছে এক গর্হিত কথা ও একটি ডাহা মিথ্যা। আর নিঃসন্দেহ আল্লাহ্ নিশ্চিত মার্জনাকারী, পরিত্রাণকারী।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmcvii{আর যারা তাদের স্ত্রীদের থেকে 'যিহার’ করে, তারপর তারা যা বলেছে তা প্রত্যাহার করে, সেক্ষেত্রে একে-অপরকে স্পর্শ করার পূর্বে একটি দাসের মুক্তিদান। এইটির দ্বারাই তোমাদের নির্দেশ দেওয়া হলো। আর তোমরা যা করছ সে-সন্বন্ধে আল্লাহ্ চির- ওয়াকিফহাল।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmcviii{কিন্ত যে খোঁজে পায় না, তবে একে-অপরকে স্পর্শ করার পূর্বে পরপর দুই মাস রোযা রাখা। কিন্ত যে শক্তি রাখে না, তা’হলে ষাটজন অভাবগ্রস্তকে খাওয়ানো। এ এজন্য যে তোমরা যেন আল্লাহ্ ও তাঁর রসূলের প্রতি বিশ্বাস স্থাপন কর, আর এগুলো হচ্ছে আল্লাহ্‌র বিধি-নিষেধ। আর অবিশ্বাসীদের জন্য রয়েছে মর্মন্তুদ শাস্তি।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmcix{নিঃসন্দেহ যারা আল্লাহ্ ও তাঁর রসূলের বিরুদ্ধাচরণ করে তাদের অপদস্থ করা হবে যেমন অপদস্থ করা হয়ে ছিল তাদের যারা ছিল এদের পূর্ববর্তী, আর আমরা সুস্পষ্ট নির্দেশাবলী অবতারণ করেই দিয়েছি। আর অবিশ্বাসীদের জন্য রয়েছে লাঞ্ছনাদায়ক শাস্তি।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmcx{একদিন আল্লাহ্ তাদেরকে একই সঙ্গে উঠিয়ে আনবেন, তখন তিনি তাদের জানিয়ে দেবেন কি তারা করেছিল। আল্লাহ্ এর হিসাব রেখেছেন যদিও তারা তা ভুলে গেছে। বস্তুত আল্লাহ্ সব-কিছুর উপরে সাক্ষী রয়েছেন।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmcxi{তুমি কি লক্ষ্য কর নি যে আল্লাহ্ জানেন যা-কিছু আছে মহাকাশমন্ডলে ও যা-কিছু রয়েছে পৃথিবীতে? তিনজনের কোনো গোপন পরামর্শ-সভা নেই যেখানে তিনি তাদের চতুর্থজন নন, আর পাঁচজনেরও নেই যেখানে তিনি তাদের ষষ্ঠজন নন, আর এর চেয়ে কম হোক অথবা বেশী হোক, সর্বাবস্থায় তিনি তাদের সঙ্গে রয়েছেন যেখানেই তারা থাকুক না কেন। তারপর তিনি কিয়ামতের দিনে তাদের জানিয়ে দেবেন কি তারা করেছিল। নিঃসন্দেহ আল্লাহ্ সব-কিছু সন্বন্ধে সর্বজ্ঞাতা।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmcxii{তুমি কি তাদের প্রতি লক্ষ্য কর নি যাদের নিষেধ করা হয়েছিল গোপন পরামর্শ-সভা পাততে, তারপর তারা ফিরে গিয়েছিল তাতে যা করতে তাদের নিষেধ করা হয়েছিল? আর তারা সলা-পরামর্শ করছে পাপাচরণে ও শত্রুতায় ও রসূলের প্রতি বিরুদ্ধাচরণের জন্য, আর যখন তারা তোমার কাছে আসে তখন তারা তোমাকে সম্ভাষণ করে এমনভাবে যেভাবে আল্লাহ্ তোমাকে সম্ভাষণ করেন না। আর তারা নিজেদের মধ্যে বলাবলি করে -- ''কেন আল্লাহ্ আমাদের শাস্তি দেন না আমরা যা বলি সেজন্য?’’ তাদের জন্য জাহান্নামই যথেষ্ট -- তারা তাতেই প্রবেশ করবে, সুতরাং কত নিকৃষ্ট এই গন্তব্যস্থল!\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmcxiii{ওহে যারা ঈমান এনেছ! যখন তোমরা কোনো গোপন পরামর্শ-সভা পাতো তখন তোমরা পরামর্শ করো না পাপাচরণ ও শত্রুতা ও রসূলের প্রতি অবাধ্যতার জন্য, বরং তোমরা পরামর্শ করো সৎকর্মের ও ধর্মভীরুতার জন্যে, আর আল্লাহ্‌কে ভয়-ভক্তি করো যাঁর কাছে তোমাদের একত্রিত করা হবে।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmcxiv{নিঃসন্দেহ সলা-পরামর্শ কেবল শয়তানের তরফ থেকে হয়ে থাকে, যেন সে যন্ত্রণা দিতে পারে তাদের যারা ঈমান এনেছে, বস্তুত তাদের কোনো অনিষ্ট হতে পারে না আল্লাহ্‌র অনুমতি ব্যতীত। কাজেই আল্লাহ্‌র উপরেই তবে নির্ভর করুক বিশ্বাসিগণ।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmcxv{ওহে যারা ঈমান এনেছ! যখন তোমাদের বলা হয় মজলিস-গুলোয় জায়গা করে দাও, তখন জায়গা করে দিয়ো, আল্লাহ্ তোমাদের জন্য জায়গা করে দেবেন। আর যখন বলা হয় উঠে দাঁড়াও, তখন উঠে দাঁড়িয়ো, তোমাদের মধ্যের যারা ঈমান এনেছে ও যাদের জ্ঞান দেওয়া হয়েছে আল্লাহ্ তাদের স্তরে স্তরে মর্যাদায় উন্নত করবেন। আর তোমরা যা করছ সে-সন্বন্ধে আল্লাহ্ চির-ওয়াকিফহাল।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmcxvi{ওহে যারা ঈমান এনেছ! তোমরা যখন রসূলের সঙ্গে ব্যক্তিগত পরামর্শ কর তখন তোমাদের পরামর্শের আগে দান-খয়রাত আগবাড়াবে, এইটি তোমাদের জন্য শ্রেয় ও পবিত্রতর। কিন্ত যদি তোমরা না পাও তবে নিঃসন্দেহ আল্লাহ্ পরিত্রাণকারী, অফুরন্ত ফলদাতা।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmcxvii{কী! তোমরা কি তোমাদের ব্যক্তিগত পরামর্শের আগে দান-খয়রাত আগবাড়াতে ভয় করছ? সুতরাং যখন তোমরা কর না, আর আল্লাহ্ তোমাদের প্রতি ফেরেন, তখন নামায কায়েম করো ও যাকাত আদায় করো, আর আল্লাহ্ ও তাঁর রসূলের আজ্ঞাপালন করো। আর তোমরা যা করছ সে-সন্বন্ধে আল্লাহ্ চির-ওয়াকিফহাল।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmcxviii{তুমি কি তাদের প্রতি লক্ষ্য কর নি যারা এমন এক জাতির সহিত বন্ধুত্ব পাতে যাদের উপরে আল্লাহ্ রুষ্ট হয়েছেন? তারা তোমাদের দলভুক্ত নয় আর তাদেরও অন্তর্ভুক্ত নয়। আর তারা জেনে-শুনেই মিথ্যা হলফ করে।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmcxix{আল্লাহ্ তাদের জন্য তৈরি করেছেন ভীষণ শাস্তি। বস্তুত তারা যা করে চলেছে তা কত মন্দ!\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmcxx{তারা তাদের শপথগুলোকে আবরণ হিসেবে গ্রহণ করেছে, ফলে তারা আল্লাহ্‌র পথ থেকে ফিরিয়ে রাখে, সুতরাং তাদের জন্য রয়েছে লাঞ্ছনাদায়ক শাস্তি।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmcxxi{আল্লাহ্‌র মোকাবিলায় তাদের ধনদৌলত কোনো প্রকারেই তাদের কোনো কাজে আসবে না, আর তাদের সন্তানসন্ততিও না। এরা হচ্ছে আগুনের অধিবাসী। তারা তাতেই অবস্থান করবে।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmcxxii{সেইদিন আল্লাহ্ তাদের সবাইকে পুনরুত্থিত করবেন, তখন তারা তাঁর কাছে হলফ করবে যেমন তারা তোমাদের কাছে হলফ করছে, আর তারা হিসেব করছে যে তারা নিশ্চয় একটা কিছুতে রয়েছে। তারাই কি স্বয়ং মিথ্যাবাদী নয়?\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmcxxiii{শয়তান তাদের উপরে কাবু করে ফেলেছে, সেজন্য সে তাদের আল্লাহ্‌কে স্মরণ করা ভুলিয়ে দিয়েছে। এরাই হচ্ছে শয়তানের দল। এটি কি নয় যে শয়তানের সাঙ্গোপাঙ্গরা নিজেরাই তো ক্ষতিগ্রস্ত দল?\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmmcxxiv{নিঃসন্দেহ যারা আল্লাহ্‌র ও তাঁর রসূলের বিরুদ্ধাচরণ করে তারাই হবে চরম লাঞ্ছিতদের মধ্যেকার।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmmcxxv{আল্লাহ্ বিধান করেছেন -- ''অবশ্য আমি ও আমার রসূলগণ বিজয়ী হবই।’’ নিঃসন্দেহ আল্লাহ্ মহাবলীয়ান, মহাশত্তি শালী।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmmcxxvi{তুমি আল্লাহ্‌তে ও পরকালে বিশ্বাস করে এমন কোনো জাতি পাবে না যারা বন্ধুত্ব পাতছে তাদের সঙ্গে যারা আল্লাহ্ ও তাঁর রসূলের বিরুদ্ধাচরণ করছে। হোক না কেন তারা তাদের পিতা-পিতামহ অথবা তাদের সন্তানসন্ততি অথবা তাদের ভাই-বিরাদর অথবা তাদের আ‌ত্মীয়-স্বজন। এরাই -- এদের অন্তরে তিনি ধর্মবিশ্বাস লিখে দিয়েছেন এবং তাদের বলবৃদ্ধি করেছেন তাঁর কাছ থেকে প্রেরণা দিয়ে। আর তিনি তাদের প্রবেশ করাবেন জান্নাতে যাদের নিচে দিয়ে বয়ে চলেছে ঝরনারাজি, তাতে তারা থাকবে চিরকাল। আল্লাহ্ তাদের উপরে প্রসন্ন থাকবেন, আর তারাও তাঁর প্রতি প্রসন্ন রইবে। এরাই হচ্ছে আল্লাহ্‌র দলের। এটি কি নয় যে আল্লাহ্‌র দলীয়রাই তো খোদ সাফল্যপ্রাপ্ত?\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmmcxxvii{\basmalahbn আল্লাহ্‌র মহিমা ঘোষণা করছে যা-কিছু আছে মহাকাশমন্ডলে ও যা-কিছু আছে পৃথিবীতে, আর তিনি মহাশক্তিশালী, পরমজ্ঞানী।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmcxxviii{তিনিই সেইজন যিনি গ্রন্থধারীদের মধ্যের যারা অবিশ্বাস পোষণ করেছিল তাদের বিতাড়িত করে দিয়েছিলেন তাদের বাড়িঘর থেকে প্রথমকার সমাবেশে। তোমরা ভাবো নি যে তারা বেরিয়ে যাবে, আর তারা ভেবেছিল যে তাদের দুর্গগুলি তাদের সংরক্ষণ করবে আল্লাহ্‌র বিরুদ্ধে, কিন্ত আল্লাহ্ তাদের কাছে এসে পৌঁছেছিলেন এমন এক দিক থেকে যা তারা ধারণা করে নি, আর তিনি তাদের অন্তরে ভয় সঞ্চার করেছিলেন, তারা তাদের বাড়িঘর বিনষ্ট করেছিল তাদের নিজেদের হাত দিয়ে, আর মুমিনদের হাত দিয়ে। অতএব তোমরা শিক্ষা গ্রহণ করো, হে চক্ষুষ্মান্ লোকেরা!\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmcxxix{আর যদি এ না হতো যে আল্লাহ্ তাদের জন্যে নির্বাসনের সিদ্ধান্ত করেছেন তাহলে তিনি অবশ্যই তাদের এই দুনিয়াতেই শাস্তি দিতেন। আর তাদের জন্য আখেরাতে রয়েছে আগুনের শাস্তি।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmcxxx{এ এইজন্য যে তারা আল্লাহ্ ও তাঁর রসূলের বিরুদ্ধাচরণ করেছিল, আর যে কেউ আল্লাহ্‌র বিরুদ্ধাচরণ করে, আল্লাহ্ তবে নিশ্চয়ই প্রতিফল দানে কঠোর।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmcxxxi{তোমরা যে-কতক খেজুর গাছ কেটে ফেলেছ অথবা যেগুলোকে তাদের শিকড়ের উপরে খাড়া রেখে দিয়েছ, তা তো আল্লাহ্‌রই অনুমতিক্রমে, আর যেন তিনি সত্যত্যাগীদের লাঞ্ছিত করতে পারেন।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmcxxxii{আর যা-কিছু তাদের থেকে আল্লাহ্ তাঁর রসূলকে ফাও দিয়েছেন, যার জন্য তোমরা ধাওয়া করাও নি কোনো ঘোড়া, আর না কোনো উট, কিন্ত আল্লাহ্ তাঁর রসূলগণকে দখল দিয়ে থাকেন যার উপরে তিনি ইচ্ছা করে থাকেন। আর আল্লাহ্ সব-কিছুর উপরে সর্বশক্তিমান।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmcxxxiii{আল্লাহ্ তাঁর রসূলকে জনপদবাসীর নিকট থেকে যা-কিছু ফাও দিয়েছেন তা কিন্ত আল্লাহ্‌র জন্য, আর রসূলের জন্য, আর নিকট- আ‌ত্মীয়দের জন্য, আর এতীমদের ও নিঃস্বদের ও পথচারীদের জন্য, যাতে তা তোমাদের মধ্যেকার ধনীদের মধ্যেই ঘোরাঘুরির বস্তু না হয়। আর রসূল যা-কিছু তোমাদের দেন তা তবে গ্রহণ করো, আর যা-কিছু তিনি নিষেধ করেন তোমরা বিরত থাকো। আর আল্লাহ্‌কে ভয়ভক্তি করো, নিঃসন্দেহ আল্লাহ্ প্রতিফল দানে কঠোর।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmcxxxiv{সেইসব দরিদ্র মুহাজিরদের জন্য যাদের বের করে দেওয়া হয়েছিল তাদের বাড়িঘর ও তাদের বিষয়-সম্পত্তি থেকে, যারা কামনা করছিল আল্লাহ্‌র কাছ থেকে অনুগ্রহ-প্রাচুর্য ও সন্তষ্টি, এবং সাহায্য করছিল আল্লাহ্‌কে ও তাঁর রসূলকে। এরাই খোদ সত্যপরায়ণ।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmcxxxv{আর যারা তাদের পূর্বেই বাড়িঘর ও ধর্মবিশ্বাস সুপ্রতিষ্ঠিত করেছিল তারা ভালবাসে তাদের যারা তাদের কাছে হিজরত করে এসেছে, আর তারা তাদের অন্তরে কোনো প্রয়োজন বোধ করে না তাদের যা দেওয়া হয়েছে তার জন্য, আর তারা তাদের নিজেদের চেয়েও অগ্রাধিকার দেয় যদিও বা তারা স্বয়ং অভাবগ্রস্ত রয়েছে। আর যে কেউ তার অন্তরের কৃপণতা থেকে মুক্ত রেখেছে তারাই তাহলে খোদ সফলকাম।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmcxxxvi{আর যারা তাদের পরে এসেছিল তারা বলে -- ''আমাদের প্রভু! আমাদের পরিত্রাণ করো আর আমাদের ভাই-বন্ধুদের যারা ধর্মবিশ্বাসে আমাদের অগ্রবর্তী রয়েছেন, আর আমাদের অন্তরে কোনো হিংসা-বিদ্বেষ রেখো না তাদের প্রতি যারা ঈমান এনেছেন; আমাদের প্রভু! তুমিই নিশ্চয় পরম স্নেহময়, অফুরন্ত ফলদাতা।’’\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmcxxxvii{তুমি কি তাদের দেখ নি যারা কপটাচরণ করছে, -- তারা গ্রন্থধারীদের মধ্যের যারা অবিশ্বাস পোষণ করে তাদের তেমন ভাই- বন্ধুদের বলে -- ''তোমাদের যদি বের করে দেওয়া হয় তাহলে আমরাও নিশ্চয়ই তোমাদের সঙ্গে বেরিয়ে যাব, আর তোমাদের ব্যাপারে আমরা কারোর তাবেদারি কখনো করব না, আর তোমাদের সঙ্গে যদি যুদ্ধ করা হয় তাহলে আমরা নিশ্চয়ই তোমাদের সাহায্য করব’’? আর আল্লাহ্ সাক্ষ্য দিচ্ছেন যে তারা নিশ্চয়ই মিথ্যাবাদী।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmcxxxviii{যদি তাদের বহিস্কার করা হয়, তারা তাদের সঙ্গে বেরুবে না, আর যদি তাদের সঙ্গে যুদ্ধ করা হয় তাহলে তারা তাদের সাহায্য করবে না, আর যদিও তারা তাদের সাহায্য করতে আসে তাহলেও তারা পৃষ্ঠপ্রদর্শন করবে, শেষপর্যন্ত তাদের সাহায্য করা হবে না।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmcxxxix{তোমরাই বরং তাদের অন্তরে আল্লাহ্‌র চাইতেও অধিকতর ভয়াবহ। এ এইজন্য যে তারা হচ্ছে এমন এক লোকদল যারা বুদ্ধি- বিবেচনা রাখে না।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmcxl{তারা সংঘবদ্ধ হয়ে তোমাদের বিরুদ্ধে যুদ্ধ করবে না সুরক্ষিত জন-বসতির ভেতরে অথবা দেওয়াল দুর্গের আড়াল থেকে ব্যতীত। তাদের নিজেদের মধ্যে তাদের সংঘর্ষ অতি প্রচন্ড। তুমি তাদের ভাবতে পার ঐক্যবদ্ধ, কিন্ত তাদের অন্তর হচ্ছে বিচ্ছিন্ন। এ এইজন্য যে তারা হচ্ছে এমন এক জাতি যারা বুদ্ধিশুদ্ধি রাখে না।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmcxli{এরা তাদের মতো যারা এদের অব্যবহিত পূর্বে অবস্থান করছিল, -- তারা তাদের কৃতকর্মের কুফল আস্বাদন করেছিল, আর তাদের জন্য রয়েছে মর্মন্তুদ শাস্তি।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmcxlii{শয়তানের সমতুল্য, দেখো! সে মানুষকে বলে -- ''অবিশ্বাস করো’’, তারপর যখন সে অবিশ্বাস করে তখন সে বলে -- ''আমি নিশ্চয়ই তোমার থেকে সম্পর্কচ্যুত, আমি অবশ্যই বিশ্বজগতের প্রভু আল্লাহ্‌কে ভয় করি।’’\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmcxliii{সুতরাং তাদের উভয়ের পরিণাম এই যে উভয়েই থাকবে আগুনে, তারা সেখানে দীর্ঘকাল অবস্থান করবে। আর এই হচ্ছে অন্যায়াচারীদের প্রতিফল।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmcxliv{ওহে যারা ঈমান এনেছ! আল্লাহ্‌কে ভয়-ভক্তি করো, আর প্রত্যেকেই ভেবে দেখুক কী সে আগবাড়াচ্ছে আগামীকালের জন্য, আর আল্লাহ্‌কে ভয়ভক্তি করো। নিঃসন্দেহ তোমরা যা করছ আল্লাহ্ সে-সন্বন্ধে পূর্ণ-ওয়াকিফহাল।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmcxlv{আর তোমরা তাদের মতো হয়ো না যারা আল্লাহ্‌কে ভুলে যায়, ফলে তিনি তাদের ভুলিয়ে দিয়ে থাকেন তাদের নিজেদের সন্বন্ধে। তারাই স্বয়ং সত্যত্যাগী।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmmcxlvi{আগুনের বাসিন্দারা ও জান্নাতের বাসিন্দারা একসমান নয়। জান্নাতের অধিবাসীরাই স্বয়ং সফলকাম।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmmcxlvii{আমরা যদি এই কুরআনকে কোনো পাহাড়ের উপরে অবতীর্ণ করতাম তাহলে তুমি দেখতে পেতে আল্লাহ্‌র ভয়ে তা নুইয়ে পড়েছে, ভেঙ্গে চুরমার হয়ে গেছে। আর এই উপমা -- আমরা এটি লোকেদের জন্য বিবৃত করছি যেন তারা চিন্তা করে।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmmcxlviii{তিনিই সেই আল্লাহ্ যিনি ব্যতীত অন্য উপাস্য নেই, তিনি অদৃশ্যের ও দৃশ্যের পরিজ্ঞাতা। তিনি পরম করুণাময়, অফুরন্ত ফলদাতা।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmmcxlix{তিনিই সেই আল্লাহ্ যিনি ব্যতীত কোনো উপাস্য নেই, -- রাজাধিরাজ, মহাপবিত্র, প্রশান্তিদাতা, নিরাপত্তা-বিধায়ক, সুরক্ষক, মহাশক্তিশালী, মহামহিম, পরম গেরবান্নিত। সকল মহিমা আল্লাহ্‌র, তারা যা আরোপ করে তার বহু উর্ধ্বে।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmmcl{তিনি আল্লাহ্‌, সৃজনকর্তা, উদ্ভাবনকর্তা, রূপদাতা, তাঁরই হচ্ছে সর্বাঙ্গসুন্দর নামাবলী। মহাকাশমন্ডলে ও পৃথিবীতে যারা আছে তারা তাঁরই জপতপ করে, আর তিনি মহাশক্তিশালী, পরমজ্ঞানী।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmmcli{\basmalahbn ওহে যারা ঈমান এনেছ! আমার শত্রু ও তোমাদের শত্রুকে বন্ধুরূপে গ্রহণ করো না, তোমরা কি তাদের প্রতি বন্ধুত্বের প্রস্তাব করবে, অথচ সত্যের যা-কিছু তোমাদের কাছে এসেছে তাতে তারা অবিশ্বাস করেছে, তারা রসূলকে ও তোমাদের বহিস্কার করে দিয়েছে যেহেতু তোমরা তোমাদের প্রভু আল্লাহ্‌তে বিশ্বাস কর। যদি তোমরা বেরিয়ে থাক আমার পথে সংগ্রাম করতে ও আমার প্রসন্নতা লাভের প্রত্যাশায়, তবে কি তোমরা তাদের প্রতি গোপনভাবেও বন্ধুত্ব দেখাবে, অথচ আমি ভাল জানি যা তোমরা গোপন রেখেছ এবং যা তোমরা প্রকাশ করছ? আর তোমাদের মধ্যে যে কেউ এটি করে সে তো তবে সরল পথ থেকে বিচ্যুত হয়েছে।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmclii{যদি তারা তোমাদের কাবু করতে পারে তাহলে তারা তোমাদের শত্রু হয়ে পড়ে এবং তোমাদের প্রতি তাদের হাত ও তাদের জিহবা তারা প্রসারিত করে মন্দভাবে, আর তারা চায় যে তোমারাও যেন অবিশ্বাস কর।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmcliii{তোমাদের রক্ত-সম্পর্কীয় আ‌ত্মীয়-স্বজন তোমাদের কোনো উপকারে আসবে না আর তোমাদের সন্তানসন্ততিরাও না -- কিয়ামতের দিনে, তিনি তোমাদের মধ্যে ফয়সালা করবেন। আর তোমরা যা করছ সে-সন্বন্ধে আল্লাহ্ সম্যক দ্রষ্টা।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmcliv{তোমাদের জন্য নিশ্চয়ই উত্তম আদর্শ রয়েছে ইব্রাহীমের ও তাঁর সঙ্গে যারা ছিল তাদের মধ্যে -- যখন তারা তাদের লোকদলকে বলেছিল -- ''নিশ্চয় আমরা দায়শূন্য তোমাদের থেকে, আর আল্লাহ্‌কে বাদ দিয়ে তোমরা যার উপাসনা কর তার থেকে, আমরা তোমাদের প্রত্যাখ্যান করেছি, কাজেই আমাদের মধ্যে ও তোমাদের মধ্যে শত্রুতা ও হিংসা-বিদ্বেষ চিরদিনের জন্য শুরু হয়েছে যতক্ষণ না তোমরা আল্লাহ্‌তে -- তাঁর একত্বে-- বিশ্বাস না কর।’’ তবে তাঁর পিতৃপুরুষের প্রতি ইব্রাহীমের বক্তব্য ছিল -- ''আমি নিশ্চয় তোমার জন্য ক্ষমাপ্রার্থনা করব, আর আল্লাহ্‌র কাছ থেকে তোমার জন্য অন্য কোনো কিছুতে আমার ক্ষমতা নেই।’’ ''আমাদের প্রভু! তোমার উপরেই আমরা নির্ভর করছি, আর তোমারই কাছে আমরা ফিরছি, আর তোমার কাছেই তো প্রত্যাবর্তন।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmclv{''আমাদের প্রভু! আমাদের তাদের শিকার বানিয়ো না যারা অবিশ্বাস পোষণ করে, আর, আমাদের প্রভু! আমাদের পরিত্রাণ করো, নিঃসন্দেহ তুমি, তুমিই তো মহাশক্তিশালী, পরমজ্ঞানী।’’\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmclvi{তোমাদের পক্ষে নিশ্চয়ই তাঁদের মধ্যে একটি উত্তম আদর্শ রয়েছে তার জন্য যে আল্লাহ্‌তে ও শেষ দিনে আশা-ভরসা রাখে। আর যে কেউ ফিরে যায় তবে নিশ্চয় আল্লাহ্ -- তিনি স্বয়ংসমৃদ্ধ, চির-প্রশংসিত।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmclvii{হতে পারে যে আল্লাহ্ তোমাদের মধ্যে ও যাদের সঙ্গে তোমরা শত্রুতা করছ তাদের কারো-কারোর মধ্যে বন্ধুত্ব ঘটিয়ে দেবেন। কেননা আল্লাহ্ সর্বশক্তিমান। আর আল্লাহ্ পরিত্রাণকারী, অফুরন্ত ফলদাতা।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmclviii{আল্লাহ্ তোমাদের নিষেধ করছেন না যে যারা তোমাদের বিরুদ্ধে ধর্মের কারণে যুদ্ধ করে নি এবং তোমাদের বাড়িঘর থেকে তোমাদের তাড়িয়ে দেয় নি, তাদের সঙ্গে তোমরা সদয় ব্যবহার করবে এবং তাদের প্রতি ন্যায়পরায়ণ হবে। নিঃসন্দেহ আল্লাহ্ ন্যায়পরায়ণদের ভালবাসেন।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmclix{আল্লাহ্ কেবল তাদের সন্বন্ধে তোমাদের নিষেধ করছেন যারা ধর্মের কারণে তোমাদের বিরুদ্ধে যুদ্ধ করেছে ও তোমাদের বাড়িঘর থেকে তোমাদের তাড়িয়ে দিয়েছে এবং পৃষ্ঠপোষকতা করেছে তোমাদের বহিস্কারের ব্যাপারে, -- যে তোমরা তাদের সঙ্গে বন্ধুত্ব পাতবে। আর যে কেউ তাদের সঙ্গে বন্ধুত্ব পাতবে তারাই তো তবে স্বয়ং অন্যায়কারী।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmclx{ওহে যারা ঈমান এনেছ! যখন বিশ্বাসিনী নারীরা দেশত্যাগী হয়ে তোমাদের কাছে আসে তখন তাদের পরীক্ষা করে দেখো। আল্লাহ্ ভাল জানেন তাদের ধর্মবিশ্বাস সন্বন্ধে। তারপর যদি তোমরা জানতে পার যে তারা বিশ্বাসিনী তাহলে তাদের ফেরত পাঠিয়ো না অবিশ্বাসীদের নিকটে। এরা তাদের জন্য বৈধ নয়, আর তারাও এদের জন্য বৈধ নয়। আর তাদের দিয়ে দাও যা তারা খরচ করেছে। আর তোমাদের উপরে কোনো দোষ বর্তাবে না যদি তোমরা তাদের বিবাহ কর যখন তাদের মহরানা তোমরা তাদের আদায় কর। আর তোমরা অবিশ্বাসিনীদের বিবাহ-বন্ধন ধরে রেখো না, আর তোমরা যা খরচ করেছ তা ফেরত চাইবে, আর তারাও ফেরত চাক যা তারা খরচ করেছে। এইটিই আল্লাহ্‌র বিধান। তিনি তোমাদের মধ্যে সুবিচার করে থাকেন, কেননা আল্লাহ্‌ই তো সর্বজ্ঞাতা, পরমজ্ঞানী।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmclxi{আর তোমাদের স্ত্রীদের মধ্যে থেকে যদি কিছু অবিশ্বাসীদের কাছে তোমাদের হাতছাড়া হয়ে যায়, তারপর যদি তোমাদেরও সুযোগ আসে তাহলে যাদের স্ত্রীরা চলে গেছে তাদের প্রদান করো তারা যা খরচ করেছিল তার সমতুল্য। আর আল্লাহ্‌কে ভয়ভক্তি করো যাঁর প্রতি তোমরা বিশ্বাসী হয়েছ।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmclxii{হে প্রিয় নবী! যখন বিশ্বাসিনী নারীরা তোমার কাছে আসে তোমার নিকট আনুগত্যের শপথ ক’রে যে তারা আল্লাহ্‌র সঙ্গে কোনো কিছু শরিক করবে না, আর চুরি করবে না, আর ব্যভিচার করবে না, আর তাদের সন্তানদের তারা হত্যা করবে না, আর তারা এমন কোনো মিথ্যা কলঙ্ক রটনা করবে না যা তাদের হাতের ও তাদের পায়ের মধ্যে তারা উদ্ভাবন করে, আর সৎকাজে তারা তোমার অবাধ্যতা করবে না, -- তেমন ক্ষেত্রে তাদের আনুগত্য গ্রহণ করো এবং আল্লাহ্‌র কাছে তাদের জন্য পরিত্রাণ খুঁজো। নিঃসন্দেহ আল্লাহ্ পরিত্রাণকারী, অফুরন্ত ফলদাতা।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmclxiii{ওহে যারা ঈমান এনেছ! সেই লোকদলের সঙ্গে বন্ধুত্ব করো না যাদের প্রতি আল্লাহ্ ত্রুদ্ধ হয়েছেন, -- যারা পরকাল সম্পর্কে হতাশ হয়ে পড়েছে, যেমন অবিশ্বাসীরা কবরের বাসিন্দাদের সন্বন্ধে হতাশ রয়েছে।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmclxiv{\basmalahbn আল্লাহ্‌র মহিমা ঘোষণা করছে যা-কিছু আছে মহাকাশমন্ডলে ও যা-কিছু আছে পৃথিবীতে, আর তিনি মহাশক্তিশালী, পরমজ্ঞানী।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmclxv{ওহে যারা ঈমান এনেছ! কেন তোমরা তা বল যা তোমরা কর না?\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmclxvi{আল্লাহ্‌র কাছে অত্যন্ত ঘৃণিত যে তোমরা এমন সব বল যা তোমরা কর না।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmclxvii{নিঃসন্দেহ আল্লাহ্ ভালবাসেন তাদের যারা তাঁর পথে যুদ্ধ করে সারিবদ্ধভাবে, যেন তারা একটি জমাট গাঁথুনি।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmclxviii{আর স্মরণ করো! মূসা তাঁর স্বজাতিকে বলেছিলেন, ''হে আমার লোকদল! কেন তোমরা আমাকে কষ্ট দিচ্ছ যখন তোমরা জেনে গিয়েছ যে আমি নিশ্চয়ই তোমাদের নিকট আল্লাহ্‌র প্রেরিত-পুরুষ?’’ তারপর তারা যখন বিমুখ হয়ে গিয়েছিল তখন আল্লাহ্ তাদের হৃদয়কে বিমুখ করে দিলেন। আর আল্লাহ্ সত্যত্যাগী জাতিকে সৎপথে চালান না।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmclxix{আর স্মরণ করো! মরিময়পুত্র ঈসা বলেছিলেন -- ''হে ইসরাইলের বংশধরগণ! আমি নিশ্চয়ই তোমাদের নিকট আল্লাহ্‌র রসূল, আমার সমক্ষে তওরাতে যা রয়েছে আমি তার সমর্থনকারী, আর সুসংবাদদাতা এমন এক রসূল সন্বন্ধে যিনি আমার পরে আসবেন, তাঁর নাম 'আহ্‌মদ’।’’ তারপর যখন তিনি তাদের কাছে এলেন স্পষ্ট প্রমাণাবলীসহ, তারা বললে -- ''এ তো এক স্পষ্ট জাদু!’’\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmclxx{আর তার চাইতে কে বেশী অন্যায়কারী যে আল্লাহ্‌র বিরুদ্ধে মিথ্যা রচনা করে, অথচ তাকে আহ্বান করা হচ্ছে ইসলামের দিকে? আর আল্লাহ্ অন্যায়াচারী জাতিকে সৎপথে চালান না।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmclxxi{ওরা চায় আল্লাহ্‌র আলোককে তাদের মুখ দিয়ে নিভিয়ে দিতে। কিন্ত আল্লাহ্ তাঁর আলোককে পূর্ণাঙ্গ করতেই যাচ্ছেন, যদিও অবিশ্বাসীরা অপছন্দ করে।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmclxxii{তিনিই সেইজন যিনি তাঁর রসূলকে পাঠিয়েছেন পথনির্দেশ ও সত্য ধর্ম দিয়ে যেন তিনি একে প্রাধান্য দিতে পারেন ধর্মের -- তাদের সবক’টির উপরে, যদিও বহুখোদাবাদীরা অপছন্দ করে।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmclxxiii{ওহে যারা ঈমান এনেছ! আমি কি তোমাদের সন্ধান দেব এমন এক পণ্যদ্রব্যের যা তোমাদের উদ্ধার করবে মর্মন্তুদ শাস্তি থেকে?\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmclxxiv{তোমরা আল্লাহ্‌তে ও তাঁর রসূলে বিশ্বাস করবে, আর আল্লাহ্‌র পথে সংগ্রাম করবে তোমাদের সম্পদ ও তোমাদের জীবন দিয়ে। এইটিই হচ্ছে তোমাদের জন্য শ্রেয় যদি তোমরা জানতে!\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmclxxv{তিনি তোমাদের পরিত্রাণ করবেন তোমাদের দোষত্রুটি থেকে, আর তোমাদের প্রবেশ করাবেন জান্নাতে যাদের নিচে দিয়ে বয়ে চলেছে ঝরনারাজি, আর নন্দন কাননের উৎকৃষ্ট গৃহসমূহে। এটিই মহাসাফল্য!\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmclxxvi{আর অন্য একটি যা তোমরা ভালবাস -- আল্লাহ্‌র কাছ থেকে সাহায্য ও আসন্ন বিজয়। আর সুসংবাদ দাও মুমিনদের।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmclxxvii{ওহে যারা ঈমান এনেছ! তোমরা আল্লাহ্‌র সাহায্যকারী হও, যেমন মরিয়ম-পুত্র ঈসা শিষ্যদের বলেছিলেন -- ''কারা আল্লাহ্‌র তরফে আমার সাহায্যকারী হবে?’’ শিষ্যেরা বলেছিল, ''আমরাই আল্লাহ্‌র সাহায্যকারী।’’ সুতরাং ইসরাইলের বংশধরদের মধ্যের একদল বিশ্বাস করেছিল এবং একদল অবিশ্বাস করেছিল। সেজন্য যারা ঈমান এনেছিল তাদের আমরা সাহায্য করেছিলাম তাদের শত্রুদের বিরুদ্ধে, ফলে পরক্ষণেই তারা উপরহাত হয়েছিল।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmclxxviii{\basmalahbn মহাকাশমন্ডলে যা-কিছু আছে ও যে কেউ আছে পৃথিবীতে তারা আল্লাহ্‌র মহিমা জপতপ করে, -- যিনি মহারাজাধিরাজ, পরম পবিত্র, মহাশক্তিশালী, পরমজ্ঞানী।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmclxxix{তিনিই সেইজন যিনি নিরক্ষরদের মধ্যে, তাদেরই মধ্যে থেকে, একজন রসূল দাঁড় করিয়েছেন, তিনি তাদের কাছে পাঠ করছেন তাঁর নির্দেশাবলী, আর তিনি তাদের পবিত্র করেছেন, আর তিনি তাদের শিক্ষা দিয়েছেন ধর্মগ্রন্থ ও জ্ঞানবিজ্ঞান, যদিও এর আগে তারা তো ছিল স্পষ্ট বিভ্রান্তিতে, --\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmclxxx{আর তাদের মধ্যে থেকে অন্যান্যদের যারা এখনও তাদের সঙ্গে যোগ দেয় নি। আর তিনি মহাশক্তিশালী, পরমজ্ঞানী।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmclxxxi{এইটিই আল্লাহ্‌র অনুগ্রহ-প্রাচুর্য, -- এটি তিনি দান করেন যাকে তিনি ইচ্ছা করেন। আর আল্লাহ্ বিরাট করুণাভান্ডারের অধিকারী।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmclxxxii{যাদের তওরাতের ভার দেওয়া হয়েছিল, তারপর তারা তা অনুসরণ করে নি, তাদের দৃষ্টান্ত হচ্ছে গাধার মতো, যে গ্রন্থরাজির বোঝা বইছে। কত নিকৃষ্ট সে-জাতির দৃষ্টান্ত যারা আল্লাহ্‌র নির্দেশাবলী প্রত্যাখ্যান করে। আর আল্লাহ্ অন্যায়াচারী জাতিকে সৎপথে চালান না।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmclxxxiii{বলো -- ''ওহে যারা ইহুদী মত পোষণ কর! যদি তোমরা মনে কর যে লোকজনকে বাদ দিয়ে তোমরাই আল্লাহ্‌র বন্ধুবান্ধব, তাহলে তোমরা মৃত্যু কামনা করো, যদি তোমরা সত্যবাদী হও।’’\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmclxxxiv{কিন্ত তাদের নিজেদের হাত যা আগবাড়িয়েছে সেজন্য তারা কখনো তা কামনা করবে না। আর আল্লাহ্ অন্যায়াচারীদের সন্বন্ধে সম্যক জ্ঞাতা।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmclxxxv{বলো -- ''আলবৎ মৃত্যু, যা থেকে তোমরা পালাতে চাও, তা কিন্ত তোমাদের সাক্ষাৎ করবেই, তারপর তোমাদের পাঠানো হবে অদৃশ্যের ও দৃশ্যের পরিজ্ঞাতার কাছে, তখন তিনি তোমাদের জানিয়ে দেবেন কি তোমরা করতে।’’\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmclxxxvi{ওহে যারা ঈমান এনেছ! যখন জুমু'আর দিনে নামাযের জন্য আহ্বান করা হয় তখন তোমরা আল্লাহ্‌র স্মরণে তাড়াতাড়ি করবে ও বেচা-কেনা বন্ধ রাখবে। এইটিই হচ্ছে তোমাদের জন্য শ্রেয়, যদি তোমরা জানতে।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmclxxxvii{তারপর যখন নামায শেষ হয়ে যায় তখন তোমরা দেশে ছড়িয়ে পড়ো এবং আল্লাহ্‌র করুণাভান্ডার থেকে অণ্বেষণ করো, আর আল্লাহ্‌কে প্রচুরভাবে স্মরণ করো, যাতে তোমাদের সফলতা প্রদান করা হয়।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmclxxxviii{কিন্ত যখন তারা পণ্যদ্রব্য অথবা ক্রীড়া-কৌতুক দেখতে পায় তখন তারা সেদিকে ভেঙ্গে পড়ে এবং তোমাকে দাঁড়ানো অবস্থায় ফেলে রাখে। তুমি বলো -- ''আল্লাহ্‌র কাছে যা রয়েছে তা ক্রীড়া-কৌতুকের চেয়ে ও ব্যবসা-বাণিজ্যের চেয়েও উত্তম! আর জীবিকাদাতাদের মধ্য আল্লাহ্‌ই সর্বশ্রেষ্ঠ।’’\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmclxxxix{\basmalahbn মুনাফিকরা যখন তোমার কাছে আসে তারা তখন বলে -- ''আমরা সাক্ষ্য দিচ্ছি যে তুমিই তো নিশ্চয়ই আল্লাহ্‌র রসূল।’’ আর আল্লাহ্ জানেন যে তুমি নিশ্চয়ই তাঁর রসূল। বস্তুত আল্লাহ্ সাক্ষ্য দিচ্ছেন যে মুনাফিকগোষ্ঠীই আলবৎ মিথ্যাবাদী।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmcxc{তারা তাদের শপথগুলোকে আবরণীরূপে গ্রহণ করে, যাতে তারা আল্লাহ্‌র পথ থেকে ফিরিয়ে রাখতে পারে। নিঃসন্দেহ তারা যা করে চলেছে তা কত মন্দ!\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmcxci{এটি এই জন্য যে তারা ঈমান আনে, তারপর অবিশ্বাস করে; সেজন্য তাদের হৃদয়ের উপরে মোহর মেরে দেয়া হয়েছে, পরিণামে তারা বুঝতে-সুঝতে পারে না।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmcxcii{আর তুমি যখন তাদের দেখ তখন তাদের গা-গতর তোমাকে তাজ্জব বানিয়ে দেয়, আর যদি তারা কথা বলে তবে তুমি তাদের বুলি শোনে থাক। তারা যেন এক-একটি কাঠের কুদোঁ ঠেস দিয়ে রাখা। তারা মনে করে প্রত্যেকটি শোরগোল তাদেরই বিরুদ্ধে। তারাই হচ্ছে শত্রু, ফলে তাদের সন্বন্ধে সাবধান হও। আল্লাহ্ তাদের ধ্বংস করুন! কোথা থেকে তাদের ফিরিয়ে দেওয়া হচ্ছে!\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmcxciii{আর যখন তাদের বলা হয় -- ''এসো, আল্লাহ্‌র রসূল তোমাদের জন্য ক্ষমা প্রার্থনা করবেন’’, তারা তখন তাদের মাথা নাড়ে, আর তুমি দেখতে পাও তারা ফিরিয়ে রাখছে। আর তারা গর্বিত বোধ করছে।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmcxciv{তুমি তাদের জন্য ক্ষমা প্রার্থনা কর অথবা তাদের জন্য ক্ষমা প্রার্থনা নাই কর -- এ তাদের জন্য একসমান। আল্লাহ্ কখনো তাদের ক্ষমা করবেন না। নিশ্চয় সত্যত্যাগী লোকদলকে আল্লাহ্ সৎপথে চালান না।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmcxcv{ওরাই তো তারা যারা বলে -- ''আল্লাহ্‌র রসূলের সঙ্গে যারা রয়েছে তাদের জন্য খরচ করো না যে পর্যন্ত না তারা সরে পড়ে।’’ আর মহাকাশমন্ডলের ও পৃথিবীর ধনভান্ডার তো আল্লাহ্‌রই, কিন্ত মুনাফিকগোষ্ঠী বোঝে না।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmcxcvi{তারা বলে -- ''আমরা যদি মদীনায় ফিরে যাই তাহলে প্রবলরা দুর্বলদের সেখান থেকে অবশ্যই বের করে দেবে।’’ কিন্ত ক্ষমতা তো আল্লাহ্‌রই আর তাঁর রসূলের আর মুমিনদের, কিন্ত মুনাফিকরা জানে না।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmcxcvii{ওহে যারা ঈমান এনেছ! তোমাদের ধনসম্পত্তি ও তোমাদের সন্তানসন্ততি যেন তোমাদের আল্লাহ্‌র স্মরণ থেকে ফিরিয়ে না রাখে। আর যে তেমন করে -- তারাই তো তবে খোদ ক্ষতিগ্রস্ত হবে।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmcxcviii{আর আমরা তোমাদের যা জীবনোপকরণ দিয়েছি তা থেকে তোমরা খরচ করো তোমাদের কোনো একজনের কাছে মৃত্যু এসে পড়ার আগেই, পাছে তাকে বলতে হয় -- ''আমার প্রভু! কেন তুমি আমাকে এক আসন্নকাল পর্যন্ত অবকাশ দাও নি, তাহলে তো আমি দান-খয়রাত করতাম এবং আমি সৎকর্মীদের অন্তর্ভুক্ত হতে পারতাম।’’\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmcxcix{আর আল্লাহ্ কোনো সত্ত্বাকে অবকাশ দেন না যখন তার অন্তিম-সময় এসে যায়। আর তোমরা যা কর সে-সন্বন্ধে আল্লাহ্ পূর্ণওয়াকিফহাল।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmcc{\basmalahbn আল্লাহ্‌রই জপতপ করছে যা-কিছু আছে মহাকাশমন্ডলে ও যা-কিছু আছে পৃথিবীতে, তাঁরই হচ্ছে সার্বভৌমত্ব ও তাঁরই সকল প্রশংসা, আর তিনি সব-কিছুর উপরে সর্বশক্তিমান।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmcci{তিনিই সেইজন যিনি তোমাদের সৃষ্টি করেছেন, তারপর তোমাদের কেউ-কেউ অবিশ্বাসী ও তোমাদের কেউ-কেউ বিশ্বাসী। আর তোমরা যা কর আল্লাহ্ তার সম্যক দ্রষ্টা।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmccii{তিনি মহাকাশমন্ডল ও পৃথিবীকে সৃষ্টি করেছেন যথাযথভাবে, আর তিনি তোমাদের আকৃতি দিয়েছেন, তারপর তোমাদের আকৃতিকে কত সুন্দর করেছেন! আর তাঁরই কাছে শেষ-প্রত্যাবর্তন।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmcciii{মহাকাশমন্ডলীতে ও পৃথিবীতে যা-কিছু আছে তা তিনি জানেন, আর তিনি জানেন যা তোমরা লুকোও ও যা তোমরা প্রকাশ কর। আর অন্তরের ভেতরে যা আছে সে-সন্বন্ধেও তিনি সর্বজ্ঞাতা।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmcciv{তোমাদের কাছে কি তাদের সংবাদ পেছেনি যাঁরা ইতিপূর্বে অবিশ্বাস পোষণ করেছিল, তারপর তাদের কাজের শাস্তি আস্বাদন করেছিল? আর তাদের জন্য রয়েছে মর্মন্তুদ শাস্তি।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmccv{এটি এইজন্য যে তাদের কাছে তাদের রসুলগণ আসতেছিলেন সুস্পষ্ট প্রমাণাবলী নিয়ে, কিন্ত তারা বলত -- ''মানুষই বুঝি আমাদের পথ দেখাবে?’’ সুতরাং তারা অবিশ্বাস করল ও ফিরে গেল, অথচ আল্লাহ্ বেপরোয়া রয়েছেন। আর আল্লাহ্ স্বয়ংসমৃদ্ধ প্রশংসার্হ।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmccvi{যারা অবিশ্বাস পোষণ করে তারা ধরে নিয়েছে যে তাদের কখনো তোলা হবে না। বলো -- ''হাঁ, আমার প্রভুর কসম, অতি-অবশ্য তোমাদের তোলা হবে, তারপর তোমাদের অবশ্যই জানানো হবে যা তোমরা করেছিলে।’’ আর এইটি আল্লাহ্‌র পক্ষে সহজ।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmccvii{অতএব তোমরা আল্লাহ্‌তে বিশ্বাস করো, আর তাঁর রসূলে ও সেই আলোকে যা আমরা অবতারণ করেছি। আর তোমরা যা করছ সে-সম্পর্কে আল্লাহ্ পূর্ণ-ওয়াকিফহাল।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmccviii{সেইদিন তিনি তোমাদের সমবেত করবেন জমায়েৎ করার দিনের জন্যে -- এইটিই মোহ-অপসারণের দিন। আর যে কেউ আল্লাহ্‌তে বিশ্বাস করে এবং সৎকর্ম সম্পাদন করে, তিনি তার থেকে তার সব পাপ মোচন করে দেবেন এবং তাকে প্রবেশ করাবেন স্বর্গোউদ্যানসমূহে যাদের নিচে দিয়ে বয়ে চলেছে ঝরনারাজি, সেখানে তারা অবস্থান করবে চিরকাল। এইটি এক বিরাট সাফল্য।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmccix{আর যারা অবিশ্বাস পোষণ করে এবং আমাদের নির্দেশাবলী প্রত্যাখ্যান করে, তারাই হচ্ছে আগুনের বাসিন্দা -- তারা সেখানেই অবস্থান করবে। আর কত মন্দ সেই গন্তব্যস্থান!\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmccx{কোনো বিপদ আপতিত হয় না আল্লাহ্‌র অনুমতি ব্যতীত। আর যে কেউ আল্লাহ্‌তে বিশ্বাস করে তিনি তার হৃদয়কে সুপথে চালিত করেন। আর আল্লাহ্ সব-কিছু সন্বন্ধে সর্বজ্ঞাতা।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmccxi{আর আল্লাহ্‌র আজ্ঞাপালন করো ও রসূলকে মেনে চলো; কিন্ত যদি তোমরা ফিরে যাও তাহলে আমাদের রসূলের উপরে কেবল সুস্পষ্টভাবে পৌঁছে দেওয়া।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmccxii{আল্লাহ্ -- তিনি ব্যতীত অন্য উপাস্য নেই। সুতরাং আল্লাহ্‌র উপরেই তবে মুমিনরা নির্ভর করুক।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmccxiii{ওহে যারা ঈমান এনেছ! নিশ্চয় তোমাদের কোনো-কোনো স্ত্রীরা ও তোমাদের ছেলেমেয়েরা তোমাদের শত্রু, অতএর তাদের ক্ষেত্রে হুশিয়াঁর হও। কিন্ত যদি তোমরা মাফ করে দাও ও উপেক্ষা কর ও উদ্ধার কর, তাহলে আল্লাহ্ পরিত্রাণকারী, অফুরন্ত ফলদাতা।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmccxiv{নিঃসন্দেহ তোমাদের ধনদৌলত ও তোমাদের সন্তানসন্ততি তো এক পরীক্ষা। আর আল্লাহ্‌, তাঁরই কাছে রয়েছে বিরাট প্রতিদান।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmccxv{অতএব আল্লাহ্‌কে ভয়ভক্তি করো যতটা তোমরা সক্ষম হও, আর শোনো, আর আজ্ঞাপালন করো, আর ব্যয় করো, -- এ তোমাদের নিজেদের জন্য কল্যাণময়। আর যে কেউ তার অন্তরের লোভ-লালসা থেকে সংযত রাখে তারাই তবে খোদ সফলকাম হয়।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmccxvi{যদি তোমরা আল্লাহ্‌কে কর্জ দাও এক উত্তম কর্জ, তিনি সেটি তোমাদের জন্য বহু-গুণিত করে দেবেন, আর তিনি তোমাদের পরিত্রাণ করবেন। আর আল্লাহ্ গুণগ্রাহী, অতি অমায়িক।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmccxvii{তিনি অদৃশ্য ও দৃশ্যের পরিজ্ঞাতা, মহাশক্তিশালী, পরমজ্ঞানী।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmccxviii{\basmalahbn হে প্রিয় নবী! যখন তোমরা স্ত্রীলোকদের তালাক দাও তখন তাদের তালাক দিয়ো তাদের নির্ধারিত দিনের জন্য, আর ইদ্দতের হিসাব রেখো, আর তোমাদের প্রভু আল্লাহ্‌কে ভয়-ভক্তি করো। তোমরা তাদের বের করে দিও না তাদের থাকা-ঘর থেকে, এবং তারাও যেন বেরিয়ে না যায় যদি না তারা স্পষ্ট অশ্লীলতায় লিপ্ত হয়ে থাকে। আর এগুলোই আল্লাহ্‌র সীমা। আর যে কেউ আল্লাহ্‌র বিধান লংঘন করে সে তো তবে নিজের অন্তরা‌ত্মার প্রতি অন্যায় করেই ফেলেছে। তুমি জানো না, হয়ত আল্লাহ্ এর পরে কোনো উপায় করে দেবেন।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmccxix{তারপর যখন তারা তাদের ইদ্দতকালে পৌঁছে যায় তখন হয় তাদের রেখে দেবে ভালভাবে অথবা তাদের ছাড়াছাড়ি করে দেবে ভালভাবে, আর তোমাদের মধ্যে থেকে দুইজন ন্যায়পরায়ণ লোককে সাক্ষী করো, আর তোমরা আল্লাহ্‌র উদ্দেশ্যে সাক্ষ্য কায়েম করবে। এইভাবেই এর দ্বারা তাকে উপদেশ দেওয়া হচ্ছে যে আল্লাহ্‌তে ও আখেরাতের দিনে বিশ্বাস করে। আর যে কেউ আল্লাহ্‌কে ভয়-ভক্তি করে তার জন্য তিনি বেরুবার পথ করে দেন।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmccxx{আর তিনি তাকে জীবনোপকরণ প্রদান করেন এমন দিক থেকে যা সে ধারণাও করে নি। আর যে আল্লাহ্‌র উপরে নির্ভর করে -- তার জন্য তবে তিনিই যথেষ্ট। নিঃসন্দেহ আল্লাহ্ তাঁর উদ্দেশ্য পরিপূর্ণকারী। আল্লাহ্ নিশ্চয়ই সব-কিছুর জন্য এক পরিমাপ ধার্য করে রেখেছেন।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmccxxi{আর তোমাদের নারীদের যারা ঋতু সন্বন্ধে হতাশ্বাস হয়েছে, যদি তোমরা সন্দেহ কর তাহলে তাদের ইদ্দত হবে তিন মাস, আর তাদেরও যারা ঋতুমতী হয় নি। আর গর্ভবতী নারীরা -- তাদের সময়সীমা হচ্ছে যে তারা যেন তাদের গর্ভ নামিয়ে ফেলে। আর যে কেউ আল্লাহ্‌কে ভয়-ভক্তি করে, তিনি তার কাজকর্ম তার জন্য সহজ করে দেবেন।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmccxxii{এইটিই আল্লাহ্‌র বিধান -- তোমাদের কাছে তিনি এ অবতারণ করেছেন। আর যে কেউ আল্লাহ্‌কে ভয়-ভক্তি করে তার থেকে তিনি তার পাপসমূহ মোচন করবেন, আর তার জন্য প্রতিদান বাড়িয়ে দেবেন।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmccxxiii{তাদের বাস করতে দাও যেখানে তোমরা বাস করছ, তোমাদের সামর্থ্য অনুযায়ী, আর তাদের কষ্ট দিয়ো না তাদের অবস্থা সংকটময় করে তোলার জন্যে। আর যদি তারা গর্ভবতী হয়ে থাকে তবে তাদের জন্য খরচ করো যে পর্যন্ত না তারা তাদের গর্ভভার নামিয়ে ফেলে, তারপর যদি তারা তোমাদের জন্য স্তন্যদান করে তাহলে তাদের মজুরি তাদের প্রদান করবে, আর তোমাদের মধ্যে ভালোভাবে কাজ করতে বলো, আর যদি তোমরা অমত হও তবে তার জন্য অন্যজনে স্তন্য দিক।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmccxxiv{প্রাচুর্যের অধিকারী যেন তার প্রাচুর্য থেকে খরচ করে, আর যার উপরে তার জীবিকা সীমিত করা হয়েছে সে যেন খরচ করে আল্লাহ্ তাকে যা দিয়েছেন তা থেকে। আল্লাহ্ কোনো সত্ত্বাকে কষ্ট দেন না তিনি তাকে যা দিয়েছেন তার অতিরিক্ত। আল্লাহ্ অচিরেই কষ্টের পরে আরাম প্রদান করবেন।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmccxxv{আর কত না জনপদ তার প্রভুর ও তাঁর রসূলদের নির্দেশের বিরুদ্ধে দাঁড়িয়েছিল, ফলে আমরা তার হিসাব তলব করেছিলাম কড়া হিসাব তলবে, আর আমরা তাকে শাস্তি দিয়েছিলাম শক্ত শাস্তিতে।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmccxxvi{সেজন্য তা তার কাজের মন্দফল আস্বাদন করেছিল, আর তার কাজের পরিণাম ক্ষতিকর হয়েছিল।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmccxxvii{আল্লাহ্ তাদের জন্য ভীষণ শাস্তি তৈরি রেখেছেন, অতএব আল্লাহ্‌কে ভয়-ভক্তি করো, হে জ্ঞানবান লোকেরা -- যারা ঈমান এনেছ! আল্লাহ্ তোমাদের কাছে প্রেরণ করেই রেখেছেন এক স্মারক --\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmccxxviii{একজন রসূল -- তিনি তোমাদের কাছে আবৃত্তি করছেন আল্লাহ্‌র নির্দেশাবলী, সুস্পষ্টভাবে, যেন যারা ঈমান এনেছে ও সৎকাজ করছে তাদের তিনি বের করে আনতে পারেন অন্ধকার থেকে আলোকে। আর যে কেউ আল্লাহ্‌তে ঈমান আনে ও সৎকাজ করে, তাকে তিনি প্রবেশ করাবেন স্বর্গোউদ্যানসমূহে যাদের নিচে দিয়ে বয়ে চলেছে ঝরনারাজি, সেখানে সে অবস্থান করবে চিরকাল। আল্লাহ্ তার জন্য জীবনোপকরণকে অতি উৎকৃষ্ট করেই রেখেছেন।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmccxxix{আল্লাহ্‌ই তিনি যিনি সৃষ্টি করেছেন সাত আসমান, আর পৃথিবীর বেলায়ও তাদের অনুরূপ। বিধান অবতরণ করে চলেছে তাদের মধ্যে, যেন তোমরা জানতে পার যে আল্লাহ্ সব-কিছুর উপরে সর্বশক্তিমান, আর এই যে আল্লাহ্ সব-কিছুকে ঘিরে রেখেছেন জ্ঞানের দ্বারা।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmccxxx{\basmalahbn হে প্রিয় নবী! কেন তুমি তা নিষিদ্ধ করছ যা আল্লাহ্ তোমার জন্য বৈধ করছেন? তুমি চাইছ তোমার স্ত্রীদের খুশি করতে? আর আল্লাহ্ পরিত্রাণকারী, অফুরন্ত ফলদাতা।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmccxxxi{আল্লাহ্ তোমাদের জন্য বিধান দিয়ে রেখেছেন তোমাদের শপথগুলো থেকে মুক্তির উপায়; আর আল্লাহ্ তোমাদের রক্ষাকারী বন্ধু, আর তিনিই সর্বজ্ঞাতা, পরমজ্ঞানী।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmccxxxii{আর স্মরণ করো! নবী তাঁর স্ত্রীদের কোনো একজনের কাছে গোপনে একটি সংবাদ দিয়েছিলেন; -- কিন্ত তিনি যখন তা বলে দিলেন, এবং আল্লাহ্ তাঁর কাছে এটি জানিয়ে দিয়েছিলেন, তখন তিনি তাঁকে তার কতকটা জানিয়েছিলেন এবং চেপে গিয়েছিলেন অন্য কতকটা। তিনি যখন তাঁকে তা জানিয়েছিলেন তখন তিনি বললেন -- ''কে আপনাকে এ কথা বললে?’’ তিনি বলেছিলেন -- ''আমাকে সংবাদ দিয়েছেন সেই সর্বজ্ঞাতা, চির-ওয়াকিফহাল।’’\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmccxxxiii{যদি তোমরা উভয়ে আল্লাহ্‌র দিকে ফেরো, কেননা তোমাদের হৃদয় ইতিপূর্বেই ঝোঁকে গেছে। কিন্ত যদি তোমরা দুজনে তাঁর বিরুদ্ধে পৃষ্ঠপোষকতা কর তাহলে আল্লাহ্ -- তিনিই তাঁর রক্ষাকারী বন্ধু, আর জিব্রীল ও পুণ্যবান মুমিনগণ, আর উপরন্ত ফিরিশ্‌তারাও পৃষ্ঠপোষক।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmccxxxiv{হতে পারে তাঁর প্রভু, যদি তিনি তোমাদের তালাক দিয়ে দেন, তবে তিনি তাঁকে বদলে দেবেন তোমাদের চাইতেও উৎকৃষ্ট স্ত্রীদের -- আ‌ত্মসমর্পিতা, বিশ্বাসিনী, বিনয়াবনতা, অনুতাপকারিণী, উপাসনাকারিণী, রোযাপালনকারিণী, স্বামিঘরকারিণী ও কুমারী।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmccxxxv{ওহে যারা ঈমান এনেছ! তোমাদের নিজেদের ও তোমাদের পরিবার-পরিজনদের রক্ষা করো সেই আগুন থেকে যার জ্বালানি হচ্ছে মানুষ ও পাথরগুলো, তার উপরে রয়েছে ফিরিশ্‌তারা -- অনমনীয়, কঠোর, তারা আল্লাহ্‌কে অমান্য করে না যা তিনি তাদের আদেশ করে থাকেন, আর তারা তাই করে যা তাদের আদেশ করা হয়।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmccxxxvi{ওহে যারা অবিশ্বাস পোষণ করেছ! আজকের দিনে কোনো অজুহাত এনো না। নিঃসন্দেহ তোমাদের তো প্রতিফল দেওয়া হচ্ছে যা তোমরা করে থাকতে তারই।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmccxxxvii{ওহে যারা ঈমান এনেছ! আল্লাহ্‌র দিকে ফেরো বিশুদ্ধ ফেরায়, হতে পারে তোমাদের প্রভু তোমাদের থেকে তোমাদের পাপ মোচন করে দেবেন এবং তোমাদের প্রবেশ করাবেন জান্নাতে যাদের নিচে দিয়ে বয়ে চলেছে ঝরনারাজি; সেই দিন আল্লাহ্ অপদস্থ করবেন না নবীকে এবং যারা তাঁর সঙ্গে ঈমান এনেছে তাদের, তাদের রোশনি তাদের সামনে চলবে আর তাদের ডানপাশে, তারা বলবে -- ''আমাদের প্রভু! আমাদের জন্য আমাদের রোশনি পরিপূর্ণ করো, আর আমাদের পরিত্রাণ করো। নিঃসন্দেহ তুমি সব-কিছুর উপরে সর্বশক্তিমান।’’\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmccxxxviii{হে প্রিয় নবী! জিহাদ করো অবিশ্বাসীদের ও মুনাফিকদের সঙ্গে, আর তাদের প্রতি কঠোর হও। আর তাদের আবাসস্থল হচ্ছে জাহান্নাম, আর মন্দ সেই গন্তব্যস্থান!\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmccxxxix{আল্লাহ্ একটি দৃষ্টান্ত উপস্থাপিত করছেন তাদের জন্য যারা অবিশ্বাস পোষণ করে, -- নূহের স্ত্রীর ও লূতের স্ত্রীর। তারা উভয়ে ছিল আমাদের বান্দাদের মধ্যের দুইজন সৎকর্মপরায়ণ বান্দার অধীনে, কিন্ত তারা তাঁদের প্রতি বিশ্বাসঘাতকতা করেছিল, ফলে তাঁরা আল্লাহ্‌র বিরুদ্ধে তাদের কোনো কাজে আসেন নি; আর বলা হবে -- ''তোমরা দুজনেও প্রবেশকারীদের সঙ্গে আগুনে প্রবেশ করো।’’\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmccxl{আর আল্লাহ্ একটি দৃষ্টান্ত উপস্থাপিত করছেন তাদের জন্য যারা ঈমান এনেছে, -- ফিরআউনের স্ত্রীর। স্মরণ করো! সে বলেছিল -- ''আমার প্রভু! আমার জন্য বেহেশতে তোমার সন্নিকটে একটি আবাস তৈরি করো, আর আমাকে উদ্ধার করো ফিরআউন ও তার ক্রিয়াকলাপ থেকে, আর আমাকে উদ্ধার করো অন্যায়াচারী লোকদের থেকে।’’\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmccxli{আর ইমরানের কন্যা মরিয়ম, যে তার আঙ্গিক কর্তব্যাবলী রক্ষা করেছিল, ফলে আমরা তার মধ্যে আমাদের রূহ থেকে ফুঁকে দিয়েছিলাম, আর সে তার প্রভুর বাণীকে ও তাঁর গ্রন্থগুলোকে সত্য জেনেছিল, আর সে ছিল বিনয়াবনতদের মধ্যেকার।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmccxlii{\basmalahbn মহামহিমান্বিত তিনি যাঁর হাতে রয়েছে সার্বভৌম কর্তৃত্ব, আর তিনি সব-কিছুর উপরে সর্বশক্তিমান;\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmccxliii{যিনি মৃত্যু ও জীবন সৃষ্টি করেছেন তোমাদের যাচাই করতে যে তোমাদের মধ্যে কে কাজকর্মে শ্রেষ্ঠ। আর তিনি মহাশক্তিশালী, পরিত্রাণকারী;\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmccxliv{যিনি সাত আকাশ সৃষ্টি করেছেন সুবিন্যস্তভাবে। তুমি পরম করুণাময়ের সৃষ্টিতে কোনো অসামঞ্জস্য দেখতে পাবে না। তারপর তুমি দৃষ্টি ঘুরিয়ে-ফিরিয়ে নাও, তুমি কি কোনো ফাটল দেখতে পাচ্ছ?\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmccxlv{তারপর দৃষ্টি আরেকবার ঘুরিয়ে-ফিরিয়ে নাও, দৃষ্টি তোমার কাছে ফিরে আসবে ব্যর্থ হয়ে, আর তা হবে ক্লান্ত।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmccxlvi{আর আমরা নিকটবর্তী আকাশকে সুশোভিত করে রেখেছি প্রদীপমালা দিয়ে, আর আমরা তাদের বানিয়েছি শয়তানদের জন্য ভাঁওতার বিষয়; আর আমরা তাদের জন্য প্রস্তুত রেখেছি জ্বলন্ত আগুনের শাস্তি।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmccxlvii{আর যারা তাদের প্রভুকে অবিশ্বাস করে তাদের জন্য রয়েছে জাহান্নামের শাস্তি। আর মন্দ সেই গন্তব্যস্থান!\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmccxlviii{যখন তাদের সেখানে নিক্ষেপ করা হবে তখন তারা তার থেকে বিকট গর্জন শুনতে পাবে, আর তা লেলিহান শিখা ছড়াবে, --\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmccxlix{যেন ক্রোধে ফেটে পড়ছে। যখনই কোনো একদলকে ওতে নিক্ষেপ করা হবে তার রক্ষীরা তাদের জিজ্ঞাসা করবে -- ''তোমাদের কাছে কি কোনো সতর্ককারী আসেন নি?”\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmccl{তারা বলবে -- ''হাঁ, আমাদের কাছে সতর্ককারী ইতিপূর্বে এসে গেছেন, আমরা কিন্তু অস্বীকার করেছিলাম ও বলেছিলাম -- 'আল্লাহ্ কোনো-কিছু অবতারণ করেন নি, তোমরা রয়েছ বিরাট পথভ্রান্তিতে বৈ তো নও’।’’\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmccli{আর তারা বলবে -- ''আমরা যদি শুনতাম অথবা বুদ্ধি প্রয়োগ করতাম তাহলে আমরা জ্বলন্ত আগুনের বাসিন্দাদের মধ্যে হতাম না।’’\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmcclii{সুতরাং তারা তাদের অপরাধ স্বীকার করবে, ফলে জ্বলন্ত আগুনের বাসিন্দাদের জন্য -- 'দূর হ!’\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmccliii{নিঃসন্দেহ যারা তাদের প্রভুকে ভয় করে গোপনে তাদের জন্য রয়েছে পরিত্রাণ ও বিরাট প্রতিদান।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmccliv{অথচ তোমাদের কথাবার্তা তোমরা গোপন কর অথবা তা প্রকাশই কর। নিঃসন্দেহ তিনি বুকের ভেতরের বিষয় সন্বন্ধেও সর্বজ্ঞাতা।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmcclv{যিনি সৃষ্টি করেছেন তিনি কি জানেন না? আর তিনি গুপ্ত বিষয়ে জ্ঞাতা, পূর্ণ-ওয়াকিফহাল।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmcclvi{তিনিই সেইজন যিনি পৃথিবীটাকে তোমাদের জন্য করে দিয়েছেন শান্ত, ফলে তোমরা এর দিগদিগন্তে বিচরণ করছ এবং তার জীবিকা থেকে আহার করছ। আর তাঁরই কাছে পুনরুত্থান।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmcclvii{কী! যিনি উর্ধ্বলোকে রয়েছেন তাঁর কাছ থেকে কি তোমরা নিরাপত্তা গ্রহণ করেছ যে তিনি পৃথিবীকে দিয়ে তোমাদের গ্রাস করাবেন না, যখন আলবৎ তা আন্দোলিত হবে?\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmcclviii{অথবা যিনি উর্ধ্বলোকে রয়েছেন তাঁর কাছ থেকে কি তোমরা নিরাপত্তা গ্রহণ করেছ পাছে তিনি তোমাদের উপরে পাঠিয়ে দেন এক কংকরময় ঘূর্ণিঝড়? ফলে তোমরা শীঘ্রই জানতে পারবে কেমন ছিল আমার সতর্কবাণী!\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmcclix{আর এদের আগে যারা ছিল তারাও প্রত্যাখ্যান করেছিল, তখন কেমন হয়েছিল আমার অসন্তোষ!\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmcclx{তারা কি দেখে নি তাদের উপরে পাখিদের ছড়ানো ও গুটানো? তাদের পরম করুণাময় ছাড়া কেউ ধরে রাখেন না। নিঃসন্দেহ তিনিই সর্ববিষয়ে সম্যক দ্রষ্টা।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxi{আচ্ছা, পরম করুণাময়কে বাদ দিয়ে কে সেইটি -- যে হবে তোমাদের জন্য সেনাবাহিনী যে তোমাদের সাহায্য করবে? অবিশ্বাসীরা তো বিভ্রান্তিতে থাকা ছাড়া আর কোথাও নয়।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxii{অথবা কে সে যে তোমাদের জীবিকা দেবে যদি তিনি তাঁর রিযেক বন্ধ করে দেন? বস্তুত তারা অবাধ্যতায় ও বিতৃষ্ণায় অনড় রয়েছে।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxiii{আচ্ছা, যে তার মুখের উপরে থুবড়ে থুবড়ে চলে সে কি তবে বেশি সৎপথে চালিত, না সেইজন যে সোজা হয়ে চলে শুদ্ধ-সঠিক পথে?\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxiv{বলো -- ''তিনিই সেইজন যিনি তোমাদের বিকশিত করেছেন, আর তোমাদের জন্য বানিয়ে দিয়েছেন শ্রবণশক্তি ও দৃষ্টিশক্তি ও অন্তঃকরণ। তোমরা যা কৃতজ্ঞতা প্রকাশ কর সে তো যৎসামান্য!’’\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxv{তুমি বলে যাও -- ''তিনিই সেইজন যিনি পৃথিবীতে তোমাদের ছড়িয়ে দিয়েছেন, আর তাঁরই কাছে তোমাদের একত্রিত করা হবে।’’\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxvi{আর তারা বলে -- ''কখন এই ওয়াদা হবে? যদি তোমরা সত্যবাদী হও।’’\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxvii{তুমি বলো -- ''জ্ঞান কেবল আল্লাহ্‌রই কাছে আছে, আর আমি নিঃসন্দেহ একজন স্পষ্ট সতর্ককারী মাত্র।’’\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxviii{তারপর তারা যখন এটি আসন্ন দেখতে পাবে তখন যারা অবিশ্বাস করেছিল তাদের চেহারা হবে মলিন, আর বলা হবে -- ''এটিই তাই যা তোমরা ডেকে আনছিলে।’’\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxix{তুমি বলো -- ''তোমরা কি ভেবে দেখেছ, -- যদি আল্লাহ্ আমাকে ও যারা আমার সঙ্গে রয়েছে তাদের ধ্বংস করেন অথবা আমাদের প্রতি করুণা করেন, কিন্তু কে অবিশ্বাসীদের রক্ষা করবে মর্মন্তুদ শাস্তি থেকে?’’\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxx{বলো -- ''তিনি পরম করুণাময়, আমরা তাঁতে ঈমান এনেছি এবং তাঁরই উপরে আমরা আস্থা রেখেছি, সুতরাং অচিরেই তোমরা জানতে পারবে কে সেইজন যে স্পষ্ট বিভ্রান্তিতে রয়েছে।’’\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxxi{বলে যাও -- ''তোমরা কি ভেবে দেখেছ -- যদি তোমাদের পানি সাত-সকালে ভূগর্ভে চলে যায়, তাহলে কে তোমাদের জন্য নিয়ে আসবে প্রবহমান পানি?’’\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxxii{\basmalahbn নূন! ভাবো কলম ও যা তারা লেখে।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxxiii{তোমার প্রভুর অনুগ্রহে তুমি কিন্তু পাগল নও।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxxiv{আর তোমার জন্য নিশ্চয়ই রয়েছে এমন এক প্রতিদান যা শেষ হবার নয়।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxxv{আর নিঃসন্দেহ তুমি সুমহান চরিত্রে অধিষ্ঠিত।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxxvi{ফলে তুমি শীঘ্রই দেখবে এবং তারাও দেখতে পাবে --\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxxvii{যে তোমাদের মধ্যে কে বিকারগ্রস্ত।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxxviii{নিঃসন্দেহ তোমার প্রভু, তিনি ভাল জানেন কে তাঁর পথ থেকে বিচ্যুত হয়েছে, আর তিনি ভাল জানেন সৎপথপ্রাপ্তদের ।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxxix{অতএব মিথ্যাচারীদের আজ্ঞাপালন করো না।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxxx{তারা চায় যে তুমি যদি নমনীয় হও তাহলে তারাও নমনীয় হবে।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxxxi{আর আজ্ঞাপালন করো না প্রত্যেকটি হলফকারীর, লাঞ্ছিতজনের, --\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxxxii{পরনিন্দাকারীর, কলঙ্ক রটাতে ঘুরে-বেড়ানো লোকের, --\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxxxiii{ভালোকাজে নিষেধকারীর, সীমালংঘনকারীর পাপাচারীর, --\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxxxiv{ষন্ডা-গুন্ডার, তদুপরি অসচ্চরিত্রের, --\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxxxv{এইজন্য যে সে ধনসম্পদের এবং সন্তানসন্ততির অধিকারী।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxxxvi{যখন তার কাছে আমাদের বাণীসমূহ পাঠ করা হয় সে বলে -- ''সেকেলে কল্পকাহিনী!’’\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxxxvii{আমরা শীঘ্রই তার উঁচু নাকে দাগ করে দেব।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxxxviii{আমরা নিশ্চয়ই তাদের পরীক্ষা করব যেমন আমরা পরীক্ষা করেছিলাম বাগান-মালিকদের, যখন ওরা কসম খেয়েছিল যে তারা নিশ্চয় ভোরবেলা এর ফসল কাটবে, --\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxxxix{আর তারা কোনো সংরক্ষণ করে নি।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmccxc{ফলে তোমার প্রভুর কাছ থেকে এক দুর্বিপাক এর উপরে আপতিত হয়েছিল যখন তারা ঘুমিয়ে পড়েছিল।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmmccxci{কাজেই সকালবেলায় তা হয়ে গেল এক কালো নিষ্ফলা জমির মতো।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmmccxcii{তারা কিন্তু সাত-সকালে একে অপরকে ডাকাডাকি করলে --\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmmccxciii{এই বলে -- ''সকাল সকাল তোমাদের খেত-খামারে যাও যদি তোমরা ফসল কাটতে চাও।’’\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmmccxciv{তখন তারা বেরিয়ে পড়ল, আর তারা ফিসফিস করতে থাকল --\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmmccxcv{এই বলে -- ''আজ যেন তোমাদের বিরুদ্ধে কোনো হাভাতে সেখানে ঢুকে না পড়ে।’’\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmmccxcvi{আর তারা সকাল সকাল সংকল্পে দৃঢ়প্রতিজ্ঞ হয়ে যাত্রা করল।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmmccxcvii{কিন্তু যখন তারা তা দেখল তারা বললে -- ''নিশ্চয় আমরা পথ ভুল করেছি।’’\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmmccxcviii{''না, আমরা বঞ্চিত হয়েছি।’’\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmmccxcix{ওদের মধ্যের শ্রেষ্ঠজন বললে -- ''আমি কি তোমাদের বলি নি, কেন তোমরা জপতপ করছ না?’’\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmmccc{তারা বললে -- ''আমাদের প্রভুর মহিমা ঘোষিত হোক, আমরা নিশ্চয় কিছুটা ফসল দান করতে অন্যায় করেছি।’’\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmmccci{তারপর তাদের কেউ-কেউ অন্যের কাছে গেল নিজেদের দোষারোপ করতে করতে।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmmcccii{তারা বললে -- ''হায়, ধিক্ আমাদের! আমরা নিশ্চয়ই সীমা ছাড়িয়ে গিয়েছিলাম।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmmmccciii{''হতে পারে আমাদের প্রভু আমাদের জন্য এর চেয়েও ভাল কিছু বদলে দেবেন, নিশ্চয় আমাদের প্রভুর কাছেই আমরা সানুনয় প্রার্থনা করছি।’’\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmmmccciv{এমনটাই শাস্তি হয়ে থাকে। আর পরকালের শাস্তি তো আরো বিরাট, -- যদি তারা জানতো!\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmmmcccv{নিঃসন্দেহ ধর্মভীরুদের জন্য তাদের প্রভুর কাছে রয়েছে আনন্দময় উদ্যান-সমূহ।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmmmcccvi{কী, আমরা কি তবে মুসলিমদের বানাব অপরাধীদের মতো?\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmmmcccvii{কি হয়েছে তোমাদের? কিভাবে তোমরা বিচার কর?\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmmmcccviii{না কি তোমাদের জন্য কোনো গ্রন্থ রয়েছে যা তোমরা অধ্যয়ন কর --\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmmmcccix{যে, নিশ্চয়ই তোমাদের জন্য তাতে তাই রয়েছে যা তোমরা পছন্দ কর?\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmmmcccx{অথবা, তোমাদের জন্য আমাদের উপরে কিয়ামতের দিন পর্যন্ত বলবৎ থাকা এমন কোনো অংগীকার রয়েছে কি যে তোমাদের জন্য আলবৎ তাই থাকবে যা তোমরা স্থির করবে?\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxi{তাদের জিজ্ঞাসা করো -- তাদের মধ্যে কে এ-সন্বন্ধে জামিন হবে;\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxii{না তাদের জন্য অংশী-দেবতারা আছে? তেমন হলে তাদের অংশী-দেবতাদের তারা নিয়ে আসুক যদি তারা সত্যবাদী হয়।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxiii{একদিন চরম সংকট দেখা দেবে, আর তাদের ডাকা হবে সিজদা করতে, কিন্তু তারা সক্ষম হবে না।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxiv{তাদের দৃষ্টি হবে অবনত, লাঞ্ছনা তাদের জড়িয়ে ফেলবে। অথচ তাদের আহ্বান করা হয়েই থাকত সিজদা করতে যখন তারা ছিল নিরাপদ।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxv{অতএব আমাকে এবং যে এই বাণী প্রত্যাখ্যান করে তাকে ছেড়ে দাও। আমরা তাদের ধাপে ধাপে নিয়ে যাব, কেমন করে তা তারা বুঝতেও পারবে না।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxvi{তথাপি আমি ওদের সহ্য করি। আমার ফাঁদ নিশ্চয়ই বড় মজবুত।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxvii{অথবা তুমি কি তাদের থেকে কোনো পারিশ্রমিক চাইছ যার ফলে তারা ধারকর্জ করে ভারাক্রান্ত হয়ে গেছে?\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxviii{অথবা অদৃশ্য কি তাদের কাছে রয়েছে, যার ফলে তারা লিখে রাখে?\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxix{অতএব তোমার প্রভুর হুকুমের জন্য অধ্যবসায় চালিয়ে যাও, এবং তুমি মাছের সঙ্গীর মতো হয়ো না। দেখো! তিনি বিষাদে কাতর হয়ে ডেকেছিলেন।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxx{যদি তাঁর প্রভুর কাছ থেকে অনুগ্রহ তাঁর কাছে না পৌঁছুত তাহলে তিনি অবশ্যই উন্মুক্ত প্রান্তরে নিক্ষিপ্ত হতেন, আর তিনি হতেন নিন্দিত।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxxi{কিন্তু তাঁর প্রভু তাঁকে মনোনীত করেছিলেন, ফলে তাঁকে সৎপথাবলন্বীদের অন্তর্ভুক্ত করেছিলেন।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxxii{আর যারা অবিশ্বাস পোষণ করেছে তারা যখন স্মারক-গ্রন্থ শোনে তখন তারা যেন তাদের চোখ দিয়ে তোমাকে আছড়ে মারবে, আর তারা বলে -- ''সে তো নিশ্চয়ই এক পাগল।’’\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxxiii{আর এটি জগদ্বাসীর জন্য স্মারক-গ্রন্থ বৈ তো নয়।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxxiv{\basmalahbn নিশ্চিত-সত্য!\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxxv{কি সেই নিশ্চিত-সত্য?\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxxvi{আহা, কি দিয়ে তোমাকে বোঝানো যাবে নিশ্চিত-সত্যটা কি?\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxxvii{ছামূদ ও 'আদগোষ্ঠী আঘাতকারী প্রলয়কে অস্বীকার করেছিল।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxxviii{তারপর ছামূদগোষ্ঠীর ক্ষেত্রে -- তাদের তখন ধ্বংস করা হয়েছিল এক প্রলয়ংকর বিপর্যয়ে।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxxix{আর 'আদগোষ্ঠীর ক্ষেত্রে -- তাদের তখন ধ্বংস করা হয়েছিল এক গর্জনকারী প্রচন্ড ঝড়ের দ্বারা --\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxxx{যাকে তিনি তাদের উপরে প্রবাহিত করেছিলেন সাত রাত ও আট দিনব্যাপী, অবিরতভাবে, ফলে তুমি সেই লোকদলকে দেখতে পেতে সেখানে লুটিয়ে পড়ে আছে, যেন তারা খেজুর গাছের ফাঁপা গুড়ি।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxxxi{তারপর তুমি তাদের অবশিষ্ট কিছু দেখতে পাও কি?\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxxxii{আর ফিরআউন আর যারা তার পূর্ববর্তী ছিল, আর বিধবস্ত শহরগুলো পাপাচার নিয়ে এসেছিল,\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxxxiii{যেহেতু তাদের প্রভুর রসূলকে তারা অমান্য করেছিল, সেজন্য তিনি তাদের পাকড়াও করেছিলেন এক সুকঠিন পাকড়ানোতে।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxxxiv{নিঃসন্দেহ যখন পানি ফেঁপে উঠেছিল, তখন আমরা তোমাদের বহন করেলিাম জাহাজের মধ্যে,\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxxxv{যেন আমরা এটিকে তোমাদের জন্য বানাতে পারি স্মরণীয় বিষয়, এবং শ্রুতিধর কান যেন এটি মনে রাখতে পারে।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxxxvi{সুতরাং যখন শিঙায় ফুৎকার দেওয়া হবে -- একটি মাত্র ফুৎকার, --\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxxxvii{এবং পৃথিবী ও পাহাড়-পর্বত উত্তোলন করা হবে, আর একটিমাত্র ধাক্কায় তাদের চূর্ণবিচূর্ণ করা হবে।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxxxviii{অতএব সেইদিন মহাঘটনা সংঘটিত হবে,\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxxxix{আর আকাশ বিদীর্ণ হবে, ফলে সেইদিন তা হবে ভঙ্গুর;\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxl{আর ফিরিশ্‌তারা এর প্রান্তগুলোয় রইবে। আর তাদের উপরে সেইদিন তোমার প্রভুর আরশ বহন করবে আটজন।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxli{সেইদিন তোমাদের অনাবৃত করা হবে, -- কোনো গোপন বিষয় তোমাদের থেকে গোপন থাকবে না।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxlii{তারপর যাকে তার বই তার ডান হাতে দেয়া হবে সে তখন বলবে -- ''নাও, আমার এই বই পড়ে দেখো!\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxliii{''আমি নিশ্চয়ই জানতাম যে আমি আলবৎ আমার এই হিসাবের সম্মুখীন হতে যাচ্ছি।’’\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxliv{সুতরাং সে থাকবে এক পূর্ণ-সন্তোষজনক জীবনযাপনে --\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxlv{এক উঁচু পর্যায়ের জান্নাতে,\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxlvi{যার ফলের থোকাগুলো নাগালের মধ্যে।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxlvii{''খাও আর পান করো তৃপ্তির সঙ্গে সেইজন্য যা তোমরা আগেকার দিনগুলোয় সম্পাদন করেছিলে।’’\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxlviii{আর তার ক্ষেত্রে যাকে তার বই তার বাম হাতে দেওয়া হবে সে তখন বলবে -- ''হায় আমার আফসোস! আমার এই বই যদি আমায় কখনো দেখানো না হতো, --\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxlix{''আর আমি যদি কখনো জানতাম না আমার এই হিসাবটি কী।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmmcccl{''হায় আফসোস! এইটাই যদি আমার শেষ হতো!\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmmcccli{''আমার ধনসম্পদ আমার কোনো কাজে এল না;\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmmccclii{''আমার কর্তৃত্ব আমার থেকে বিনাশ হয়ে গেছে।’’\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmmcccliii{''তাকে ধরো এবং তাকে বাঁধো,\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmmcccliv{''তারপর জ্বলন্ত আগুনে তাকে নিক্ষেপ করো,\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmmmccclv{''তারপর তাকে এক শিকলে আবদ্ধ করো যার দৈঘ্য হচ্ছে সত্তর হাত।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmmmccclvi{''নিশ্চয় সে বিশ্বাস করত না মহান আল্লাহ্‌তে,\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmmmccclvii{''আর সে উৎসাহ দেখাত না গরীবদের খাবার দিতে,\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmmmccclviii{''সেজন্য আজ তার জন্যে এখানে কোনো অন্তরঙ্গ বন্ধু থাকবে না,\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmmmccclix{''আর কোনো খাদ্য থাকবে না ক্ষতনিঃসৃত পুজঁ ব্যতীত --\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmmmccclx{''যা পাপীরা ব্যতীত আর কেউ খায় না।’’\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxi{কিন্ত না, আমি কসম খাচ্ছি যা তোমরা দেখছ তার,\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxii{এবং যা তোমরা দেখছ না তারও, --\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxiii{যে এটি এক সম্মানিত রসূলের বাণী,\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxiv{আর এ কোনো কবির আলাপন নয়; সামান্যই তো যা তোমরা বিশ্বাস কর।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxv{আর কোনো গনৎকারের বাক্‌চাতুরীও নয়, যৎসামান্য যা তোমরা চিন্তা কর!\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxvi{এ হচ্ছে এক অবতারণ বিশ্বজগতের প্রভুর কাছ থেকে।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxvii{আর তিনি যদি আমাদের নামে কোনো বাণী রচনা করতে চাইতেন, --\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxviii{তাহলে আমরা নিশ্চয়ই তাকে ডানহাতে পাকড়াও করতাম,\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxix{তারপর নিশ্চয়ই তার কন্ঠশিরা কেটে ফেলতাম,\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxx{তখন তোমাদের মধ্যের কেউই ওর থেকে নিবৃত্ত করতে পারতে না।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxxi{আর নিশ্চয়ই এইটি ধর্মভীরুদের জন্য এক স্মারক-গ্রন্থ।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxxii{আর নিশ্চয়ই আমরা তো জানি যে তোমাদের মধ্যে সত্যপ্রত্যাখ্যানকারী রয়েছে।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxxiii{আর নিঃসন্দেহ এটি অবিশ্বাসীদের জন্য বড় অনুতাপের বিষয়।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxxiv{আর নিঃসন্দেহ এটি তো সুনিশ্চিত সত্য।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxxv{অতএব তোমার মহামহিমান্নিত প্রভুর নামের জপতপ করো।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxxvi{\basmalahbn এক প্রশ্নকারী প্রশ্ন করছে অবধারিত শাস্তি সম্পর্কে --\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxxvii{অবিশ্বাসীদের জন্য, এর প্রতিরোধকারী কেউ নেই --\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxxviii{আল্লাহ্‌র নিকট থেকে, যিনি উন্নয়নের সোপানের অধিকর্তা।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxxix{ফিরিশ্‌তাগণ ও আ‌ত্মা তাঁর দিকে আরোহণ করে এমন এক দিনে যার পরিমাপ হলো পঞ্চাশ হাজার বছর।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxxx{অতএব তুমি অধ্যবসায় চালিয়ে যাও এক সুমহান ধৈর্যধারণে।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxxxi{নিঃসন্দেহ তারা একে মনে করে বহু দূরে,\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxxxii{কিন্তু আমরা দেখছি এ নিকটে।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxxxiii{সেইদিন আকাশ হয়ে যাবে গলানো তামার মতো,\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxxxiv{আর পাহাড়গুলো হবে উলের মতো,\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxxxv{আর কোনো অন্তরঙ্গ বন্ধু জিজ্ঞাসাবাদ করবে না অন্তরঙ্গ বন্ধু সন্বন্ধে --\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxxxvi{তাদের পরস্পরকে দৃষ্টিগোচরে রাখা হবে। অপরাধী ব্যক্তি শাস্তি থেকে সেইদিন মুক্তিলাভ করতে চাইবে তার সন্তানদের বিনিময়ে,\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxxxvii{আর তার সহধর্মিণীর ও তার ভাইয়ের,\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxxxviii{আর তার নিকট-আ‌ত্মীয়ের যারা তাকে আশ্রয় দিত,\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxxxix{আর যা-কিছু আছে পৃথিবীতে সে-সমস্তটাই, -- যেন তাকে মুক্তি দেওয়া হয়।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxc{কখনোই নয়! নিঃসন্দেহ এটি এক শিখায়িত আগুন, --\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxci{চামড়া ঝলসিয়ে খসাতে উদগ্রীব, --\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxcii{এ ডাকবে তাকে যে পালিয়েছিল ও ফিরে গিয়েছিল,\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxciii{আর জমা করেছিল এবং আটকে রেখেছিল।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxciv{নিঃসন্দেহ মানুষের বেলা -- তাকে সৃষ্টি করা হয়েছে ব্যস্তসমস্ত করে,\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxcv{যখন খারাপ অবস্থা তাকে স্পর্শ করে তখন অতীব ব্যথাতুর,\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxcvi{আর যখন সচ্ছলতা তাকে স্পর্শ করে তখন হাড়-কিপটে,\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxcvii{তারা ব্যতীত যারা মুছল্লী, --\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxcviii{যারা তাদের নামাযের প্রতি স্বতঃনিষ্ঠাবান,\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxcix{আর যারা তাদের ধনসম্পত্তিতে নির্দিষ্ট অধিকার রেখেছে --\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmmcd{ভিখারির ও বঞ্চিতের জন্য,\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmmcdi{আর যারা বিচারের দিনকে সত্য বলে গ্রহণ করে,\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmmcdii{আর যারা তাদের প্রভুর শাস্তি সম্পর্কে খোদ ভীতসন্ত্রস্ত, --\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmmcdiii{নিশ্চয় তাদের প্রভুর শাস্তি প্রশান্তিদায়ক নয়;\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmmcdiv{আর যারা নিজেরাই তাদের আঙ্গিক-কর্তব্যাবলী সম্পর্কে যত্নবান, --\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmmcdv{তবে নিজেদের দম্পতি অথবা তাদের ডানহাত যাদের ধরে রেখেছে তাদের ছাড়া, কেননা সেক্ষেত্রে তারা নিন্দনীয় নহে,\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmmcdvi{কিন্তু যে এর বাইরে যাওয়া কামনা করে তাহলে তারা নিজেরাই হবে সীমালংঘনকারী।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmmmcdvii{আর যারা খোদ তাদের আমানত সন্বন্ধে ও তাদের অংগীকার সন্বন্ধে সজাগ থাকে,\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmmmcdviii{আর যারা স্বয়ং তাদের সাক্ষ্যদানে সুপ্রতিষ্ঠিত,\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmmmcdix{আর যারা নিজেরা তাদের নামায সন্বন্ধে সদা যত্নবান,\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmmmcdx{তারাই থাকবে জান্নাতে পরম সম্মানিত অবস্থায়।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxi{কিন্তু কি হয়েছে তাদের যারা অবিশ্বাস পোষণ করে, যে তারা তোমার দিকে উদগ্রীব হয়ে ছুটে আসছে --\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxii{ডান দিক থেকে ও বাম দিক থেকে, দলেদলে?\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxiii{তাদের মধ্যের প্রত্যেক লোকই কি আশা করে যে তাকে প্রবেশ করানো হবে আনন্দময় উদ্যানে?\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxiv{কখনই না। নিঃসন্দেহ আমরা কি দিয়ে তাদের গড়েছি তা তারা জানে।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxv{কিন্তু না, আমি উদয়াচলের ও অস্তাচলের প্রভুর নামে শপথ করছি যে আমরা আলবৎ সমর্থ --\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxvi{যে আমরা তাদের চেয়ে ভালোদের দিয়ে বদলে দেব, আর আমরা পরাজিত হবার নই।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxvii{সেজন্য তাদের ছেড়ে দাও গল্পগুজব ও খেলাধুলো করতে যে পর্যন্ত না তারা তাদের সেই দিনটির সাক্ষাৎ পায় যার সন্বন্ধে তাদের ওয়াদা করা হয়েছিল, --\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxviii{সেইদিন তারা কবরগুলো থেকে বেরিয়ে আসবে ব্যস্তসমস্ত হয়ে, যেন তারা একটি লক্ষ্যস্থলের দিকে ধাবিত হয়েছে,\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxix{তাদের চোখ হবে অবনত, হীনতা তাদের আচ্ছন্ন করবে। এমনটাই সেইদিন যার বিষয়ে তাদের ওয়াদা করা হয়েছিল।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxx{\basmalahbn নিঃসন্দেহ আমরা নূহ্‌কে তাঁর লোকদলের কাছে পাঠিয়েছিলাম এই বলে -- ''তোমার লোকদলকে সতর্ক করে দাও তাদের উপরে মর্মন্তুদ শাস্তি আসবার আগে।’’\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxxi{তিনি বলেছিলেন -- ''হে আমার স্বজাতি! নিঃসন্দেহ আমি তোমাদের জন্য একজন স্পষ্ট সতর্ককারী, --\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxxii{''এ বিষয়ে যে তোমরা আল্লাহ্‌র উপাসনা করো ও তাঁকে ভয়-ভক্তি করো, আর আমাকে মেনে চলো।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxxiii{''তিনি তোমাদের পাপগুলোর কতকটা ক্ষমা করবেন এবং তোমাদের বিরাম দেবেন এক নির্ধারিত কাল পর্যন্ত। নিঃসন্দেহ আল্লাহ্‌র নির্ধারণ করা কাল যখন এসে পড়ে তখন তা পিছিয়ে দেওয়া যায় না, -- যদি তোমরা জানতে!’’\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxxiv{তিনি বললেন -- ''আমার প্রভূ! আমি তো আমার স্বজাতিকে রাতে ও দিনে আহ্বান করেছি,\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxxv{''কিন্ত আমার ডাক তাদের পালিয়ে যাওয়া ছাড়া আর কিছুই বাড়ায় নি।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxxvi{''আর নিশ্চয় যখনই আমি তাদের আহ্বান করেছি যেন তুমি তাদের ক্ষমা করতে পার, তারা তাদের কানের ভেতরে তাদের আঙ্গুলগুলো ভরে দেয়, আর তাদের কাপড় দিয়ে নিজেদের ঢেকে ফেলে, আর গোঁ ধরে, আর সগর্বে গর্ব করে।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxxvii{''তারপর আমি নিশ্চয় তাদের আহ্বান করেছি উঁচু গলায়,\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxxviii{''তারপর নিশ্চয় আমি তাদের কাছে ঘোষণা করেছি, আর আমি তাদের সঙ্গে গোপনে গোপন কথা বলেছি,\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxxix{''আর আমি বলেছি -- তোমাদের প্রভুর কাছে পরিত্রাণ খোঁজো, নিশ্চয় তিনি হচ্ছেন পরম ক্ষমাশীল।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxxx{''তিনি তোমাদের উপরে বৃষ্টি পাঠাবেন প্রচুর পরিমাণে,\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxxxi{''আর তোমাদের সমৃদ্ধ করবেন ধনদৌলত ও সন্তানসন্ততি দিয়ে, আর তোমাদের জন্য তৈরি করবেন বাগানসমূহ, আর তোমাদের জন্য স্থাপন করবেন নদী-নালা।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxxxii{''তোমাদের কী হয়েছে যে তোমরা আল্লাহ্‌র পক্ষ থেকে শ্রেষ্ঠত্ব স্বীকার করতে চাইছ না,\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxxxiii{''অথচ তিনি তোমাদের সৃষ্টি করেইছেন স্তরে-স্তরে।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxxxiv{''তোমরা কি লক্ষ্য কর নি কিভাবে আল্লাহ্ সাত আসমানকে সৃষ্টি করেছেন সুবিন্যস্তভাবে,\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxxxv{''আর তাদের মধ্যে তিনি চন্দ্রকে করেছেন একটি আলোক আর সূর্যকে বানিয়েছেন একটি প্রদীপ।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxxxvi{''আর আল্লাহ্ পৃথিবী থেকে তোমাদের জন্মিয়েছেন এক উৎপাদনরূপে।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxxxvii{''তারপর তিনি তোমাদের তাতেই ফিরে পাঠান, এবং তিনি তোমাদের বের করে আনবেন এক বহিষ্কারে।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxxxviii{''আর আল্লাহ্ তোমাদের জন্য পৃথিবীটাকে করেছেন সুবিস্তৃত,\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxxxix{''যেন তোমরা তাতে চলতে পার প্রশস্ত পথে।’’\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxl{নূহ্ বলেছিলেন -- ''আমার প্রভূ! নিঃসন্দেহ তারা আমাকে অমান্য করেছে এবং অনুসরণ করছে তার যার ধনসম্পত্তি ও সন্তানসন্ততি ক্ষতিসাধন ছাড়া তার আর কিছুই বাড়ায় নি,\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxli{''আর তারা এক বিরাট ষড়যন্ত্র এটেছিলঁ।’’\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxlii{আর তারা বলেছিল -- ''তোমাদের দেবদেবীকে কিছুতেই পরিত্যাগ করো না, আর পরিত্যাগ করো না ওয়াদকে, এবং সুওয়াকে না, আর নয় য়াগূস ও ইয়া'উক ও নসর-কে।’’\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxliii{আর তারা অনেককে পথভ্রষ্ট করেই ফেলেছে। আর তুমি অন্যায়াচারীদের বিভ্রান্তি ছাড়া আর কিছুই বাড়াচ্ছ না!\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxliv{তাদের অপরাধের জন্য তাদের ডুবিয়ে দেওয়া হয়েছিল, ফলে তাদের ঢোকানো হয়েছিল আগুনে। সুতরাং তারা আল্লাহ্‌কে বাদ দিয়ে তাদের জন্য কোনো সাহায্যকারী পায় নি।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxlv{আর নূহ্ বলেছিলেন -- ''আমার প্রভূ! এই পৃথিবীর বুকে অবিশ্বাসীদের মধ্যের এক গৃহবাসীকেও অব্যাহতি দিয়ো না।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxlvi{''কেননা তুমি যদি তাদের অব্যাহতি দাও তাহলে তারা তোমার বান্দাদের বিভ্রান্ত করবে, আর তারা দুষ্কৃতিকারী বেঈমানদের ব্যতীত আর কারোর জন্ম দেবে না।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxlvii{''আমার প্রভূ! আমাকে পরিত্রাণ করো, আর আমার পিতামাতাকে, আর যে কেউ আমার ঘরে বিশ্বাসী হয়ে প্রবেশ করে তাকে, আর বিশ্বাসীপুরুষদের ও বিশ্বাসিনীদের। আর অন্যায়াচারীদের আর কিছু বাড়িয়ো না নিপাত হওয়া ব্যতীত।’’\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxlviii{\basmalahbn বলো -- ''আমার কাছে প্রত্যাদেশ করা হয়েছে যে জিনদের একটি দল শুনেছিল, এবং বলেছিল -- 'আমরা নিশ্চয় এক আশ্চর্যজনক কুরআন শুনেছি,\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxlix{'যা সুষ্ঠুপথের দিকে চালনা করে, তাই আমরা তাতে ঈমান এনেছি, আর আমরা কখনো আমাদের প্রভুর সাথে কাউকেও শরিক করব না,\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmcdl{'আর তিনি, -- সুউন্নত হোক আমাদের প্রভুর মহিমা, -- তিনি কোনো সহচরী গ্রহণ করেন নি, আর না কোনো সন্তান,\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmcdli{'আর এই যে আমাদের মধ্যের নির্বোধেরা আল্লাহ্ সন্বন্ধে অমূলক কথা বলত,\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlii{'আর এই যে আমরা ভেবেছিলাম যে মানুষ ও জিন আল্লাহ্ সন্বন্ধে কখনো মিথ্যাকথা বলবে না’,\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmcdliii{''আর এই যে মানুষের মধ্যের কিছু লোক জিনজাতির কিছু লোকের আশ্রয় নিত, ফলে ওরা তাদের পাপাচার বাড়িয়ে দিত,\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmcdliv{''আর এই যে তারা ভেবেছিল যেমন তোমরা ভাবছো যে আল্লাহ্ কাউকেও পুনরুত্থিত করবেন না,\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlv{''আর 'আমরা আকাশে আড়ি পাততাম, কিন্ত আমরা তাকে দেখতে পেতাম কড়া প্রহরী ও অগ্নিশিখা দিয়ে ভরপূর,\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlvi{'আর আমরা নিশ্চয় তার মধ্যের বসবার জায়গাগুলোয় বসে থাকতাম গুনবার জন্য, কিন্ত যে কেউ শুনতে চায় সে এখন দেখতে পায় তার জন্য রয়েছে অগ্নিশিখা অপেক্ষারত;\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlvii{'আর আমরা অবশ্য জানি না -- পৃথিবীতে যারা রয়েছে তাদের জন্য অমঙ্গল কামনা করা হচ্ছে, না এ-সবের দ্বারা তাদের প্রভু সুষ্ঠুপথের দিশা চাইছেন;\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlviii{'আর নিশ্চয় আমাদের কেউ-কেউ সৎপথাবলন্বী আর আমাদের অন্যেরা এর বিপরীত। আমরা বিভিন্ন সম্প্রদায় বিভিন্ন পন্থী;\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlix{'আর আমরা বুঝি যে আমরা দুনিয়াতে কখনো আল্লাহ্‌কে পরাভূত করতে পারব না এবং পলায়নের দ্বারাও তাঁকে কখনও এড়াতে পারব না,\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlx{'আর আমরা যখন পথনির্দেশ শুনেছি আমরা তাতে বিশ্বাস করেছি। সুতরাং যে কেউ তার প্রভুর প্রতি বিশ্বাস স্থাপন করে, সে তবে আশংকা করবে না কমে যাওয়ার অথবা লাঞ্ছনা পাবার,\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxi{''আর আমাদের মধ্যের কেউ-কেউ অবশ্য মুসলিম আর আমাদের অন্যেরা সীমালংঘনকারী। সুতরাং যারা আ‌ত্মসমর্পণ করেছে তারাই তবে সুষ্ঠুপথের সন্ধান খোঁজেছে।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxii{'আর সীমালংঘনকারীদের ক্ষেত্রে -- তারা তো জাহান্নামেরই ইন্ধন হয়েছে।’”\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxiii{আর এই যে যদি তারা নির্দেশিত পথে কায়েম থাকত তবে আমরা অবশ্যই তাদের প্রচুর পানি দিয়ে সমৃদ্ধ করতাম;\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxiv{যেন আমরা তাদের পরীক্ষা করতে পারি তার দ্বারা। আর যে কেউ তার প্রভুর স্মরণ থেকে ফিরে থাকে, তিনি তাকে ঢুকিয়ে দেবেন চিরবর্ধমান শাস্তিতে।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxv{আর এই যে মসজিদগুলো হচ্ছে আল্লাহ্‌র জন্য, সুতরাং তোমরা আল্লাহ্‌র সঙ্গে আর কাউকেও ডেকো না।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxvi{আর এই যে যখন আল্লাহ্‌র বান্দা তাঁকে আহ্বান করতে দাঁড়িয়েছিলেন তখন তারা চেয়েছিল তাঁর চারিদিকে ভিড় করতে।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxvii{বলো -- ''নিঃসন্দেহ আমি আমার প্রভুকেই ডাকি, আর আমি তাঁর সঙ্গে কাউকেও শরিক করি না।’’\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxviii{তুমি বলো -- ''আমি কোনো কর্তৃত্ব করি না তোমাদের উপরে আঘাত হানার অথবা উপকার করার।’’\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxix{তুমি বলে যাও -- ''নিশ্চয়ই কেউ আমাকে কখনো রক্ষা করতে পারবে না আল্লাহ্ থেকে, আর তাঁকে বাদ দিয়ে আমি কখনো কোনো আশ্রয়ও পাব না, --\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxx{শুধু আল্লাহ্ থেকে পৌঁছে দেওয়া, আর তাঁর বাণীসমূহ।’’ আর যে আল্লাহ্ ও তাঁর রসূলের অবাধ্যতা করে, তার জন্য তবে নিশ্চয়ই রয়েছে জাহান্নামের আগুন, তাতে তারা থাকবে দীর্ঘকাল।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxxi{যে পর্যন্ত না তারা দেখতে পায় যা তাদের ওয়াদা করা হয়েছিল, তখন তারা সঙ্গে-সঙ্গে জানতে পারবে কে সাহায্যলাভের ক্ষেত্রে দুর্বলতর, আর সংখ্যার দিক দিয়ে অল্প।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxxii{বলো -- ''আমি জানি না তোমাদের যা ওয়াদা করা হয়েছে তা আসন্ন, না আমার প্রভু তার জন্য কোনো দীর্ঘমিয়াদ স্থির করবেন।’’\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxxiii{তিনি অদৃশ্যের পরিজ্ঞাতা, তাই কারো কাছে তিনি তাঁর রহস্য প্রকাশ করেন না, --\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxxiv{রসূলের মধ্যে যাঁকে তিনি মনোনয়ন করেছেন তাঁকে ব্যতীত, সেজন্য নিশ্চয় তিনি তাঁর সামনে ও তাঁর পেছনে প্রহরী নিয়োজিত করেন,\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxxv{যেন তিনি জানতে পারেন যে তাঁরা তাঁদের প্রভুর বাণীসমূহ পৌঁছে দিয়েছেন কি না, আর তিনি ঘিরে আছেন তাঁদের কাছের সব- কিছু, আর তিনি সব-কিছুর হিসাব রাখেন গোনে-গোনে।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxxvi{\basmalahbn হে বস্ত্রাচ্ছাদনকারী!\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxxvii{তুমি উঠে দাঁড়াও রাতেরবেলা অল্পসময় ব্যতীত, --\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxxviii{তার অর্ধেক, অথবা তার থেকে কিছুটা কমিয়ে নাও,\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxxix{অথবা এর উপরে বাড়িয়ে নাও, আর কুরআন আবৃত্তি করো ধীরস্থিরভাবে শান্ত-সুন্দর আবৃত্তিতে।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxxx{নিঃসন্দেহ আমরা তোমার উপরে চাপাচ্ছি এক গুরুভার বাণী।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxxxi{নিঃসন্দেহ রাত-জেগে উপাসনা -- এ হচ্ছে বলিষ্ঠতম পদক্ষেপ ও সুসংস্থাপিত বক্তব্য।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxxxii{নিঃসন্দেহ তোমার জন্য দিনের বেলায় রয়েছে সুদীর্ঘ কর্মতৎপরতা।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxxxiii{সুতরাং তোমার প্রভুর নাম কীর্তন করো এবং তাঁর প্রতি ধ্যানধারণায় মগ্ন হও একনিষ্ঠ ধ্যানে।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxxxiv{পূর্বাঞ্চল ও পশ্চিমাঞ্চলের প্রভু, তিনি ব্যতীত কোনো উপাস্য নেই, সুতরাং তাঁকেই কর্ণধাররূপে গ্রহণ করো।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxxxv{আর অধ্যবসায় চালিয়ে যাও তারা যা বলে তা সত্ত্বেও, আর তাদের পরিহার করে চলো সৌজন্যময় পরিহারে!\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxxxvi{আর ছেড়ে দাও আমাকে এবং সত্যপ্রত্যাখ্যানকারীদের, বিলাস-সামগ্রীর অধিকারীদের, আর তাদের বিরাম দাও অল্পকাল।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxxxvii{নিঃসন্দেহ আমাদের কাছে আছে ভারী শিকল ও জ্বলন্ত আগুন,\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxxxviii{আর খাদ্য যা গলায় আটকে যায়, আর মর্মন্তুদ শাস্তি!\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxxxix{সেইদিন পৃথিবী ও পাহাড়গুলো কেঁপে উঠবে, আর পাহাড়গুলো হয়ে যাবে স্তূপাকার বালির গাদা!\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxc{নিঃসন্দেহ আমরা তোমাদের কাছে এজন রসূল পাঠিয়েছি, তোমাদের উপরে সাক্ষীরূপে, যেমন আমরা ফিরআউনের কাছে একজন রসূল পাঠিয়েছিলাম।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxci{কিন্ত ফিরআউন সেই রসূলকে অমান্য করেছিল, ফলে আমরা তাকে পাকড়াও করেছিলাম নিদারুণ পাকড়ানোতে।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxcii{অতএব কেমন করে তোমরা আ‌ত্মরক্ষা করবে, যদি তোমরা অবিশ্বাস কর সেই দিনকে যেদিন ছেলেপিলেদের চুল পাকিয়ে তুলবে, --\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxciii{আকাশ হবে বিদীর্ণ? তাঁর ওয়াদা অবশ্যই বাস্তবায়িত হবে।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxciv{নিশ্চয়ই এটি একটি স্মরণকারী বিষয়, সুতরাং যে ইচ্ছা করে সে তার প্রভুর দিকে পথ ধরুক।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxcv{তোমার প্রভু অবশ্য জানেন যে তুমি তো জেগে থাক রাতের প্রায় দুই-তৃতীয়াংশ, আর তার অর্ধেক আর তার এক-তৃতীয়াংশ, আর তোমার সঙ্গে যারা আছে তাদের একটি দলও। আর আল্লাহ্ রাত ও দিনের পরিমাপ রক্ষা করেন। তিনি জানেন যে তোমরা কখনো এর হিসাব রাখতে পারবে না, কাজেই তিনি তোমাদের দিকে ফিরেছেন, সেজন্য কুরআন থেকে যতটা তোমাদের জন্য সহজ ততটা আবৃত্তি করো। তিনি জানেন যে তোমাদের কেউ-কেউ রোগগ্রস্ত হবে এবং অন্যেরা দুনিয়াতে চষে বেড়াবে আল্লাহ্‌র করুণাভান্ডারের সন্ধানে, আর অন্যান্যরা আল্লাহ্‌র পথে যুদ্ধ করবে, সেজন্য এ-থেকে যতটা তোমরা সহজ মনে কর ততটা আবৃত্তি করো, আর নামায কায়েম রেখো ও যাকাত আদায় করো এবং আল্লাহ্‌কে ঋণদান করো উত্তম ঋণ। আর যা কিছু সৎকাজ তোমরা নিজেদের জন্য আগবাড়াও তা তোমরা আল্লাহ্‌র কাছে পাবে, -- সেটিই বেশি ভাল ও বিরাট প্রতিদান। আর আল্লাহ্‌র কাছে পরিত্রাণ খোঁজো, নিঃসন্দেহ আল্লাহ্ পরিত্রাণকারী, অফুরন্ত ফলদাতা।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxcvi{\basmalahbn হে প্রিয় পোশাক-পরিহিত!\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxcvii{ওঠো এবং সতর্ক করো,\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxcviii{আর তোমার প্রভু -- মাহা‌ত্ম্য ঘোষণা করো,\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxcix{আর তোমার পোশাক -- তবে পবিত্র করো,\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmd{আর কদর্যতা -- তবে পরিহার করো,\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmdi{আর অনুগ্রহ করো না বেশি পাবার প্রত্যাশায়,\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmdii{আর তোমার প্রভুর জন্য তবে অধ্যবসায় চালিয়ে যাও।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmdiii{তারপর যখন শিঙায় আওয়াজ দেওয়া হবে,\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmdiv{সেটি তবে হবে, সেই দিনটি, এক মহাসংকটের দিন --\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmdv{অবিশ্বাসীদের উপরে; আরামদায়ক নয়।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmdvi{ছেড়ে দাও আমাকে ও তাকে যাকে আমি সৃষ্টি করেছি এককভাবে,\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmdvii{আর তার জন্য আমি বিপুল ধনসম্পদ দিয়েছিলাম,\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmdviii{আর সন্তানসন্ততি প্রত্যক্ষ অবস্থানকারী,\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmdix{আর তার জন্য আমি সহজ করে দিয়েছিলাম স্বচ্ছন্দভাবে,\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmdx{তারপরেও সে চায় যে আমি যেন আরো বাড়িয়ে দিই!\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmdxi{কখনো নয়! কেননা সে আমাদের নির্দেশাবলী সন্বন্ধে ঘোর বিরুদ্ধাচারী।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmdxii{আমি তার উপরে আনব এক ক্রমবর্ধমান আঘাত।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmdxiii{কেননা নিশ্চয় সে ভাবনাচিন্তা করল এবং মেপেজোখে দেখল।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmdxiv{সুতরাং সে নিপাত যাক! কেমনতর সে যাচাই করেছিল!\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmmdxv{পুনশ্চ সে নিপাত যাক! কেমন করে সে যাচাই করছিল!\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmmdxvi{সে আবার তাকিয়ে দেখল,\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmmdxvii{তারপর সে ভ্রকুঞ্চিত করল ও মুখ বিকৃত করল,\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmmdxviii{তারপর সে পিছিয়ে গেল ও বুক ফুলিয়ে এগিয়ে এল,\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmmdxix{তারপর বললে -- ''এ বরাবর চলে আসা জাদু বৈ তো নয়!\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmmdxx{''এ একজন মানুষের কথা বৈ তো নয়।’’\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmmdxxi{আমি শীঘ্রই তাকে ফেলব জ্বালাময় আগুনে।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmmdxxii{আর কী তোমাকে বোঝাবে জ্বালাময় আগুনটা কি?\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmmdxxiii{তা কিছুই বাকী রাখে না, আর কিছুই ছেড়ে দেয় না,\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmmdxxiv{মানুষকে একেবারে ঝলসে দেবে,\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmmdxxv{তার উপরে রয়েছে ''উনিশ’’।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmmdxxvi{আর আমরা ফিরিশ্‌তাদের ছাড়া আগুনের প্রহরী করি নি, আর যারা অবিশ্বাস পোষণ করেছে তাদের পরীক্ষারূপে ছাড়া আমরা এদের সংখ্যা নির্ধারণ করি নি, যেন যাদের গ্রন্থ দেয়া হয়েছিল তাদের দৃঢ়প্রত্যয় জন্মে, আর যারা বিশ্বাস করেছে তাদের ঈমান যেন বর্ধিত হয়, আর যাদের গ্রন্থ দেওয়া হয়েছে ও যারা বিশ্বাসী তারা যেন সন্দেহ না করে, আর যাদের অন্তরে ব্যাধি রয়েছে ও যারা অবিশ্বাসী তারা যেন বলতে পারে -- ''এই রূপকের দ্বারা আল্লাহ্ কী বোঝাতে চাইছেন?’’ এইভাবে আল্লাহ্ বিভ্রান্ত করেন যাকে তিনি ইচ্ছা করেন, এবং পথনির্দেশ দেন যাকে তিনি চান। আর তিনি ছাড়া আর কেউ তোমার প্রভুর বাহিনীকে সম্যক জানে না। বস্তুত এটি মানবকুলের জন্য এক সতর্কীকরণ বৈ তো নয়।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmmmdxxvii{না! ভাবো চাঁদের কথা;\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmmmdxxviii{আর রাতের কথা যখন তার অবসান ঘটে।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmmmdxxix{আর প্রভাতকালের কথা যখন তা হয় আলোকোজ্জ্বল।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmmmdxxx{নিঃসন্দেহ এটি অতি বিরাট এক ব্যাপার --\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmmmdxxxi{মানুষের জন্য সতর্কীকরণরূপে,\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmmmdxxxii{তোমাদের মধ্যের তার জন্য যে আগবাড়তে চায়, অথবা পেছনে থাকতে চায়।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmmmdxxxiii{প্রত্যেক সত্ত্বাই জামিন থাকবে যা সে অর্জন করে তার জন্য, --\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmmmdxxxiv{ডানদিকের লোকেরা ব্যতীত,\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmmmdxxxv{জান্নাতে, তারা পরস্পরকে জিজ্ঞাসাবাদ করবে --\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmmmdxxxvi{অপরাধীদের সম্পর্কে;\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmmmdxxxvii{''কিসে তোমাদের নিয়ে এসেছে জ্বালাময় আগুনে?’’\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmmmdxxxviii{তারা বলবে -- ''আমরা নামাযীদের অন্তর্ভুক্ত ছিলাম না,\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmmmdxxxix{''আর আমরা অভাবগ্রস্তদের খাবার দিতে চাইতাম না;\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmmmdxl{''বরং আমরা বৃথা তর্ক করতাম বৃথা তর্ককারীদের সঙ্গে,\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmmmmdxli{''আর আমরা বিচারের দিনকে মিথ্যা বলতাম, --\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmmmmdxlii{''যতক্ষণ না অবশ্যাম্ভাবী আমাদের কাছে এসেছিল।’’\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmmmmdxliii{ফলে সুপারিশকারীদের সুপারিশ তাদের কোনো কাজে আসবে না।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmmmmdxliv{তাদের তবে কি হয়েছে যে তারা অনুশাসন থেকে ফিরে চলে যায়,\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmmmmdxlv{যেন তারা ভীত-ত্রস্ত গাধার দল,\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmmmmdxlvi{পালিয়ে যাচ্ছে সিংহের থেকে?\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmmmmdxlvii{বস্তুত তাদের মধ্যের প্রত্যেকটি লোকই চায় যে তাকে যেন দেওয়া হয় খোলামেলা কাগজের তাড়া।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmmmmdxlviii{কখনো না। তারা কিন্ত পরকালের ভয় করে না।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmmmmdxlix{কক্ষনো না! এটি নিশ্চয়ই এক অনুশাসন।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmmmmdl{সুতরাং যে কেউ চায় সে এটি স্মরণ করুক।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mmmmmdli{আর তারা মনোনিবেশ করবে না যদি না আল্লাহ্ ইচ্ছা করেন। তিনিই ভয়ভক্তি করার যোগ্য পাত্র এবং তিনিই পরিত্রাণের যথার্থ অধিকারী।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mmmmmdlii{\basmalahbn না, আমি শপথ করছি কিয়ামতের দিনের।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmdliii{আর না, আমি শপথ করছি আ‌ত্মসমালোচনাপরায়ণ আ‌ত্মার।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmdliv{মানুষ কি মনে করে যে আমরা কখনো তার হাড়গোড় একত্রিত করব না?\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmdlv{হাঁ, আমরা তার আঙুলগুলো পর্যন্ত পুনর্বিন্যস্ত করতে সক্ষম।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmdlvi{তবুও মানুষ চায় যা তার সামনে রয়েছে তা অস্বীকার করতে।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmdlvii{সে প্রশ্ন করে -- ''কখন কিয়ামতের দিন আসবে?’’\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmdlviii{কিন্ত যখন দৃষ্টি দিশাহারা হয়ে যাবে,\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmdlix{আর চন্দ্র হবে অন্ধকারাচ্ছন্ন,\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmdlx{আর সূর্য ও চন্দ্রকে একত্রিত করা হবে,\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxi{মানুষ সেইদিন বলবে -- ''কোথায় পালানোর স্থান?’’\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxii{কিছুতেই না, কোনো আশ্রয়স্থল নেই।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxiii{সেদিন ঠাই হবে কেবল তোমার প্রভুর নিকটেই।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxiv{মানুষকে সেইদিন জানানো হবে কী সে আগবাড়িয়েছে এবং সে ফেলে রেখেছে।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxv{বস্তুত মানুষ তার নিজের সত্ত্বা সন্বন্ধে চক্ষুষ্মান,\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxvi{যদিও সে তার অজুহাত দেখায়।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxvii{এর দ্বারা তোমার জিহবা নাড়াচাড়া করো না একে ত্বরান্বিত করতে।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxviii{নিঃসন্দেহ আমাদের উপরেই রয়েছে এর সংগ্রহের ও এর পাঠ করানোর দায়িত্ব।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxix{সুতরাং যখন আমরা তা পাঠ করি তখন তুমি তার পঠন অনুসরণ করো,\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxx{তারপর নিশ্চয় আমাদেরই উপরে রয়েছে এর ব্যাখ্যাকরণ।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxxi{না, তোমরা কিন্তু ভালবাস ক্ষণস্থায়ী,\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxxii{আর অবহেলা কর পরকালকে।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxxiii{সেদিন কতকগুলো মুখ হবে উজ্জ্বল, --\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxxiv{তাদের প্রভুর দিকে চেয়ে থাকবে,\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxxv{আর কতকগুলো মুখ সেইদিন বিবর্ণ হয়ে যাবে, --\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxxvi{এই ভেবে যে কোনো বিধ্বংসী বিপর্যয় তাদের উপরে পড়তে যাচ্ছে।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxxvii{না, যখন এটি গলায় এসে পৌঁছুবে,\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxxviii{এবং বলা হবে -- ''কে সেই জাদুকর?’’\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxxix{আর সে বুঝতে পারে যে, এ হচ্ছে বিদায় বেলা,\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxxx{এবং এক পায়ের হাড় অন্য পায়ের হাড়ে ঠোকর খেতে থাকবে,\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxxxi{তোমার প্রভুর দিকেই সেইদিন হবে চালিয়ে নেওয়া।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxxxii{সে তো সত্যনিষ্ঠ ছিল না, আর নামাযও পড়ে নি,\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxxxiii{বরং সে সত্যপ্রত্যাখ্যান করেছিল এবং ফিরে এসেছিল,\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxxxiv{তারপর সে তার স্বজনগণের কাছে গিয়েছিল গর্ব করতে করতে।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxxxv{''তুমি নিপাত যাও! তবে নিপাত যাও!\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxxxvi{''আবার তুমি নিপাত যাও, ফলে নিপাত যাও!’’\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxxxvii{মানুষ কি ভাবে যে তাকে ছেড়ে দেয়া হবে বাঁধনছাড়াভাবে?\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxxxviii{সে কি ছিল না এক শুক্রকীট এক সবেগে নির্গত স্খলনের মধ্যেকার?\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxxxix{তারপর সে হলো একটি রক্তপিন্ড, তারপর তিনি আকৃতি দান করলেন ও পূর্ণাঙ্গ করলেন।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmmmdxc{তারপর তিনি তা হতে সৃষ্টি করলেন তার যুগল -- পুরুষ ও নারী।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmmmdxci{তবুও কি তিনি ক্ষমতাবান নন মৃতকে পুনর্জীবিত করতে?\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmmmdxcii{\basmalahbn মানুষের উপরে কি দীর্ঘ সময়ের অবকাশ অতিবাহিত হয় নি যখন সে উল্লেখযোগ্য কিছুই ছিল না?\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmdxciii{নিঃসন্দেহ আমরা মানুষকে সৃষ্টি করেছি সংযুক্ত এক শুক্রকীট থেকে, আমরা তাকে শৃঙ্খলাবদ্ধ করেছি, সেজন্য আমরা তা কে বানিয়েছি শ্রবণশক্তি ও দৃষ্টিশক্তি সম্পন্ন।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmdxciv{নিঃসন্দেহ আমরা তাকে পথের নির্দেশ দিয়েছি, -- হয় সে কৃতজ্ঞ হবে, না হয় সে অকৃতজ্ঞ হবে।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmdxcv{আমরা অবশ্য অকৃতজ্ঞদের জন্য তৈরি করেছি শিকল ও বেড়ি, আর জ্বলন্ত আগুন।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmdxcvi{নিঃসন্দেহ পুণ্যা‌ত্মারা পান করবে এমন একটি পাত্র থেকে যার মেজাজ হবে কর্পূরের --\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmdxcvii{একটি ফোয়ারা -- যা থেকে আল্লাহ্‌র বান্দারা পান করবে, তারা এটিকে প্রবাহিত করবে অবিরাম ধারায়।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmdxcviii{তারা মানত পালন করে, এবং ভয় করে সেই দিনটির যার ধ্বংসলীলা হবে সুদূরপ্রসারী।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmdxcix{আর তারা তাঁর প্রতি প্রেমবশতঃ খাবার খেতে দেয় অভাবগ্রস্তকে ও এতিমকে ও বন্দীকে --\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmdc{''আমরা তোমাদের খেতে দিচ্ছি শুধু আল্লাহ্‌র সন্তষ্টিলাভের জন্য, তোমাদের থেকে আমরা কোনো প্রতিদান চাই না, কৃতজ্ঞতাও নয়।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmdci{''আমরা আলবৎ আমাদের প্রভুর নিকট থেকে এক ভীতিপ্রদ বিপদসংকুল দিনের ভয় করি।’’\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmdcii{কাজেই আল্লাহ্ তাদের রক্ষা করবেন সেইদিনের অকল্যাণ থেকে এবং তাদের সাক্ষাৎ করাবেন প্রফুল্লতার ও প্রশান্তির সাথে,\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmdciii{আর যেহেতু তারা অধ্যবসায় চালিয়েছিল সেজন্য প্রতিদানে তাদের দেবেন বাগান ও রেশমী পোশাক,\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmdciv{তারা সেখানে সমাসীন থাকবে রাজকীয় আসনে, তারা সেখানে দেখতে পাবে না সূর্যোত্তাপ, না কোনো কনকনে ঠান্ডা,\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmdcv{আর তাদের সন্নিকটে থাকবে তাদের গাছের ছায়া, আর তাদের থোকা-থোকা ফল থাকবে নত হয়ে নাগালের মধ্যে।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmdcvi{আর তাদের সামনে পরিবেশন করা হবে রূপোর পেয়ালা ও ঝলমলে কাচের পানপাত্র, --\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmdcvii{চাঁদির তৈরি চক্‌মকে কাচের মতো, -- তারা তা মেপে নেবে একটি পরিমাপে।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmdcviii{আর তাদের তাতে পান করানো হবে এমন একটি পাত্র যার মেজাজ হবে আদ্রকের, --\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmdcix{তার মধ্যের একটি ফোয়ারাতে যার নাম দেয়া হয়েছে সাল্‌সাবীল।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmdcx{আর তাদের প্রদক্ষিণ করবে চিরস্ফুটিত কিশোরগণ, -- তোমরা যখন তাদের দেখবে তাদের তোমরা ভাববে ছড়ানো মুক্তো!\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxi{আর যখন তুমি সেখানে চেয়ে দেখবে, তুমি দেখতে পাবে অনুগ্রহ-সামগ্রী ও এক বিশাল রাজ্য।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxii{তাদের পরিধেয় হবে মিহি সবুজ রেশমের ও পুরু জরির পোশাক, আর তাদের অলংকৃত করানো হবে রূপোর কাঁকন দিয়ে, আর তাদের প্রভু তাদের পান করাবেন এক পবিত্র পানীয়।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxiii{''নিঃসন্দেহ এটি হচ্ছে তোমাদের জন্য পুরস্কার, আর তোমাদের প্রচেষ্টা স্বীকৃত হয়েছে।’’\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxiv{নিঃসন্দেহ আমরা -- আমরা স্বয়ং তোমার কাছে এই কুরআান এক অবতারণে অবতীর্ণ করেছি।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxv{সুতরাং তোমার প্রভুর নির্দেশের জন্য অধ্যবসায় চালিয়ে যাও, আর তাদের মধ্যেকার কোনো পাপিষ্ঠের অথবা সত্যপ্রত্যাখ্যান- কারীর আজ্ঞা পালন করো না।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxvi{আর তোমার প্রভুর নাম কীর্তন করো সকালে ও বিকেলে,\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxvii{আর রাতের থেকে তাঁর প্রতি সিজদা করো, আর লন্বা রাত পর্যন্ত তাঁর গুণগান করো।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxviii{নিঃসন্দেহ এরা ভালবাসে অস্থায়ী জীবন, আর অবহেলা করে এদের সামনের এক কঠিন দিনকে।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxix{আমরাই তাদের সৃষ্টি করেছি এবং মজবুত করেছি তাদের গঠন, কাজেই যখন আমরা চাইব তখন তাদের অনুরূপদের আমরা বদলে দেবো আমূল পরিবর্তনে।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxx{নিঃসন্দেহ এটি এক স্মরণীয় বার্তা, সুতরাং যে ইচ্ছা করে সে তার প্রভুর দিকে পথ ধরুক।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxxi{আর তোমরা চাও না আল্লাহ্‌র চাওয়া ব্যতিরেকে। নিঃসন্দেহ আল্লাহ্ হচ্ছেন সর্বজ্ঞাতা, পরমজ্ঞানী।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxxii{তিনি যাকে ইচ্ছা করেন তাকে তাঁর অনুগ্রহের মধ্যে প্রবেশ করান। কিন্ত অন্যায়কারীরা -- তাদের জন্য তিনি তৈরি করেছেন মর্মন্তুদ শাস্তি।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxxiii{\basmalahbn ভাবো প্রেরিতপুরুষগণের কথা -- একের পর এক,\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxxiv{আর ভাবো ঝড়ের মতো আসা দমকা হাওয়ার কথা,\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxxv{আর ভাবো যারা ছড়াচ্ছে ছড়ানোর মতো,\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxxvi{তারপর আলাদা করে দেয় আলাদা করণে,\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxxvii{তারপর গেথে দেঁয় স্মারক গ্রন্থ, --\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxxviii{পরিশোধিত করতে অথবা সতর্ক করতে।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxxix{নিশ্চয় তোমাদের যা ওয়াদা করা হয়েছে তা অবশ্যই ঘটতে যাচ্ছে।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxxx{সুতরাং যখন তারাগুলো ঝিমিয়ে পড়বে।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxxxi{আর যখন আকাশ ভেঙ্গে পড়বে,\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxxxii{আর যখন পাহাড়গুলোকে উড়িয়ে দেওয়া হবে,\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxxxiii{আর যখন রসূলগণকে নির্ধারিত সময়ে নিয়ে আসা হবে --\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxxxiv{কোন সে দিনের জন্য ধার্য রাখা হয়েছে?\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxxxv{ফয়সালার দিনের জন্য।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxxxvi{আর কী তোমাকে বুঝতে দেবে ফয়সালার দিনটি কি?\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxxxvii{ধিক্ সেইদিন সত্যপ্রত্যাখ্যানকারীদের জন্য!\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxxxviii{আমরা কি পূর্ববর্তীদের নিধন করি নি?\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxxxix{তারপর পরবর্তীদেরও আমরা তাদের অনুগমন করাব।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxl{এইভাবেই আমরা অপরাধীদের প্রতি আচরণ করে থাকি।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxli{ধিক সেইদিন সত্যপ্রত্যাখ্যানকারীদের প্রতি!\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxlii{তোমাদের কি আমরা সৃষ্টি করি নি এক তুচ্ছ জলীয় পদার্থ থেকে?\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxliii{তারপর আমরা তা স্থাপন করি এক সুরক্ষিত স্থানে, --\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxliv{এক অবহিত পরিমাপ পর্যন্ত;\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxlv{তারপর আমরা বিন্যস্ত করি, সুতরাং কত নিপুণ বিন্যাসকারী আমরা!\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxlvi{ধিক্ সেইদিন সত্যপ্রত্যাখ্যানকারীদের প্রতি!\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxlvii{আমরা কি পৃথিবীটাকে বানাই নি আধাররূপে --\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxlviii{জীবিত ও মৃত, --\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxlix{আর তাতেই তো আমরা বানিয়েছি উঁচু পাহাড়-পর্বত, আর তোমাদের পান করতে দিয়েছি সুপেয় পানি?\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmmdcl{ধিক সেইদিন সত্যপ্রত্যাখ্যানকারীদের প্রতি!\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmmdcli{''তোমরা চলো তারই দিকে যাকে তোমরা অস্বীকার করতে, --\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmmdclii{''চলো সেই ছায়ার দিকে যার রয়েছে তিনটি স্তর, --\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmmdcliii{''যা ছায়াময় নয় এবং অগ্নিশিখা থেকে রক্ষা করার মতোও নয়।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmmmdcliv{''নিঃসন্দেহ এটি স্ফুলিঙ্গ তোলে অট্টালিকার আকারে,\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmmmdclv{''যেন সেগুলো হলুদবরণ উটের পাল।’’\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmmmdclvi{ধিক্ সেইদিন সত্যপ্রত্যাখ্যানকারীদের প্রতি!\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmmmdclvii{এ হচ্ছে ঐ দিন যেদিন তারা কোনো কথা বলতে পারবে না,\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmmmdclviii{আর তাদের অনুমতি দেওয়া হবে না যেন তারা অজুহাত দেখাতে পারে।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmmmdclix{ধিক্ সেইদিন সত্যপ্রত্যাখানকারীদের প্রতি!\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmmmdclx{এই হচ্ছে ফয়সালা করার দিন, আমরা তোমাদের সমবেত করেছি, আর পূর্ববর্তীদেরও।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxi{সুতরাং তোমাদের যদি কোনো কলাকৌশল থাকে তাহলে আমার বিরুদ্ধে অপকৌশল চালাও।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxii{ধিক্ সেইদিন সত্যপ্রত্যাখ্যানকারীদের প্রতি!\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxiii{নিশ্চয় ধর্মভীরুরা থাকবে স্নিগ্ধছায়ায় ও ফোয়ারাগুলোতে,\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxiv{আর ফলফসলের মধ্যে যা তারা পেতে চায়।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxv{''খাও আর পিয়ো মহানন্দে যা তোমরা করে চলেছিলে সেজন্য।’’\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxvi{নিঃসন্দেহ এইভাবেই আমরা প্রতিদান দিই সৎকর্মশীলদের।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxvii{ধিক্ সেইদিন সত্যপ্রত্যাখ্যানকারীদের প্রতি!\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxviii{খাও-দাও আর ভোগ করে নাও অল্পকালের জন্য -- তোমরা তো অপরাধী!’’\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxix{ধিক্ সেইদিন সত্যপ্রত্যাখ্যানকারীদের প্রতি!\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxx{আর যখন তাদের বলা হয় ''নত হও’’, তারা নত হয় না।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxxi{ধিক্ সেইদিন সত্যপ্রত্যাখ্যানকারীদের প্রতি!\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxxii{অতএব এর পরে আর কোন বাণীতে তারা বিশ্বাস করবে?\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxxiii{\basmalahbn কি সন্বন্ধে তারা পরস্পরকে জিজ্ঞাসাবাদ করছে?\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxxiv{সেই মহাসংবাদ সন্বন্ধে --\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxxv{যে বিষয়ে তারা মতানৈক্যের মধ্যে রয়েছে।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxxvi{না, তারা শীঘ্রই জানতে পারবে।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxxvii{পুনশ্চ, না, তারা অতিশীঘ্রই জানতে পারবে।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxxviii{আমরা কি পৃথিবীটাকে পাতানো-বিছানারূপে বানাই নি,\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxxix{আর পাহাড়-পর্বতকে খুটিরূঁপে?\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxxx{আর আমরা তোমাদের সৃষ্টি করেছি জোড়ায়-জোড়ায়;\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxxxi{আর তোমাদের ঘুমকে করেছি বিশ্রাম,\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxxxii{আর রাতকে করেছি পোশাকস্বরূপ;\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxxxiii{আর দিনকে করেছি জীবিকার সংস্থান।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxxxiv{আর তোমাদের উপরে আমরা বানিয়েছি সাত মজবুত জিনিস,\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxxxv{আর তৈরি করেছি একটি অত্যুজ্জ্বল প্রদীপ,\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxxxvi{আর ঝরন্ত-মেঘ থেকে আমরা বর্ষণ করি প্রচুর বৃষ্টি,\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxxxvii{যেন তার দ্বারা গজাতে পারি শস্য ও গাছপালা,\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxxxviii{আর ঘনসন্নিবিষ্ট বাগানসমূহ।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxxxix{নিশ্চয় ফয়সালা করার দিনের এক নির্ধারিত সময়কাল আছে --\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxc{সেইদিন শিঙ্গায় ফুৎকার দেওয়া হবে, তখন তোমরা আসবে দলে-দলে,\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxci{আর আকাশকে বিদীর্ণ করা হবে, সুতরাং তা হবে বহু-দরজা-বিশিষ্ট।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxcii{আর পাহাড়গুলো ধসে পড়বে, ফলে তা হবে বালুময়-মরীচিকা।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxciii{নিঃসন্দেহ জাহান্নাম -- তা প্রতীক্ষায় রয়েছে --\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxciv{সীমালংঘনকারীদের জন্য প্রত্যাবর্তনস্থল; --\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxcv{সেখানে তারা অবস্থান করবে যুগ যুগ ধরে।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxcvi{তারা সেখানে স্বাদ গ্রহণ করবে না শীতলতার, না কোনো পানীয়ের --\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxcvii{শুধু ফুটন্ত জল ও হিমশীতল পানীয় ব্যতীত, --\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxcviii{এক যথাযথ প্রতিদান।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxcix{নিঃসন্দেহ তারা হিসাবের কথা ভাবে নি,\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmmdcc{আর আমাদের বাণীসমূহ প্রত্যাখ্যান করেছিল জোর প্রত্যাখ্যানে।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmmdcci{আর সব-কিছুই -- আমরা তা লিখিতভাবে সংরক্ষণ করছি,\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmmdccii{সুতরাং স্বাদ গ্রহণ করো, আমরা তোমাদের বাড়িয়ে দেবো না শাস্তি ব্যতীত।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmmdcciii{ধর্মভীরুদের জন্য নিশ্চয়ই রয়েছে মহাসাফল্য --\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmmmdcciv{ফলের বাগান ও আঙুর,\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmmmdccv{আর সমবয়স্ক ফুটফুটে কিশোর,\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmmmdccvi{আর পরিপূর্ণ পানপাত্র।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmmmdccvii{তারা সেখানে খেলো কথা শুনবে না, আর মিথ্যাকথাও নয়।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmmmdccviii{তোমার প্রভুর কাছ থেকে প্রতিফল, -- হিসাবমতো পুরস্কার, --\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmmmdccix{মহাকাশমন্ডল ও পৃথিবীর এবং তাদের মধ্যে যা-কিছু আছে তার প্রভু, পরম করুণাময়, তাঁর কাছে বক্তব্য রাখার কোনো ক্ষমতা তারা রাখে না।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmmmdccx{সেইদিন আর-রূহ ও ফিরিশ্‌তাগণ সারবেঁধে দাঁড়াবে, পরম করুণাময় যাকে অনুমতি দেবেন সে ব্যতীত তাদের কেউ কথা বলতে পারবে না, আর সে সঠিক কথা বলবে।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxi{এইটাই মহাসত্যের দিন। অতএব যে কেউ চায় সে তার প্রভুর কাছে আশ্রয়স্থল খুঁজুক।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxii{নিশ্চয় আমরা তোমাদের সতর্ক করছি এক নিকটবর্তী শাস্তি সন্বন্ধে, -- যেদিন মানুষ দেখতে পাবে তার হাত দুখানা কী আগবাড়িয়েছে, আর অবিশ্বাসী ব্যক্তি বলবে -- ''হায় আমার আফসোস! আমি যদি ধুলো হয়ে যেতাম!’’\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxiii{\basmalahbn ভাবো প্রচেষ্টাকারীদের প্রচন্ড-প্রচেষ্টার কথা;\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxiv{আর ক্ষিপ্রগামীদের ত্বরিত এগুনোয়,\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxv{আর সন্তরণকারীদের দ্রত সন্তরণে,\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxvi{আর অগ্রগামীরা এগিয়েই চলেছে,\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxvii{তারপর ঘটনানিয়ন্ত্রণকারীদের কথা!\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxviii{সেদিন স্পন্দিত হবে বিরাট স্পন্দনে,\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxix{পরবর্তী ঘটনা তাকে অনুসরণ করবেই।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxx{হৃদয় সেদিন সন্ত্রস্ত হবে,\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxxi{তাদের চোখ হবে অবনত।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxxii{তারা বলছে -- ''আমরা কি সত্যিই প্রথমাবস্থায় প্রত্যাবর্তিত হব?\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxxiii{''যখন আমরা গলা-পচা হাড্ডি হয়ে যাব তখনও?’’\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxxiv{তারা বলে -- ''তাই যদি হয় তবে এ হবে সর্বনাশা প্রত্যাবর্তন।’’\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxxv{কিন্ত এটি নিশ্চয়ই হবে একটি মহাগর্জন,\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxxvi{তখন দেখো! তারা হবে জাগ্রত।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxxvii{তোমার কাছে মূসার কাহিনী পৌঁছেছে কি? --\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxxviii{যখন তাঁর প্রভু তাঁকে আহ্বান করেছিলেন পবিত্র উপত্যকা 'তুওয়া’তে --\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxxix{''ফিরআউনের কাছে যাও, সে নিশ্চয়ই বিদ্রোহ করেছে --\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxxx{''তারপর বলো -- 'তোমার কি আগ্রহ আছে যে তুমি পবিত্র হও?’\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxxxi{''আমি তাহলে তোমাকে তোমার প্রভুর দিকে পরিচালিত করব যেন তুমি ভয় করো’।’’\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxxxii{তারপর তিনি তাকে দেখালেন একটি বিরাট নিদর্শন।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxxxiii{কিন্ত সে মিথ্যা আরোপ করল ও অবাধ্য হল।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxxxiv{তারপর সে চলে গেল প্রচেষ্টা চালাতে;\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxxxv{তারপর সে জড়ো করল এবং ঘোষণা করলো,\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxxxvi{এবং বললো -- ''আমিই তোমাদের প্রভু, সর্বোচ্চ।’’\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxxxvii{সেজন্য আল্লাহ্ তাকে পাকড়াও করলেন পরকালের ও পূর্বের জীবনের দৃষ্টান্ত বানিয়ে।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxxxviii{নিঃসন্দেহ এতে বাস্তব শিক্ষা রয়েছে তার জন্য যে ভয় করে।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxxxix{তোমরা কি সৃষ্টিতে কঠিনতর, না মহাকাশ? তিনিই এ-সব বানিয়েছেন।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxl{তিনি এর উচ্চতা উন্নীত করেছেন, আর তাকে সুবিন্যস্ত করেছেন,\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxli{আর এর রাতকে তিনি অন্ধকারাচ্ছন্ন করেছেন, আর বের করে এনেছেন এর দিবালোক।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxlii{আর পৃথিবী -- এর পরে তাকে প্রসারিত করেছেন।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxliii{এর থেকে তিনি বের করেছেন তার জল, আর তার চারণভূমি।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxliv{আর পাহাড়-পর্বত -- তিনি তাদের মজবুতভাবে বসিয়ে দিয়েছেন, --\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxlv{তোমাদের জন্য ও তোমাদের গবাদি-পশুর জন্য খাদ্যের আয়োজন।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxlvi{তারপর যখন ভীষণ দুর্বিপাক আসবে,\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxlvii{সেইদিন মানুষ স্মরণ করবে যার জন্য সে প্রচেষ্টা চালিয়েছিল,\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxlviii{আর ভয়ংকর আগুন দৃষ্টিগোচর করানো হবে যে দেখে তার জন্য।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxlix{তাছাড়া তার ক্ষেত্রে যে সীমালংঘন করেছে,\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmmmdccl{এবং দুনিয়ার জীবনকেই বেছে নিয়েছে,\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmmmdccli{সেক্ষেত্রে অবশ্য ভয়ংকর আগুন, -- সেটাই তো বাসস্থান।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclii{পক্ষান্তরে যে তার প্রভুর সামনে দাঁড়াতে ভয় করে এবং আ‌ত্মাকে কামনা-বাসনা থেকে নিবৃত্ত রাখে --\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmmmdccliii{সেক্ষেত্রে অবশ্য জান্নাত, -- সেটাই তো বাসস্থান।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmmmdccliv{তারা ঘড়ি-ঘান্টা সম্পর্কে তোমাকে জিজ্ঞাসা করে -- কখন তার আগমন হবে?’’\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclv{এ-সন্বন্ধে বলবার মতো তোমার কী আছে?\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclvi{এর চরম সীমা রয়েছে তোমার প্রভুর নিকট।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclvii{তুমি তো শুধু সতর্ককারী তার জন্য যে এ-সন্বন্ধে ভয় করে।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclviii{যেদিন তারা একে দেখবে সেদিন যেন তারা মাত্র এক সন্ধ্যাবেলা বা তার প্রভাতকাল ব্যতীত অবস্থান করে নি।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclix{\basmalahbn তিনি ভ্রকুটি করলেন এবং ফিরে বসলেন,\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclx{কেননা একজন অন্ধ তাঁর কাছে এসেছিল।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxi{আর কী তোমাকে বুঝতে দেবে যে সে হয়ত পবিত্র হতে চেয়েছিল,\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxii{অথবা সে মনোনিবেশ করত, ফলে স্মারকবাণী তার উপকারে আসত?\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxiii{আর তার ক্ষেত্রে যে নিজেকে সমৃদ্ধ ভাবে,\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxiv{তুমি তো তার প্রতিই মনোযোগ দেখাচ্ছ।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxv{অথচ তোমার উপরে নেই যদি সে নিজেকে পবিত্র না করে।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxvi{আর তার ক্ষেত্রে যে তোমার কাছে এসেছিল আগ্রহ নিয়ে,\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxvii{আর সে ভয় করছিল,\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxviii{কিন্ত তুমি তার প্রতি অবহেলা দেখালে।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxix{কদাচ না! নিঃসন্দেহ এ এক স্মরণীয় বার্তা,\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxx{অতএব যে ইচ্ছা করে সে তা স্মরণ রাখুক।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxxi{সম্মানিত পৃষ্ঠাগুলোয় --\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxxii{সুউন্নত, সুপবিত্র,\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxxiii{লেখকদের হস্তাক্ষরে,\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxxiv{সম্মানিত, গুণান্নিত।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxxv{যা তাকে অকৃতজ্ঞ বানিয়েছে সেজন্য মানুষকে ধ্বংস করা হোক।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxxvi{কী জিনিস থেকে তাকে তিনি সৃষ্টি করেছেন?\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxxvii{এক শুক্রকীট থেকে! তিনি তাকে সৃষ্টি করেছেন, তারপর তিনি তাকে সুসমঞ্জস করেছেন,\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxxviii{তারপর তার জন্য পথ সহজ করে দিয়েছেন,\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxxix{তারপর তিনি তার মৃত্যু ঘটান, এবং তাকে কবরস্থ করেন,\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxxx{তারপর যখন তিনি চাইবেন তখন তাকে পুনর্জীবিত করবেন।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxxxi{না, তাকে তিনি যা আদেশ করেছিলেন তা সে পালন করে নি।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxxxii{অতএব মানুষ তার খাদ্যের দিকে ভেবে দেখুক --\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxxxiii{কেমন ক’রে আমরা বৃষ্টি বর্ষণ করি বর্ষণধারায়,\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxxxiv{তারপর আমরা মাটিকে ফাটিয়ে দিই চৌচির ক’রে,\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxxxv{তারপর তাতে আমরা জন্মাই শস্য,\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxxxvi{আর আঙ্গুর ও শাকসবজি,\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxxxvii{আর জলপাই ও খেজুর,\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxxxviii{আর ঘন গাছপালাময় বাগান,\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxxxix{আর ফলফসল ও তৃণলতা, --\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxc{তোমাদের জন্য খাদ্যভান্ডার ও তোমাদের গবাদি-পশুর জন্যেও।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxci{তারপর যেদিন কান-ফাটানো আওয়াজ আসবে --\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxcii{সেইদিন মানুষ তার ভাইকে ছেড়ে পালাবে,\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxciii{আর তার মাকে ও তার বাবাকে,\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxciv{আর তার পতিপত্নীকে ও তার সন্তানসন্ততিকে।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxcv{সেদিন তাদের মধ্যের প্রত্যেক লোকেরই এত ব্যস্ততা থাকবে যে তাকে বেখেয়াল করে দেবে।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxcvi{অনেক মুখ সেইদিন হবে উজ্জ্বল,\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxcvii{হাসিমাখা, আনন্দমুখর,\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxcviii{আর সেইদিন অনেক মুখ -- তাদের উপরে ধূলো-বালি,\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxcix{কালো- আঁধার তাদের ঢেকে ফেলবে।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmmmdccc{এরা নিজেরাই সত্যপ্রত্যাখ্যানকারী, দুষ্কৃতিকারী।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmmmdccci{\basmalahbn যখন সূর্য অন্ধকারাচ্ছন্ন হয়ে যাবে,\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccii{আর যখন তারকারা নিস্তেজ হয়ে পড়বে,\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmdccciii{আর যখন পাহাড়গুলোকে অপসারণ করা হবে,\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmdccciv{আর যখন পূর্ণ-গর্ভা উষ্টীদের পরিত্যাগ করা হবে;\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccv{আর যখন বন্য পশুদের সমবেত করা হবে,\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccvi{আর যখন সাগর-নদী ফেঁপে উঠবে,\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccvii{আর যখন মনপ্রাণকে একতাবদ্ধ করা হবে,\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccviii{আর যখন জীবন্ত-প্রোথিত কন্যাসন্তানকে প্রশ্ন করা হবে --\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccix{''কোন অপরাধে তাকে হত্যা করা হয়েছিল’’?\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccx{আর যখন পৃষ্ঠাগুলো খুলে ধরা হবে,\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxi{আর যখন আকাশের ঢাকনি খুলে ফেলা হবে,\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxii{আর যখন ভয়ংকর আগুন জ্বালিয়ে তোলা হবে,\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxiii{আর যখন বেহেশতকে নিকটে আনা হবে, --\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxiv{সত্ত্বা জানতে পারবে কী সে হাজির করেছে।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxv{কাজেই না, আমি সাক্ষী মানছি গ্রহ-নক্ষত্রদের --\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxvi{যারা চলে থাকে, অদৃশ্য হয়ে যায়,\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxvii{আর রাত্রিকে যখন তা বিগত হয়ে যায়,\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxviii{আর প্রভাতকে যখন তা উজ্জ্বল হতে থাকে,\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxix{নিঃসন্দেহ এ তো হচ্ছে এক সম্মানিত রসূলের বাণী --\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxx{শক্তির অধিকারী, আরশের অধীশ্বরের সামনে অধিষ্ঠিত,\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxxi{যাঁকে মেনে চলতে হয়, আর যিনি বিশ্বাসভাজন।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxxii{আর তোমাদের সাথী তো পাগল নন।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxxiii{আর তিনি তো নিজেকে দেখেছিলেন স্পষ্ট দিগন্তে;\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxxiv{আর তিনি অদৃশ্য-সন্বন্ধে কৃপণ নন,\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxxv{আর এটি কোনো বিতাড়িত শয়তানের বক্তব্য নয়।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxxvi{তোমরা তাহলে কোন দিকে চলেছ?\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxxvii{এটি আলবৎ বিশ্ববাসীর জন্য স্মরণীয় বার্তা বৈ তো নয়, --\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxxviii{তোমাদের মধ্যেকার তার জন্য যে সহজ-সঠিক পথে চলতে চায়।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxxix{আর বিশ্বজগতের প্রভু আল্লাহ্ যা চান তা ব্যতীত তোমরা অন্য কোনো-কিছু চাইবে না।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxxx{\basmalahbn যখন আকাশ বিদীর্ণ হবে,\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxxxi{আর যখন নক্ষত্রসব বিক্ষিপ্ত হবে,\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxxxii{আর যখন সমুদ্রগুলো উচ্ছলিত হবে,\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxxxiii{আর যখন কবরগুলো উন্মোচিত হবে, --\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxxxiv{তখন প্রত্যেকেই জানতে পারবে সে কী আগ-বাড়িয়েছে, আর কী সে পেছনে ফেলে রেখেছে।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxxxv{ওহে মানব! কিসে তোমাকে ভুলিয়েছে তোমার মহানুভব প্রভুসন্বন্ধে --\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxxxvi{যিনি তোমাকে সৃষ্টি করেছেন, তারপর তোমাকে সুঠাম করেছেন, তারপর তোমাকে সুসমঞ্জস করেছেন, --\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxxxvii{যে আকৃতিতে তিনি চেয়েছেন সেইভাবে তিনি তোমাকে গঠন করেছেন?\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxxxviii{না, তোমরা বরং সদ্বিচারকেই মিথ্যারোপ করছ।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxxxix{অথচ তোমাদের উপরে নিশ্চয়ই তত্ত্বাবধায়ক রয়েছে, --\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxl{সম্মানিত লিপিকারগণ,\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxli{তারা জানে তোমরা যা-কিছু কর।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxlii{ধার্মিকরা নিশ্চয় থাকবে আনন্দেরই মাঝে,\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxliii{আর পাপাচারীরা আলবৎ থাকবে ভয়ংকর আগুনে, --\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxliv{তারা এতে প্রবেশ করবে বিচারের দিনে\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxlv{আর তারা এর থেকে গরহাজির থাকতে পারবে না।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxlvi{আর কিসে তোমাকে বুঝতে দেবে কী সেই বিচারের দিন?\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxlvii{পুনরায় কিসে তোমাকে বোঝানো যাবে বিচারের দিন কি?\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxlviii{এ সেইদিন যেদিন কোনো সত্ত্বা কোনো আ‌ত্মার জন্যে কোনো-কিছু করার সামর্থ্য রাখবে না। আর কর্তৃত্ব সেইদিন হবে আল্লাহ্‌রই।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxlix{\basmalahbn ধিক্ প্রতারণাকারীদের জন্য --\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccl{যারা মানুষের কাছ থেকে যখন মেপে নেয় তখন পুরো মাপ চায়,\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccli{আর যখন তাদের মেপে দেয় অথবা তাদের জন্য ওজন করে তখন কম করে।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclii{তারা কি ভাবে না যে তারাই তো -- তারা নিশ্চয়ই পুনরুত্থিত হবে --\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccliii{ভীষণ এক দিনে,\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccliv{যেদিন মানুষরা দাঁড়াবে বিশ্বজগতের প্রভুর সামনে?\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclv{না, নিঃসন্দেহ দুষ্কৃতিকারীদের দলিল-দস্তাবেজ তো সিজ্জীনের ভেতরে রয়েছে ।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclvi{আর কী তোমাকে বোঝাবে সিজ্জীন কি?\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclvii{স্পষ্টভাবে লিখিত নিবন্ধগ্রন্থ।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclviii{ধিক্ সেইদিন সত্যপ্রত্যাখ্যানকারীদের প্রতি --\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclix{যারা বিচারের দিনকে মিথ্যা ভেবেছে!\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclx{আর কেউ একে অস্বীকার করে না কেবল প্রত্যেক সীমালংঘনকারী পাপিষ্ঠ ব্যতীত --\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxi{যে, যখন তার কাছে আমাদের বাণীসমূহ পাঠ করা হয় তখন বলে -- ''আদ্যিকালের গালগল্প।’’\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxii{না, বরং তারা যা অর্জন করে চলেছিল তা তাদের হৃদয়ে মরচে ধরিয়েছে।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxiii{না, তারা নিঃসন্দেহ তাদের প্রভুর কাছ থেকে সেদিন অবশ্যই বঞ্চিত হবে।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxiv{তারপর তারা নিশ্চয় ভয়ংকর আগুনে প্রবেশ করবে।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxv{তখন তাদের বলা হবে -- ''এই তো তাই যা তোমরা মিথ্যা বলতে।’’\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxvi{না, নিঃসন্দেহ ধর্মপরায়ণদের কর্মবিবরণী তো ইল্লিয়ীনে রয়েছে।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxvii{আর কেমন ক’রে তোমাকে বুঝানো যাবে ইল্লিয়ীন কি?\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxviii{স্পষ্টভাবে লিখিত নিবন্ধগ্রন্থ, --\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxix{নৈকট্যপ্রাপ্তরা তা দেখতে পাবে।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxx{নিঃসন্দেহ ধর্মপরায়ণরা তো থাকবে পরমানন্দে,\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxxi{উঁচু আসনে চেয়ে থাকবে।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxxii{তাদের চেহারাতে তুমি পরিচয় পাবে পরমানন্দের দীপ্তি।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxxiii{তাদের পান করানো হবে বিশুদ্ধ পানীয় থেকে, যা মোহর-মারা;\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxxiv{তার মোহর হচ্ছে কস্তুরীর। আর এর জন্যেই তবে উচ্চাকাঙক্ষীরা আকাঙক্ষা করুক।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxxv{আর তার সংমিশ্রণ হবে তসনীম থেকে,\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxxvi{একটি প্রস্রবণ যা থেকে পান করে নৈকট্যপ্রাপ্তরা।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxxvii{যারা অপরাধ করত তারা অবশ্য উপহাস করতো তাদের যারা ঈমান এনেছে,\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxxviii{আর যখন তারা তাদের পাশ দিয়ে যেতো তখন তারা পরস্পর চোখ ঠারতো;\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxxix{আর যখন তারা নিজেদের দলের কাছে ফিরে আসত তখন তারা ফিরতো উল্লাস করতে করতে।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxxx{আর যখন তারা তাদের দেখত তখন বলতো -- ''নিশ্চয় এরাই তো পথভ্রষ্ট।’’\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxxxi{কিন্ত তাদের তো এদের উপরে তত্ত্বাবধায়ক করে পাঠানো হয় নি।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxxxii{কাজেই আজকের দিনে যারা ঈমান এনেছিল তারা অবিশ্বাসীদের প্রতি হাসাহাসি করবে,\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxxxiii{উঁচু আসনে চেয়ে চেয়ে দেখবে।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxxxiv{অবিশ্বাসীদের কি সেই প্রতিফলই দেওয়া হ’ল না যা তারা করত?\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxxxv{\basmalahbn যখন আকাশ খন্ডবিখন্ড হবে,\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxxxvi{আর তার প্রভুর প্রতি উৎকর্ণ হবে এবং কর্তব্যরত হবে --\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxxxvii{আর যখন পৃথিবীকে সমতল করা হবে,\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxxxviii{আর তার ভেতরে যা-কিছু রয়েছে তা নিক্ষেপ করবে এবং শূন্যগর্ভ হবে,\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxxxix{ফলে তার প্রভুর প্রতি উৎকর্ণ হবে এবং কর্তব্যরত হবে।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxc{ওহে মানব! নিশ্চয় তোমার প্রভুর তরফে তোমাকে প্রচেষ্টা চালাতে হবে বিশেষ উদ্যমে, তাহলে তুমি তাঁর সাক্ষাৎ পাবে।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxci{সুতরাং তার ক্ষেত্রে যাকে তার নিবন্ধগ্রন্থ তার ডান হাতে দেওয়া হবে,\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxcii{তাকে তো তবে হিসেব চুকিয়ে দেওয়া হবে সহজ হিসেবনিকেশে,\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxciii{আর সে তার স্বজনদের কাছে ফিরে যাবে খুশি হয়ে।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxciv{আর তার ক্ষেত্রে যাকে তার নিবন্ধগ্রন্থ তার পিঠের পশ্চাৎ দিকে দেওয়া হবে,\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxcv{সে তখনই ধ্বংসের জন্য আর্তনাদ করবে,\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxcvi{আর জ্বলন্ত আগুনে প্রবেশ করবে।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxcvii{নিঃসন্দেহ সে তার স্বজনদের মধ্যে ফুর্তিতে ছিল।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxcviii{নিঃসন্দেহ সে ভেবেছিল যে সে কখনো ফিরে আসবে না।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxcix{না, নিঃসন্দেহ তার প্রভু বরাবর তার প্রতি দৃষ্টিদাতা।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmcm{কিন্ত না, আমি সাক্ষী করছি সূর্যাস্তের রক্তিমাভা,\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmcmi{আর রাত্রিকে ও যা-কিছু তা তাড়িয়ে নেয়,\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmcmii{আর চন্দ্রকে যখন সে পূর্ণাঙ্গতা পায়,\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmcmiii{যেন তোমরা এক স্তর থেকে অন্য স্তরে আরোহণ করতে পারো।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmmcmiv{সুতরাং তাদের কী হয়েছে যে তারা ঈমান আনছে না,\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmmcmv{আর যখন তাদের নিকট কুরআন পাঠ করা হয় তখন তারা সিজদা করে না?\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmmcmvi{পরন্তু যারা অবিশ্বাস করে তারা মিথ্যারোপ করে,\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmmcmvii{অথচ আল্লাহ্ ভালো জানেন যা তারা লুকোচ্ছে।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmmcmviii{অতএব তাদের সুসংবাদ দাও মর্মন্তুদ শাস্তির,\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmmcmix{তারা ব্যতীত যারা ঈমান এনেছে ও সৎকাজ করছে, -- তাদের জন্য রয়েছে এক নিরবচ্ছিন্ন প্রতিদান।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmmcmx{\basmalahbn ভাবো নক্ষত্রপুঞ্জবিশিষ্ট আকাশের কথা,\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxi{আর সেই অঙ্গীকার করা দিনের কথা,\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxii{আর সাক্ষ্যদাতার ও যাদের জন্য সাক্ষ্য দেওয়া হবে তাদের কথা।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxiii{খন্দকগুলোর মালিকদের নিপাত করা হয়েছে,-\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxiv{জ্বালানি দেওয়া অগ্নিকুন্ড;\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxv{দেখো! তারা এর কিনারা বসে থাকত,\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxvi{আর তারা মুমিনদের সঙ্গে যা করত তার জন্য তারাই সাক্ষী ছিল।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxvii{আর তারা এদের প্রতি বিরূপ ছিল না এই ব্যতীত যে এরা বিশ্বাস করত মহাশক্তিশালী পরমপ্রশংসিত আল্লাহ্ তে-\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxviii{যাঁর অধিকারে মহাকাশমন্ডল ও পৃথিবীর সার্বভৌম কর্তৃত্ব রয়েছে। আর আল্লাহ্ সব-কিছুর উপরে সাক্ষী রয়েছেন।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxix{নিঃসন্দেহে যারা মুমিন পুরুষ ওমুমিন নারীদের নির্যাতন করে এবং তারপরে ফেরে না, তাদের জন্য তবে রয়েছে জাহান্নামের শাস্তি, আর তাদের জন্য আছে দহন যন্ত্রণা।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxx{পক্ষান্তরে যারা ঈমান এনেছে ও সৎকর্ম করছে তাদের জন্য রয়েছে বাগানসমূহ যাদের নিচে দিয়ে বয়ে চলেছে ঝরনারাজি। এটিইতো বিরাট সাফল্য।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxxi{নিঃসন্দেহে তোমার প্রভুর পাকড়ানো বড়ই কঠোর।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxxii{নিঃসন্দেহে তিনি, তিনিই সৃষ্টি শুরু করেন এবং পুনঃসৃষ্টি করেন;\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxxiii{আর তিনিই পরিত্রাণকারী, প্রেমময়,\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxxiv{সম্মানিত আরশের অধিকারী,\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxxv{তিনি যা চাহেন তার একক কর্মকর্তা।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxxvi{তোমার কাছে কি সৈন্যবাহিনীর সংবাদ পৌঁছেছে-\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxxvii{ফিরআউনের ও ছামূদের?\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxxviii{বস্তুত যারা অবিশ্বাস করেছে তারা মিথ্যারোপ করায় রত;\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxxix{কিন্তু আল্লাহ্ তাদের পেছন থেকে ঘেরাও করে রয়েছেন।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxxx{বস্তুত এ হচ্ছে সম্মানিত কুরআন-\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxxxi{সুরক্ষিত ফলকে।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxxxii{\basmalahbn ভাবো আকাশের ও রাতের আগন্তুকের কথা!\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxxxiii{আর কী তোমাকে বুঝতে দেবে কে সেই রাতের আগন্তুক?\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxxxiv{একটি অত্যুজ্জ্বল নক্ষত্র।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxxxv{প্রত্যেক সার পক্ষেই -- তার উপরে একজন তত্ত্বাবধায়ক রয়েছে।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxxxvi{সুতরাং মানুষ ভেবে দেখুক কিসে থেকে তাকে সৃষ্টি করা হয়েছে।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxxxvii{তাকে সৃষ্টি করা হয়েছে সবেগে-স্খলিত পানি থেকে, --\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxxxviii{যা নির্গত হয় মেরুদন্ড ও বুকের পাঁজরের মধ্য হতে।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxxxix{নিঃসন্দেহ তিনি তার প্রত্যাবর্তনে অবশ্যই ক্ষমতাবান।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxl{সেইদিন লুকোনো সব-কিছুকে প্রকাশ করা হবে;\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxli{তখন তার থাকবে না কোনো ক্ষমতা ও না কোনো সাহায্যকারী।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxlii{ভাবো বর্ষণোন্নুখ আকাশের কথা,\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxliii{আর পৃথিবীর কথা যা বিদীর্ণ হয়।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxliv{নিঃসন্দেহ এটি সুমীমাংসাকারী বক্তব্য,\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxlv{আর এটি কোনো তামাশার জিনিস নয়।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxlvi{নিঃসন্দেহ তারা চাল চালছে,\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxlvii{আর আমিও পরিকল্পনা উদ্ভাবন করছি।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxlviii{অতএব তুমি অবিশ্বাসীদের অবকাশ দাও, তাদের অবকাশ দাও কিছুটা সময়।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxlix{\basmalahbn মহিমা ঘোষণা করো তোমার সর্বোন্নত প্রভুর নামের, --\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmcml{যিনি সৃষ্টি করেন, তারপর সুঠাম করেন,\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmcmli{আর যিনি সুসমঞ্জস করেন, তারপর পথ দেখিয়ে নেন,\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlii{আর যিনি তৃণলতা উদ্‌গত করেন,\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmcmliii{তারপর তাকে শুকিয়ে পাঁশুটে বানিয়ে ফেলেন।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmcmliv{আমরা যথাশীঘ্র তোমাকে পড়াবো, ফলে তুমি ভুলবে না, --\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlv{শুধু যা-কিছু আল্লাহ্ ইচ্ছা করেন তা ব্যতীত। নিশ্চয় তিনি জানেন প্রকাশ্য এবং যা গুপ্ত রয়েছে।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlvi{আর আমরা তোমার জন্য সহজ করে দেব সহজকরনের জন্য।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlvii{অতএব তুমি স্মরণ করিয়ে চলোচ নিশ্চয় স্মরণ করানোতে সুফল রয়েছে।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlviii{যে ভয় করে সে যথাসত্বর উপদেশ গ্রহণ করবে,\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlix{কিন্ত এটি এড়িয়ে চলবে নেহাত দুশ্চরিত্র, --\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlx{যে বিরাট আগুনে ঢোকে পড়বে,\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxi{তখন সে সেখানে মরবে না, আর বাঁচবেও না।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxii{সে-ই যথার্থ সফলকাম হবে যে নিজেকে পবিত্র করেছে,\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxiii{এবং তার প্রভুর নাম স্মরণ করে, আর নামায পড়ে।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxiv{না, তোমরা দুনিয়ার জীবনকে প্রাধান্য দাও,\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxv{অথচ পরকালই বেশি ভাল ও দীর্ঘস্থায়ী।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxvi{নিঃসন্দেহ এইসব আছে পূর্ববর্তী ধর্মগ্রন্থে --\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxvii{ইব্রাহীম ও মূসার ধর্মগ্রন্থে।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxviii{\basmalahbn তোমার কাছে কি বিহবলকর ঘটনার সংবাদ পৌঁছেছে?\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxix{সেইদিন অনেক মুখ হবে অবনত,\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxx{পরিশ্রান্ত, অবসাদগ্রস্ত,\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxxi{প্রবেশমান হবে জ্বলন্ত আগুনে;\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxxii{তাদের পান করানো হবে ফুটন্ত ফোয়ারা থেকে।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxxiii{তাদের জন্য বিষাক্ত কাঁটাগাছ থেকে ছাড়া অন্য কোনো খাদ্য থাকবে না,\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxxiv{তাদের নাদুসনুদুস বানাবে না এবং ক্ষুধাও মেটাবে না।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxxv{সেইদিন অনেক মুখ হবে শান্ত,\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxxvi{তাদের প্রচেষ্টার জন্য পরিতৃপ্ত,\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxxvii{সমুচ্চ উদ্যানে,\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxxviii{সেখানে তুমি শুনবে না কোনো বাজে কথা।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxxix{সেখানে রয়েছে বহমান ঝরনা,\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxxx{সেখানে আছে উঁচু সিংহাসন,\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxxxi{আর পানপাত্রগুলো হাতের কাছে স্থাপিত,\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxxxii{আর তাকিয়াগুলো সারিসারি সাজানো,\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxxxiii{আর গালিচাসব বিছানো।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxxxiv{তারা কি তবে ভেবে দেখে না উটের দিকে -- কেমন করে তাকে সৃষ্টি করা হয়েছে,\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxxxv{আর আকাশের দিকে -- কেমন করে তাকে তোলে রাখা হয়েছে।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxxxvi{আর পাহাড়-পর্বতের দিকে -- কেমন করে তাদের স্থাপন করা হয়েছে,\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxxxvii{আর এই পৃথিবীর দিকে -- কেমন করে তাকে প্রসারিত করা হয়েছে?\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxxxviii{অতএব উপদেশ দিয়ে চলো, নিঃসন্দেহ তুমি তো একজন উপদেষ্টা।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxxxix{তুমি তাদের উপরে আদৌ অধ্যক্ষ নও,\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxc{কিন্ত যে কেউ ফিরে যায় ও অবিশ্বাস পোষণ করে --\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxci{আল্লাহ্ তখন তাকে শাস্তি দেবেন কঠিনতম শাস্তিতে।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxcii{নিঃসন্দেহ আমাদের কাছেই তাদের প্রত্যাবর্তন,\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxciii{অতঃপর আমাদের উপরেই তাদের হিসেব-নিকেশের ভার।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxciv{\basmalahbn ভাবো ভোরবেলার কথা,\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxcv{আর দশ রাত্রির কথা,\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxcvi{আর জোড়ের ও বেজোড়ের কথা,\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxcvii{আর রাত্রির কথা যখন তা বিগত হয়।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxcviii{এতে কি নেই কোনো শপথবাক্য বোধশক্তিসম্পন্নদের জন্য?\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxcix{তুমি কি দেখো নি তোমার প্রভু কি করেছিলেন 'আদ বংশের প্রতি, --\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmm{ইরামের প্রতি যাদের ছিল উঁচু গঠন,\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmmi{যাদের ক্ষেত্রে ওগুলোর সমতুল্য অন্য শহরে তৈরি হয় নি,\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmmii{আর ছামূদ-জাতির প্রতি, যারা খোলা-প্রান্তরে বিশালাকার পাথর কাটতো;\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmmiii{আর ফিরআউনের প্রতি, যার ছিল দুর্ধর্ষ সেনাদল,\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmmiv{যারা বিদ্রোহাচরণ করেছিল শহরে-নগরে,\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmmv{আর সেখানে অশান্তি বাড়িয়ে দিয়েছিল?\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmmvi{সেইজন্য তোমার প্রভু তাদের উপরে হেনেছিলেন শাস্তির কশাঘাত।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmmvii{নিঃসন্দেহ তোমার প্রভু তো প্রহরামঞ্চে রয়েছেন।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmmviii{সুতরাং মানুষের বেলা -- যখন তার প্রভু তাকে পরীক্ষা করেন, ফলে তাকে সম্মান দেন ও তাকে অনুগ্রহ দান করেন, তখন সে বলে -- ''আমার প্রভু আমাকে সম্মান দিয়েছেন।’’\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmmix{আর যখন তিনি তাকে পরীক্ষা করেন, ফলে তার প্রতি তার জীবনোপকরণ মেপে-জোখে দেন, তখন সে বলে -- ''আমার প্রভু আমাকে হীন করেছেন।’’\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmmx{না, বস্তুত তোমরা এতীমকে সম্মান কর না,\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmmxi{আর নিঃস্বদের খাবার দিতে পরস্পরকে উৎসাহিত কর না,\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmmxii{আর তোমরা গ্রাস করে ফেল উত্তরাধিকার স্বত্ব পুরোপুরি গলাধঃকরণে;\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmmmxiii{আর তোমরা ধনসম্পত্তি ভালবাস গভীর ভালবাসায়।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmmmxiv{কখনই না! যখন পৃথিবীটা ভেঙ্গে চূর্ণবিচূর্ণ হয়ে যাবে,\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmmmxv{আর তোমার প্রভু ও ফিরিশ্‌তাগণ আসবেন কাতারে কাতারে,\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmmmxvi{আর সেইদিন তিনি জাহান্নামকে নিয়ে আসবেন; সেইদিন মানুষ স্মরণ করবে, কিন্ত এ স্মরণে তার কী কাজ হবে?\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmmmxvii{সে বলবে -- ''হায় আমার আফসোস! আমি যদি আগবাড়াতাম আমার এই জীবনের জন্য!’’\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmmmxviii{কিন্ত সেইদিন কেউই তাঁর শাস্তির মতো শাস্তি দিতে পারবে না,\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmmmxix{আর না পারবে কেউ বাঁধতে তাঁর বাঁধনের মতো।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmmmxx{''ওহে প্রশান্ত প্রাণ!\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmmmxxi{''তোমার প্রভুর কাছে ফিরে এসো সন্তষ্ট হয়ে, -- সন্তোষভাজন হয়ে,\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmmmxxii{''তারপর প্রবেশ করো আমার বান্দাদের দলে;\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmmmxxiii{''আর প্রবেশ করো আমার জান্নাতে।’’\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmmmxxiv{\basmalahbn না, আমি শপথ করছি এই নগরের নামে,\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmmxxv{আর তুমি বৈধ থাকবে এই নগরীতে;\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmmxxvi{আর জন্মদাতার, আর যাদের তিনি জন্ম দিয়েছেন।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmmxxvii{আমরা নিশ্চয়ই মানুষকে সৃষ্টি করেছি শ্রমনির্ভর করে।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmmxxviii{সে কি ভাবে যে তার উপরে কেউ কোনো ক্ষমতা রাখতে পারে না?\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmmxxix{সে বলে -- ''আমি প্রচুর সম্পদ নিঃশেষ করেছি।’’\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmmxxx{সে কি ভাবে যে তাকে কেউ দেখতে পাবে না?\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmmxxxi{আমরা কি তার জন্য বানিয়ে দিই নি দুটি চোখ,\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmmxxxii{আর একটি জিহবা ও দুটি ঠোঁট,\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmmxxxiii{আর আমরা কি তাকে দুটি পথই দেখাই নি?\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmmxxxiv{কিন্ত সে ঊর্ধ্বগামী পথ ধরতে চায় নি।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmmxxxv{আর কেমন করে তোমাকে বোঝানো যাবে কী সেই ঊর্ধ্বগামী পথ?\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmmxxxvi{দাসকে মুক্তি দেওয়া,\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmmxxxvii{অথবা আকালের দিনে খাবার দেওয়া --\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmmxxxviii{নিকট সম্পর্কের এতীমকে,\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmmxxxix{অথবা ধুলোয় লুটানো নিঃস্বকে।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmmxl{তাহলে সে তাদের অন্তর্ভুক্ত যারা ঈমান এনেছে, আর পরস্পরকে অধ্যবসায় অবলন্বনে প্রচেষ্টা করে ও একে-অন্যে দয়া-দাক্ষিণ্যের প্রয়াস চালায়।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmmxli{এরাই হচ্ছে দক্ষিণপন্থীয়দের দলভুক্ত।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmmxlii{আর যারা আমাদের বাণীসমূহে অবিশ্বাস পোষণ করে তারাই হচ্ছে বামপন্থীয়দের দলভুক্ত।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmmmxliii{তাদের উপরে আগুন আচ্ছাদিত করে রইবে।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmmmxliv{\basmalahbn ভাবো সূর্যের আর তার সকাল বেলাকার কিরণের কথা,\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmmxlv{আর চন্দ্রের কথা যখন সে তার কিরণ ধার করে,\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmmxlvi{আর দিনের কথা যখন সে তাকে উজ্জ্বলভাবে প্রকাশ করে,\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmmxlvii{আর রাতের কথা যখন সে তাকে আচ্ছাদিত করে।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmmxlviii{ভাবো মহাকাশের কথা ও যিনি তাকে বানিয়েছেন,\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmmxlix{আর পৃথিবীর কথা ও যিনি তাকে প্রসারিত করেছেন,\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmml{আর মানবা‌ত্মার কথা ও যিনি তাকে সুঠাম করেছেন,\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmmli{তারপর তাতে আবেগ সঞ্চার করেছেন তার মন্দ কাজের ও তার ধর্মপরায়ণতার।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmmlii{সে-ই সফলতা অর্জন করবে যে তাকে শোধিত করবে;\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmmliii{আর সে-ই ব্যর্থ হবে যে একে পঙ্গু করবে।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmmliv{ছামূদ জাতি তাদের অবাধ্যতা বশত মিথ্যা বলেছিল,\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmmlv{যখন তাদের সব চাইতে ইতর লোকটি উঠে দাঁড়িয়েছিল, --\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmmlvi{তখন আল্লাহ্‌র রসূল তাদের বলেছিলেন -- ''আল্লাহ্‌র উষ্ট্রী, আর তার জলপানস্থল।’’\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmmlvii{কিন্ত তারা তাঁকে মিথ্যাবাদী বললো ও তাকে হত্যা করল, সেজন্য তাদের প্রভু তাদের পাপের জন্যে তাদের উপরে বিধ্বংসী আঘাত হানলেন, ফলে তাদের একসমান করে দিলেন;\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmmlviii{আর তিনি এর পরিণামের জন্য ভয় করেন না।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmmlix{\basmalahbn ভাবো রাত্রির কথা, যখন তা ঢেকে দেয়,\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmmlx{আর দিনের কথা যখন তা ঝলমল করে;\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxi{আর তাঁর কথা যিনি পুরুষ ও নারী সৃষ্টি করেছেন।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxii{নিঃসন্দেহ তোমাদের কর্মপ্রচেষ্টা অবশ্য বিভিন্ন প্রকৃতির।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxiii{সুতরাং যে কেউ দান করে ও ধর্মভীরুতা অবলন্বন করে,\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxiv{এবং সুষ্ঠু-সুন্দর বিষয়ে সত্যনিষ্ঠ থাকে,\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxv{আমি শীঘই তার জন্য তবে সহজ করে দেব আরাম করার জন্য।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxvi{কিন্ত তার ক্ষেত্রে যে কৃপণতা করে ও নিজেকে স্বয়ংসমৃদ্ধ জ্ঞান করে,\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxvii{এবং সুষ্ঠু-সুন্দর বিষয়ে মিথ্যারোপ করে,\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxviii{তার জন্য তবে আমি অচিরেই সহজ করে দেব কষ্ট ভোগের জন্য।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxix{আর তার ধনসম্পদ তার কোনো কাজে আসবে না যখন সে অধঃপাতে পড়বে।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxx{নিঃসন্দেহ আমাদের কর্তব্য তো পথনির্দেশ করা চ\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxxi{আর নিঃসন্দেহ আমরাই তো মালিক পরকালের ও পূর্বকালের।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxxii{সেজন্য তোমাদের সাবধান করে দিচ্ছি লেলিহান আগুন সন্বন্ধে,\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxxiii{তাতে প্রবেশ করবে না নিতান্ত হতভাগ্য ব্যতীত --\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxxiv{যে মিথ্যারোপ করে ও ফিরে যায়।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxxv{আর এর থেকে আলবৎ দূরে রাখা হবে তাকে যে পরম ধর্মভীরু --\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxxvi{যে তার ধনদেলত দান করে, আ‌ত্মশুদ্ধি করে,\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxxvii{আর কারো ক্ষেত্রে তার জন্য এমন কোনো অনুগ্রহসামগ্রী নেই যার জন্যে সে প্রতিদান দাবি করতে পারে --\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxxviii{তার মহিমান্বিত প্রভুর প্রসন্নবদন কামনা ব্যতীত।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxxix{আর অচিরেই সে তো সন্তোষ লাভ করবেই।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxxx{\basmalahbn ভাবো পূর্বাহ্নের সূর্যকিরণের কথা;\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxxxi{আর রাত্রির কথা যখন তা অন্ধকার ছড়িয়ে দেয়।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxxxii{তোমার প্রভু তোমাকে পরিত্যাগ করেন নি, এবং তিনি অসন্তষ্টও নন।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxxxiii{আর আলবৎ পরকাল তোমার জন্য হবে প্রাথমিককালের চেয়ে ভালো।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxxxiv{আর শীঘ্রই তো তোমার প্রভু তোমাকে দান করবেন, ফলে তুমি সন্তষ্ট হবে।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxxxv{তিনি কি তোমাকে এতীম অবস্থায় পান নি, তখন তিনি আশ্রয় দেন?\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxxxvi{আর তিনি তোমাকে পান দিশাহারা, কাজেই তিনি পথনির্দেশ দেন।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxxxvii{আর তিনি তোমাকে পান নিঃস্ব অবস্থায়, সেজন্য তিনি সমৃদ্ধ করেন।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxxxviii{সুতরাং এতীমের ক্ষেত্রে -- তুমি তবে রূঢ় হয়ো না।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxxxix{আর সাহায্যপ্রার্থীর ক্ষেত্রে -- তুমি তবে হাঁকিয়ে দিয়ো না।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmmxc{আর তোমার প্রভুর অনুগ্রহের ক্ষেত্রে -- তুমি তবে ঘোষণা করতে থাকো।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmmxci{\basmalahbn আমরা কি তোমার বক্ষ প্রশস্ত করে দিই নি?\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmmxcii{আর আমরা তোমার থেকে লাঘব করেছি তোমার ভার, --\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmmxciii{যা চেপে বসেছিল তোমার পিঠে;\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmmxciv{আর আমরা তোমার জন্য উন্নত করেছি তোমার নামোল্লেখ।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmmxcv{অতএব কষ্টের সঙ্গেই তো আরাম রয়েছে,\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmmxcvi{নিশ্চয় কষ্টের সঙ্গে আরাম রয়েছে।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmmxcvii{সুতরাং যখন তুমি মুক্ত হয়েছে তখন কঠোর পরিশ্রম করো,\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmmxcviii{আর তোমার প্রভুর প্রতি তবে একান্তভাবে মনোনিবেশ করো।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmmxcix{\basmalahbn ভাবো ডুমুরেব, আর জলপাইয়ের কথা;\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmmc{আর সিনাই পর্বতের কথা,\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmmci{আর এই নিরাপদ নগরের কথা!\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmmcii{সুনিশ্চয় আমরা মানুষকে সৃষ্টি করেছি শ্রেষ্ঠ-সুন্দর আকৃতিতে।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmmciii{তারপর আমরা তাকে পরিণত করি হীনদের মধ্যে হীনতমে, --\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmmciv{তারা ব্যতীত যারা ঈমান এনেছে ও সৎকাজ করছে, তাদের জন্য তবে রয়েছে বাধা-বিরতিবিহীন প্রতিদান।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmmcv{তবে কী যা এরপরে তোমাকে বিচারসন্বন্ধে মিথ্যারোপ করতে দেয়?\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmmcvi{আল্লাহ্ কি বিচারকদের মধ্যে সর্বশ্রেষ্ঠ বিচারক নন?\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmmcvii{\basmalahbn তুমি পড়ো তোমার প্রভুর নামে যিনি সৃষ্টি করেছেন, --\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmmcviii{সৃষ্টি করেছেন মানুষকে এক রক্তপিন্ড থেকে।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmmcix{পড়ো! আর তোমার প্রভু মহাসম্মানিত --\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmmcx{যিনি শিক্ষা দিয়েছেন কলমের সাহায্যে,\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxi{শিক্ষা দিয়েছেন মানুষকে যা সে জানতোই না।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxii{বস্তুতঃ মানুষ নিশ্চয়ই সীমালংঘন করেই থাকে।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxiii{কারণ সে নিজেকে স্বয়ংসমৃদ্ধ দেখে।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxiv{নিশ্চয় তোমার প্রভুর কাছেই প্রত্যাবর্তন।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxv{তুমি কি তাকে দেখেছ যে বারণ করে --\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxvi{একজন বান্দাকে যখন সে নামায পড়ে?\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxvii{তুমি কি লক্ষ্য করেছ -- সে সৎপথে রয়েছে কি না,\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxviii{অথবা ধর্মভীরুতা অবলন্বনের নির্দেশ দেয় কিনা?\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxix{তুমি কি দেখেছ -- সে মিথ্যারোপ করছে ও ফিরে যাচ্ছে কি না?\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxx{সে কি জানে না যে আল্লাহ্ অবশ্যই দেখতে পাচ্ছেন?\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxxi{না, যদি সে না থামে তবে আমরা নিশ্চয় টেনে ধরব কপালের চুলের গোছা --\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxxii{মিথ্যাচারী পাপাচারী চুলের গোছা!\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxxiii{তাহলে সে ডাকুক তার সাঙ্গোপাঙ্গদের,\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxxiv{আমরাও সঙ্গে সঙ্গে ডাকবো দুর্ধর্ষ বাহিনীকে।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxxv{না, তুমি তার আজ্ঞা পালন করো না, বরং তুমি সিজদা করো এবং নিকটবর্তী হও।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxxvi{\basmalahbn নিঃসন্দেহ আমরা এটি অবতারণ করেছি মহিমান্বিত রজনীতে।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxxvii{আর কী তোমাকে বুঝতে দেবে মহিমান্বিত রজনীটি কি?\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxxviii{মহিমান্বিত রজনী হচ্ছে হাজার মাসের চাইতেও শ্রেষ্ঠ।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxxix{ফিরিশ্‌তাগণ ও রূহ্ তাতে অবতীর্ণ হয় তাদের প্রভুর অনুমতিক্রমে প্রতিটি ব্যাপার সন্বন্ধে --\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxxx{শান্তি -- ফজরের উদয় পর্যন্ত তা চলতে থাকবে।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxxxi{\basmalahbn গ্রন্থধারীদের মধ্যে থেকে যারা অবিশ্বাস পোষণ করে আর বহুখোদাবাদীরা তাদের ছাড়ানো যাচ্ছিল না যতক্ষণ না তাদের কাছে এসেছে সুস্পষ্ট প্রমাণ --\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxxxii{আল্লাহ্‌র কাছ থেকে একজন রসূল, তিনি পাঠ করছেন পবিত্র পৃষ্ঠাসমূহ,\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxxxiii{যাতে রয়েছে সুপ্রতিষ্ঠিত গ্রন্থসমূহ।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxxxiv{আর যাদের গ্রন্থখানা দেওয়া হয়েছিল তারা বিভক্ত হয় নি যতক্ষণ না তাদের কাছে সুস্পষ্ট প্রমাণ এসেছিল।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxxxv{আর তাদের আদেশ করা হয় নি এ ভিন্ন যে তারা আল্লাহ্‌র উপাসনা করবে ধর্মে তাঁর প্রতি বিশুদ্ধচিত্ত হয়ে, একনিষ্ঠভাবে, আর নামায কায়েম করবে ও যাকাত আদায় করবে, -- আর এইটিই সুপ্রতিষ্ঠিত ধর্ম।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxxxvi{নিঃসন্দেহ গ্রন্থের অনুবর্তীদের মধ্যের যারা অবিশ্বাস পোষণ করে আর বহুখোদাবাদীরা -- জাহান্নামের আগুনে, তা তে তারা অবস্থান করবে। তারাই স্বয়ং সৃষ্টজীবদের মধ্যে নিকৃষ্টতম।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxxxvii{পক্ষান্তরে যারা ঈমান এনেছে ও সৎকাজ করছে -- তারাই খোদ সৃষ্টজগতের মধ্যে শ্রেষ্ঠতম।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxxxviii{তাদের পুরস্কার রয়েছে তাদের প্রভুর কাছে -- নন্দনকাননসমূহ, তাদের নিচ দিয়ে বয়ে চলেছে ঝরনারাজি, সেখানে তারা অবস্থান করবে চিরকাল। আল্লাহ্ তাদের উপরে সন্তষ্ট আর তারা সন্তষ্ট তাঁর প্রতি। এইটি তার জন্য যে তার প্রভুকে ভয় করে।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxxxix{\basmalahbn পৃথিবী যখন কম্পিত হবে আপন কম্পনে,\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxl{আর পৃথিবী বের করে দেবে তার বোঝাগুলা,\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxli{আর মানুষ বলবে -- ''এর কী হল?’’\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxlii{সেইদিন সে বর্ণনা করবে তার কাহিনীগুলো,\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxliii{যেন তোমার প্রভু তাকে প্রেরণা দিয়েছেন।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxliv{সেইদিন মানুষেরা দলে-দলে বেরিয়ে পড়বে যেন তাদের দেখানো যেতে পারে তাদের ক্রিয়াকলাপ।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxlv{তখন যে কেউ এক অণু-পরিমাণ সৎকাজ করেছে সে তা দেখতে পাবে;\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxlvi{আর যে কেউ এক অণু-পরিমাণ মন্দকাজ করেছে সেও তা দেখতে পাবে।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxlvii{\basmalahbn ভাবো ঊর্ধ্বশ্বাসে ধাবমানদের কথা,\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxlviii{ফলে যারা আগুনের ফুলকি ছোড়ে আঘাতের ছোটে,\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxlix{আর যারা ভোরে অভিযান চালায়,\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmmcl{আর তার ফলে যারা ধূলো উড়ায় --\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmmcli{তখন এর ফলে সৈন্যদলকে ভেদ করে যায়।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmmclii{মানুষ নিশ্চয়ই তার প্রভুর প্রতি বড় অকৃতজ্ঞ,\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmmcliii{আর সে আলবৎ এ বিষয়ে অবশ্য প্রত্যক্ষদশ।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmmcliv{আর নিঃসন্দেহ সে ধনসম্পদের মোহে দুরন্ত।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmmclv{তবে কি সে জানে না যখন কবরগুলোয় যা আছে তা তোলা হবে,\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmmclvi{এবং অন্তরে যা আছে তা প্রকাশ করা হবে?\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmmclvii{নিঃসন্দেহ তাদের প্রভু সেইদিন তাদের সন্বন্ধে সবিশেষে অবহিত থাকবেন।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmmclviii{\basmalahbn মহাসংকট!\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmmclix{কী সে মহাসংকট?\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmmclx{হায়, কিভাবে তোমাকে বোঝানো যাবে সেই মহাসংকট কি?\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxi{সেইদিন মানুষরা হবে বিক্ষিপ্ত পঙ্গপালের মতো,\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxii{আর পাহাড়গুলো হয়ে যাবে ধোনা পশমের মতো।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxiii{সুতরাং তার ক্ষেত্রে যার পাল্লা ভারী হবে, --\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxiv{সে তো তখন হবে সন্তোষজনক জীবনযাপনে।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxv{কিন্ত তার ক্ষেত্রে যার পাল্লা হবে হাল্কা --\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxvi{তার মাতা হবে হাবিয়াহ্‌।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxvii{হায়, কি করে তোমাকে বোঝানো যাবে কী সেই!\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxviii{জ্বলন্ত আগুন।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxix{\basmalahbn প্রাচুর্যের প্রতিযোগিতা তোমাদের মতিভ্রম ঘটায়, --\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxx{যতক্ষণ না তোমরা কবরে আসো।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxxi{না! শীঘ্রই তোমরা জানতে পারবে!\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxxii{আবার বলি, -- না, শীঘ্রই তোমরা জানতে পারবে!\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxxiii{না, যদি তোমরা জানতে নিশ্চিত জ্ঞানে!\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxxiv{তোমরা তো ভয়ংকর আগুন দেখবেই।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxxv{আবার বলি, তোমরা অবশ্যই এটি দেখবে নিশ্চিত দৃষ্টিতে।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxxvi{এরপর সেইদিন তোমাদের অবশ্যই জিজ্ঞাসা করা হবে অবদান সম্পর্কে।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxxvii{\basmalahbn ভাবো বিকালবেলার কথা।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxxviii{নিঃসন্দেহ মানুষ আলবৎ লোকসানে পড়েছে, --\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxxix{তারা ব্যতীত যারা ঈমান এনেছে ও সৎকাজ করছে, আর পরস্পরকে সত্য অবলন্বনের জন্য মন্ত্রণা দিচ্ছে, এবং পরস্পরকে অধ্যবসায় অবলন্বনের পরামর্শ দিচ্ছে।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxxx{\basmalahbn ধিক্ প্রত্যেক নিন্দাকারী কুৎসারটনাকারীর প্রতি,\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxxxi{যে ধনসম্পদ জমা করছে এবং তা গুনছে,\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxxxii{সে ভাবছে যে তার ধনসম্পত্তি তাকে অমর করবে।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxxxiii{কখনো না! তাকে অবশ্যই নিক্ষেপ করা হবে সর্বনাশা দুর্ঘটনায়।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxxxiv{আর কিসে তোমাকে বোঝানো যাবে সেই হুতামাহ্ কি?\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxxxv{তা আল্লাহ্‌র হুতাশন, প্রজ্জ্বলিত রয়েছে --\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxxxvi{যা উদিত হয়েছে হৃদয়ের উপরে।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxxxvii{নিঃসন্দেহ এটি হচ্ছে তাদের চারপাশে এক বেড়া --\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxxxviii{সারিসারি খুটিরঁ ভেতরে।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxxxix{\basmalahbn তুমি কি দেখো নি তোমার প্রভু কেমন করেছিলেন হস্তি-বাহিনীর প্রতি?\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxc{তাদের চক্রান্ত তিনি কি ব্যর্থতায় পর্যবসিত করেন নি?\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxci{আর তাদের উপরে তিনি পাঠালেন ঝাঁকে ঝাঁকে পাখীর দল,\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxcii{যারা তাদের আছড়ে ছিল শক্ত-কঠিন পাথরের গায়ে;\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxciii{ফলে তিনি তাদের বানিয়ে দিলেন খেয়ে ফেলা খড়ের মতো।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxciv{\basmalahbn কুরাইশদের নিরাপত্তার জন্য, --\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxcv{শীতকালীন ও গ্রীকালীন বিদেশযাত্রায় তাদের নিরাপত্তার জন্য।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxcvi{অতএব তারা এই গৃহের প্রভুর উপাসনা করুক;\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxcvii{যিনি ক্ষুধায় তাদের আহার দিয়েছেন, আর ভয়-ভীতি থেকে তাদের নিরাপদ রেখেছেন।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxcviii{\basmalahbn তুমি কি তাকে দেখেছ যে ধর্মকর্মকে প্রত্যাখান করে?\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxcix{সে তো ঐ জন যে এতীমদের হাঁকিয়ে দেয়,\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmmcc{আর গরীব-দুঃখীকে খাওয়ানোর ক্ষেত্রে উৎসাহ দেখায় না।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmmcci{অতএব ধিক্ সেইসব নামায-পড়ুয়াদের প্রতি --\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmmccii{যারা স্বয়ং তাদের নামায সন্বন্ধে উদাসীন,\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmmcciii{যারা নিজেরাই হচ্ছে লোক-দেখিয়ে,\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmmcciv{আর যারা নিষেধ করে সাহায্য-সহায়তাকরণ।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmmccv{\basmalahbn নিঃসন্দেহ আমরা তোমাকে প্রাচুর্য দিয়েছি।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmmccvi{সুতরাং তোমার প্রভুর উদ্দেশ্যে নামায আদায় করো এবং কুরবানি করো।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmmccvii{তোমার বিদ্বেষকারীই তো স্বয়ং বঞ্চিত।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmmccviii{\basmalahbn বলো -- ''ওহে অবিশ্বাসিগোষ্ঠী!\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmmccix{''আমি তাকে উপাসনা করি না যাকে তোমরা উপাসনা কর,\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmmccx{''আর তোমরাও তাঁর উপাসনাকারী নও যাঁকে আমি উপাসনা করি।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmmccxi{''আর আমিও তার উপাসনাকারী নই যাকে তোমরা উপাসনা কর।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmmccxii{''আর তোমরাও তাঁর উপাসনাকারী নও যাঁকে আমি উপাসনা করি।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmmccxiii{''তোমাদের জন্য তোমাদের ধর্মমত এবং আমার জন্য আমার ধর্মমত।’’\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmmccxiv{\basmalahbn যখন আল্লাহ্‌র সাহায্য ও বিজয় আসছে,\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmmccxv{আর লোকেদের দলে-দলে আল্লাহ্‌র ধর্মে প্রবেশ করতে দেখতে পাচ্ছ,\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmmccxvi{তখন তোমার প্রভুর প্রশংসায় জপতপ করো ও তাঁর পরিত্রাণ খোঁজো। নিঃসন্দেহ তিনি বারবার প্রত্যাবর্তনকারী।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmmccxvii{\basmalahbn ধ্বংস হোক আবু লহবের উভয় হাত, আর সে-ও ধ্বংস হোক!\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmmccxviii{তার ধন-সম্পদ ও যা সে অর্জন করেছে তা তার কোনো কাজে আসবে না।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmmccxix{তাকে অচিরেই ঠেলে দেওয়া হবে লেলিহান আগুনে --\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmmccxx{আর তার স্ত্রীকেও, -- ইন্ধন বহনকারিণী --\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmmccxxi{তার গলায় থাকবে কড়াপাকের খেজুরের আঁশের রশি।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmmccxxii{\basmalahbn তুমি বলো -- ''তিনি আল্লাহ্‌, একক-অদ্বিতীয়;\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmmccxxiii{''আল্লাহ্ -- পরম নির্ভরস্থল।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmmccxxiv{''তিনি জন্ম দেন না, এবং জন্ম নেনও নি,\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmmccxxv{''এবং কেউই তাঁর সমতুল্য হতে পারে না।’’\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmmccxxvi{\basmalahbn তুমি বলো -- ''আমি আশ্রয় চাইছি নিশিভোরের প্রভুর কাছে, --\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmmccxxvii{''তিনি যা সৃষ্টি করেছেন তার অনিষ্ট থেকে,\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmmccxxviii{''আর অন্ধকারের অনিষ্ট থেকে যখন তা আচ্ছন্ন করে ফেলে,\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmmccxxix{''আর গাঁথনিতে ফুৎকারিণীদের অনিষ্ট থেকে,\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmmccxxx{''আর হিংসাকারীর অনিষ্ট থেকে যখন সে হিংসা করে।’’\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmmccxxxi{\basmalahbn তুমি বলে যাও -- ''আমি আশ্রয় চাইছি মানুষের প্রভুর কাছে, --\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmmccxxxii{''মানুষের মালিকের, --\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmmccxxxiii{''মানুষের উপাস্যের,\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmmccxxxiv{''গোপনে আনাগোনাকারীর কুমন্ত্রণার অনিষ্ট থেকে, --\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmmccxxxv{''যে মানুষের বুকের ভেতরে কুমন্ত্রণা দেয়,\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmmccxxxvi{''জিনের অথবা মানুষের মধ্যে থেকে।’’\qt@no{(6)}}
%% End of file `qurantext-bni.translation.def'.
