\qt@newcmd\qurantrans@bn@i{শুরু করছি আল্লাহর নামে যিনি পরম করুণাময়, অতি দয়ালু।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@ii{যাবতীয় প্রশংসা আল্লাহ তাআলার যিনি সকল সৃষ্টি জগতের পালনকর্তা।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@iii{যিনি নিতান্ত মেহেরবান ও দয়ালু।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@iv{যিনি বিচার দিনের মালিক।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@v{আমরা একমাত্র তোমারই ইবাদত করি এবং শুধুমাত্র তোমারই সাহায্য প্রার্থনা করি।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@vi{আমাদেরকে সরল পথ দেখাও,\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@vii{সে সমস্ত লোকের পথ, যাদেরকে তুমি নেয়ামত দান করেছ। তাদের পথ নয়, যাদের প্রতি তোমার গজব নাযিল হয়েছে এবং যারা পথভ্রষ্ট হয়েছে।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@viii{\basmalahbn আলিফ লাম মীম।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@ix{এ সেই কিতাব যাতে কোনই সন্দেহ নেই। পথ প্রদর্শনকারী পরহেযগারদের জন্য,\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@x{যারা অদেখা বিষয়ের উপর বিশ্বাস স্থাপন করে এবং নামায প্রতিষ্ঠা করে। আর আমি তাদেরকে যে রুযী দান করেছি তা থেকে ব্যয় করে\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@xi{এবং যারা বিশ্বাস স্থাপন করেছে সেসব বিষয়ের উপর যা কিছু তোমার প্রতি অবতীর্ণ হয়েছে এবং সেসব বিষয়ের উপর যা তোমার পূর্ববর্তীদের প্রতি অবতীর্ণ হয়েছে। আর আখেরাতকে যারা নিশ্চিত বলে বিশ্বাস করে।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@xii{তারাই নিজেদের পালনকর্তার পক্ষ থেকে সুপথ প্রাপ্ত, আর তারাই যথার্থ সফলকাম।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@xiii{নিশ্চিতই যারা কাফের হয়েছে তাদেরকে আপনি ভয় প্রদর্শন করুন আর নাই করুন তাতে কিছুই আসে যায় না, তারা ঈমান আনবে না।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@xiv{আল্লাহ তাদের অন্তকরণ এবং তাদের কানসমূহ বন্ধ করে দিয়েছেন, আর তাদের চোখসমূহ পর্দায় ঢেকে দিয়েছেন। আর তাদের জন্য রয়েছে কঠোর শাস্তি।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@xv{আর মানুষের মধ্যে কিছু লোক এমন রয়েছে যারা বলে, আমরা আল্লাহ ও পরকালের প্রতি ঈমান এনেছি অথচ আদৌ তারা ঈমানদার নয়।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@xvi{তারা আল্লাহ এবং ঈমানদারগণকে ধোঁকা দেয়। অথচ এতে তারা নিজেদেরকে ছাড়া অন্য কাউকে ধোঁকা দেয় না অথচ তারা তা অনুভব করতে পারে না।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@xvii{তাদের অন্তঃকরণ ব্যধিগ্রস্ত আর আল্লাহ তাদের ব্যধি আরো বাড়িয়ে দিয়েছেন। বস্তুতঃ তাদের জন্য নির্ধারিত রয়েছে ভয়াবহ আযাব, তাদের মিথ্যাচারের দরুন।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@xviii{আর যখন তাদেরকে বলা হয় যে, দুনিয়ার বুকে দাঙ্গা-হাঙ্গামা সৃষ্টি করো না, তখন তারা বলে, আমরা তো মীমাংসার পথ অবলম্বন করেছি।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@xix{মনে রেখো, তারাই হাঙ্গামা সৃষ্টিকারী, কিন্তু তারা তা উপলব্ধি করে না।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@xx{আর যখন তাদেরকে বলা হয়, অন্যান্যরা যেভাবে ঈমান এনেছে তোমরাও সেভাবে ঈমান আন, তখন তারা বলে, আমরাও কি ঈমান আনব বোকাদেরই মত! মনে রেখো, প্রকৃতপক্ষে তারাই বোকা, কিন্তু তারা তা বোঝে না।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@xxi{আর তারা যখন ঈমানদারদের সাথে মিশে, তখন বলে, আমরা ঈমান এনেছি। আবার যখন তাদের শয়তানদের সাথে একান্তে সাক্ষাৎ করে, তখন বলে, আমরা তোমাদের সাথে রয়েছি। আমরা তো (মুসলমানদের সাথে) উপহাস করি মাত্রা।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@xxii{বরং আল্লাহই তাদের সাথে উপহাস করেন। আর তাদেরকে তিনি ছেড়ে দিয়েছেন যেন তারা নিজেদের অহংকার ও কুমতলবে হয়রান ও পেরেশান থাকে।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@xxiii{তারা সে সমস্ত লোক, যারা হেদায়েতের বিনিময়ে গোমরাহী খরিদ করে। বস্তুতঃ তারা তাদের এ ব্যবসায় লাভবান হতে পারেনি এবং তারা হেদায়েতও লাভ করতে পারেনি।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@xxiv{তাদের অবস্থা সে ব্যক্তির মত, যে লোক কোথাও আগুন জ্বালালো এবং তার চারদিককার সবকিছুকে যখন আগুন স্পষ্ট করে তুললো, ঠিক এমনি সময় আল্লাহ তার চারদিকের আলোকে উঠিয়ে নিলেন এবং তাদেরকে অন্ধকারে ছেড়ে দিলেন। ফলে, তারা কিছুই দেখতে পায় না।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@xxv{তারা বধির, মূক ও অন্ধ। সুতরাং তারা ফিরে আসবে না।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@xxvi{আর তাদের উদাহরণ সেসব লোকের মত যারা দুর্যোগপূর্ণ ঝড়ো রাতে পথ চলে, যাতে থাকে আঁধার, গর্জন ও বিদ্যুৎচমক। মৃত্যুর ভয়ে গর্জনের সময় কানে আঙ্গুল দিয়ে রক্ষা পেতে চায়। অথচ সমস্ত কাফেরই আল্লাহ কর্তৃক পরিবেষ্ঠিত।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@xxvii{বিদ্যুতালোকে যখন সামান্য আলোকিত হয়, তখন কিছুটা পথ চলে। আবার যখন অন্ধকার হয়ে যায়, তখন ঠাঁয় দাঁড়িয়ে থাকে। যদি আল্লাহ ইচ্ছা করেন, তাহলে তাদের শ্রবণশক্তি ও দৃষ্টিশক্তি ছিনিয়ে নিতে পারেন। আল্লাহ যাবতীয় বিষয়ের উপর সর্বময় ক্ষমতাশীল।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@xxviii{হে মানব সমাজ! তোমরা তোমাদের পালনকর্তার এবাদত কর, যিনি তোমাদিগকে এবং তোমাদের পূর্ববর্তীদিগকে সৃষ্টি করেছেন। তাতে আশা করা যায়, তোমরা পরহেযগারী অর্জন করতে পারবে।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@xxix{যে পবিত্রসত্তা তোমাদের জন্য ভূমিকে বিছানা এবং আকাশকে ছাদ স্বরূপ স্থাপন করে দিয়েছেন, আর আকাশ থেকে পানি বর্ষণ করে তোমাদের জন্য ফল-ফসল উৎপাদন করেছেন তোমাদের খাদ্য হিসাবে। অতএব, আল্লাহর সাথে তোমরা অন্য কাকেও সমকক্ষ করো না। বস্তুতঃ এসব তোমরা জান।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@xxx{এতদসম্পর্কে যদি তোমাদের কোন সন্দেহ থাকে যা আমি আমার বান্দার প্রতি অবতীর্ণ করেছি, তাহলে এর মত একটি সূরা রচনা করে নিয়ে এস। তোমাদের সেসব সাহায্যকারীদেরকে সঙ্গে নাও-এক আল্লাহকে ছাড়া, যদি তোমরা সত্যবাদী হয়ে থাকো।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@xxxi{আর যদি তা না পার-অবশ্য তা তোমরা কখনও পারবে না, তাহলে সে দোযখের আগুন থেকে রক্ষা পাওয়ার চেষ্টা কর, যার জ্বালানী হবে মানুষ ও পাথর। যা প্রস্তুত করা হয়েছে কাফেরদের জন্য।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@xxxii{আর হে নবী (সাঃ), যারা ঈমান এনেছে এবং সৎকাজসমূহ করেছে, আপনি তাদেরকে এমন বেহেশতের সুসংবাদ দিন, যার পাদদেশে নহরসমূহ প্রবাহমান থাকবে। যখনই তারা খাবার হিসেবে কোন ফল প্রাপ্ত হবে, তখনই তারা বলবে, এতো অবিকল সে ফলই যা আমরা ইতিপূর্বেও লাভ করেছিলাম। বস্তুতঃ তাদেরকে একই প্রকৃতির ফল প্রদান করা হবে। এবং সেখানে তাদের জন্য শুদ্ধচারিনী রমণীকূল থাকবে। আর সেখানে তারা অনন্তকাল অবস্থান করবে।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@xxxiii{আল্লাহ পাক নিঃসন্দেহে মশা বা তদুর্ধ্ব বস্তু দ্বারা উপমা পেশ করতে লজ্জাবোধ করেন না। বস্তুতঃ যারা মুমিন তারা নিশ্চিতভাবে বিশ্বাস করে যে, তাদের পালনকর্তা কর্তৃক উপস্থাপিত এ উপমা সম্পূর্ণ নির্ভূল ও সঠিক। আর যারা কাফের তারা বলে, এরূপ উপমা উপস্থাপনে আল্লাহর মতলবই বা কি ছিল। এ দ্বারা আল্লাহ তা’আলা অনেককে বিপথগামী করেন, আবার অনেককে সঠিক পথও প্রদর্শন করেন। তিনি অনুরূপ উপমা দ্বারা অসৎ ব্যক্তিবর্গ ভিন্ন কাকেও বিপথগামী করেন না।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@xxxiv{(বিপথগামী ওরাই) যারা আল্লাহর সঙ্গে অঙ্গীকারাবদ্ধ হওয়ার পর তা ভঙ্গ করে এবং আল্লাহ পাক যা অবিচ্ছিন্ন রাখতে নির্দেশ দিয়েছেন, তা ছিন্ন করে, আর পৃথিবীর বুকে অশান্তি সৃষ্টি করে। ওরা যথার্থই ক্ষতিগ্রস্ত।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@xxxv{কেমন করে তোমরা আল্লাহর ব্যাপারে কুফরী অবলম্বন করছ? অথচ তোমরা ছিলে নিষ্প্রাণ। অতঃপর তিনিই তোমাদেরকে প্রাণ দান করেছেন, আবার মৃত্যু দান করবেন। পুনরায় তোমাদেরকে জীবনদান করবেন। অতঃপর তারই প্রতি প্রত্যাবর্তন করবে।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@xxxvi{তিনিই সে সত্ত্বা যিনি সৃষ্টি করেছেন তোমাদের জন্য যা কিছু জমীনে রয়েছে সে সমস্ত। তারপর তিনি মনোসংযোগ করেছেন আকাশের প্রতি। বস্তুতঃ তিনি তৈরী করেছেন সাত আসমান। আর আল্লাহ সর্ববিষয়ে অবহিত।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@xxxvii{আর তোমার পালনকর্তা যখন ফেরেশতাদিগকে বললেনঃ আমি পৃথিবীতে একজন প্রতিনিধি বানাতে যাচ্ছি, তখন ফেরেশতাগণ বলল, তুমি কি পৃথিবীতে এমন কাউকে সৃষ্টি করবে যে দাঙ্গা-হাঙ্গামার সৃষ্টি করবে এবং রক্তপাত ঘটাবে? অথচ আমরা নিয়ত তোমার গুণকীর্তন করছি এবং তোমার পবিত্র সত্তাকে স্মরণ করছি। তিনি বললেন, নিঃসন্দেহে আমি জানি, যা তোমরা জান না।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@xxxviii{আর আল্লাহ তা’আলা শিখালেন আদমকে সমস্ত বস্তু-সামগ্রীর নাম। তারপর সে সমস্ত বস্তু-সামগ্রীকে ফেরেশতাদের সামনে উপস্থাপন করলেন। অতঃপর বললেন, আমাকে তোমরা এগুলোর নাম বলে দাও, যদি তোমরা সত্য হয়ে থাক।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@xxxix{তারা বলল, তুমি পবিত্র! আমরা কোন কিছুই জানি না, তবে তুমি যা আমাদিগকে শিখিয়েছ (সেগুলো ব্যতীত) নিশ্চয় তুমিই প্রকৃত জ্ঞানসম্পন্ন, হেকমতওয়ালা।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@xl{তিনি বললেন, হে আদম, ফেরেশতাদেরকে বলে দাও এসবের নাম। তারপর যখন তিনি বলে দিলেন সে সবের নাম, তখন তিনি বললেন, আমি কি তোমাদেরকে বলিনি যে, আমি আসমান ও যমীনের যাবতীয় গোপন বিষয় সম্পর্কে খুব ভাল করেই অবগত রয়েছি? এবং সেসব বিষয়ও জানি যা তোমরা প্রকাশ কর, আর যা তোমরা গোপন কর!\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@xli{এবং যখন আমি হযরত আদম (আঃ)-কে সেজদা করার জন্য ফেরেশতাগণকে নির্দেশ দিলাম, তখনই ইবলীস ব্যতীত সবাই সিজদা করলো। সে (নির্দেশ) পালন করতে অস্বীকার করল এবং অহংকার প্রদর্শন করল। ফলে সে কাফেরদের অন্তর্ভূক্ত হয়ে গেল।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@xlii{এবং আমি আদমকে হুকুম করলাম যে, তুমি ও তোমার স্ত্রী জান্নাতে বসবাস করতে থাক এবং ওখানে যা চাও, যেখান থেকে চাও, পরিতৃপ্তিসহ খেতে থাক, কিন্তু এ গাছের নিকটবর্তী হয়ো না। অন্যথায় তোমরা যালিমদের অন্তর্ভূক্ত হয়ে পড়বে।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@xliii{অনন্তর শয়তান তাদের উভয়কে ওখান থেকে পদস্খলিত করেছিল। পরে তারা যে সুখ-স্বাচ্ছন্দ্যে ছিল তা থেকে তাদেরকে বের করে দিল এবং আমি বললাম, তোমরা নেমে যাও। তোমরা পরস্পর একে অপরের শক্র হবে এবং তোমাদেরকে সেখানে কিছুকাল অবস্থান করতে হবে ও লাভ সংগ্রহ করতে হবে।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@xliv{অতঃপর হযরত আদম (আঃ) স্বীয় পালনকর্তার কাছ থেকে কয়েকটি কথা শিখে নিলেন, অতঃপর আল্লাহ পাক তাঁর প্রতি (করুণাভরে) লক্ষ্য করলেন। নিশ্চয়ই তিনি মহা-ক্ষমাশীল ও অসীম দয়ালু।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@xlv{আমি হুকুম করলাম, তোমরা সবাই নীচে নেমে যাও। অতঃপর যদি তোমাদের নিকট আমার পক্ষ থেকে কোন হেদায়েত পৌঁছে, তবে যে ব্যক্তি আমার সে হেদায়েত অনুসারে চলবে, তার উপর না কোন ভয় আসবে, না (কোন কারণে) তারা চিন্তাগ্রস্ত ও সন্তপ্ত হবে।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@xlvi{আর যে লোক তা অস্বীকার করবে এবং আমার নিদর্শনগুলোকে মিথ্যা প্রতিপন্ন করার প্রয়াস পাবে, তারাই হবে জাহান্নামবাসী; অন্তকাল সেখানে থাকবে।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@xlvii{হে বনী-ইসরাঈলগণ, তোমরা স্মরণ কর আমার সে অনুগ্রহ যা আমি তোমাদের প্রতি করেছি এবং তোমরা পূরণ কর আমার সাথে কৃত প্রতিজ্ঞা, তাহলে আমি তোমাদেরকে প্রদত্ত প্রতিশ্রুতি পূরণ করব। আর ভয় কর আমাকেই।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@xlviii{আর তোমরা সে গ্রন্থের প্রতি বিশ্বাস স্থাপন কর, যা আমি অবতীর্ণ করেছি সত্যবক্তা হিসেবে তোমাদের কাছে। বস্তুতঃ তোমরা তার প্রাথমিক অস্বীকারকারী হয়ো না আর আমার আয়াতের অল্প মূল্য দিও না। এবং আমার (আযাব) থেকে বাঁচ।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@xlix{তোমরা সত্যকে মিথ্যার সাথে মিশিয়ে দিও না এবং জানা সত্ত্বে সত্যকে তোমরা গোপন করো না।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@l{আর নামায কায়েম কর, যাকাত দান কর এবং নামাযে অবনত হও তাদের সাথে, যারা অবনত হয়।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@li{তোমরা কি মানুষকে সৎকর্মের নির্দেশ দাও এবং নিজেরা নিজেদেরকে ভূলে যাও, অথচ তোমরা কিতাব পাঠ কর? তবুও কি তোমরা চিন্তা কর না?\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@lii{ধৈর্য্যর সাথে সাহায্য প্রার্থনা কর নামাযের মাধ্যমে। অবশ্য তা যথেষ্ট কঠিন। কিন্তু সে সমস্ত বিনয়ী লোকদের পক্ষেই তা সম্ভব।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@liii{যারা একথা খেয়াল করে যে, তাদেরকে সম্মুখীন হতে হবে স্বীয় পরওয়ারদেগারের এবং তাঁরই দিকে ফিরে যেতে হবে।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@liv{হে বনী-ইসরাঈলগণ! তোমরা স্মরণ কর আমার অনুগ্রহের কথা, যা আমি তোমাদের উপর করেছি এবং (স্মরণ কর) সে বিষয়টি যে, আমি তোমাদেরকে উচ্চমর্যাদা দান করেছি সমগ্র বিশ্বের উপর।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@lv{আর সে দিনের ভয় কর, যখন কেউ কারও সামান্য উপকারে আসবে না এবং তার পক্ষে কোন সুপারিশও কবুল হবে না; কারও কাছ থেকে ক্ষতিপূরণও নেয়া হবে না এবং তারা কোন রকম সাহায্যও পাবে না।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@lvi{আর (স্মরণ কর) সে সময়ের কথা, যখন আমি তোমাদিগকে মুক্তিদান করেছি ফেরআউনের লোকদের কবল থেকে যারা তোমাদিগকে কঠিন শাস্তি দান করত; তোমাদের পুত্রসন্তানদেরকে জবাই করত এবং তোমাদের স্ত্রীদিগকে অব্যাহতি দিত। বস্তুতঃ তাতে পরীক্ষা ছিল তোমাদের পালনকর্তার পক্ষ থেকে, মহা পরীক্ষা।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@lvii{আর যখন আমি তোমাদের জন্য সাগরকে দ্বিখন্ডিত করেছি, অতঃপর তোমাদেরকে বাঁচিয়ে দিয়েছি এবং ডুবিয়ে দিয়েছি ফেরআউনের লোকদিগকে অথচ তোমরা দেখছিলে।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@lviii{আর যখন আমি মূসার সাথে ওয়াদা করেছি চল্লিশ রাত্রির অতঃপর তোমরা গোবৎস বানিয়ে নিয়েছ মূসার অনুপস্থিতিতে। বস্তুতঃ তোমরা ছিলে যালেম।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@lix{তারপর আমি তাতেও তোমাদেরকে ক্ষমা করে দিয়েছি, যাতে তোমরা কৃতজ্ঞতা স্বীকার করে নাও।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@lx{আর (স্মরণ কর) যখন আমি মূসাকে কিতাব এবং সত্য-মিথ্যার পার্থক্য বিধানকারী নির্দেশ দান করেছি, যাতে তোমরা সরল পথ প্রাপ্ত হতে পার।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@lxi{আর যখন মূসা তার সম্প্রদায়কে বলল, হে আমার সম্প্রদায়, তোমরা তোমাদেরই ক্ষতিসাধন করেছ এই গোবৎস নির্মাণ করে। কাজেই এখন তওবা কর স্বীয় স্রষ্টার প্রতি এবং নিজ নিজ প্রাণ বিসর্জন দাও। এটাই তোমাদের জন্য কল্যাণকর তোমাদের স্রষ্টার নিকট। তারপর তোমাদের প্রতি লক্ষ্য করা হল। নিঃসন্দেহে তিনিই ক্ষমাকারী, অত্যন্ত মেহেরবান।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@lxii{আর যখন তোমরা বললে, হে মূসা, কস্মিনকালেও আমরা তোমাকে বিশ্বাস করব না, যতক্ষণ না আমরা আল্লাহকে (প্রকাশ্যে) দেখতে পাব। বস্তুতঃ তোমাদিগকে পাকড়াও করল বিদ্যুৎ। অথচ তোমরা তা প্রত্যক্ষ করছিলে।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@lxiii{তারপর, মরে যাবার পর তোমাদিগকে আমি তুলে দাঁড় করিয়েছি, যাতে করে তোমরা কৃতজ্ঞতা স্বীকার করে নাও।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@lxiv{আর আমি তোমাদের উপর ছায়া দান করেছি মেঘমালার দ্বারা এবং তোমাদের জন্য খাবার পাঠিয়েছি ’মান্না’ ও সালওয়া’। সেসব পবিত্র বস্তু তোমরা ভক্ষন কর, যা আমি তোমাদেরকে দান করেছি। বস্তুতঃ তারা আমার কোন ক্ষতি করতে পারেনি, বরং নিজেদেরই ক্ষতি সাধন করেছে।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@lxv{আর যখন আমি বললাম, তোমরা প্রবেশ কর এ নগরীতে এবং এতে যেখানে খুশী খেয়ে স্বাচ্ছন্দ্যে বিচরণ করতে থাক এবং দরজার ভিতর দিয়ে প্রবেশ করার সময় সেজদা করে ঢুক, আর বলতে থাক-‘আমাদিগকে ক্ষমা করে দাও’-তাহলে আমি তোমাদের অপরাধ ক্ষমা করব এবং সৎ কর্মশীলদেরকে অতিরিক্ত দানও করব।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@lxvi{অতঃপর যালেমরা কথা পাল্টে দিয়েছে, যা কিছু তাদেরকে বলে দেয়া হয়েছিল তা থেকে। তারপর আমি অবতীর্ণ করেছি যালেমদের উপর আযাব, আসমান থেকে, নির্দেশ লংঘন করার কারণে।\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@lxvii{আর মূসা যখন নিজ জাতির জন্য পানি চাইল, তখন আমি বললাম, স্বীয় যষ্ঠির দ্বারা আঘাত কর পাথরের উপরে। অতঃপর তা থেকে প্রবাহিত হয়ে এল বারটি প্রস্রবণ। তাদের সব গোত্রই চিনে নিল নিজ নিজ ঘাট। আল্লাহর দেয়া রিযিক খাও, পান কর আর দুনিয়ার বুকে দাংগা-হাংগামা করে বেড়িও না।\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@lxviii{আর তোমরা যখন বললে, হে মূসা, আমরা একই ধরনের খাদ্য-দ্রব্যে কখনও ধৈর্য্যধারণ করব না। কাজেই তুমি তোমার পালনকর্তার নিকট আমাদের পক্ষে প্রার্থনা কর, তিনি যেন আমাদের জন্যে এমন বস্তুসামগ্রী দান করেন যা জমিতে উৎপন্ন হয়, তরকারী, কাকড়ী, গম, মসুরি, পেঁয়াজ প্রভৃতি। মূসা (আঃ) বললেন, তোমরা কি এমন বস্তু নিতে চাও যা নিকৃষ্ট সে বস্তুর পরিবর্তে যা উত্তম? তোমরা কোন নগরীতে উপনীত হও, তাহলেই পাবে যা তোমরা কামনা করছ। আর তাদের উপর আরোপ করা হল লাঞ্ছনা ও পরমুখাপেক্ষিতা। তারা আল্লাহর রোষানলে পতিত হয়ে ঘুরতে থাকল। এমন হলো এ জন্য যে, তারা আল্লাহর বিধি বিধান মানতো না এবং নবীগনকে অন্যায়ভাবে হত্যা করত। তার কারণ, তারা ছিল নাফরমান সীমালংঘকারী।\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@lxix{নিঃসন্দেহে যারা মুসলমান হয়েছে এবং যারা ইহুদী, নাসারা ও সাবেঈন, (তাদের মধ্য থেকে) যারা ঈমান এনেছে আল্লাহর প্রতি ও কিয়ামত দিবসের প্রতি এবং সৎকাজ করেছে, তাদের জন্য রয়েছে তার সওয়াব তাদের পালনকর্তার কাছে। আর তাদের কোনই ভয়-ভীতি নেই, তারা দুঃখিতও হবে না।\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@lxx{আর আমি যখন তোমাদের কাছ থেকে অঙ্গীকার নিয়েছিলাম এবং তুর পর্বতকে তোমাদের মাথার উপর তুলে ধরেছিলাম এই বলে যে, তোমাদিগকে যে কিতাব দেয়া হয়েছে তাকে ধর সুদৃঢ়ভাবে এবং এতে যা কিছু রয়েছে তা মনে রেখো যাতে তোমরা ভয় কর।\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@lxxi{তারপরেও তোমরা তা থেকে ফিরে গেছ। কাজেই আল্লাহর অনুগ্রহ ও মেহেরবানী যদি তোমাদের উপর না থাকত, তবে অবশ্যই তোমরা ধবংস হয়ে যেতে।\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@lxxii{তোমরা তাদেরকে ভালরূপে জেনেছ, যারা শনিবারের ব্যাপারে সীমা লঙ্ঘণ করেছিল। আমি বলেছিলামঃ তোমরা লাঞ্ছিত বানর হয়ে যাও।\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@lxxiii{অতঃপর আমি এ ঘটনাকে তাদের সমসাময়িক ও পরবর্তীদের জন্য দৃষ্টান্ত এবং আল্লাহভীরুদের জন্য উপদেশ গ্রহণের উপাদান করে দিয়েছি।\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@lxxiv{যখন মূসা (আঃ) স্বীয় সম্প্রদায়কে বললেনঃ আল্লাহ তোমাদের একটি গরু জবাই করতে বলেছেন। তারা বলল, তুমি কি আমাদের সাথে উপহাস করছ? মূসা (আঃ) বললেন, মূর্খদের অন্তর্ভুক্ত হওয়া থেকে আমি আল্লাহর আশ্রয় প্রার্থনা করছি।\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@lxxv{তারা বলল, তুমি তোমার পালনকর্তার কাছে আমাদের জন্য প্রার্থনা কর, যেন সেটির রূপ বিশ্লেষণ করা হয়। মূসা (আঃ) বললেন, তিনি বলছেন, সেটা হবে একটা গাভী, যা বৃদ্ধ নয় এবং কুমারীও নয়-বার্ধক্য ও যৌবনের মাঝামাঝি বয়সের। এখন আদিষ্ট কাজ করে ফেল।\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@lxxvi{তারা বলল, তোমার পালনকর্তার কাছে আমাদের জন্য প্রার্থনা কর যে, তার রঙ কিরূপ হবে? মূসা (আঃ) বললেন, তিনি বলেছেন যে, গাঢ় পীতবর্ণের গাভী-যা দর্শকদের চমৎকৃত করবে।\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@lxxvii{তারা বলল, আপনি প্রভুর কাছে প্রার্থনা করুন-তিনি বলে দিন যে, সেটা কিরূপ? কেননা, গরু আমাদের কাছে সাদৃশ্যশীল মনে হয়। ইনশাআল্লাহ এবার আমরা অবশ্যই পথপ্রাপ্ত হব। মূসা (আঃ) বললেন, তিনি বলেন যে, এ গাভী ভূকর্ষণ ও জল সেচনের শ্রমে অভ্যস্ত নয়-হবে নিষ্কলঙ্ক, নিখুঁত।\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@lxxviii{তারা বলল, এবার সঠিক তথ্য এনেছ। অতঃপর তারা সেটা জবাই করল, অথচ জবাই করবে বলে মনে হচ্ছিল না।\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@lxxix{যখন তোমরা একজনকে হত্যা করে পরে সে সম্পর্কে একে অপরকে অভিযুক্ত করেছিলে। যা তোমরা গোপন করছিলে, তা প্রকাশ করে দেয়া ছিল আল্লাহর অভিপ্রায়।\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@lxxx{অতঃপর আমি বললামঃ গরুর একটি খন্ড দ্বারা মৃতকে আঘাত কর। এভাবে আল্লাহ মৃতকে জীবিত করেন এবং তোমাদেরকে তাঁর নিদর্শণ সমূহ প্রদর্শন করেন-যাতে তোমরা চিন্তা কর।\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@lxxxi{অতঃপর এ ঘটনার পরে তোমাদের অন্তর কঠিন হয়ে গেছে। তা পাথরের মত অথবা তদপেক্ষাও কঠিন। পাথরের মধ্যে এমন ও আছে; যা থেকে ঝরণা প্রবাহিত হয়, এমনও আছে, যা বিদীর্ণ হয়, অতঃপর তা থেকে পানি নির্গত হয় এবং এমনও আছে, যা আল্লাহর ভয়ে খসেপড়তে থাকে! আল্লাহ তোমাদের কাজকর্ম সম্পর্কে বে-খবর নন।\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@lxxxii{হে মুসলমানগণ, তোমরা কি আশা কর যে, তারা তোমাদের কথায় ঈমান আনবে? তাদের মধ্যে একদল ছিল, যারা আল্লাহর বাণী শ্রবণ করত; অতঃপর বুঝে-শুনে তা পরিবর্তন করে দিত এবং তারা তা অবগত ছিল।\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@lxxxiii{যখন তারা মুসলমানদের সাথে মিলিত হয়, তখন বলেঃ আমরা মুসলমান হয়েছি। আর যখন পরস্পরের সাথে নিভৃতে অবস্থান করে, তখন বলে, পালনকর্তা তোমাদের জন্যে যা প্রকাশ করেছেন, তা কি তাদের কাছে বলে দিচ্ছ? তাহলে যে তারা এ নিয়ে পালকর্তার সামনে তোমাদেরকে মিথ্যা প্রতিপন্ন করবে। তোমরা কি তা উপলব্ধি কর না?\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@lxxxiv{তারা কি এতটুকুও জানে না যে, আল্লাহ সেসব বিষয়ও পরিজ্ঞাত যা তারা গোপন করে এবং যা প্রকাশ করে?\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@lxxxv{তোমাদের কিছু লোক নিরক্ষর। তারা মিথ্যা আকাঙ্খা ছাড়া আল্লাহর গ্রন্থের কিছুই জানে না। তাদের কাছে কল্পনা ছাড়া কিছুই নেই।\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@lxxxvi{অতএব তাদের জন্যে আফসোস! যারা নিজ হাতে গ্রন্থ লেখে এবং বলে, এটা আল্লাহর পক্ষ থেকে অবতীর্ণ-যাতে এর বিনিময়ে সামান্য অর্থ গ্রহণ করতে পারে। অতএব তাদের প্রতি আক্ষেপ, তাদের হাতের লেখার জন্য এবং তাদের প্রতি আক্ষেপ, তাদের উপার্জনের জন্যে।\qt@no{(79)}}
\qt@newcmd\qurantrans@bn@lxxxvii{তারা বলেঃ আগুন আমাদিগকে কখনও স্পর্শ করবে না; কিন্তু গণাগনতি কয়েকদিন। বলে দিনঃ তোমরা কি আল্লাহর কাছ থেকে কোন অঙ্গীকার পেয়েছ যে, আল্লাহ কখনও তার খেলাফ করবেন না-না তোমরা যা জান না, তা আল্লাহর সাথে জুড়ে দিচ্ছ।\qt@no{(80)}}
\qt@newcmd\qurantrans@bn@lxxxviii{হাঁ, যে ব্যক্তি পাপ অর্জন করেছে এবং সে পাপ তাকে পরিবেষ্টিত করে নিয়েছে, তারাই দোযখের অধিবাসী। তারা সেখানেই চিরকাল থাকবে।\qt@no{(81)}}
\qt@newcmd\qurantrans@bn@lxxxix{পক্ষান্তরে যারা ঈমান এনেছে এবং সৎকাজ করেছে, তারাই জান্নাতের অধিবাসী। তারা সেখানেই চিরকাল থাকবে।\qt@no{(82)}}
\qt@newcmd\qurantrans@bn@xc{যখন আমি বনী-ইসরাঈলের কাছ থেকে অঙ্গীকার নিলাম যে, তোমরা আল্লাহ ছাড়া কারও উপাসনা করবে না, পিতা-মাতা, আত্নীয়-স্বজন, এতীম ও দীন-দরিদ্রদের সাথে সদ্ব্যবহার করবে, মানুষকে সৎ কথাবার্তা বলবে, নামায প্রতিষ্ঠা করবে এবং যাকাত দেবে, তখন সামান্য কয়েকজন ছাড়া তোমরা মুখ ফিরিয়ে নিলে, তোমরাই অগ্রাহ্যকারী।\qt@no{(83)}}
\qt@newcmd\qurantrans@bn@xci{যখন আমি তোমাদের কাছ থেকে অঙ্গীকার নিলাম যে, তোমরা পরস্পর খুনাখুনি করবে না এবং নিজেদেরকে দেশ থেকে বহিস্কার করবে না, তখন তোমরা তা স্বীকার করেছিলে এবং তোমরা তার সাক্ষ্য দিচ্ছিলে।\qt@no{(84)}}
\qt@newcmd\qurantrans@bn@xcii{অতঃপর তোমরাই পরস্পর খুনাখুনি করছ এবং তোমাদেরই একদলকে তাদের দেশ থেকে বহিস্কার করছ। তাদের বিরুদ্ধে পাপ ও অন্যায়ের মাধ্যমে আক্রমণ করছ। আর যদি তারাই কারও বন্দী হয়ে তোমাদের কাছে আসে, তবে বিনিময় নিয়ে তাদের মুক্ত করছ। অথচ তাদের বহিস্কার করাও তোমাদের জন্য অবৈধ। তবে কি তোমরা গ্রন্থের কিয়দংশ বিশ্বাস কর এবং কিয়দংশ অবিশ্বাস কর? যারা এরূপ করে পার্থিব জীবনে দূগর্তি ছাড়া তাদের আর কোনই পথ নেই। কিয়ামতের দিন তাদের কঠোরতম শাস্তির দিকে পৌঁছে দেয়া হবে। আল্লাহ তোমাদের কাজ-কর্ম সম্পর্কে বে-খবর নন।\qt@no{(85)}}
\qt@newcmd\qurantrans@bn@xciii{এরাই পরকালের বিনিময়ে পার্থিব জীবন ক্রয় করেছে। অতএব এদের শাস্তি লঘু হবে না এবং এরা সাহায্যও পাবে না।\qt@no{(86)}}
\qt@newcmd\qurantrans@bn@xciv{অবশ্যই আমি মূসাকে কিতাব দিয়েছি। এবং তার পরে পর্যায়ক্রমে রসূল পাঠিয়েছি। আমি মরিয়ম তনয় ঈসাকে সুস্পষ্ট মোজেযা দান করেছি এবং পবিত্র রূহের মাধ্যমে তাকে শক্তিদান করেছি। অতঃপর যখনই কোন রসূল এমন নির্দেশ নিয়ে তোমাদের কাছে এসেছে, যা তোমাদের মনে ভাল লাগেনি, তখনই তোমরা অহংকার করেছ। শেষ পর্যন্ত তোমরা একদলকে মিথ্যাবাদী বলেছ এবং একদলকে হত্যা করেছ।\qt@no{(87)}}
\qt@newcmd\qurantrans@bn@xcv{তারা বলে, আমাদের হৃদয় অর্ধাবৃত। এবং তাদের কুফরের কারণে আল্লাহ অভিসম্পাত করেছেন। ফলে তারা অল্পই ঈমান আনে।\qt@no{(88)}}
\qt@newcmd\qurantrans@bn@xcvi{যখন তাদের কাছে আল্লাহর পক্ষ থেকে কিতাব এসে পৌঁছাল, যা সে বিষয়ের সত্যায়ন করে, যা তাদের কাছে রয়েছে এবং তারা পূর্বে করত। অবশেষে যখন তাদের কাছে পৌঁছল যাকে তারা চিনে রেখেছিল, তখন তারা তা অস্বীকার করে বসল। অতএব, অস্বীকারকারীদের উপর আল্লাহর অভিসম্পাত।\qt@no{(89)}}
\qt@newcmd\qurantrans@bn@xcvii{যার বিনিময়ে তারা নিজেদের বিক্রি করেছে, তা খুবই মন্দ; যেহেতু তারা আল্লাহ যা নযিল করেছেন, তা অস্বীকার করেছে এই হঠকারিতার দরুন যে, আল্লাহ স্বীয় বান্দাদের মধ্যে যার প্রতি ইচ্ছা অনুগ্রহ নাযিল করেন। অতএব, তারা ক্রোধের উপর ক্রোধ অর্জন করেছে। আর কাফেরদের জন্য রয়েছে অপমানজনক শাস্তি।\qt@no{(90)}}
\qt@newcmd\qurantrans@bn@xcviii{যখন তাদেরকে বলা হয়, আল্লাহ যা পাঠিয়েছেন তা মেনে নাও, তখন তারা বলে, আমরা মানি যা আমাদের প্রতি অবর্তীণ হয়েছে। সেটি ছাড়া সবগুলোকে তারা অস্বীকার করে। অথচ এ গ্রন্থটি সত্য এবং সত্যায়ন করে ঐ গ্রন্থের যা তাদের কাছে রয়েছে। বলে দিন, তবে তোমরা ইতিপূর্বে পয়গম্বরদের হত্যা করতে কেন যদি তোমরা বিশ্বাসী ছিলে?\qt@no{(91)}}
\qt@newcmd\qurantrans@bn@xcix{সুস্পষ্ট মু’জেযাসহ মূসা তোমাদের কাছে এসেছেন। এরপর তার অনুপস্থিতিতে তোমরা গোবৎস বানিয়েছ। বাস্তবিকই তোমরা অত্যাচারী।\qt@no{(92)}}
\qt@newcmd\qurantrans@bn@c{আর যখন আমি তোমাদের কাছ থেকে প্রতিশ্রুতি নিলাম এবং তুর পর্বতকে তোমাদের উপর তুলে ধরলাম যে, শক্ত করে ধর, আমি যা তোমাদের দিয়েছি আর শোন। তারা বলল, আমরা শুনেছি আর অমান্য করেছি। কুফরের কারণে তাদের অন্তরে গোবৎসপ্রীতি পান করানো হয়েছিল। বলে দিন, তোমরা বিশ্বাসী হলে, তোমাদের সে বিশ্বাস মন্দ বিষয়াদি শিক্ষা দেয়।\qt@no{(93)}}
\qt@newcmd\qurantrans@bn@ci{বলে দিন, যদি আখেরাতের বাসস্থান আল্লাহর কাছে একমাত্র তোমাদের জন্যই বরাদ্দ হয়ে থাকে-অন্য লোকদের বাদ দিয়ে, তবে মৃত্যু কামনা কর, যদি সত্যবাদী হয়ে থাক।\qt@no{(94)}}
\qt@newcmd\qurantrans@bn@cii{কস্মিনকালেও তারা মৃত্যু কামনা করবে না ঐসব গোনাহর কারণে, যা তাদের হাত পাঠিয়ে দিয়েছে। আল্লাহ গোনাহগারদের সম্পর্কে সম্যক অবগত রয়েছেন।\qt@no{(95)}}
\qt@newcmd\qurantrans@bn@ciii{আপনি তাদেরকে জীবনের প্রতি সবার চাইতে, এমনকি মুশরিকদের চাইতেও অধিক লোভী দেখবেন। তাদের প্রত্যেকে কামনা করে, যেন হাজার বছর আয়ু পায়। অথচ এরূপ আয়ু প্রাপ্তি তাদেরকে শাস্তি থেকে রক্ষা করতে পারবে না। আল্লাহ দেখেন যা কিছু তারা করে।\qt@no{(96)}}
\qt@newcmd\qurantrans@bn@civ{আপনি বলে দিন, যে কেউ জিবরাঈলের শত্রু হয়-যেহেতু তিনি আল্লাহর আদেশে এ কালাম আপনার অন্তরে নাযিল করেছেন, যা সত্যায়নকারী তাদের সম্মুখস্থ কালামের এবং মুমিনদের জন্য পথপ্রদর্শক ও সুসংবাদদাতা।\qt@no{(97)}}
\qt@newcmd\qurantrans@bn@cv{যে ব্যক্তি আল্লাহ তাঁর ফেরেশতা ও রসূলগণ এবং জিবরাঈল ও মিকাঈলের শত্রু হয়, নিশ্চিতই আল্লাহ সেসব কাফেরের শত্রু।\qt@no{(98)}}
\qt@newcmd\qurantrans@bn@cvi{আমি আপনার প্রতি উজ্জ্বল নিদর্শনসমূহ অবতীর্ণ করেছি। অবাধ্যরা ব্যতীত কেউ এগুলো অস্বীকার করে না।\qt@no{(99)}}
\qt@newcmd\qurantrans@bn@cvii{কি আশ্চর্য, যখন তারা কোন অঙ্গীকারে আবদ্ধ হয়, তখন তাদের একদল তা ছুঁড়ে ফেলে, বরং অধিকাংশই বিশ্বাস করে না।\qt@no{(100)}}
\qt@newcmd\qurantrans@bn@cviii{যখন তাদের কাছে আল্লাহর পক্ষ থেকে একজন রসূল আগমন করলেন-যিনি ঐ কিতাবের সত্যায়ন করেন, যা তাদের কাছে রয়েছে, তখন আহলে কেতাবদের একদল আল্লাহর গ্রন্থকে পশ্চাতে নিক্ষেপ করল-যেন তারা জানেই না।\qt@no{(101)}}
\qt@newcmd\qurantrans@bn@cix{তারা ঐ শাস্ত্রের অনুসরণ করল, যা সুলায়মানের রাজত্ব কালে শয়তানরা আবৃত্তি করত। সুলায়মান কুফর করেনি; শয়তানরাই কুফর করেছিল। তারা মানুষকে জাদুবিদ্যা এবং বাবেল শহরে হারুত ও মারুত দুই ফেরেশতার প্রতি যা অবতীর্ণ হয়েছিল, তা শিক্ষা দিত। তারা উভয়ই একথা না বলে কাউকে শিক্ষা দিত না যে, আমরা পরীক্ষার জন্য; কাজেই তুমি কাফের হয়ো না। অতঃপর তারা তাদের কাছ থেকে এমন জাদু শিখত, যদ্দ্বারা স্বামী ও স্ত্রীর মধ্যে বিচ্ছেদ ঘটে। তারা আল্লাহর আদেশ ছাড়া তদ্দ্বারা কারও অনিষ্ট করতে পারত না। যা তাদের ক্ষতি করে এবং উপকার না করে, তারা তাই শিখে। তারা ভালরূপে জানে যে, যে কেউ জাদু অবলম্বন করে, তার জন্য পরকালে কোন অংশ নেই। যার বিনিময়ে তারা আত্নবিক্রয় করেছে, তা খুবই মন্দ যদি তারা জানত।\qt@no{(102)}}
\qt@newcmd\qurantrans@bn@cx{যদি তারা ঈমান আনত এবং খোদাভীরু হত, তবে আল্লাহর কাছ থেকে উত্তম প্রতিদান পেত। যদি তারা জানত।\qt@no{(103)}}
\qt@newcmd\qurantrans@bn@cxi{হে মুমিন গণ, তোমরা ‘রায়িনা’ বলো না-‘উনযুরনা’ বল এবং শুনতে থাক। আর কাফেরদের জন্যে রয়েছে বেদনাদায়ক শাস্তি।\qt@no{(104)}}
\qt@newcmd\qurantrans@bn@cxii{আহলে-কিতাব ও মুশরিকদের মধ্যে যারা কাফের, তাদের মনঃপুত নয় যে, তোমাদের পালনকর্তার পক্ষ থেকে তোমাদের প্রতি কোন কল্যাণ অবতীর্ণ হোক। আল্লাহ যাকে ইচ্ছা বিশেষ ভাবে স্বীয় অনুগ্রহ দান করেন। আল্লাহ মহান অনুগ্রহদাতা।\qt@no{(105)}}
\qt@newcmd\qurantrans@bn@cxiii{আমি কোন আয়াত রহিত করলে অথবা বিস্মৃত করিয়ে দিলে তদপেক্ষা উত্তম অথবা তার সমপর্যায়ের আয়াত আনয়ন করি। তুমি কি জান না যে, আল্লাহ সব কিছুর উপর শক্তিমান?\qt@no{(106)}}
\qt@newcmd\qurantrans@bn@cxiv{তুমি কি জান না যে, আল্লাহর জন্যই নভোমন্ডল ও ভূমন্ডলের আধিপত্য? আল্লাহ ব্যতীত তোমাদের কোন বন্ধু ও সাহায্যকারী নেই।\qt@no{(107)}}
\qt@newcmd\qurantrans@bn@cxv{ইতিপূর্বে মূসা (আঃ) যেমন জিজ্ঞাসিত হয়েছিলেন, (মুসলমানগন, ) তোমরাও কি তোমাদের রসূলকে তেমনি প্রশ্ন করতে চাও? যে কেউ ঈমানের পরিবর্তে কুফর গ্রহন করে, সে সরল পথ থেকে বিচ্যুত হয়ে যায়।\qt@no{(108)}}
\qt@newcmd\qurantrans@bn@cxvi{আহলে কিতাবদের অনেকেই প্রতিহিংসাবশতঃ চায় যে, মুসলমান হওয়ার পর তোমাদেরকে কোন রকমে কাফের বানিয়ে দেয়। তাদের কাছে সত্য প্রকাশিত হওয়ার পর (তারা এটা চায়)। যাক তোমরা আল্লাহর নির্দেশ আসা পর্যন্ত তাদের ক্ষমা কর এবং উপেক্ষা কর। নিশ্চয় আল্লাহ সব কিছুর উপর ক্ষমতাবান।\qt@no{(109)}}
\qt@newcmd\qurantrans@bn@cxvii{তোমরা নামায প্রতিষ্ঠা কর এবং যাকাত দাও। তোমরা নিজের জন্যে পূর্বে যে সৎকর্ম প্রেরণ করবে, তা আল্লাহর কাছে পাবে। তোমরা যা কিছু কর, নিশ্চয় আল্লাহ তা প্রত্যক্ষ করেন।\qt@no{(110)}}
\qt@newcmd\qurantrans@bn@cxviii{ওরা বলে, ইহুদী অথবা খ্রীস্টান ব্যতীত কেউ জান্নাতে যাবে না। এটা ওদের মনের বাসনা। বলে দিন, তোমরা সত্যবাদী হলে, প্রমাণ উপস্থিত কর।\qt@no{(111)}}
\qt@newcmd\qurantrans@bn@cxix{হাঁ, যে ব্যক্তি নিজেকে আল্লাহর উদ্দেশ্যে সমর্পন করেছে এবং সে সৎকর্মশীলও বটে তার জন্য তার পালনকর্তার কাছে পুরস্কার বয়েছে। তাদের ভয় নেই এবং তারা চিন্তিতও হবে না।\qt@no{(112)}}
\qt@newcmd\qurantrans@bn@cxx{ইহুদীরা বলে, খ্রীস্টানরা কোন ভিত্তির উপরেই নয় এবং খ্রীস্টানরা বলে, ইহুদীরা কোন ভিত্তির উপরেই নয়। অথচ ওরা সবাই কিতাব পাঠ করে! এমনিভাবে যারা মূর্খ, তারাও ওদের মতই উক্তি করে। অতএব, আল্লাহ কেয়ামতের দিন তাদের মধ্যে ফয়সালা দেবেন, যে বিষয়ে তারা মতবিরোধ করছিল।\qt@no{(113)}}
\qt@newcmd\qurantrans@bn@cxxi{যে ব্যাক্তি আল্লাহর মসজিদসমূহে তাঁর নাম উচ্চারণ করতে বাধা দেয় এবং সেগুলোকে উজাড় করতে চেষ্টা করে, তার চাইতে বড় যালেম আর কে? এদের পক্ষে মসজিদসমূহে প্রবেশ করা বিধেয় নয়, অবশ্য ভীত-সন্ত্রস্ত অবস্থায়। ওদের জন্য ইহকালে লাঞ্ছনা এবং পরকালে কঠিন শাস্তি রয়েছে।\qt@no{(114)}}
\qt@newcmd\qurantrans@bn@cxxii{পূর্ব ও পশ্চিম আল্লারই। অতএব, তোমরা যেদিকেই মুখ ফেরাও, সেদিকেই আল্লাহ বিরাজমান। নিশ্চয় আল্লাহ সর্বব্যাপী, সর্বজ্ঞ।\qt@no{(115)}}
\qt@newcmd\qurantrans@bn@cxxiii{তারা বলে, আল্লাহ সন্তান গ্রহণ করেছেন। তিনি তো এসব কিছু থেকে পবিত্র, বরং নভোমন্ডল ও ভূমন্ডলে যা কিছু রয়েছে সবই তার আজ্ঞাধীন।\qt@no{(116)}}
\qt@newcmd\qurantrans@bn@cxxiv{তিনি নভোমন্ডল ও ভূমন্ডলের উদ্ভাবক। যখন তিনি কোন কার্য সম্পাদনের সিন্ধান্ত নেন, তখন সেটিকে একথাই বলেন, ‘হয়ে যাও’ তৎক্ষণাৎ তা হয়ে যায়।\qt@no{(117)}}
\qt@newcmd\qurantrans@bn@cxxv{যারা কিছু জানে না, তারা বলে, আল্লাহ আমাদের সঙ্গে কেন কথা বলেন না? অথবা আমাদের কাছে কোন নিদর্শন কেন আসে না? এমনি ভাবে তাদের পূর্বে যারা ছিল তারাও তাদেরই অনুরূপ কথা বলেছে। তাদের অন্তর একই রকম। নিশ্চয় আমি উজ্জ্বল নিদর্শনসমূহ বর্ণনা করেছি তাদের জন্যে যারা প্রত্যয়শীল।\qt@no{(118)}}
\qt@newcmd\qurantrans@bn@cxxvi{নিশ্চয় আমি আপনাকে সত্যধর্মসহ সুসংবাদদাতা ও ভীতি প্রদর্শনকারীরূপে পাঠিয়েছি। আপনি দোযখবাসীদের সম্পর্কে জিজ্ঞাসিত হবেন না।\qt@no{(119)}}
\qt@newcmd\qurantrans@bn@cxxvii{ইহুদী ও খ্রীষ্টানরা কখনই আপনার প্রতি সন্তুষ্ট হবে না, যে পর্যন্ত না আপনি তাদের ধর্মের অনুসরণ করেন। বলে দিন, যে পথ আল্লাহ প্রদর্শন করেন, তাই হল সরল পথ। যদি আপনি তাদের আকাঙ্খাসমূহের অনুসরণ করেন, ঐ জ্ঞান লাভের পর, যা আপনার কাছে পৌঁছেছে, তবে কেউ আল্লাহর কবল থেকে আপনার উদ্ধারকারী ও সাহায্যকারী নেই।\qt@no{(120)}}
\qt@newcmd\qurantrans@bn@cxxviii{আমি যাদেরকে গ্রন্থ দান করেছি, তারা তা যথাযথভাবে পাঠ করে। তারাই তৎপ্রতি বিশ্বাস করে। আর যারা তা অবিশ্বাস করে, তারাই হবে ক্ষতিগ্রস্ত।\qt@no{(121)}}
\qt@newcmd\qurantrans@bn@cxxix{হে বনী-ইসরাঈল! আমার অনুগ্রহের কথা স্মরণ কর, যা আমি তোমাদের দিয়েছি। আমি তোমাদেরকে বিশ্বাবাসীর উপর শ্রেষ্ঠত্ব দান করেছি।\qt@no{(122)}}
\qt@newcmd\qurantrans@bn@cxxx{তোমরা ভয় কর সেদিনকে, যে দিন এক ব্যক্তি থেকে অন্য ব্যক্তি বিন্দুমাত্র উপকৃত হবে না, কারও কাছ থেকে বিনিময় গৃহীত হবে না, কার ও সুপারিশ ফলপ্রদ হবে না এবং তারা সাহায্য প্রাপ্ত ও হবে না।\qt@no{(123)}}
\qt@newcmd\qurantrans@bn@cxxxi{যখন ইব্রাহীমকে তাঁর পালনকর্তা কয়েকটি বিষয়ে পরীক্ষা করলেন, অতঃপর তিনি তা পূর্ণ করে দিলেন, তখন পালনকর্তা বললেন, আমি তোমাকে মানবজাতির নেতা করব। তিনি বললেন, আমার বংশধর থেকেও! তিনি বললেন আমার অঙ্গীকার অত্যাচারীদের পর্যন্ত পৌঁছাবে না।\qt@no{(124)}}
\qt@newcmd\qurantrans@bn@cxxxii{যখন আমি কা’বা গৃহকে মানুষের জন্যে সম্মিলন স্থল ও শান্তির আলয় করলাম, আর তোমরা ইব্রাহীমের দাঁড়ানোর জায়গাকে নামাযের জায়গা বানাও এবং আমি ইব্রাহীম ও ইসমাঈলকে আদেশ করলাম, তোমরা আমার গৃহকে তওয়াফকারী, অবস্থানকারী ও রুকু-সেজদাকারীদের জন্য পবিত্র রাখ।\qt@no{(125)}}
\qt@newcmd\qurantrans@bn@cxxxiii{যখন ইব্রাহীম বললেন, পরওয়ারদেগার! এ স্থানকে তুমি শান্তিধান কর এবং এর অধিবাসীদের মধ্যে যারা অল্লাহ ও কিয়ামতে বিশ্বাস করে, তাদেরকে ফলের দ্বারা রিযিক দান কর। বললেনঃ যারা অবিশ্বাস করে, আমি তাদেরও কিছুদিন ফায়দা ভোগ করার সুযোগ দেব, অতঃপর তাদেরকে বলপ্রয়োগে দোযখের আযাবে ঠেলে দেবো; সেটা নিকৃষ্ট বাসস্থান।\qt@no{(126)}}
\qt@newcmd\qurantrans@bn@cxxxiv{স্মরণ কর, যখন ইব্রাহীম ও ইসমাঈল কা’বাগৃহের ভিত্তি স্থাপন করছিল। তারা দোয়া করেছিলঃ পরওয়ারদেগার! আমাদের থেকে কবুল কর। নিশ্চয়ই তুমি শ্রবণকারী, সর্বজ্ঞ।\qt@no{(127)}}
\qt@newcmd\qurantrans@bn@cxxxv{পরওয়ারদেগার! আমাদের উভয়কে তোমার আজ্ঞাবহ কর এবং আমাদের বংশধর থেকেও একটি অনুগত দল সৃষ্টি কর, আমাদের হজ্বের রীতিনীতি বলে দাও এবং আমাদের ক্ষমা কর। নিশ্চয় তুমি তওবা কবুলকারী। দয়ালু।\qt@no{(128)}}
\qt@newcmd\qurantrans@bn@cxxxvi{হে পরওয়ারদেগার! তাদের মধ্যে থেকেই তাদের নিকট একজন পয়গম্বর প্রেরণ করুণ যিনি তাদের কাছে তোমার আয়াতসমূহ তেলাওয়াত করবেন, তাদেরকে কিতাব ও হেকমত শিক্ষা দিবেন। এবং তাদের পবিত্র করবেন। নিশ্চয় তুমিই পরাক্রমশালী হেকমতওয়ালা।\qt@no{(129)}}
\qt@newcmd\qurantrans@bn@cxxxvii{ইব্রাহীমের ধর্ম থেকে কে মুখ ফেরায়? কিন্তু সে ব্যক্তি, যে নিজেকে বোকা প্রতিপন্ন করে। নিশ্চয়ই আমি তাকে পৃথিবীতে মনোনীত করেছি এবং সে পরকালে সৎকর্মশীলদের অন্তর্ভুক্ত।\qt@no{(130)}}
\qt@newcmd\qurantrans@bn@cxxxviii{স্মরণ কর, যখন তাকে তার পালনকর্তা বললেনঃ অনুগত হও। সে বললঃ আমি বিশ্বপালকের অনুগত হলাম।\qt@no{(131)}}
\qt@newcmd\qurantrans@bn@cxxxix{এরই ওছিয়ত করেছে ইব্রাহীম তার সন্তানদের এবং ইয়াকুবও যে, হে আমার সন্তানগণ, নিশ্চয় আল্লাহ তোমাদের জন্য এ ধর্মকে মনোনীত করেছেন। কাজেই তোমরা মুসলমান না হয়ে কখনও মৃত্যুবরণ করো না।\qt@no{(132)}}
\qt@newcmd\qurantrans@bn@cxl{তোমরা কি উপস্থিত ছিলে, যখন ইয়াকুবের মৃত্যু নিকটবর্তী হয়? যখন সে সন্তানদের বললঃ আমার পর তোমরা কার এবাদত করবে? তারা বললো, আমরা তোমার পিতৃ-পুরুষ ইব্রাহীম, ইসমাঈল ও ইসহাকের উপাস্যের এবাদত করব। তিনি একক উপাস্য।\qt@no{(133)}}
\qt@newcmd\qurantrans@bn@cxli{আমরা সবাই তাঁর আজ্ঞাবহ। তারা ছিল এক সম্প্রদায়-যারা গত হয়ে গেছে। তারা যা করেছে, তা তাদেরই জন্যে। তারা কি করত, সে সম্পর্কে তোমরা জিজ্ঞাসিত হবে না।\qt@no{(134)}}
\qt@newcmd\qurantrans@bn@cxlii{তারা বলে, তোমরা ইহুদী অথবা খ্রীষ্টান হয়ে যাও, তবেই সুপথ পাবে। আপনি বলুন, কখনই নয়; বরং আমরা ইব্রাহীমের ধর্মে আছি যাতে বক্রতা নেই। সে মুশরিকদের অন্তর্ভুক্ত ছিল না।\qt@no{(135)}}
\qt@newcmd\qurantrans@bn@cxliii{তোমরা বল, আমরা ঈমান এনেছি আল্লাহর উপর এবং যা অবতীর্ণ হয়েছে আমাদের প্রতি এবং যা অবতীর্ণ হয়েছে ইব্রাহীম, ইসমাঈল, ইসহাক, ইয়াকুব এবং তদীয় বংশধরের প্রতি এবং মূসা, ঈসা, অন্যান্য নবীকে পালনকর্তার পক্ষ থেকে যা দান করা হয়েছে, তৎসমুদয়ের উপর। আমরা তাদের মধ্যে পার্থক্য করি না। আমরা তাঁরই আনুগত্যকারী।\qt@no{(136)}}
\qt@newcmd\qurantrans@bn@cxliv{অতএব তারা যদি ঈমান আনে, তোমাদের ঈমান আনার মত, তবে তারা সুপথ পাবে। আর যদি মুখ ফিরিয়ে নেয়, তবে তারাই হঠকারিতায় রয়েছে। সুতরাং এখন তাদের জন্যে আপনার পক্ষ থেকে আল্লাহই যথেষ্ট। তিনিই শ্রবণকারী, মহাজ্ঞানী।\qt@no{(137)}}
\qt@newcmd\qurantrans@bn@cxlv{আমরা আল্লাহর রং গ্রহণ করেছি। আল্লাহর রং এর চাইতে উত্তম রং আর কার হতে পারে?আমরা তাঁরই এবাদত করি।\qt@no{(138)}}
\qt@newcmd\qurantrans@bn@cxlvi{আপনি বলে দিন, তোমরা কি আমাদের সাথে আল্লাহ সম্পর্কে তর্ক করছ? অথচ তিনিই আমাদের পালনকর্তা এবং তোমাদের ও পালনকর্তা। আমাদের জন্যে আমাদের কর্ম তোমাদের জন্যে তোমাদের কর্ম। এবং আমরা তাঁরই প্রতি একনিষ্ঠ।\qt@no{(139)}}
\qt@newcmd\qurantrans@bn@cxlvii{অথবা তোমরা কি বলছ যে, নিশ্চয়ই ইব্রাহীম, ইসমাঈল, ইসহাক, ইয়াকুব (আঃ) ও তাদের সন্তানগন ইহুদী অথবা খ্রীষ্টান ছিলেন? আপনি বলে দিন, তোমরা বেশী জান, না আল্লাহ বেশী জানেন?\qt@no{(140)}}
\qt@newcmd\qurantrans@bn@cxlviii{তার চাইতে অত্যাচারী কে, যে আল্লাহর পক্ষ থেকে তার কাছে প্রমাণিত সাক্ষ্যকে গোপন করে? আল্লাহ তোমাদের কর্ম সম্পর্কে বেখবর নন। সে সম্প্রদায় অতীত হয়ে গেছে। তারা যা করেছে, তা তাদের জন্যে এবং তোমরা যা করছ, তা তোমাদের জন্যে। তাদের কর্ম সম্পর্কে তোমাদের জিজ্ঞেস করা হবে না।\qt@no{(141)}}
\qt@newcmd\qurantrans@bn@cxlix{এখন নির্বোধেরা বলবে, কিসে মুসলমানদের ফিরিয়ে দিল তাদের ঐ কেবলা থেকে, যার উপর তারা ছিল? আপনি বলুনঃ পূর্ব ও পশ্চিম আল্লাহরই। তিনি যাকে ইচ্ছা সরল পথে চালান।\qt@no{(142)}}
\qt@newcmd\qurantrans@bn@cl{এমনিভাবে আমি তোমাদেরকে মধ্যপন্থী সম্প্রদায় করেছি যাতে করে তোমরা সাক্ষ্যদাতা হও মানবমন্ডলীর জন্যে এবং যাতে রসূল সাক্ষ্যদাতা হন তোমাদের জন্য। আপনি যে কেবলার উপর ছিলেন, তাকে আমি এজন্যই কেবলা করেছিলাম, যাতে একথা প্রতীয়মান হয় যে, কে রসূলের অনুসারী থাকে আর কে পিঠটান দেয়। নিশ্চিতই এটা কঠোরতর বিষয়, কিন্তু তাদের জন্যে নয়, যাদেরকে আল্লাহ পথপ্রদর্শন করেছেন। আল্লাহ এমন নন যে, তোমাদের ঈমান নষ্ট করে দেবেন। নিশ্চয়ই আল্লাহ, মানুষের প্রতি অত্যন্ত স্নেহশীল, করুনাময়।\qt@no{(143)}}
\qt@newcmd\qurantrans@bn@cli{নিশ্চয়ই আমি আপনাকে বার বার আকাশের দিকে তাকাতে দেখি। অতএব, অবশ্যই আমি আপনাকে সে কেবলার দিকেই ঘুরিয়ে দেব যাকে আপনি পছন্দ করেন। এখন আপনি মসজিদুল-হারামের দিকে মুখ করুন এবং তোমরা যেখানেই থাক, সেদিকে মুখ কর। যারা আহলে-কিতাব, তারা অবশ্যই জানে যে, এটাই ঠিক পালনকর্তার পক্ষ থেকে। আল্লাহ বেখবর নন, সে সমস্ত কর্ম সম্পর্কে যা তারা করে।\qt@no{(144)}}
\qt@newcmd\qurantrans@bn@clii{যদি আপনি আহলে কিতাবদের কাছে সমুদয় নিদর্শন উপস্থাপন করেন, তবুও তারা আপনার কেবলা মেনে নেবে না এবং আপনিও তাদের কেবলা মানেন না। তারাও একে অন্যের কেবলা মানে না। যদি আপনি তাদের বাসনার অনুসরণ করেন, সে জ্ঞানলাভের পর, যা আপনার কাছে পৌঁছেছে, তবে নিশ্চয় আপনি অবিচারকারীদের অন্তর্ভুক্ত হবেন।\qt@no{(145)}}
\qt@newcmd\qurantrans@bn@cliii{আমি যাদেরকে কিতাব দান করেছি, তারা তাকে চেনে, যেমন করে চেনে নিজেদের পুত্রদেরকে। আর নিশ্চয়ই তাদের একটি সম্প্রদায় জেনে শুনে সত্যকে গোপন করে।\qt@no{(146)}}
\qt@newcmd\qurantrans@bn@cliv{বাস্তব সত্য সেটাই যা তোমার পালনকর্তা বলেন। কাজেই তুমি সন্দিহান হয়ো না।\qt@no{(147)}}
\qt@newcmd\qurantrans@bn@clv{আর সবার জন্যই রয়েছে কেবলা একেক দিকে, যে দিকে সে মুখ করে (এবাদত করবে)। কাজেই সৎকাজে প্রতিযোগিতামূলকভাবে এগিয়ে যাও। যেখানেই তোমরা থাকবে, আল্লাহ অবশ্যই তোমাদেরকে সমবেত করবেন। নিশ্চয়ই আল্লাহ সর্ব বিষয়ে ক্ষমতাশীল।\qt@no{(148)}}
\qt@newcmd\qurantrans@bn@clvi{আর যে স্থান থেকে তুমি বের হও, নিজের মুখ মসজিদে হারামের দিকে ফেরাও-নিঃসন্দেহে এটাই হলো তোমার পালনকর্তার পক্ষ থেকে নির্ধারিত বাস্তব সত্য। বস্তুতঃ তোমার পালনকর্তা তোমাদের কার্যকলাপ সম্পর্কে অনবহিত নন।\qt@no{(149)}}
\qt@newcmd\qurantrans@bn@clvii{আর তোমরা যেখান থেকেই বেরিয়ে আস এবং যেখানেই অবস্থান কর, সেদিকেই মুখ ফেরাও, যাতে করে মানুষের জন্য তোমাদের সাথে ঝগড়া করার অবকাশ না থাকে। অবশ্য যারা অবিবেচক, তাদের কথা আলাদা। কাজেই তাদের আপত্তিতে ভীত হয়ো না। আমাকেই ভয় কর। যাতে আমি তোমাদের জন্যে আমার অনুগ্রহ সমূহ পূর্ণ করে দেই এবং তাতে যেন তোমরা সরলপথ প্রাপ্ত হও।\qt@no{(150)}}
\qt@newcmd\qurantrans@bn@clviii{যেমন, আমি পাঠিয়েছি তোমাদেরই মধ্য থেকে তোমাদের জন্যে একজন রসূল, যিনি তোমাদের নিকট আমার বাণীসমুহ পাঠ করবেন এবং তোমাদের পবিত্র করবেন; আর তোমাদের শিক্ষা দেবেন কিতাব ও তাঁর তত্ত্বজ্ঞান এবং শিক্ষা দেবেন এমন বিষয় যা কখনো তোমরা জানতে না।\qt@no{(151)}}
\qt@newcmd\qurantrans@bn@clix{সুতরাং তোমরা আমাকে স্মরণ কর, আমিও তোমাদের স্মরণ রাখবো এবং আমার কৃতজ্ঞতা প্রকাশ কর; অকৃতজ্ঞ হয়ো না।\qt@no{(152)}}
\qt@newcmd\qurantrans@bn@clx{হে মুমিন গন! তোমরা ধৈর্য্য ও নামাযের মাধ্যমে সাহায্য প্রার্থনা কর। নিশ্চিতই আল্লাহ ধৈর্য্যশীলদের সাথে রয়েছেন।\qt@no{(153)}}
\qt@newcmd\qurantrans@bn@clxi{আর যারা আল্লাহর রাস্তায় নিহত হয়, তাদের মৃত বলো না। বরং তারা জীবিত, কিন্তু তোমরা তা বুঝ না।\qt@no{(154)}}
\qt@newcmd\qurantrans@bn@clxii{এবং অবশ্যই আমি তোমাদিগকে পরীক্ষা করব কিছুটা ভয়, ক্ষুধা, মাল ও জানের ক্ষতি ও ফল-ফসল বিনষ্টের মাধ্যমে। তবে সুসংবাদ দাও সবরকারীদের।\qt@no{(155)}}
\qt@newcmd\qurantrans@bn@clxiii{যখন তারা বিপদে পতিত হয়, তখন বলে, নিশ্চয় আমরা সবাই আল্লাহর জন্য এবং আমরা সবাই তাঁরই সান্নিধ্যে ফিরে যাবো।\qt@no{(156)}}
\qt@newcmd\qurantrans@bn@clxiv{তারা সে সমস্ত লোক, যাদের প্রতি আল্লাহর অফুরন্ত অনুগ্রহ ও রহমত রয়েছে এবং এসব লোকই হেদায়েত প্রাপ্ত।\qt@no{(157)}}
\qt@newcmd\qurantrans@bn@clxv{নিঃসন্দেহে সাফা ও মারওয়া আল্লাহ তা’আলার নিদর্শন গুলোর অন্যতম। সুতরাং যারা কা’বা ঘরে হজ্ব বা ওমরাহ পালন করে, তাদের পক্ষে এ দুটিতে প্রদক্ষিণ করাতে কোন দোষ নেই। বরং কেউ যদি স্বেচ্ছায় কিছু নেকীর কাজ করে, তবে আল্লাহ তা’আলার অবশ্যই তা অবগত হবেন এবং তার সে আমলের সঠিক মুল্য দেবেন।\qt@no{(158)}}
\qt@newcmd\qurantrans@bn@clxvi{নিশ্চয় যারা গোপন করে, আমি যেসব বিস্তারিত তথ্য এবং হেদায়েতের কথা নাযিল করেছি মানুষের জন্য কিতাবের মধ্যে বিস্তারিত বর্ণনা করার পরও; সে সমস্ত লোকের প্রতিই আল্লাহর অভিসম্পাত এবং অন্যান্য অভিসম্পাতকারীগণের ও।\qt@no{(159)}}
\qt@newcmd\qurantrans@bn@clxvii{তবে যারা তওবা করে এবং বর্ণিত তথ্যাদির সংশোধন করে মানুষের কাছে তা বর্ণনা করে দেয়, সে সমস্ত লোকের তওবা আমি কবুল করি এবং আমি তওবা কবুলকারী পরম দয়ালু।\qt@no{(160)}}
\qt@newcmd\qurantrans@bn@clxviii{নিশ্চয় যারা কুফরী করে এবং কাফের অবস্থায়ই মৃত্যুবরণ করে, সে সমস্ত লোকের প্রতি আল্লাহর ফেরেশতাগনের এবং সমগ্র মানুষের লা’নত।\qt@no{(161)}}
\qt@newcmd\qurantrans@bn@clxix{এরা চিরকাল এ লা’নতের মাঝেই থাকবে। তাদের উপর থেকে আযাব কখনও হালকা করা হবে না বরং এরা বিরাম ও পাবে না।\qt@no{(162)}}
\qt@newcmd\qurantrans@bn@clxx{আর তোমাদের উপাস্য একইমাত্র উপাস্য। তিনি ছাড়া মহা করুণাময় দয়ালু কেউ নেই।\qt@no{(163)}}
\qt@newcmd\qurantrans@bn@clxxi{নিশ্চয়ই আসমান ও যমীনের সৃষ্টিতে, রাত ও দিনের বিবর্তনে এবং নদীতে নৌকাসমূহের চলাচলে মানুষের জন্য কল্যাণ রয়েছে। আর আল্লাহ তা’ আলা আকাশ থেকে যে পানি নাযিল করেছেন, তদ্দ্বারা মৃত যমীনকে সজীব করে তুলেছেন এবং তাতে ছড়িয়ে দিয়েছেন সবরকম জীব-জন্তু। আর আবহাওয়া পরিবর্তনে এবং মেঘমালার যা তাঁরই হুকুমের অধীনে আসমান ও যমীনের মাঝে বিচরণ করে, নিশ্চয়ই সে সমস্ত বিষয়ের মাঝে নিদর্শন রয়েছে বুদ্ধিমান সম্প্রদায়ের জন্যে।\qt@no{(164)}}
\qt@newcmd\qurantrans@bn@clxxii{আর কোন লোক এমনও রয়েছে যারা অন্যান্যকে আল্লাহর সমকক্ষ সাব্যস্ত করে এবং তাদের প্রতি তেমনি ভালবাসা পোষণ করে, যেমন আল্লাহর প্রতি ভালবাসা হয়ে থাকে। কিন্তু যারা আল্লাহর প্রতি ঈমানদার তাদের ভালবাসা ওদের তুলনায় বহুগুণ বেশী। আর কতইনা উত্তম হ’ত যদি এ জালেমরা পার্থিব কোন কোন আযাব প্রত্যক্ষ করেই উপলব্ধি করে নিত যে, যাবতীয় ক্ষমতা শুধুমাত্র আল্লাহরই জন্য এবং আল্লাহর আযাবই সবচেয়ে কঠিনতর।\qt@no{(165)}}
\qt@newcmd\qurantrans@bn@clxxiii{অনুসৃতরা যখন অনুসরণকারীদের প্রতি অসন্তুষ্ট হয়ে যাবে এবং যখন আযাব প্রত্যক্ষ করবে আর বিচ্ছিন্ন হয়ে যাবে তাদের পারস্পরিক সমস্ত সম্পর্ক।\qt@no{(166)}}
\qt@newcmd\qurantrans@bn@clxxiv{এবং অনুসারীরা বলবে, কতইনা ভাল হত, যদি আমাদিগকে পৃথিবীতে ফিরে যাবার সুযোগ দেয়া হত। তাহলে আমরাও তাদের প্রতি তেমনি অসন্তুষ্ট হয়ে যেতাম, যেমন তারা অসন্তুষ্ট হয়েছে আমাদের প্রতি। এভাবেই আল্লাহ তা’আলা তাদেরকে দেখাবেন তাদের কৃতকর্ম তাদেরকে অনুতপ্ত করার জন্যে। অথচ, তারা কস্মিনকালেও আগুন থেকে বের হতে পারবে না।\qt@no{(167)}}
\qt@newcmd\qurantrans@bn@clxxv{হে মানব মন্ডলী, পৃথিবীর হালাল ও পবিত্র বস্তু-সামগ্রী ভক্ষন কর। আর শয়তানের পদাঙ্ক অনুসরণ করো না। সে নিঃসন্দেহে তোমাদের প্রকাশ্য শত্রু।\qt@no{(168)}}
\qt@newcmd\qurantrans@bn@clxxvi{সে তো এ নির্দেশই তোমাদিগকে দেবে যে, তোমরা অন্যায় ও অশ্লীল কাজ করতে থাক এবং আল্লাহর প্রতি এমন সব বিষয়ে মিথ্যারোপ কর যা তোমরা জান না।\qt@no{(169)}}
\qt@newcmd\qurantrans@bn@clxxvii{আর যখন তাদেরকে কেউ বলে যে, সে হুকুমেরই আনুগত্য কর যা আল্লাহ তা’আলা নাযিল করেছেন, তখন তারা বলে কখনো না, আমরা তো সে বিষয়েরই অনুসরণ করব। যাতে আমরা আমাদের বাপ-দাদাদেরকে দেখেছি। যদি ও তাদের বাপ দাদারা কিছুই জানতো না, জানতো না সরল পথও।\qt@no{(170)}}
\qt@newcmd\qurantrans@bn@clxxviii{বস্তুতঃ এহেন কাফেরদের উদাহরণ এমন, যেন কেউ এমন কোন জীবকে আহবান করছে যা কোন কিছুই শোনে না, হাঁক-ডাক আর চিৎকার ছাড়া বধির মুক, এবং অন্ধ। সুতরাং তারা কিছুই বোঝে না।\qt@no{(171)}}
\qt@newcmd\qurantrans@bn@clxxix{হে ঈমানদারগণ, তোমরা পবিত্র বস্তু সামগ্রী আহার কর, যেগুলো আমি তোমাদেরকে রুযী হিসাবে দান করেছি এবং শুকরিয়া আদায় কর আল্লাহর, যদি তোমরা তাঁরই বন্দেগী কর।\qt@no{(172)}}
\qt@newcmd\qurantrans@bn@clxxx{তিনি তোমাদের উপর হারাম করেছেন, মৃত জীব, রক্ত, শুকর মাংস এবং সেসব জীব-জন্তু যা আল্লাহ ব্যাতীত অপর কারো নামে উৎসর্গ করা হয়। অবশ্য যে লোক অনন্যোপায় হয়ে পড়ে এবং নাফরমানী ও সীমালঙ্ঘনকারী না হয়, তার জন্য কোন পাপ নেই। নিঃসন্দেহে আল্লাহ মহান ক্ষমাশীল, অত্যন্ত দয়ালু।\qt@no{(173)}}
\qt@newcmd\qurantrans@bn@clxxxi{নিশ্চয় যারা সেসব বিষয় গোপন করে, যা আল্লাহ কিতাবে নাযিল করেছেন এবং সেজন্য অল্প মূল্য গ্রহণ করে, তারা আগুন ছাড়া নিজের পেটে আর কিছুই ঢুকায় না। আর আল্লাহ কেয়ামতের দিন তাদের সাথে না কথা বলবেন, না তাদের পবিত্র করা হবে, বস্তুতঃ তাদের জন্যে রয়েছে বেদনাদায়ক আযাব।\qt@no{(174)}}
\qt@newcmd\qurantrans@bn@clxxxii{এরাই হল সে সমস্ত লোক, যারা হেদায়েতের বিনিময়ে গোমরাহী খরিদ করেছে এবং (খরিদ করেছে) ক্ষমা ও অনুগ্রহের বিনিময়ে আযাব। অতএব, তারা দোযখের উপর কেমন ধৈর্য্য ধারণকারী।\qt@no{(175)}}
\qt@newcmd\qurantrans@bn@clxxxiii{আর এটা এজন্যে যে, আল্লাহ নাযিল করেছেন সত্যপূর্ণ কিতাব। আর যারা কেতাবের মাঝে মতবিরোধ সৃষ্টি করেছে নিশ্চয়ই তারা জেদের বশবর্তী হয়ে অনেক দূরে চলে গেছে।\qt@no{(176)}}
\qt@newcmd\qurantrans@bn@clxxxiv{সৎকর্ম শুধু এই নয় যে, পূর্ব কিংবা পশ্চিমদিকে মুখ করবে, বরং বড় সৎকাজ হল এই যে, ঈমান আনবে আল্লাহর উপর কিয়ামত দিবসের উপর, ফেরেশতাদের উপর এবং সমস্ত নবী-রসূলগণের উপর, আর সম্পদ ব্যয় করবে তাঁরই মহব্বতে আত্নীয়-স্বজন, এতীম-মিসকীন, মুসাফির-ভিক্ষুক ও মুক্তিকামী ক্রীতদাসদের জন্যে। আর যারা নামায প্রতিষ্ঠা করে, যাকাত দান করে এবং যারা কৃত প্রতিজ্ঞা সম্পাদনকারী এবং অভাবে, রোগে-শোকে ও যুদ্ধের সময় ধৈর্য্য ধারণকারী তারাই হল সত্যাশ্রয়ী, আর তারাই পরহেযগার।\qt@no{(177)}}
\qt@newcmd\qurantrans@bn@clxxxv{হে ঈমানদারগন! তোমাদের প্রতি নিহতদের ব্যাপারে কেসাস গ্রহণ করা বিধিবদ্ধ করা হয়েছে। স্বাধীন ব্যক্তি স্বাধীন ব্যক্তির বদলায়, দাস দাসের বদলায় এবং নারী নারীর বদলায়। অতঃপর তার ভাইয়ের তরফ থেকে যদি কাউকে কিছুটা মাফ করে দেয়া হয়, তবে প্রচলিত নিয়মের অনুসরণ করবে এবং ভালভাবে তাকে তা প্রদান করতে হবে। এটা তোমাদের পালনকর্তার তরফ থেকে সহজ এবং বিশেষ অনুগ্রহ। এরপরও যে ব্যাক্তি বাড়াবাড়ি করে, তার জন্য রয়েছে বেদনাদায়ক আযাব।\qt@no{(178)}}
\qt@newcmd\qurantrans@bn@clxxxvi{হে বুদ্ধিমানগণ! কেসাসের মধ্যে তোমাদের জন্যে জীবন রয়েছে, যাতে তোমরা সাবধান হতে পার।\qt@no{(179)}}
\qt@newcmd\qurantrans@bn@clxxxvii{তোমাদের কারো যখন মৃত্যুর সময় উপস্থিত হয়, সে যদি কিছু ধন-সম্পদ ত্যাগ করে যায়, তবে তার জন্য ওসীয়ত করা বিধিবদ্ধ করা হলো, পিতা-মাতা ও নিকটাত্নীয়দের জন্য ইনসাফের সাথে পরহেযগারদের জন্য এ নির্দেশ জরুরী। নিশ্চয় আল্লাহ তা’আলা সবকিছু শোনেন ও জানেন।\qt@no{(180)}}
\qt@newcmd\qurantrans@bn@clxxxviii{যদি কেউ ওসীয়ত শোনার পর তাতে কোন রকম পরিবর্তন সাধন করে, তবে যারা পরিবর্তন করে তাদের উপর এর পাপ পতিত হবে।\qt@no{(181)}}
\qt@newcmd\qurantrans@bn@clxxxix{যদি কেউ ওসীয়তকারীর পক্ষ থেকে আশংকা করে পক্ষপাতিত্বের অথবা কোন অপরাধমূলক সিদ্ধান্তের এবং তাদের মধ্যে মীমাংসা করে দেয়, তবে তার কোন গোনাহ হবে না। নিশ্চয় আল্লাহ তা’আলা ক্ষমাশীল, অতি দয়ালু।\qt@no{(182)}}
\qt@newcmd\qurantrans@bn@cxc{হে ঈমানদারগণ! তোমাদের উপর রোজা ফরয করা হয়েছে, যেরূপ ফরজ করা হয়েছিল তোমাদের পূর্ববর্তী লোকদের উপর, যেন তোমরা পরহেযগারী অর্জন করতে পার।\qt@no{(183)}}
\qt@newcmd\qurantrans@bn@cxci{গণনার কয়েকটি দিনের জন্য অতঃপর তোমাদের মধ্যে যে, অসুখ থাকবে অথবা সফরে থাকবে, তার পক্ষে অন্য সময়ে সে রোজা পূরণ করে নিতে হবে। আর এটি যাদের জন্য অত্যন্ত কষ্ট দায়ক হয়, তারা এর পরিবর্তে একজন মিসকীনকে খাদ্যদান করবে। যে ব্যক্তি খুশীর সাথে সৎকর্ম করে, তা তার জন্য কল্যাণ কর হয়। আর যদি রোজা রাখ, তবে তোমাদের জন্যে বিশেষ কল্যাণকর, যদি তোমরা তা বুঝতে পার।\qt@no{(184)}}
\qt@newcmd\qurantrans@bn@cxcii{রমযান মাসই হল সে মাস, যাতে নাযিল করা হয়েছে কোরআন, যা মানুষের জন্য হেদায়েত এবং সত্যপথ যাত্রীদের জন্য সুষ্পষ্ট পথ নির্দেশ আর ন্যায় ও অন্যায়ের মাঝে পার্থক্য বিধানকারী। কাজেই তোমাদের মধ্যে যে লোক এ মাসটি পাবে, সে এ মাসের রোযা রাখবে। আর যে লোক অসুস্থ কিংবা মুসাফির অবস্থায় থাকবে সে অন্য দিনে গণনা পূরণ করবে। আল্লাহ তোমাদের জন্য সহজ করতে চান; তোমাদের জন্য জটিলতা কামনা করেন না যাতে তোমরা গণনা পূরণ কর এবং তোমাদের হেদায়েত দান করার দরুন আল্লাহ তা’আলার মহত্ত্ব বর্ণনা কর, যাতে তোমরা কৃতজ্ঞতা স্বীকার কর।\qt@no{(185)}}
\qt@newcmd\qurantrans@bn@cxciii{আর আমার বান্দারা যখন তোমার কাছে জিজ্ঞেস করে আমার ব্যাপারে বস্তুতঃ আমি রয়েছি সন্নিকটে। যারা প্রার্থনা করে, তাদের প্রার্থনা কবুল করে নেই, যখন আমার কাছে প্রার্থনা করে। কাজেই আমার হুকুম মান্য করা এবং আমার প্রতি নিঃসংশয়ে বিশ্বাস করা তাদের একান্ত কর্তব্য। যাতে তারা সৎপথে আসতে পারে।\qt@no{(186)}}
\qt@newcmd\qurantrans@bn@cxciv{রোযার রাতে তোমাদের স্ত্রীদের সাথে সহবাস করা তোমাদের জন্য হালাল করা হয়েছে। তারা তোমাদের পরিচ্ছদ এবং তোমরা তাদের পরিচ্ছদ। আল্লাহ অবগত রয়েছেন যে, তোমরা আত্নপ্রতারণা করছিলে, সুতরাং তিনি তোমাদেরকে ক্ষমা করেছেন এবং তোমাদের অব্যাহতি দিয়েছেন। অতঃপর তোমরা নিজেদের স্ত্রীদের সাথে সহবাস কর এবং যা কিছু তোমাদের জন্য আল্লাহ দান করেছেন, তা আহরন কর। আর পানাহার কর যতক্ষণ না কাল রেখা থেকে ভোরের শুভ্র রেখা পরিষ্কার দেখা যায়। অতঃপর রোযা পূর্ণ কর রাত পর্যন্ত। আর যতক্ষণ তোমরা এতেকাফ অবস্থায় মসজিদে অবস্থান কর, ততক্ষণ পর্যন্ত স্ত্রীদের সাথে মিশো না। এই হলো আল্লাহ কর্তৃক বেঁধে দেয়া সীমানা। অতএব, এর কাছেও যেও না। এমনিভাবে বর্ণনা করেন আল্লাহ নিজের আয়াত সমূহ মানুষের জন্য, যাতে তারা বাঁচতে পারে।\qt@no{(187)}}
\qt@newcmd\qurantrans@bn@cxcv{তোমরা অন্যায়ভাবে একে অপরের সম্পদ ভোগ করো না। এবং জনগণের সম্পদের কিয়দংশ জেনে-শুনে পাপ পন্থায় আত্নসাৎ করার উদ্দেশে শাসন কতৃপক্ষের হাতেও তুলে দিও না।\qt@no{(188)}}
\qt@newcmd\qurantrans@bn@cxcvi{তোমার নিকট তারা জিজ্ঞেস করে নতুন চাঁদের বিষয়ে। বলে দাও যে এটি মানুষের জন্য সময় নির্ধারণ এবং হজ্বের সময় ঠিক করার মাধ্যম। আর পেছনের দিক দিয়ে ঘরে প্রবেশ করার মধ্যে কোন নেকী বা কল্যাণ নেই। অবশ্য নেকী হল আল্লাহকে ভয় করার মধ্যে। আর তোমরা ঘরে প্রবেশ কর দরজা দিয়ে এবং আল্লাহকে ভয় করতে থাক যাতে তোমরা নিজেদের বাসনায় কৃতকার্য হতে পার।\qt@no{(189)}}
\qt@newcmd\qurantrans@bn@cxcvii{আর লড়াই কর আল্লাহর ওয়াস্তে তাদের সাথে, যারা লড়াই করে তোমাদের সাথে। অবশ্য কারো প্রতি বাড়াবাড়ি করো না। নিশ্চয়ই আল্লাহ সীমালঙ্ঘনকারীদেরকে পছন্দ করেন না।\qt@no{(190)}}
\qt@newcmd\qurantrans@bn@cxcviii{আর তাদেরকে হত্যাকর যেখানে পাও সেখানেই এবং তাদেরকে বের করে দাও সেখান থেকে যেখান থেকে তারা বের করেছে তোমাদেরকে। বস্তুতঃ ফেতনা ফ্যাসাদ বা দাঙ্গা-হাঙ্গামা সৃষ্টি করা হত্যার চেয়েও কঠিন অপরাধ। আর তাদের সাথে লড়াই করো না মসজিদুল হারামের নিকটে যতক্ষণ না তারা তোমাদের সাথে সেখানে লড়াই করে। অবশ্য যদি তারা নিজেরাই তোমাদের সাথে লড়াই করে। তাহলে তাদেরকে হত্যা কর। এই হল কাফেরদের শাস্তি।\qt@no{(191)}}
\qt@newcmd\qurantrans@bn@cxcix{আর তারা যদি বিরত থাকে, তাহলে আল্লাহ অত্যন্ত দয়ালু।\qt@no{(192)}}
\qt@newcmd\qurantrans@bn@cc{আর তোমরা তাদের সাথে লড়াই কর, যে পর্যন্ত না ফেতনার অবসান হয় এবং আল্লাহর দ্বীন প্রতিষ্ঠিত হয়। অতঃপর যদি তারা নিবৃত হয়ে যায় তাহলে কারো প্রতি কোন জবরদস্তি নেই, কিন্তু যারা যালেম (তাদের ব্যাপারে আলাদা)।\qt@no{(193)}}
\qt@newcmd\qurantrans@bn@cci{সম্মানিত মাসই সম্মানিত মাসের বদলা। আর সম্মান রক্ষা করারও বদলা রয়েছে। বস্তুতঃ যারা তোমাদের উপর জবর দস্তি করেছে, তোমরা তাদের উপর জবরদস্তি কর, যেমন জবরদস্তি তারা করেছে তোমাদের উপর। আর তোমরা আল্লাহকে ভয় কর এবং জেনে রাখ, যারা পরহেযগার, আল্লাহ তাদের সাথে রয়েছেন।\qt@no{(194)}}
\qt@newcmd\qurantrans@bn@ccii{আর ব্যয় কর আল্লাহর পথে, তবে নিজের জীবনকে ধ্বংসের সম্মুখীন করো না। আর মানুষের প্রতি অনুগ্রহ কর। আল্লাহ অনুগ্রহকারীদেরকে ভালবাসেন।\qt@no{(195)}}
\qt@newcmd\qurantrans@bn@cciii{আর তোমরা আল্লাহর উদ্দেশ্যে হজ্জ্ব ওমরাহ পরিপূর্ণ ভাবে পালন কর। যদি তোমরা বাধা প্রাপ্ত হও, তাহলে কোরবানীর জন্য যাকিছু সহজলভ্য, তাই তোমাদের উপর ধার্য। আর তোমরা ততক্ষণ পর্যন্ত মাথা মুন্ডন করবে না, যতক্ষণ না কোরবাণী যথাস্থানে পৌছে যাবে। যারা তোমাদের মধ্যে অসুস্থ হয়ে পড়বে কিংবা মাথায় যদি কোন কষ্ট থাকে, তাহলে তার পরিবর্তে রোজা করবে কিংবা খয়রাত দেবে অথবা কুরবানী করবে। আর তোমাদের মধ্যে যারা হজ্জ্ব ওমরাহ একত্রে একই সাথে পালন করতে চাও, তবে যাকিছু সহজলভ্য, তা দিয়ে কুরবানী করাই তার উপর কর্তব্য। বস্তুতঃ যারা কোরবানীর পশু পাবে না, তারা হজ্জ্বের দিনগুলোর মধ্যে রোজা রাখবে তিনটি আর সাতটি রোযা রাখবে ফিরে যাবার পর। এভাবে দশটি রোযা পূর্ণ হয়ে যাবে। এ নির্দেশটি তাদের জন্য, যাদের পরিবার পরিজন মসজিদুল হারামের আশে-পাশে বসবাস করে না। আর আল্লাহকে ভয় করতে থাক। সন্দেহাতীতভাবে জেনো যে, আল্লাহর আযাব বড়ই কঠিন।\qt@no{(196)}}
\qt@newcmd\qurantrans@bn@cciv{হজ্জ্বে কয়েকটি মাস আছে সুবিদিত। এসব মাসে যে লোক হজ্জ্বের পরিপূর্ণ নিয়ত করবে, তার পক্ষে স্ত্রীও সাথে নিরাভরণ হওয়া জায়েজ নয়। না অশোভন কোন কাজ করা, না ঝাগড়া-বিবাদ করা হজ্জ্বের সেই সময় জায়েজ নয়। আর তোমরা যাকিছু সৎকাজ কর, আল্লাহ তো জানেন। আর তোমরা পাথেয় সাথে নিয়ে নাও। নিঃসন্দেহে সর্বোত্তম পাথেয় হচ্ছে আল্লাহর ভয়। আর আমাকে ভয় করতে থাক, হে বুদ্ধিমানগন! তোমাদের উপর তোমাদের পালনকর্তার অনুগ্রহ অন্বেষণ করায় কোন পাপ নেই।\qt@no{(197)}}
\qt@newcmd\qurantrans@bn@ccv{তোমাদের উপর তোমাদের পালনকর্তার অনুগ্রহ অন্বেষন করায় কোন পাপ নেই। অতঃপর যখন তওয়াফের জন্য ফিরে আসবে আরাফাত থেকে, তখন মাশ‘ আরে-হারামের নিকটে আল্লাহকে স্মরণ কর। আর তাঁকে স্মরণ কর তেমনি করে, যেমন তোমাদিগকে হেদায়েত করা হয়েছে। আর নিশ্চয়ই ইতিপূর্বে তোমরা ছিলে অজ্ঞ।\qt@no{(198)}}
\qt@newcmd\qurantrans@bn@ccvi{অতঃপর তওয়াফের জন্যে দ্রুতগতিতে সেখান থেকে ফিরে আস, যেখান থেকে সবাই ফিরে। আর আল্লাহর কাছেই মাগফেরাত কামনা কর। নিশ্চয়ই আল্লাহ ক্ষমাকারী, করুনাময়।\qt@no{(199)}}
\qt@newcmd\qurantrans@bn@ccvii{আর অতঃপর যখন হজ্জ্বের যাবতীয় অনুষ্ঠানক্রিয়াদি সমাপ্ত করে সারবে, তখন স্মরণ করবে আল্লাহকে, যেমন করে তোমরা স্মরণ করতে নিজেদের বাপ-দাদাদেরকে; বরং তার চেয়েও বেশী স্মরণ করবে। তারপর অনেকে তো বলে যে পরওয়াদেগার! আমাদিগকে দুনিয়াতে দান কর। অথচ তার জন্যে পরকালে কোন অংশ নেই।\qt@no{(200)}}
\qt@newcmd\qurantrans@bn@ccviii{আর তাদের মধ্যে কেউ কেউ বলে-হে পরওয়ারদেগার! আমাদিগকে দুনয়াতেও কল্যাণ দান কর এবং আখেরাতেও কল্যাণ দান কর এবং আমাদিগকে দোযখের আযাব থেকে রক্ষা কর।\qt@no{(201)}}
\qt@newcmd\qurantrans@bn@ccix{এদেরই জন্য অংশ রয়েছে নিজেদের উপার্জিত সম্পদের। আর আল্লাহ দ্রুত হিসাব গ্রহণকারী।\qt@no{(202)}}
\qt@newcmd\qurantrans@bn@ccx{আর স্মরণ কর আল্লাহকে নির্দিষ্ট সংখ্যক কয়েকটি দিনে। অতঃপর যে লোক তাড়াহুড়া করে চলে যাবে শুধু দু, দিনের মধ্যে, তার জন্যে কোন পাপ নেই। আর যে লোক থেকে যাবে তাঁর উপর কোন পাপ নেই, অবশ্য যারা ভয় করে। আর তোমরা আল্লাহকে ভয় করতে থাক এবং নিশ্চিত জেনে রাখ, তোমরা সবাই তার সামনে সমবেত হবে।\qt@no{(203)}}
\qt@newcmd\qurantrans@bn@ccxi{আর এমন কিছু লোক রযেছে যাদের পার্থিব জীবনের কথাবার্তা তোমাকে চমৎকৃত করবে। আর তারা সাক্ষ্য স্থাপন করে আল্লাহকে নিজের মনের কথার ব্যাপারে। প্রকৃতপক্ষে তারা কঠিন ঝগড়াটে লোক।\qt@no{(204)}}
\qt@newcmd\qurantrans@bn@ccxii{যখন ফিরে যায় তখন চেষ্টা করে যাতে সেখানে অকল্যাণ সৃষ্টি করতে পারে এবং শস্যক্ষেত্র ও প্রাণনাশ করতে পারে। আল্লাহ ফাসাদ ও দাঙ্গা-হাঙ্গামা পছন্দ করেন না।\qt@no{(205)}}
\qt@newcmd\qurantrans@bn@ccxiii{আর যখন তাকে বলা হয় যে, আল্লাহকে ভয় কর, তখন তার পাপ তাকে অহঙ্কারে উদ্বুদ্ধ করে। সুতরাং তার জন্যে দোযখই যথেষ্ট। আর নিঃসন্দেহে তা হলো নিকৃষ্টতর ঠিকানা।\qt@no{(206)}}
\qt@newcmd\qurantrans@bn@ccxiv{আর মানুষের মাঝে এক শ্রেণীর লোক রয়েছে যারা আল্লাহর সন্তুষ্টিকল্পে নিজেদের জানের বাজি রাখে। আল্লাহ হলেন তাঁর বান্দাদের প্রতি অত্যন্ত মেহেরবান।\qt@no{(207)}}
\qt@newcmd\qurantrans@bn@ccxv{হে ঈমানদার গন! তোমরা পরিপূর্ণভাবে ইসলামের অন্তর্ভুক্ত হয়ে যাও এবং শয়তানের পদাংক অনুসরণ কর না। নিশ্চিত রূপে সে তোমাদের প্রকাশ্য শত্রু।\qt@no{(208)}}
\qt@newcmd\qurantrans@bn@ccxvi{অতঃপর তোমাদের মাঝে পরিস্কার নির্দেশ এসে গেছে বলে জানার পরেও যদি তোমরা পদস্খলিত হও, তাহলে নিশ্চিত জেনে রেখো, আল্লাহ, পরাক্রমশালী, বিজ্ঞ।\qt@no{(209)}}
\qt@newcmd\qurantrans@bn@ccxvii{তারা কি সে দিকেই তাকিয়ে রয়েছে যে, মেঘের আড়ালে তাদের সামনে আসবেন আল্লাহ ও ফেরেশতাগণ ? আর তাতেই সব মীমাংসা হয়ে যাবে। বস্তুতঃ সবকার্যকলাপই আল্লাহর নিকট গিয়ে পৌঁছবে।\qt@no{(210)}}
\qt@newcmd\qurantrans@bn@ccxviii{বনী ইসরাঈলদিগকে জিজ্ঞেস কর, তাদেরকে আমি কত স্পষ্ট নির্দশনাবলী দান করেছি। আর আল্লাহর নেয়ামত পৌছে যাওয়ার পর যদি কেউ সে নেয়ামতকে পরিবর্তিত করে দেয়, তবে আল্লাহর আযাব অতি কঠিন।\qt@no{(211)}}
\qt@newcmd\qurantrans@bn@ccxix{পার্থিব জীবনের উপর কাফেরদিগকে উম্মত্ত করে দেয়া হয়েছে। আর তারা ঈমানদারদের প্রতি লক্ষ্য করে হাসাহাসি করে। পক্ষান্তরে যারা পরহেযগার তারা সেই কাফেরদের তুলনায় কেয়ামতের দিন অত্যন্ত উচ্চমর্যাদায় থাকবে। আর আল্লাহ যাকে ইচ্ছা সীমাহীন রুযী দান করেন।\qt@no{(212)}}
\qt@newcmd\qurantrans@bn@ccxx{সকল মানুষ একই জাতি সত্তার অন্তর্ভুক্ত ছিল। অতঃপর আল্লাহ তা’আলা পয়গম্বর পাঠালেন সুসংবাদদাতা ও ভীতি প্রদর্শনকরী হিসাবে। আর তাঁদের সাথে অবর্তীণ করলেন সত্য কিতাব, যাতে মানুষের মাঝে বিতর্কমূলক বিষয়ে মীমাংসা করতে পারেন। বস্তুতঃ কিতাবের ব্যাপারে অন্য কেউ মতভেদ করেনি; কিন্তু পরিষ্কার নির্দেশ এসে যাবার পর নিজেদের পারস্পরিক জেদবশতঃ তারাই করেছে, যারা কিতাব প্রাপ্ত হয়েছিল। অতঃপর আল্লাহ ঈমানদারদেরকে হেদায়েত করেছেন সেই সত্য বিষয়ে, যে ব্যাপারে তারা মতভেদ লিপ্ত হয়েছিল। আল্লাহ যাকে ইচ্ছা, সরল পথ বাতলে দেন।\qt@no{(213)}}
\qt@newcmd\qurantrans@bn@ccxxi{তোমাদের কি এই ধারণা যে, তোমরা জান্নাতে চলে যাবে, অথচ সে লোকদের অবস্থা অতিক্রম করনি যারা তোমাদের পূর্বে অতীত হয়েছে। তাদের উপর এসেছে বিপদ ও কষ্ট। আর এমনি ভাবে শিহরিত হতে হয়েছে যাতে নবী ও তাঁর প্রতি যারা ঈমান এনেছিল তাদেরকে পর্যন্ত একথা বলতে হয়েছে যে, কখন আসবে আল্লাহর সাহায্যে! তোমরা শোনে নাও, আল্লাহর সাহায্যে একান্তই নিকটবর্তী।\qt@no{(214)}}
\qt@newcmd\qurantrans@bn@ccxxii{তোমার কাছে জিজ্ঞেস করে, কি তারা ব্যয় করবে? বলে দাও-যে বস্তুই তোমরা ব্যয় কর, তা হবে পিতা-মাতার জন্যে, আত্নীয়-আপনজনের জন্যে, এতীম-অনাথদের জন্যে, অসহায়দের জন্যে এবং মুসাফিরদের জন্যে। আর তোমরা যে কোন সৎকাজ করবে, নিঃসন্দেহে তা অত্যন্ত ভালভাবেই আল্লাহর জানা রয়েছে।\qt@no{(215)}}
\qt@newcmd\qurantrans@bn@ccxxiii{তোমাদের উপর যুদ্ধ ফরয করা হয়েছে, অথচ তা তোমাদের কাছে অপছন্দনীয়। পক্ষান্তরে তোমাদের কাছে হয়তো কোন একটা বিষয় পছন্দসই নয়, অথচ তা তোমাদের জন্য কল্যাণকর। আর হয়তোবা কোন একটি বিষয় তোমাদের কাছে পছন্দনীয় অথচ তোমাদের জন্যে অকল্যাণকর। বস্তুতঃ আল্লাহই জানেন, তোমরা জান না।\qt@no{(216)}}
\qt@newcmd\qurantrans@bn@ccxxiv{সম্মানিত মাস সম্পর্কে তোমার কাছে জিজ্ঞেস করে যে, তাতে যুদ্ধ করা কেমন? বলে দাও এতে যুদ্ধ করা ভীষণ বড় পাপ। আর আল্লাহর পথে প্রতিবন্দ্বকতা সৃষ্টি করা এবং কুফরী করা, মসজিদে-হারামের পথে বাধা দেয়া এবং সেখানকার অধিবাসীদেরকে বহিস্কার করা, আল্লাহর নিকট তার চেয়েও বড় পাপ। আর ধর্মের ব্যাপারে ফেতনা সৃষ্টি করা নরহত্যা অপেক্ষাও মহা পাপ। বস্তুতঃ তারা তো সর্বদাই তোমাদের সাথে যুদ্ধ করতে থাকবে, যাতে করে তোমাদিগকে দ্বীন থেকে ফিরিয়ে দিতে পারে যদি সম্ভব হয়। তোমাদের মধ্যে যারা নিজের দ্বীন থেকে ফিরে দাঁড়াবে এবং কাফের অবস্থায় মৃত্যুবরণ করবে, দুনিয়া ও আখেরাতে তাদের যাবতীয় আমল বিনষ্ট হয়ে যাবে। আর তারাই হলো দোযখবাসী। তাতে তারা চিরকাল বাস করবে।\qt@no{(217)}}
\qt@newcmd\qurantrans@bn@ccxxv{আর এতে কোন সন্দেহের অবকাশ নেই যে, যারা ঈমান এনেছে এবং যারা হিজরত করেছে আর আল্লাহর পথে লড়াই (জেহাদ) করেছে, তারা আল্লাহর রহমতের প্রত্যাশী। আর আল্লাহ হচ্ছেন ক্ষমাকারী করুনাময়।\qt@no{(218)}}
\qt@newcmd\qurantrans@bn@ccxxvi{তারা তোমাকে মদ ও জুয়া সম্পর্কে জিজ্ঞেস করে। বলে দাও, এতদুভয়ের মধ্যে রয়েছে মহাপাপ। আর মানুষের জন্যে উপকারিতাও রয়েছে, তবে এগুলোর পাপ উপকারিতা অপেক্ষা অনেক বড়। আর তোমার কাছে জিজ্ঞেস করে, কি তারা ব্যয় করবে? বলে দাও, নিজেদের প্রয়োজনীয় ব্যয়ের পর যা বাঁচে তাই খরচ করবে। এভাবেই আল্লাহ তোমাদের জন্যে নির্দেশ সুস্পষ্টরূপে বর্ণনা করেন, যাতে তোমরা চিন্তা করতে পার।\qt@no{(219)}}
\qt@newcmd\qurantrans@bn@ccxxvii{দুনিয়া ও আখেরাতের বিষয়ে। আর তোমার কাছে জিজ্ঞেস করে, এতীম সংক্রান্ত হুকুম। বলে দাও, তাদের কাজ-কর্ম সঠিকভাবে গুছিয়ে দেয়া উত্তম আর যদি তাদের ব্যয়ভার নিজের সাথে মিশিয়ে নাও, তাহলে মনে করবে তারা তোমাদের ভাই । বস্তুতঃ অমঙ্গলকামী ও মঙ্গলকামীদেরকে আল্লাহ জানেন। আল্লাহ যদি ইচ্ছা করতেন, তাহলে তোমাদের উপর জটিলতা আরোপ করতে পারতেন। নিশ্চয়ই তিনি পরাক্রমশালী, মহাপ্রজ্ঞ।\qt@no{(220)}}
\qt@newcmd\qurantrans@bn@ccxxviii{আর তোমরা মুশরেক নারীদেরকে বিয়ে করোনা, যতক্ষণ না তারা ঈমান গ্রহণ করে। অবশ্য মুসলমান ক্রীতদাসী মুশরেক নারী অপেক্ষা উত্তম, যদিও তাদেরকে তোমাদের কাছে ভালো লাগে। এবং তোমরা (নারীরা) কোন মুশরেকের সঙ্গে বিবাহ বন্ধনে আবদ্ধ হয়ো না, যে পর্যন্ত সে ঈমান না আনে। একজন মুসলমান ক্রীতদাসও একজন মুশরেকের তুলনায় অনেক ভাল, যদিও তোমরা তাদের দেখে মোহিত হও। তারা দোযখের দিকে আহ্বান করে, আর আল্লাহ নিজের হুকুমের মাধ্যমে আহ্বান করেন জান্নাত ও ক্ষমার দিকে। আর তিনি মানুষকে নিজের নির্দেশ বাতলে দেন যাতে তারা উপদেশ গ্রহণ করে।\qt@no{(221)}}
\qt@newcmd\qurantrans@bn@ccxxix{আর তোমার কাছে জিজ্ঞেস করে হায়েয (ঋতু) সম্পর্কে। বলে দাও, এটা অশুচি। কাজেই তোমরা হায়েয অবস্থায় স্ত্রীগমন থেকে বিরত থাক। তখন পর্যন্ত তাদের নিকটবর্তী হবে না, যতক্ষণ না তারা পবিত্র হয়ে যায়। যখন উত্তম রূপে পরিশুদ্ধ হয়ে যাবে, তখন গমন কর তাদের কাছে, যেভাবে আল্লাহ তোমাদেরকে হুকুম দিয়েছেন। নিশ্চয়ই আল্লাহ তওবাকারী এবং অপবিত্রতা থেকে যারা বেঁচে থাকে তাদেরকে পছন্দ করেন।\qt@no{(222)}}
\qt@newcmd\qurantrans@bn@ccxxx{তোমাদের স্ত্রীরা হলো তোমাদের জন্য শস্য ক্ষেত্র। তোমরা যেভাবে ইচ্ছা তাদেরকে ব্যবহার কর। আর নিজেদের জন্য আগামী দিনের ব্যবস্থা কর এবং আল্লাহকে ভয় করতে থাক। আর নিশ্চিতভাবে জেনে রাখ যে, আল্লাহর সাথে তোমাদেরকে সাক্ষাত করতেই হবে। আর যারা ঈমান এনেছে তাদেরকে সুসংবাদ জানিয়ে দাও।\qt@no{(223)}}
\qt@newcmd\qurantrans@bn@ccxxxi{আর নিজেদের শপথের জন্য আল্লাহর নামকে লক্ষ্যবস্তু বানিও না মানুষের সাথে কোন আচার আচরণ থেকে পরহেযগারী থেকে এবং মানুষের মাঝে মীমাংসা করে দেয়া থেকে বেঁচে থাকার উদ্দেশ্যে। আল্লাহ সবকিছুই শুনেন ও জানেন।\qt@no{(224)}}
\qt@newcmd\qurantrans@bn@ccxxxii{তোমাদের নিরর্থক শপথের জন্য আল্লাহ তোমাদেরকে ধরবেন না, কিন্তু সেসব কসমের ব্যাপারে ধরবেন, তোমাদের মন যার প্রতিজ্ঞা করেছে। আর আল্লাহ হচ্ছেন ক্ষমাকারী ধৈর্য্যশীল।\qt@no{(225)}}
\qt@newcmd\qurantrans@bn@ccxxxiii{যারা নিজেদের স্ত্রীদের নিকট গমন করবেনা বলে কসম খেয়ে বসে তাদের জন্য চার মাসের অবকাশ রয়েছে অতঃপর যদি পারস্পরিক মিল-মিশ করে নেয়, তবে আল্লাহ ক্ষামাকারী দয়ালু।\qt@no{(226)}}
\qt@newcmd\qurantrans@bn@ccxxxiv{আর যদি বর্জন করার সংকল্প করে নেয়, তাহলে নিশ্চয়ই আল্লাহ শ্রবণকারী ও জ্ঞানী।\qt@no{(227)}}
\qt@newcmd\qurantrans@bn@ccxxxv{আর তালাকপ্রাপ্তা নারী নিজেকে অপেক্ষায় রাখবে তিন হায়েয পর্যন্ত। আর যদি সে আল্লাহর প্রতি এবং আখেরাত দিবসের উপর ঈমানদার হয়ে থাকে, তাহলে আল্লাহ যা তার জরায়ুতে সৃষ্টি করেছেন তা লুকিয়ে রাখা জায়েজ নয়। আর যদি সদ্ভাব রেখে চলতে চায়, তাহলে তাদেরকে ফিরিয়ে নেবার অধিকার তাদের স্বামীরা সংরক্ষণ করে। আর পুরুষদের যেমন স্ত্রীদের উপর অধিকার রয়েছে, তেমনি ভাবে স্ত্রীদেরও অধিকার রয়েছে পুরুষদের উপর নিয়ম অনুযায়ী। আর নারীরদের ওপর পুরুষদের শ্রেষ্ঠত্ব রয়েছে। আর আল্লাহ হচ্ছে পরাক্রমশালী, বিজ্ঞ।\qt@no{(228)}}
\qt@newcmd\qurantrans@bn@ccxxxvi{তালাকে-‘রাজঈ’ হ’ল দুবার পর্যন্ত তারপর হয় নিয়মানুযায়ী রাখবে, না হয় সহৃদয়তার সঙ্গে বর্জন করবে। আর নিজের দেয়া সম্পদ থেকে কিছু ফিরিয়ে নেয়া তোমাদের জন্য জায়েয নয় তাদের কাছ থেকে। কিন্তু যে ক্ষেত্রে স্বামী ও স্ত্রী উভয়েই এ ব্যাপারে ভয় করে যে, তারা আল্লাহর নির্দেশ বজায় রাখতে পারবে না, অতঃপর যদি তোমাদের ভয় হয় যে, তারা উভয়েই আল্লাহর নির্দেশ বজায় রাখতে পারবে না, তাহলে সেক্ষেত্রে স্ত্রী যদি বিনিময় দিয়ে অব্যাহতি নিয়ে নেয়, তবে উভয়ের মধ্যে কারোরই কোন পাপ নেই। এই হলো আল্লাহ কর্তৃক নির্ধারিত সীমা। কাজেই একে অতিক্রম করো না। বস্তুতঃ যারা আল্লাহ কর্তৃক নির্ধারিত সীমা লঙ্ঘন করবে, তারাই জালেম।\qt@no{(229)}}
\qt@newcmd\qurantrans@bn@ccxxxvii{তারপর যদি সে স্ত্রীকে (তৃতীয়বার) তালাক দেয়া হয়, তবে সে স্ত্রী যে পর্যন্ত তাকে ছাড়া অপর কোন স্বামীর সাথে বিয়ে করে না নেবে, তার জন্য হালাল নয়। অতঃপর যদি দ্বিতীয় স্বামী তালাক দিয়ে দেয়, তাহলে তাদের উভয়ের জন্যই পরস্পরকে পুনরায় বিয়ে করাতে কোন পাপ নেই। যদি আল্লাহর হুকুম বজায় রাখার ইচ্ছা থাকে। আর এই হলো আল্লাহ কতৃꦣ2453; নির্ধারিত সীমা; যারা উপলব্ধি করে তাদের জন্য এসব বর্ণনা করা হয়।\qt@no{(230)}}
\qt@newcmd\qurantrans@bn@ccxxxviii{আর যখন তোমরা স্ত্রীদেরকে তালাক দিয়ে দাও, অতঃপর তারা নির্ধারিত ইদ্দত সমাপ্ত করে নেয়, তখন তোমরা নিয়ম অনুযায়ী তাদেরকে রেখে দাও অথবা সহানুভুতির সাথে তাদেরকে মুক্ত করে দাও। আর তোমরা তাদেরকে জ্বালাতন ও বাড়াবাড়ি করার উদ্দেশ্যে আটকে রেখো না। আর যারা এমন করবে, নিশ্চয়ই তারা নিজেদেরই ক্ষতি করবে। আর আল্লাহর নির্দেশকে হাস্যকর বিষয়ে পরিণত করো না। আল্লাহর সে অনুগ্রহের কথা স্মরণ কর, যা তোমাদের উপর রয়েছে এবং তাও স্মরণ কর, যে কিতাব ও জ্ঞানের কথা তোমাদের উপর নাযিল করা হয়েছে যার দ্বারা তোমাদেরকে উপদেশ দান করা হয়। আল্লাহকে ভয় কর এবং জেনে রাখ যে, আল্লাহ সর্ববিষয়েই জ্ঞানময়।\qt@no{(231)}}
\qt@newcmd\qurantrans@bn@ccxxxix{আর যখন তোমরা স্ত্রীদেরকে তালাক দিয়ে দাও এবং তারপর তারাও নির্ধারিত ইদ্দত পূর্ন করতে থাকে, তখন তাদেরকে পূর্ব স্বামীদের সাথে পারস্পরিক সম্মতির ভিত্তিতে নিয়মানুযায়ী বিয়ে করতে বাধাদান করো না। এ উপদেশ তাকেই দেয়া হচ্ছে, যে আল্লাহ ও কেয়ামত দিনের উপর বিশ্বাস স্থাপন করেছে। এর মধ্যে তোমাদের জন্য রয়েছে একান্ত পরিশুদ্ধতা ও অনেক পবিত্রতা। আর আল্লাহ জানেন, তোমরা জান না।\qt@no{(232)}}
\qt@newcmd\qurantrans@bn@ccxl{আর সন্তানবতী নারীরা তাদের সন্তানদেরকে পূর্ন দু’বছর দুধ খাওয়াবে, যদি দুধ খাওয়াবার পূর্ণ মেয়াদ সমাপ্ত করতে চায়। আর সন্তানের অধিকারী অর্থাৎ, পিতার উপর হলো সে সমস্ত নারীর খোর-পোষের দায়িত্ব প্রচলিত নিয়ম অনুযায়ী। কাউকে তার সামর্থাতিরিক্ত চাপের সম্মুখীন করা হয় না। আর মাকে তার সন্তানের জন্য ক্ষতিগ্রস্ত করা যাবে না। এবং যার সন্তান তাকেও তার সন্তানের কারণে ক্ষতির সম্মুখীন করা যাবে না। আর ওয়ারিসদের উপরও দায়িত্ব এই। তারপর যদি পিতা-মাতা ইচ্ছা করে, তাহলে দু’বছরের ভিতরেই নিজেদের পারস্পরিক পরামর্শক্রমে দুধ ছাড়িয়ে দিতে পারে, তাতে তাদের কোন পাপ নেই, আর যদি তোমরা কোন ধাত্রীর দ্বারা নিজের সন্তানদেরকে দুধ খাওয়াতে চাও, তাহলে যদি তোমরা সাব্যস্তকৃত প্রচলিত বিনিময় দিয়ে দাও তাতেও কোন পাপ নেই। আর আল্লাহকে ভয় কর এবং জেনে রেখো যে, আল্লাহ তোমাদের যাবতীয় কাজ অত্যন্ত ভাল করেই দেখেন।\qt@no{(233)}}
\qt@newcmd\qurantrans@bn@ccxli{আর তোমাদের মধ্যে যারা মৃত্যুবরণ করবে এবং নিজেদের স্ত্রীদেরকে ছেড়ে যাবে, তখন সে স্ত্রীদের কর্তব্য হলো নিজেকে চার মাস দশ দিন পর্যন্ত অপেক্ষা করিয়ে রাখা। তারপর যখন ইদ্দত পূর্ণ করে নেবে, তখন নিজের ব্যাপারে নীতি সঙ্গত ব্যবস্থা নিলে কোন পাপ নেই। আর তোমাদের যাবতীয় কাজের ব্যাপারেই আল্লাহর অবগতি রয়েছে।\qt@no{(234)}}
\qt@newcmd\qurantrans@bn@ccxlii{আর যদি তোমরা আকার ইঙ্গিতে সে নারীর বিয়ের পয়গাম দাও, কিংবা নিজেদের মনে গোপন রাখ, তবে তাতেও তোমাদের কোন পাপ নেই, আল্লাহ জানেন যে, তোমরা অবশ্যই সে নারীদের কথা উল্লেখ করবে। কিন্তু তাদের সাথে বিয়ে করার গোপন প্রতিশ্রুতি দিয়ে রেখো না। অবশ্য শরীয়তের নির্ধারিত প্রথা অনুযায়ী কোন কথা সাব্যস্ত করে নেবে। আর নির্ধারিত ইদ্দত সমাপ্তি পর্যায়ে না যাওয়া অবধি বিয়ে করার কোন ইচ্ছা করো না। আর একথা জেনে রেখো যে, তোমাদের মনে যে কথা রয়েছে, আল্লাহর তা জানা আছে। কাজেই তাঁকে ভয় করতে থাক। আর জেনে রেখো যে, আল্লাহ ক্ষমাকারী ও ধৈর্য্যশীল।\qt@no{(235)}}
\qt@newcmd\qurantrans@bn@ccxliii{স্ত্রীদেরকে স্পর্শ করার আগে এবং কোন মোহর সাব্যস্ত করার পূর্বেও যদি তালাক দিয়ে দাও, তবে তাতেও তোমাদের কোন পাপ নেই। তবে তাদেরকে কিছু খরচ দেবে। আর সামর্থ্যবানদের জন্য তাদের সামর্থ্য অনুযায়ী এবং কম সামর্থ্যবানদের জন্য তাদের সাধ্য অনুযায়ী। যে খরচ প্রচলিত রয়েছে তা সৎকর্মশীলদের উপর দায়িত্ব।\qt@no{(236)}}
\qt@newcmd\qurantrans@bn@ccxliv{আর যদি মোহর সাব্যস্ত করার পর স্পর্শ করার পূর্বে তালাক দিয়ে দাও, তাহলে যে, মোহর সাব্যস্ত করা হয়েছে তার অর্ধেক দিয়ে দিতে হবে। অবশ্য যদি নারীরা ক্ষমা করে দেয় কিংবা বিয়ের বন্ধন যার অধিকারে সে (অর্থাৎ, স্বামী) যদি ক্ষমা করে দেয় তবে তা স্বতন্ত্র কথা। আর তোমরা পুরুষরা যদি ক্ষমা কর, তবে তা হবে পরহেযগারীর নিকটবর্তী। আর পারস্পরিক সহানুভূতির কথা বিস্মৃত হয়ো না। নিশ্চয় তোমরা যা কিছু কর আল্লাহ সেসবই অত্যন্ত ভাল করে দেখেন।\qt@no{(237)}}
\qt@newcmd\qurantrans@bn@ccxlv{সমস্ত নামাযের প্রতি যত্নবান হও, বিশেষ করে মধ্যবর্তী নামাযের ব্যাপারে। আর আল্লাহর সামনে একান্ত আদবের সাথে দাঁড়াও।\qt@no{(238)}}
\qt@newcmd\qurantrans@bn@ccxlvi{অতঃপর যদি তোমাদের কারো ব্যাপারে ভয় থাকে, তাহলে পদচারী অবস্থাতেই পড়ে নাও অথবা সওয়ারীর উপরে। তারপর যখন তোমরা নিরাপত্তা পাবে, তখন আল্লাহকে স্মরণ কর, যেভাবে তোমাদের শেখানো হয়েছে, যা তোমরা ইতিপূর্বে জানতে না।\qt@no{(239)}}
\qt@newcmd\qurantrans@bn@ccxlvii{আর যখন তোমাদের মধ্যে যারা মৃত্যুবরণ করবে তখন স্ত্রীদের ঘর থেকে বের না করে এক বছর পর্যন্ত তাদের খরচের ব্যাপারে ওসিয়ত করে যাবে। অতঃপর যদি সে স্ত্রীরা নিজে থেকে বেরিয়ে যায়, তাহলে সে নারী যদি নিজের ব্যাপারে কোন উত্তম ব্যবস্থা করে, তবে তাতে তোমাদের উপর কোন পাপ নেই। আর আল্লাহ হচ্ছেন পরাক্রমশালী বিজ্ঞতা সম্পন্ন।\qt@no{(240)}}
\qt@newcmd\qurantrans@bn@ccxlviii{আর তালাকপ্রাপ্তা নারীদের জন্য প্রচলিত নিয়ম অনুযায়ী খরচ দেয়া পরহেযগারদের উপর কর্তব্য।\qt@no{(241)}}
\qt@newcmd\qurantrans@bn@ccxlix{এভাবেই আল্লাহ তা’আলা তোমাদের জন্য স্বীয় নির্দেশ বর্ণনা করেন যাতে তোমরা তা বুঝতে পার।\qt@no{(242)}}
\qt@newcmd\qurantrans@bn@ccl{তুমি কি তাদেরকে দেখনি, যারা মৃত্যুর ভয়ে নিজেদের ঘর ছেড়ে বেরিয়ে গিয়েছিলেন? অথচ তারা ছিল হাজার হাজার। তারপর আল্লাহ তাদেরকে বললেন মরে যাও। তারপর তাদেরকে জীবিত করে দিলেন। নিশ্চয়ই আল্লাহ মানুষের উপর অনুগ্রহকারী। কিন্তু অধিকাংশ লোক শুকরিয়া প্রকাশ করে না।\qt@no{(243)}}
\qt@newcmd\qurantrans@bn@ccli{আল্লাহর পথে লড়াই কর এবং জেনে রাখ, নিঃসন্দেহে আল্লাহ সবকিছু জানেন, সবকিছু শুনেন।\qt@no{(244)}}
\qt@newcmd\qurantrans@bn@cclii{এমন কে আছে যে, আল্লাহকে করজ দেবে, উত্তম করজ; অতঃপর আল্লাহ তাকে দ্বিগুণ-বহুগুণ বৃদ্ধি করে দিবেন। আল্লাহই সংকোচিত করেন এবং তিনিই প্রশস্ততা দান করেন এবং তাঁরই নিকট তোমরা সবাই ফিরে যাবে।\qt@no{(245)}}
\qt@newcmd\qurantrans@bn@ccliii{মূসার পরে তুমি কি বনী ইসরাঈলের একটি দলকে দেখনি, যখন তারা বলেছে নিজেদের নবীর কাছে যে, আমাদের জন্য একজন বাদশাহ নির্ধারিত করে দিন যাতে আমরা আল্লাহর পথে যুদ্ধ করতে পারি। নবী বললেন, তোমাদের প্রতিও কি এমন ধারণা করা যায় যে, লড়াইর হুকুম যদি হয়, তাহলে তখন তোমরা লড়বে না? তারা বলল, আমাদের কি হয়েছে যে, আমরা আল্লাহর পথে লড়াই করব না। অথচ আমরা বিতাড়িত হয়েছি নিজেদের ঘর-বাড়ী ও সন্তান-সন্ততি থেকে। অতঃপর যখন লড়াইয়ের নির্দেশ হলো, তখন সামান্য কয়েকজন ছাড়া তাদের সবাই ঘুরে দাঁড়ালো। আর আল্লাহ তা’আলা জালেমদের ভাল করেই জানেন।\qt@no{(246)}}
\qt@newcmd\qurantrans@bn@ccliv{আর তাদেরকে তাদের নবী বললেন, নিশ্চয়ই আল্লাহ তালূতকে তোমাদের জন্য বাদশাহ সাব্যস্ত করেছেন। তারা বলতে লাগল তা কেমন করে হয় যে, তার শাসন চলবে আমাদের উপর। অথচ রাষ্ট্রক্ষমতা পাওয়ার ক্ষেত্রে তার চেয়ে আমাদেরই অধিকার বেশী। আর সে সম্পদের দিক দিয়েও সচ্ছল নয়। নবী বললেন, নিশ্চয় আল্লাহ তোমাদের উপর তাকে পছন্দ করেছেন এবং স্বাস্থ্য ও জ্ঞানের দিক দিয়ে প্রাচুর্য দান করেছেন। বস্তুতঃ আল্লাহ তাকেই রাজ্য দান করেন, যাকে ইচ্ছা। আর আল্লাহ হলেন অনুগ্রহ দানকারী এবং সব বিষয়ে অবগত।\qt@no{(247)}}
\qt@newcmd\qurantrans@bn@cclv{বনী-ইসরাঈলদেরকে তাদের নবী আরো বললেন, তালূতের নেতৃত্বের চিহ্ন হলো এই যে, তোমাদের কাছে একটা সিন্দুক আসবে তোমাদের পালকর্তার পক্ষ থেকে তোমাদের মনের সন্তুষ্টির নিমিত্তে। আর তাতে থাকবে মূসা, হারুন এবং তাঁদের সন্তানবর্গের পরিত্যক্ত কিছু সামগ্রী। সিন্দুকটিকে বয়ে আনবে ফেরেশতারা। তোমরা যদি ঈমানদার হয়ে থাক, তাহলে এতে তোমাদের জন্য নিশ্চিতই পরিপূর্ণ নিদর্শন রয়েছে।\qt@no{(248)}}
\qt@newcmd\qurantrans@bn@cclvi{অতঃপর তালূত যখন সৈন্য-সামন্ত নিয়ে বেরুল, তখন বলল, নিশ্চয় আল্লাহ তোমাদিগকে পরীক্ষা করবেন একটি নদীর মাধ্যমে। সুতরাং যে লোক সেই নদীর পানি পান করবে সে আমার নয়। আর যে, লোক তার স্বাদ গ্রহণ করলো না, নিশ্চয়ই সে আমার লোক। কিন্তু যে লোক হাতের আঁজলা ভরে সামান্য খেয়ে নেবে তার দোষঅবশ্য তেমন গুরুতর হবে না। অতঃপর সবাই পান করল সে পানি, সামান্য কয়েকজন ছাড়া। পরে তালূত যখন তা পার হলো এবং তার সাথে ছিল মাত্র কয়েকজন ঈমানদার, তখন তারা বলতে লাগল, আজকের দিনে জালূত এবং তার সেনাবাহিনীর সাথে যুদ্ধ করার শক্তি আমাদের নেই, যাদের ধারণা ছিল যে, আল্লাহর সামনে তাদের একদিন উপস্থিত হতে হবে, তারা বার বার বলতে লাগল, সামান্য দলই বিরাট দলের মোকাবেলায় জয়ী হয়েছে আল্লাহর হুকুমে। আর যারা ধৈর্য্যশীল আল্লাহ তাদের সাথে রয়েছেন।\qt@no{(249)}}
\qt@newcmd\qurantrans@bn@cclvii{আর যখন তালূত ও তার সেনাবাহিনী শত্রুর সম্মুখীন হল, তখন বলল, হে আমাদের পালনকর্তা, আমাদের মনে ধৈর্য্য সৃষ্টি করে দাও এবং আমাদেরকে দৃঢ়পদ রাখ-আর আমাদের সাহায্য কর সে কাফের জাতির বিরুদ্ধে।\qt@no{(250)}}
\qt@newcmd\qurantrans@bn@cclviii{তারপর ঈমানদাররা আল্লাহর হুকুমে জালূতের বাহিনীকে পরাজিত করে দিল এবং দাউদ জালূতকে হত্যা করল। আর আল্লাহ দাউদকে দান করলেন রাজ্য ও অভিজ্ঞতা। আর তাকে যা চাইলেন শিখালেন। আল্লাহ যদি একজনকে অপরজনের দ্বারা প্রতিহত না করতেন, তাহলে গোটা দুনিয়া বিধ্বস্ত হয়ে যেতো। কিন্তু বিশ্ববাসীর প্রতি আল্লাহ একান্তই দয়ালু, করুণাময়।\qt@no{(251)}}
\qt@newcmd\qurantrans@bn@cclix{এগুলো হলো আল্লাহর নিদর্শন, যা আমরা তোমাদেরকে যথাযথভাবে শুনিয়ে থাকি। আর আপনি নিশ্চিতই আমার রসূলগণের অন্তর্ভুক্ত।\qt@no{(252)}}
\qt@newcmd\qurantrans@bn@cclx{এই রসূলগণ-আমি তাদের কাউকে কারো উপর মর্যাদা দিয়েছি। তাদের মধ্যে কেউ তো হলো তারা যার সাথে আল্লাহ কথা বলেছেন, আর কারও মর্যাদা উচ্চতর করেছেন এবং আমি মরিয়ম তনয় ঈসাকে প্রকৃষ্ট মু’জেযা দান করেছি এবং তাকে শক্তি দান করেছি ‘রুহূল কুদ্দুস’ অর্থৎ জিবরাঈলের মাধ্যমে। আর আল্লাহ যদি ইচ্ছা করতেন, তাহলে পরিস্কার নির্দেশ এসে যাবার পর পয়গম্বরদের পেছনে যারা ছিল তারা লড়াই করতো না। কিন্তু তাদের মধ্যে মতবিরোধ সৃষ্টি হয়ে গেছে। অতঃপর তাদের কেউ তো ঈমান এনেছে, আর কেউ হয়েছে কাফের। আর আল্লাহ যদি ইচ্ছা করতেন, তাহলে তারা পরস্পর লড়াই করতো, কিন্তু আল্লাহ তাই করেন, যা তিনি ইচ্ছা করেন।\qt@no{(253)}}
\qt@newcmd\qurantrans@bn@cclxi{হে ঈমানদারগণ! আমি তোমাদেরকে যে রুযী দিয়েছি, সেদিন আসার পূর্বেই তোমরা তা থেকে ব্যয় কর, যাতে না আছে বেচা-কেনা, না আছে সুপারিশ কিংবা বন্ধুত্ব। আর কাফেররাই হলো প্রকৃত যালেম।\qt@no{(254)}}
\qt@newcmd\qurantrans@bn@cclxii{আল্লাহ ছাড়া অন্য কোন উপাস্য নেই, তিনি জীবিত, সবকিছুর ধারক। তাঁকে তন্দ্রাও স্পর্শ করতে পারে না এবং নিদ্রাও নয়। আসমান ও যমীনে যা কিছু রয়েছে, সবই তাঁর। কে আছ এমন, যে সুপারিশ করবে তাঁর কাছে তাঁর অনুমতি ছাড়া? দৃষ্টির সামনে কিংবা পিছনে যা কিছু রয়েছে সে সবই তিনি জানেন। তাঁর জ্ঞানসীমা থেকে তারা কোন কিছুকেই পরিবেষ্টিত করতে পারে না, কিন্তু যতটুকু তিনি ইচ্ছা করেন। তাঁর সিংহাসন সমস্ত আসমান ও যমীনকে পরিবেষ্টিত করে আছে। আর সেগুলোকে ধারণ করা তাঁর পক্ষে কঠিন নয়। তিনিই সর্বোচ্চ এবং সর্বাপেক্ষা মহান।\qt@no{(255)}}
\qt@newcmd\qurantrans@bn@cclxiii{দ্বীনের ব্যাপারে কোন জবরদস্তি বা বাধ্য-বাধকতা নেই। নিঃসন্দেহে হেদায়াত গোমরাহী থেকে পৃথক হয়ে গেছে। এখন যারা গোমরাহকারী ‘তাগুত’দেরকে মানবে না এবং আল্লাহতে বিশ্বাস স্থাপন করবে, সে ধারণ করে নিয়েছে সুদৃঢ় হাতল যা ভাংবার নয়। আর আল্লাহ সবই শুনেন এবং জানেন।\qt@no{(256)}}
\qt@newcmd\qurantrans@bn@cclxiv{যারা ঈমান এনেছে, আল্লাহ তাদের অভিভাবক। তাদেরকে তিনি বের করে আনেন অন্ধকার থেকে আলোর দিকে। আর যারা কুফরী করে তাদের অভিভাবক হচ্ছে তাগুত। তারা তাদেরকে আলো থেকে বের করে অন্ধকারের দিকে নিয়ে যায়। এরাই হলো দোযখের অধিবাসী, চিরকাল তারা সেখানেই থাকবে।\qt@no{(257)}}
\qt@newcmd\qurantrans@bn@cclxv{তুমি কি সে লোককে দেখনি, যে পালনকর্তার ব্যাপারে বাদানুবাদ করেছিল ইব্রাহীমের সাথে এ কারণে যে, আল্লাহ সে ব্যাক্তিকে রাজ্য দান করেছিলেন? ইব্রাহীম যখন বললেন, আমার পালনকর্তা হলেন তিনি, যিনি জীবন দান করেন এবং মৃত্যু ঘটান। সে বলল, আমি জীবন দান করি এবং মৃত্যু ঘটিয়ে থাকি। ইব্রাহীম বললেন, নিশ্চয়ই তিনি সুর্যকে উদিত করেন পূর্ব দিক থেকে এবার তুমি তাকে পশ্চিম দিক থেকে উদিত কর। তখন সে কাফের হতভম্ব হয়ে গেল। আর আল্লাহ সীমালংঘণকারী সম্প্রদায়কে সরল পথ প্রদর্শন করেন না।\qt@no{(258)}}
\qt@newcmd\qurantrans@bn@cclxvi{তুমি কি সে লোককে দেখনি যে এমন এক জনপদ দিয়ে যাচ্ছিল যার বাড়ীঘরগুলো ভেঙ্গে ছাদের উপর পড়ে ছিল? বলল, কেমন করে আল্লাহ মরনের পর একে জীবিত করবেন? অতঃপর আল্লাহ তাকে মৃত অবস্থায় রাখলেন একশ বছর। তারপর তাকে উঠালেন। বললেন, কত কাল এভাবে ছিলে? বলল আমি ছিলাম, একদিন কংবা একদিনের কিছু কম সময়। বললেন, তা নয়; বরং তুমি তো একশ বছর ছিলে। এবার চেয়ে দেখ নিজের খাবার ও পানীয়ের দিকে-সেগুলো পচে যায় নি এবং দেখ নিজের গাধাটির দিকে। আর আমি তোমাকে মানুষের জন্য দৃষ্টান্ত বানাতে চেয়েছি। আর হাড়গুলোর দিকে চেয়ে দেখ যে, আমি এগুলোকে কেমন করে জুড়ে দেই এবং সেগুলোর উপর মাংসের আবরণ পরিয়ে দেই। অতঃপর যখন তার উপর এ অবস্থা প্রকাশিত হল, তখন বলে উঠল-আমি জানি, নিঃসন্দেহে আল্লাহ সর্ব বিষয়ে ক্ষমতাশীল।\qt@no{(259)}}
\qt@newcmd\qurantrans@bn@cclxvii{আর স্মরণ কর, যখন ইব্রাহীম বলল, হে আমার পালনকর্তা আমাকে দেখাও, কেমন করে তুমি মৃতকে জীবিত করবে। বললেন; তুমি কি বিশ্বাস কর না? বলল, অবশ্যই বিশ্বাস করি, কিন্তু দেখতে এজন্যে চাইছি যাতে অন্তরে প্রশান্তি লাভ করতে পারি। বললেন, তাহলে চারটি পাখী ধরে নাও। পরে সেগুলোকে নিজের পোষ মানিয়ে নাও, অতঃপর সেগুলোর দেহের একেকটি অংশ বিভিন্ন পাহাড়ের উপর রেখে দাও। তারপর সেগুলোকে ডাক; তোমার নিকট দৌড়ে চলে আসবে। আর জেনে রাখো, নিশ্চয়ই আল্লাহ পরাক্রমশালী, অতি জ্ঞান সম্পন্ন।\qt@no{(260)}}
\qt@newcmd\qurantrans@bn@cclxviii{যারা আল্লাহর রাস্তায় স্বীয় ধন সম্পদ ব্যয় করে, তাদের উদাহরণ একটি বীজের মত, যা থেকে সাতটি শীষ জন্মায়। প্রত্যেকটি শীষে একশ করে দানা থাকে। আল্লাহ অতি দানশীল, সর্বজ্ঞ।\qt@no{(261)}}
\qt@newcmd\qurantrans@bn@cclxix{যারা স্বীয় ধন সম্পদ আল্লাহর রাস্তায় ব্যয় করে, এরপর ব্যয় করার পর সে অনুগ্রহের কথা প্রকাশ করে না এবং কষ্টও দেয় না, তাদেরই জন্যে তাদের পালনকর্তার কাছে রয়েছে পুরস্কার এবং তাদের কোন আশংকা নেই, তারা চিন্তিতও হবে না।\qt@no{(262)}}
\qt@newcmd\qurantrans@bn@cclxx{নম্র কথা বলে দেয়া এবং ক্ষমা প্রদর্শন করা ঐ দান খয়রাত অপেক্ষা উত্তম, যার পরে কষ্ট দেয়া হয়। আল্লাহ তা’আলা সম্পদশালী, সহিঞ্চু।\qt@no{(263)}}
\qt@newcmd\qurantrans@bn@cclxxi{হে ঈমানদারগণ!তোমরা অনুগ্রহের কথা প্রকাশ করে এবং কষ্ট দিয়ে নিজেদের দান খয়রাত বরবাদ করো না সে ব্যক্তির মত যে নিজের ধন-সম্পদ লোক দেখানোর উদ্দেশ্যে ব্যয় করে এবং আল্লাহ ও পরকালের প্রতি বিশ্বাস রাখে না। অতএব, এ ব্যাক্তির দৃষ্টান্ত একটি মসৃণ পাথরের মত যার উপর কিছু মাটি পড়েছিল। অতঃপর এর উপর প্রবল বৃষ্টি বর্ষিত হলো, অনন্তর তাকে সম্পূর্ণ পরিষ্কার করে দিল। তারা ঐ বস্তুর কোন সওয়াব পায় না, যা তারা উপার্জন করেছে। আল্লাহ কাফের সম্প্রদায়কে পথ প্রদর্শন করেন না।\qt@no{(264)}}
\qt@newcmd\qurantrans@bn@cclxxii{যারা আল্লাহর রাস্তায় স্বীয় ধন-সম্পদ ব্যয় করে আল্লাহর সন্তুষ্টি অর্জনের লক্ষ্যে এবং নিজের মনকে সুদৃঢ় করার জন্যে তাদের উদাহরণ টিলায় অবস্থিত বাগানের মত, যাতে প্রবল বৃষ্টিপাত হয়; অতঃপর দ্বিগুণ ফসল দান করে। যদি এমন প্রবল বৃষ্টিপাত নাও হয়, তবে হাল্কা বর্ষণই যথেষ্ট। আল্লাহ তোমাদের কাজকর্ম যথার্থই প্রত্যক্ষ করেন।\qt@no{(265)}}
\qt@newcmd\qurantrans@bn@cclxxiii{তোমাদের কেউ পছন্দ করে যে, তার একটি খেজুর ও আঙ্গুরের বাগান হবে, এর তলদেশ দিয়ে নহর প্রবাহিত হবে, আর এতে সর্বপ্রকার ফল-ফসল থাকবে এবং সে বার্ধক্যে পৌছবে, তার দুর্বল সন্তান সন্ততিও থাকবে, এমতাবস্থায় এ বাগানের একটি ঘূর্ণিবায়ু আসবে, যাতে আগুন রয়েছে, অনন্তর বাগানটি ভষ্মীভূত হয়ে যাবে? এমনিভাবে আল্লাহ তা’আলা তোমাদের জন্যে নিদর্শনসমূহ বর্ননা করেন-যাতে তোমরা চিন্তা-ভাবনা কর।\qt@no{(266)}}
\qt@newcmd\qurantrans@bn@cclxxiv{হে ঈমানদারগণ! তোমরা স্বীয় উপার্জন থেকে এবং যা আমি তোমাদের জন্যে ভূমি থেকে উৎপন্ন করেছি, তা থেকে উৎকৃষ্ট বস্তু ব্যয় কর এবং তা থেকে নিকৃষ্ট জিনিস ব্যয় করতে মনস্থ করো না। কেননা, তা তোমরা কখনও গ্রহণ করবে না; তবে যদি তোমরা চোখ বন্ধ করে নিয়ে নাও। জেনে রেখো, আল্লাহ অভাব মুক্ত, প্রশংসিত।\qt@no{(267)}}
\qt@newcmd\qurantrans@bn@cclxxv{শয়তান তোমাদেরকে অভাব অনটনের ভীতি প্রদর্শন করে এবং অশ্লীলতার আদেশ দেয়। পক্ষান্তরে আল্লাহ তোমাদেরকে নিজের পক্ষ থেকে ক্ষমা ও বেশী অনুগ্রহের ওয়াদা করেন। আল্লাহ প্রাচুর্যময়, সুবিজ্ঞ।\qt@no{(268)}}
\qt@newcmd\qurantrans@bn@cclxxvi{তিনি যাকে ইচ্ছা বিশেষ জ্ঞান দান করেন এবং যাকে বিশেষ জ্ঞান দান করা হয়, সে প্রভুত কল্যাণকর বস্তু প্রাপ্ত হয়। উপদেশ তারাই গ্রহণ করে, যারা জ্ঞানবান।\qt@no{(269)}}
\qt@newcmd\qurantrans@bn@cclxxvii{তোমরা যে খয়রাত বা সদ্ব্যয় কর কিংবা কোন মানত কর, আল্লাহ নিশ্চয়ই সেসব কিছুই জানেন। অন্যায়কারীদের কোন সাহায্যকারী নেই।\qt@no{(270)}}
\qt@newcmd\qurantrans@bn@cclxxviii{যদি তোমরা প্রকাশ্যে দান-খয়রাত কর, তবে তা কতইনা উত্তম। আর যদি খয়রাত গোপনে কর এবং অভাবগ্রস্তদের দিয়ে দাও, তবে তা তোমাদের জন্যে আরও উত্তম। আল্লাহ তা’আলা তোমাদের কিছু গোনাহ দূর করে দিবেন। আল্লাহ তোমাদের কাজ কর্মের খুব খবর রাখেন।\qt@no{(271)}}
\qt@newcmd\qurantrans@bn@cclxxix{তাদেরকে সৎপথে আনার দায় তোমার নয়। বরং আল্লাহ যাকে ইচ্ছা সৎপথে পরিচালিত করেন। যে মাল তোমরা ব্যয় কর, তা নিজ উপাকারার্থেই কর। আল্লাহর সন্তুষ্টি ছাড়া অন্য কোন উদ্দেশ্যে ব্যয় করো না। তোমরা যে, অর্থ ব্যয় করবে, তার পুরস্কার পুরোপুরি পেয়ে যাবে এবং তোমাদের প্রতি অন্যায় করা হবে না।\qt@no{(272)}}
\qt@newcmd\qurantrans@bn@cclxxx{খয়রাত ঐ সকল গরীব লোকের জন্যে যারা আল্লাহর পথে আবদ্ধ হয়ে গেছে-জীবিকার সন্ধানে অন্যত্র ঘোরাফেরা করতে সক্ষম নয়। অজ্ঞ লোকেরা যাঞ্চা না করার কারণে তাদেরকে অভাবমুক্ত মনে করে। তোমরা তাদেরকে তাদের লক্ষণ দ্বারা চিনবে। তারা মানুষের কাছে কাকুতি-মিনতি করে ভিক্ষা চায় না। তোমরা যে অর্থ ব্যয় করবে, তা আল্লাহ তা’আলা অবশ্যই পরিজ্ঞাত।\qt@no{(273)}}
\qt@newcmd\qurantrans@bn@cclxxxi{যারা স্বীয় ধন-সম্পদ ব্যয় করে, রাত্রে ও দিনে, গোপনে ও প্রকাশ্যে। তাদের জন্যে তাদের সওয়াব রয়েছে তাদের পালনকর্তার কাছে। তাদের কোন আশংঙ্কা নেই এবং তারা চিন্তিত ও হবে না।\qt@no{(274)}}
\qt@newcmd\qurantrans@bn@cclxxxii{যারা সুদ খায়, তারা কিয়ামতে দন্ডায়মান হবে, যেভাবে দন্ডায়মান হয় ঐ ব্যক্তি, যাকে শয়তান আসর করে মোহাবিষ্ট করে দেয়। তাদের এ অবস্থার কারণ এই যে, তারা বলেছেঃ ক্রয়-বিক্রয় ও তো সুদ নেয়ারই মত! অথচ আল্লা’হ তা’আলা ক্রয়-বিক্রয় বৈধ করেছেন এবং সুদ হারাম করেছেন। অতঃপর যার কাছে তার পালনকর্তার পক্ষ থেকে উপদেশ এসেছে এবং সে বিরত হয়েছে, পূর্বে যা হয়ে গেছে, তা তার। তার ব্যাপার আল্লাহর উপর নির্ভরশীল। আর যারা পুনরায় সুদ নেয়, তারাই দোযখে যাবে। তারা সেখানে চিরকাল অবস্থান করবে।\qt@no{(275)}}
\qt@newcmd\qurantrans@bn@cclxxxiii{আল্লাহ তা’আলা সুদকে নিশ্চিহ্ন করেন এবং দান খয়রাতকে বর্ধিত করেন। আল্লাহ পছন্দ করেন না কোন অবিশ্বাসী পাপীকে।\qt@no{(276)}}
\qt@newcmd\qurantrans@bn@cclxxxiv{নিশ্চয়ই যারা বিশ্বাস স্থাপন করেছে, সৎকাজ করেছে, নামায প্রতিষ্ঠিত করেছে এবং যাকাত দান করেছে, তাদের জন্যে তাদের পুরষ্কার তাদের পালনকর্তার কছে রয়েছে। তাদের কোন শঙ্কা নেই এবং তারা দুঃখিত হবে না।\qt@no{(277)}}
\qt@newcmd\qurantrans@bn@cclxxxv{হে ঈমানদারগণ, তোমরা আল্লাহকে ভয় কর এবং সুদের যে সমস্ত বকেয়া আছে, তা পরিত্যাগ কর, যদি তোমরা ঈমানদার হয়ে থাক।\qt@no{(278)}}
\qt@newcmd\qurantrans@bn@cclxxxvi{অতঃপর যদি তোমরা পরিত্যাগ না কর, তবে আল্লাহ ও তাঁর রসূলের সাথে যুদ্ধ করতে প্রস্তুত হয়ে যাও। কিন্তু যদি তোমরা তওবা কর, তবে তোমরা নিজের মূলধন পেয়ে যাবে। তোমরা কারও প্রতি অত্যাচার করো না এবং কেউ তোমাদের প্রতি অত্যাচার করবে না।\qt@no{(279)}}
\qt@newcmd\qurantrans@bn@cclxxxvii{যদি খাতক অভাবগ্রস্থ হয়, তবে তাকে সচ্ছলতা আসা পর্যন্ত সময় দেয়া উচিত। আর যদি ক্ষমা করে দাও, তবে তা খুবই উত্তম যদি তোমরা উপলব্ধি কর।\qt@no{(280)}}
\qt@newcmd\qurantrans@bn@cclxxxviii{ঐ দিনকে ভয় কর, যে দিন তোমরা আল্লাহর কাছে প্রত্যাবর্তিত হবে। অতঃপর প্রত্যেকেই তার কর্মের ফল পুরোপুরি পাবে এবং তাদের প্রতি কোন রূপ অবিচার করা হবে না।\qt@no{(281)}}
\qt@newcmd\qurantrans@bn@cclxxxix{হে মুমিনগণ! যখন তোমরা কোন নির্দিষ্ট সময়ের জন্যে ঋনের আদান-প্রদান কর, তখন তা লিপিবদ্ধ করে নাও এবং তোমাদের মধ্যে কোন লেখক ন্যায়সঙ্গতভাবে তা লিখে দেবে; লেখক লিখতে অস্বীকার করবে না। আল্লাহ তাকে যেমন শিক্ষা দিয়েছেন, তার উচিত তা লিখে দেয়া। এবং ঋন গ্রহীতা যেন লেখার বিষয় বলে দেয় এবং সে যেন স্বীয় পালনকর্তা আল্লাহকে ভয় করে এবং লেখার মধ্যে বিন্দুমাত্রও বেশ কম না করে। অতঃপর ঋণগ্রহীতা যদি নির্বোধ হয় কিংবা দূর্বল হয় অথবা নিজে লেখার বিষয়বস্তু বলে দিতে অক্ষম হয়, তবে তার অভিভাবক ন্যায়সঙ্গতভাবে লিখাবে। দুজন সাক্ষী কর, তোমাদের পুরুষদের মধ্যে থেকে। যদি দুজন পুরুষ না হয়, তবে একজন পুরুষ ও দুজন মহিলা। ঐ সাক্ষীদের মধ্য থেকে যাদেরকে তোমরা পছন্দ কর যাতে একজন যদি ভুলে যায়, তবে একজন অন্যজনকে স্মরণ করিয়ে দেয়। যখন ডাকা হয়, তখন সাক্ষীদের অস্বীকার করা উচিত নয়। তোমরা এটা লিখতে অলসতা করোনা, তা ছোট হোক কিংবা বড়, নির্দিষ্ট সময় পর্যন্ত। এ লিপিবদ্ধ করণ আল্লাহর কাছে সুবিচারকে অধিক কায়েম রাখে, সাক্ষ্যকে অধিক সুসংহত রাখে এবং তোমাদের সন্দেহে পতিত না হওয়ার পক্ষে অধিক উপযুক্ত। কিন্তু যদি কারবার নগদ হয়, পরস্পর হাতে হাতে আদান-প্রদান কর, তবে তা না লিখলে তোমাদের প্রতি কোন অভিযোগ নেই। তোমরা ক্রয়-বিক্রয়ের সময় সাক্ষী রাখ। কোন লেখক ও সাক্ষীকে ক্ষতিগ্রস্ত করো না। যদি তোমরা এরূপ কর, তবে তা তোমাদের পক্ষে পাপের বিষয়। আল্লাহকে ভয় কর তিনি তোমাদেরকে শিক্ষা দেন। আল্লাহ সব কিছু জানেন।\qt@no{(282)}}
\qt@newcmd\qurantrans@bn@ccxc{আর তোমরা যদি প্রবাসে থাক এবং কোন লেখক না পাও তবে বন্ধকী বন্তু হস্তগত রাখা উচিত। যদি একে অন্যকে বিশ্বাস করে, তবে যাকে বিশ্বাস করা হয়, তার উচিত অন্যের প্রাপ্য পরিশোধ করা এবং স্বীয় পালনকর্তা আল্লাহকে ভয় কর! তোমরা সাক্ষ্য গোপন করো না। যে কেউ তা গোপন করবে, তার অন্তর পাপপূর্ণ হবে। তোমরা যা করা, আল্লাহ সে সম্পর্কে খুব জ্ঞাত।\qt@no{(283)}}
\qt@newcmd\qurantrans@bn@ccxci{যা কিছু আকাশসমূহে রয়েছে এবং যা কিছু যমীনে আছে, সব আল্লাহরই। যদি তোমরা মনের কথা প্রকাশ কর কিংবা গোপন কর, আল্লাহ তোমাদের কাছ থেকে তার হিসাব নেবেন। অতঃপর যাকে ইচ্ছা তিনি ক্ষমা করবেন এবং যাকে ইচ্ছা তিনি শাস্তি দেবেন। আল্লাহ সর্ববিষয়ে শক্তিমান।\qt@no{(284)}}
\qt@newcmd\qurantrans@bn@ccxcii{রসূল বিশ্বাস রাখেন ঐ সমস্ত বিষয় সম্পর্কে যা তাঁর পালনকর্তার পক্ষ থেকে তাঁর কাছে অবতীর্ণ হয়েছে এবং মুসলমানরাও সবাই বিশ্বাস রাখে আল্লাহর প্রতি, তাঁর ফেরেশতাদের প্রতি, তাঁর গ্রন্থসমুহের প্রতি এবং তাঁর পয়গম্বরগণের প্রতি। তারা বলে আমরা তাঁর পয়গম্বরদের মধ্যে কোন তারতম্য করিনা। তারা বলে, আমরা শুনেছি এবং কবুল করেছি। আমরা তোমার ক্ষমা চাই, হে আমাদের পালনকর্তা। তোমারই দিকে প্রত্যাবর্তন করতে হবে।\qt@no{(285)}}
\qt@newcmd\qurantrans@bn@ccxciii{আল্লাহ কাউকে তার সাধ্যাতীত কোন কাজের ভার দেন না, সে তাই পায় যা সে উপার্জন করে এবং তাই তার উপর বর্তায় যা সে করে। হে আমাদের পালনকর্তা, যদি আমরা ভুলে যাই কিংবা ভুল করি, তবে আমাদেরকে অপরাধী করো না। হে আমাদের পালনকর্তা! এবং আমাদের উপর এমন দায়িত্ব অর্পণ করো না, যেমন আমাদের পূর্ববর্তীদের উপর অর্পণ করেছ, হে আমাদের প্রভূ! এবং আমাদের দ্বারা ঐ বোঝা বহন করিও না, যা বহন করার শক্তি আমাদের নাই। আমাদের পাপ মোচন কর। আমাদেরকে ক্ষমা কর এবং আমাদের প্রতি দয়া কর। তুমিই আমাদের প্রভু। সুতরাং কাফের সম্প্রদায়ের বিরুদ্ধে আমাদের কে সাহায্যে কর।\qt@no{(286)}}
\qt@newcmd\qurantrans@bn@ccxciv{\basmalahbn আলিফ লাম মীম।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@ccxcv{আল্লাহ ছাড়া কোন উপাস্য নেই, তিনি চিরঞ্জীব, সবকিছুর ধারক।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@ccxcvi{তিনি আপনার প্রতি কিতাব নাযিল করেছেন সত্যতার সাথে; যা সত্যায়ন করে পূর্ববর্তী কিতাবসমুহের।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@ccxcvii{নাযিল করেছেন তাওরত ও ইঞ্জিল, এ কিতাবের পূর্বে, মানুষের হেদায়েতের জন্যে এবং অবতীর্ণ করেছেন মীমাংসা। নিঃসন্দেহে যারা আল্লাহর আয়াতসমূহ অস্বীকার করে, তাদের জন্যে রয়েছে কঠিন আযাব। আর আল্লাহ হচ্ছেন পরাক্রমশীল, প্রতিশোধ গ্রহণকারী।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@ccxcviii{আল্লাহর নিকট আসমান ও যমীনের কোন বিষয়ই গোপন নেই।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@ccxcix{তিনিই সেই আল্লাহ, যিনি তোমাদের আকৃতি গঠন করেন মায়ের গর্ভে, যেমন তিনি চেয়েছেন। তিনি ছাড়া আর কোন উপাস্য নেই। তিনি প্রবল পরাক্রমশীল, প্রজ্ঞাময়।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@ccc{তিনিই আপনার প্রতি কিতাব নাযিল করেছেন। তাতে কিছু আয়াত রয়েছে সুস্পষ্ট, সেগুলোই কিতাবের আসল অংশ। আর অন্যগুলো রূপক। সুতরাং যাদের অন্তরে কুটিলতা রয়েছে, তারা অনুসরণ করে ফিৎনা বিস্তার এবং অপব্যাখ্যার উদ্দেশে তন্মধ্যেকার রূপকগুলোর। আর সেগুলোর ব্যাখ্যা আল্লাহ ব্যতীত কেউ জানে না। আর যারা জ্ঞানে সুগভীর, তারা বলেনঃ আমরা এর প্রতি ঈমান এনেছি। এই সবই আমাদের পালনকর্তার পক্ষ থেকে অবতীর্ণ হয়েছে। আর বোধশক্তি সম্পন্নেরা ছাড়া অপর কেউ শিক্ষা গ্রহণ করে না।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@ccci{হে আমাদের পালনকর্তা! সরল পথ প্রদর্শনের পর তুমি আমাদের অন্তরকে সত্যলংঘনে প্রবৃত্ত করোনা এবং তোমার নিকট থেকে আমাদিগকে অনুগ্রহ দান কর। তুমিই সব কিছুর দাতা।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@cccii{হে আমাদের পালনকর্তা! তুমি মানুষকে একদিন অবশ্যই একত্রিত করবেঃ এতে কোনই সন্দেহ নেই। নিশ্চয় আল্লাহ তাঁর ওয়াদার অন্যথা করেন না।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@ccciii{যারা কুফুরী করে, তাদের ধন-সম্পদ ও সন্তান-সন্ততি আল্লাহর সামনে কখনও কাজে আসবে না। আর তারাই হচ্ছে দোযখের ইন্ধন।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@ccciv{ফেরআউনের সম্প্রদায় এবং তাদের পূর্ববর্তীদের ধারা অনুযায়ীই তারা আমার আয়াতসমূহকে মিথ্যা প্রতিপন্ন করেছে। ফলে তাদের পাপের কারণে আল্লাহ তাদেরকে পাকড়াও করেছেন আর আল্লাহর আযাব অতি কঠিন।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@cccv{কাফেরদিগকে বলে দিন, খুব শিগগীরই তোমরা পরাভূত হয়ে দোযখের দিকে হাঁকিয়ে নীত হবে-সেটা কতই না নিকৃষ্টতম অবস্থান।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@cccvi{নিশ্চয়ই দুটো দলের মোকাবিলার মধ্যে তোমাদের জন্য নিদর্শন ছিল। একটি দল আল্লাহর রাহে যুদ্ধ করে। আর অপর দল ছিল কাফেরদের এরা স্বচক্ষে তাদেরকে দ্বিগুন দেখছিল। আর আল্লাহ যাকে নিজের সাহায্যের মাধ্যমে শক্তি দান করেন। এরই মধ্যে শিক্ষনীয় রয়েছে দৃষ্টি সম্পন্নদের জন্য।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@cccvii{মানবকূলকে মোহগ্রস্ত করেছে নারী, সন্তান-সন্ততি, রাশিকৃত স্বর্ণ-রৌপ্য, চিহ্নিত অশ্ব, গবাদি পশুরাজি এবং ক্ষেত-খামারের মত আকর্ষণীয় বস্তুসামগ্রী। এসবই হচ্ছে পার্থিব জীবনের ভোগ্য বস্তু। আল্লাহর নিকটই হলো উত্তম আশ্রয়।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@cccviii{বলুন, আমি কি তোমাদেরকে এসবের চাইতেও উত্তম বিষয়ের সন্ধান বলবো?-যারা পরহেযগার, আল্লাহর নিকট তাদের জন্যে রয়েছে বেহেশত, যার তলদেশে প্রস্রবণ প্রবাহিত-তারা সেখানে থাকবে অনন্তকাল। আর রয়েছে পরিচ্ছন্ন সঙ্গিনীগণ এবং আল্লাহর সন্তুষ্টি। আর আল্লাহ তাঁর বান্দাদের প্রতি সুদৃষ্টি রাখেন।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@cccix{যারা বলে, হে আমাদের পালনকর্তা, আমরা ঈমান এনেছি, কাজেই আমাদের গোনাহ ক্ষমা করে দাও আর আমাদেরকে দোযখের আযাব থেকে রক্ষা কর।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@cccx{তারা ধৈর্য্যধারণকারী, সত্যবাদী, নির্দেশ সম্পাদনকারী, সৎপথে ব্যয়কারী এবং শেষরাতে ক্ষমা প্রার্থনাকারী।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@cccxi{আল্লাহ সাক্ষ্য দিয়েছেন যে, তাঁকে ছাড়া আর কোন উপাস্য নেই। ফেরেশতাগণ এবং ন্যায়নিষ্ঠ জ্ঞানীগণও সাক্ষ্য দিয়েছেন যে, তিনি ছাড়া আর কোন ইলাহ নেই। তিনি পরাক্রমশালী প্রজ্ঞাময়।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@cccxii{নিঃসন্দেহে আল্লাহর নিকট গ্রহণযোগ্য দ্বীন একমাত্র ইসলাম। এবং যাদের প্রতি কিতাব দেয়া হয়েছে তাদের নিকট প্রকৃত জ্ঞান আসার পরও ওরা মতবিরোধে লিপ্ত হয়েছে, শুধুমাত্র পরস্পর বিদ্বেষবশতঃ, যারা আল্লাহর নিদর্শনসমূহের প্রতি কুফরী করে তাদের জানা উচিত যে, নিশ্চিতরূপে আল্লাহ হিসাব গ্রহণে অত্যন্ত দ্রুত।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@cccxiii{যদি তারা তোমার সাথে বিতর্কে অবতীর্ণ হয় তবে বলে দাও, ``আমি এবং আমার অনুসরণকারীগণ আল্লাহর প্রতি আত্নসমর্পণ করেছি।" আর আহলে কিতাবদের এবং নিরক্ষরদের বলে দাও যে, তোমরাও কি আত্নসমর্পণ করেছ? তখন যদি তারা আত্নসমর্পণ করে, তবে সরল পথ প্রাপ্ত হলো, আর যদি মুখ ঘুরিয়ে নেয়, তাহলে তোমার দায়িত্ব হলো শুধু পৌছে দেয়া। আর আল্লাহর দৃষ্টিতে রয়েছে সকল বান্দা।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@cccxiv{যারা আল্লাহর নিদর্শনাবলীকে অস্বীকার করে এবং পয়গম্বরগণকে হত্যা করে অন্যায়ভাবে, আর সেসব লোককে হত্যা করে যারা ন্যায়পরায়ণতার নির্দেশ দেয় তাদেরকে বেদনাদায়ক শাস্তির সংবাদ দিন।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@cccxv{এরাই হলো সে লোক যাদের সমগ্র আমল দুনিয়া ও আখেরাত উভয়লোকেই বিনষ্ট হয়ে গেছে। পক্ষান্তরে তাদের কোন সাহায্যকারীও নেই।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@cccxvi{আপনি কি তাদের দেখেননি, যারা কিতাবের কিছু অংশ পেয়েছে-আল্লাহর কিতাবের প্রতি তাদের আহবান করা হয়েছিল যাতে তাদের মধ্যে মীমাংসা করা যায়। অতঃপর তাদের মধ্যে একদল তা অমান্য করে মুখ ফিরিয়ে নেয়।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@cccxvii{তা এজন্য যে, তারা বলে থাকে যে, দোযখের আগুন আমাদের স্পর্শ করবে না; তবে সামান্য হাতে গোনা কয়েকদিনের জন্য স্পর্শ করতে পারে। নিজেদের উদ্ভাবিত ভিত্তিহীন কথায় তারা ধোকা খেয়েছে।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@cccxviii{কিন্তু তখন কি অবস্থা দাঁড়াবে যখন আমি তাদেরকে একদিন সমবেত করবো যে দিনের আগমনে কোন সন্দেহ নেই আর নিজেদের কৃতকর্ম তাদের প্রত্যেকেই পাবে তাদের প্রাপ্য প্রদান মোটেই অন্যায় করা হবে না।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@cccxix{বলুন ইয়া আল্লাহ! তুমিই সার্বভৌম শক্তির অধিকারী। তুমি যাকে ইচ্ছা রাজ্য দান কর এবং যার কাছ থেকে ইচ্ছা রাজ্য ছিনিয়ে নাও এবং যাকে ইচ্ছা সম্মান দান কর আর যাকে ইচ্ছা অপমানে পতিত কর। তোমারই হাতে রয়েছে যাবতীয় কল্যাণ। নিশ্চয়ই তুমি সর্ব বিষয়ে ক্ষমতাশীল।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@cccxx{তুমি রাতকে দিনের ভেতরে প্রবেশ করাও এবং দিনকে রাতের ভেতরে প্রবেশ করিয়ে দাও। আর তুমিই জীবিতকে মৃতের ভেতর থেকে বের করে আন এবং মৃতকে জীবিতের ভেতর থেকে বের কর। আর তুমিই যাকে ইচ্ছা বেহিসাব রিযিক দান কর।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@cccxxi{মুমিনগন যেন অন্য মুমিনকে ছেড়ে কেন কাফেরকে বন্ধুরূপে গ্রহণ না করে। যারা এরূপ করবে আল্লাহর সাথে তাদের কেন সম্পর্ক থাকবে না। তবে যদি তোমরা তাদের পক্ষ থেকে কোন অনিষ্টের আশঙ্কা কর, তবে তাদের সাথে সাবধানতার সাথে থাকবে আল্লাহ তা’আলা তাঁর সম্পর্কে তোমাদের সতর্ক করেছেন। এবং সবাই কে তাঁর কাছে ফিরে যেতে হবে।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@cccxxii{বলে দিন, তোমরা যদি মনের কথা গোপন করে রাখ অথবা প্রকাশ করে দাও, আল্লাহ সে সবই জানতে পারেন। আর আসমান ও জমিনে যা কিছু আছে, সেসব ও তিনি জানেন। আল্লাহ সর্ব বিষয়ে শক্তিমান।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@cccxxiii{সেদিন প্রত্যেকেই যা কিছু সে ভাল কাজ করেছে; চোখের সামনে দেখতে পাবে এবং যা কিছু মন্দ কাজ করেছে তাও, ওরা তখন কামনা করবে, যদি তার এবং এসব কর্মের মধ্যে ব্যবধান দুরের হতো! আল্লাহ তাঁর নিজের সম্পর্কে তোমাদের সাবধান করছেন। আল্লাহ তাঁর বান্দাদের প্রতি অত্যন্ত দয়ালু।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@cccxxiv{বলুন, যদি তোমরা আল্লাহকে ভালবাস, তাহলে আমাকে অনুসরণ কর, যাতে আল্লাহ ও তোমাদিগকে ভালবাসেন এবং তোমাদিগকে তোমাদের পাপ মার্জনা করে দেন। আর আল্লাহ হলেন ক্ষমাকারী দয়ালু।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@cccxxv{বলুন, আল্লাহ ও রসূলের আনুগত্য প্রকাশ কর। বস্তুতঃ যদি তারা বিমুখতা অবলম্বন করে, তাহলে আল্লাহ কাফেরদিগকে ভালবাসেন না।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@cccxxvi{নিঃসন্দেহে আল্লাহ আদম (আঃ) নূহ (আঃ)͠ও ইব্রাহীম (আঃ) এর বংশধর এবং এমরানের খান্দানকে নির্বাচিত করেছেন।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@cccxxvii{যারা বংশধর ছিলেন পরস্পরের। আল্লাহ শ্রবণকারী ও মহাজ্ঞানী।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@cccxxviii{এমরানের স্ত্রী যখন বললো-হে আমার পালনকর্তা! আমার গর্ভে যা রয়েছে আমি তাকে তোমার নামে উৎসর্গ করলাম সবার কাছ থেকে মুক্ত রেখে। আমার পক্ষ থেকে তুমি তাকে কবুল করে নাও, নিশ্চয়ই তুমি শ্রবণকারী, সর্বজ্ঞাত।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@cccxxix{অতঃপর যখন তাকে প্রসব করলো বলল, হে আমার পালনকর্তা! আমি একে কন্যা প্রসব করেছি। বস্তুতঃ কি সে প্রসব করেছে আল্লাহ তা ভালই জানেন। সেই কন্যার মত কোন পুত্রই যে নেই। আর আমি তার নাম রাখলাম মারইয়াম। আর আমি তাকে ও তার সন্তানদেরকে তোমার আশ্রয়ে সমর্পণ করছি। অভিশপ্ত শয়তানের কবল থেকে।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@cccxxx{অতঃপর তাঁর পালনকর্তা তাঁকে উত্তম ভাবে গ্রহণ করে নিলেন এবং তাঁকে প্রবৃদ্ধি দান করলেন-অত্যন্ত সুন্দর প্রবৃদ্ধি। আর তাঁকে যাকারিয়ার তত্ত্বাবধানে সমর্পন করলেন। যখনই যাকারিয়া মেহরাবের মধ্যে তার কছে আসতেন তখনই কিছু খাবার দেখতে পেতেন। জিজ্ঞেস করতেন ``মারইয়াম! কোথা থেকে এসব তোমার কাছে এলো?" তিনি বলতেন, ``এসব আল্লাহর নিকট থেকে আসে। আল্লাহ যাকে ইচ্ছা বেহিসাব রিযিক দান করেন।"\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@cccxxxi{সেখানেই যাকারিয়া তাঁর পালনকর্তার নিকট প্রার্থনা করলেন। বললেন, হে, আমার পালনকর্তা! তোমার নিকট থেকে আমাকে পুত-পবিত্র সন্তান দান কর-নিশ্চয়ই তুমি প্রার্থনা শ্রবণকারী।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@cccxxxii{যখন তিনি কামরার ভেতরে নামাযে দাঁড়িয়েছিলেন, তখন ফেরেশতারা তাঁকে ডেকে বললেন যে, আল্লাহ তোমাকে সুসংবাদ দিচ্ছেন ইয়াহইয়া সম্পর্কে, যিনি সাক্ষ্য দেবেন আল্লাহর নির্দেশের সত্যতা সম্পর্কে, যিনি নেতা হবেন এবং নারীদের সংস্পর্শে যাবেন না, তিনি অত্যন্ত সৎকর্মশীল নবী হবেন।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@cccxxxiii{তিনি বললেন হে পালনকর্তা! কেমন করে আমার পুত্র সন্তান হবে, আমার যে বার্ধক্য এসে গেছে, আমার স্ত্রীও যে বন্ধ্যা। বললেন, আল্লাহ এমনি ভাবেই যা ইচ্ছা করে থাকেন।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@cccxxxiv{তিনি বললেন, হে পালনকর্তা আমার জন্য কিছু নিদর্শন দাও। তিনি বললেন, তোমার জন্য নিদর্শন হলো এই যে, তুমি তিন দিন পর্যন্ত কারও সাথে কথা বলবে না। তবে ইশারা ইঙ্গতে করতে পারবে এবং তোমার পালনকর্তাকে অধিক পরিমাণে স্মরণ করবে আর সকাল-সন্ধ্যা তাঁর পবিত্রতা ও মহিমা ঘোষনা করবে।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@cccxxxv{আর যখন ফেরেশতা বলল হে মারইয়াম!, আল্লাহ তোমাকে পছন্দ করেছেন এবং তোমাকে পবিত্র পরিচ্ছন্ন করে দিয়েছেন। আর তোমাকে বিশ্ব নারী সমাজের উর্ধ্বে মনোনীত করেছেন।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@cccxxxvi{হে মারইয়াম! তোমার পালনকর্তার উপাসনা কর এবং রুকুকারীদের সাথে সেজদা ও রুকু কর।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@cccxxxvii{এ হলো গায়েবী সংবাদ, যা আমি আপনাকে পাঠিয়ে থাকি। আর আপনি তো তাদের কাছে ছিলেন না, যখন প্রতিযোগিতা করছিল যে, কে প্রতিপালন করবে মারইয়ামকে এবং আপনি তাদের কাছে ছিলেন না, যখন তারা ঝগড়া করছিলো।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@cccxxxviii{যখন ফেরেশতাগণ বললো, হে মারইয়াম আল্লাহ তোমাকে তাঁর এক বানীর সুসংবাদ দিচ্ছেন, যার নাম হলো মসীহ-মারইয়াম-তনয় ঈসা, দুনিয়া ও আখেরাতে তিনি মহাসম্মানের অধিকারী এবং আল্লাহর ঘনিষ্ঠদের অন্তর্ভূক্ত।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@cccxxxix{যখন তিনি মায়ের কোলে থাকবেন এবং পূর্ণ বয়স্ক হবেন তখন তিনি মানুষের সাথে কথা বলবেন। আর তিনি সৎকর্মশীলদের অন্তর্ভুক্ত হবেন।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@cccxl{তিনি বললেন, পরওয়ারদেগার! কেমন করে আমার সন্তান হবে; আমাকে তো কোন মানুষ স্পর্শ করেনি। বললেন এ ভাবেই আল্লাহ যা ইচ্ছা সৃষ্টি করেন। যখন কোন কাজ করার জন্য ইচ্ছা করেন তখন বলেন যে, ‘হয়ে যাও’ অমনি তা হয়ে যায়।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@cccxli{আর তাকে তিনি শিখিয়ে দেবেন কিতাব, হিকমত, তওরাত, ইঞ্জিল।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@cccxlii{আর বণী ইসরাঈলদের জন্যে রসূল হিসেবে তাকে মনোনীত করবেন। তিনি বললেন নিশ্চয়ই আমি তোমাদের নিকট তোমাদের পালনকর্তার পক্ষ থেকে এসেছি নিদর্শনসমূহ নিয়ে। আমি তোমাদের জন্য মাটির দ্বারা পাখীর আকৃতি তৈরী করে দেই। তারপর তাতে যখন ফুৎকার প্রদান করি, তখন তা উড়ন্ত পাখীতে পরিণত হয়ে যায় আল্লাহর হুকুমে। আর আমি সুস্থ করে তুলি জন্মান্ধকে এবং শ্বেত কুষ্ঠ রোগীকে। আর আমি জীবিত করে দেই মৃতকে আল্লাহর হুকুমে। আর আমি তোমাদেরকে বলে দেই যা তোমরা খেয়ে আস এবং যা তোমরা ঘরে রেখে আস। এতে প্রকৃষ্ট নিদর্শন রয়েছে, যদি তোমরা বিশ্বাসী হও।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@cccxliii{আর এটি পূর্ববর্তী কিতাব সমুহকে সত্যায়ন করে, যেমন তওরাত। আর তা এজন্য যাতে তোমাদের জন্য হালাল করে দেই কোন কোন বস্তু যা তোমাদের জন্য হারাম ছিল। আর আমি তোমাদের নিকট এসেছি তোমাদের পালনকর্তার নিদর্শনসহ। কাজেই আল্লাহকে ভয় কর এবং আমার অনুসরণ কর।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@cccxliv{নিশ্চয়ই আল্লাহ আমার পালনকর্তা এবং তোমাদেরও পালনকর্তা-তাঁর এবাদত কর, এটাই হলো সরল পথ।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@cccxlv{অতঃপর ঈসা (আঃ) যখন বণী ইসরায়ীলের কুফরী সম্পর্কে উপলব্ধি করতে পারলেন, তখন বললেন, কারা আছে আল্লাহর পথে আমাকে সাহায্য করবে? সঙ্গী-সাথীরা বললো, আমরা রয়েছি আল্লাহর পথে সাহায্যকারী। আমরা আল্লাহর প্রতি ঈমান এনেছি। আর তুমি সাক্ষী থাক যে, আমরা হুকুম কবুল করে নিয়েছি।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@cccxlvi{হে আমাদের পালনকর্তা! আমরা সে বিষয়ের প্রতি বিশ্বাস স্থাপন করেছি যা তুমি নাযিল করেছ, আমরা রসূলের অনুগত হয়েছি। অতএব, আমাদিগকে মান্যকারীদের তালিকাভুক্ত করে নাও।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@cccxlvii{এবং কাফেরেরা চক্রান্ত করেছে আর আল্লাহও কৌশল অবলম্বন করেছেন। বস্তুতঃ আল্লাহ হচ্ছেন সর্বোত্তম কুশলী।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@cccxlviii{আর স্মরণ কর, যখন আল্লাহ বলবেন, হে ঈসা! আমি তোমাকে নিয়ে নেবো এবং তোমাকে নিজের দিকে তুলে নিবো-কাফেরদের থেকে তোমাকে পবিত্র করে দেবো। আর যারা তোমার অনুগত রয়েছে তাদেরকে কিয়ামতের দিন পর্যন্ত যারা অস্বীকৃতি জ্ঞাপন করে তাদের উপর জয়ী করে রাখবো। বস্তুতঃ তোমাদের সবাইকে আমার কাছেই ফিরে আসতে হবে। তখন যে বিষয়ে তোমরা বিবাদ করতে, আমি তোমাদের মধ্যে তার ফয়সালা করে দেবো।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@cccxlix{অতএব যারা কাফের হয়েছে, তাদেরকে আমি কঠিন শাস্তি দেবো দুনিয়াতে এবং আখেরাতে-তাদের কোন সাহায্যকারী নেই।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@cccl{পক্ষান্তরে যারা ঈমান এনেছে এবং সৎকাজ করেছে। তাদের প্রাপ্য পরিপুর্ণভাবে দেয়া হবে। আর আল্লাহ অত্যাচারীদেরকে ভালবাসেন না।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@cccli{আমি তোমাদেরকে পড়ে শুনাই এ সমস্ত আয়াত এবং নিশ্চিত বর্ণনা।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@ccclii{নিঃসন্দেহে আল্লাহর নিকট ঈসার দৃষ্টান্ত হচ্ছে আদমেরই মতো। তাকে মাটি দিয়ে তৈরী করেছিলেন এবং তারপর তাকে বলেছিলেন হয়ে যাও, সঙ্গে সঙ্গে হয়ে গেলেন।\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@cccliii{যা তোমার পালকর্তা বলেন তাই হচ্ছে যথার্থ সত্য। কাজেই তোমরা সংশয়বাদী হয়ো না।\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@cccliv{অতঃপর তোমার নিকট সত্য সংবাদ এসে যাওয়ার পর যদি এই কাহিনী সম্পর্কে তোমার সাথে কেউ বিবাদ করে, তাহলে বল-এসো, আমরা ডেকে নেই আমাদের পুত্রদের এবং তোমাদের পুত্রদের এবং আমাদের স্ত্রীদের ও তোমাদের স্ত্রীদের এবং আমাদের নিজেদের ও তোমাদের নিজেদের আর তারপর চল আমরা সবাই মিলে প্রার্থনা করি এবং তাদের প্রতি আল্লাহর অভিসম্পাত করি যারা মিথ্যাবাদী।\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@ccclv{নিঃসন্দেহে এটাই হলো সত্য ভাষণ। আর এক আল্লাহ ছাড়া অন্য কোন ইলাহ নেই। আর আল্লাহ; তিনিই হলেন পরাক্রমশালী মহাপ্রাজ্ঞ।\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@ccclvi{তারপর যদি তারা গ্রহণ না করে, তাহলে প্রমাদ সৃষ্টিকারীদেরকে আল্লাহ জানেন।\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@ccclvii{বলুনঃ ‘হে আহলে-কিতাবগণ! একটি বিষয়ের দিকে আস-যা আমাদের মধ্যে ও তোমাদের মধ্যে সমান-যে, আমরা আল্লাহ ছাড়া অন্য কারও ইবাদত করব না, তাঁর সাথে কোন শরীক সাব্যস্ত করব না এবং একমাত্র আল্লাহকে ছাড়া কাউকে পালনকর্তা বানাব না। তারপর যদি তারা স্বীকার না করে, তাহলে বলে দাও যে, ‘সাক্ষী থাক আমরা তো অনুগত।\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@ccclviii{হে আহলে কিতাবগণ! কেন তোমরা ইব্রাহীমের বিষয়ে বাদানুবাদ কর? অথচ তওরাত ও ইঞ্জিল তাঁর পরেই নাযিল হয়েছে। তোমরা কি বুঝ না?\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@ccclix{শোন! ইতিপূর্বে তোমরা যে বিষয়ে কিছু জানতে, তাই নিয়ে বিবাদ করতে। এখন আবার যে বিষয়ে তোমরা কিছুই জান না, সে বিষয়ে কেন বিবাদ করছ?\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@ccclx{ইব্রাহীম ইহুদী ছিলেন না এবং নাসারাও ছিলেন না, কিক্তু তিনি ছিলেন ‘হানীফ’ অর্থাৎ, সব মিথ্যা ধর্মের প্রতি বিমুখ এবং আত্নসমর্পণকারী, এবং তিনি মুশরিক ছিলেন না।\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@ccclxi{মানুষদের মধ্যে যারা ইব্রাহীমের অনুসরণ করেছিল, তারা, আর এই নবী এবং যারা এ নবীর প্রতি ঈমান এনেছে তারা ইব্রাহীমের ঘনিষ্ঠতম-আর আল্লাহ হচ্ছেন মুমিনদের বন্ধু।\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@ccclxii{কোন কোন আহলে-কিতাবের আকাঙ্খা, যাতে তোমাদের গোমরাহ করতে পারে, কিন্তু তারা নিজেদের ছাড়া অন্য কাউকেই গোমরাহ করে না। অথচ তারা বুঝতে পারে না।\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@ccclxiii{হে আহলে-কিতাবগণ, কেন তোমরা আল্লাহর কালামকে অস্বীকার কর, অথচ তোমরাই তাঁর প্রবক্তা?\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@ccclxiv{হে আহলে কিতাবগণ, কেন তোমরা সত্যকে মিথ্যার সাথে সংমিশ্রণ করছ এবং সত্যকে গোপন করছ, অথচ তোমরা তা জান।\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@ccclxv{আর আহলে-কিতাবগণের একদল বললো, মুসলমানগণের উপর যা কিছু অবর্তীণ হয়েছে তাকে দিনের প্রথম ভাগে মেনে নাও, আর দিনের শেষ ভাগে অস্বীকার ক র, হয়তো তারা মুখ ফিরিয়ে নিতে পারে।\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@ccclxvi{যারা তোমাদের ধর্মমতে চলবে, তাদের ছাড়া আর কাউকে বিশ্বাস করবে না। বলে দিন নিঃসন্দেহে হেদায়েত সেটাই, যে হেদায়েত আল্লাহ করেন। আর এসব কিছু এ জন্যে যে, তোমরা যা লাভ করেছিলে তা অন্য কেউ কেন প্রাপ্ত হবে, কিংবা তোমাদের পালনকর্তার সামনে তোমাদের উপর তারা কেন প্রবল হয়ে যাবে! বলে দিন, মর্যাদা আল্লাহরই হাতে; তিনি যাকে ইচ্ছা দান করেন এবং আল্লাহ প্রাচুর্যময় ও সর্বজ্ঞ।\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@ccclxvii{তিনি যাকে ইচ্ছা নিজের বিশেষ অনুগ্রহ দান করেন। আর আল্লাহ মহা অনুগ্রহশীল।\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@ccclxviii{কোন কোন আহলে কিতাব এমনও রয়েছে, তোমরা যদি তাদের কাছে বহু ধন-সম্পদ আমানত রাখ, তাহলেও তা তোমাদের যথারীতি পরিশোধ করবে। আর তোদের মধ্যে অনেক এমনও রয়েছে যারা একটি দীনার গচ্ছিত রাখলেও ফেরত দেবে না-যে পর্যন্ত না তুমি তার মাথার উপর দাঁড়াতে পারবে। এটা এজন্য যে, তারা বলে রেখেছে যে, উম্মীদের অধিকার বিনষ্ট করাতে আমাদের কোন পাপ নেই। আর তারা আল্লাহ সম্পর্কে জেনে শুনেই মিথ্যা বলে।\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@ccclxix{যে লোক নিজ প্রতিজ্ঞা পূর্ন করবে এং পরহেজগার হবে, অবশ্যই আল্লাহ পরহেজগারদেরকে ভালবাসেন।\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@ccclxx{যারা আল্লাহর নামে কৃত অঙ্গীকার এবং প্রতিজ্ঞা সামান্য মুল্যে বিক্রয় করে, আখেরাতে তাদের কেন অংশ নেই। আর তাদের সাথে কেয়ামতের দিন আল্লাহ কথা বলবেন না। তাদের প্রতি (করুণার) দৃষ্টিও দেবেন না। আর তাদেরকে পরিশুদ্ধও করবেন না। বস্তুতঃ তাদের জন্য রয়েছে যন্ত্রণাদায়ক আযাব।\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@ccclxxi{আর তাদের মধ্যে একদল রয়েছে, যারা বিকৃত উচ্চারণে মুখ বাঁকিয়ে কিতাব পাঠ করে, যাতে তোমরা মনে কর যে, তার কিতাব থেকেই পাঠ করছে। অথচ তারা যা আবৃত্তি করছে তা আদৌ কিতাব নয়। এবং তারা বলে যে, এসব কথা আল্লাহর তরফ থেকে আগত। অথচ এসব আল্লাহর তরফ থেকে প্রেরিত নয়। তারা বলে যে, এটি আল্লাহর কথা অথচ এসব আল্লাহর কথা নয়। আর তারা জেনে শুনে আল্লাহরই প্রতি মিথ্যারোপ করে।\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@ccclxxii{কোন মানুষকে আল্লাহ কিতাব, হেকমত ও নবুওয়ত দান করার পর সে বলবে যে, ‘তোমরা আল্লাহকে পরিহার করে আমার বান্দা হয়ে যাও’-এটা সম্ভব নয়। বরং তারা বলবে, ‘তোমরা আল্লাহওয়ালা হয়ে যাও, যেমন, তোমরা কিতাব শিখাতে এবং যেমন তোমরা নিজেরা ও পড়তে।\qt@no{(79)}}
\qt@newcmd\qurantrans@bn@ccclxxiii{তাছাড়া তোমাদেরকে একথা বলাও সম্ভব নয় যে, তোমরা ফেরেশতা ও নবীগনকে নিজেদের পালনকর্তা সাব্যস্ত করে নাও। তোমাদের মুসলমান হবার পর তারা কি তোমাদেরকে কুফরী শেখাবে?\qt@no{(80)}}
\qt@newcmd\qurantrans@bn@ccclxxiv{আর আল্লাহ যখন নবীগনের কাছ থেকে অস্বীকার গ্রহন করলেন যে, আমি যা কিছু তোমাদের দান করেছি কিতাব ও জ্ঞান এবং অতঃপর তোমাদের নিকট কোন রসূল আসেন তোমাদের কিতাবকে সত্য বলে দেয়ার জন্য, তখন সে রসূলের প্রতি ঈমান আনবে এবং তার সাহায্য করবে। তিনি বললেন, ‘তোমার কি অঙ্গীকার করছো এবং এই শর্তে আমার ওয়াদা গ্রহণ করে নিয়েছ? তারা বললো, ‘আমরা অঙ্গীকার করেছি’। তিনি বললেন, তাহলে এবার সাক্ষী থাক। আর আমিও তোমাদের সাথে সাক্ষী রইলাম।\qt@no{(81)}}
\qt@newcmd\qurantrans@bn@ccclxxv{অতঃপর যে লোক এই ওয়াদা থেকে ফিরে দাঁড়াবে, সেই হবে নাফরমান।\qt@no{(82)}}
\qt@newcmd\qurantrans@bn@ccclxxvi{তারা কি আল্লাহর দ্বীনের পরিবর্তে অন্য দ্বীন তালাশ করছে? আসমান ও যমীনে যা কিছু রয়েছে স্বেচ্ছায় হোক বা অনিচ্ছায় হোক, তাঁরই অনুগত হবে এবং তাঁর দিকেই ফিরে যাবে।\qt@no{(83)}}
\qt@newcmd\qurantrans@bn@ccclxxvii{বলুন, আমরা ঈমান এনেছি আল্লাহর উপর এবং যা কিছু অবতীর্ণ হয়েছে আমাদের উপর, ইব্রাহীম, ইসমাঈল, ইসহাক, ইয়াকুব এবং তাঁদের সন্তানবর্গের উপর আর যা কিছু পেয়েছেন মূসা ও ঈসা এবং অন্যান্য নবী রসূলগণ তাঁদের পালনকর্তার পক্ষ থেকে। আমরা তাঁদের কারো মধ্যে পার্থক্য করি না। আর আমরা তাঁরই অনুগত।\qt@no{(84)}}
\qt@newcmd\qurantrans@bn@ccclxxviii{যে লোক ইসলাম ছাড়া অন্য কোন ধর্ম তালাশ করে, কস্মিণকালেও তা গ্রহণ করা হবে না এবং আখেরাতে সে ক্ষতি গ্রস্ত।\qt@no{(85)}}
\qt@newcmd\qurantrans@bn@ccclxxix{কেমন করে আল্লাহ এমন জাতিকে হেদায়েত দান করবেন, যারা ঈমান আনার পর এবং রসূলকে সত্য বলে সাক্ষ্য দেয়ার পর এবং তাদের নিকট প্রমাণ এসে যাওয়ার পর কাফের হয়েছে। আর আল্লাহ জালেম সম্প্রদায়কে হেদায়েত দান করেন না।\qt@no{(86)}}
\qt@newcmd\qurantrans@bn@ccclxxx{এমন লোকের শাস্তি হলো আল্লাহ, ফেরেশতাগণ এবং মানুষ সকলেরই অভিসম্পাত।\qt@no{(87)}}
\qt@newcmd\qurantrans@bn@ccclxxxi{সর্বক্ষণই তারা তাতে থাকবে। তাদের আযাব হালকাও হবে না এবং তার এত অবকাশও পাবে না।\qt@no{(88)}}
\qt@newcmd\qurantrans@bn@ccclxxxii{কিন্তু যারা অতঃপর তওবা করে নেবে এবং সৎকাজ করবে তারা ব্যতীত, নিশ্চয় আল্লাহ ক্ষমাশীল ও পরম দয়ালূ।\qt@no{(89)}}
\qt@newcmd\qurantrans@bn@ccclxxxiii{যারা ঈমান আনার পর অস্বীকার করেছে এবং অস্বীকৃতিতে বৃদ্ধি ঘটেছে, কস্মিণকালেও তাদের তওবা কবুল করা হবে না। আর তারা হলো গোমরাহ।\qt@no{(90)}}
\qt@newcmd\qurantrans@bn@ccclxxxiv{যদি সারা পৃথিবী পরিমাণ স্বর্ণও তার পরিবর্তে দেয়া হয়, তবুও যারা কাফের হয়েছে এবং কাফের অবস্থায় মৃত্যুবরণ করেছে তাদের তওবা কবুল করা হবে না। তাদের জন্য রয়েছে যন্ত্রণাদায়ক আযাব! পক্ষান্তরে তাদের কোনই সাহায্যকারী নেই।\qt@no{(91)}}
\qt@newcmd\qurantrans@bn@ccclxxxv{কস্মিণকালেও কল্যাণ লাভ করতে পারবে না, যদি তোমাদের প্রিয় বস্তু থেকে তোমরা ব্যয় না কর। আর তোমরা যদি কিছু ব্যয় করবে আল্লাহ তা জানেন।\qt@no{(92)}}
\qt@newcmd\qurantrans@bn@ccclxxxvi{তওরাত নাযিল হওয়ার পূর্বে ইয়াকুব যেগুলো নিজেদের জন্য হারাম করে নিয়েছিলেন, সেগুলো ব্যতীত সমস্ত আহার্য বস্তুই বনী-ইসরায়ীলদের জন্য হালাল ছিল। তুমি বলে দাও, তোমরা যদি সত্যবাদী হয়ে থাক। তাহলে তওরাত নিয়ে এসো এবং তা পাঠ কর।\qt@no{(93)}}
\qt@newcmd\qurantrans@bn@ccclxxxvii{অতঃপর আল্লাহর প্রতি যারা মিথ্যা আরোপ করেছে, তারাই যালেম সীমালংঘনকারী।\qt@no{(94)}}
\qt@newcmd\qurantrans@bn@ccclxxxviii{বল, ‘আল্লাহ সত্য বলেছেন। এখন সবাই ইব্রাহীমের ধর্মের অনুগত হয়ে যাও, যিনি ছিলেন একনিষ্ঠ ভাবে সত্যধর্মের অনুসারী। তিনি মুশরিকদের অন্তর্ভুক্ত ছিলেন না।\qt@no{(95)}}
\qt@newcmd\qurantrans@bn@ccclxxxix{নিঃসন্দেহে সর্বপ্রথম ঘর যা মানুষের জন্যে নির্ধারিত হয়েছে, সেটাই হচ্ছে এ ঘর, যা মক্কায় অবস্থিত এবং সারা জাহানের মানুষের জন্য হেদায়েত ও বরকতময়।\qt@no{(96)}}
\qt@newcmd\qurantrans@bn@cccxc{এতে রয়েছে মকামে ইব্রাহীমের মত প্রকৃষ্ট নিদর্শন। আর যে, লোক এর ভেতরে প্রবেশ করেছে, সে নিরাপত্তা লাভ করেছে। আর এ ঘরের হজ্ব করা হলো মানুষের উপর আল্লাহর প্রাপ্য; যে লোকের সামর্থ?2480;য়েছে এ পর্যন্ত পৌছার। আর যে লোক তা মানে না। আল্লাহ সারা বিশ্বের কোন কিছুরই পরোয়া করেন না।\qt@no{(97)}}
\qt@newcmd\qurantrans@bn@cccxci{বলুন, হে আহলে কিতাবগণ, কেন তোমরা আল্লাহর কিতাব অমান্য করছো, অথচ তোমরা যা কিছু কর, তা আল্লাহর সামনেই রয়েছে।\qt@no{(98)}}
\qt@newcmd\qurantrans@bn@cccxcii{বলুন, হে আহলে কিতাবগণ! কেন তোমরা আল্লাহর পথে ঈমানদারদিগকে বাধা দান কর-তোমরা তাদের দ্বীনের মধ্যে বক্রতা অনুপ্রবেশ করানোর পন্থা অনুসন্ধান কর, অথচ তোমরা এ পথের সত্যতা প্রত্যক্ষ করছ। বস্তুতঃ আল্লাহ তোমাদের কার্যকলাপ সম্পর্কে অনবগত নন।\qt@no{(99)}}
\qt@newcmd\qurantrans@bn@cccxciii{হে ঈমানদারগণ! তোমরা যদি আহলে কিতাবদের কোন ফেরকার কথা মান, তাহলে ঈমান আনার পর তারা তোমাদিগকে কাফেরে পরিণত করে দেবে।\qt@no{(100)}}
\qt@newcmd\qurantrans@bn@cccxciv{আর তোমরা কেমন করে কাফের হতে পার, অথচ তোমাদের সামনে পাঠ করা হয় আল্লাহর আয়াত সমূহ এবং তোমাদের মধ্যে রয়েছেন আল্লাহর রসূল। আর যারা আল্লাহর কথা দৃঢ়ভাবে ধরবে, তারা হেদায়েত প্রাপ্ত হবে সরল পথের।\qt@no{(101)}}
\qt@newcmd\qurantrans@bn@cccxcv{হে ঈমানদারগণ! আল্লাহকে যেমন ভয় করা উচিৎ ঠিক তেমনিভাবে ভয় করতে থাক। এবং অবশ্যই মুসলমান না হয়ে মৃত্যুবরণ করো না।\qt@no{(102)}}
\qt@newcmd\qurantrans@bn@cccxcvi{আর তোমরা সকলে আল্লাহর রজ্জুকে সুদৃঢ় হস্তে ধারণ কর; পরস্পর বিচ্ছিন্ন হয়ো না। আর তোমরা সে নেয়ামতের কথা স্মরণ কর, যা আল্লাহ তোমাদিগকে দান করেছেন। তোমরা পরস্পর শত্রু ছিলে। অতঃপর আল্লাহ তোমাদের মনে সম্প্রীতি দান করেছেন। ফলে, এখন তোমরা তাঁর অনুগ্রহের কারণে পরস্পর ভাই ভাই হয়েছ। তোমরা এক অগ্নিকুন্ডের পাড়ে অবস্থান করছিলে। অতঃপর তা থেকে তিনি তোমাদেরকে মুক্তি দিয়েছেন। এভাবেই আল্লাহ নিজের নিদর্শনসমুহ প্রকাশ করেন, যাতে তোমরা হেদায়েত প্রাপ্ত হতে পার।\qt@no{(103)}}
\qt@newcmd\qurantrans@bn@cccxcvii{আর তোমাদের মধ্যে এমন একটা দল থাকা উচিত যারা আহবান জানাবে সৎকর্মের প্রতি, নির্দেশ দেবে ভাল কাজের এবং বারণ করবে অন্যায় কাজ থেকে, আর তারাই হলো সফলকাম।\qt@no{(104)}}
\qt@newcmd\qurantrans@bn@cccxcviii{আর তাদের মত হয়ো না, যারা বিচ্ছিন্ন হয়ে গেছে এবং নিদর্শন সমূহ আসার পরও বিরোধিতা করতে শুরু করেছে-তাদের জন্যে রয়েছে ভয়ঙ্কর আযাব।\qt@no{(105)}}
\qt@newcmd\qurantrans@bn@cccxcix{সেদিন কোন কোন মুখ উজ্জ্বল হবে, আর কোন কোন মুখ হবে কালো। বস্তুতঃ যাদের মুখ কালো হবে, তাদের বলা হবে, তোমরা কি ঈমান আনার পর কাফের হয়ে গিয়েছিলে? এবার সে কুফরীর বিনিময়ে আযাবের আস্বাদ গ্রহণ কর।\qt@no{(106)}}
\qt@newcmd\qurantrans@bn@cd{আর যাদের মুখ উজ্জ্বল হবে, তারা থাকবে রহমতের মাঝে। তাতে তারা অনন্তকাল অবস্থান করবে।\qt@no{(107)}}
\qt@newcmd\qurantrans@bn@cdi{এগুলো হচ্ছে আল্লাহর নির্দেশ, যা তোমাদিগকে যথাযথ পাঠ করে শুনানো হচ্ছে। আর আল্লাহ বিশ্ব জাহানের প্রতি উৎপীড়ন করতে চান না।\qt@no{(108)}}
\qt@newcmd\qurantrans@bn@cdii{আর যা কিছু আসমান ও যমীনে রয়েছে সে সবই আল্লাহর এবং আল্লাহর প্রতিই সব কিছু প্রত্যাবর্তনশীল।\qt@no{(109)}}
\qt@newcmd\qurantrans@bn@cdiii{তোমরাই হলে সর্বোত্তম উম্মত, মানবজাতির কল্যানের জন্যেই তোমাদের উদ্ভব ঘটানো হয়েছে। তোমরা সৎকাজের নির্দেশ দান করবে ও অন্যায় কাজে বাধা দেবে এবং আল্লাহর প্রতি ঈমান আনবে। আর আহলে-কিতাবরা যদি ঈমান আনতো, তাহলে তা তাদের জন্য মঙ্গলকর হতো। তাদের মধ্যে কিছু তো রয়েছে ঈমানদার আর অধিকাংশই হলো পাপাচারী।\qt@no{(110)}}
\qt@newcmd\qurantrans@bn@cdiv{যৎসামান্য কষ্ট দেয়া ছাড়া তারা তোমাদের কোনই ক্ষতি করতে পারবে না। আর যদি তারা তোমাদের সাথে লড়াই করে, তাহলে তারা পশ্চাদপসরণ করবে। অতঃপর তাদের সাহায্য করা হবে না।\qt@no{(111)}}
\qt@newcmd\qurantrans@bn@cdv{আল্লাহর প্রতিশ্রুতি কিংবা মানুষের প্রতিশ্রুতি ব্যতিত ওরা যেখানেই অবস্থান করেছে সেখানেই তাদের ওপর লাঞ্ছনা চাপিয়ে দেয়া হয়েছে। আর ওরা উপার্জন করেছে আল্লাহর গযব। ওদের উপর চাপানো হয়েছে গলগ্রহতা। তা এজন্যে যে, ওরা আল্লাহর আয়াতসমূহকে অনবরত অস্বীকার করেছে এবং নবীগনকে অন্যায়ভাবে হত্যা করেছে। তার কারণ, ওরা নাফরমানী করেছে এবং সীমা লংঘন করেছে।\qt@no{(112)}}
\qt@newcmd\qurantrans@bn@cdvi{তারা সবাই সমান নয়। আহলে কিতাবদের মধ্যে কিছু লোক এমনও আছে যারা অবিচলভাবে আল্লাহর আয়াতসমূহ পাঠ করে এবং রাতের গভীরে তারা সেজদা করে।\qt@no{(113)}}
\qt@newcmd\qurantrans@bn@cdvii{তারা আল্লাহর প্রতি ও কিয়ামত দিবসের প্রতি ঈমান রাখে এবং কল্যাণকর বিষয়ের নির্দেশ দেয়; অকল্যাণ থেকে বারণ করে এবং সৎকাজের জন্য সাধ্যমত চেষ্টা করতে থাকে। আর এরাই হল সৎকর্মশীল।\qt@no{(114)}}
\qt@newcmd\qurantrans@bn@cdviii{তারা যেসব সৎকাজ করবে, কোন অবস্থাতেই সেগুলোর প্রতি অবজ্ঞা প্রদর্শন করা হবে না। আর আল্লাহ পরহেযগারদের বিষয়ে অবগত।\qt@no{(115)}}
\qt@newcmd\qurantrans@bn@cdix{নিশ্চয় যারা কাফের হয়, তাদের ধন সম্পদ ও সন্তান-সন্ততি আল্লাহর সামনে কখনও কোন কাজে আসবে না। আর তারাই হলো দোযখের আগুনের অধিবাসী। তারা সে আগুনে চিরকাল থাকবে।\qt@no{(116)}}
\qt@newcmd\qurantrans@bn@cdx{এ দুনিয়ার জীবনে যা কিছু ব্যয় করা হয়, তার তুলনা হলো ঝড়ো হাওয়ার মতো, যাতে রয়েছে তুষারের শৈত্য, যা সে জাতির শস্যক্ষেত্রে গিয়ে লেগেছে যারা নিজের জন্য মন্দ করেছে। অতঃপর সেগুলোকে নিঃশেষ করে দিয়েছে। বস্তুতঃ আল্লাহ তাদের উপর কোন অন্যায় করেননি, কিন্তু তারা নিজেরাই নিজেদের উপর অত্যাচার করছিল।\qt@no{(117)}}
\qt@newcmd\qurantrans@bn@cdxi{হে ঈমানদারগণ! তোমরা মুমিন ব্যতীত অন্য কাউকে অন্তরঙ্গরূপে গ্রহণ করো না, তারা তোমাদের অমঙ্গল সাধনে কোন ক্রটি করে না-তোমরা কষ্টে থাক, তাতেই তাদের আনন্দ। শত্রুতাপ্রসুত বিদ্বেষ তাদের মুখেই ফুটে বেরোয়। আর যা কিছু তাদের মনে লুকিয়ে রয়েছে, তা আরো অনেকগুণ বেশী জঘন্য। তোমাদের জন্যে নিদর্শন বিশদভাবে বর্ণনা করে দেয়া হলো, যদি তোমরা তা অনুধাবন করতে সমর্থ হও।\qt@no{(118)}}
\qt@newcmd\qurantrans@bn@cdxii{দেখ! তোমরাই তাদের ভালবাস, কিন্তু তারা তোমাদের প্রতি মোটেও সদভাব পোষণ করে না। আর তোমরা সমস্ত কিতাবেই বিশ্বাস কর। অথচ তারা যখন তোমাদের সাথে এসে মিশে, বলে, আমরা ঈমান এনেছি। পক্ষান্তরে তারা যখন পৃথক হয়ে যায়, তখন তোমাদের উপর রোষবশতঃ আঙ্গুল কামড়াতে থাকে। বলুন, তোমরা আক্রোশে মরতে থাক। আর আল্লাহ মনের কথা ভালই জানেন।\qt@no{(119)}}
\qt@newcmd\qurantrans@bn@cdxiii{তোমাদের যদি কোন মঙ্গল হয়; তাহলে তাদের খারাপ লাগে। আর তোমাদের যদি অমঙ্গল হয় তাহলে আনন্দিত হয় আর তাতে যদি তোমরা ধৈর্য্যধারণ কর এবং তাকওয়া অবলম্বন কর, তবে তাদের প্রতারণায় তোমাদের কোনই ক্ষতি হবে না। নিশ্চয়ই তারা যা কিছু করে সে সমস্তই আল্লাহর আয়ত্তে রয়েছে।\qt@no{(120)}}
\qt@newcmd\qurantrans@bn@cdxiv{আর আপনি যখন পরিজনদের কাছ থেকে সকাল বেলা বেরিয়ে গিয়ে মুমিনগণকে যুদ্ধের অবস্থানে বিন্যস্ত করলেন, আর আল্লাহ সব বিষয়েই শোনেন এবং জানেন।\qt@no{(121)}}
\qt@newcmd\qurantrans@bn@cdxv{যখন তোমাদের দুটি দল সাহস হারাবার উপক্রম হলো, অথচ আল্লাহ তাদের সাহায্যকারী ছিলেন, আর আল্লাহর উপরই ভরসা করা মুমিনদের উচিত।\qt@no{(122)}}
\qt@newcmd\qurantrans@bn@cdxvi{বস্তুতঃ আল্লাহ বদরের যুদ্ধে তোমাদের সাহায্য করেছেন, অথচ তোমরা ছিলে দুর্বল। কাজেই আল্লাহকে ভয় করতে থাক, যাতে তোমরা কৃতজ্ঞ হতে পারো।\qt@no{(123)}}
\qt@newcmd\qurantrans@bn@cdxvii{আপনি যখন বলতে লাগলেন মুমিনগণকে-তোমাদের জন্য কি যথেষ্ট নয় যে, তোমাদের সাহায্যার্থে তোমাদের পালনকর্তা আসমান থেকে অবতীর্ণ তিন হাজার ফেরেশতা পাঠাবেন।\qt@no{(124)}}
\qt@newcmd\qurantrans@bn@cdxviii{অবশ্য তোমরা যদি সবর কর এবং বিরত থাক আর তারা যদি তখনই তোমাদের উপর চড়াও হয়, তাহলে তোমাদের পালনকর্তা চিহ্নিত ঘোড়ার উপর পাঁচ হাজার ফেরেশতা তোমাদের সাহায্যে পাঠাতে পারেন।\qt@no{(125)}}
\qt@newcmd\qurantrans@bn@cdxix{বস্তুতঃ এটা তো আল্লাহ তোমাদের সুসংবাদ দান করলেন, যাতে তোমাদের মনে এতে সান্ত্বনা আসতে পারে। আর সাহায্য শুধুমাত্র পরাক্রান্ত, মহাজ্ঞানী আল্লাহরই পক্ষ থেকে,\qt@no{(126)}}
\qt@newcmd\qurantrans@bn@cdxx{যাতে ধবংস করে দেন কোন কোন কাফেরকে অথবা লাঞ্ছিত করে দেন-যেন ওরা বঞ্চিত হয়ে ফিরে যায়।\qt@no{(127)}}
\qt@newcmd\qurantrans@bn@cdxxi{হয় আল্লাহ তাদের ক্ষমা করবেন কিংবা তাদেরকে আযাব দেবেন। এ ব্যাপারে আপনার কোন করণীয় নাই। কারণ তারা রয়েছে অন্যায়ের উপর।\qt@no{(128)}}
\qt@newcmd\qurantrans@bn@cdxxii{আর যা কিছু আসমান ও যমীনে রয়েছে, সেসবই আল্লাহর। তিনি যাকে ইচ্ছা ক্ষমা করবেন, যাকে ইচ্ছা আযাব দান করবেন। আর আল্লাহ হচ্ছেন ক্ষমাকারী, করুণাময়।\qt@no{(129)}}
\qt@newcmd\qurantrans@bn@cdxxiii{হে ঈমানদারগণ! তোমরা চক্রবৃদ্ধি হারে সুদ খেয়ো না। আর আল্লাহকে ভয় করতে থাক, যাতে তোমরা কল্যাণ অর্জন করতে পারো।\qt@no{(130)}}
\qt@newcmd\qurantrans@bn@cdxxiv{এবং তোমরা সে আগুন থেকে বেঁচে থাক, যা কাফেরদের জন্য প্রস্তুত করা হয়েছে।\qt@no{(131)}}
\qt@newcmd\qurantrans@bn@cdxxv{আর তোমরা আনুগত্য কর আল্লাহ ও রসূলের, যাতে তোমাদের উপর রহমত করা হয়।\qt@no{(132)}}
\qt@newcmd\qurantrans@bn@cdxxvi{তোমরা তোমাদের পালনকর্তার ক্ষমা এবং জান্নাতের দিকে ছুটে যাও যার সীমানা হচ্ছে আসমান ও যমীন, যা তৈরী করা হয়েছে পরহেযগারদের জন্য।\qt@no{(133)}}
\qt@newcmd\qurantrans@bn@cdxxvii{যারা স্বচ্ছলতায় ও অভাবের সময় ব্যয় করে, যারা নিজেদের রাগকে সংবরণ করে আর মানুষের প্রতি ক্ষমা প্রদর্শন করে, বস্তুতঃ আল্লাহ সৎকর্মশীলদিগকেই ভালবাসেন।\qt@no{(134)}}
\qt@newcmd\qurantrans@bn@cdxxviii{তারা কখনও কোন অশ্লীল কাজ করে ফেললে কিংবা কোন মন্দ কাজে জড়িত হয়ে নিজের উপর জুলুম করে ফেললে আল্লাহকে স্মরণ করে এবং নিজের পাপের জন্য ক্ষমা প্রার্থনা করে। আল্লাহ ছাড়া আর কে পাপ ক্ষমা করবেন? তারা নিজের কৃতকর্মের জন্য হঠকারিতা প্রদর্শন করে না এবং জেনে-শুনে তাই করতে থাকে না।\qt@no{(135)}}
\qt@newcmd\qurantrans@bn@cdxxix{তাদেরই জন্য প্রতিদান হলো তাদের পালনকর্তার ক্ষমা ও জান্নাত, যার তলদেশে প্রবাহিত হচ্ছে প্রস্রবণ যেখানে তারা থাকবে অনন্তকাল। যারা কাজ করে তাদের জন্য কতইনা চমৎকার প্রতিদান।\qt@no{(136)}}
\qt@newcmd\qurantrans@bn@cdxxx{তোমাদের আগে অতীত হয়েছে অনেক ধরনের জীবনাচরণ। তোমরা পৃথিবীতে ভ্রমণ কর এবং দেখ যারা মিথ্যা প্রতিপন্ন করেছে তাদের পরিণতি কি হয়েছে।\qt@no{(137)}}
\qt@newcmd\qurantrans@bn@cdxxxi{এই হলো মানুষের জন্য বর্ণনা। আর যারা ভয় করে তাদের জন্য উপদেশবাণী।\qt@no{(138)}}
\qt@newcmd\qurantrans@bn@cdxxxii{আর তোমরা নিরাশ হয়ো না এবং দুঃখ করো না। যদি তোমরা মুমিন হও তবে, তোমরাই জয়ী হবে।\qt@no{(139)}}
\qt@newcmd\qurantrans@bn@cdxxxiii{তোমরা যদি আহত হয়ে থাক, তবে তারাও তো তেমনি আহত হয়েছে। আর এ দিনগুলোকে আমি মানুষের মধ্যে পালাক্রমে আবর্তন ঘটিয়ে থাকি। এভাবে আল্লাহ জানতে চান কারা ঈমানদার আর তিনি তোমাদের কিছু লোককে শহীদ হিসাবে গ্রহণ করতে চান। আর আল্লাহ অত্যাচারীদেরকে ভালবাসেন না।\qt@no{(140)}}
\qt@newcmd\qurantrans@bn@cdxxxiv{আর এ কারণে আল্লাহ ঈমানদারদেরকে পাক-সাফ করতে চান এবং কাফেরদেরকে ধবংস করে দিতে চান।\qt@no{(141)}}
\qt@newcmd\qurantrans@bn@cdxxxv{তোমাদের কি ধারণা, তোমরা জান্নাতে প্রবেশ করবে? অথচ আল্লাহ এখনও দেখেননি তোমাদের মধ্যে কারা জেহাদ করেছে এবং কারা ধৈর্য্যশীল।\qt@no{(142)}}
\qt@newcmd\qurantrans@bn@cdxxxvi{আর তোমরা তো মৃত্যু আসার আগেই মরণ কামনা করতে, কাজেই এখন তো তোমরা তা চোখের সামনে উপস্থিত দেখতে পাচ্ছ।\qt@no{(143)}}
\qt@newcmd\qurantrans@bn@cdxxxvii{আর মুহাম্মদ একজন রসূল বৈ তো নয়! তাঁর পূর্বেও বহু রসূল অতিবাহিত হয়ে গেছেন। তাহলে কি তিনি যদি মৃত্যুবরণ করেন অথবা নিহত হন, তবে তোমরা পশ্চাদপসরণ করবে? বস্তুতঃ কেউ যদি পশ্চাদপসরণ করে, তবে তাতে আল্লাহর কিছুই ক্ষতি-বৃদ্ধি হবে না। আর যারা কৃতজ্ঞ, আল্লাহ তাদের সওয়াব দান করবেন।\qt@no{(144)}}
\qt@newcmd\qurantrans@bn@cdxxxviii{আর আল্লাহর হুকুম ছাড়া কেউ মরতে পারে না-সেজন্য একটা সময় নির্ধারিত রয়েছে। বস্তুতঃ যে লোক দুনিয়ায় বিনিময় কামনা করবে, আমি তাকে তা দুনিয়াতেই দান করব। পক্ষান্তরে-যে লোক আখেরাতে বিনিময় কামনা করবে, তা থেকে আমি তাকে তাই দেবো। আর যারা কৃতজ্ঞ তাদেরকে আমি প্রতিদান দেবো\qt@no{(145)}}
\qt@newcmd\qurantrans@bn@cdxxxix{আর বহু নবী ছিলেন, যাঁদের সঙ্গী-সাথীরা তাঁদের অনুবর্তী হয়ে জেহাদ করেছে; আল্লাহর পথে-তাদের কিছু কষ্ট হয়েছে বটে, কিন্তু আল্লাহর রাহে তারা হেরেও যায়নি, ক্লান্তও হয়নি এবং দমেও যায়নি। আর যারা সবর করে, আল্লাহ তাদেরকে ভালবাসেন।\qt@no{(146)}}
\qt@newcmd\qurantrans@bn@cdxl{তারা আর কিছুই বলেনি-শুধু বলেছে, হে আমাদের পালনকর্তা! মোচন করে দাও আমাদের পাপ এবং যা কিছু বাড়াবাড়ি হয়ে গেছে আমাদের কাজে। আর আমাদিগকে দৃঢ় রাখ এবং কাফেরদের উপর আমাদিগকে সাহায্য কর।\qt@no{(147)}}
\qt@newcmd\qurantrans@bn@cdxli{অতঃপর আল্লাহ তাদেরকে দুনিয়ার সওয়াব দান করেছেন এবং যথার্থ আখেরাতের সওয়াব। আর যারা সৎকর্মশীল আল্লাহ তাদেরকে ভালবাসেন।\qt@no{(148)}}
\qt@newcmd\qurantrans@bn@cdxlii{হে ঈমানদারগণ! তোমরা যদি কাফেরদের কথা শোন, তাহলে ওরা তোমাদেরকে পেছনে ফিরিয়ে দেবে, তাতে তোমরা ক্ষতির সম্মুখীণ হয়ে পড়বে।\qt@no{(149)}}
\qt@newcmd\qurantrans@bn@cdxliii{বরং আল্লাহ তোমাদের সাহায্যকারী, আর তাঁর সাহায্যই হচ্ছে উত্তম সাহায্য।\qt@no{(150)}}
\qt@newcmd\qurantrans@bn@cdxliv{খুব শীঘ্রই আমি কাফেরদের মনে ভীতির সঞ্চার করবো। কারণ, ওরা আল্লাহর সাথে অংশীদার সাব্যস্ত করে যে সম্পর্কে কোন সনদ অবতীর্ণ করা হয়নি। আর ওদের ঠিকানা হলো দোযখের আগুন। বস্তুতঃ জালেমদের ঠিকানা অত্যন্ত নিকৃষ্ট।\qt@no{(151)}}
\qt@newcmd\qurantrans@bn@cdxlv{আর আল্লাহ সে ওয়াদাকে সত্যে পরিণত করেছেন, যখন তোমরা তাঁরই নির্দেশে ওদের খতম করছিলে। এমনকি যখন তোমরা ছত্রভঙ্গ হয়ে পড়েছে ও কর্তব্য স্থির করার ব্যাপারে বিবাদে লিপ্ত হয়েছে। আর যা তোমরা চাইতে তা দেখার পর কৃতঘ্নতা প্রদর্শন করেছ, তাতে তোমাদের কারো কাম্য ছিল দুনিয়া আর কারো বা কাম্য ছিল আখেরাত। অতঃপর তোমাদিগকে সরিয়ে দিলেন ওদের উপর থেকে যাতে তোমাদিগকে পরীক্ষা করেন। বস্তুতঃ তিনি তোমাদিগকে ক্ষমা করেছেন। আর আল্লাহর মুমিনদের প্রতি অনুগ্রহশীল।\qt@no{(152)}}
\qt@newcmd\qurantrans@bn@cdxlvi{আর তোমরা উপরে উঠে যাচ্ছিলে এবং পেছন দিকে ফিরে তাকাচ্ছিলে না কারো প্রতি, অথচ রসূল ডাকছিলেন তোমাদিগকে তোমাদের পেছন দিক থেকে। অতঃপর তোমাদের উপর এলো শোকের ওপরে শোক, যাতে তোমরা হাত থেকে বেরিয়ে যাওয়া বস্তুর জন্য দুঃখ না কর এবং যার সম্মুখীণ হচ্ছ সেজন্য বিমর্ষ না হও। আর আল্লাহ তোমাদের কাজের ব্যাপারে অবহিত রয়েছেন।\qt@no{(153)}}
\qt@newcmd\qurantrans@bn@cdxlvii{অতঃপর তোমাদের উপর শোকের পর শান্তি অবতীর্ণ করলেন, যা ছিল তন্দ্রার মত। সে তন্দ্রায় তোমাদের মধ্যে কেউ কেউ ঝিমোচ্ছিল আর কেউ কেউ প্রাণের ভয়ে ভাবছিল। আল্লাহ সম্পর্কে তাদের মিথ্যা ধারণা হচ্ছিল মুর্খদের মত। তারা বলছিল আমাদের হাতে কি কিছুই করার নেই? তুমি বল, সবকিছুই আল্লাহর হাতে। তারা যা কিছু মনে লুকিয়ে রাখে-তোমার নিকট প্রকাশ করে না সে সবও। তারা বলে আমাদের হাতে যদি কিছু করার থাকতো, তাহলে আমরা এখানে নিহত হতাম না। তুমি বল, তোমরা যদি নিজেদের ঘরেও থাকতে তবুও তারা অবশ্যই বেরিয়ে আসত নিজেদের অবস্থান থেকে যাদের মৃত্যু লিখে দেয়া হয়েছে। তোমাদের বুকে যা রয়েছে তার পরীক্ষা করা ছিল আল্লাহর ইচ্ছা, আর তোমাদের অন্তরে যা কিছু রয়েছে তা পরিষ্কার করা ছিল তাঁর কাম্য। আল্লাহ মনের গোপন বিষয় জানেন।\qt@no{(154)}}
\qt@newcmd\qurantrans@bn@cdxlviii{তোমাদের যে দুটি দল লড়াইয়ের দিনে ঘুরে দাঁড়িয়েছিল শয়তান তাদেরকে বিভ্রান্ত করেছিল, তাদেরই পাপের দরুন।\qt@no{(155)}}
\qt@newcmd\qurantrans@bn@cdxlix{হে ঈমাণদারগণ! তোমরা তাদের মত হয়ো না, যারা কাফের হয়েছে এবং নিজেদের ভাই বন্ধুরা যখন কোন অভিযানে বের হয় কিংবা জেহাদে যায়, তখন তাদের সম্পর্কে বলে, তারা যদি আমাদের সাথে থাকতো, তাহলে মরতোও না আহতও হতো না। যাতে তারা এ ধারণা সৃষ্টির মাধ্যমে সংশ্লিষ্টদের মনে অনুতাপ সৃষ্টি করতে পারে। অথচ আল্লাহই জীবন দান করেন এবং মৃত্যু দেন। তোমাদের সমস্ত কাজই, তোমরা যা কিছুই কর না কেন, আল্লাহ সবকিছুৃই দেখেন।\qt@no{(156)}}
\qt@newcmd\qurantrans@bn@cdl{আর তোমরা যদি আল্লাহর পথে নিহত হও কিংবা মৃত্যুবরণ কর, তোমরা যা কিছু সংগ্রহ করে থাক আল্লাহ তা’আলার ক্ষমা ও করুণা সে সবকিছুর চেয়ে উত্তম।\qt@no{(157)}}
\qt@newcmd\qurantrans@bn@cdli{আর তোমরা মৃত্যুই বরণ কর অথবা নিহতই হও, অবশ্য আল্লাহ তা’আলার সামনেই সমবেত হবে।\qt@no{(158)}}
\qt@newcmd\qurantrans@bn@cdlii{আল্লাহর রহমতেই আপনি তাদের জন্য কোমল হৃদয় হয়েছেন পক্ষান্তরে আপনি যদি রাগ ও কঠিন হৃদয় হতেন তাহলে তারা আপনার কাছ থেকে বিচ্ছিন্ন হয়ে যেতো। কাজেই আপনি তাদের ক্ষমা করে দিন এবং তাদের জন্য মাগফেরাত কামনা করুন এবং কাজে কর্মে তাদের পরামর্শ করুন। অতঃপর যখন কোন কাজের সিদ্ধান্ত গ্রহণ করে ফেলেন, তখন আল্লাহ তা’আলার উপর ভরসা করুন আল্লাহ তাওয়াক্কুল কারীদের ভালবাসেন।\qt@no{(159)}}
\qt@newcmd\qurantrans@bn@cdliii{যদি আল্লাহ তোমাদের সহায়তা করেন, তাহলে কেউ তোমাদের উপর পরাক্রান্ত হতে পারবে না। আর যদি তিনি তোমাদের সাহায্য না করেন, তবে এমন কে আছে, যে তোমাদের সাহায্য করতে পারে? আর আল্লাহর ওপরই মুসলমানগনের ভরসা করা উচিত।\qt@no{(160)}}
\qt@newcmd\qurantrans@bn@cdliv{আর কোন বিষয় গোপন করে রাখা নবীর কাজ নয়। আর যে লোক গোপন করবে সে কিয়ামতের দিন সেই গোপন বস্তু নিয়ে আসবে। অতঃপর পরিপূর্ণভাবে পাবে প্রত্যেকে, যা সে অর্জন করেছে। আর তাদের প্রতি কোন অন্যায় করা হবে না।\qt@no{(161)}}
\qt@newcmd\qurantrans@bn@cdlv{যে লোক আল্লাহর ইচ্ছার অনুগত, সে কি ঐ লোকের সমান হতে পারে, যে আল্লাহর রোষ অর্জন করেছে? বস্তুতঃ তার ঠিকানা হল দোযখ। আর তা কতইনা নিকৃষ্ট অবস্থান!\qt@no{(162)}}
\qt@newcmd\qurantrans@bn@cdlvi{আল্লাহর নিকট মানুষের মর্যাদা বিভিন্ন স্তরের আর আল্লাহ দেখেন যা কিছু তারা করে।\qt@no{(163)}}
\qt@newcmd\qurantrans@bn@cdlvii{আল্লাহ ঈমানদারদের উপর অনুগ্রহ করেছেন যে, তাদের মাঝে তাদের নিজেদের মধ্য থেকে নবী পাঠিয়েছেন। তিনি তাদের জন্য তাঁর আয়াতসমূহ পাঠ করেন। তাদেরকে পরিশোধন করেন এবং তাদেরকে কিতাব ও কাজের কথা শিক্ষা দেন। বস্তুতঃ তারা ছিল পূর্ব থেকেই পথভ্রষ্ট।\qt@no{(164)}}
\qt@newcmd\qurantrans@bn@cdlviii{যখন তোমাদের উপর একটি মুসীবত এসে পৌছাল, অথচ তোমরা তার পূর্বেই দ্বিগুণ কষ্টে পৌছে গিয়েছ, তখন কি তোমরা বলবে, এটা কোথা থেকে এল? তাহলে বলে দাও, এ কষ্ট তোমাদের উপর পৌছেছে তোমারই পক্ষ থেকে। নিশ্চয়ই আল্লাহ প্রত্যেক বিষয়ের উপর ক্ষমতাশীল।\qt@no{(165)}}
\qt@newcmd\qurantrans@bn@cdlix{আর যেদিন দু’দল সৈন্যের মোকাবিলা হয়েছে; সেদিন তোমাদের উপর যা আপতিত হয়েছে তা আল্লাহর হুকুমেই হয়েছে এবং তা এজন্য যে, তাতে ঈমানদারদিগকে জানা যায়।\qt@no{(166)}}
\qt@newcmd\qurantrans@bn@cdlx{এবং তাদেরকে যাতে সনাক্ত করা যায় যারা মুনাফিক ছিল। আর তাদেরকে বলা হল এসো, আল্লাহর রাহে লড়াই কর কিংবা শত্রুদিগকে প্রতিহত কর। তারা বলেছিল, আমরা যদি জানতাম যে, লড়াই হবে, তাহলে অবশ্যই তোমাদের সাথে থাকতাম। সে দিন তারা ঈমানের তুলনায় কুফরীর কাছাকাছি ছিল। যা তাদের অন্তরে নেই তারা নিজের মুখে সে কথাই বলে বস্তুতঃআল্লাহ ভালভাবে জানেন তারা যা কিছু গোপন করে থাকে।\qt@no{(167)}}
\qt@newcmd\qurantrans@bn@cdlxi{ওরা হলো যে সব লোক, যারা বসে থেকে নিজেদের ভাইদের সম্বদ্ধে বলে, যদি তারা আমাদের কথা শুনত, তবে নিহত হত না। তাদেরকে বলে দিন, এবার তোমাদের নিজেদের উপর থেকে মৃত্যুকে সরিয়ে দাও, যদি তোমরা সত্যবাদী হয়ে থাক।\qt@no{(168)}}
\qt@newcmd\qurantrans@bn@cdlxii{আর যারা আল্লাহর রাহে নিহত হয়, তাদেরকে তুমি কখনো মৃত মনে করো না। বরং তারা নিজেদের পালনকর্তার নিকট জীবিত ও জীবিকাপ্রাপ্ত।\qt@no{(169)}}
\qt@newcmd\qurantrans@bn@cdlxiii{আল্লাহ নিজের অনুগ্রহ থেকে যা দান করেছেন তার প্রেক্ষিতে তারা আনন্দ উদযাপন করছে। আর যারা এখনও তাদের কাছে এসে পৌঁছেনি তাদের পেছনে তাদের জন্যে আনন্দ প্রকাশ করে। কারণ, তাদের কোন ভয় ভীতিও নেই এবং কোন চিন্তা ভাবনাও নেই।\qt@no{(170)}}
\qt@newcmd\qurantrans@bn@cdlxiv{আল্লাহর নেয়ামত ও অনুগ্রহের জন্যে তারা আনন্দ প্রকাশ করে এবং তা এভাবে যে, আল্লাহ, ঈমানদারদের শ্রমফল বিনষ্ট করেন না।\qt@no{(171)}}
\qt@newcmd\qurantrans@bn@cdlxv{যারা আহত হয়ে পড়ার পরেও আল্লাহ এবং তাঁর রসূলের নির্দেশ মান্য করেছে, তাদের মধ্যে যারা সৎ ও পরহেযগার, তাদের জন্য রয়েছে মহান সওয়াব।\qt@no{(172)}}
\qt@newcmd\qurantrans@bn@cdlxvi{যাদেরকে লোকেরা বলেছে যে, তোমাদের সাথে মোকাবেলা করার জন্য লোকেরা সমাবেশ করেছে বহু সাজ-সরঞ্জাম; তাদের ভয় কর। তখন তাদের বিশ্বাস আরও দৃঢ়তর হয়ে যায় এবং তারা বলে, আমাদের জন্য আল্লাহই যথেষ্ট; কতই না চমৎকার কামিয়াবীদানকারী।\qt@no{(173)}}
\qt@newcmd\qurantrans@bn@cdlxvii{অতঃপর ফিরে এল মুসলমানরা আল্লাহর অনুগ্রহ নিয়ে, তদের কিছুই অনিষ্ট হলো না। তারপর তারা আল্লাহর ইচ্ছার অনুগত হল। বস্তুতঃ আল্লাহর অনুগ্রহ অতি বিরাট।\qt@no{(174)}}
\qt@newcmd\qurantrans@bn@cdlxviii{এরা যে রয়েছে, এরাই হলে শয়তান, এরা নিজেদের বন্ধুদের ব্যাপারে ভীতি প্রদর্শন করে। সুতরাং তোমরা তাদের ভয় করো না। আর তোমরা যদি ঈমানদার হয়ে থাক, তবে আমাকে ভয় কর।\qt@no{(175)}}
\qt@newcmd\qurantrans@bn@cdlxix{আর যারা কুফরের দিকে ধাবিত হচ্ছে তারা যেন তোমাদিগকে চিন্তাম্বিত করে না তোলে। তারা আল্লাহ তা’আলার কোন কিছুই অনিষ্ট সাধন করতে পারবে না। আখেরাতে তাদেরকে কোন কল্যাণ দান না করাই আল্লাহর ইচ্ছা। বস্তুতঃ তাদের জন্যে রয়েছে মহা শাস্তি।\qt@no{(176)}}
\qt@newcmd\qurantrans@bn@cdlxx{যারা ঈমানের পরিবর্তে কুফর ক্রয় করে নিয়েছে, তারা আল্লাহ তা’আলার কিছুই ক্ষতিসাধন করতে পারবে না। আর তাদের জন্য রয়েছে বেদনাদায়ক শাস্তি।\qt@no{(177)}}
\qt@newcmd\qurantrans@bn@cdlxxi{কাফেররা যেন মনে না করে যে আমি যে, অবকাশ দান করি, তা তাদের পক্ষে কল্যাণকর। আমি তো তাদেরকে অবকাশ দেই যাতে করে তারা পাপে উন্নতি লাভ করতে পারে। বস্তুতঃ তাদের জন্য রয়েছে লাঞ্ছনাজনক শাস্তি।\qt@no{(178)}}
\qt@newcmd\qurantrans@bn@cdlxxii{নাপাককে পাক থেকে পৃথক করে দেয়া পর্যন্ত আল্লাহ এমন নন যে, ঈমানদারগণকে সে অবস্থাতেই রাখবেন যাতে তোমরা রয়েছ, আর আল্লাহ এমন নন যে, তোমাদিগকে গায়বের সংবাদ দেবেন। কিন্তু আল্লাহ স্বীয় রসূল গণের মধ্যে যাকে ইচ্ছা বাছাই করে নিয়েছেন। সুতরাং আল্লাহর ওপর এবং তাঁর রসূলগণের ওপর তোমরা প্রত্যয় স্থাপন কর। বস্তুতঃ তোমরা যদি বিশ্বাস ও পরহেযগারীর ওপর প্রতিষ্ঠিত থেকে থাক, তবে তোমাদের জন্যে রয়েছে বিরাট প্রতিদান।\qt@no{(179)}}
\qt@newcmd\qurantrans@bn@cdlxxiii{আল্লাহ তাদেরকে নিজের অনুগ্রহে যা দান করেছেন তাতে যারা কৃপণতা করে এই কার্পন্য তাদের জন্য মঙ্গলকর হবে বলে তারা যেন ধারণা না করে। বরং এটা তাদের পক্ষে একান্তই ক্ষতিকর প্রতিপন্ন হবে। যাতে তারা কার্পন্য করে সে সমস্ত ধন-সম্পদকে কিয়ামতের দিন তাদের গলায় বেড়ী বানিয়ে পরানো হবে। আর আল্লাহ হচ্ছেন আসমান ও যমীনের পরম সত্ত্বাধিকারী। আর যা কিছু তোমরা কর; আল্লাহ সে সম্পর্কে জানেন।\qt@no{(180)}}
\qt@newcmd\qurantrans@bn@cdlxxiv{নিঃসন্দেহে আল্লাহ তাদের কথা শুনেছেন, যারা বলেছে যে, আল্লাহ হচ্ছেন অভাবগ্রস্ত আর আমরা বিত্তবান! এখন আমি তাদের কথা এবং যেসব নবীকে তারা অন্যায়ভাবে হত্যা করেছে তা লিখে রাখব, অতঃপর বলব, আস্বাদন কর জ্বলন্ত আগুনের আযাব।\qt@no{(181)}}
\qt@newcmd\qurantrans@bn@cdlxxv{এ হল তারই প্রতিফল যা তোমরা ইতিপূর্বে নিজের হাতে পাঠিয়েছ। বস্তুতঃ আল্লাহ বান্দাদের প্রতি অত্যাচার করেন না।\qt@no{(182)}}
\qt@newcmd\qurantrans@bn@cdlxxvi{সে সমস্ত লোক, যারা বলে যে, আল্লাহ আমাদিগকে এমন কোন রসূলের ওপর বিশ্বাস না করতে বলে রেখেছেন যতক্ষণ না তারা আমাদের নিকট এমন কোরবানী নিয়ে আসবেন যাকে আগুন গ্রাস করে নেবে। তুমি তাদের বলে দাও, তোমাদের মাঝে আমার পূর্বে বহু রসূল নিদর্শনসমূহ এবং তোমরা যা আব্দার করেছ তা নিয়ে এসেছিলেন, তখন তোমরা কেন তাদেরকে হত্যা করলে যদি তোমরা সত্য হয়ে থাক।\qt@no{(183)}}
\qt@newcmd\qurantrans@bn@cdlxxvii{তাছাড়া এরা যদি তোমাকে মিথ্যা প্রতিপন্ন করে, তবে তোমার পূর্বেও এরা এমন বহু নবীকে মিথ্যা প্রতিপন্ন করেছে, যারা নিদর্শন সমূহ নিয়ে এসেছিলেন। এবং এনেছিলেন সহীফা ও প্রদীপ্ত গ্রন্থ।\qt@no{(184)}}
\qt@newcmd\qurantrans@bn@cdlxxviii{প্রত্যেক প্রাণীকে আস্বাদন করতে হবে মৃত্যু। আর তোমরা কিয়ামতের দিন পরিপূর্ণ বদলা প্রাপ্ত হবে। তারপর যাকে দোযখ থেকে দূরে রাখা হবে এবং জান্নাতে প্রবেশ করানো হবে, তার কার্যসিদ্ধি ঘটবে। আর পার্থিব জীবন ধোঁকা ছাড়া অন্য কোন সম্পদ নয়।\qt@no{(185)}}
\qt@newcmd\qurantrans@bn@cdlxxix{অবশ্য ধন-সম্পদে এবং জনসম্পদে তোমাদের পরীক্ষা হবে এবং অবশ্য তোমরা শুনবে পূর্ববর্তী আহলে কিতাবদের কাছে এবং মুশরেকদের কাছে বহু অশোভন উক্তি। আর যদি তোমরা ধৈর্য্য ধারণ কর এবং পরহেযগারী অবলম্বন কর, তবে তা হবে একান্ত সৎসাহসের ব্যাপার।\qt@no{(186)}}
\qt@newcmd\qurantrans@bn@cdlxxx{আর আল্লাহ যখন আহলে কিতাবদের কাছ থেকে প্রতিজ্ঞা গ্রহণ করলেন যে, তা মানুষের নিকট বর্ণনা করবে এবং গোপন করবে না, তখন তারা সে প্রতিজ্ঞাকে নিজেদের পেছনে ফেলে রাখল আর তার কেনা-বেচা করল সামান্য মূল্যের বিনিময়ে। সুতরাং কতই না মন্দ তাদের এ বেচা-কেনা।\qt@no{(187)}}
\qt@newcmd\qurantrans@bn@cdlxxxi{তুমি মনে করো না, যারা নিজেদের কৃতকর্মের উপর আনন্দিত হয় এবং না করা বিষয়ের জন্য প্রশংসা কামনা করে, তারা আমার নিকট থেকে অব্যাহতি লাভ করেছে। বস্তুতঃ তাদের জন্যে রয়েছে বেদনাদায়ক আযাব।\qt@no{(188)}}
\qt@newcmd\qurantrans@bn@cdlxxxii{আর আল্লাহর জন্যই হল আসমান ও যমিনের বাদশাহী। আল্লাহই সর্ব বিষয়ে ক্ষমতার অধিকারী।\qt@no{(189)}}
\qt@newcmd\qurantrans@bn@cdlxxxiii{নিশ্চয় আসমান ও যমীন সৃষ্টিতে এবং রাত্রি ও দিনের আবর্তনে নিদর্শন রয়েছে বোধ সম্পন্ন লোকদের জন্যে।\qt@no{(190)}}
\qt@newcmd\qurantrans@bn@cdlxxxiv{যাঁরা দাঁড়িয়ে, বসে, ও শায়িত অবস্থায় আল্লাহকে স্মরণ করে এবং চিন্তা গবেষণা করে আসমান ও জমিন সৃষ্টির বিষযে, (তারা বলে) পরওয়ারদেগার! এসব তুমি অনর্থক সৃষ্টি করনি। সকল পবিত্রতা তোমারই, আমাদিগকে তুমি দোযখের শাস্তি থেকে বাঁচাও।\qt@no{(191)}}
\qt@newcmd\qurantrans@bn@cdlxxxv{হে আমাদের পালনকর্তা! নিশ্চয় তুমি যাকে দোযখে নিক্ষেপ করলে তাকে সবসময়ে অপমানিত করলে; আর জালেমদের জন্যে তো সাহায্যকারী নেই।\qt@no{(192)}}
\qt@newcmd\qurantrans@bn@cdlxxxvi{হে আমাদের পালনকর্তা! আমরা নিশ্চিতরূপে শুনেছি একজন আহবানকারীকে ঈমানের প্রতি আহবান করতে যে, তোমাদের পালনকর্তার প্রতি ঈমান আন; তাই আমরা ঈমান এনেছি। হে আমাদের পালনকর্তা! অতঃপর আমাদের সকল গোনাহ মাফ কর এবং আমাদের সকল দোষত্রুটি দুর করে দাও, আর আমাদের মৃত্যু দাও নেক লোকদের সাথে।\qt@no{(193)}}
\qt@newcmd\qurantrans@bn@cdlxxxvii{হে আমাদের পালনকর্তা! আমাদেরকে দাও, যা তুমি ওয়াদা করেছ তোমার রসূলগণের মাধ্যমে এবং কিয়ামতের দিন আমাদিগকে তুমি অপমানিত করো না। নিশ্চয় তুমি ওয়াদা খেলাফ করো না।\qt@no{(194)}}
\qt@newcmd\qurantrans@bn@cdlxxxviii{অতঃপর তাদের পালনকর্তা তাদের দোয়া (এই বলে) কবুল করে নিলেন যে, আমি তোমাদের কোন পরিশ্রমকারীর পরিশ্রমই বিনষ্ট করি না, তা সে পুরুষ হোক কিংবা স্ত্রীলোক। তোমরা পরস্পর এক। তারপর সে সমস্ত লোক যারা হিজরত করেছে, তাদেরকে নিজেদের দেশ থেকে বের করে দেওয়া হয়েছে এবং তাদের প্রতি উৎপীড়ন করা হয়েছে আমার পথে এবং যারা লড়াই করেছে ও মৃত্যুবরণ করেছে, অবশ্যই আমি তাদের উপর থেকে অকল্যাণকে অপসারিত করব। এবং তাদেরকে প্রবিষ্ট করব জান্নাতে যার তলদেশে নহর সমূহ প্রবাহিত। এই হলো বিনিময় আল্লাহর পক্ষ থেকে। আর আল্লাহর নিকট রয়েছে উত্তম বিনিময়।\qt@no{(195)}}
\qt@newcmd\qurantrans@bn@cdlxxxix{নগরীতে কাফেরদের চাল-চলন যেন তোমাদিগকে ধোঁকা না দেয়।\qt@no{(196)}}
\qt@newcmd\qurantrans@bn@cdxc{এটা হলো সামান্য ফায়দা-এরপর তাদের ঠিকানা হবে দোযখ। আর সেটি হলো অতি নিকৃষ্ট অবস্থান।\qt@no{(197)}}
\qt@newcmd\qurantrans@bn@cdxci{কিন্তু যারা ভয় করে নিজেদের পালনকর্তাকে তাদের জন্যে রয়েছে জান্নাত যার তলদেশে প্রবাহিত রয়েছে প্রস্রবণ। তাতে আল্লাহর পক্ষ থেকে সদা আপ্যায়ন চলতে থাকবে। আর যা আল্লাহর নিকট রয়েছে, তা সৎকর্মশীলদের জন্যে একান্তই উত্তম।\qt@no{(198)}}
\qt@newcmd\qurantrans@bn@cdxcii{আর আহলে কিতাবদের মধ্যে কেউ কেউ এমনও রয়েছে, যারা আল্লাহর উপর ঈমান আনে এবং যা কিছু তোমার উপর অবতীর্ণ হয় আর যা কিছু তাদের উপর অবতীর্ণ হয়েছে সেগুলোর উপর, আল্লাহর সামনে বিনয়াবনত থাকে এবং আল্লার আয়াতসমুহকে স্বল্পমুল্যের বিনিময়ে সওদা করে না, তারাই হলো সে লোক যাদের জন্য পারিশ্রমিক রয়েছে তাদের পালনকর্তার নিকট। নিশ্চয়ই আল্লাহ যথাশীঘ্র হিসাব চুকিয়ে দেন।\qt@no{(199)}}
\qt@newcmd\qurantrans@bn@cdxciii{হে ঈমানদানগণ! ধৈর্য্য ধারণ কর এবং মোকাবেলায় দৃঢ়তা অবলম্বন কর। আর আল্লাহকে ভয় করতে থাক যাতে তোমরা তোমাদের উদ্দেশ্য লাভে সমর্থ হতে পার।\qt@no{(200)}}
\qt@newcmd\qurantrans@bn@cdxciv{\basmalahbn হে মানব সমাজ! তোমরা তোমাদের পালনকর্তাকে ভয় কর, যিনি তোমাদেরকে এক ব্যক্তি থেকে সৃষ্টি করেছেন এবং যিনি তার থেকে তার সঙ্গীনীকে সৃষ্টি করেছেন; আর বিস্তার করেছেন তাদের দু’জন থেকে অগণিত পুরুষ ও নারী। আর আল্লাহকে ভয় কর, যাঁর নামে তোমরা একে অপরের নিকট যাচঞ্ঝা করে থাক এবং আত্নীয় জ্ঞাতিদের ব্যাপারে সতর্কতা অবলম্বন কর। নিশ্চয় আল্লাহ তোমাদের ব্যাপারে সচেতন রয়েছেন।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@cdxcv{এতীমদেরকে তাদের সম্পদ বুঝিয়ে দাও। খারাপ মালামালের সাথে ভালো মালামালের অদল-বদল করো না। আর তাদের ধন-সম্পদ নিজেদের ধন-সম্পদের সাথে সংমিশ্রিত করে তা গ্রাস করো না। নিশ্চয় এটা বড়ই মন্দ কাজ।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@cdxcvi{আর যদি তোমরা ভয় কর যে, এতীম মেয়েদের হক যথাথভাবে পুরণ করতে পারবে না, তবে সেসব মেয়েদের মধ্যে থেকে যাদের ভাল লাগে তাদের বিয়ে করে নাও দুই, তিন, কিংবা চারটি পর্যন্ত। আর যদি এরূপ আশঙ্কা কর যে, তাদের মধ্যে ন্যায় সঙ্গত আচরণ বজায় রাখতে পারবে না, তবে, একটিই অথবা তোমাদের অধিকারভুক্ত দাসীদেরকে; এতেই পক্ষপাতিত্বে জড়িত না হওয়ার অধিকতর সম্ভাবনা।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@cdxcvii{আর তোমরা স্ত্রীদেরকে তাদের মোহর দিয়ে দাও খুশীমনে। তারা যদি খুশী হয়ে তা থেকে অংশ ছেড়ে দেয়, তবে তা তোমরা স্বাচ্ছন্দ্যে ভোগ কর।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@cdxcviii{আর যে সম্পদকে আল্লাহ তোমাদের জীবন-যাত্রার অবলম্বন করেছেন, তা অর্বাচীনদের হাতে তুলে দিও না। বরং তা থেকে তাদেরকে খাওয়াও, পরাও এবং তাদেরকে সান্তনার বানী শোনাও।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@cdxcix{আর এতীমদের প্রতি বিশেষভাবে নজর রাখবে, যে পর্যন্ত না তারা বিয়ের বয়সে পৌঁছে। যদি তাদের মধ্যে বুদ্ধি-বিবেচনার উন্মেষ আঁচ করতে পার, তবে তাদের সম্পদ তাদের হাতে অর্পন করতে পার। এতীমের মাল প্রয়োজনাতিরিক্ত খরচ করো না বা তারা বড় হয়ে যাবে মনে করে তাড়াতাড়ি খেয়ে ফেলো না। যারা স্বচ্ছল তারা অবশ্যই এতীমের মাল খরচ করা থেকে বিরত থাকবে। আর যে অভাবগ্রস্ত সে সঙ্গত পরিমাণ খেতে পারে। যখন তাদের হাতে তাদের সম্পদ প্রত্যার্পণ কর, তখন সাক্ষী রাখবে। অবশ্য আল্লাহই হিসাব নেয়ার ব্যাপারে যথেষ্ট।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@d{পিতা-মাতা ও আত্নীয়-স্বজনদের পরিত্যক্ত সম্পত্তিতে পুরুষদেরও অংশ আছে এবং পিতা-মাতা ও আত্নীয়-স্বজনদের পরিত্যক্ত সম্পত্তিতে নারীদেরও অংশ আছে; অল্প হোক কিংবা বেশী। এ অংশ নির্ধারিত।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@di{সম্পতি বন্টনের সময় যখন আত্নীয়-স্বজন, এতীম ও মিসকীন উপস্থিত হয়, তখন তা থেকে তাদের কিছু খাইয়ে দাও এবং তাদের সাথে কিছু সদালাপ করো।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@dii{তাদের ভয় করা উচিত, যারা নিজেদের পশ্চাতে দুর্বল অক্ষম সন্তান-সন্ততি ছেড়ে গেলে তাদের জন্যে তারাও আশঙ্কা করে; সুতরাং তারা যেন আল্লাহকে ভয় করে এবং সংগত কথা বলে।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@diii{যারা এতীমদের অর্থ-সম্পদ অন্যায়ভাবে খায়, তারা নিজেদের পেটে আগুনই ভর্তি করেছে এবং সত্ত্বরই তারা অগ্নিতে প্রবেশ করবে।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@div{আল্লাহ তোমাদেরকে তোমাদের সন্তানদের সম্পর্কে আদেশ করেনঃ একজন পুরুষের অংশ দু?জন নারীর অংশের সমান। অতঃপর যদি শুধু নারীই হয় দু' এর অধিক, তবে তাদের জন্যে ঐ মালের তিন ভাগের দুই ভাগ যা ত্যাগ করে মরে এবং যদি একজনই হয়, তবে তার জন্যে অর্ধেক। মৃতের পিতা-মাতার মধ্য থেকে প্রত্যেকের জন্যে ত্যাজ্য সম্পত্তির ছয় ভাগের এক ভাগ, যদি মৃতের পুত্র থাকে। যদি পুত্র না থাকে এবং পিতা-মাতাই ওয়ারিস হয়, তবে মাতা পাবে তিন ভাগের এক ভাগ। অতঃপর যদি মৃতের কয়েকজন ভাই থাকে, তবে তার মাতা পাবে ছয় ভাগের এক ভাগ ওছিয়্যতের পর, যা করে মরেছে কিংবা ঋণ পরিশোধের পর। তোমাদের পিতা ও পুত্রের মধ্যে কে তোমাদের জন্যে অধিক উপকারী তোমরা জান না। এটা আল্লাহ কতৃক নির্ধারিত অংশ নিশ্চয় আল্লাহ সর্বজ্ঞ, রহস্যবিদ।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@dv{আর, তোমাদের হবে অর্ধেক সম্পত্তি, যা ছেড়ে যায় তোমাদের স্ত্রীরা যদি তাদের কোন সন্তান না থাকে। যদি তাদের সন্তান থাকে, তবে তোমাদের হবে এক-চতুর্থাংশ ঐ সম্পত্তির, যা তারা ছেড়ে যায়; ওছিয়্যতের পর, যা তারা করে এবং ঋণ পরিশোধের পর। স্ত্রীদের জন্যে এক-চতুর্থাংশ হবে ঐ সম্পত্তির, যা তোমরা ছেড়ে যাও যদি তোমাদের কোন সন্তান না থাকে। আর যদি তোমাদের সন্তান থাকে, তবে তাদের জন্যে হবে ঐ সম্পত্তির আট ভাগের এক ভাগ, যা তোমরা ছেড়ে যাও ওছিয়্যতের পর, যা তোমরা কর এবং ঋণ পরিশোধের পর। যে পুরুষের, ত্যাজ্য সম্পত্তি, তার যদি পিতা-পুত্র কিংবা স্ত্রী না থাকে এবং এই মৃতের এক ভাই কিংবা এক বোন থাকে, তবে উভয়ের প্রত্যেকে ছয়-ভাগের এক পাবে। আর যদি ততোধিক থাকে, তবে তারা এক তৃতীয়াংশ অংশীদার হবে ওছিয়্যতের পর, যা করা হয় অথবা ঋণের পর এমতাবস্থায় যে, অপরের ক্ষতি না করে। এ বিধান আল্লাহর। আল্লাহ সর্বজ্ঞ, সহনশীল।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@dvi{এগুলো আল্লাহর নির্ধারিত সীমা। যে কেউ আল্লাহ ও রসূলের আদেশমত চলে, তিনি তাকে জান্নাত সমূহে প্রবেশ করাবেন, যেগুলোর তলদেশ দিয়ে স্রোতস্বিনী প্রবাহিত হবে। তারা সেখানে চিরকাল থাকবে। এ হল বিরাট সাফল্য।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@dvii{যে কেউ আল্লাহ ও রসূলের অবাধ্যতা করে এবং তার সীমা অতিক্রম করে তিনি তাকে আগুনে প্রবেশ করাবেন। সে সেখানে চিরকাল থাকবে। তার জন্যে রয়েছে অপমানজনক শাস্তি।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@dviii{আর তোমাদের নারীদের মধ্যে যারা ব্যভিচারিণী তাদের বিরুদ্ধে তোমাদের মধ্য থেকে চার জন পুরুষকে সাক্ষী হিসেবে তলব কর। অতঃপর যদি তারা সাক্ষ্য প্রদান করে তবে সংশ্লিষ্টদেরকে গৃহে আবদ্ধ রাখ, যে পর্যন্ত মৃত্যু তাদেরকে তুলে না নেয় অথবা আল্লাহ তাদের জন্য অন্য কোন পথ নির্দেশ না করেন।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@dix{তোমাদের মধ্য থেকে যে দু’জন সেই কুকর্মে লিপ্ত হয়, তাদেরকে শাস্তি প্রদান কর। অতঃপর যদি উভয়ে তওবা করে এবং নিজেদের সংশোধন করে, তবে তাদের থেকে হাত গুটিয়ে নাও। নিশ্চয় আল্লাহ তওবা কবুলকারী, দয়ালু।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@dx{অবশ্যই আল্লাহ তাদের তওবা কবুল করবেন, যারা ভূলবশতঃ মন্দ কাজ করে, অতঃপর অনতিবিলম্বে তওবা করে; এরাই হল সেসব লোক যাদেরকে আল্লাহ ক্ষমা করে দেন। আল্লাহ মহাজ্ঞানী, রহস্যবিদ।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@dxi{আর এমন লোকদের জন্য কোন ক্ষমা নেই, যারা মন্দ কাজ করতেই থাকে, এমন কি যখন তাদের কারো মাথার উপর মৃত্যু উপস্থিত হয়, তখন বলতে থাকেঃ আমি এখন তওবা করছি। আর তওবা নেই তাদের জন্য, যারা কুফরী অবস্থায় মৃত্যুবরণ করে। আমি তাদের জন্য যন্ত্রণাদায়ক শাস্তি প্রস্তুত করে রেখেছি।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@dxii{হে ঈমাণদারগণ! বলপূর্বক নারীদেরকে উত্তরাধিকারে গ্রহন করা তোমাদের জন্যে হালাল নয় এবং তাদেরকে আটক রেখো না যাতে তোমরা তাদেরকে যা প্রদান করেছ তার কিয়দংশ নিয়ে নাও; কিন্তু তারা যদি কোন প্রকাশ্য অশ্লীলতা করে! নারীদের সাথে সদ্ভাবে জীবন-যাপন কর। অতঃপর যদি তাদেরকে অপছন্দ কর, তবে হয়ত তোমরা এমন এক জিনিসকে অপছন্দ করছ, যাতে আল্লাহ, অনেক কল্যাণ রেখেছেন।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@dxiii{যদি তোমরা এক স্ত্রীর স্থলে অন্য স্ত্রী পরিবর্তন করতে ইচ্ছা কর এবং তাদের একজনকে প্রচুর ধন-সম্পদ প্রদান করে থাক, তবে তা থেকে কিছুই ফেরত গ্রহণ করো না। তোমরা কি তা অন্যায়ভাবে ও প্রকাশ্য গোনাহর মাধ্যমে গ্রহণ করবে?\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@dxiv{তোমরা কিরূপে তা গ্রহণ করতে পার, অথচ তোমাদের একজন অন্য জনের কাছে গমন এবং নারীরা তোমাদের কাছে থেকে সুদৃঢ় অঙ্গীকার গ্রহণ করেছে।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@dxv{যে নারীকে তোমাদের পিতা-পিতামহ বিবাহ করেছে তোমরা তাদের বিবাহ করো না। কিন্তু যা বিগত হয়ে গেছে। এটা অশ্লীল, গযবের কাজ এবং নিকৃষ্ট আচরণ।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@dxvi{তোমাদের জন্যে হারাম করা হয়েছে তোমাদের মাতা, তোমাদের কন্যা, তোমাদের বোন, তোমাদের ফুফু, তোমাদের খালা, ভ্রাতৃকণ্যা; ভগিনীকণ্যা তোমাদের সে মাতা, যারা তোমাদেরকে স্তন্যপান করিয়েছে, তোমাদের দুধ-বোন, তোমাদের স্ত্রীদের মাতা, তোমরা যাদের সাথে সহবাস করেছ সে স্ত্রীদের কন্যা যারা তোমাদের লালন-পালনে আছে। যদি তাদের সাথে সহবাস না করে থাক, তবে এ বিবাহে তোমাদের কোন গোনাহ নেই। তোমাদের ঔরসজাত পুত্রদের স্ত্রী এবং দুই বোনকে একত্রে বিবাহ করা; কিন্তু যা অতীত হয়ে গেছে। নিশ্চয় আল্লাহ ক্ষমাকরী, দয়ালু।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@dxvii{এবং নারীদের মধ্যে তাদের ছাড়া সকল সধবা স্ত্রীলোক তোমাদের জন্যে নিষিদ্ধ; তোমাদের দক্ষিণ হস্ত যাদের মালিক হয়ে যায়-এটা তোমাদের জন্য আল্লাহর হুকুম। এদেরকে ছাড়া তোমাদের জন্যে সব নারী হালাল করা হয়েছে, শর্ত এই যে, তোমরা তাদেরকে স্বীয় অর্থের বিনিময়ে তলব করবে বিবাহ বন্ধনে আবদ্ধ করার জন্য-ব্যভিচারের জন্য নয়। অনন্তর তাদের মধ্যে যাকে তোমরা ভোগ করবে, তাকে তার নির্ধারিত হক দান কর। তোমাদের কোন গোনাহ হবে না যদি নির্ধারণের পর তোমরা পরস্পরে সম্মত হও। নিশ্চয় আল্লাহ সুবিজ্ঞ, রহস্যবিদ।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@dxviii{আর তোমাদের মধ্যে যে ব্যক্তি স্বাধীন মুসলমান নারীকে বিয়ে করার সামর্থ্য রাখে না, সে তোমাদের অধিকারভুক্ত মুসলিম ক্রীতদাসীদেরকে বিয়ে করবে। আল্লাহ তোমাদের ঈমান সম্পর্কে ভালোভাবে জ্ঞাত রয়েছেন। তোমরা পরস্পর এক, অতএব, তাদেরকে তাদের মালিকের অনুমতিক্রমে বিয়ে কর এবং নিয়ম অনুযায়ী তাদেরকে মোহরানা প্রদান কর এমতাবস্থায় যে, তারা বিবাহ বন্ধনে আবদ্ধ হবে-ব্যভিচারিণী কিংবা উপ-পতি গ্রহণকারিণী হবে না। অতঃপর যখন তারা বিবাহ বন্ধনে এসে যায়, তখন যদি কোন অশ্লীল কাজ করে, তবে তাদেরকে স্বাধীন নারীদের অর্ধেক শাস্তি ভোগ করতে হবে। এ ব্যবস্থা তাদের জন্যে, তোমাদের মধ্যে যারা ব্যভিচারে লিপ্ত হওয়ার ব্যাপারে ভয় করে। আর যদি সবর কর, তবে তা তোমাদের জন্যে উত্তম। আল্লাহ ক্ষমাশীল, করুণাময়।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@dxix{আল্লাহ তোমাদের জন্যে সব কিছু পরিষ্কার বর্ণনা করে দিতে চান, তোমাদের পূর্ববর্তীদের পথ প্রদর্শন করতে চান। এবং তোমাদেরকে ক্ষমা করতে চান, আল্লাহ মহাজ্ঞানী রহস্যবিদ।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@dxx{আল্লাহ তোমাদের প্রতি ক্ষমাশীল হতে চান, এবং যারা কামনা-বাসনার অনুসারী, তারা চায় যে, তোমরা পথ থেকে অনেক দূরে বিচ্যুত হয়ে পড়।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@dxxi{আল্লাহ তোমাদের বোঝা হালকা করতে চান। মানুষ দুর্বল সৃজিত হয়েছে।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@dxxii{হে ঈমানদারগণ! তোমরা একে অপরের সম্পদ অন্যায়ভাবে গ্রাস করো না। কেবলমাত্র তোমাদের পরস্পরের সম্মতিক্রমে যে ব্যবসা করা হয় তা বৈধ। আর তোমরা নিজেদের কাউকে হত্যা করো না। নিঃসন্দেহে আল্লাহ তা’আলা তোমাদের প্রতি দয়ালু।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@dxxiii{আর যে কেউ সীমালঙ্ঘন কিংবা জুলুমের বশবর্তী হয়ে এরূপ করবে, তাকে খুব শীঘ্রই আগুনে নিক্ষেপ করা হবে। এটা আল্লাহর পক্ষে খুবই সহজসাধ্য।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@dxxiv{যেগুলো সম্পর্কে তোমাদের নিষেধ করা হয়েছে যদি তোমরা সেসব বড় গোনাহ গুলো থেকে বেঁচে থাকতে পার। তবে আমি তোমাদের ক্রটি-বিচ্যুতিগুলো ক্ষমা করে দেব এবং সম্মান জনক স্থানে তোমাদের প্রবেশ করার।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@dxxv{আর তোমরা আকাঙ্ক্ষা করো না এমন সব বিষয়ে যাতে আল্লাহ তা’আলা তোমাদের একের উপর অপরের শ্রেষ্ঠত্ব দান করেছেন। পুরুষ যা অর্জন করে সেটা তার অংশ এবং নারী যা অর্জন করে সেটা তার অংশ। আর আল্লাহর কাছে তাঁর অনুগ্রহ প্রার্থনা কর। নিঃসন্দেহে আল্লাহ তা’আলা সর্ব বিষয়ে জ্ঞাত।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@dxxvi{পিতা-মাতা এবং নিকটাত্নীয়গণ যা ত্যাগ করে যান সেসবের জন্যই আমি উত্তরাধিকারী নির্ধারণ করে দিয়েছি। আর যাদের সাথে তোমরা অঙ্গীকারাবদ্ধ হয়েছ তাদের প্রাপ্য দিয়ে দাও। আল্লাহ তা’আলা নিঃসন্দেহে সব কিছুই প্রত্যক্ষ করেন।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@dxxvii{পুরুষেরা নারীদের উপর কৃর্তত্বশীল এ জন্য যে, আল্লাহ একের উপর অন্যের বৈশিষ্ট্য দান করেছেন এবং এ জন্য যে, তারা তাদের অর্থ ব্যয় করে। সে মতে নেককার স্ত্রীলোকগণ হয় অনুগতা এবং আল্লাহ যা হেফাযতযোগ্য করে দিয়েছেন লোক চক্ষুর অন্তরালেও তার হেফাযত করে। আর যাদের মধ্যে অবাধ্যতার আশঙ্কা কর তাদের সদুপদেশ দাও, তাদের শয্যা ত্যাগ কর এবং প্রহার কর। যদি তাতে তারা বাধ্য হয়ে যায়, তবে আর তাদের জন্য অন্য কোন পথ অনুসন্ধান করো না। নিশ্চয় আল্লাহ সবার উপর শ্রেষ্ঠ।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@dxxviii{যদি তাদের মধ্যে সম্পর্কচ্ছেদ হওয়ার মত পরিস্থিতিরই আশঙ্কা কর, তবে স্বামীর পরিবার থেকে একজন এবং স্ত্রীর পরিবার থেকে একজন সালিস নিযুক্ত করবে। তারা উভয়ের মীমাংসা চাইলে আল্লাহ সর্বজ্ঞ, সবকিছু অবহিত।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@dxxix{আর উপাসনা কর আল্লাহর, শরীক করো না তাঁর সাথে অপর কাউকে। পিতা-মাতার সাথে সৎ ও সদয় ব্যবহার কর এবং নিকটাত্নীয়, এতীম-মিসকীন, প্রতিবেশী, অসহায় মুসাফির এবং নিজের দাস-দাসীর প্রতিও। নিশ্চয়ই আল্লাহ পছন্দ করেন না দাম্ভিক-গর্বিতজনকে।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@dxxx{যারা নিজেরাও কার্পন্য করে এবং অন্যকেও কৃপণতা শিক্ষা দেয় আর গোপন করে সে সব বিষয় যা আল্লাহ তা’আলা তাদেরকে দান করেছেন স্বীয় অনুগ্রহে-বস্তুতঃ তৈরী করে রেখেছি কাফেরদের জন্য অপমান জনক আযাব।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@dxxxi{আর সে সমস্ত লোক যারা ব্যয় করে স্বীয় ধন-সম্পদ লোক-দেখানোর উদ্দেশে এবং যারা আল্লাহর উপর ঈমান আনে না, ঈমান আনে না কেয়ামত দিবসের প্রতি এবং শয়তান যার সাথী হয় সে হল নিকৃষ্টতর সাথী।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@dxxxii{আর কিই বা ক্ষতি হত তাদের যদি তারা ঈমান আনত আল্লাহর উপর কেয়ামত দিবসের উপর এবং যদি ব্যয় করত আল্লাহ প্রদত্ত রিযিক থেকে! অথচ আল্লাহ, তাদের ব্যাপারে যথার্থভাবেই অবগত।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@dxxxiii{নিশ্চয়ই আল্লাহ কারো প্রাপ্য হক বিন্দু-বিসর্গও রাখেন না; আর যদি তা সৎকর্ম হয়, তবে তাকে দ্বিগুণ করে দেন এবং নিজের পক্ষ থেকে বিপুল সওয়াব দান করেন।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@dxxxiv{আর তখন কি অবস্থা দাঁড়াবে, যখন আমি ডেকে আনব প্রতিটি উম্মতের মধ্য থেকে অবস্থা বর্ণনাকারী এবং আপনাকে ডাকব তাদের উপর অবস্থা বর্ণনাকারীরূপে।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@dxxxv{সেদিন কামনা করবে সে সমস্ত লোক, যারা কাফের হয়েছিল এবং রসূলের নাফরমানী করেছিল, যেন যমীনের সাথে মিশে যায়। কিন্তু গোপন করতে পারবে না আল্লাহর নিকট কোন বিষয়।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@dxxxvi{হে ঈমাণদারগণ! তোমরা যখন নেশাগ্রস্ত থাক, তখন নামাযের ধারে-কাছেও যেওনা, যতক্ষণ না বুঝতে সক্ষম হও যা কিছু তোমরা বলছ, আর (নামাযের কাছে যেও না) ফরয গোসলের আবস্থায়ও যতক্ষণ না গোসল করে নাও। কিন্তু মুসাফির অবস্থার কথা স্বতন্ত্র আর যদি তোমরা অসুস্থ হয়ে থাক কিংবা সফরে থাক অথবা তোমাদের মধ্য থেকে কেউ যদি প্রস্রাব-পায়খানা থেকে এসে থাকে কিংবা নারী গমন করে থাকে, কিন্তু পরে যদি পানিপ্রাপ্তি সম্ভব না হয়, তবে পাক-পবিত্র মাটির দ্বারা তায়াম্মুম করে নাও-তাতে মুখমন্ডল ও হাতকে ঘষে নাও। নিশ্চয়ই আল্লাহ তা’আলা ক্ষমাশীল।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@dxxxvii{তুমি কি ওদের দেখনি, যারা কিতাবের কিছু অংশ প্রাপ্ত হয়েছে, (অথচ) তারা পথভ্রষ্টতা খরিদ করে এবং কামনা করে, যাতে তোমরাও আল্লাহর পথ থেকে বিভ্রান্ত হয়ে যাও।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@dxxxviii{অথচ আল্লাহ তোমাদের শত্রুদেরকে যথার্থই জানেন। আর অভিভাবক হিসাবে আল্লাহই যথেষ্ট এবং সাহায্যকারী হিসাবেও আল্লাহই যথেষ্ট।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@dxxxix{কোন কোন ইহুদী তার লক্ষ্য থেকে কথার মোড় ঘুড়িয়ে নেয় এবং বলে, আমরা শুনেছি কিন্তু অমান্য করছি। তারা আরো বলে, শোন, না শোনার মত। মুখ বাঁকিয়ে দ্বীনের প্রতি তাচ্ছিল্য প্রদর্শনের উদ্দেশে বলে, রায়েনা’ (আমাদের রাখাল)। অথচ যদি তারা বলত যে, আমরা শুনেছি ও মান্য করেছি এবং (যদি বলত, ) শোন এবং আমাদের প্রতি লক্ষ্য রাখ, তবে তাই ছিল তাদের জন্য উত্তম আর সেটাই ছিল যথার্থ ও সঠিক। কিন্তু আল্লাহ তাদের প্রতি অভিসম্পাত করেছেন তাদের কুফরীর দরুন। অতএব, তারা ঈমান আনছে না, কিন্তু অতি অল্পসংখ্যক।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@dxl{হে আসমানী গ্রন্থের অধিকারীবৃন্দ! যা কিছু আমি অবতীর্ণ করেছি তার উপর বিশ্বাস স্থাপন কর, যা সে গ্রন্থের সত্যায়ন করে এবং যা তোমাদের নিকট রয়েছে পূর্ব থেকে। (বিশ্বাস স্থাপন কর) এমন হওয়ার আগেই যে, আমি মুছে দেব অনেক চেহারাকে এবং অতঃপর সেগুলোকে ঘুরিয়ে দেব পশ্চাৎ দিকে কিংবা অভিসম্পাত করব তাদের প্রতি যেমন করে অভিসম্পাত করেছি আছহাবে-সাবতের উপর। আর আল্লাহর নির্দেশ অবশ্যই কার্যকর হবে।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@dxli{নিঃসন্দেহে আল্লাহ তাকে ক্ষমা করেন না, যে লোক তাঁর সাথে শরীক করে। তিনি ক্ষমা করেন এর নিম্ন পর্যায়ের পাপ, যার জন্য তিনি ইচ্ছা করেন। আর যে লোক অংশীদার সাব্যস্ত করল আল্লাহর সাথে, সে যেন অপবাদ আরোপ করল।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@dxlii{তুমি কি তাদেকে দেখনি, যারা নিজেদেরকে পূত-পবিত্র বলে থাকে অথচ পবিত্র করেন আল্লাহ যাকে ইচ্ছা তাকেই? বস্তুতঃ তাদের উপর সুতা পরিমাণ অন্যায়ও হবে না।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@dxliii{লক্ষ্য কর, কেমন করে তারা আল্লাহর প্রতি মিথ্যা অপবাদ আরোপ করে, অথচ এই প্রকাশ্য পাপই যথেষ্ট।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@dxliv{তুমি কি তাদেরকে দেখনি, যারা কিতাবের কিছু অংশ প্রাপ্ত হয়েছে, যারা মান্য করে প্রতিমা ও শয়তানকে এবং কাফেরদেরকে বলে যে, এরা মুসলমানদের তুলনায় অধিকতর সরল সঠিক পথে রয়েছে।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@dxlv{এরা হলো সে সমস্ত লোক, যাদের উপর লা’নত করেছেন আল্লাহ তা’আলা স্বয়ং। বস্তুতঃ আল্লাহ যার উপর লা’নত করেন তুমি তার কোন সাহায্যকারী খুঁজে পাবে না।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@dxlvi{তাদের কাছে কি রাজ্যের কোন অংশ আছে? তাহলে যে এরা কাউকেও একটি তিল পরিমাণও দেবে না।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@dxlvii{নাকি যাকিছু আল্লাহ তাদেরকে স্বীয় অনুগ্রহে দান করেছেন সে বিষয়ের জন্য মানুষকে হিংসা করে। অবশ্যই আমি ইব্রাহীমের বংশধরদেরকে কিতাব ও হেকমত দান করেছিলাম আর তাদেরকে দান করেছিলাম বিশাল রাজ্য।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@dxlviii{অতঃপর তাদের কেউ তাকে মান্য করেছে আবার কেউ তার কাছ থেকে দূরে সরে রয়েছে। বস্তুতঃ (তাদের জন্য) দোযখের শিখায়িত আগুনই যথেষ্ট।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@dxlix{এতে সন্দেহ নেই যে, আমার নিদর্শন সমুহের প্রতি যেসব লোক অস্বীকৃতি জ্ঞাপন করবে, আমি তাদেরকে আগুনে নিক্ষেপ করব। তাদের চামড়াগুলো যখন জ্বলে-পুড়ে যাবে, তখন আবার আমি তা পালটে দেব অন্য চামড়া দিয়ে, যাতে তারা আযাব আস্বাদন করতে থাকে। নিশ্চয়ই আল্লাহ মহাপরাক্রমশালী, হেকমতের অধিকারী।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@dl{আর যারা ঈমান এনেছে এবং সৎকর্ম করেছে, অবশ্য আমি প্রবিষ্ট করাব তাদেরকে জান্নাতে, যার তলদেশে প্রবাহিত রয়েছে নহর সমূহ। সেখানে তারা থাকবে অনন্তকাল। সেখানে তাদের জন্য থাকবে পরিষ্কার-পরিচ্ছন্ন স্ত্রীগণ। তাদেরকে আমি প্রবিষ্ট করব ঘন ছায়া নীড়ে।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@dli{নিশ্চয়ই আল্লাহ তোমাদিগকে নির্দেশ দেন যে, তোমরা যেন প্রাপ্য আমানতসমূহ প্রাপকদের নিকট পৌছে দাও। আর যখন তোমরা মানুষের কোন বিচার-মীমাংসা করতে আরম্ভ কর, তখন মীমাংসা কর ন্যায় ভিত্তিক। আল্লাহ তোমাদিগকে সদুপদেশ দান করেন। নিশ্চয়ই আল্লাহ শ্রবণকারী, দর্শনকারী।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@dlii{হে ঈমানদারগণ! আল্লাহর নির্দেশ মান্য কর, নির্দেশ মান্য কর রসূলের এবং তোমাদের মধ্যে যারা বিচারক তাদের। তারপর যদি তোমরা কোন বিষয়ে বিবাদে প্রবৃত্ত হয়ে পড়, তাহলে তা আল্লাহ ও তাঁর রসূলের প্রতি প্রত্যর্পণ কর-যদি তোমরা আল্লাহ ও কেয়ামত দিবসের উপর বিশ্বাসী হয়ে থাক। আর এটাই কল্যাণকর এবং পরিণতির দিক দিয়ে উত্তম।\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@dliii{আপনি কি তাদেরকে দেখেননি, যারা দাবী করে যে, যা আপনার প্রতি অবর্তীর্ণ হয়েছে আমরা সে বিষয়ের উপর ঈমান এনেছি এবং আপনার পূর্বে যা অবর্তীণ হয়েছে। তারা বিরোধীয় বিষয়কে শয়তানের দিকে নিয়ে যেতে চায়, অথচ তাদের প্রতি নির্দেশ হয়েছে, যাতে তারা ওকে মান্য না করে। পক্ষান্তরে শয়তান তাদেরকে প্রতারিত করে পথভ্রষ্ট করে ফেলতে চায়।\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@dliv{আর যখন আপনি তাদেরকে বলবেন, আল্লাহর নির্দেশের দিকে এসো-যা তিনি রসূলের প্রতি নাযিল করেছেন, তখন আপনি মুনাফেকদিগকে দেখবেন, ওরা আপনার কাছ থেকে সম্পূর্ণ ভাবে সরে যাচ্ছে।\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@dlv{এমতাবস্থায় যদি তাদের কৃতকর্মের দরুন বিপদ আরোপিত হয়, তবে তাতে কি হল! অতঃপর তারা আপনার কাছে আল্লাহর নামে কসম খেয়ে খেয়ে ফিরে আসবে যে, মঙ্গল ও সম্প্রীতি ছাড়া আমাদের অন্য কোন উদ্দেশ্য ছিল না।\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@dlvi{এরা হলো সে সমস্ত লোক, যাদের মনের গোপন বিষয় সম্পর্কেও আল্লাহ তা’আলা অবগত। অতএব, আপনি ওদেরকে উপেক্ষা করুন এবং ওদেরকে সদুপদেশ দিয়ে এমন কোন কথা বলুন যা তাদের জন্য কল্যাণকর।\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@dlvii{বস্তুতঃ আমি একমাত্র এই উদ্দেশ্যেই রসূল প্রেরণ করেছি, যাতে আল্লাহর নির্দেশানুযায়ী তাঁদের আদেশ-নিষেধ মান্য করা হয়। আর সেসব লোক যখন নিজেদের অনিষ্ট সাধন করেছিল, তখন যদি আপনার কাছে আসত অতঃপর আল্লাহর নিকট ক্ষমা প্রার্থনা করত এবং রসূলও যদি তাদেরকে ক্ষমা করিয়ে দিতেন। অবশ্যই তারা আল্লাহকে ক্ষমাকারী, মেহেরবানরূপে পেত।\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@dlviii{অতএব, তোমার পালনকর্তার কসম, সে লোক ঈমানদার হবে না, যতক্ষণ না তাদের মধ্যে সৃষ্ট বিবাদের ব্যাপারে তোমাকে ন্যায়বিচারক বলে মনে না করে। অতঃপর তোমার মীমাংসার ব্যাপারে নিজের মনে কোন রকম সংকীর্ণতা পাবে না এবং তা হূষ্টচিত্তে কবুল করে নেবে।\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@dlix{আর যদি আমি তাদের নির্দেশ দিতাম যে, নিজেদের প্রাণ ধ্বংস করে দাও কিংবা নিজেদের নগরী ছেড়ে বেরিয়ে যাও, তবে তারা তা করত না; অবশ্য তাদের মধ্যে অল্প কয়েকজন। যদি তারা তাই করে যা তাদের উপদেশ দেয়া হয়, তবে তা অবশ্যই তাদের জন্য উত্তম এং তাদেরকে নিজের ধর্মের উপর সুদৃঢ় রাখার জন্য তা উত্তম হবে।\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@dlx{আর তখন অবশ্যই আমি তাদেরকে নিজের পক্ষ থেকে মহান সওয়াব দেব।\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@dlxi{আর তাদেরকে সরল পথে পরিচালিত করব।\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@dlxii{আর যে কেউ আল্লাহর হুকুম এবং তাঁর রসূলের হুকুম মান্য করবে, তাহলে যাঁদের প্রতি আল্লাহ নেয়ামত দান করেছেন, সে তাঁদের সঙ্গী হবে। তাঁরা হলেন নবী, ছিদ্দীক, শহীদ ও সৎকর্মশীল ব্যক্তিবর্গ। আর তাদের সান্নিধ্যই হল উত্তম।\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@dlxiii{এটা হল আল্লাহ-প্রদত্ত মহত্ত্ব। আর আল্লাহ যথেষ্ট পরিজ্ঞাত।\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@dlxiv{হে ঈমানদারগণ! নিজেদের অস্ত্র তুলে নাও এবং পৃথক পৃথক সৈন্যদলে কিংবা সমবেতভাবে বেরিয়ে পড়।\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@dlxv{আর তোমাদের মধ্যে এমনও কেউ কেউ রয়েছে, যারা অবশ্য বিলম্ব করবে এবং তোমাদের উপর কোন বিপদ উপস্থিত হলে বলবে, আল্লাহ আমার প্রতি অনুগ্রহ করেছেন যে, আমি তাদের সাথে যাইনি।\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@dlxvi{পক্ষান্তরে তোমাদের প্রতি আল্লাহর পক্ষ থেকে কোন অনুগ্রহ আসলে তারা এমন ভাবে বলতে শুরু করবে যেন তোমাদের মধ্যে এবং তাদের মধ্যে কোন মিত্রতাই ছিল না। (বলবে) হায়, আমি যদি তাদের সাথে থাকতাম, তাহলে আমি ও যে সফলতা লাভ করতাম।\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@dlxvii{কাজেই আল্লাহর কাছে যারা পার্থিব জীবনকে আখেরাতের পরিবর্তে বিক্রি করে দেয় তাদের জেহাদ করাই কর্তব্য। বস্তুতঃ যারা আল্লাহর রাহে লড়াই করে এবং অতঃপর মৃত্যুবরণ করে কিংবা বিজয় অর্জন করে, আমি তাদেরকে মহাপুণ্য দান করব।\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@dlxviii{আর তোমাদের কি হল যে, তেমারা আল্লাহর রাহে লড়াই করছ না দুর্বল সেই পুরুষ, নারী ও শিশুদের পক্ষে, যারা বলে, হে আমাদের পালনকর্তা! আমাদিগকে এই জনপদ থেকে নিষ্কৃতি দান কর; এখানকার অধিবাসীরা যে, অত্যাচারী! আর তোমার পক্ষ থেকে আমাদের জন্য পক্ষালম্বনকারী নির্ধারণ করে দাও এবং তোমার পক্ষ থেকে আমাদের জন্য সাহায্যকারী নির্ধারণ করে দাও।\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@dlxix{যারা ঈমানদার তারা যে, জেহাদ করে আল্লাহর রাহেই। পক্ষান্তরে যারা কাফের তারা লড়াই করে শয়তানের পক্ষে সুতরাং তোমরা জেহাদ করতে থাক শয়তানের পক্ষালম্বনকারীদের বিরুদ্ধে, (দেখবে) শয়তানের চক্রান্ত একান্তই দুর্বল।\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@dlxx{তুমি কি সেসব লোককে দেখনি, যাদেরকে নির্দেশ দেয়া হয়েছিল যে, তোমরা নিজেদের হাতকে সংযত রাখ, নামায কায়েম কর এবং যাকাত দিতে থাক? অতঃপর যখন তাদের প্রতি জেহাদের নির্দেশ দেয়া হল, তৎক্ষণাৎ তাদের মধ্যে একদল লোক মানুষকে ভয় করতে আরম্ভ করল, যেমন করে ভয় করা হয় আল্লাহকে। এমন কি তার চেয়েও অধিক ভয়। আর বলতে লাগল, হায় পালনকর্তা, কেন আমাদের উপর যুদ্ধ ফরজ করলে! আমাদেরকে কেন আরও কিছুকাল অবকাশ দান করলে না। ( হে রসূল) তাদেরকে বলে দিন, পার্থিব ফায়দা সীমিত। আর আখেরাত পরহেযগারদের জন্য উত্তম। আর তোমাদের অধিকার একটি সূতা পরিমান ও খর্ব করা হবে না।\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@dlxxi{তোমরা যেখানেই থাক না কেন; মৃত্যু কিন্তু তোমাদেরকে পাকড়াও করবেই। যদি তোমরা সুদৃঢ় দূর্গের ভেতরেও অবস্থান কর, তবুও। বস্তুতঃ তাদের কোন কল্যাণ সাধিত হলে তারা বলে যে, এটা সাধিত হয়েছে আল্লাহর পক্ষ থেকে। আর যদি তাদের কোন অকল্যাণ হয়, তবে বলে, এটা হয়েছে তোমার পক্ষ থেকে, বলে দাও, এসবই আল্লাহর পক্ষ থেকে। পক্ষান্তরে তাদের পরিণতি কি হবে, যারা কখনও কোন কথা বুঝতে চেষ্টা করে না।\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@dlxxii{আপনার যে কল্যাণ হয়, তা হয় আল্লাহর পক্ষ থেকে আর আপনার যে অকল্যাণ হয়, সেটা হয় আপনার নিজের কারণে। আর আমি আপনাকে পাঠিয়েছি মানুষের প্রতি আমার পয়গামের বাহক হিসাবে। আর আল্লাহ সব বিষয়েই যথেষ্ট-সববিষয়ই তাঁর সম্মুখে উপস্থিত।\qt@no{(79)}}
\qt@newcmd\qurantrans@bn@dlxxiii{যে লোক রসূলের হুকুম মান্য করবে সে আল্লাহরই হুকুম মান্য করল। আর যে লোক বিমুখতা অবলম্বন করল, আমি আপনাকে (হে মুহাম্মদ), তাদের জন্য রক্ষণাবেক্ষণকারী নিযুক্ত করে পাঠাইনি।\qt@no{(80)}}
\qt@newcmd\qurantrans@bn@dlxxiv{আর তারা বলে, আপনার আনুগত্য করি। অতঃপর আপনার নিকট থেকে বেরিয়ে গেলেই তাদের মধ্য থেকে কেউ কেউ পরামর্শ করে রাতের বেলায় সে কথার পরিপন্থী যা তারা আপনার সাথে বলেছিল। আর আল্লাহ লিখে নেন, সে সব পরামর্শ যা তারা করে থাকে। সুতরাং আপনি তাদের ব্যাপারে নিস্পৃহতা অবলম্বন করুন এবং ভরসা করুন আল্লাহর উপর, আল্লাহ হলেন যথেষ্ট ও কার্যসম্পাদনকারী।\qt@no{(81)}}
\qt@newcmd\qurantrans@bn@dlxxv{এরা কি লক্ষ্য করে না কোরআনের প্রতি? পক্ষান্তরে এটা যদি আল্লাহ ব্যতীত অপর কারও পক্ষ থেকে হত, তবে এতো অবশ্যই বহু বৈপরিত্য দেখতে পেত।\qt@no{(82)}}
\qt@newcmd\qurantrans@bn@dlxxvi{আর যখন তাদের কছে পৌঁছে কোন সংবাদ শান্তি-সংক্রান্ত কিংবা ভয়ের, তখন তারা সেগুলোকে রটিয়ে দেয়। আর যদি সেগুলো পৌঁছে দিত রসূল পর্যন্ত কিংবা তাদের শাসকদের পর্যন্ত, তখন অনুসন্ধান করে দেখা যেত সেসব বিষয়, যা তাতে রয়েছে অনুসন্ধান করার মত। বস্তুতঃ আল্লাহর অনুগ্রহ ও করুণা যদি তোমাদের উপর বিদ্যমান না থাকত তবে তোমাদের অল্প কতিপয় লোক ব্যতীত সবাই শয়তানের অনুসরণ করতে শুরু করত!\qt@no{(83)}}
\qt@newcmd\qurantrans@bn@dlxxvii{আল্লাহর রাহে যুদ্ধ করতে থাকুন, আপনি নিজের সত্তা ব্যতীত অন্য কোন বিষয়ের যিম্মাদার নন! আর আপনি মুসলমানদেরকে উৎসাহিত করতে থাকুন। শীঘ্রই আল্লাহ কাফেরদের শক্তি-সামর্থ খর্ব করে দেবেন। আর আল্লাহ শক্তি-সামর্থের দিক দিয়ে অত্যন্ত কঠোর এবং কঠিন শাস্তিদাতা।\qt@no{(84)}}
\qt@newcmd\qurantrans@bn@dlxxviii{যে লোক সৎকাজের জন্য কোন সুপারিশ করবে, তা থেকে সেও একটি অংশ পাবে। আর যে লোক সুপারিশ করবে মন্দ কাজের জন্যে সে তার বোঝারও একটি অংশ পাবে। বস্তুতঃ আল্লাহ সর্ব বিষয়ে ক্ষমতাশীল।\qt@no{(85)}}
\qt@newcmd\qurantrans@bn@dlxxix{আর তোমাদেরকে যদি কেউ দোয়া করে, তাহলে তোমরাও তার জন্য দোয়া কর; তারচেয়ে উত্তম দোয়া অথবা তারই মত ফিরিয়ে বল। নিশ্চয়ই আল্লাহ সর্ব বিষয়ে হিসাব-নিকাশ গ্রহণকারী।\qt@no{(86)}}
\qt@newcmd\qurantrans@bn@dlxxx{আল্লাহ ব্যতীত আর কোনোই উপাস্য নেই। অবশ্যই তিনি তোমাদেরকে সমবেত করবেন কেয়ামতের দিন, এতে বিন্দুমাত্র সন্দেহ নেই। তাছাড়া আল্লাহর চাইতে বেশী সত্য কথা আর কার হবে!\qt@no{(87)}}
\qt@newcmd\qurantrans@bn@dlxxxi{অতঃপর তোমাদের কি হল যে, মুনাফিকদের সম্পর্কে তোমরা দু’দল হয়ে গেলে? অথচ আল্লাহ তা’আলা তাদেরকে ঘুরিয়ে দিয়েছেন তাদের মন্দ কাজের কারনে! তোমরা কি তাদেরকে পথ প্রদর্শন করতে চাও, যাদেরকে আল্লাহ পথভ্রষ্ট করেছেন? আল্লাহ যাকে পথভ্রান্ত করেন, তুমি তার জন্য কোন পথ পাবে না।\qt@no{(88)}}
\qt@newcmd\qurantrans@bn@dlxxxii{তারা চায় যে, তারা যেমন কাফের, তোমরাও তেমনি কাফের হয়ে যাও, যাতে তোমরা এবং তারা সব সমান হয়ে যাও। অতএব, তাদের মধ্যে কাউকে বন্ধুরূপে গ্রহণ করো না, যে পর্যন্ত না তারা আল্লাহর পথে হিজরত করে চলে আসে। অতঃপর যদি তারা বিমুখ হয়, তবে তাদেরকে পাকড়াও কর এবং যেখানে পাও হত্যা কর। তাদের মধ্যে কাউকে বন্ধুরূপে গ্রহণ করো না এবং সাহায্যকারী বানিও না।\qt@no{(89)}}
\qt@newcmd\qurantrans@bn@dlxxxiii{কিন্তু যারা এমন সম্প্রদায়ের সাথে মিলিত হয় যে, তোমাদের মধ্যে ও তাদের মধ্যে চুক্তি আছে অথবা তোমাদের কাছে এভাবে আসে যে, তাদের অন্তর তোমাদের সাথে এবং স্বজাতির সাথেও যুদ্ধ করতে অনিচ্ছুক। যদি আল্লাহ ইচ্ছে করতেন, তবে তোমাদের উপর তাদেরকে প্রবল করে দিতেন। ফলে তারা অবশ্যই তোমাদের সাথে যুদ্ধ করত। অতঃপর যদি তারা তোমাদের থেকে পৃথক থাকে তোমাদের সাথে যুদ্ধ না করে এবং তোমাদের সাথে সন্ধি করে, তবে আল্লাহ তোমাদের কে তাদের বিরুদ্ধে কোন পথ দেননি।\qt@no{(90)}}
\qt@newcmd\qurantrans@bn@dlxxxiv{এখন তুমি আরও এক সম্প্রদায়কে পাবে। তারা তোমাদের কাছেও স্বজাতির কাছেও এবং নির্বিঘ্ন হয়ে থাকতে চায়। যখন তাদেরকে ফ্যাসাদের প্রতি মনোনিবেশ করানো হয়, তখন তারা তাতে নিপতিত হয়, অতএব তারা যদি তোমাদের থেকে নিবৃত্ত না হয়, তোমাদের সাথে সন্ধি না রাখে এবং স্বীয় হস্তসমূহকে বিরত না রাখে, তবে তোমরা তাদেরকে পাকড়াও কর এবং যেখানে পাও হত্যা কর। আমি তাদের বিরুদ্ধে তোমাদেরকে প্রকাশ্য যুক্তি-প্রমাণ দান করেছি।\qt@no{(91)}}
\qt@newcmd\qurantrans@bn@dlxxxv{মুসলমানের কাজ নয় যে, মুসলমানকে হত্যা করে; কিন্তু ভুলক্রমে। যে ব্যক্তি মুসলমানকে ভূলক্রমে হত্যা করে, সে একজন মুসলমান ক্রীতদাস মুক্ত করবে এবং রক্ত বিনিময় সমর্পন করবে তার স্বজনদেরকে; কিন্তু যদি তারা ক্ষমা করে দেয়। অতঃপর যদি নিহত ব্যক্তি তোমাদের শত্রু সম্প্রদায়ের অন্তর্গত হয়, তবে মুসলমান ক্রীতদাস মুক্ত করবে এবং যদি সে তোমাদের সাথে চুক্তিবদ্ধ কোন সম্প্রদায়ের অন্তর্গত হয়, তবে রক্ত বিনিময় সমর্পণ করবে তার স্বজনদেরকে এবং একজন মুসলমান ক্রীতদাস মুক্ত করবে। অতঃপর যে ব্যক্তি না পায়, সে আল্লাহর কাছ থেকে গোনাহ মাফ করানোর জন্যে উপর্যুপুরি দুই মাস রোযা রাখবে। আল্লাহ, মহাজ্ঞানী, প্রজ্ঞাময়।\qt@no{(92)}}
\qt@newcmd\qurantrans@bn@dlxxxvi{যে ব্যক্তি স্বেচ্ছাক্রমে মুসলমানকে হত্যা করে, তার শাস্তি জাহান্নাম, তাতেই সে চিরকাল থাকবে। আল্লাহ তার প্রতি ক্রুদ্ধ হয়েছেন, তাকে অভিসম্পাত করেছেন এবং তার জন্যে ভীষণ শাস্তি প্রস্তুত রেখেছেন।\qt@no{(93)}}
\qt@newcmd\qurantrans@bn@dlxxxvii{হে ঈমানদারগণ! তোমরা যখন আল্লাহর পথে সফর কর, তখন যাচাই করে নিও এবং যে, তোমাদেরকে সালাম করে তাকে বলো না যে, তুমি মুসলমান নও। তোমরা পার্থিব জীবনের সম্পদ অন্বেষণ কর, বস্তুতঃ আল্লাহর কাছে অনেক সম্পদ রয়েছে। তোমরা ও তো এমনি ছিলে ইতিপূর্বে; অতঃপর আল্লাহ তোমাদের প্রতি অনুগ্রহ করেছেন। অতএব, এখন অনুসন্ধান করে নিও। নিশ্চয় আল্লাহ তোমাদের কাজ কর্মের খবর রাখেন।\qt@no{(94)}}
\qt@newcmd\qurantrans@bn@dlxxxviii{গৃহে উপবিষ্ট মুসলমান-যাদের কোন সঙ্গত ওযর নেই এবং ঐ মুসলমান যারা জান ও মাল দ্বারা আল্লাহর পথে জেহাদ করে,-সমান নয়। যারা জান ও মাল দ্বারা জেহাদ করে, আল্লাহ তাদের পদমর্যাদা বাড়িয়ে দিয়েছেন গৃহে উপবিষ্টদের তুলনায় এবং প্রত্যেকের সাথেই আল্লাহ কল্যাণের ওয়াদা করেছেন। আল্লাহ মুজাহেদীনকে উপবিষ্টদের উপর মহান প্রতিদানে শ্রেষ্ঠ করেছেন।\qt@no{(95)}}
\qt@newcmd\qurantrans@bn@dlxxxix{এগুলো তাঁর পক্ষ থেকে পদমর্যাদা, ক্ষমা ও করুণা; আল্লাহ ক্ষমাশীল ও করুণাময়।\qt@no{(96)}}
\qt@newcmd\qurantrans@bn@dxc{যারা নিজের অনিষ্ট করে, ফেরেশতারা তাদের প্রাণ হরণ করে বলে, তোমরা কি অবস্থায় ছিলে? তারা বলেঃ এ ভূখন্ডে আমরা অসহায় ছিলাম। ফেরেশতারা বলেঃ আল্লাহর পৃথিবী কি প্রশস্ত ছিল না যে, তোমরা দেশত্যাগ করে সেখানে চলে যেতে? অতএব, এদের বাসস্থান হল জাহান্নাম এবং তা অত্যন্ত মন্দ স্থান।\qt@no{(97)}}
\qt@newcmd\qurantrans@bn@dxci{কিন্তু পুরুষ, নারী ও শিশুদের মধ্যে যারা অসহায়, তারা কোন উপায় করতে পারে না এবং পথও জানে না।\qt@no{(98)}}
\qt@newcmd\qurantrans@bn@dxcii{অতএব, আশা করা যায়, আল্লাহ তাদেরকে ক্ষমা করবেন। আল্লাহ মার্জনাকারী, ক্ষমাশীল।\qt@no{(99)}}
\qt@newcmd\qurantrans@bn@dxciii{যে কেউ আল্লাহর পথে দেশত্যাগ করে, সে এর বিনিময়ে অনেক স্থান ও সচ্ছলতা প্রাপ্ত হবে। যে কেউ নিজ গৃহ থেকে বের হয় আল্লাহ ও রসূলের প্রতি হিজরত করার উদ্দেশে, অতঃপর মৃত্যুমুখে পতিত হয়, তবে তার সওয়াব আল্লাহর কাছে অবধারিত হয়ে যায়। আল্লাহ ক্ষমাশীল, করুণাময়।\qt@no{(100)}}
\qt@newcmd\qurantrans@bn@dxciv{যখন তোমরা কোন দেশ সফর কর, তখন নামাযে কিছুটা হ্রাস করলে তোমাদের কোন গোনাহ নেই, যদি তোমরা আশঙ্কা কর যে, কাফেররা তোমাদেরকে উত্ত্যক্ত করবে। নিশ্চয় কাফেররা তোমাদের প্রকাশ্য শত্রু।\qt@no{(101)}}
\qt@newcmd\qurantrans@bn@dxcv{যখন আপনি তাদের মধ্যে থাকেন, অতঃপর নামাযে দাঁড়ান, তখন যেন একদল দাঁড়ায় আপনার সাথে এবং তারা যেন স্বীয় অস্ত্র সাথে নেয়। অতঃপর যখন তারা সেজদা সম্পন্ন করে, তখন আপনার কাছ থেকে যেন সরে যায় এবং অন্য দল যেন আসে, যারা নামায পড়েনি। অতঃপর তারা যেন আপনার সাথে নামায পড়ে এবং আত্মরক্ষার হাতিয়ার সাথে নেয়। কাফেররা চায় যে, তোমরা কোন রূপে অসতর্ক থাক, যাতে তারা একযোগে তোমাদেরকে আক্রমণ করে বসে। যদি বৃষ্টির কারণে তোমাদের কষ্ট হয় অথবা তোমরা অসুস্থ হও তবে স্বীয় অস্ত্র পরিত্যাগ করায় তোমাদের কোন গোনাহ নেই এবং সাথে নিয়ে নাও তোমাদের আত্নরক্ষার অস্ত্র। নিশ্চয় আল্লাহ কাফেরদের জন্যে অপমানকর শাস্তি প্রস্তুত করে রেখেছেন।\qt@no{(102)}}
\qt@newcmd\qurantrans@bn@dxcvi{অতঃপর যখন তোমরা নামায সম্পন্ন কর, তখন দন্ডায়মান, উপবিষ্ট ও শায়িত অবস্থায় আল্লাহকে স্মরণ কর। অতঃপর যখন বিপদমুক্ত হয়ে যাও, তখন নামায ঠিক করে পড়। নিশ্চয় নামায মুসলমানদের উপর ফরয নির্দিষ্ট সময়ের মধ্যে।\qt@no{(103)}}
\qt@newcmd\qurantrans@bn@dxcvii{তাদের পশ্চাদ্ধাবনে শৈথিল্য করো না। যদি তোমরা আঘাত প্রাপ্ত, তবে তারাও তো তোমাদের মতই হয়েছে আঘাতপ্রাপ্ত এবং তোমরা আল্লাহর কাছে আশা কর, যা তারা আশা করে না। আল্লাহ মহাজ্ঞানী, প্রজ্ঞাময়।\qt@no{(104)}}
\qt@newcmd\qurantrans@bn@dxcviii{নিশ্চয় আমি আপনার প্রতি সত্য কিতাব অবতীর্ণ করেছি, যাতে আপনি মানুষের মধ্যে ফয়সালা করেন, যা আল্লাহ আপনাকে হৃদয়ঙ্গম করান। আপনি বিশ্বাসঘাতকদের পক্ষ থেকে বিতর্ককারী হবেন না।\qt@no{(105)}}
\qt@newcmd\qurantrans@bn@dxcix{এবং আল্লাহর কাছে ক্ষমা প্রার্থনা করুন। নিশ্চয় আল্লাহ ক্ষমাশীল, দয়ালু।\qt@no{(106)}}
\qt@newcmd\qurantrans@bn@dc{যারা মনে বিশ্বাস ঘাতকতা পোষণ করে তাদের পক্ষ থেকে বিতর্ক করবেন না। আল্লাহ পছন্দ করেন না তাকে, যে বিশ্বাস ঘাতক পাপী হয়।\qt@no{(107)}}
\qt@newcmd\qurantrans@bn@dci{তারা মানুষের কাছে লজ্জিত হয় এবং আল্লাহর কাছে লজ্জিত হয় না। তিনি তাদের সাথে রয়েছেন, যখন তারা রাত্রে এমন বিষয়ে পরামর্শ করে, যাতে আল্লাহ সম্মত নন। তারা যাকিছু করে, সবই আল্লাহর আয়ত্তাধীণ।\qt@no{(108)}}
\qt@newcmd\qurantrans@bn@dcii{শুনছ? তোমরা তাদের পক্ষ থেকে পার্থিব জীবনে বিবাদ করছ, অতঃপর কেয়ামতের দিনে তাদের পক্ষ হয়ে আল্লাহর সাথে কে বিবাদ করবে অথবা কে তাদের কার্যনির্বাহী হবে।\qt@no{(109)}}
\qt@newcmd\qurantrans@bn@dciii{যে গোনাহ, করে কিংবা নিজের অনিষ্ট করে, অতঃপর আল্লাহর কাছে ক্ষমা প্রার্থনা করে, সে আল্লাহকে ক্ষমাশীল, করুণাময় পায়।\qt@no{(110)}}
\qt@newcmd\qurantrans@bn@dciv{যে কেউ পাপ করে, সে নিজের পক্ষেই করে। আল্লাহ মহাজ্ঞানী, প্রজ্ঞাময়।\qt@no{(111)}}
\qt@newcmd\qurantrans@bn@dcv{যে ব্যক্তি ভূল কিংবা গোনাহ করে, অতঃপর কোন নিরপরাধের উপর অপবাদ আরোপ করে সে নিজের মাথায় বহন করে জঘন্য মিথ্যা ও প্রকাশ্য গোনাহ।\qt@no{(112)}}
\qt@newcmd\qurantrans@bn@dcvi{যদি আপনার প্রতি আল্লাহর অনুগ্রহ ও করুণা না হত, তবে তাদের একদল আপনাকে পথভ্রষ্ট করার সংকল্প করেই ফেলেছিল। তারা পথভ্রান্ত করতে পারে না কিন্তু নিজেদেরকেই এবং আপনার কোন অনিষ্ট করতে পারে না। আল্লাহ আপনার প্রতি ঐশী গ্রন্থ ও প্রজ্ঞা অবতীর্ণ করেছেন এবং আপনাকে এমন বিষয় শিক্ষা দিয়েছেন, যা আপনি জানতেন না। আপনার প্রতি আল্লাহর করুণা অসীম।\qt@no{(113)}}
\qt@newcmd\qurantrans@bn@dcvii{তাদের অধিকাংশ সলা-পরামর্শ ভাল নয়; কিন্তু যে সলা-পরামর্শ দান খয়রাত করতে কিংবা সৎকাজ করতে কিংবা মানুষের মধ্যে সন্ধিস্থাপন কল্পে করতো তা স্বতন্ত্র। যে একাজ করে আল্লাহর সন্তুষ্টির জন্যে আমি তাকে বিরাট ছওয়াব দান করব।\qt@no{(114)}}
\qt@newcmd\qurantrans@bn@dcviii{যে কেউ রসূলের বিরুদ্ধাচারণ করে, তার কাছে সরল পথ প্রকাশিত হওয়ার পর এবং সব মুসলমানের অনুসৃত পথের বিরুদ্ধে চলে, আমি তাকে ঐ দিকেই ফেরাব যে দিক সে অবলম্বন করেছে এবং তাকে জাহান্নামে নিক্ষেপ করব। আর তা নিকৃষ্টতর গন্তব্যস্থান।\qt@no{(115)}}
\qt@newcmd\qurantrans@bn@dcix{নিশ্চয় আল্লাহ তাকে ক্ষমা করেন না, যে তাঁর সাথে কাউকে শরীক করে। এছাড়া যাকে ইচ্ছা, ক্ষমা করেন। যে আল্লাহর সাথে শরীক করে সে সুদূর ভ্রান্তিতে পতিত হয়।\qt@no{(116)}}
\qt@newcmd\qurantrans@bn@dcx{তারা আল্লাহকে পরিত্যাগ করে শুধু নারীর আরাধনা করে এবং শুধু অবাধ্য শয়তানের পূজা করে।\qt@no{(117)}}
\qt@newcmd\qurantrans@bn@dcxi{যার প্রতি আল্লাহ অভিসম্পাত করেছেন। শয়তান বললঃ আমি অবশ্যই তোমার বান্দাদের মধ্য থেকে নির্দিষ্ট অংশ গ্রহণ করব।\qt@no{(118)}}
\qt@newcmd\qurantrans@bn@dcxii{তাদেরকে পথভ্রষ্ট করব, তাদেরকে আশ্বাস দেব; তাদেরকে পশুদের কর্ণ ছেদন করতে বলব এবং তাদেরকে আল্লাহর সৃষ্ট আকৃতি পরিবর্তন করতে আদেশ দেব। যে কেউ আল্লাহকে ছেড়ে শয়তানকে বন্ধুরূপে গ্রহণ করে, সে প্রকাশ্য ক্ষতিতে পতিত হয়।\qt@no{(119)}}
\qt@newcmd\qurantrans@bn@dcxiii{সে তাদেরকে প্রতিশ্রুতি দেয় এবং তাদেরকে আশ্বাস দেয়। শয়তান তাদেরকে যে প্রতিশ্রুতি দেয়, তা সব প্রতারণা বৈ নয়।\qt@no{(120)}}
\qt@newcmd\qurantrans@bn@dcxiv{তাদের বাসস্থান জাহান্নাম। তারা সেখান থেকে কোথাও পালাবার জায়গা পাবে না।\qt@no{(121)}}
\qt@newcmd\qurantrans@bn@dcxv{যারা বিশ্বাস স্থাপন করেছে এবং সৎকর্ম করেছে, আমি তাদেরকে উদ্যানসমূহে প্রবিষ্ট করাব, যেগুলোর তলদেশে নহরসমূহ প্রবাহিত হয়। তারা চিরকাল তথায় অবস্থান করবে। আল্লাহ প্রতিশ্রুতি দিয়েছেন সত্য সত্য। আল্লাহর চাইতে অধিক সত্যবাদী কে?\qt@no{(122)}}
\qt@newcmd\qurantrans@bn@dcxvi{তোমাদের আশার উপর ও ভিত্তি নয় এবং আহলে-কিতাবদের আশার উপরও না। যে কেউ মন্দ কাজ করবে, সে তার শাস্তি পাবে এবং সে আল্লাহ ছাড়া নিজের কোন সমর্থক বা সাহায্যকারী পাবে না।\qt@no{(123)}}
\qt@newcmd\qurantrans@bn@dcxvii{যে লোক পুরুষ হোক কিংবা নারী, কোন সৎকর্ম করে এবং বিশ্বাসী হয়, তবে তারা জান্নাতে প্রবেশ করবে এবং তাদের প্রাপ্য তিল পরিমাণ ও নষ্ট হবে না।\qt@no{(124)}}
\qt@newcmd\qurantrans@bn@dcxviii{যে আল্লাহর নির্দেশের সামনে মস্তক অবনত করে সৎকাজে নিয়োজিত থাকে এবং ইব্রাহীমের ধর্ম অনুসরণ করে, যিনি একনিষ্ঠ ছিলেন, তার চাইতে উত্তম ধর্ম কার? আল্লাহ ইব্রাহীমকে বন্ধুরূপে গ্রহণ করেছেন।\qt@no{(125)}}
\qt@newcmd\qurantrans@bn@dcxix{যা কিছু নভোন্ডলে আছে এবং যা কিছু ভুমন্ডলে আছে, সব আল্লাহরই। সব বস্তু আল্লাহর মুষ্ঠি বলয়ে।\qt@no{(126)}}
\qt@newcmd\qurantrans@bn@dcxx{তারা আপনার কাছে নারীদের বিবাহের অনুমতি চায়। বলে দিনঃ আল্লাহ তোমাদেরকে তাদের সম্পর্কে অনুমতি দেন এবং কোরআনে তোমাদেরকে যা যা পাট করে শুনানো হয়, তা ঐ সব পিতৃহীনা-নারীদের বিধান, যাদের কে তোমরা নির্ধারিত অধিকার প্রদান কর না অথচ বিবাহ বন্ধনে আবদ্ধ করার বাসনা রাখ। আর অক্ষম শিশুদের বিধান এই যে, এতীমদের জন্যে ইনসাফের উপর কায়েম থাক। তোমরা যা ভাল কাজ করবে, তা আল্লাহ জানেন।\qt@no{(127)}}
\qt@newcmd\qurantrans@bn@dcxxi{যদি কোন নারী স্বীয় স্বামীর পক্ষ থেকে অসদাচরণ কিংবা উপেক্ষার আশংকা করে, তবে পরস্পর কোন মীমাংসা করে নিলে তাদের উভয়ের কোন গোনাহ নাই। মীমাংসা উত্তম। মনের সামনে লোভ বিদ্যমান আছে। যদি তোমরা উত্তম কাজ কর এবং খোদাভীরু হও, তবে, আল্লাহ তোমাদের সব কাজের খবর রাখেন।\qt@no{(128)}}
\qt@newcmd\qurantrans@bn@dcxxii{তোমরা কখনও নারীদেরকে সমান রাখতে পারবে না, যদিও এর আকাঙ্ক্ষী হও। অতএব, সম্পূর্ণ ঝুঁকেও পড়ো না যে, একজনকে ফেলে রাখ দোদুল্যমান অবস্থায়। যদি সংশোধন কর এবং খোদাভীরু হও, তবে আল্লাহ ক্ষমাশীল, করুণাময়।\qt@no{(129)}}
\qt@newcmd\qurantrans@bn@dcxxiii{যদি উভয়েই বিচ্ছিন্ন হয়ে যায়, তবে আল্লাহ স্বীয় প্রশস্ততা দ্বারা প্রত্যেককে অমুখাপেক্ষী করে দিবেন। আল্লাহ সুপ্রশস্ত, প্রজ্ঞাময়।\qt@no{(130)}}
\qt@newcmd\qurantrans@bn@dcxxiv{আর যা কিছু রয়েছে আসমান সমূহে ও যমীনে সবই আল্লাহর। বস্তুতঃ আমি নির্দেশ দিয়েছি তোমাদের পূর্ববর্তী গ্রন্থের অধিকারীদেরকে এবং তোমাদেরকে যে, তোমরা সবাই ভয় করতে থাক আল্লাহকে। যদি তোমরা তা না মান, তবে জেনো, সে সব কিছুই আল্লাহ তা’আলার যা কিছু রয়েছে আসমান সমূহে ও যমীনে। আর আল্লাহ হচ্ছেন অভাবহীন, প্রসংশিত।\qt@no{(131)}}
\qt@newcmd\qurantrans@bn@dcxxv{আর আল্লাহরই জন্যে সে সবকিছু যা কিছু রয়েছে আসমান সমূহে ও যমীনে। আল্লাহই যথেষ্ট কর্মবিধায়ক।\qt@no{(132)}}
\qt@newcmd\qurantrans@bn@dcxxvi{হে মানবকূল, যদি আল্লাহ তোমাদেরকে সরিয়ে তোমাদের জায়গায় অন্য কাউকে প্রতিষ্ঠিত করেন? বস্তুতঃ আল্লাহর সে ক্ষমতা রয়েছে।\qt@no{(133)}}
\qt@newcmd\qurantrans@bn@dcxxvii{যে কেউ দুনিয়ার কল্যাণ কামনা করবে, তার জেনে রাখা প্রয়োজন যে, দুনিয়া ও আখেরাতের কল্যাণ আল্লাহরই নিকট রয়েছে। আর আল্লাহ সব কিছু শোনেন ও দেখেন।\qt@no{(134)}}
\qt@newcmd\qurantrans@bn@dcxxviii{হে ঈমানদারগণ, তোমরা ন্যায়ের উপর প্রতিষ্ঠিত থাক; আল্লাহর ওয়াস্তে ন্যায়সঙ্গত সাক্ষ্যদান কর, তাতে তোমাদের নিজের বা পিতা-মাতার অথবা নিকটবর্তী আত্নীয়-স্বজনের যদি ক্ষতি হয় তবুও। কেউ যদি ধনী কিংবা দরিদ্র হয়, তবে আল্লাহ তাদের শুভাকাঙ্খী তোমাদের চাইতে বেশী। অতএব, তোমরা বিচার করতে গিয়ে রিপুর কামনা-বাসনার অনুসরণ করো না। আর যদি তোমরা ঘুরিয়ে-পেঁচিয়ে কথা বল কিংবা পাশ কাটিয়ে যাও, তবে আল্লাহ তোমাদের যাবতীয় কাজ কর্ম সম্পর্কেই অবগত।\qt@no{(135)}}
\qt@newcmd\qurantrans@bn@dcxxix{হে ঈমানদারগণ, আল্লাহর উপর পরিপূর্ণ বিশ্বাস স্থাপন কর এবং বিশ্বাস স্থাপন কর তাঁর রসূলও তাঁর কিতাবের উপর, যা তিনি নাযিল করেছেন স্বীয় রসূলের উপর এবং সেসমস্ত কিতাবের উপর, যেগুলো নাযিল করা হয়েছিল ইতিপূর্বে। যে আল্লাহর উপর, তাঁর ফেরেশতাদের উপর, তাঁর কিতাব সমূহের উপর এবং রসূলগণের উপর ও কিয়ামতদিনের উপর বিশ্বাস করবে না, সে পথভ্রষ্ট হয়ে বহু দূরে গিয়ে পড়বে।\qt@no{(136)}}
\qt@newcmd\qurantrans@bn@dcxxx{যারা একবার মুসলমান হয়ে পরে পুনরায় কাফের হয়ে গেছে, আবার মুসলমান হয়েছে এবং আবারো কাফের হয়েছে এবং কুফরীতেই উন্নতি লাভ করেছে, আল্লাহ তাদেরকে না কখনও ক্ষমা করবেন, না পথ দেখাবেন।\qt@no{(137)}}
\qt@newcmd\qurantrans@bn@dcxxxi{সেসব মুনাফেককে সুসংবাদ শুনিয়ে দিন যে, তাদের জন্য নির্ধারিত রয়েছে বেদনাদায়ক আযাব।\qt@no{(138)}}
\qt@newcmd\qurantrans@bn@dcxxxii{যারা মুসলমানদের বর্জন করে কাফেরদেরকে নিজেদের বন্ধু বানিয়ে নেয় এবং তাদেরই কাছে সম্মান প্রত্যাশা করে, অথচ যাবতীয় সম্মান শুধুমাত্র আল্লাহরই জন্য।\qt@no{(139)}}
\qt@newcmd\qurantrans@bn@dcxxxiii{আর কোরআনের মাধ্যমে তোমাদের প্রতি এই হুকুম জারি করে দিয়েছেন যে, যখন আল্লাহ তা’ আলার আয়াতসমূহের প্রতি অস্বীকৃতি জ্ঞাপন ও বিদ্রুপ হতে শুনবে, তখন তোমরা তাদের সাথে বসবে না, যতক্ষণ না তারা প্রসঙ্গান্তরে চলে যায়। তা না হলে তোমরাও তাদেরই মত হয়ে যাবে। আল্লাহ দোযখের মাঝে মুনাফেক ও কাফেরদেরকে একই জায়গায় সমবেত করবেন।\qt@no{(140)}}
\qt@newcmd\qurantrans@bn@dcxxxiv{এরা এমনি মুনাফেক যারা তোমাদের কল্যাণ-অকল্যাণের প্রতীক্ষায় ওঁৎপেতে থাকে। অতঃপর আল্লাহর ইচ্ছায় তোমাদের যদি কোন বিজয় অর্জিত হয়, তবে তারা বলে, আমরাও কি তোমাদের সাথে ছিলাম না? পক্ষান্তরে কাফেরদের যদি আংশিক বিজয় হয়, তবে বলে, আমরা কি তোমাদেরকে ঘিরে রাখিনি এবং মুসলমানদের কবল থেকে রক্ষা করিনি? সুতরাং আল্লাহ তোমাদের মধ্যে কেয়ামতের দিন মীমাংসা করবেন এবং কিছুতেই আল্লাহ কাফেরদেরকে মুসলমানদের উপর বিজয় দান করবেন না।\qt@no{(141)}}
\qt@newcmd\qurantrans@bn@dcxxxv{অবশ্যই মুনাফেকরা প্রতারণা করছে আল্লাহর সাথে, অথচ তারা নিজেরাই নিজেদের প্রতারিত করে। বস্তুতঃ তারা যখন নামাযে দাঁড়ায় তখন দাঁড়ায়, একান্ত শিথিল ভাবে লোক দেখানোর জন্য। আর তারা আল্লাহকে অল্পই স্মরণ করে।\qt@no{(142)}}
\qt@newcmd\qurantrans@bn@dcxxxvi{এরা দোদুল্যমান অবস্থায় ঝুলন্ত; এদিকেও নয় ওদিকেও নয়। বস্তুতঃ যাকে আল্লাহ গোমরাহ করে দেন, তুমি তাদের জন্য কোন পথই পাবে না কোথাও।\qt@no{(143)}}
\qt@newcmd\qurantrans@bn@dcxxxvii{হে ঈমানদারগণ! তোমরা কাফেরদেরকে বন্ধু বানিও না মুসলমানদের বাদ দিয়ে। তোমরা কি এমনটি করে নিজের উপর আল্লাহর প্রকাশ্য দলীল কায়েম করে দেবে?\qt@no{(144)}}
\qt@newcmd\qurantrans@bn@dcxxxviii{নিঃসন্দেহে মুনাফেকরা রয়েছে দোযখের সর্বনিম্ন স্তরে। আর তোমরা তাদের জন্য কোন সাহায্যকারী কখনও পাবে না।\qt@no{(145)}}
\qt@newcmd\qurantrans@bn@dcxxxix{অবশ্য যারা তওবা করে নিয়েছে, নিজেদের অবস্থার সংস্কার করেছে এবং আল্লাহর পথকে সুদৃঢ়ভাবে আঁকড়ে ধরে আল্লাহর ফরমাবরদার হয়েছে, তারা থাকবে মুসলমানদেরই সাথে। বস্তুতঃ আল্লাহ শীঘ্রই ঈমানদারগণকে মহাপূণ্য দান করবেন।\qt@no{(146)}}
\qt@newcmd\qurantrans@bn@dcxl{তোমাদের আযাব দিয়ে আল্লাহ কি করবেন যদি তোমরা কৃতজ্ঞতা প্রকাশ কর এবং ঈমানের উপর প্রতিষ্ঠিত থাক! আর আল্লাহ হচ্ছেন সমুচিত মূল্যদানকারী সর্বজ্ঞ।\qt@no{(147)}}
\qt@newcmd\qurantrans@bn@dcxli{আল্লাহ কোন মন্দ বিষয় প্রকাশ করা পছন্দ করেন না। তবে কারো প্রতি জুলুম হয়ে থাকলে সে কথা আলাদা। আল্লাহ শ্রবণকারী, বিজ্ঞ।\qt@no{(148)}}
\qt@newcmd\qurantrans@bn@dcxlii{তোমরা যদি কল্যাণ কর প্রকাশ্যভাবে কিংবা গোপনে অথবা যদি তোমরা আপরাধ ক্ষমা করে দাও, তবে জেনো, আল্লাহ নিজেও ক্ষমাকারী, মহাশক্তিশালী।\qt@no{(149)}}
\qt@newcmd\qurantrans@bn@dcxliii{যারা আল্লাহ ও তার রসূলের প্রতি অস্বীকৃতি জ্ঞাপনকারী তদুপরি আল্লাহ ও রসূলের প্রতি বিশ্বাসে তারতম্য করতে চায় আর বলে যে, আমরা কতককে বিশ্বাস করি কিন্তু কতককে প্রত্যাখ্যান করি এবং এরই মধ্যবর্তী কোন পথ অবলম্বন করতে চায়।\qt@no{(150)}}
\qt@newcmd\qurantrans@bn@dcxliv{প্রকৃতপক্ষে এরাই সত্য প্রত্যাখ্যাকারী। আর যারা সত্য প্রত্যাখ্যানকারী তাদের জন্য তৈরী করে রেখেছি অপমানজনক আযাব।\qt@no{(151)}}
\qt@newcmd\qurantrans@bn@dcxlv{আর যারা ঈমান এনেছে আল্লাহর উপর, তাঁর রসূলের উপর এবং তাঁদের কারও প্রতি ঈমান আনতে গিয়ে কাউকে বাদ দেয়নি, শীঘ্রই তাদেরকে প্রাপ্য সওয়াব দান করা হবে। বস্তুতঃ আল্লাহ ক্ষমাশীল দয়ালু।\qt@no{(152)}}
\qt@newcmd\qurantrans@bn@dcxlvi{আপনার নিকট আহলে-কিতাবরা আবেদন জানায় যে, আপনি তাদের উপর আসমান থেকে লিখিত কিতাব অবতীর্ণ করিয়ে নিয়ে আসুন। বস্তুতঃ এরা মূসার কাছে এর চেয়েও বড় জিনিস চেয়েছে। বলেছে, একেবারে সামনাসামনিভাবে আমাদের আল্লাহকে দেখিয়ে দাও। অতএব, তাদের উপর বজ্রপাত হয়েছে তাদের পাপের দরুন; অতঃপর তাদের নিকট সুস্পষ্ট প্রমাণ-নিদর্শন প্রকাশিত হবার পরেও তারা গো-বৎসকে উপাস্যরূপে গ্রহণ করেছিল; তাও আমি ক্ষমা করে দিয়েছিলাম এবং আমি মূসাকে প্রকৃষ্ট প্রভাব দান করেছিলাম।\qt@no{(153)}}
\qt@newcmd\qurantrans@bn@dcxlvii{আর তাদের কাছ থেকে প্রতিশ্রুতি নেবার উদ্দেশ্যে আমি তাদের উপর তূর পর্বতকে তুলে ধরেছিলাম এবং তাদেরকে বলেছিলাম, অবনত মস্তকে দরজায় ঢোক। আর বলেছিলাম, শনিবার দিন সীমালংঘন করো না। এভাবে তাদের কাছ থেকে দৃঢ় অঙ্গীকার নিয়েছিলাম।\qt@no{(154)}}
\qt@newcmd\qurantrans@bn@dcxlviii{অতএব, তারা যে শাস্তিপ্রাপ্ত হয়েছিল, তা ছিল তাদেরই অঙ্গীকার ভঙ্গর জন্য এবং অন্যায়ভাবে রসূলগণকে হত্যা করার কারণে এবং তাদের এই উক্তির দরুন যে, আমাদের হৃদয় আচ্ছন্ন। অবশ্য তা নয়, বরং কুফরীর কারণে স্বয়ং আল্লাহ তাদের অন্তরের উপর মোহর এঁটে দিয়েছেন। ফলে এরা ঈমান আনে না কিন্তু অতি অল্পসংখ্যক।\qt@no{(155)}}
\qt@newcmd\qurantrans@bn@dcxlix{আর তাদের কুফরী এবং মরিয়মের প্রতি মহা অপবাদ আরোপ করার কারণে।\qt@no{(156)}}
\qt@newcmd\qurantrans@bn@dcl{আর তাদের একথা বলার কারণে যে, আমরা মরিয়ম পুত্র ঈসা মসীহকে হত্যা করেছি যিনি ছিলেন আল্লাহর রসূল। অথচ তারা না তাঁকে হত্যা করেছে, আর না শুলীতে চড়িয়েছে, বরং তারা এরূপ ধাঁধায় পতিত হয়েছিল। বস্তুতঃ তারা এ ব্যাপারে নানা রকম কথা বলে, তারা এক্ষেত্রে সন্দেহের মাঝে পড়ে আছে, শুধুমাত্র অনুমান করা ছাড়া তারা এ বিষয়ে কোন খবরই রাখে না। আর নিশ্চয়ই তাঁকে তারা হত্যা করেনি।\qt@no{(157)}}
\qt@newcmd\qurantrans@bn@dcli{বরং তাঁকে উঠিয়ে নিয়েছেন আল্লাহ তা’আলা নিজের কাছে। আর আল্লাহ হচ্ছেন মহাপরাক্রমশালী, প্রজ্ঞাময়।\qt@no{(158)}}
\qt@newcmd\qurantrans@bn@dclii{আর আহলে-কিতাবদের মধ্যে যত শ্রেণী রয়েছে তারা সবাই ঈমান আনবে ঈসার উপর তাদের মৃত্যুর পূর্বে। আর কেয়ামতের দিন তাদের জন্য সাক্ষীর উপর সাক্ষী উপস্থিত হবে।\qt@no{(159)}}
\qt@newcmd\qurantrans@bn@dcliii{বস্তুতঃ ইহুদীদের জন্য আমি হারাম করে দিয়েছি বহু পূত-পবিত্র বস্তু যা তাদের জন্য হালাল ছিল-তাদের পাপের কারণে এবং আল্লাহর পথে অধিক পরিমাণে বাধা দানের দরুন।\qt@no{(160)}}
\qt@newcmd\qurantrans@bn@dcliv{আর এ কারণে যে, তারা সুদ গ্রহণ করত, অথচ এ ব্যাপারে নিষেধাজ্ঞা আরোপ করা হয়েছিল এবং এ কারণে যে, তারা অপরের সম্পদ ভোগ করতো অন্যায় ভাবে। বস্তুত; আমি কাফেরদের জন্য তৈরী করে রেখেছি বেদনাদায়ক আযাব।\qt@no{(161)}}
\qt@newcmd\qurantrans@bn@dclv{কিন্তু যারা তাদের মধ্যে জ্ঞানপক্ক ও ঈমানদার, তারা তাও মান্য করে যা আপনার উপর অবতীর্ণ হয়েছে এবং যা অবতীর্ণ হয়েছে আপনার পূর্বে। আর যারা নামাযে অনুবর্তিতা পালনকারী, যারা যাকাত দানকারী এবং যারা আল্লাহ ও কেয়ামতে আস্থাশীল। বস্তুতঃ এমন লোকদেরকে আমি দান করবো মহাপুণ্য।\qt@no{(162)}}
\qt@newcmd\qurantrans@bn@dclvi{আমি আপনার প্রতি ওহী পাঠিয়েছি, যেমন করে ওহী পাঠিয়েছিলাম নূহের প্রতি এবং সে সমস্ত নবী-রসূলের প্রতি যাঁরা তাঁর পরে প্রেরিত হয়েছেন। আর ওহী পাঠিয়েছি, ইসমাঈল, ইব্রাহীম, ইসহাক, ইয়াকুব, ও তাঁর সন্তাবর্গের প্রতি এবং ঈসা, আইয়ুব, ইউনূস, হারুন ও সুলায়মানের প্রতি। আর আমি দাউদকে দান করেছি যবুর গ্রন্থ।\qt@no{(163)}}
\qt@newcmd\qurantrans@bn@dclvii{এছাড়া এমন রসূল পাঠিয়েছি যাদের ইতিবৃত্ত আমি আপনাকে শুনিয়েছি ইতিপূর্বে এবং এমন রসূল পাঠিয়েছি যাদের বৃত্তান্ত আপনাকে শোনাইনি। আর আল্লাহ মূসার সাথে কথোপকথন করেছেন সরাসরি।\qt@no{(164)}}
\qt@newcmd\qurantrans@bn@dclviii{সুসংবাদদাতা ও ভীতি-প্রদর্শনকারী রসূলগণকে প্রেরণ করেছি, যাতে রসূলগণের পরে আল্লাহর প্রতি অপবাদ আরোপ করার মত কোন অবকাশ মানুষের জন্য না থাকে। আল্লাহ প্রবল পরাক্রমশীল, প্রাজ্ঞ।\qt@no{(165)}}
\qt@newcmd\qurantrans@bn@dclix{আল্লাহ আপনার প্রতি যা অবতীর্ণ করেছেন তিনি যে তা সজ্ঞানেই করেছেন, সে ব্যাপারে আল্লাহ নিজেও সাক্ষী এবং ফেরেশতাগণও সাক্ষী। আর সাক্ষী হিসাবে আল্লাহই যথেষ্ট।\qt@no{(166)}}
\qt@newcmd\qurantrans@bn@dclx{যারা কুফরী অবলম্বন করেছে, এবং আল্লাহর পথে বাধার সৃষ্টি করেছে, তারা বিভ্রান্তিতে সুদূরে পতিত হয়েছে।\qt@no{(167)}}
\qt@newcmd\qurantrans@bn@dclxi{যারা কুফরী অবলম্বন করেছে এবং সত্য চাপা দিয়ে রেখেছে, আল্লাহ কখনও তাদের ক্ষমা করবেন না এবং সরল পথ দেখাবেন না।\qt@no{(168)}}
\qt@newcmd\qurantrans@bn@dclxii{তাদের জন্য রয়েছে জাহান্নামের পথ। সেখানে তারা বাস করবে অনন্তকাল। আর এমন করাটা আল্লাহর পক্ষে সহজ।\qt@no{(169)}}
\qt@newcmd\qurantrans@bn@dclxiii{হে মানবজাতি! তোমাদের পালনকর্তার যথার্থ বাণী নিয়ে তোমাদের নিকট রসূল এসেছেন, তোমরা তা মেনে নাও যাতে তোমাদের কল্যাণ হতে পারে। আর যদি তোমরা তা না মান, জেনে রাখ আসমানসমূহে ও যমীনে যা কিছু রয়েছে সে সবকিছুই আল্লাহর। আর আল্লাহ হচ্ছেন সর্বজ্ঞ, প্রাজ্ঞ।\qt@no{(170)}}
\qt@newcmd\qurantrans@bn@dclxiv{হে আহলে-কিতাবগণ! তোমরা দ্বীনের ব্যাপারে বাড়াবাড়ি করো না এবং আল্লাহর শানে নিতান্ত সঙ্গত বিষয় ছাড়া কোন কথা বলো না। নিঃসন্দেহে মরিয়ম পুত্র মসীহ ঈসা আল্লাহর রসূল এবং তাঁর বাণী যা তিনি প্রেরণ করেছেন মরিয়মের নিকট এবং রূহ-তাঁরই কাছ থেকে আগত। অতএব, তোমরা আল্লাহকে এবং তার রসূলগণকে মান্য কর। আর একথা বলো না যে, আল্লাহ তিনের এক, একথা পরিহার কর; তোমাদের মঙ্গল হবে। নিঃসন্দেহে আল্লাহ একক উপাস্য। সন্তান-সন্ততি হওয়াটা তাঁর যোগ্য বিষয় নয়। যা কিছু আসমান সমূহ ও যমীনে রয়েছে সবই তার। আর কর্মবিধানে আল্লাহই যথেষ্ট।\qt@no{(171)}}
\qt@newcmd\qurantrans@bn@dclxv{মসীহ আল্লাহর বান্দা হবেন, তাতে তার কোন লজ্জাবোধ নেই এবং ঘনিষ্ঠ ফেরেশতাদেরও না। বস্তুতঃ যারা আল্লাহর দাসত্বে লজ্জাবোধ করবে এবং অহংকার করবে, তিনি তাদের সবাইকে নিজের কাছে সমবেত করবেন।\qt@no{(172)}}
\qt@newcmd\qurantrans@bn@dclxvi{অতঃপর যারা ঈমান এনেছে এবং সৎকাজ করেছে, তিনি তাদেরকে পরিপূর্ণ সওয়াব দান করবেন, বরং স্বীয় অনুগ্রহে আরো বেশী দেবেন। পক্ষান্তরে যারা লজ্জাবোধ করেছে এবং অহঙ্কার করেছে তিনি তাদেরকে দেবেন বেদনাদায়ক আযাব। আল্লাহকে ছাড়া তারা কোন সাহায্যকারী ও সমর্থক পাবে না।\qt@no{(173)}}
\qt@newcmd\qurantrans@bn@dclxvii{হে মানবকুল! তোমাদের পরওয়ারদেগারের পক্ষ থেকে তোমাদের নিকট সনদ পৌঁছে গেছে। আর আমি তোমাদের প্রতি প্রকৃষ্ট আলো অবতীর্ণ করেছি।\qt@no{(174)}}
\qt@newcmd\qurantrans@bn@dclxviii{অতএব, যারা আল্লাহর প্রতি ঈমান এনেছে এবং তাতে দৃঢ়তা অবলম্বন করেছে তিনি তাদেরকে স্বীয় রহমত ও অনুগ্রহের আওতায় স্থান দেবেন এবং নিজের দিকে আসার মত সরল পথে তুলে দেবেন।\qt@no{(175)}}
\qt@newcmd\qurantrans@bn@dclxix{মানুষ আপনার নিকট ফতোয়া জানতে চায় অতএব, আপনি বলে দিন, আল্লাহ তোমাদিগকে কালালাহ এর মীরাস সংক্রান্ত সুস্পষ্ট নির্দেশ বাতলে দিচ্ছেন, যদি কোন পুরুষ মারা যায় এবং তার কোন সন্তানাদি না থাকে এবং এক বোন থাকে, তবে সে পাবে তার পরিত্যাক্ত সম্পত্তির অর্ধেক অংশ এবং সে যদি নিঃসন্তান হয়, তবে তার ভাই তার উত্তরাধিকারী হবে। তা দুই বোন থাকলে তাদের জন্য পরিত্যক্ত সম্পত্তির দুই তৃতীয়াংশ। পক্ষান্তরে যদি ভাই ও বোন উভয়ই থাকে, তবে একজন পুরুষের অংশ দুজন নারীর সমান। তোমরা বিভ্রান্ত হবে আল্লাহ তোমাদিগকে সুস্পষ্ট ভাবে জানিয়ে দিচ্ছেন। আর আল্লাহ হচ্ছেন সর্ব বিষয়ে পরিজ্ঞাত।\qt@no{(176)}}
\qt@newcmd\qurantrans@bn@dclxx{\basmalahbn মুমিনগণ, তোমরা অঙ্গীকারসমূহ পূর্ন কর। তোমাদের জন্য চতুষ্পদ জন্তু হালাল করা হয়েছে, যা তোমাদের কাছে বিবৃত হবে তা ব্যতীত। কিন্তু এহরাম বাধাঁ অবস্থায় শিকারকে হালাল মনে করো না! নিশ্চয় আল্লাহ তা’আলা যা ইচ্ছা করেন, নির্দেশ দেন।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@dclxxi{হে মুমিনগণ! হালাল মনে করো না আল্লাহর নিদর্শনসমূহ এবং সম্মানিত মাসসমূহকে এবং হরমে কুরবানীর জন্যে নির্দিষ্ট জন্তুকে এবং ঐসব জন্তুকে, যাদের গলায় কন্ঠাভরণ রয়েছে এবং ঐসব লোককে যারা সম্মানিত গৃহ অভিমুখে যাচ্ছে, যারা স্বীয় পালনকর্তার অনুগ্রহ ও সন্তুষ্টি কামনা করে। যখন তোমরা এহরাম থেকে বের হয়ে আস, তখন শিকার কর। যারা পবিত্র মসজিদ থেকে তোমাদেরকে বাধা প্রদান করেছিল, সেই সম্প্রদায়ের শুত্রুতা যেন তোমাদেরকে সীমালঙ্ঘনে প্ররোচিত না করে। সৎকর্ম ও খোদাভীতিতে একে অন্যের সাহায্য কর। পাপ ও সীমালঙ্ঘনের ব্যাপারে একে অন্যের সহায়তা করো না। আল্লাহকে ভয় কর। নিশ্চয় আল্লাহ তা’আলা কঠোর শাস্তিদাতা।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@dclxxii{তোমাদের জন্যে হারাম করা হয়েছে মৃত জীব, রক্ত, শুকরের মাংস, যেসব জন্তু আল্লাহ ছাড়া অন্যের নামে উৎসর্গকৃত হয়, যা কন্ঠরোধে মারা যায়, যা আঘাত লেগে মারা যায়, যা উচ্চ স্থান থেকে পতনের ফলে মারা যা, যা শিং এর আঘাতে মারা যায় এবং যাকে হিংস্র জন্তু ভক্ষণ করেছে, কিন্তু যাকে তোমরা যবেহ করেছ। যে জন্তু যজ্ঞবেদীতে যবেহ করা হয় এবং যা ভাগ্য নির্ধারক শর দ্বারা বন্টন করা হয়। এসব গোনাহর কাজ। আজ কাফেররা তোমাদের দ্বীন থেকে নিরাশ হয়ে গেছে। অতএব তাদেরকে ভয় করো না বরং আমাকে ভয় কর। আজ আমি তোমাদের জন্যে তোমাদের দ্বীনকে পূর্নাঙ্গ করে দিলাম, তোমাদের প্রতি আমার অবদান সম্পূর্ণ করে দিলাম এবং ইসলামকে তোমাদের জন্যে দ্বীন হিসেবে পছন্দ করলাম। অতএব যে ব্যাক্তি তীব্র ক্ষুধায় কাতর হয়ে পড়ে; কিন্তু কোন গোনাহর প্রতি প্রবণতা না থাকে, তবে নিশ্চয়ই আল্লাহ তা’আলা ক্ষমাশীল।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@dclxxiii{তারা আপনাকে জিজ্ঞেস করে যে, কি বস্তু তাদের জন্যে হালাল? বলে দিন, তোমাদের জন্যে পবিত্র বস্তুসমূহ হালাল করা হয়েছে। যেসব শিকারী জন্তুকে তোমরা প্রশিক্ষণ দান কর শিকারের প্রতি প্রেরণের জন্যে এবং ওদেরকে ঐ পদ্ধতিতে প্রশিক্ষণ দাও, যা আল্লাহ তোমাদেরকে শিক্ষা দিয়েছেন। এমন শিকারী জন্তু যে শিকারকে তোমাদের জন্যে ধরে রাখে, তা খাও এবং তার উপর আল্লাহর নাম উচ্চারণ কর। আল্লাহকে ভয় করতে থাক। নিশ্চয় আল্লাহ সত্ত্বর হিসাব গ্রহণকারী।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@dclxxiv{আজ তোমাদের জন্য পবিত্র বস্তুসমূহ হালাল করা হল। আহলে কিতাবদের খাদ্য তোমাদের জন্যে হালাল এবং তোমাদের খাদ্য তাদের জন্য হালাল। তোমাদের জন্যে হালাল সতী-সাধ্বী মুসলমান নারী এবং তাদের সতী-সাধ্বী নারী, যাদেরকে কিতাব দেয়া হয়েছে তোমাদের পূর্বে, যখন তোমরা তাদেরকে মোহরানা প্রদান কর তাদেরকে স্ত্রী করার জন্যে, কামবাসনা চরিতার্থ করার জন্যে কিংবা গুপ্ত প্রেমে লিপ্ত হওয়ার জন্যে নয়। যে ব্যক্তি বিশ্বাসের বিষয় অবিশ্বাস করে, তার শ্রম বিফলে যাবে এবং পরকালে সে ক্ষতিগ্রস্ত হবে।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@dclxxv{হে মুমিনগণ, যখন তোমরা নামাযের জন্যে উঠ, তখন স্বীয় মুখমন্ডল ও হস্তসমূহ কনুই পর্যন্ত ধৌত কর, মাথা মুছেহ কর এবং পদযুগল গিটসহ। যদি তোমরা অপবিত্র হও তবে সারা দেহ পবিত্র করে নাও এবং যদি তোমরা রুগ্ন হও, অথবা প্রবাসে থাক অথবা তোমাদের কেউ প্রসাব-পায়খানা সেরে আসে অথবা তোমরা স্ত্রীদের সাথে সহবাস কর, অতঃপর পানি না পাও, তবে তোমরা পবিত্র মাটি দ্বারা তায়াম্মুম করে নাও-অর্থাৎ, স্বীয় মুখ-মন্ডল ও হস্তদ্বয় মাটি দ্বারা মুছে ফেল। আল্লাহ তোমাদেরকে অসুবিধায় ফেলতে চান না; কিন্তু তোমাদেরকে পবিত্র রাখতে চান এবং তোমাদের প্রতি স্বীয় নেয়ামত পূর্ণ করতে চান-যাতে তোমরা কৃতজ্ঞাতা প্রকাশ কর।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@dclxxvi{তোমরা আল্লাহর নেয়ামতের কথা স্মরণ কর, যা তোমাদের প্রতি অবতীর্ণ হয়েছে এবং ঐ অঙ্গীকারকেও যা তোমাদের কাছ থেকে নিয়েছেন, যখন তোমরা বলেছিলেঃ আমরা শুনলাম এবং মেনে নিলাম। আল্লাহকে ভয় কর। নিশ্চয়ই আল্লাহ অন্তরের বিষয় সম্পর্কে পুরোপুরি খবর রাখেন।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@dclxxvii{হে মুমিনগণ, তোমরা আল্লাহর উদ্দেশে ন্যায় সাক্ষ্যদানের ব্যাপারে অবিচল থাকবে এবং কোন সম্প্রদায়ের শত্রুতার কারণে কখনও ন্যায়বিচার পরিত্যাগ করো না। সুবিচার কর এটাই খোদাভীতির অধিক নিকটবর্তী। আল্লাহকে ভয় কর। তোমরা যা কর, নিশ্চয় আল্লাহ সে বিষয়ে খুব জ্ঞাত।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@dclxxviii{যারা বিশ্বাস স্থাপন করে, এবং সৎকর্ম সম্পাদন করে, আল্লাহ তাহাদেরকে ক্ষমা ও মহান প্রতিদানের প্রতিশ্রুতি দিয়েছেন।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@dclxxix{যারা অবিশ্বাস করে এবং আমার নিদর্শনাবলীকে মিথ্যা বলে, তার দোযখী।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@dclxxx{হে মুমিনগণ, তোমাদের প্রতি আল্লাহর অনুগ্রহ স্মরণ কর, যখন এক সম্প্রদায় তোমাদের দিকে স্বীয় হস্ত প্রসারিত করতে সচেষ্ট হয়েছিল, তখন তিনি তাদের হস্ত তোমাদের থেকে প্রতিহত করে দিলেন। আল্লাহকে ভয় কর এবং মুমিনদের আল্লাহর উপরই ভরসা করা উচিত।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@dclxxxi{আল্লাহ বনী-ইসরাঈলের কাছ থেকে অঙ্গীকার নিয়েছিলেন এবং আমি তাদের মধ্য থেকে বার জন সর্দার নিযুক্ত করেছিলাম। আল্লাহ বলে দিলেনঃ আমি তোমাদের সঙ্গে আছি। যদি তোমরা নামায প্রতিষ্ঠিত কর, যাকাত দিতে থাক, আমার পয়গম্বরদের প্রতি বিশ্বাস রাখ, তাঁদের সাহায্য কর এবং আল্লাহকে উত্তম পন্থায় ঋন দিতে থাক, তবে আমি অবশ্যই তোমাদের গোনাহ দুর করে দিব এবং অবশ্যই তোমাদেরকে উদ্যান সমূহে প্রবিষ্ট করব, যেগুলোর তলদেশ দিয়ে নিঝরিনীসমূহ প্রবাহিত হয়। অতঃপর তোমাদের মধ্য থেকে যে ব্যক্তি এরপরও কাফের হয়, সে নিশ্চিতই সরল পথ থেকে বিচ্যুত হয়ে পড়ে।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@dclxxxii{অতএব, তাদের অঙ্গীকার ভঙ্গের দরুন আমি তাদের উপর অভিসম্পাত করেছি এবং তাদের অন্তরকে কঠোর করে দিয়েছি। তারা কালামকে তার স্থান থেকে বিচ্যুত করে দেয় এবং তাদেরকে যে উপদেশ দেয়া হয়েছিল, তারা তা থেকে উপকার লাভ করার বিষয়টি বিস্মৃত হয়েছে। আপনি সর্বদা তাদের কোন না কোন প্রতারণা সম্পর্কে অবগত হতে থাকেন, তাদের অল্প কয়েকজন ছাড়া। অতএব, আপনি তাদেরকে ক্ষমা করুন এবং মার্জনা করুন। আল্লাহ অনুগ্রহকারীদেরকে ভালবাসেন।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@dclxxxiii{যারা বলেঃ আমরা নাছারা, আমি তাদের কাছ থেকেও তাদের অঙ্গীকার নিয়েছিলাম। অতঃপর তারাও যে উপদেশ প্রাপ্ত হয়েছিল, তা থেকে উপকার লাভ করা ভুলে গেল। অতঃপর আমি কেয়ামত পর্যন্ত তাদের মধ্যে পারস্পরিক শত্রুতা ও বিদ্বেষ সঞ্চারিত করে দিয়েছি। অবশেষে আল্লাহ তাদেরকে তাদের কৃতকর্ম সম্পর্কে অবহিত করবেন।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@dclxxxiv{হে আহলে-কিতাবগণ! তোমাদের কাছে আমার রাসূল আগমন করেছেন! কিতাবের যেসব বিষয় তোমরা গোপন করতে, তিনি তার মধ্য থেকে অনেক বিষয় প্রকাশ করেন এবং অনেক বিষয় মার্জনা করেন। তোমাদের কাছে একটি উজ্জল জ্যোতি এসেছে এবং একটি সমুজ্জল গ্রন্থ।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@dclxxxv{এর দ্বারা আল্লাহ যারা তাঁর সন্তুষ্টি কামনা করে, তাদেরকে নিরাপত্তার পথ প্রদর্শন করেন এবং তাদেরকে স্বীয় নির্দেশ দ্বারা অন্ধকার থেকে বের করে আলোর দিকে আনয়ন করেন এবং সরল পথে পরিচালনা করেন।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@dclxxxvi{নিশ্চয় তারা কাফের, যারা বলে, মসীহ ইবনে মরিয়মই আল্লাহ। আপনি জিজ্ঞেস করুন, যদি তাই হয়, তবে বল যদি আল্লাহ মসীহ ইবনে মরিয়ম, তাঁর জননী এবং ভূমন্ডলে যারা আছে, তাদের সবাইকে ধ্বংস করতে চান, তবে এমন কারও সাধ্য আছে কি যে আল্লাহর কাছ থেকে তাদেরকে বিন্দুমাত্রও বাঁচাতে পারে? নভোমন্ডল, ভুমন্ডল ও এতদুভয়ের মধ্যে যা আছে, সবকিছুর উপর আল্লাহ তা’আলার আধিপত্য। তিনি যা ইচ্ছা সৃষ্টি করেন। আল্লাহ সবকিছুর উপর শক্তিমান।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@dclxxxvii{ইহুদী ও খ্রীষ্টানরা বলে, আমরা আল্লাহর সন্তান ও তাঁর প্রিয়জন। আপনি বলুন, তবে তিনি তোমাদেরকে পাপের বিনিময়ে কেন শাস্তি দান করবেন? বরং তোমারও অন্যান্য সৃষ্ট মানবের অন্তর্ভুক্ত সাধারণ মানুষ। তিনি যাকে ইচ্ছা ক্ষমা করেন এবং যাকে ইচ্ছা শাস্তি প্রদান করেন। নভোমন্ডল, ভুমন্ডল ও এতদুভয়ের মধ্যে যা কিছু আছে, তাতে আল্লাহরই আধিপত্য রয়েছে এবং তাঁর দিকেই প্রত্যাবর্তন করতে হবে।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@dclxxxviii{হে আহলে-কিতাবগণ! তোমাদের কাছে আমার রসূল আগমণ করেছেন, যিনি পয়গম্বরদের বিরতির পর তোমাদের কাছে পুঙ্খানুপুঙ্খ বর্ণনা করেন-যাতে তোমরা একথা বলতে না পার যে, আমাদের কাছে কোন সুসংবাদদাতা ও ভীতিপ্রদর্শক আগমন করে নি। অতএব, তোমাদের কাছে সুসংবাদদাতা ও ভীতি প্রদর্শক আগমন করেননি। অতএব, তোমাদের কাছে সুসংবাদদাতা ও ভয় প্রদর্শক এসে গেছেন। আল্লাহ সবকিছুর উপর শক্তিমান।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@dclxxxix{যখন মূসা স্বীয় সম্প্রদায়কে বললেনঃ হে আমার সম্প্রদায়, তোমাদের প্রতি আল্লাহর নেয়ামত স্মরণ কর, যখন তিনি তোমাদের মধ্যে পয়গম্বর সৃষ্টি করেছেন, তোমাদেরকে রাজ্যাধিপতি করেছেন এবং তোমাদেরকে এমন জিনিস দিয়েছেন, যা বিশ্বজগতের কাউকে দেননি।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@dcxc{হে আমার সম্প্রদায়, পবিত্র ভুমিতে প্রবেশ কর, যা আল্লাহ তোমাদের জন্যে নির্ধারিত করে দিয়েছেন এবং পেছন দিকে প্রত্যাবর্তন করো না। অন্যথায় তোমরা ক্ষতিগ্রস্ত হয়ে পড়বে।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@dcxci{তারা বললঃ হে মূসা, সেখানে একটি প্রবল পরাক্রান্ত জাতি রয়েছে। আমরা কখনও সেখানে যাব না, যে পর্যন্ত না তারা সেখান থেকে বের হয়ে যায়। তারা যদি সেখান থেকে বের হয়ে যায় তবে নিশ্চিতই আমরা প্রবেশ করব।’\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@dcxcii{খোদাভীরুদের মধ্য থেকে দু’ব্যক্তি বলল, যাদের প্রতি আল্লাহ অনুগ্রহ করেছিলেনঃ তোমরা তাদের উপর আক্রমণ করে দরজায় প্রবেশ কর। অতঃপর তোমরা যখন তাতে পবেশ করবে, তখন তোমরাই জয়ী হবে। আর আল্লাহর উপর ভরসা কর যদি তোমরা বিশ্বাসী হও।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@dcxciii{তারা বললঃ হে মূসা, আমরা জীবনেও কখনো সেখানে যাব না, যতক্ষণ তারা সেখানে থাকবে। অতএব, আপনি ও আপনার পালনকর্তাই যান এবং উভয়ে যুদ্ধ করে নিন। আমরা তো এখানেই বসলাম।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@dcxciv{মূসা বললঃ হে আমার পালনকর্তা, আমি শুধু নিজের উপর ও নিজের ভাইয়ের উপর ক্ষমতা রাখি। অতএব, আপনি আমাদের মধ্যে ও এ অবাধ্য সম্প্রদায়ের মধ্যে সম্পর্কচ্ছেদ করুন।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@dcxcv{বললেনঃ এ দেশ চল্লিশ বছর পর্যন্ত তাদের জন্যে হারাম করা হল। তারা ভুপৃষ্ঠে উদভ্রান্ত হয়ে ফিরবে। অতএব, আপনি অবাধ্য সম্প্রদায়ের জন্যে দুঃখ করবেন না।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@dcxcvi{আপনি তাদেরকে আদমের দুই পুত্রের বাস্তব অবস্থা পাঠ করে শুনান। যখন তারা ভয়েই কিছু উৎসর্গ নিবেদন করেছিল, তখন তাদের একজনের উৎসর্গ গৃহীত হয়েছিল এবং অপরজনের গৃহীত হয়নি। সে বললঃ আমি অবশ্যই তোমাকে হত্যা করব। সে বললঃ আল্লাহ ধর্মভীরুদের পক্ষ থেকেই তো গ্রহণ করেন।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@dcxcvii{যদি তুমি আমাকে হত্যা করতে আমার দিকে হস্ত প্রসারিত কর, তবে আমি তোমাকে হত্যা করতে তোমার দিকে হস্ত প্রসারিত করব না। কেননা, আমি বিশ্বজগতের পালনকর্তা আল্লাহকে ভয় করি।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@dcxcviii{আমি চাই যে, আমার পাপ ও তোমার পাপ তুমি নিজের মাথায় চাপিয়ে নাও। অতঃপর তুমি দোযখীদের অন্তর্ভূক্ত হয়ে যাও। এটাই অত্যাচারীদের শাস্তি।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@dcxcix{অতঃপর তার অন্তর তাকে ভ্রাতৃহত্যায় উদুদ্ধ করল। অনন্তর সে তাকে হত্যা করল। ফলে সে ক্ষতিগ্রস্তদের অন্তর্ভুক্ত হয়ে গেল।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@dcc{আল্লাহ এক কাক প্রেরণ করলেন। সে মাটি খনন করছিল যাতে তাকে শিক্ষা দেয় যে, আপন ভ্রাতার মৃতদেহ কিভাবে আবৃত করবে। সে বললঃ আফসোস, আমি কি এ কাকের সমতুল্যও হতে পারলাম না যে, আপন ভ্রাতার মৃতদেহ আবৃত করি। অতঃপর সে অনুতাপ করতে লাগল।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@dcci{এ কারণেই আমি বনী-ইসলাঈলের প্রতি লিখে দিয়েছি যে, যে কেউ প্রাণের বিনিময়ে প্রাণ অথবাপৃথিবীতে অনর্থ সৃষ্টি করা ছাড়া কাউকে হত্যা করে সে যেন সব মানুষকেই হত্যা করে। এবং যে কারও জীবন রক্ষা করে, সে যেন সবার জীবন রক্ষা করে। তাদের কাছে আমার পয়গম্বরগণ প্রকাশ্য নিদর্শনাবলী নিয়ে এসেছেন। বস্তুতঃ এরপরও তাদের অনেক লোক পৃথিবীতে সীমাতিক্রম করে।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@dccii{যারা আল্লাহ ও তাঁর রসূলের সাথে সংগ্রাম করে এবং দেশে হাঙ্গামা সৃষ্টি করতে সচেষ্ট হয়, তাদের শাস্তি হচ্ছে এই যে, তাদেরকে হত্যা করা হবে অথবা শূলীতে চড়ানো হবে অথবা তাদের হস্তপদসমূহ বিপরীত দিক থেকে কেটে দেয়া হবে অথবা দেশ থেকে বহিষ্কার করা হবে। এটি হল তাদের জন্য পার্থিব লাঞ্ছনা আর পরকালে তাদের জন্যে রয়েছে কঠোর শাস্তি।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@dcciii{কিন্তু যারা তোমাদের গ্রেফতারের পূর্বে তওবা করে; জেনে রাখ, আল্লাহ ক্ষমাকারী, দয়ালু।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@dcciv{হে মুমিনগণ! আল্লাহকে ভয় কর, তাঁর নৈকট্য অন্বেষন কর এবং তাঁর পথে জেহাদ কর যাতে তোমরা সফলকাম হও।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@dccv{যারা কাফের, যদি তাদের কাছে পৃথিবীর সমুদয় সম্পদ এবং তৎসহ আরও তদনুরূপ সম্পদ থাকে আর এগুলো বিনিময়ে দিয়ে কিয়ামতের শাস্তি থেকে পরিত্রান পেতে চায়, তবুও তাদের কাছ থেকে তা কবুল করা হবে না। তাদের জন্যে যন্ত্রনাদায়ক শাস্তি রয়েছে।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@dccvi{তারা দোযখের আগুন থেকে বের হয়ে আসতে চাইবে কিন্তু তা থেকে বের হতে পারবে না। তারা চিরস্থায়ী শাস্তি ভোগ করবে।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@dccvii{যে পুরুষ চুরি করে এবং যে নারী চুরি করে তাদের হাত কেটে দাও তাদের কৃতকর্মের সাজা হিসেবে। আল্লাহর পক্ষ থেকে হুশিয়ারী। আল্লাহ পরাক্রান্ত, জ্ঞানময়।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@dccviii{অতঃপর যে তওবা করে স্বীয় অত্যাচারের পর এবং সংশোধিত হয়, নিশ্চয় আল্লাহ তার তওবা কবুল করেন। নিশ্চয় আল্লাহ ক্ষমাশীল, দয়ালু।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@dccix{তুমি কি জান না যে আল্লাহর নিমিত্তেই নভোমন্ডল ও ভূমন্ডলের আধিপত্য। তিনি যাকে ইচ্ছা শাস্তি দেন এবং যাকে ইচ্ছা ক্ষমা করেন। আল্লাহ সবকিছুর উপর ক্ষমতাবান।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@dccx{হে রসূল, তাদের জন্যে দুঃখ করবেন না, যারা দৌড়ে গিয়ে কুফরে পতিত হয়; যারা মুখে বলেঃ আমরা মুসলমান, অথচ তাদের অন্তর মুসলমান নয় এবং যারা ইহুদী; মিথ্যাবলার জন্যে তারা গুপ্তচর বৃত্তি করে। তারা অন্যদলের গুপ্তচর, যারা আপনার কাছে আসেনি। তারা বাক্যকে স্বস্থান থেকে পরিবর্তন করে। তারা বলেঃ যদি তোমরা এ নির্দেশ পাও, তবে কবুল করে নিও এবং যদি এ নির্দেশ না পাও, তবে বিরত থেকো। আল্লাহ যাকে পথভ্রষ্ট করতে চান, তার জন্যে আল্লাহর কাছে আপনি কিছু করতে পারবেন না। এরা এমনিই যে, আল্লাহ এদের অন্তরকে পবিত্র করতে চান না। তাদের জন্যে রয়েছে দুনিয়াতে লাঞ্ছনা এবং পরকালে বিরাট শাস্তি।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@dccxi{এরা মিথ্যা বলার জন্যে গুপ্তচরবৃত্তি করে, হারাম ভক্ষণ করে। অতএব, তারা যদি আপনার কাছে আসে, তবে হয় তাদের মধ্যে ফয়সালা করে দিন, না হয় তাদের ব্যাপারে নির্লিপ্ত থাকুন। যদি তাদের থেকে নির্লিপ্ত থাকেন, তবে তাদের সাধ্য নেই যে, আপনার বিন্দুমাত্র ক্ষতি করতে পারে। যদি ফয়সালা করেন, তবেন্যায় ভাবে ফয়সালা করুন। নিশ্চয় আল্লাহ সুবিচারকারীদেরকে ভালবাসেন।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@dccxii{তারা আপনাকে কেমন করে বিচারক নিয়োগ করবে অথচ তাদের কাছে তওরাত রয়েছে। তাতে আল্লাহর নির্দেশ আছে। অতঃপর এরা পেছন দিকে মুখ ফিরিয়ে নেয়। তারা কখনও বিশ্বাসী নয়।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@dccxiii{আমি তওরাত অবর্তীর্ন করেছি। এতে হেদায়াত ও আলো রয়েছে। আল্লাহর আজ্ঞাবহ পয়গম্বর, দরবেশ ও আলেমরা এর মাধ্যমে ইহুদীদেরকে ফয়সালা দিতেন। কেননা, তাদেরকে এ খোদায়ী গ্রন্থের দেখাশোনা করার নির্দেশ দেয়া হয়েছিল এবং তাঁরা এর রক্ষণাবেক্ষণে নিযুক্ত ছিলেন। অতএব, তোমরা মানুষকে ভয় করো না এবং আমাকে ভয় কর এবং আমার আয়াত সমূহের বিনিময়ে স্বল্পমূল্যে গ্রহণ করো না, যেসব লোক আল্লাহ যা অবতীর্ণ করেছেন, তদনুযায়ী ফায়সালা করে না, তারাই কাফের।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@dccxiv{আমি এ গ্রন্থে তাদের প্রতি লিখে দিয়েছি যে, প্রাণের বিনিময়ে প্রাণ, চক্ষুর বিনিময়ে চক্ষু, নাকের বিনিময়ে নাক, কানের বিনিময়ে কান, দাঁতের বিনিময়ে দাঁত এবং যখম সমূহের বিনিময়ে সমান যখম। অতঃপর যে ক্ষমা করে, সে গোনাহ থেকে পাক হয়ে যায়। যেসব লোক আল্লাহ যা অবতীর্ণ করেছেন, তদনুযায়ী ফয়সালা করে না তারাই জালেম।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@dccxv{আমি তাদের পেছনে মরিয়ম তনয় ঈসাকে প্রেরণ করেছি। তিনি পূর্ববর্তী গ্রন্থ তওরাতের সত্যায়নকারী ছিলেন। আমি তাঁকে ইঞ্জিল প্রদান করেছি। এতে হেদায়াত ও আলো রয়েছে। এটি পূর্ববতী গ্রন্থ তওরাতের সত্যায়ন করে পথ প্রদর্শন করে এবং এটি খোদাভীরুদের জন্যে হেদায়েত উপদেশ বানী।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@dccxvi{ইঞ্জিলের অধিকারীদের উচিত, আল্লাহ তাতে যা অবতীর্ণ করেছেন। তদানুযায়ী ফয়সালা করা। যারা আল্লাহ যা অবতীর্ণ করেছেন, তদনুযায়ী ফয়সালা করে না, তারাই পাপাচারী।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@dccxvii{আমি আপনার প্রতি অবতীর্ণ করেছি সত্যগ্রন্থ, যা পূর্ববতী গ্রন্থ সমূহের সত্যায়নকারী এবং সেগুলোর বিষয়বস্তুর রক্ষণাবেক্ষণকারী। অতএব, আপনি তাদের পারস্পারিক ব্যাপারাদিতে আল্লাহ যা অবতীর্ণ করেছেন, তদনুযায়ী ফয়সালা করুন এবং আপনার কাছে যে সৎপথ এসেছে, তা ছেড়ে তাদের প্রবৃত্তির অনুসরণ করবেন না। আমি তোমাদের প্রত্যেককে একটি আইন ও পথ দিয়েছি। যদি আল্লাহ চাইতেন, তবে তোমাদের সবাইকে এক উম্মত করে দিতেন, কিন্তু এরূপ করেননি-যাতে তোমাদেরকে যে ধর্ম দিয়েছেন, তাতে তোমাদের পরীক্ষা নেন। অতএব, দৌড়ে কল্যাণকর বিষয়াদি অর্জন কর। তোমাদের সবাইকে আল্লাহর কাছে প্রত্যাবর্তন করতে হবে। অতঃপর তিনি অবহিত করবেন সে বিষয়, যাতে তোমরা মতবিরোধ করতে।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@dccxviii{আর আমি আদেশ করছি যে, আপনি তাদের পারস্পরিক ব্যাপারাদিতে আল্লাহ যা নাযিল করেছেন তদনুযায়ী ফয়সালা করুন; তাদের প্রবৃত্তির অনুসরণ করবেন না এবং তাদের থেকে সতর্ক থাকুন-যেন তারা আপনাকে এমন কোন নির্দেশ থেকে বিচ্যুত না করে, যা আল্লাহ আপনার প্রতি নাযিল করেছেন। অনন্তর যদি তার মুখ ফিরিয়ে নেয়, তবে জেনে নিন, আল্লাহ তাদেরকে তাদের গোনাহের কিছু শাস্তি দিতেই চেয়েছেন। মানুষের মধ্যে অনেকেই নাফরমান।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@dccxix{তারা কি জাহেলিয়াত আমলের ফয়সালা কামনা করে? আল্লাহ অপেক্ষা বিশ্বাসীদের জন্যে উত্তম ফয়সালাকারী কে?\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@dccxx{হে মুমিণগণ! তোমরা ইহুদী ও খ্রীষ্টানদেরকে বন্ধু হিসাবে গ্রহণ করো না। তারা একে অপরের বন্ধু। তোমাদের মধ্যে যে তাদের সাথে বন্ধুত্ব করবে, সে তাদেরই অন্তর্ভুক্ত। আল্লাহ জালেমদেরকে পথ প্রদর্শন করেন না।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@dccxxi{বস্তুতঃ যাদের অন্তরে রোগ রয়েছে, তাদেরকে আপনি দেখবেন, দৌড়ে গিয়ে তাদেরই মধ্যে প্রবেশ করে। তারা বলেঃ আমরা আশঙ্কা করি, পাছে না আমরা কোন দুর্ঘটনায় পতিত হই। অতএব, সেদিন দুরে নয়, যেদিন আল্লাহ তা’আলা বিজয় প্রকাশ করবেন অথবা নিজের পক্ষ থেকে কোন নির্দেশ দেবেন-ফলে তারা স্বীয় গোপন মনোভাবের জন্যে অনুতপ্ত হবে।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@dccxxii{মুসলমানরা বলবেঃ এরাই কি সেসব লোক, যারা আল্লাহর নামে প্রতিজ্ঞা করত যে, আমরা তোমাদের সাথে আছি? তাদের কৃতকর্মসমূহ বিফল হয়ে গেছে, ফলে তারা ক্ষতিগ্রস্ত হয়ে আছে।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@dccxxiii{হে মুমিনগণ, তোমাদের মধ্যে যে স্বীয় ধর্ম থেকে ফিরে যাবে, অচিরে আল্লাহ এমন সম্প্রদায় সৃষ্টি করবেন, যাদেরকে তিনি ভালবাসবেন এবং তারা তাঁকে ভালবাসবে। তারা মুসলমানদের প্রতি বিনয়-নম্র হবে এবং কাফেরদের প্রতি কঠোর হবে। তারা আল্লাহর পথে জেহাদ করবে এবং কোন তিরস্কারকারীর তিরস্কারে ভীত হবে না। এটি আল্লাহর অনুগ্রহ-তিনি যাকে ইচ্ছা দান করেন। আল্লাহ প্রাচুর্য দানকারী, মহাজ্ঞানী।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@dccxxiv{তোমাদের বন্ধু তো আল্লাহ তাঁর রসূল এবং মুমিনবৃন্দ-যারা নামায কায়েম করে, যাকাত দেয় এবং বিনম্র।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@dccxxv{আর যারা আল্লাহ তাঁর রসূল এবং বিশ্বাসীদেরকে বন্ধুরূপে গ্রহণ করে, তারাই আল্লাহর দল এবং তারাই বিজয়ী।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@dccxxvi{হে মুমিনগণ, আহলে কিতাবদের মধ্য থেকে যারা তোমাদের ধর্মকে উপহাস ও খেলা মনে করে, তাদেরকে এবং অন্যান্য কাফেরকে বন্ধু রূপে গ্রহণ করো না। আল্লাহকে ভয় কর, যদি তোমরা ঈমানদার হও।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@dccxxvii{আর যখন তোমরা নামাযের জন্যে আহবান কর, তখন তারা একে উপহাস ও খেলা বলে মনে করে। কারণ, তারা নিবোর্ধ।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@dccxxviii{বলুনঃ হে আহলে কিতাবগণ, আমাদের সাথে তোমাদের এছাড়া কি শত্রুতা যে, আমরা বিশ্বাস স্থাপন করেছি আল্লাহর প্রতি, আমাদের উপর অবতীর্ণ গ্রন্থের প্রতি এবং পূর্বে অবতীর্ণ গ্রন্থের প্রতি। আর তোমাদের অধিকাংশই নাফরমান।\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@dccxxix{বলুনঃ আমি তোমাদেরকে বলি, তাদের মধ্যে কার মন্দ প্রতিফল রয়েছে আল্লাহর কাছে? যাদের প্রতি আল্লাহ অভিসম্পাত করেছেন, যাদের প্রতি তিনি ক্রোধাম্বিত হয়েছেন, যাদের কতককে বানর ও শুকরে রূপান্তরিত করে দিয়েছেন এবং যারা শয়তানের আরাধনা করেছে, তারাই মর্যাদার দিক দিয়ে নিকৃষ্টতর এবং সত্যপথ থেকেও অনেক দূরে।\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@dccxxx{যখন তারা তোমাদের কাছে আসে তখন বলে দাওঃ আমরা বিশ্বাস স্থাপন করেছি। অথচ তারা কুফর নিয়ে এসেছিল এবং কুফর নিয়েই প্রস্থান করেছে। তারা যা গোপন করত, আল্লাহ তা খুব জানেন।\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@dccxxxi{আর আপনি তাদের অনেককে দেখবেন যে, দৌড়ে দৌড়ে পাপে, সীমালঙ্ঘনে এবং হারাম ভক্ষনে পতিত হয়। তারা অত্যন্ত মন্দ কাজ করছে।\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@dccxxxii{দরবেশ ও আলেমরা কেন তাদেরকে পাপ কথা বলতে এবং হারাম ভক্ষণ করতে নিষেধ করে না? তারা খুবই মন্দ কাজ করছে।\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@dccxxxiii{আর ইহুদীরা বলেঃ আল্লাহর হাত বন্ধ হয়ে গেছে। তাদেরই হাত বন্ধ হোক। একথা বলার জন্যে তাদের প্রতি অভিসম্পাত। বরং তাঁর উভয় হস্ত উম্মুক্ত। তিনি যেরূপ ইচ্ছা ব্যয় করেন। আপনার প্রতি পলনকর্তার পক্ষ থেকে যে কালাম অবর্তীণ হয়েছে, তার কারণে তাদের অনেকের অবাধ্যতা ও কুফর পরিবর্ধিত হবে। আমি তাদের পরস্পরের মধ্যে কেয়ামত পর্যন্ত শত্রুতা ও বিদ্বেষ সঞ্চারিত করে দিয়েছি। তারা যখনই যুদ্ধের আগুন প্রজ্জ?482;িত করে, আল্লাহ তা নির্বাপিত করে দেন। তারা দেশে অশান্তি উৎপাদন করে বেড়ায়। আল্লাহ অশান্তি ও বিশৃঙ্খলা সৃষ্টিকারীদেরকে পছন্দ করেন না।\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@dccxxxiv{আর যদি আহলে-কিতাবরা বিশ্বাস স্থাপন করত এবং খোদাভীতি অবলম্বন করত, তবে আমি তাদের মন্দ বিষয়সমূহ ক্ষমা করে দিতাম এবং তাদেরকে নেয়ামতের উদ্যানসমূহে প্রবিষ্ট করতাম।\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@dccxxxv{যদি তারা তওরাত, ইঞ্জিল এবং যা প্রতিপালকের পক্ষ থেকে তাদের প্রতি অবতীর্ণ হয়েছে, পুরোপুরি পালন করত, তবে তারা উপর থেকে এবং পায়ের নীচ থেকে ভক্ষণ করত। তাদের কিছুসংখ্যক লোক সৎপথের অনুগামী এবং অনেকেই মন্দ কাজ করে যাচ্ছে।\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@dccxxxvi{হে রসূল, পৌছে দিন আপনার প্রতিপালকের পক্ষ থেকে আপনার প্রতি যা অবতীর্ণ হয়েছে। আর যদি আপনি এরূপ না করেন, তবে আপনি তাঁর পয়গাম কিছুই পৌছালেন না। আল্লাহ আপনাকে মানুষের কাছ থেকে রক্ষা করবেন। নিশ্চয় আল্লাহ কাফেরদেরকে পথ প্রদর্শন করেন না।\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@dccxxxvii{বলে দিনঃ হে আহলে কিতাবগণ, তোমরা কোন পথেই নও, যে পর্যন্ত না তোমরা তওরাত, ইঞ্জিল এবং যে গ্রন্থ তোমাদের পালনকর্তার পক্ষ থেকে তোমাদের প্রতি অবতীর্ণ হয়েছে তাও পুরোপুরি পালন না কর। আপনার পালনকর্তার কাছ থেকে আপনার প্রতি যা অবর্তীণ হয়েছে, তার কারণে তাদের অনেকের অবাধ্যতা ও কুফর বৃদ্ধি পাবে। অতএব, এ কাফের সম্প্রদায়ের জন্যে দুঃখ করবেন না।\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@dccxxxviii{নিশ্চয় যারা মুসলমান, যারা ইহুদী, ছাবেয়ী বা খ্রীষ্টান, তাদের মধ্যে যারা বিশ্বাস স্থাপন করে আল্লাহর প্রতি, কিয়ামতের প্রতি এবং সৎকর্ম সম্পাদন করে, তাদের কোন ভয় নেই এবং তারা দুঃখিত হবে না।\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@dccxxxix{আমি বনী-ইসরাঈলের কাছ থেকে অঙ্গীকার নিয়েছিলাম এবং তাদের কাছে অনেক পয়গম্বর প্রেরণ করে ছিলাম। যখনই তাদের কাছে কোন পয়গম্বর এমন নির্দেশ নিয়ে আসত যা তাদের মনে চাইত না, তখন তাদের অনেকের প্রতি তারা মিথ্যারোপ করত এবংঅনেককে হত্যা করে ফেলত।\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@dccxl{তারা ধারণা করেছে যে, কোন অনিষ্ট হবে না। ফলে তারা আরও অন্ধ ও বধির হয়ে গেল। অতঃপর আল্লাহ তাদের তওবা কবুল করলেন। এরপরও তাদের অধিকাংশই অন্ধ ও বধির হয়ে রইল। আল্লাহ দেখেন তারা যা কিছু করে।\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@dccxli{তারা কাফের, যারা বলে যে, মরিময়-তনয় মসীহ-ই আল্লাহ; অথচ মসীহ বলেন, হে বণী-ইসরাঈল, তোমরা আল্লাহর এবাদত কর, যিনি আমার পালন কর্তা এবং তোমাদেরও পালনকর্তা। নিশ্চয় যে ব্যক্তি আল্লাহর সাথে অংশীদার স্থির করে, আল্লাহ তার জন্যে জান্নাত হারাম করে দেন। এবং তার বাসস্থান হয় জাহান্নাম। অত্যাচারীদের কোন সাহায্যকারী নেই।\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@dccxlii{নিশ্চয় তারা কাফের, যারা বলেঃ আল্লাহ তিনের এক; অথচ এক উপাস্য ছাড়া কোন উপাস্য নেই। যদি তারা স্বীয় উক্তি থেকে নিবৃত্ত না হয়, তবে তাদের মধ্যে যারা কুফরে অটল থাকবে, তাদের উপর যন্ত্রনাদায়ক শাস্তি পতিত হবে।\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@dccxliii{তারা আল্লাহর কাছে তওবা করে না কেন এবং ক্ষমা প্রার্থনা করে না কেন? আল্লাহ যে ক্ষমাশীল, দয়ালু।\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@dccxliv{মরিয়ম-তনয় মসীহ রসূল ছাড়া আর কিছু নন। তাঁর পূর্বে অনেক রসূল অতিক্রান্ত হয়েছেন আর তার জননী একজন ওলী। তাঁরা উভয়েই খাদ্য ভক্ষণ করতেন। দেখুন, আমি তাদের জন্যে কিরূপ যুক্তি-প্রমাণ বর্ননা করি, আবার দেখুন, তারা উল্টা কোন দিকে যাচেছ।\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@dccxlv{বলে দিনঃ তোমরা কি আল্লাহ ব্যতীত এমন বস্তুর এবাদত কর যে, তোমাদের অপকার বা উপকার করার ক্ষমতা রাখে না? অথচ আল্লাহ সব শুনেন ও জানেন।\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@dccxlvi{বলুনঃ হে আহলে কিতাবগন, তোমরা স্বীয় ধর্মে অন্যায় বাড়াবাড়ি করো না এবং এতে ঐ সম্প্রদায়ের প্রবৃত্তির অনুসরণ করো না, যারা পূর্বে পথভ্রষ্ট হয়েছে এবং অনেককে পথভ্রষ্ট করেছে। তারা সরল পথ থেকে বিচ্যুত হয়ে পড়েছে।\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@dccxlvii{বনী-ইসলাঈলের মধ্যে যারা কাফের, তাদেরকে দাউদ ও মরিয়মতনয় ঈসার মুখে অভিসম্পাত করা হয়েছে। এটা একারণে যে, তারা অবাধ্যতা করত এবং সীমা লংঘন করত।\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@dccxlviii{তারা পরস্পরকে মন্দ কাজে নিষেধ করত না, যা তারা করত। তারা যা করত তা অবশ্যই মন্দ ছিল\qt@no{(79)}}
\qt@newcmd\qurantrans@bn@dccxlix{আপনি তাদের অনেককে দেখবেন, কাফেরদের সাথে বন্ধুত্ব করে। তারা নিজেদের জন্য যা পাঠিয়েছে তা অবশ্যই মন্দ। তা এই যে, তাদের প্রতি আল্লাহ ক্রোধান্বিত হয়েছেন এবং তারা চিরকাল আযাবে থাকবে।\qt@no{(80)}}
\qt@newcmd\qurantrans@bn@dccl{যদি তারা আল্লাহর প্রতি ও রসূলের প্রতি অবতীর্ণ বিষয়ের প্রতি বিশ্বাস স্থাপন করত, তবে কাফেরদেরকে বন্ধুরূপে গ্রহণ করত না। কিন্তু তাদের মধ্যে অনেকেই দুরাচার।\qt@no{(81)}}
\qt@newcmd\qurantrans@bn@dccli{আপনি সব মানুষের চাইতে মুসলমানদের অধিক শত্রু ইহুদী ও মুশরেকদেরকে পাবেন এবং আপনি সবার চাইতে মুসলমানদের সাথে বন্ধুত্বে অধিক নিকটবর্তী তাদেরকে পাবেন, যারা নিজেদেরকে খ্রীষ্টান বলে। এর কারণ এই যে, খ্রীষ্টানদের মধ্যে আলেম রয়েছে, দরবেশ রয়েছে এবং তারা অহঙ্কার করে না।\qt@no{(82)}}
\qt@newcmd\qurantrans@bn@dcclii{আর তারা রসূলের প্রতি যা অবতীর্ণ হয়েছে, তা যখন শুনে, তখন আপনি তাদের চোখ অশ্রু সজল দেখতে পাবেন; এ কারণে যে, তারা সত্যকে চিনে নিয়েছে। তারা বলেঃ হে আমাদের প্রতি পালক, আমরা মুসলমান হয়ে গেলাম। অতএব, আমাদেরকেও মান্যকারীদের তালিকাভুক্ত করে নিন।\qt@no{(83)}}
\qt@newcmd\qurantrans@bn@dccliii{আমাদের কি ওযর থাকতে পারে যে, আমরা আল্লাহর প্রতি এবং যে সত্য আমাদের কাছে এসেছে, তৎপ্রতি বিশ্বাস স্থাপন করব না এবং এ আশা করবো না যে, আমদের প্রতিপালক আমাদেরকে সৎ লোকদের সাথে প্রবিষ্ট করবেন?\qt@no{(84)}}
\qt@newcmd\qurantrans@bn@dccliv{অতঃপর তাদেরকে আল্লাহ এ উক্তির প্রতিদান স্বরূপ এমন উদ্যান দিবেন যার তলদেশে নির্ঝরিণীসমূহ প্রবাহিত হবে। তারা তন্মধ্যে চিরকাল অবস্থান করবে। এটাই সৎকর্মশীলদের প্রতিদান।\qt@no{(85)}}
\qt@newcmd\qurantrans@bn@dcclv{যারা কাফের হয়েছে এবং আমার নিদর্শনাবলীকে মিথ্যা বলেছে, তারাই দোযখী।\qt@no{(86)}}
\qt@newcmd\qurantrans@bn@dcclvi{হে মুমিনগণ, তোমরা ঐসব সুস্বাদু বস্তু হারাম করো না, যেগুলো আল্লাহ তোমাদের জন্য হালাল করেছেন এবং সীমা অতিক্রম করো না। নিশ্চয় আল্লাহ সীমা অতিক্রমকারীদেরকে পছন্দ করেন না।\qt@no{(87)}}
\qt@newcmd\qurantrans@bn@dcclvii{আল্লাহ তা’য়ালা যেসব বস্তু তোমাদেরকে দিয়েছেন, তন্মধ্য থেকে হালাল ও পবিত্র বস্তু খাও এবং আল্লাহকে ভয় কর, যার প্রতি তোমরা বিশ্বাসী।\qt@no{(88)}}
\qt@newcmd\qurantrans@bn@dcclviii{আল্লাহ তোমাদেরকে পাকড়াও করেন না তোমাদের অনর্থক শপথের জন্যে; কিন্তু পাকড়াও করেন ঐ শপথের জন্যে যা তোমরা মজবুত করে বাধ। অতএব, এর কাফফরা এই যে, দশজন দরিদ্রকে খাদ্য প্রদান করবে; মধ্যম শ্রেনীর খাদ্য যা তোমরা স্বীয় পরিবারকে দিয়ে থাক। অথবা, তাদেরকে বস্তু প্রদান করবে অথবা, একজন ক্রীতদাস কিংবা দাসী মুক্ত করে দিবে। যে ব্যক্তি সামর্থ্য রাখে না, সে তিন দিন রোযা রাখবে। এটা কাফফরা তোমাদের শপথের, যখন শপথ করবে। তোমরা স্বীয় শপথসমূহ রক্ষা কর এমনিভাবে আল্লাহ তোমাদের জন্য স্বীয় নির্দেশ বর্ণনা করেন, যাতে তোমরা কৃতজ্ঞতা স্বীকার কর।\qt@no{(89)}}
\qt@newcmd\qurantrans@bn@dcclix{হে মুমিনগণ, এই যে মদ, জুয়া, প্রতিমা এবং ভাগ্য-নির্ধারক শরসমূহ এসব শয়তানের অপবিত্র কার্য বৈ তো নয়। অতএব, এগুলো থেকে বেঁচে থাক-যাতে তোমরা কল্যাণপ্রাপ্ত হও।\qt@no{(90)}}
\qt@newcmd\qurantrans@bn@dcclx{শয়তান তো চায়, মদ ও জুয়ার মাধ্যমে তোমাদের পরস্পরের মাঝে শুত্রুতা ও বিদ্বেষ সঞ্চারিত করে দিতে এবং আল্লাহর স্মরণ ও নামায থেকে তোমাদেরকে বিরত রাখতে। অতএব, তোমরা এখন ও কি নিবৃত্ত হবে?\qt@no{(91)}}
\qt@newcmd\qurantrans@bn@dcclxi{তোমরা আল্লাহর অনুগত হও, রসূলের অনুগত হও এবং আত্মরক্ষা কর। কিন্তু যদি তোমরা বিমুখ হও, তবে জেনে রাখ, আমার রসূলের দায়িত্ব প্রকাশ্য প্রচার বৈধ নয়।\qt@no{(92)}}
\qt@newcmd\qurantrans@bn@dcclxii{যারা বিশ্বাস স্থাপন করেছে এবং সৎকর্ম করেছে, তারা পূর্বে যা ভক্ষণ করেছে, সে জন্য তাদের কোন গোনাহ নেই যখন ভবিষ্যতের জন্যে সংযত হয়েছে, বিশ্বাস স্থাপন করেছে এবং সৎকর্ম সম্পাদন করেছে। এরপর সংযত থাকে এবং বিশ্বাস স্থাপন করে। এরপর সংযত থাকে এবং সৎকর্ম করে। আল্লাহ সৎকর্মীদেরকে ভালবাসেন।\qt@no{(93)}}
\qt@newcmd\qurantrans@bn@dcclxiii{হে মুমিনগণ, আল্লাহ তোমাদেরকে এমন কিছু শিকারের মাধ্যমে পরীক্ষা করবেন, যে শিকার পর্যন্ত তোমাদের হাত ও বর্শা সহজেই পৌছতে পারবে-যাতে আল্লাহ বুঝতে পারেন যে, কে তাকে অদৃশ্যভাবে ভয়করে। অতএব, যে ব্যক্তি এরপর সীমা অতিক্রম করবে, তার জন্য যন্ত্রনাদায়ক শাস্তি রয়েছে।\qt@no{(94)}}
\qt@newcmd\qurantrans@bn@dcclxiv{মুমিনগণ, তোমরা এহরাম অবস্থায় শিকার বধ করো না। তোমাদের মধ্যে যে জেনেশুনে শিকার বধ করবে, তার উপর বিনিময় ওয়াজেব হবে, যা সমান হবে ঐ জন্তুর, যাকে সে বধ করেছে। দু’জন নির্ভরযোগ্য ব্যক্তি এর ফয়সালা করবে-বিনিময়ের জন্তুটি উৎসর্গ হিসেবে কাবায় পৌছাতে হবে। অথবা তার উপর কাফফারা ওয়াজেব-কয়েকজন দরিদ্রকে খাওয়ানো অথবা তার সমপরিমাণ রোযা রাখতে যাতে সে স্বীয় কৃতকর্মের প্রতিফল আস্বাদন করে। যা হয়ে গেছে, তা আল্লাহ মাফ করেছেন। যে পুনরায় এ কান্ড করবে, আল্লাহ তার কাছ থেকে প্রতিশোধ নিবেন। আল্লাহ পরাক্রান্ত, প্রতিশোধ গ্রহণে সক্ষম।\qt@no{(95)}}
\qt@newcmd\qurantrans@bn@dcclxv{তোমাদের জন্য সমুদ্রের শিকার ও সুমুদ্রের খাদ্য হালাল করা হয়েছে তোমাদের উপকারার্থে এবং তোমাদের এহরামকারীদের জন্যে হারাম করা হয়েছে স্থল শিকার যতক্ষণ এহরাম অবস্থায় থাক। আল্লাহকে ভয় কর, যার কাছে তোমরা একত্রিত হবে।\qt@no{(96)}}
\qt@newcmd\qurantrans@bn@dcclxvi{আল্লাহ সম্মানিত গৃহ কাবাকে মানুষের স্থীতিশীলতার কারণ করেছেন এবং সম্মানিত মাসসমূকে, হারাম কোরবানীর জন্তুকে ও যাদের গলায় আবরণ রয়েছে। এর কারণ এই যে, যাতে তোমরা জেনে নাও যে, আল্লাহ নভোমন্ডল ও ভুমন্ডলের সব কিছু জানেন এবং আল্লাহ সর্ব বিষয়ে মহাজ্ঞানী।\qt@no{(97)}}
\qt@newcmd\qurantrans@bn@dcclxvii{জেনে নাও, নিশ্চয় আল্লাহ কঠোর শাস্তি দাতা ও নিশ্চয় আল্লাহ ক্ষমাশীল-দয়ালূ।\qt@no{(98)}}
\qt@newcmd\qurantrans@bn@dcclxviii{রসূলের দায়িত্ব শুধু পৌছিয়ে দেওয়া। আল্লাহ জানেন, যা কিছু তোমরা প্রকাশ্যে কর এবং যা কিছু গোপন কর।\qt@no{(99)}}
\qt@newcmd\qurantrans@bn@dcclxix{বলে দিনঃ অপবিত্র ও পবিত্র সমান নয়, যদিও অপবিত্রের প্রাচুর্য তোমাকে বিস্মিত করে। অতএব, হে বুদ্ধিমানগণ, আল্লাহকে ভয় কর-যাতে তোমরা মুক্তি পাও।\qt@no{(100)}}
\qt@newcmd\qurantrans@bn@dcclxx{হে মুমিণগন, এমন কথাবার্তা জিজ্ঞেস করো না, যা তোমাদের কাছে পরিব্যক্ত হলে তোমাদের খারাপ লাগবে। যদি কোরআন অবতরণকালে তোমরা এসব বিষয় জিজ্ঞেস কর, তবে তা তোমাদের জন্যে প্রকাশ করা হবে। অতীত বিষয় আল্লাহ ক্ষমা করেছেন আল্লাহ ক্ষমাশীল, সহনশীল।\qt@no{(101)}}
\qt@newcmd\qurantrans@bn@dcclxxi{এরূপ কথা বার্তা তোমাদের পুর্বে এক সম্প্রদায় জিজ্ঞেস করেছিল। এর পর তারা এসব বিষয়ে অবিশ্বাসী হয়ে গেল।\qt@no{(102)}}
\qt@newcmd\qurantrans@bn@dcclxxii{আল্লাহ ‘বহিরা’ ‘সায়েবা’ ওসীলা’ এবং ‘হামী’ কে শরীয়তসিদ্ধ করেননি। কিন্তু যারা কাফের, তারা আল্লাহর উপর মিথ্যা অপবাদ আরোপ করে। তাদের অধিকাংশেরই বিবেক বুদ্ধি নেই।\qt@no{(103)}}
\qt@newcmd\qurantrans@bn@dcclxxiii{যখন তাদেরকে বলা হয় যে, আল্লাহর নাযিলকৃত বিধান এবং রসূলের দিকে এস, তখন তারা বলে, আমাদের জন্যে তাই যথেষ্ট, যার উপর আমরা আমাদের বাপ-দাদাকে পেয়েছি। যদি তাদের বাপ দাদারা কোন জ্ঞান না রাখে এবং হেদায়েত প্রাপ্ত না হয় তবুও কি তারা তাই করবে?\qt@no{(104)}}
\qt@newcmd\qurantrans@bn@dcclxxiv{হে মুমিনগণ, তোমরা নিজেদের চিন্তা কর। তোমরা যখন সৎপথে রয়েছ, তখন কেউ পথভ্রান্ত হলে তাতে তোমাদের কোন ক্ষতি নাই। তোমাদের সবাইকে আল্লাহর কাছে ফিরে যেতে হবে। তখন তিনি তোমাদেরকে বলে দেবেন, যা কিছু তোমরা করতে।\qt@no{(105)}}
\qt@newcmd\qurantrans@bn@dcclxxv{হে, মুমিনগণ, তোমাদের মধ্যে যখন কারও মৃত্যু উপস্থিত হয়, তখন ওছিয়ত করার সময় তোমাদের মধ্য থেকে ধর্মপরায়ন দুজনকে সাক্ষী রেখো। তোমরা সফরে থাকলে এবং সে অবস্থায় তোমাদের মৃত্যু উপস্থিত হলে তোমরা তোমাদের ছাড়াও দু ব্যক্তিকে সাক্ষী রেখো। যদি তোমাদের সন্দেহ হয়, তবে উভয়কে নামাযের পর থাকতে বলবে। অতঃপর উভয়েই আল্লাহর নামে কসম খাবে যে, আমরা এ কসমের বিনিময়ে কোন উপকার গ্রহণ করতে চাই না, যদিও কোন আত্নীয়ও হয় এবং আল্লাহর সাক্ষ্য আমরা গোপন করব না। এমতাবস্থায় কঠোর গোনাহগার হব।\qt@no{(106)}}
\qt@newcmd\qurantrans@bn@dcclxxvi{অতঃপর যদি জানা যায় যে, উভয় ওসি কোন গোনাহে জড়িত রয়েছে, তবে যাদের বিরুদ্ধে গোনাহ হয়েছিল, তাদের মধ্য থেকে মৃতু ব্যক্তির নিকটতম দু’ব্যক্তি তাদের স্থলাভিষিক্ত হবে। অতঃপর আল্লাহর নামে কসম খাবে যে, অবশ্যই আমাদের সাক্ষ্য তাদের সাক্ষ্যর চাইতে অধিক সত্য এবং আমরা সীমা অতিক্রম করিনি। এমতাবস্থায় আমরা অবশ্যই অত্যাচারী হব।\qt@no{(107)}}
\qt@newcmd\qurantrans@bn@dcclxxvii{এটি এ বিষয়ের নিকটতম উপায় যে, তারা ঘটনাকে সঠিকভাবে প্রকাশ করবে অথবা আশঙ্কা করবে যে, তাদের কাছ থেকে কসম নেয়ার পর আবার কসম চাওয়া হবে। আল্লাহকে ভয় কর এবং শুন, আল্লাহ দুরাচারীদেরকে পথ-প্রদর্শন করবেন না।\qt@no{(108)}}
\qt@newcmd\qurantrans@bn@dcclxxviii{যেদিন আল্লাহ সব পয়গম্বরকে একত্রিত করবেন, অতঃপর বলবেন তোমরা কি উত্তর পেয়েছিলে? তাঁরা বলবেনঃ আমরা অবগত নই, আপনিই অদৃশ্য বিষয়ে মহাজ্ঞানী।\qt@no{(109)}}
\qt@newcmd\qurantrans@bn@dcclxxix{যখন আল্লাহ বলবেনঃ হে ঈসা ইবনে মরিয়ম, তোমার প্রতি ও তোমার মাতার প্রতি আমার অনুগ্রহ স্মরণ কর, যখন আমি তোমাকে পবিত্র আত্মার দ্বারা সাহায্য করেছি। তুমি মানুষের সাথে কথা বলতে কোলে থাকতেও এবং পরিণত বয়সেও এবং যখন আমি তোমাকে গ্রন্থ, প্রগাঢ় জ্ঞান, তওরাত ও ইঞ্জিল শিক্ষা দিয়েছি এবং যখন তুমি কাদামাটি দিয়ে পাখীর প্রতিকৃতির মত প্রতিকৃতি নির্মাণ করতে আমার আদেশে, অতঃপর তুমি তাতে ফুঁ দিতে; ফলে তা আমার আদেশে পাখী হয়ে যেত এবং তুমি আমার আদেশে জন্মান্ধ ও কুষ্টরোগীকে নিরাময় করে দিতে এবং যখন আমি বনী-ইসরাঈলকে তোমা থেকে নিবৃত্ত রেখেছিলাম, যখন তুমি তাদের কাছে প্রমাণাদি নিয়ে এসেছিলে, অতঃপর তাদের মধ্যে যারা কাফের ছিল, তারা বললঃ এটা প্রকাশ্য জাদু ছাড়া কিছুই নয়।\qt@no{(110)}}
\qt@newcmd\qurantrans@bn@dcclxxx{আর যখন আমি হাওয়ারীদের মনে জাগ্রত করলাম যে, আমার প্রতি এবং আমার রসূলের প্রতি বিশ্বাস স্থাপন কর, তখন তারা বলতে লাগল, আমরা বিশ্বাস স্থাপন করলাম এবং আপনি সাক্ষী থাকুন যে, আমরা অনুগত্যশীল।\qt@no{(111)}}
\qt@newcmd\qurantrans@bn@dcclxxxi{যখন হাওয়ারীরা বললঃ হে মরিয়ম তনয় ঈসা, আপনার পালনকর্তা কি এরূপ করতে পারেন যে, আমাদের জন্যে আকাশ থেকে খাদ্যভর্তি খাঞ্চা অবতরণ করে দেবেন? তিনি বললেনঃ যদি তোমরা ঈমানদার হও, তবে আল্লাহকে ভয় কর।\qt@no{(112)}}
\qt@newcmd\qurantrans@bn@dcclxxxii{তারা বললঃ আমরা তা থেকে খেতে চাই; আমাদের অন্তর পরিতৃপ্ত হবে; আমরা জেনে নেব যে, আপনি সত্য বলেছেন এবং আমরা সাক্ষ্যদাতা হয়ে যাব।\qt@no{(113)}}
\qt@newcmd\qurantrans@bn@dcclxxxiii{ঈসা ইবনে মরিয়ম বললেনঃ হে আল্লাহ আমাদের পালনকর্তা আমাদের প্রতি আকাশ থেকে খাদ্যভর্তি খাঞ্চা অবতরণ করুন। তা আমাদের জন্যে অর্থাৎ, আমাদের প্রথম ও পরবর্তী সবার জন্যে আনন্দোৎসব হবে এবং আপনার পক্ষ থেকে একটি নিদর্শন হবে। আপনি আমাদের রুযী দিন। আপনিই শ্রেষ্ট রুযীদাতা।\qt@no{(114)}}
\qt@newcmd\qurantrans@bn@dcclxxxiv{আল্লাহ বললেনঃ নিশ্চয় আমি সে খাঞ্চা তোমাদের প্রতি অবতরণ করব। অতঃপর যে ব্যাক্তি এর পরেও অকৃতজ্ঞ হবে, আমি তাকে এমন শাস্তি দেব, যে শাস্তি বিশ্বজগতের অপর কাউকে দেব না।\qt@no{(115)}}
\qt@newcmd\qurantrans@bn@dcclxxxv{যখন আল্লাহ বললেনঃ হে ঈসা ইবনে মরিয়ম! তুমি কি লোকদেরকে বলে দিয়েছিলে যে, আল্লাহকে ছেড়ে আমাকে ও আমার মাতাকে উপাস্য সাব্যস্ত কর? ঈসা বলবেন; আপনি পবিত্র! আমার জন্যে শোভা পায় না যে, আমি এমন কথা বলি, যা বলার কোন অধিকার আমার নেই। যদি আমি বলে থাকি, তবে আপনি অবশ্যই পরিজ্ঞাত; আপনি তো আমার মনের কথা ও জানেন এবং আমি জানি না যা আপনার মনে আছে। নিশ্চয় আপনিই অদৃশ্য বিষয়ে জ্ঞাত।\qt@no{(116)}}
\qt@newcmd\qurantrans@bn@dcclxxxvi{আমি তো তাদেরকে কিছুই বলিনি, শুধু সে কথাই বলেছি যা আপনি বলতে আদেশ করেছিলেন যে, তোমরা আল্লাহর দাসত্ব অবলম্বন কর যিনি আমার ও তোমাদের পালনকর্তা আমি তাদের সম্পর্কে অবগত ছিলাম যতদিন তাদের মধ্যে ছিলাম। অতঃপর যখন আপনি আমাকে লোকান্তরিত করলেন, তখন থেকে আপনিই তাদের সম্পর্কে অবগত রয়েছেন। আপনি সর্ববিষয়ে পূর্ণ পরিজ্ঞাত।\qt@no{(117)}}
\qt@newcmd\qurantrans@bn@dcclxxxvii{যদি আপনি তাদেরকে শাস্তি দেন, তবে তারা আপনার দাস এবং যদি আপনি তাদেরকে ক্ষমা করেন, তবে আপনিই পরাক্রান্ত, মহাবিজ্ঞ।\qt@no{(118)}}
\qt@newcmd\qurantrans@bn@dcclxxxviii{আল্লাহ বললেনঃ আজকের দিনে সত্যবাদীদের সত্যবাদিতা তাদের উপকারে আসবে। তাদের জন্যে উদ্যান রয়েছে, যার তলদেশে নির্ঝরিনী প্রবাহিত হবে; তারা তাতেই চিরকাল থাকবে। আল্লাহ তাদের প্রতি সন্তুষ্ট। এটিই মহান সফলতা।\qt@no{(119)}}
\qt@newcmd\qurantrans@bn@dcclxxxix{নভোমন্ডল, ভূমন্ডল এবং এতদুভয়ে অবস্থিত সবকিছুর আধিপত্য আল্লাহরই। তিনি সবকিছুর উপর ক্ষমতাবান।\qt@no{(120)}}
\qt@newcmd\qurantrans@bn@dccxc{\basmalahbn সর্ববিধ প্রশংসা আল্লাহরই জন্য যিনি নভোমন্ডল ও ভূমন্ডল সৃষ্টি করেছেন এবং অন্ধকার ও আলোর উদ্ভব করেছেন। তথাপি কাফেররা স্বীয় পালনকর্তার সাথে অন্যান্যকে সমতুল্য স্থির করে।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@dccxci{তিনিই তোমাদেরকে মাটির দ্বারা সৃষ্টি করেছেন, অতঃপর নির্দিষ্টকাল নির্ধারণ করেছেন। আর অপর নির্দিষ্টকাল আল্লাহর কাছে আছে। তথাপি তোমরা সন্দেহ কর।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@dccxcii{তিনিই আল্লাহ নভোমন্ডলে এবং ভূমন্ডলে। তিনি তোমাদের গোপন ও প্রকাশ্য বিষয় জানেন এবং তোমরা যা কর তাও অবগত।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@dccxciii{তাদের কাছে তাদের প্রতিপালকের নিদর্শনাবলী থেকে কোন নিদর্শন আসেনি; যার প্রতি তারা বিমুখ হয় না।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@dccxciv{অতএব, অবশ্য তারা সত্যকে মিথ্যা বলেছে যখন তা তাদের কাছে এসেছে। বস্তুতঃ অচিরেই তাদের কাছে ঐ বিষয়ের সংবাদ আসবে, যার সাথে তারা উপহাস করত।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@dccxcv{তারা কি দেখেনি যে, আমি তাদের পুর্বে কত সম্প্রদায়কে ধ্বংস করে দিয়েছি, যাদেরকে আমি পৃথিবীতে এমন প্রতিষ্ঠা দিয়েছিলাম, যা তোমাদেরকে দেইনি। আমি আকাশকে তাদের উপর অনবরত বৃষ্টি বর্ষণ করতে দিয়েছি এবং তাদের তলদেশে নদী সৃষ্টি করে দিয়েছি, অতঃপর আমি তাদেরকে তাদের পাপের কারণে ধ্বংস করে দিয়েছি এবং তাদের পরে অন্য সম্প্রদায় সৃষ্টি করেছি।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@dccxcvi{যদি আমি কাগজে লিখিত কোন বিষয় তাদের প্রতি নাযিল করতাম, অতঃপর তারা তা সহস্তে স্পর্শ করত, তবুও অবিশ্বাসীরা একথাই বলত যে, এটা প্রকাশ্য জাদু বৈ কিছু নয়।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@dccxcvii{তারা আরও বলে যে, তাঁর কাছে কোন ফেরেশতা কেন প্রেরণ করা হল না ? যদি আমি কোন ফেরেশতা প্রেরণ করতাম, তবে গোটা ব্যাপারটাই শেষ হয়ে যেত। অতঃপর তাদেরকে সামান্যও অবকাশ দেওয়া হতনা।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@dccxcviii{যদি আমি কোন ফেরেশতাকে রসূল করে পাঠাতাম, তবে সে মানুষের আকারেই হত। এতেও ঐ সন্দেহই করত, যা এখন করছে।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@dccxcix{নিশ্চয়ই আপনার পূর্ববর্তী পয়গম্বরগণের সাথেও উপহাস করা হয়েছে। অতঃপর যারা তাঁদের সাথে উপহাস করেছিল, তাদেরকে ঐ শাস্তি বেষ্টন করে নিল, যা নিয়ে তারা উপহাস করত।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@dccc{বলে দিনঃ তোমরা পৃথিবীতে পরিভ্রমণ কর, অতপর দেখ, মিথ্যারোপ কারীদের পরিণাম কি হয়েছে?\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@dccci{জিজ্ঞেস করুন, নভোমন্ডল ও ভুমন্ডলে যা আছে, তার মালিক কে? বলে দিনঃআল্লাহ। তিনি অনুকম্পা প্রদর্শনকে নিজ দায়িত্বে লিপিবদ্ধ করে নিয়েছেন। তিনি অবশ্যই তোমাদেরকে কেয়ামতের দিন একত্রিত করবেন। এর আগমনে কোন সন্দেহ নেই। যারা নিজেদের কে ক্ষতিগ্রস্ত করেছে, তারাই বিশ্বাস স্থাপন করে না।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@dcccii{যা কিছু রাত ও দিনে স্থিতি লাভ করে, তাঁরই। তিনিই শ্রোতা, মহাজ্ঞানী।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@dccciii{আপনি বলে দিনঃ আমি কি আল্লাহ ব্যতীত-যিনি নভোমন্ডল ও ভুমন্ডলের স্রষ্টা এবং যিনি সবাইকে আহার্য দানকরেন ও তাঁকে কেউ আহার্য দান করে না অপরকে সাহায্যকারী স্থির করব? আপনি বলে দিনঃ আমি আদিষ্ট হয়েছি যে, সর্বাগ্রে আমিই আজ্ঞাবহ হব। আপনি কদাচ অংশীবাদীদের অন্তর্ভুক্ত হবেন না।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@dccciv{আপনি বলুন, আমি আমার প্রতিপালকের অবাধ্য হতে ভয় পাই কেননা, আমি একটি মহাদিবসের শাস্তিকে ভয় করি।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@dcccv{যার কাছ থেকে ঐদিন এ শাস্তি সরিয়ে নেওয়া হবে, তার প্রতি আল্লাহর অনুকম্পা হবে। এটাই বিরাট সাফল্য।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@dcccvi{আর যদি আল্লাহ তোমাকে কোন কষ্ট দেন, তবে তিনি ব্যতীত তা অপসারণকারী কেউ নেই। পক্ষান্তরে যদি তোমার মঙ্গল করেন, তবে তিনি সবকিছুর উপর ক্ষমতাবান।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@dcccvii{তিনিই পরাক্রান্ত স্বীয় বান্দাদের উপর। তিনিই জ্ঞানময়, সর্বজ্ঞ।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@dcccviii{আপনি জিজ্ঞেস করুনঃ সর্ববৃহৎ সাক্ষ্যদাতা কে ? বলে দিনঃ আল্লাহ আমার ও তোমাদের মধ্যে সাক্ষী। আমার প্রতি এ কোরআন অবর্তীর্ণ হয়েছে-যাতে আমি তোমাদেরকে এবং যাদের কাছে এ কোরআন পৌঁছে সবাইকে ভীতি প্রদর্শন করি। তোমরা কি সাক্ষ্য দাও যে, আল্লাহর সাথে অন্যান্য উপাস্যও রয়েছে ? আপনি বলে দিনঃ আমি এরূপ সাক্ষ্য দেব না। বলে দিনঃ তিনিই একমাত্র উপাস্য; আমি অবশ্যই তোমাদের শিরক থেকে মুক্ত।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@dcccix{যাদেরকে আমি কিতাব দান করেছি, তারা তাকে চিনে, যেমন তাদের সন্তানদেরকে চিনে। যারা নিজেদেরকে ক্ষতির মধ্যে ফেলেছে, তারা বিশ্বাস স্থাপন করবে না।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@dcccx{আর যে, আল্লাহর প্রতি অপবাদ আরোপ করে অথবা তাঁর নিদর্শনাবলীকে মিথ্যা বলে, তার চাইতে বড় জালেম কে? নিশ্চয় জালেমরা সফলকাম হবে না।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@dcccxi{আর যেদিন আমি তাদের সবাইকে একত্রিত করব, অতঃপর যারা শিরক করেছিল, তাদের বলবঃ যাদেরকে তোমরা অংশীদার বলে ধারণা করতে, তারা কোথায়?\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@dcccxii{অতঃপর তাদের কোন অপরিচ্ছন্নতা থাকবে না; তবে এটুকুই যে তারা বলবে আমাদের প্রতিপালক আল্লাহর কসম, আমরা মুশরিক ছিলাম না।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@dcccxiii{দেখতো, কিভাবে মিথ্যা বলছে নিজেদের বিপক্ষে ? এবং যেসব বিষয় তারা আপনার প্রতি মিছামিছি রচনা করত, তা সবই উধাও হয়ে গেছে।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@dcccxiv{তাদের কেউ কেউ আপনার দিকে কান লাগিয়ে থাকে। আমি তাদের অন্তরের উপর আবরণ রেখে দিয়েছি যাতে একে না বুঝে এবং তাদের কানে বোঝা ভরে দিয়েছি। যদি তারা সব নিদর্শন অবলোকন করে তবুও সেগুলো বিশ্বাস করবে না। এমনকি, তারা যখন আপনার কাছে ঝগড়া করতে আসে, তখন কাফেররা বলেঃ এটি পুর্ববর্তীদের কিচ্ছাকাহিনী বৈ তো নয়।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@dcccxv{তারা এ থেকে বাধা প্রদান করে এবং এ থেকে পলায়ন করে। তারা নিজেদেরকে ধ্বংস করেছে, কিন্তু বুঝছে না।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@dcccxvi{আর আপনি যদি দেখেন, যখন তাদেরকে দোযখের উপর দাঁড় করানো হবে! তারা বলবেঃ কতই না ভাল হত, যদি আমরা পুনঃ প্রেরিত হতাম; তা হলে আমরা স্বীয় পালনকর্তার নিদর্শনসমূহে মিথ্যারোপ করতাম না এবং আমরা বিশ্বাসীদের অন্তর্ভুক্ত হয়ে যেতাম।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@dcccxvii{এবং তারা ইতি পূর্বে যা গোপন করত, তা তাদের সামনে প্রকাশ হয়ে পড়েছে। যদি তারা পুনঃ প্রেরিত হয়, তবুও তাই করবে, যা তাদেরকে নিষেধ করা হয়েছিল। নিশ্চয় তারা মিথ্যাবাদী।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@dcccxviii{তারা বলেঃ আমাদের এ পার্থিব জীবনই জীবন। আমাদেরকে পুনরায় জীবিত হতে হবে না।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@dcccxix{আর যদি আপনি দেখেন; যখন তাদেরকে প্রতিপালকের সামনে দাঁড় করানো হবে। তিনি বলবেনঃ এটা কি বাস্তব সত্য নয়? তারা বলবেঃ হঁ্যা আমাদের প্রতিপালকের কসম। তিনি বলবেনঃ অতএব, স্বীয় কুফরের কারণে শাস্তি আস্বাদন কর।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@dcccxx{নিশ্চয় তারা ক্ষতিগ্রস্ত, যারা আল্লাহর সাক্ষাৎকে মিথ্যা মনে করেছে। এমনকি, যখন কিয়ামত তাদের কাছে অকস্মাৎ এসে যাবে, তারা বলবেঃ হায় আফসোস, এর ব্যাপারে আমরা কতই না ক্রটি করেছি। তার স্বীয় বোঝা স্বীয় পৃষ্ঠে বহন করবে। শুনে রাখ, তারা যে বোঝা বহন করবে, তা নিকৃষ্টতর বোঝা।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@dcccxxi{পার্থিব জীবন ক্রীড়া ও কৌতুক ব্যতীত কিছুই নয়। পরকালের আবাস পরহেযগারদের জন্যে শ্রেষ্টতর। তোমরা কি বুঝ না ?\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@dcccxxii{আমার জানা আছে যে, তাদের উক্তি আপনাকে দুঃখিত করে। অতএব, তারা আপনাকে মিথ্যা প্রতিপন্ন করে না, বরং জালেমরা আল্লাহর নিদর্শনাবলীকে অস্বীকার করে।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@dcccxxiii{আপনার পূর্ববর্তী অনেক পয়গম্বরকে মিথ্যা বলা হয়েছে। তাঁরা এতে ছবর করেছেন। তাদের কাছে আমার সাহায্য পৌঁছে পর্যন্ত তারা নির্যাতিত হয়েছেন। আল্লাহর বানী কেউ পরিবর্তন করতে পারে না। আপনার কাছে পয়গম্বরদের কিছু কাহিনী পৌঁছেছে।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@dcccxxiv{আর যদি তাদের বিমুখতা আপনার পক্ষে কষ্টকর হয়, তবে আপনি যদি ভূতলে কোন সুড়ঙ্গ অথবা আকাশে কোন সিড়ি অনুসন্ধান করতে সমর্থ হন, অতঃপর তাদের কাছে কোন একটি মোজেযা আনতে পারেন, তবে নিয়ে আসুন। আল্লাহ ইচ্ছা করলে সবাইকে সরল পথে সমবেত করতে পারতেন। অতএব, আপনি নির্বোধদের অন্তর্ভুক্ত হবেন না।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@dcccxxv{তারাই মানে, যারা শ্রবণ করে। আল্লাহ মৃতদেরকে জীবিত করে উত্থিত করবেন। অতঃপর তারা তাঁরই দিকে প্রত্যাবর্তিত হবে।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@dcccxxvi{তারা বলেঃ তার প্রতি তার পালনকর্তার পক্ষ থেকে কোন নিদর্শন অবতীর্ণ হয়নি কেন? বলে দিনঃ আল্লাহ নিদর্শন অবতরণ করতে পূর্ন সক্ষম; কিন্তু তাদের অধিকাংশই জানে না।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@dcccxxvii{আর যত প্রকার প্রাণী পৃথিবীতে বিচরণশীল রয়েছে এবং যত প্রকার পাখী দু’ ডানাযোগে উড়ে বেড়ায় তারা সবাই তোমাদের মতই একেকটি শ্রেণী। আমি কোন কিছু লিখতে ছাড়িনি। অতঃপর সবাই স্বীয় প্রতিপালকের কাছে সমবেত হবে।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@dcccxxviii{যারা আমার নিদর্শনসমূহকে মিথ্যা বলে, তারা অন্ধকারের মধ্যে মূক ও বধির। আল্লাহ যাকে ইচ্ছা পথভ্রষ্ট করেন এবং যাকে ইচ্ছা সরল পথে পরিচালিত করেন।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@dcccxxix{বলুন, বলতো দেখি, যদি তোমাদের উপর আল্লাহর শাস্তি পতিত হয় কিংবা তোমাদের কাছে কিয়ামত এসে যায়, তবে তোমরা কি আল্লাহ ব্যতীত অন্যকে ডাকবে যদি তোমরা সত্যবাদী হও।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@dcccxxx{বরং তোমরা তো তাঁকেই ডাকবে। অতঃপর যে বিপদের জন্যে তাঁকে ডাকবে, তিনি ইচ্ছা করলে তা দুরও করে দেন। যাদেরকে অংশীদার করছ, তখন তাদেরকে ভুলে যাবে।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@dcccxxxi{আর আমি আপনার পূর্ববর্তী উম্মতদের প্রতিও পয়গম্বর প্রেরণ করেছিলাম। অতঃপর আমি তাদেরকে অভাব-অনটন ও রোগ-ব্যধি দ্বারা পাকড়াও করেছিলাম যাতে তারা কাকুতি মিনতি করে।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@dcccxxxii{অতঃপর তাদের কাছে যখন আমার আযাব আসল, তখন কেন কাকুতি-মিনতি করল না ? বস্তুতঃ তাদের অন্তর কঠোর হয়ে গেল এবং শয়তান তাদের কাছে সুশোভিত করে দেখাল, যে কাজ তারা করছিল।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@dcccxxxiii{অতঃপর তারা যখন ঐ উপদেশ ভুলে গেল, যা তাদেরকে দেয়া হয়েছিল, তখন আমি তাদের সামনে সব কিছুর দ্বার উম্মুক্ত করে দিলাম। এমনকি, যখন তাদেরকে প্রদত্ত বিষয়াদির জন্যে তারা খুব গর্বিত হয়ে পড়ল, তখন আমি অকস্মাৎ তাদেরকে পাকড়াও করলাম। তখন তারা নিরাশ হয়ে গেল।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@dcccxxxiv{অতঃপর জালেমদের মূল শিকড় কর্তিত হল। সমস্ত প্রশংসা আল্লাহরই জন্যে, যিনি বিশ্বজগতের পালনকর্তা।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@dcccxxxv{আপনি বলুনঃ বল তো দেখি, যদি আল্লাহ তোমাদের কান ও চোখ নিয়ে যান এবং তোমাদের অন্তরে মোহর এঁটে দেন, তবে এবং তোমাদের আল্লাহ ব্যতীত এমন উপাস্য কে আছে, যে তোমাদেরকে এগুলো এনে দেবে? দেখ, আমি কিভাবে ঘুরিয়ে-ফিরিয়ে নিদর্শনাবলী বর্ণনা করি। তথাপি তারা বিমুখ হচ্ছে।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@dcccxxxvi{বলে দিনঃ দেখতো, যদি আল্লাহর শাস্তি, আকস্মিক কিংবা প্রকাশ্যে তোমাদের উপর আসে, তবে জালেম, সম্প্রদায় ব্যতীত কে ধ্বংস হবে?\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@dcccxxxvii{আমি পয়গম্বরদেরকে প্রেরণ করি না, কিন্তু সুসংবাদাতা ও ভীতি প্রদর্শকরূপে অতঃপর যে বিশ্বাস স্থাপন করে এবং সংশোধিত হয়, তাদের কোন শঙ্কা নেই এবং তারা দুঃখিত হবে না।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@dcccxxxviii{যারা আমার নিদর্শনাবলীকে মিথ্যা বলে, তাদেরকে তাদের নাফরমানীর কারণে আযাব স্পর্শ করবে।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@dcccxxxix{আপনি বলুনঃ আমি তোমাদেরকে বলি না যে, আমার কাছে আল্লাহর ভান্ডার রয়েছে। তাছাড়া আমি অদৃশ্য বিষয় অবগতও নই। আমি এমন বলি না যে, আমি ফেরেশতা। আমি তো শুধু ঐ ওহীর অনুসরণ করি, যা আমার কাছে আসে। আপনি বলে দিনঃ অন্ধ ও চক্ষুমান কি সমান হতে পারে? তোমরা কি চিন্তা কর না ?\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@dcccxl{আপনি এ কোরআন দ্বারা তাদেরকে ভয়-প্রদর্শন করুন, যারা আশঙ্কা করে স্বীয় পালনকর্তার কাছে এমতাবস্থায় একত্রিত হওয়ার যে, তাদের কোন সাহায্যকারী ও সুপারিশকারী হবে না-যাতে তারা গোনাহ থেকে বেঁচে থাকে।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@dcccxli{আর তাদেরকে বিতাড়িত করবেন না, যারা সকাল-বিকাল স্বীয় পালকর্তার এবাদত করে, তাঁর সন্তুষ্টি কামনা করে। তাদের হিসাব বিন্দুমাত্রও আপনার দায়িত্বে নয় এবং আপনার হিসাব বিন্দুমাত্রও তাদের দায়িত্বে নয় যে, আপনি তাদেরকে বিতাড়িত করবেন। নতুবা আপনি অবিচারকারীদের অন্তর্ভূক্ত হয়ে যাবেন।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@dcccxlii{আর এভাবেই আমি কিছু লোককে কিছু লোক দ্বারা পরীক্ষায় ফেলেছি যাতে তারা বলে যে, এদেরকেই কি আমাদের সবার মধ্য থেকে আল্লাহ স্বীয় অনুগ্রহ দান করেছেন? আল্লাহ কি কৃতজ্ঞদের সম্পর্কে সুপরিজ্ঞাত নন ?\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@dcccxliii{আর যখন তারা আপনার কাছে আসবে যারা আমার নিদর্শনসমূহে বিশ্বাস করে, তখন আপনি বলে দিনঃ তোমাদের উপর শান্তি বর্ষিত হোক। তোমাদের পালনকর্তা রহমত করা নিজ দায়িত্বে লিখে নিয়েছেন যে, তোমাদের মধ্যে যে কেউ অজ্ঞতাবশতঃ কোন মন্দ কাজ করে, অনন্তর এরপরে তওবা করে নেয় এবং সৎ হয়ে যায়, তবে তিনি অত্যন্ত ক্ষমাশীল, করুণাময়।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@dcccxliv{আর এমনিভাবে আমি নিদর্শনসমূহ বিস্তারিত বর্ণনা করি-যাতে অপরাধীদের পথ সুস্পষ্ট হয়ে উঠে।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@dcccxlv{আপনি বলে দিনঃ আমাকে তাদের এবাদত করতে নিষেধ করা হয়েছে, তোমরা আল্লাহকে ছেড়ে যাদের এবাদত কর। আপনি বলে দিনঃ আমি তোমাদের খুশীমত চলবো না। কেননা, তাহলে আমি পথভ্রান্ত হয়ে যাব এবং সুপথগামীদের অন্তর্ভুক্ত হব না।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@dcccxlvi{আপনি বলে দিনঃ আমার কাছে প্রতিপালকের পক্ষ থেকে একটি প্রমাণ আছে এবং তোমরা তার প্রতি মিথ্যারোপ করেছ। তোমরা যে বস্তু শীঘ্র দাবী করছ, তা আমার কাছে নেই। আল্লাহ ছাড়া কারো নির্দেশ চলে না। তিনি সত্য বর্ণনা করেন এবং তিনিই শ্রেষ্ঠতম মীমাংসাকারী।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@dcccxlvii{আপনি বলে দিনঃ যদি আমার কাছে তা থাকত, যা তোমরা শীঘ্র দাবী করছ, তবে আমার ও তোমাদের পারস্পরিক বিবাদ কবেই চুকে যেত। আল্লাহ জালেমদের সম্পর্কে যথেষ্ট পরিমাণে অবহিত।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@dcccxlviii{তাঁর কাছেই অদৃশ্য জগতের চাবি রয়েছে। এ গুলো তিনি ব্যতীত কেউ জানে না। স্থলে ও জলে যা আছে, তিনিই জানেন। কোন পাতা ঝরে না; কিন্তু তিনি তা জানেন। কোন শস্য কণা মৃত্তিকার অন্ধকার অংশে পতিত হয় না এবং কোন আর্দ্র ও শুস্ক দ্রব্য পতিত হয় না; কিন্তু তা সব প্রকাশ্য গ্রন্থে রয়েছে।\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@dcccxlix{তিনিই রাত্রি বেলায় তোমাদেরকে করায়ত্ত করে নেন এবং যা কিছু তোমরা দিনের বেলায় কর, তা জানেন। অতঃপর তোমাদেরকে দিবসে সম্মুখিত করেন-যাতে নির্দিষ্ট ওয়াদা পূর্ণ হয়।\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@dcccl{অনন্তর তাঁরই দিকে তোমাদের প্রত্যাবর্তন। অতঃপর তোমাদেরকে বলে দিবেন, যা কিছু তোমরা করছিলে। তিনিই স্বীয় বান্দাদের উপর প্রবল। তিনি প্রেরণ করেন তোমাদের কাছে রক্ষণাবেক্ষণকারী। এমন কি, যখন তোমাদের কারও মৃত্যু আসে তখন আমার প্রেরিত ফেরেশতারা তার আত্মা হস্তগত করে নেয়।\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@dcccli{অতঃপর সবাইকে সত্যিকার প্রভু আল্লাহর কাছে পৌঁছানো হবে। শুনে রাখ, ফয়সালা তাঁরই এবং তিনি দ্রুত হিসাব গ্রহণ করবেন।\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@dccclii{আপনি বলুনঃ কে তোমাদেরকে স্থল ও জলের অন্ধকার থেকে উদ্ধার করেন, যখন তোমরা তাঁকে বিনীতভাবে ও গোপনে আহবান কর যে, যদি আপনি আমাদের কে এ থেকে উদ্ধার করে নেন, তবে আমরা অবশ্যই কৃতজ্ঞদের অন্তর্ভুক্ত হয়ে যাব।\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@dcccliii{আপনি বলে দিনঃ আল্লাহ তোমাদেরকে তা থেকে মুক্তি দেন এব সব দুঃখ-বিপদ থেকে। তথাপি তোমরা শেরক কর।\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@dcccliv{আপনি বলুনঃ তিনিই শক্তিমান যে, তোমাদের উপর কোন শাস্তি উপর দিক থেকে অথবা তোমাদের পদতল থেকে প্রেরণ করবেন অথবা তোমাদেরকে দলে-উপদলে বিভক্ত করে সবাইকে মুখোমুখী করে দিবেন এবং এককে অন্যের উপর আক্রমণের স্বাদ আস্বাদন করাবেন। দেখ, আমি কেমন ঘুরিয়ে-ফিরিয়ে নিদর্শনাবলী বর্ণনা করি যাতে তারা বুঝে নেয়।\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@dccclv{আপনার সম্প্রদায় একে মিথ্যা বলছে, অথচ তা সত্য। আপনি বলে দিনঃ আমি তোমাদের উপর নিয়োজিত নই।\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@dccclvi{প্রত্যেক খবরের একটি সময় নির্দিষ্ট রয়েছে এবং অচিরেই তোমরা তা জেনে নিবে।\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@dccclvii{যখন আপনি তাদেরকে দেখেন, যারা আমার আয়াত সমূহে ছিদ্রান্বেষণ করে, তখন তাদের কাছ থেকে সরে যান যে পর্যন্ত তারা অন্য কথায় প্রবৃত্ত না হয়, যদি শয়তান আপনাকে ভূলিয়ে দেয় তবে স্মরণ হওয়ার পর জালেমদের সাথে উপবেশন করবেন না।\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@dccclviii{এদের যখন বিচার করা হবে তখন পরহেযগারদের উপর এর কোন প্রভাব পড়বে না; কিন্তু তাদের দায়িত্ব উপদেশ দান করা যাতে ওরা ভীত হয়।\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@dccclix{তাদেরকে পরিত্যাগ করুন, যারা নিজেদের ধর্মকে ক্রীড়া ও কৌতুকরূপে গ্রহণ করেছে এবং পার্থিব জীবন যাদেরকে ধোঁকায় ফেলে রেখেছে। কোরআন দ্বারা তাদেরকে উপদেশ দিন, যাতে কেউ স্বীয় কর্মে এমন ভাবে গ্রেফতার না হয়ে যায় যে, আল্লাহ ব্যতীত তার কোন সাহায্যকারী ও সুপারিশকারী নেই এবং যদি তারা জগতের বিনিময়ও প্রদান কবে, তবু তাদের কাছ থেকে তা গ্রহণ করা হবে না। একাই স্বীয় কর্মে জড়িত হয়ে পড়েছে। তাদের জন্যে উত্তপ্ত পানি এবং যন্ত্রণাদায়ক শাস্তি রয়েছে-কুফরের কারণে।\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@dccclx{আপনি বলে দিনঃ আমরা কি আল্লাহ ব্যতীত এমন বস্তুকে আহবান করব, যে আমাদের উপকার করতে পারে না এবং ক্ষতিও করতে পারে না এবং আমরা কি পশ্চাৎপদে ফিরে যাব, এরপর যে, আল্লাহ আমাদেরকে পথ প্রদর্শন করেছেন? ঐ ব্যক্তির মত, যাকে শয়তানরা বনভুমিতে বিপথগামী করে দিয়েছে-সে উদভ্রান্ত হয়ে ঘোরাফেরা করছে। তার সহচররা তাকে পথের দিকে ডেকে বলছেঃ আস, আমাদের কাছে। আপনি বলে দিনঃ নিশ্চয় আল্লাহর পথই সুপথ। আমরা আদিষ্ট হয়েছি যাতে স্বীয় পালনকর্তা আজ্ঞাবহ হয়ে যাই।\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@dccclxi{এবং তা এই যে, নামায কায়েম কর এবং তাঁকে ভয় কর। তাঁর সামনেই তোমরা একত্রিত হবে।\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@dccclxii{তিনিই সঠিকভাবে নভোমন্ডল সৃষ্টি করেছেন। যেদিন তিনি বলবেনঃ হয়ে যা, অতঃপর হয়ে যাবে। তাঁর কথা সত্য। যেদিন শিঙ্গায় ফুৎকার করা হবে, সেদিন তাঁরই আধিপত্য হবে। তিনি অদৃশ্য বিষয়ে এবং প্রত্যক্ষ বিষয়ে জ্ঞাত। তিনিই প্রজ্ঞাময়, সর্বজ্ঞ।\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@dccclxiii{স্মরণ কর, যখন ইব্রাহীম পিতা আযরকে বললেনঃ তুমি কি প্রতিমা সমূহকে উপাস্য মনে কর? আমি দেখতে পাচ্ছি যে, তুমি ও তোমার সম্প্রদায় প্রকাশ্য পথভ্রষ্ট।\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@dccclxiv{আমি এরূপ ভাবেই ইব্রাহীমকে নভোমন্ডল ও ভুমন্ডলের অত্যাশ্চর্য বস্তুসমূহ দেখাতে লাগলাম-যাতে সে দৃঢ় বিশ্বাসী হয়ে যায়।\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@dccclxv{অনন্তর যখন রজনীর অন্ধকার তার উপর সমাচ্ছন্ন হল, তখন সে একটি তারকা দেখতে পেল, বললঃ ইহা আমার প্রতিপালক। অতঃপর যখন তা অস্তমিত হল তখন বললঃ আমি অস্তগামীদেরকে ভালবাসি না।\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@dccclxvi{অতঃপর যখন চন্দ্রকে ঝলমল করতে দেখল, বললঃ এটি আমার প্রতিপালক। অনন্তর যখন তা অদৃশ্য হয়ে গেল, তখন বলল যদি আমার প্রতিপালক আমাকে পথ-প্রদর্শন না করেন, তবে অবশ্যই আমি বিভ্রান্ত সম্প্রদায়ের অন্তর্ভুক্ত হয়ে যাব।\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@dccclxvii{অতঃপর যখন সূর্যকে চকচক করতে দেখল, বললঃ এটি আমার পালনকর্তা, এটি বৃহত্তর। অতপর যখন তা ডুবে গেল, তখন বলল হে আমার সম্প্রদায়, তোমরা যেসব বিষয়কে শরীক কর, আমি ওসব থেকে মুক্ত।\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@dccclxviii{আমি এক মুখী হয়ে স্বীয় আনন ঐ সত্তার দিকে করেছি, যিনি নভোমন্ডল ও ভুমন্ডল সৃষ্টি করেছেন এবং আমি মুশরেক নই।\qt@no{(79)}}
\qt@newcmd\qurantrans@bn@dccclxix{তাঁর সাথে তার সম্প্রদায় বিতর্ক করল। সে বললঃ তোমরা কি আমার সাথে আল্লাহর একত্ববাদ সম্পর্কে বিতর্ক করছ; অথচ তিনি আমাকে পথ প্রদর্শন করেছেন। তোমরা যাদেরকে শরীক কর, আমি তাদেরকে ভয় করি না তবে আমার পালকর্তাই যদি কোন কষ্ট দিতে চান। আমার পালনকর্তাই প্রত্যেক বস্তুকে স্বীয় জ্ঞান দ্বারা বেষ্টন করে আছেন। তোমরা কি চিন্তা কর না ?\qt@no{(80)}}
\qt@newcmd\qurantrans@bn@dccclxx{যাদেরকে তোমরা আল্লাহর সাথে শরীক করে রেখেছ, তাদেরকে কিরূপে ভয় কর, অথচ তোমরা ভয় কর না যে, তোমরা আল্লাহর সাথে এমন বস্তুকে শরীক করছ, যাদের সম্পর্কে আল্লাহ তোমাদের প্রতি কোন প্রমাণ অবতীর্ণ করেননি। অতএব, উভয় সম্প্রদায়ের মধ্যে শাস্তি লাভের অধিক যোগ্য কে, যদি তোমরা জ্ঞানী হয়ে থাক।\qt@no{(81)}}
\qt@newcmd\qurantrans@bn@dccclxxi{যারা ঈমান আনে এবং স্বীয় বিশ্বাসকে শেরেকীর সাথে মিশ্রিত করে না, তাদের জন্যেই শান্তি এবং তারাই সুপথগামী।\qt@no{(82)}}
\qt@newcmd\qurantrans@bn@dccclxxii{এটি ছিল আমার যুক্তি, যা আমি ইব্রাহীমকে তাঁর সম্প্রদায়ের বিপক্ষে প্রদান করেছিলাম। আমি যাকে ইচ্ছা মর্যাদায় সমুন্নত করি। আপনার পালনকর্তা প্রজ্ঞাময়, মহাজ্ঞানী\qt@no{(83)}}
\qt@newcmd\qurantrans@bn@dccclxxiii{আমি তাঁকে দান করেছি ইসহাক এবং এয়াকুব। প্রত্যেককেই আমি পথ প্রদর্শন করেছি এবং পূর্বে আমি নূহকে পথ প্রদর্শন করেছি-তাঁর সন্তানদের মধ্যে দাউদ, সোলায়মান, আইউব, ইউসুফ, মূসা ও হারুনকে। এমনিভাবে আমি সৎকর্মীদেরকে প্রতিদান দিয়ে থাকি।\qt@no{(84)}}
\qt@newcmd\qurantrans@bn@dccclxxiv{আর ও যাকারিয়া, ইয়াহিয়া, ঈসা এবং ইলিয়াসকে। তারা সবাই পুণ্যবানদের অন্তর্ভুক্ত ছিল।\qt@no{(85)}}
\qt@newcmd\qurantrans@bn@dccclxxv{এবং ইসরাঈল, ইয়াসা, ইউনূস, লূতকে প্রত্যেককেই আমি সারা বিশ্বের উপর গৌরবাম্বিত করেছি।\qt@no{(86)}}
\qt@newcmd\qurantrans@bn@dccclxxvi{আর ও তাদের কিছু সংখ্যক পিতৃপুরুষ, সন্তান-সন্ততি ও ভ্রাতাদেরকে; আমি তাদেরকে মনোনীত করেছি এবং সরল পথ প্রদর্শন করেছি।\qt@no{(87)}}
\qt@newcmd\qurantrans@bn@dccclxxvii{এটি আল্লাহর হেদায়েত। স্বীয় বান্দাদের মধ্যে যাকে ইচ্ছা, এপথে চালান। যদি তারা শেরেকী করত, তবে তাদের কাজ কর্ম তাদের জন্যে ব্যর্থ হয়ে যেত।\qt@no{(88)}}
\qt@newcmd\qurantrans@bn@dccclxxviii{তাদেরকেই আমি গ্রন্থ, শরীয়ত ও নবুয়ত দান করেছি। অতএব, যদি এরা আপনার নবুয়ত অস্বীকার করে, তবে এর জন্যে এমন সম্প্রদায় নির্দিষ্ট করেছি, যারা এতে অবিশ্বাসী হবে না।\qt@no{(89)}}
\qt@newcmd\qurantrans@bn@dccclxxix{এরা এমন ছিল, যাদেরকে আল্লাহ পথ প্রদর্শন করেছিলেন। অতএব, আপনিও তাদের পথ অনুসরণ করুন। আপনি বলে দিনঃ আমি তোমাদের কাছে এর জন্যে কোন পারিশ্রমিক চাই না। এটি সারা বিশ্বের জন্যে একটি উপদেশমাত্র।\qt@no{(90)}}
\qt@newcmd\qurantrans@bn@dccclxxx{তারা আল্লাহকে যথার্থ মূল্যায়ন করতে পারেনি, যখন তারা বললঃ আল্লাহ কোন মানুষের প্রতি কোন কিছু অবতীর্ণ করেননি। আপনি জিজ্ঞেস করুনঃ ঐ গ্রন্থ কে নাযিল করেছে, যা মূসা নিয়ে এসেছিল ? যা জ্যোতিবিশেষ এবং মানব মন্ডলীর জন্যে হোদায়েতস্বরূপ, যা তোমরা বিক্ষিপ্তপত্রে রেখে লোকদের জন্যে প্রকাশ করছ এবং বহুলাংশকে গোপন করছ। তোমাদেরকে এমন অনেক বিষয় শিক্ষা দেয়া হয়েছে, যা তোমরা এবং তোমাদের পূর্বপুরুষরা জানতো না। আপনি বলে দিনঃ আল্লাহ নাযিল করেছেন। অতঃপর তাদেরকে তাদের ক্রীড়ামূলক বৃত্তিতে ব্যাপৃত থাকতে দিন।\qt@no{(91)}}
\qt@newcmd\qurantrans@bn@dccclxxxi{এ কোরআন এমন গ্রন্থ, যা আমি অবতীর্ন করেছি; বরকতময়, পূর্ববর্তী গ্রন্থের সত্যতা প্রমাণকারী এবং যাতে আপনি মক্কাবাসী ও পাশ্ববর্তীদেরকে ভয় প্রদর্শন করেন। যারা পরকালে বিশ্বাস স্থাপন করে তারা এর প্রতি বিশ্বাস স্থাপন করে এবং তার স্বীয় নামায সংরক্ষণ করে।\qt@no{(92)}}
\qt@newcmd\qurantrans@bn@dccclxxxii{ঐ ব্যক্তির চাইতে বড় জালেম কে হবে, যে আল্লাহর প্রতি মিথ্যা আরোপ করে অথবা বলেঃ আমার প্রতি ওহী অবতীর্ণ হয়েছে। অথচ তার প্রতি কোন ওহী আসেনি এবং যে দাবী করে যে, আমিও নাযিল করে দেখাচ্ছি যেমন আল্লাহ নাযিল করেছেন। যদি আপনি দেখেন যখন জালেমরা মৃত্যু যন্ত্রণায় থাকে এবং ফেরেশতারা স্বীয় হস্ত প্রসারিত করে বলে, বের কর স্বীয় আত্মা! অদ্য তোমাদেরকে অবমাননাকর শাস্তি প্রদান করা হবে। কারণ, তোমরা আল্লাহর উপর অসত্য বলতে এবং তাঁর আয়াত সমূহ থেকে অহংকার করতে।\qt@no{(93)}}
\qt@newcmd\qurantrans@bn@dccclxxxiii{তোমরা আমার কাছে নিঃসঙ্গ হয়ে এসেছ, আমি প্রথমবার তোমাদেরকে সৃষ্টি করেছিলাম। আমি তোদেরকে যা দিয়েছিলাম, তা পশ্চাতেই রেখে এসেছ। আমি তো তোমাদের সাথে তোমাদের সুপারিশকারীদের কে দেখছি না। যাদের সম্পর্কে তোমাদের দাবী ছিল যে, তারা তোমাদের ব্যাপারে অংশীদার। বাস্তুবিকই তোমাদের পরস্পরের সম্পর্ক ছিন্ন হয়ে গেছে এবং তোমাদের দাবী উধাও হয়ে গেছে।\qt@no{(94)}}
\qt@newcmd\qurantrans@bn@dccclxxxiv{নিশ্চয় আল্লাহই বীজ ও আঁটি থেকে অঙ্কুর সৃষ্টিকারী; তিনি জীবিতকে মৃত থেকে বের করেন ও মৃতকে জীবিত থেকে বের করেন। তিনি আল্লাহ অতঃপর তোমরা কোথায় বিভ্রান্ত হচ্ছ?\qt@no{(95)}}
\qt@newcmd\qurantrans@bn@dccclxxxv{তিনি প্রভাত রশ্মির উন্মেষক। তিনি রাত্রিকে আরামদায়ক করেছেন এবং সূর্য ও চন্দ্রকে হিসেবের জন্য রেখেছেন। এটি পরাক্রান্ত, মহাজ্ঞানীর নির্ধারণ।\qt@no{(96)}}
\qt@newcmd\qurantrans@bn@dccclxxxvi{তিনিই তোমাদের জন্য নক্ষত্রপুঞ্জ সৃজন করেছেন যাতে তোমরা স্থল ও জলের অন্ধকারে পথ প্রাপ্ত হও। নিশ্চয় যারা জ্ঞানী তাদের জন্যে আমি নির্দেশনাবলী বিস্তারিত বর্ণনা করে দিয়েছি।\qt@no{(97)}}
\qt@newcmd\qurantrans@bn@dccclxxxvii{তিনিই তোমাদের কে এক ব্যক্তি থেকে সৃষ্টি করেছেন। অনন্তর একটি হচ্ছে তোমাদের স্থায়ী ঠিকানা ও একটি হচ্ছে গচ্ছিত স্থল। নিশ্চয় আমি প্রমাণাদি বিস্তারিত ভাবে বর্ণনা করে দিয়েছি তাদের জন্যে, যারা চিন্তা করে।\qt@no{(98)}}
\qt@newcmd\qurantrans@bn@dccclxxxviii{তিনিই আকাশ থেকে পানি বর্ষণ করেছেন অতঃপর আমি এর দ্বারা সর্বপ্রকার উদ্ভিদ উৎপন্ন করেছি, অতঃপর আমি এ থেকে সবুজ ফসল নির্গত করেছি, যা থেকে যুগ্ম বীজ উৎপন্ন করি। খেজুরের কাঁদি থেকে গুচ্ছ বের করি, যা নুয়ে থাকে এবং আঙ্গুরের বাগান, যয়তুন, আনার পরস্পর সাদৃশ্যযুক্ত এবং সাদৃশ্যহীন। বিভিন্ন গাছের ফলের প্রতি লক্ষ্য কর যখন সেুগুলো ফলন্ত হয় এবং তার পরিপক্কতার প্রতি লক্ষ্য কর। নিশ্চয় এ গুলোতে নিদর্শন রয়েছে ঈমানদারদের জন্যে।\qt@no{(99)}}
\qt@newcmd\qurantrans@bn@dccclxxxix{তারা জিনদেরকে আল্লাহর অংশীদার স্থির করে; অথচ তাদেরকে তিনিই সৃস্টি করেছেন। তারা অজ্ঞতাবশতঃ আল্লাহর জন্যে পুত্র ও কন্যা সাব্যস্ত করে নিয়েছে। তিনি পবিত্র ও সমুন্নত, তাদের বর্ননা থেকে।\qt@no{(100)}}
\qt@newcmd\qurantrans@bn@dcccxc{তিনি নভোমন্ডল ও ভূমন্ডলের আদি স্রষ্টা। কিরূপে আল্লাহর পুত্র হতে পারে, অথচ তাঁর কোন সঙ্গী নেই ? তিনি যাবতীয় কিছু সৃষ্টি করেছেন। তিনি সব বস্তু সম্পর্কে সুবিজ্ঞ।\qt@no{(101)}}
\qt@newcmd\qurantrans@bn@dcccxci{তিনিই আল্লাহ তোমাদের পালনকর্তা। তিনি ব্যতীত কোন উপাস্য নেই। তিনিই সব কিছুর স্রষ্টা। অতএব, তোমরা তাঁরই এবাদত কর। তিনি প্রত্যেক বস্তুর কার্যনির্বাহী।\qt@no{(102)}}
\qt@newcmd\qurantrans@bn@dcccxcii{দৃষ্টিসমূহ তাঁকে পেতে পারে না, অবশ্য তিনি দৃষ্টিসমূহকে পেতে পারেন। তিনি অত্যন্ত সুক্ষদর্শী, সুবিজ্ঞ।\qt@no{(103)}}
\qt@newcmd\qurantrans@bn@dcccxciii{তোমাদের কাছে তোমাদের পালনকর্তার পক্ষ থেকে নিদর্শনাবলী এসে গেছে। অতএব, যে প্রত্যক্ষ করবে, সে নিজেরই উপকার করবে এবং যে অন্ধ হবে, সে নিজেরই ক্ষতি করবে। আমি তোমাদের পর্যবেক্ষক নই।\qt@no{(104)}}
\qt@newcmd\qurantrans@bn@dcccxciv{এমনি ভাবে আমি নিদর্শনাবলী ঘুরিয়ে-ফিরিয়ে বর্ণনা করি যাতে তারা না বলে যে, আপনি তো পড়ে নিয়েছেন এবং যাতে আমি একে সুধীবৃন্দের জন্যে খুব পরিব্যক্ত করে দেই।\qt@no{(105)}}
\qt@newcmd\qurantrans@bn@dcccxcv{আপনি পথ অনুসরণ করুন, যার আদেশ পালনকর্তার পক্ষ থেকে আসে। তিনি ব্যতীত কোন উপাস্য নেই এবং মুশরিকদের তরফ থেকে মুখ ফিরিয়ে নিন।\qt@no{(106)}}
\qt@newcmd\qurantrans@bn@dcccxcvi{যদি আল্লাহ চাইতেন তবে তারা শেরক করত না। আমি আপনাকে তাদের সংরক্ষক করিনি এবং আপনি তাদের কার্যনির্বাহী নন।\qt@no{(107)}}
\qt@newcmd\qurantrans@bn@dcccxcvii{তোমরা তাদেরকে মন্দ বলো না, যাদের তারা আরাধনা করে আল্লাহকে ছেড়ে। তাহলে তারা ধৃষ্টতা করে অজ্ঞতাবশতঃ আল্লাহকে মন্দ বলবে। এমনিভাবে আমি প্রত্যেক সম্প্রদায়ের দৃষ্টিতে তাদের কাজ কর্ম সুশোভিত করে দিয়েছি। অতঃপর স্বীয় পালনকর্তার কাছে তাদেরকে প্রত্যাবর্তন করতে হবে। তখন তিনি তাদেরকে বলে দেবেন যা কিছু তারা করত।\qt@no{(108)}}
\qt@newcmd\qurantrans@bn@dcccxcviii{তারা জোর দিয়ে আল্লাহর কসম খায় যে, যদি তাদের কাছে কোন নিদর্শন আসে, তবে অবশ্যই তারা বিশ্বাস স্থাপন করবে। আপনি বলে দিনঃ নিদর্শনাবলী তো আল্লাহর কাছেই আছে। হে মুসলমানগণ, তোমাদেরকে কে বলল যে, যখন তাদের কাছে নিদর্শনাবলী আসবে, তখন তারা বিশ্বাস স্থাপন করবেই ?\qt@no{(109)}}
\qt@newcmd\qurantrans@bn@dcccxcix{আমি ঘুরিয়ে দিব তাদের অন্তর ও দৃষ্টিকে, যেমন-তারা এর প্রতি প্রথমবার বিশ্বাস স্থাপন করেনি এবং আমি তাদেরকে তাদের অবাধ্যতায় উদভ্রান্ত ছেড়ে দিব।\qt@no{(110)}}
\qt@newcmd\qurantrans@bn@cm{আমি যদি তাদের কাছে ফেরেশতাদেরকে অবতারণ করতাম এবং তাদের সাথে মৃতরা কথাবার্তা বলত এবং আমি সব বস্তুকে তাদের সামনে জীবিত করে দিতাম, তথাপি তারা কখনও বিশ্বাস স্থাপনকারী নয়; কিন্তু যদি আল্লাহ চান। কিন্তু তাদের অধিকাংশই মুর্খ।\qt@no{(111)}}
\qt@newcmd\qurantrans@bn@cmi{এমনিভাবে আমি প্রত্যেক নবীর জন্যে শত্রু করেছি শয়তান, মানব ও জিনকে। তারা ধোঁকা দেয়ার জন্যে একে অপরকে কারুকার্যখচিত কথাবার্তা শিক্ষা দেয়। যদি আপনার পালনকর্তা চাইতেন, তবে তারা এ কাজ করত না।\qt@no{(112)}}
\qt@newcmd\qurantrans@bn@cmii{অতএব, আপনি তাদেরকে এবং তাদের মিথ্যাপবাদকে মুক্ত ছেড়ে দিন যাতে কারুকার্যখচিত বাক্যের প্রতি তাদের মন আকৃষ্ট হয় যারা পরকালে বিশ্বাস করে না এবং তারা একেও পছন্দ করে নেয় এবং যাতে ঐসব কাজ করে, যা তারা করছে।\qt@no{(113)}}
\qt@newcmd\qurantrans@bn@cmiii{তবে কি আমি আল্লাহ ব্যতীত অন্য কোন বিচারক অনুসন্ধান করব, অথচ তিনিই তোমাদের প্রতি বিস্তারিত গ্রন্থ অবতীর্ন করেছেন? আমি যাদেরকে গ্রন্থ প্রদান করেছি, তারা নিশ্চিত জানে যে, এটি আপনার প্রতি পালকের পক্ষ থেকে সত্যসহ অবর্তীর্ন হয়েছে। অতএব, আপনি সংশয়কারীদের অন্তর্ভুক্ত হবেন না।\qt@no{(114)}}
\qt@newcmd\qurantrans@bn@cmiv{আপনার প্রতিপালকের বাক্য পূর্ণ সত্য ও সুষম। তাঁর বাক্যের কোন পরিবর্তনকারী নেই। তিনিই শ্রবণকারী, মহাজ্ঞানী।\qt@no{(115)}}
\qt@newcmd\qurantrans@bn@cmv{আর যদি আপনি পৃথিবীর অধিকাংশ লোকের কথা মেনে নেন, তবে তারা আপনাকে আল্লাহর পথ থেকে বিপথগামী করে দেবে। তারা শুধু অলীক কল্পনার অনুসরণ করে এবং সম্পূর্ণ অনুমান ভিত্তিক কথাবার্তা বলে থাকে।\qt@no{(116)}}
\qt@newcmd\qurantrans@bn@cmvi{আপনার প্রতিপালক তাদের সম্পর্কে খুব জ্ঞাত রয়েছেন, যারা তাঁর পথ থেকে বিপথগামী হয় এবং তিনি তাদেরকেও খুব ভাল করে জানেন, যারা তাঁর পথে অনুগমন করে।\qt@no{(117)}}
\qt@newcmd\qurantrans@bn@cmvii{অতঃপর যে জন্তুর উপর আল্লাহর নাম উচ্চারিত হয়, তা থেকে ভক্ষণ কর যদি তোমরা তাঁর বিধানসমূহে বিশ্বাসী হও।\qt@no{(118)}}
\qt@newcmd\qurantrans@bn@cmviii{কোন কারণে তোমরা এমন জন্তু থেকে ভক্ষণ করবে না, যার উপর আল্লাহর নাম উচ্চারিত হয়, অথচ আল্লাহ ঐ সব জন্তুর বিশদ বিবরণ দিয়েছেন, যেগুলোকে তোমাদের জন্যে হারাম করেছেন; কিন্তু সেগুলোও তোমাদের জন্যে হালাল, যখন তোমরা নিরুপায় হয়ে যাও। অনেক লোক স্বীয় ভ্রান্ত প্রবৃত্তি দ্বারা না জেনে বিপথগামী করতে থাকে। আপনার প্রতিপালক সীমাতিক্রম কারীদেরকে যথার্থই জানেন।\qt@no{(119)}}
\qt@newcmd\qurantrans@bn@cmix{তোমরা প্রকাশ্য ও প্রচ্ছন্ন গোনাহ পরিত্যাগ কর। নিশ্চয় যারা গোনাহ করেছে, তারা অতিসত্বর তাদের কৃতকর্মের শাস্তি পাবে।\qt@no{(120)}}
\qt@newcmd\qurantrans@bn@cmx{যেসব জন্তুর উপর আল্লাহর নাম উচ্চারিত হয় না, সেগুলো থেকে ভক্ষণ করো না; এ ভক্ষণ করা গোনাহ। নিশ্চয় শয়তানরা তাদের বন্ধুদেরকে প্রত্যাদেশ করে-যেন তারা তোমাদের সাথে তর্ক করে। যদি তোমরা তাদের আনুগত্য কর, তোমরাও মুশরেক হয়ে যাবে।\qt@no{(121)}}
\qt@newcmd\qurantrans@bn@cmxi{আর যে মৃত ছিল অতঃপর আমি তাকে জীবিত করেছি এবং তাকে এমন একটি আলো দিয়েছি, যা নিয়ে সে মানুষের মধ্যে চলাফেরা করে। সে কি ঐ ব্যক্তির সমতুল্য হতে পারে, যে অন্ধকারে রয়েছে-সেখান থেকে বের হতে পারছে না? এমনিভাবে কাফেরদের দৃষ্টিতে তাদের কাজকর্মকে সুশোভিত করে দেয়া হয়েছে।\qt@no{(122)}}
\qt@newcmd\qurantrans@bn@cmxii{আর এমনিভাবে আমি প্রত্যেক জনপদে অপরাধীদের জন্য কিছু সর্দার নিয়োগ করেছি-যেন তারা সেখানে চক্রান্ত করে। তাদের সে চক্রান্ত তাদের নিজেদের বিরুদ্ধেই; কিন্তু তারা তা উপলব্ধি করতে পারে না।\qt@no{(123)}}
\qt@newcmd\qurantrans@bn@cmxiii{যখন তাদের কাছে কোন আয়াত পৌঁছে, তখন বলে, আমরা কখনই মানব না যে, পর্যন্ত না আমরাও তা প্রদত্ত হই, যা আল্লাহর রসূলগণ প্রদত্ত হয়েছেন। আল্লাহ এ বিষয়ে সুপারিজ্ঞাত যে, কোথায় স্বীয় পয়গাম প্রেরণ করতে হবে। যারা অপরাধ করছে, তারা অতিসত্বর আল্লাহর কাছে পৌছে লাঞ্ছনা ও কঠোর শাস্তি পাবে, তাদের চক্রান্তের কারণে।\qt@no{(124)}}
\qt@newcmd\qurantrans@bn@cmxiv{অতঃপর আল্লাহ যাকে পথ-প্রদর্শন করতে চান, তার বক্ষকে ইসলামের জন্যে উম্মুক্ত করে দেন এবং যাকে বিপথগামী করতে চান, তার বক্ষকে সংকীর্ণ অত্যধিক সংকীর্ণ করে দেন-যেন সে সবেগে আকাশে আরোহণ করছে। এমনি ভাবে যারা বিশ্বাস স্থাপন করে না। আল্লাহ তাদের উপর আযাব বর্ষন করেন।\qt@no{(125)}}
\qt@newcmd\qurantrans@bn@cmxv{আর এটাই আপনার পালনকর্তার সরল পথ। আমি উপদেশ গ্রহণকারীদের জন্যে আয়াতসমূহ পুঙ্খানুপুঙ্খ বর্ননা করেছি।\qt@no{(126)}}
\qt@newcmd\qurantrans@bn@cmxvi{তাদের জন্যেই তাদের প্রতিপালকের কাছে নিরাপত্তার গৃহ রয়েছে এবং তিনি তাদের বন্ধু তাদের কর্মের কারণে।\qt@no{(127)}}
\qt@newcmd\qurantrans@bn@cmxvii{যেদিন আল্লাহ সবাইকে একত্রিত করবেন, হে জিন সম্প্রদায়, তোমরা মানুষদের মধ্যে অনেককে অনুগামী করে নিয়েছ। তাদের মানব বন্ধুরা বলবেঃ হে আমাদের পালনকর্তা, আমরা পরস্পরে পরস্পরের মাধ্যমে ফল লাভ করেছি। আপনি আমাদের জন্যে যে সময় নির্ধারণ করেছিলেন, আমরা তাতে উপনীত হয়েছি। আল্লাহ বলবেনঃ আগুন হল তোমাদের বাসস্থান। তথায় তোমরা চিরকাল অবস্থান করবে; কিন্তু যখন চাইবেন আল্লাহ। নিশ্চয় আপনার পালনকর্তা প্রজ্ঞাময়, মহাজ্ঞানী।\qt@no{(128)}}
\qt@newcmd\qurantrans@bn@cmxviii{এমনিভাবে আমি পাপীদেরকে একে অপরের সাথে যুক্ত করে দেব তাদের কাজকর্মের কারণে।\qt@no{(129)}}
\qt@newcmd\qurantrans@bn@cmxix{হে জ্বিন ও মানব সম্প্রদায়, তোমাদের কাছে কি তোমাদের মধ্য থেকে পয়গম্বরগণ আগমন করেনি? যাঁরা তোমাদেরকে আমার বিধানাবলী বর্ণনা করতেন এবং তোমাদেরকে আজকের এ দিনের সাক্ষাতের ভীতি প্রদর্শন করতেন? তারা বলবেঃ আমরা স্বীয় গোনাহ স্বীকার করে নিলাম। পার্থিব জীবন তাদেরকে প্রতারিত করেছে। তারা নিজেদের বিরুদ্ধে স্বীকার করে নিয়েছে যে, তারা কাফের ছিল।\qt@no{(130)}}
\qt@newcmd\qurantrans@bn@cmxx{এটা এ জন্যে যে, আপনার প্রতিপালক কোন জনপদের অধিবাসীদেরকে জুলুমের কারণে ধ্বংস করেন না এমতাবস্থায় যে, তথাকার অধিবাসীরা অজ্ঞ থাকে।\qt@no{(131)}}
\qt@newcmd\qurantrans@bn@cmxxi{প্রত্যেকের জন্যে তাদের কর্মের আনুপাতিক মর্যাদা আছে এবং আপনার প্রতিপালক তাদের কর্ম সম্পর্কে বেখবর নন।\qt@no{(132)}}
\qt@newcmd\qurantrans@bn@cmxxii{আপনার প্রতিপালক অমুখাপেক্ষী, করুণাময়। তিনি ইচ্ছা করলে তোমাদের সবাইকে উচ্ছেদ করে দিবেন এবং তোমাদের পর যাকে ইচ্ছা তোমাদের স্থলে অভিষিক্ত করবেন; যেমন তোমাদেরকে অন্য এক সম্প্রদায়ের বংশধর থেকে সৃষ্টি করেছেন।\qt@no{(133)}}
\qt@newcmd\qurantrans@bn@cmxxiii{যে বিষয়ের ওয়াদা তোমাদের সাথে করা হয়, তা অবশ্যই আগমন করবে এবং তোমরা অক্ষম করতে পারবে না।\qt@no{(134)}}
\qt@newcmd\qurantrans@bn@cmxxiv{আপনি বলে দিনঃ হে আমার সম্প্রদায়, তোমরা স্বস্থানে কাজ করে যাও, আমিও কাজ করি। অচিরেই জানতে পারবে যে, পরিণাম গৃহ কে লাভ করে। নিশ্চয় জালেমরা সুফলপ্রাপ্ত হবে না।\qt@no{(135)}}
\qt@newcmd\qurantrans@bn@cmxxv{আল্লাহ যেসব শস্যক্ষেত্র ও জীবজন্তু সৃষ্টি করেছেন, সেগুলো থেকে তারা এক অংশ আল্লাহর জন্য নির্ধারণ করে অতঃপর নিজ ধারণা অনুসারে বলে এটা আল্লাহর এবং এটা আমাদের অংশীদারদের। অতঃপর যে অংশ তাদের অংশীদারদের, তা তো আল্লাহর দিকে পৌঁছে না এবং যা আল্লাহর তা তাদের উপাস্যদের দিকে পৌছে যায়। তাদের বিচার কতই না মন্দ।\qt@no{(136)}}
\qt@newcmd\qurantrans@bn@cmxxvi{এমনিভাবে অনেক মুশরেকের দৃষ্টিতে তাদের উপাস্যরা সন্তান হত্যাকে সুশোভিত করে দিয়েছে যেন তারা তাদেরকে বিনষ্ট করে দেয় এবং তাদের ধর্মমতকে তাদের কাছে বিভ্রান্ত করে দেয়। যদি আল্লাহ চাইতেন, তবে তারা এ কাজ করত না। অতএব, আপনি তাদেরকে এবং তাদের মনগড়া বুলিকে পরিত্যাগ করুন।\qt@no{(137)}}
\qt@newcmd\qurantrans@bn@cmxxvii{তারা বলেঃ এসব চতুষ্পদ জন্তু ও শস্যক্ষেত্র নিষিদ্ধ। আমরা যাকে ইচছা করি, সে ছাড়া এগুলো কেউ খেতে পারবে না, তাদের ধারণা অনুসারে। আর কিছুসংখ্যক চতুষ্পদ জন্তুর পিঠে আরোহন হারাম করা হয়েছে এবং কিছু সংখ্যক চতুষ্পদ জন্তুর উপর তারা ভ্রান্ত ধারনা বশতঃ আল্লাহর নাম উচ্চারণ করে না, তাদের মনগড়া বুলির কারণে, অচিরেই তিনি তাদের কে শাস্তি দিবেন।\qt@no{(138)}}
\qt@newcmd\qurantrans@bn@cmxxviii{তারা বলেঃ এসব চতুষ্পদ জন্তুর পেটে যা আছে, তা বিশেষ ভাবে আমাদের পুরুষদের জন্যে এবং আমাদের মহিলাদের জন্যে তা হারাম। যদি তা মৃত হয়, তবে তার প্রাপক হিসাবে সবাই সমান। অচিরেই তিনি তাদেরকে তাদের বর্ণনার শাস্তি দিবেন। তিনি প্রজ্ঞাময়, মহাজ্ঞানী।\qt@no{(139)}}
\qt@newcmd\qurantrans@bn@cmxxix{নিশ্চয় তারা ক্ষতিগ্রস্ত হয়েছে, যারা নিজ সন্তানদেরকে নির্বুদ্ধিতাবশতঃ কোন প্রমাণ ছাড়াই হত্যা করেছে এবং আল্লাহ তাদেরকে যেসব দিয়েছিলেন, সেগুলোকে আল্লাহর প্রতি ভ্রান্ত ধারণা পোষণ করে হারাম করে নিয়েছে। নিশ্চিতই তারা পথভ্রষ্ট হয়েছে এবং সুপথগামী হয়নি।\qt@no{(140)}}
\qt@newcmd\qurantrans@bn@cmxxx{তিনিই উদ্যান সমূহ সৃষ্টি করেছে-তাও, যা মাচার উপর তুলে দেয়া হয়, এবং যা মাচার উপর তোলা হয় না এবং খর্জুর বৃক্ষ ও শস্যক্ষেত্র যেসবের স্বাদবিশিষ্ট এবং যয়তুন ও আনার সৃষ্টি করেছেন-একে অন্যের সাদৃশ্যশীল এবং সাদৃশ্যহীন। এগুলোর ফল খাও, যখন ফলন্ত হয় এবং হক দান কর কর্তনের সময়ে এবং অপব্যয় করো না। নিশ্চয় তিনি অপব্যয়ীদেরকে পছন্দ করেন না।\qt@no{(141)}}
\qt@newcmd\qurantrans@bn@cmxxxi{তিনি সৃষ্টি করেছেন চতুষ্পদ জন্তুর মধ্যে বোঝা বহনকারীকে এবং খর্বাকৃতিকে। আল্লাহ তোমাদেরকে যা কিছু দিয়েছেন, তা থেকে খাও এবং শয়তানের পদাঙ্ক অনুসরণ করো না। সে তোমাদের প্রকাশ্য শত্রু।\qt@no{(142)}}
\qt@newcmd\qurantrans@bn@cmxxxii{সৃষ্টি করেছেন আটটি নর ও মাদী। ভেড়ার মধ্যে দুই প্রকার ও ছাগলের মধ্যে দুই প্রকার। জিজ্ঞেস করুন, তিনি কি উভয় নর হারাম করেছেন, না উভয় মাদীকে ? না যা উভয় মাদীর পেটে আছে? তোমরা আমাকে প্রমাণসহ বল, যদি তোমরা সত্যবাদী হও।\qt@no{(143)}}
\qt@newcmd\qurantrans@bn@cmxxxiii{সৃষ্টি করেছেন উটের মধ্যে দুই প্রকার এবং গরুর মধ্যে দুই প্রকার। আপনি জিজ্ঞেস করুনঃ তিনি কি উভয় নর হারাম করেছেন, না উভয় মাদীকে, না যা উভয় মাদীর পেটে আছে? তোমরা কি উপস্থিত ছিলে, যখন আল্লাহ এ নির্দেশ দিয়েছিলেন? অতএব সে ব্যক্তি অপেক্ষা বেশী অত্যচারী কে, যে আল্লাহ সম্পর্কে মিথ্যা ধারণা পোষন করে যাতে করে মানুষকে বিনা প্রমাণে পথভ্রষ্ট করতে পারে? নিশ্চয় আল্লাহ অত্যাচারী সম্প্রদায়কে পথপ্রদর্শন করেন না।\qt@no{(144)}}
\qt@newcmd\qurantrans@bn@cmxxxiv{আপনি বলে দিনঃ যা কিছু বিধান ওহীর মাধ্যমে আমার কাছে পৌঁছেছে, তন্মধ্যে আমি কোন হারাম খাদ্য পাই না কোন ভক্ষণকারীর জন্যে, যা সে ভক্ষণ করে; কিন্তু মৃত অথবা প্রবাহিত রক্ত অথবা শুকরের মাংস এটা অপবিত্র অথবা অবৈধ; যবেহ করা জন্তু যা আল্লাহ ছাড়া অন্যের নামে উৎসর্গ করা হয়। অতপর যে ক্ষুধায় কাতর হয়ে পড়ে এমতাবস্থায় যে অবাধ্যতা করে না এবং সীমালঙ্গন করে না, নিশ্চয় আপনার পালনকর্তা ক্ষমাশীল দয়ালু।\qt@no{(145)}}
\qt@newcmd\qurantrans@bn@cmxxxv{ইহুদীদের জন্যে আমি প্রত্যেক নখবিশিষ্ট জন্তু হারাম করেছিলাম এবং ছাগল ও গরু থেকে এতদুভয়ের চর্বি আমি তাদের জন্যে হারাম করেছিলাম, কিন্তু ঐ চর্বি, যা পৃষ্টে কিংবা অন্ত্রে সংযুক্ত থাকে অথবা অস্থির সাথে মিলিত থাকে। তাদের অবাধ্যতার কারণে আমি তাদেরকে এ শাস্তি দিয়েছিলাম। আর আমি অবশ্যই সত্যবাদী।\qt@no{(146)}}
\qt@newcmd\qurantrans@bn@cmxxxvi{যদি তারা আপনাকে মিথ্যবাদী বলে, তবে বলে দিনঃ তোমার প্রতিপালক সুপ্রশস্ত করুণার মালিক। তাঁর শাস্তি অপরাধীদের উপর থেকে টলবে না।\qt@no{(147)}}
\qt@newcmd\qurantrans@bn@cmxxxvii{এখন মুশরেকরা বলবেঃ যদি আল্লাহ ইচ্ছা করতেন, তবে না আমরা শিরক করতাম, না আমাদের বাপ দাদারা এবং না আমরা কোন বস্তুকে হারাম করতাম। এমনিভাবে তাদের পূর্ববর্তীরা মিথ্যারোপ করেছে, এমন কি তারা আমার শাস্তি আস্বাদন করেছে। আপনি বলুনঃ তোমাদের কাছে কি কোন প্রমাণ আছে যা আমাদেরকে দেখাতে পার। তোমরা শুধুমাত্র আন্দাজের অনুসরণ কর এবং তোমরা শুধু অনুমান করে কথা বল।\qt@no{(148)}}
\qt@newcmd\qurantrans@bn@cmxxxviii{আপনি বলে দিনঃ অতএব, পরিপূর্ন যুক্তি আল্লাহরই। তিনি ইচ্ছা করলে তোমাদের সবাইকে পথ প্রদর্শন করতেন।\qt@no{(149)}}
\qt@newcmd\qurantrans@bn@cmxxxix{আপনি বলুনঃ তোমাদের সাক্ষীদেরকে আন, যারা সাক্ষ্য দেয় যে, আল্লাহ তা’আলা এগুলো হারাম করেছেন। যদি তারা সাক্ষ্য দেয়, তবে আপনি এ সাক্ষ্য গ্রহণ করবেন না এবং তাদের কুপ্রবৃত্তির অনুসরণ করবেন না, যারা আমার নির্দেশাবলীকে মিথ্যা বলে, যারা পরকালে বিশ্বাস করে না এবং যারা স্বীয় প্রতিপালকের সমতুল্য অংশীদার করে।\qt@no{(150)}}
\qt@newcmd\qurantrans@bn@cmxl{আপনি বলুনঃ এস, আমি তোমাদেরকে ঐসব বিষয় পাঠ করে শুনাই, যেগুলো তোমাদের প্রতিপালক তোমাদের জন্যে হারাম করেছেন। তাএই যে, আল্লাহর সাথে কোন কিছুকে অংশীদার করো না, পিতা-মাতার সাথে সদয় ব্যবহার করো স্বীয় সন্তানদেরকে দারিদ্রে?480; কারণে হত্যা করো না, আমি তোমাদেরকে ও তাদেরকে আহার দেই, নির্লজ্জতার কাছেও যেয়ো না, প্রকাশ্য হোক কিংবা অপ্রকাশ্য, যাকে হত্যা করা আল্লাহ হারাম করেছেন, তাকে হত্যা করো না; কিন্তু ন্যায়ভাবে। তোমাদেরকে এ নির্দেশ দিয়েছেন, যেন তোমরা বুঝ।\qt@no{(151)}}
\qt@newcmd\qurantrans@bn@cmxli{এতীমদের ধনসম্পদের কাছেও যেয়ো না; কিন্তু উত্তম পন্থায় যে পর্যন্ত সে বয়ঃপ্রাপ্ত না হয়। ওজন ও মাপ পূর্ণ কর ন্যায় সহকারে। আমি কাউকে তার সাধ্যের অতীত কষ্ট দেই না। যখন তোমরা কথা বল, তখন সুবিচার কর, যদিও সে আত্নীয়ও হয়। আল্লাহর অঙ্গীকার পূর্ণ কর।\qt@no{(152)}}
\qt@newcmd\qurantrans@bn@cmxlii{তোমাদেরকে এ নির্দেশ দিয়েছেন, যেন তোমরা উপদেশ গ্রহণ কর। নিশ্চিত এটি আমার সরল পথ। অতএব, এ পথে চল এবং অন্যান্য পথে চলো না। তা হলে সেসব পথ তোমাদেরকে তাঁর পথ থেকে বিচ্ছিন্ন করে দিবে। তোমাদেরকে এ নির্দেশ দিয়েছেন, যাতে তোমরা সংযত হও।\qt@no{(153)}}
\qt@newcmd\qurantrans@bn@cmxliii{অতঃপর আমি মূসাকে গ্রন্থ দিয়েছি, সৎকর্মীদের প্রতি নেয়ামতপূর্ণ করার জন্যে, প্রত্যেক বস্তুর বিশদ বিবরণের জন্যে, হোদায়াতের জন্যে এবং করুণার জন্যে-যাতে তারা স্বীয় পালনকর্তার সাথে সাক্ষাতে বিশ্বাসী হয়।\qt@no{(154)}}
\qt@newcmd\qurantrans@bn@cmxliv{এটি এমন একটি গ্রন্থ, যা আমি অবতীর্ণ করেছি, খুব মঙ্গলময়, অতএব, এর অনুসরণ কর এবং ভয় কর-যাতে তোমরা করুণাপ্রাপ্ত হও।\qt@no{(155)}}
\qt@newcmd\qurantrans@bn@cmxlv{এ জন্যে যে, কখনও তোমরা বলতে শুরু করঃ গ্রন্থ তো কেবল আমাদের পূর্ববর্তী দু'সম্প্রদায়ের প্রতিই অবতীর্ণ হয়েছে এবং আমরা সেগুলোর পাঠ ও পঠন সম্পর্কে কিছুই জানতাম না।\qt@no{(156)}}
\qt@newcmd\qurantrans@bn@cmxlvi{কিংবা বলতে শুরু করঃ যদি আমাদের প্রতি কোন গ্রন্থ অবতীর্ণ হত, আমরা এদের চাইতে অধিক পথপ্রাপ্ত হতাম। অতএব, তোমাদের পালনকর্তার পক্ষ থেকে তোমাদের কাছে সুষ্পষ্ট প্রমাণ, হেদায়েত ও রহমত এসে গেছে। অতঃপর সে ব্যক্তির চাইতে অধিক অনাচারী কে হবে, যে আল্লাহর আয়াত সমূহকে মিথ্যা বলে এবং গা বাঁচিয়ে চলে। অতি সত্ত্বর আমি তাদেরকে শাস্তি দেব। যারা আমার আয়াত সমূহ থেকে গা বাঁচিয়ে চলে-জঘন্য শাস্তি তাদের গা বাঁচানোর কারণে।\qt@no{(157)}}
\qt@newcmd\qurantrans@bn@cmxlvii{তারা শুধু এ বিষয়ের দিকে চেয়ে আছে যে, তাদের কাছে ফেরেশতা আগমন করবে কিংবা আপনার পালনকর্তা আগমন করবেন অথবা আপনার পালনকর্তার কোন নির্দেশ আসবে। যেদিন আপনার পালনকর্তার কোন নিদর্শন আসবে, সেদিন এমন কোন ব্যক্তির বিশ্বাস স্থাপন তার জন্যে ফলপ্রসূ হবে না, যে পূর্ব থেকে বিশ্বাস স্থাপন করেনি কিংবা স্বীয় বিশ্বাস অনুযায়ী কোনরূপ সৎকর্ম করেনি। আপনি বলে দিনঃ তোমরা পথের দিকে চেয়ে থাক, আমরাও পথে দিকে তাকিয়ে রইলাম।\qt@no{(158)}}
\qt@newcmd\qurantrans@bn@cmxlviii{নিশ্চয় যারা স্বীয় ধর্মকে খন্ড-বিখন্ড করেছে এবং অনেক দল হয়ে গেছে, তাদের সাথে আপনার কোন সম্পর্ক নেই। তাদের ব্যাপার আল্লাহ তা'আয়ালার নিকট সমর্পিত। অতঃপর তিনি বলে দেবেন যা কিছু তারা করে থাকে।\qt@no{(159)}}
\qt@newcmd\qurantrans@bn@cmxlix{যে একটি সৎকর্ম করবে, সে তার দশগুণ পাবে এবং যে, একটি মন্দ কাজ করবে, সে তার সমান শাস্তিই পাবে। বস্তুতঃ তাদের প্রতি জুলুম করা হবে না।\qt@no{(160)}}
\qt@newcmd\qurantrans@bn@cml{আপনি বলে দিনঃ আমার প্রতিপালক আমাকে সরল পথ প্রদর্শন করেছেন একাগ্রচিত্ত ইব্রাহীমের বিশুদ্ধ ধর্ম। সে অংশীবাদীদের অন্তর্ভূক্ত ছিল না।\qt@no{(161)}}
\qt@newcmd\qurantrans@bn@cmli{আপনি বলুনঃ আমার নামায, আমার কোরবাণী এবং আমার জীবন ও মরন বিশ্ব-প্রতিপালক আল্লাহরই জন্যে।\qt@no{(162)}}
\qt@newcmd\qurantrans@bn@cmlii{তাঁর কোন অংশীদার নেই। আমি তাই আদিষ্ট হয়েছি এবং আমি প্রথম আনুগত্যশীল।\qt@no{(163)}}
\qt@newcmd\qurantrans@bn@cmliii{আপনি বলুনঃ আমি কি আল্লাহ ব্যতীত অন্য প্রতিপালক খোঁজব, অথচ তিনিই সবকিছুর প্রতিপালক? যে ব্যক্তি কোন গোনাহ করে, তা তারই দায়িত্বে থাকে। কেউ অপরের বোঝা বহন করবে না। অতঃপর তোমাদেরকে সবাইকে প্রতিপালকের কাছে প্রত্যাবর্তন করতে হবে। অনন্তর তিনি তোমাদেরকে বলে দিবেন, যেসব বিষয়ে তোমরা বিরোধ করতে।\qt@no{(164)}}
\qt@newcmd\qurantrans@bn@cmliv{তিনিই তোমাদেরকে পৃথিবীতে প্রতিনিধি করেছেন এবং একে অন্যের উপর মর্যাদা সমুন্নত করেছেন, যাতে তোমাদের কে এ বিষয়ে পরীক্ষা করেন, যা তোমাদেরকে দিয়েছেন। আপনার প্রতিপালক দ্রুত শাস্তি দাতা এবং তিনি অত্যন্ত ক্ষমাশীল, দয়ালু।\qt@no{(165)}}
\qt@newcmd\qurantrans@bn@cmlv{\basmalahbn আলিফ, লাম, মীম, ছোয়াদ।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@cmlvi{এটি একটি গ্রন্থ, যা আপনার প্রতি অবতীর্ণ হয়েছে, যাতে করে আপনি এর মাধ্যমে ভীতি-প্রদর্শন করেন। অতএব, এটি পৌছে দিতে আপনার মনে কোনরূপ সংকীর্ণতা থাকা উচিত নয়। আর এটিই বিশ্বাসীদের জন্যে উপদেশ।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@cmlvii{তোমরা অনুসরণ কর, যা তোমাদের প্রতি পালকের পক্ষ থেকে অবতীর্ণ হয়েছে এবং আল্লাহকে বাদ দিয়ে অন্য সাথীদের অনুসরণ করো না।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@cmlviii{আর তোমরা অল্পই উপদেশ গ্রহণ কর। অনেক জনপদকে আমি ধ্বংস করে দিয়েছি। তাদের কাছে আমার আযাব রাত্রি বেলায় পৌছেছে অথবা দ্বিপ্রহরে বিশ্রামরত অবস্থায়।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@cmlix{অনন্তর যখন তাদের কাছে আমার আযাব উপস্থিত হয়, তখন তাদের কথা এই ছিল যে, তারা বললঃ নিশ্চয় আমরা অত্যাচারী ছিলাম।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@cmlx{অতএব, আমি অবশ্যই তাদেরকে জিজ্ঞেস করব যাদের কাছে রসূল প্রেরিত হয়েছিল এবং আমি অবশ্যই তাদেরকে জিজ্ঞেস করব রসূলগণকে।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@cmlxi{অতঃপর আমি স্বজ্ঞানে তাদের কাছে অবস্থা বর্ণনা করব। বস্তুতঃ আমি অনুপস্থিত তো ছিলাম না।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@cmlxii{আর সেদিন যথার্থই ওজন হবে। অতঃপর যাদের পাল্লা ভারী হবে, তারাই সফলকাম হবে।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@cmlxiii{এবং যাদের পাল্লা হাল্কা হবে, তারাই এমন হবে, যারা নিজেদের ক্ষতি করেছে। কেননা, তারা আমার আয়াত সমূহ অস্বীকার করতো।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@cmlxiv{আমি তোমাদেরকে পৃথিবীতে ঠাই দিয়েছি এবং তোমাদের জীবিকা নির্দিষ্ট করে দিয়েছি। তোমরা অল্পই কৃতজ্ঞতা স্বীকার কর।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@cmlxv{আর আমি তোমাদেরকে সৃষ্টি করেছি, এরপর আকার-অবয়ব, তৈরী করেছি। অতঃপর আমি ফেরেশতাদেরকে বলছি-আদমকে সেজদা কর তখন সবাই সেজদা করেছে, কিন্তু ইবলীস সে সেজদাকারীদের অন্তর্ভূক্ত ছিল না।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@cmlxvi{আল্লাহ বললেনঃ আমি যখন নির্দেশ দিয়েছি, তখন তোকে কিসে সেজদা করতে বারণ করল? সে বললঃ আমি তার চাইতে শ্রেষ্ট। আপনি আমাকে আগুন দ্বারা সৃষ্টি করেছেন এবং তাকে সৃষ্টি করেছেন মাটির দ্বারা।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@cmlxvii{বললেন তুই এখান থেকে যা। এখানে অহংকার করার কোন অধিকার তোর নাই। অতএব তুই বের হয়ে যা। তুই হীনতমদের অন্তর্ভুক্ত।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@cmlxviii{সে বললঃ আমাকে কেয়ামত দিবস পর্যন্ত অবকাশ দিন।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@cmlxix{আল্লাহ বললেনঃ তোকে সময় দেয়া হল।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@cmlxx{সে বললঃ আপনি আমাকে যেমন উদভ্রান্ত করেছেন, আমিও অবশ্য তাদের জন্যে আপনার সরল পথে বসে থাকবো।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@cmlxxi{এরপর তাদের কাছে আসব তাদের সামনের দিক থেকে, পেছন দিক থেকে, ডান দিক থেকে এবং বাম দিক থেকে। আপনি তাদের অধিকাংশকে কৃতজ্ঞ পাবেন না।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@cmlxxii{আল্লাহ বললেনঃ বের হয়ে যা এখান থেকে লাঞ্ছিত ও অপমানিত হয়ে। তাদের যে কেউ তোর পথেচলবে, নিশ্চয় আমি তোদের সবার দ্বারা জাহান্নাম পূর্ণ করে দিব।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@cmlxxiii{হে আদম তুমি এবং তোমার স্ত্রী জান্নাতে বসবাস কর। অতঃপর সেখান থেকে যা ইচ্ছা খাও তবে এ বৃক্ষের কাছে যেয়োনা তাহলে তোমরা গোনাহগার হয়ে যাবে।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@cmlxxiv{অতঃপর শয়তান উভয়কে প্ররোচিত করল, যাতে তাদের অঙ্গ, যা তাদের কাছে গোপন ছিল, তাদের সামনে প্রকাশ করে দেয়। সে বললঃ তোমাদের পালনকর্তা তোমাদেরকে এ বৃক্ষ থেকে নিষেধ করেননি; তবে তা এ কারণে যে, তোমরা না আবার ফেরেশতা হয়ে যাও-কিংবা হয়ে যাও চিরকাল বসবাসকারী।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@cmlxxv{সে তাদের কাছে কসম খেয়ে বললঃ আমি অবশ্যই তোমাদের হিতাকাঙ্খী।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@cmlxxvi{অতঃপর প্রতারণাপূর্বক তাদেরকে সম্মত করে ফেলল। অনন্তর যখন তারা বৃক্ষ আস্বাদন করল, তখন তাদের লজ্জাস্থান তাদের সামনে খুলে গেল এবং তারা নিজের উপর বেহেশতের পাতা জড়াতে লাগল। তাদের প্রতিপালক তাদেরকে ডেকে বললেনঃ আমি কি তোমাদেরকে এ বৃক্ষ থেকে নিষেধ করিনি এবং বলিনি যে, শয়তান তোমাদের প্রকাশ্য শত্রু।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@cmlxxvii{তারা উভয়ে বললঃ হে আমাদের পালনকর্তা আমরা নিজেদের প্রতি জুলম করেছি। যদি আপনি আমাদেরকে ক্ষমা না করেন এবং আমাদের প্রতি অনুগ্রহ না করেন, তবে আমরা অবশ্যই অবশ্যই ধ্বংস হয়ে যাব।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@cmlxxviii{আল্লাহ বললেনঃ তোমরা নেমে যাও। তোমরা এক অপরের শত্রু। তোমাদের জন্যে পৃথিবীতে বাসস্থান আছে এবং একটি নির্দিষ্ট মেয়াদ পর্যন্ত ফল ভোগ আছে।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@cmlxxix{বললেনঃ তোমরা সেখানেই জীবিত থাকবে, সেখানেই মৃত্যুবরন করবে এবং সেখান থেকেই পুনরুঙ্খিত হবে।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@cmlxxx{হে বনী-আদম আমি তোমাদের জন্যে পোশাক অবর্তীণ করেছি, যা তোমাদের লজ্জাস্থান আবৃত করে এবং অবর্তীণ করেছি সাজ সজ্জার বস্ত্র এবং পরহেযগারীর পোশাক, এটি সর্বোত্তম। এটি আল্লাহর কুদরতেরঅন্যতম নিদর্শন, যাতে তারা চিন্তা-ভাবনা করে।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@cmlxxxi{হে বনী-আদম শয়তান যেন তোমাদেরকে বিভ্রান্ত না করে; যেমন সে তোমাদের পিতামাতাকে জান্নাত থেকে বের করে দিয়েছে এমতাবস্থায় যে, তাদের পোশাক তাদের থেকে খুলিয়ে দিয়েছি-যাতে তাদেরকে লজ্জাস্থান দেখিয়ে দেয়। সে এবং তার দলবল তোমাদেরকে দেখে, যেখান থেকে তোমরা তাদেরকে দেখ না। আমি শয়তানদেরকে তাদের বন্ধু করে দিয়েছি, , যারা বিশ্বাস স্থাপন করে না।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@cmlxxxii{তারা যখন কোন মন্দ কাজ করে, তখন বলে আমরা বাপ-দাদাকে এমনি করতে দেখেছি এবং আল্লাহও আমাদেরকে এ নির্দেশই দিয়েছেন। আল্লাহ মন্দকাজের আদেশ দেন না। এমন কথা আল্লাহর প্রতি কেন আরোপ কর, যা তোমরা জান না।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@cmlxxxiii{আপনি বলে দিনঃ আমার প্রতিপালক সুবিচারের নির্দেশ দিয়েছেন এবং তোমরা প্রত্যেক সেজদার সময় স্বীয় মুখমন্ডল সোজা রাখ এবং তাঁকে খাঁটি আনুগত্যশীল হয়ে ডাক। তোমাদেরকে প্রথমে যেমন সৃষ্টি করেছেন, পুনর্বারও সৃজিত হবে।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@cmlxxxiv{একদলকে পথ প্রদর্শন করেছেন এবং একদলের জন্যে পথভ্রষ্টতা অবধারিত হয়ে গেছে। তারা আল্লাহকে ছেড়ে শয়তানদেরকে বন্ধু হিসাবে গ্রহণ করেছে এবং ধারণা করে যে, তারা সৎপথে রয়েছে।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@cmlxxxv{হে বনী-আদম! তোমরা প্রত্যেক নামাযের সময় সাজসজ্জা পরিধান করে নাও, খাও ও পান কর এবং অপব্যয় করো না। তিনি অপব্যয়ীদেরকে পছন্দ করেন না।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@cmlxxxvi{আপনি বলুনঃ আল্লাহর সাজ-সজ্জাকে, যা তিনি বান্দাদের জন্যে সৃষ্টি করেছেন এবং পবিত্র খাদ্রবস্তুসমূহকে কে হারাম করেছে? আপনি বলুনঃ এসব নেয়ামত আসলে পার্থিব জীবনে মুমিনদের জন্যে এবং কিয়ামতের দিন খাঁটিভাবে তাদেরই জন্যে। এমনিভাবে আমি আয়াতসমূহ বিস্তারিত বর্ণনা করি তাদের জন্যে যারা বুঝে।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@cmlxxxvii{আপনি বলে দিনঃ আমার পালনকর্তা কেবলমাত্র অশ্লীল বিষয়সমূহ হারাম করেছেন যা প্রকাশ্য ও অপ্রকাশ্য এবং হারাম করেছেন গোনাহ, অন্যায়-অত্যাচার আল্লাহর সাথে এমন বস্তুকে অংশীদার করা, তিনি যার কোন, সনদ অবতীর্ণ করেননি এবং আল্লাহর প্রতি এমন কথা আরোপ করা, যা তোমরা জান না।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@cmlxxxviii{প্রত্যেক সম্প্রদায়ের একটি মেয়াদ রয়েছে। যখন তাদের মেয়াদ এসে যাবে, তখন তারা না এক মুহুর্ত পিছে যেতে পারবে, আর না এগিয়ে আসতে পারবে।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@cmlxxxix{হে বনী-আদম, যদি তোমাদের কাছে তোমাদেরই মধ্য থেকে পয়গম্বর আগমন করে তোমাদেরকে আমার আয়াত সমূহ শুনায়, তবে যে ব্যক্তি সংযত হয় এবং সৎকাজ অবলম্বন করে, তাদের কোন আশঙ্কা নেই এবং তারা দুঃখিত হবে না।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@cmxc{যারা আমার আয়াতসমূহকে মিথ্যা বলবে এবং তা থেকে অহংকার করবে, তারাই দোযখী এবং তথায় চিরকাল থাকবে।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@cmxci{অতঃপর ঐ ব্যক্তির চাইতে অধিক জালেম কে, যে আল্লাহর প্রতি মিথ্যা আরোপ করে অথবা তার নির্দেশাবলীকে মিথ্যা বলে? তারা তাদের গ্রন্থে লিখিত অংশ পেয়ে যাবে। এমন কি, যখন তাদের কাছে আমার প্রেরিত ফেরশতারা প্রাণ নেওয়ার জন্যে পৌছে, তখন তারা বলে; তারা কোথায় গেল, যাদের কে তোমরা আল্লাহ ব্যতীত আহবান করতে? তারা উত্তর দেবেঃ আমাদের কাছ থেকে উধাও হয়ে গেছে, তারা নিজেদের সম্পর্কে স্বীকার করবে যে, তারা অবশ্যই কাফের ছিল।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@cmxcii{আল্লাহ বলবেনঃ তোমাদের পূর্বে জিন ও মানবের যেসব সম্প্রদায় চলে গেছে, তাদের সাথে তোমরাও দোযখে যাও। যখন এক সম্প্রদায় প্রবেশ করবে; তখন অন্য সম্প্রদায়কে অভিসম্পাত করবে। এমনকি, যখন তাতে সবাই পতিত হবে, তখন পরবর্তীরা পূর্ববর্তীদের সম্পর্কে বলবেঃ হে আমাদের প্রতিপালক এরাই আমাদেরকে বিপথগামী করেছিল। অতএব, আপনি তাদেরকে দ্বিগুণ শাস্তি দিন। আল্লাহ বলবেন প্রত্যেকেরই দ্বিগুণ; তোমরা জান না।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@cmxciii{পূর্ববর্তীরা পরবর্তীদেরকে বলবেঃ তাহলে আমাদের উপর তোমাদের কোন শ্রেষ্ঠত্ব নেই অতএব, শাস্তি আস্বাদন কর স্বীয় কর্মের কারণে।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@cmxciv{নিশ্চয়ই যারা আমার আয়াতসমূহকে মিথ্যা বলেছে এবং এগুলো থেকে অহংকার করেছে, তাদের জন্যে আকাশের দ্বার উম্মুক্ত করা হবে না এবং তারা জান্নাতে প্রবেশ করবে না। যে পর্যন্ত না সূচের ছিদ্র দিয়ে উট প্রবেশ করে। আমি এমনিভাবে পাপীদেরকে শাস্তি প্রদান করি।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@cmxcv{তাদের জন্যে নরকাগ্নির শয্যা রয়েছে এবং উপর থেকে চাদর। আমি এমনিভাবে জালেমদেরকে শাস্তি প্রদান করি।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@cmxcvi{যারা বিশ্বাস স্থাপন করেছে এবং সৎকর্ম করেছে আমি কাউকে তার সামর্থ্যের চাইতে বেশী বোঝা দেই না। তারাই জান্নাতের অধিবাসী। তারা তাতেই চিরকাল থাকবে।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@cmxcvii{তাদের অন্তরে যা কিছু দুঃখ ছিল, আমি তা বের করে দেব। তাদের তলদেশ দিয়ে নির্ঝরণী প্রবাহিত হবে। তারা বলবেঃ আল্লাহ শোকর, যিনি আমাদেরকে এ পর্যন্ত পৌছিয়েছেন। আমরা কখনও পথ পেতাম না, যদি আল্লাহ আমাদেরকে পথ প্রদর্শন না করতেন। আমাদের প্রতিপালকের রসূল আমাদের কাছে সত্যকথা নিয়ে এসেছিলেন। আওয়াজ আসবেঃ এটি জান্নাত। তোমরা এর উত্তরাধিকারী হলে তোমাদের কর্মের প্রতিদানে।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@cmxcviii{জান্নাতীরা দোযখীদেরকে ডেকে বলবেঃ আমাদের সাথে আমাদের প্রতিপালক যে ওয়াদা করেছিলেন, তা আমরা সত্য পেয়েছি? অতএব, তোমরাও কি তোমাদের প্রতিপালকের ওয়াদা সত্য পেয়েছ? তারা বলবেঃ হ্যাঁ। অতঃপর একজন ঘোষক উভয়ের মাঝখানে ঘোষণা করবেঃ আল্লাহর অভিসম্পাত জালেমদের উপর।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@cmxcix{যারা আল্লাহর পথে বাধা দিত এবং তাতে বক্রতা অন্বেষণ করত। তারা পরকালের বিষয়েও অবিশ্বাসী ছিল।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@m{উভয়ের মাঝখানে একটি প্রাচীর থাকবে এবং আরাফের উপরে অনেক লোক থাকবে। তারা প্রত্যেককে তার চিহ্ন দ্বারা চিনে নেবে। তারা জান্নাতীদেরকে ডেকে বলবেঃ তোমাদের উপর শান্তি বর্ষিত হোক। তারা তখনও জান্নাতে প্রবেশ করবে না, কিন্তু প্রবেশ করার ব্যাপারে আগ্রহী হবে।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mi{যখন তাদের দৃষ্টি দোযখীদের উপর পড়বে, তখন বলবেঃ হে আমাদের প্রতিপালক, আমাদেরকে এ জালেমদের সাথী করো না।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mii{আরাফবাসীরা যাদেরকে তাদের চিহ্ন দ্বারা চিনবে, তাদেরকে ডেকে বলবে তোমাদের দলবল ও ঔদ্ধত্য তোমাদের কোন কাজে আসেনি।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@miii{এরা কি তারাই; যাদের সম্পর্কে তোমরা কসম খেয়ে বলতে যে, আল্লাহ এদের প্রতি অনুগ্রহ করবেন না। প্রবেশ কর জান্নাতে। তোমাদের কোন আশঙ্কা নেই এবং তোমরা দুঃখিত হবে না।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@miv{দোযখীরা জান্নাতীদেরকে ডেকে বলবেঃ আমাদের উপর সামান্য পানি নিক্ষেপ কর অথবা আল্লাহ তোমাদেরকে যে রুযী দিয়েছেন, তা থেকেই কিছু দাও। তারা বলবেঃ আল্লাহ এই উভয় বস্তু কাফেরদের জন্যে নিষিদ্ধ করেছেন,\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mv{তারা স্বীয় ধর্মকে তামাশা ও খেলা বানিয়ে নিয়েছিল এবং পার্থিব জীবন তাদের কে ধোকায় ফেলে রেখেছিল। অতএব, আমি আজকে তাদেরকে ভুলে যাব; যেমন তারা এ দিনের সাক্ষাৎকে ভুলে গিয়েছিল এবং যেমন তারা আয়াতসমূহকে অবিশ্বাস করত।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mvi{আমি তাদের কাছে গ্রন্থ পৌছিয়েছি, যা আমি স্বীয় জ্ঞানে বিস্তারিত বর্ণনা করেছি, যা পথপ্রদর্শক এবং মুমিনদের জন্যে রহমত।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mvii{তারা কি এখন এ অপেক্ষায়ই আছে যে, এর বিষয়বস্তু প্রকাশিত হোক? যেদিন এর বিষয়বস্তু প্রকাশিত হবে, সেদিন পূর্বে যারা একে ভূলে গিয়েছিল, তারা বলবেঃ বাস্তবিকই আমাদের প্রতিপালকের পয়গম্বরগণ সত্যসহ আগমন করেছিলেন। অতএব, আমাদের জন্যে কোন সুপারিশকারী আছে কি যে, সুপারিশ করবে অথবা আমাদেরকে পুনঃ প্রেরণ করা হলে আমরা পূর্বে যা করতাম তার বিপরীত কাজ করে আসতাম। নিশ্চয় তারা নিজেদেরকে ক্ষতিগ্রস্ত করেছে। তারা মনগড়া যা বলত, তা উধাও হয়ে যাবে।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mviii{নিশ্চয় তোমাদের প্রতিপালক আল্লাহ। তিনি নভোমন্ডল ও ভূমন্ডলকে ছয় দিনে সৃষ্টি করেছেন। অতঃপর আরশের উপর অধিষ্টিত হয়েছেন। তিনি পরিয়ে দেন রাতের উপর দিনকে এমতাবস্থায় যে, দিন দৌড়ে রাতের পিছনে আসে। তিনি সৃষ্টি করেছেন সূর্য, চন্দ্র ও নক্ষত্র দৌড় স্বীয় আদেশের অনুগামী। শুনে রেখ, তাঁরই কাজ সৃষ্টি করা এবং আদেশ দান করা। আল্লাহ, বরকতময় যিনি বিশ্বজগতের প্রতিপালক।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mix{তোমরা স্বীয় প্রতিপালককে ডাক, কাকুতি-মিনতি করে এবং সংগোপনে। তিনি সীমা অতিক্রমকারীদেরকে পছন্দ করেন না।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mx{পৃথিবীকে কুসংস্কারমুক্ত ও ঠিক করার পর তাতে অনর্থ সৃষ্টি করো না। তাঁকে আহবান কর ভয় ও আশা সহকারে। নিশ্চয় আল্লাহর করুণা সৎকর্মশীলদের নিকটবর্তী।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mxi{তিনিই বৃষ্টির পূর্বে সুসংবাদবাহী বায়ু পাঠিয়ে দেন। এমনকি যখন বায়ুরাশি পানিপূর্ন মেঘমালা বয়ে আনে, তখন আমি এ মেঘমালাকে একটি মৃত শহরের দিকে হঁ্যাকিয়ে দেই। অতঃপর এ মেঘ থেকে বৃষ্টি ধারা বর্ষণ করি। অতঃপর পানি দ্বারা সব রকমের ফল উৎপন্ন করি। এমনি ভাবে মৃতদেরকে বের করব-যাতে তোমরা চিন্তা কর।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mxii{যে শহর উৎকৃষ্ট, তার ফসল তার প্রতিপালকের নির্দেশে উৎপন্ন হয় এবং যা নিকৃষ্ট তাতে অল্পই ফসল উৎপন্ন হয়। এমনিভাবে আমি আয়াতসমূহ ঘুরিয়ে ফিরিয়ে বর্ণনা করি কৃতজ্ঞ সম্প্রদায়ের জন্যে।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mxiii{নিশ্চয় আমি নূহকে তার সম্প্রদায়ের প্রতি পাঠিয়েছি। সে বললঃ হে আমার সম্প্রদায়, তোমরা আল্লাহর এবাদত কর। তিনি ব্যতীত তোমাদের কোন উপাস্য নেই। আমি তোমাদের জন্যে একটি মহাদিবসের শাস্তির আশঙ্কা করি।\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mxiv{তার সম্প্রদায়ের সর্দাররা বললঃ আমরা তোমাকে প্রকাশ্য পথভ্রষ্টতার মাঝে দেখতে পাচ্ছি।\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mxv{সে বললঃ হে আমার সম্প্রদায়, আমি কখনও ভ্রান্ত নই; কিন্তু আমি বিশ্বপ্রতিপালকের রসূল।\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mxvi{তোমাদেরকে প্রতিপালকের পয়গাম পৌঁছাই এবং তোমাদেরকে সদুপদেশ দেই। আমি আল্লাহর পক্ষ থেকে এমনসব বিষয় জানি, যেগুলো তোমরা জান না।\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mxvii{তোমরা কি আশ্চর্যবোধ করছ যে, তোমাদের কাছে তোমাদের প্রতিপালকের পক্ষ থেকে তোমাদের মধ্য থেকেই একজনের বাচনিক উপদেশ এসেছে যাতে সে তোমাদেরকে ভীতি প্রদর্শন করে, যেন তোমরা সংযত হও এবং যেন তোমরা অনুগৃহীত হও।\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mxviii{অতঃপর তারা তাকে মিথ্যা প্রতিপন্ন করল। আমি তাকে এবং নৌকাস্থিত লোকদেরকে উদ্ধার করলাম এবং যারা মিথ্যারোপ করত, তাদেরকে ডুবিয়ে দিলাম। নিশ্চয় তারা ছিল অন্ধ।\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mxix{আদ সম্প্রদায়ের কাছে প্রেরণ করেছি তাদের ভাই হুদকে। সে বললঃ হে আমার সম্প্রদায়, তোমরা আল্লাহর এবাদত কর। তিনি ব্যতিত তোমাদের কোন উপাস্য নেই।\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mxx{তারা স্প্রদায়ের সর্দররা বললঃ আমরা তোমাকে নির্বোধ দেখতে পাচ্ছি এবং আমরা তোমাকে মিথ্যাবাদী মনে করি।\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mxxi{সে বললঃ হে আমার সম্প্রদায়, আমি মোটেই নির্বোধ নই, বরং আমি বিশ্ব প্রতিপালকের প্রেরিত পয়গম্বর।\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mxxii{তোমাদের কে প্রতিপালকের পয়গাম পৌঁছাই এবং আমি তোমাদের হিতাকাঙ্ক্ষী বিশ্বস্ত।\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mxxiii{তোমরা কি আশ্চর্য্যবোধ করছ যে, তোমাদের কাছে তোমাদের পালনকর্তার পক্ষ থেকে তোমাদের মধ্য থেকেই একজনের বাচনিক উপদেশ এসেছে যাতে সে তোমাদেরকে ভীতি প্রদর্শন করে। তোমরা স্মরণ কর, যখন আল্লাহ তোমাদেরকে কওমে নূহের পর সর্দার করেছেন এবং তোমাদের দেহের বিস্তৃতি বেশী করেছেন। তোমরা আল্লাহর নেয়ামতসমূহ স্মরণ কর-যাতে তোমাদের মঙ্গল হয়।\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mxxiv{তারা বললঃ তুমি কি আমাদের কাছে এজন্যে এসেছ যে আমরা এক আল্লাহর এবাদত করি এবং আমাদের বাপ-দাদা যাদের পূজা করত, তাদেরকে ছেড়ে দেই? অতএব নিয়ে আস আমাদের কাছে যাদ্দ্বারা আমাদেরকে ভয় দেখাচ্ছ, যদি তুমি সত্যবাদী হও।\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@mxxv{সে বললঃ অবধারিত হয়ে গেছে তোমাদের উপর তোমাদের প্রতিপালকের পক্ষ থেকে শাস্তি ও ক্রোধ। আমার সাথে ঐসব নাম সম্পর্কে কেন তর্ক করছ, যেগুলো তোমরা ও তোমাদের বাপ-দাদারা রেখেছে। আল্লাহ এদের কোন মন্দ অবর্তীণ করেননি। অতএব অপেক্ষা কর। আমিও তোমাদের সাথে অপেক্ষা করছি।\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@mxxvi{অনন্তর আমি তাকে ও তার সঙ্গীদেরকে স্বীয় অনুগ্রহে রক্ষা করলাম এবং যারা আমার আয়াতসমূহে মিথ্যারোপ করত তাদের মূল কেটে দিলাম। তারা মান্যকারী ছিল না।\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@mxxvii{সামুদ সম্প্রদায়ের কাছে প্রেরণ করেছি তাদের ভাই সালেহকে। সে বললঃ হে আমার সম্প্রদায়, তোমরা আল্লাহর এবাদত কর। তিনি ব্যতিত তোমাদের কোন উপাস্য নেই। তোমাদের কাছে তোমাদের প্রতিপালকের পক্ষ থেকে একটি প্রমাণ এসে গেছে। এটি আল্লাহর উষ্টী তোমাদের জন্যে প্রমাণ। অতএব একে ছেড়ে দাও, আল্লাহর ভুমিতে চড়ে বেড়াবে। একে অসৎভাবে স্পর্শ করবে না। অন্যথায় তোমাদেরকে যন্ত্রনাদায়ক শাস্তি পাকড়াও করবে।\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@mxxviii{তোমরা স্মরণ কর, যখন তোমাদেরকে আদ জাতির পরে সর্দার করেছেন; তোমাদেরকে পৃথিবীতে ঠিকানা দিয়েছেন। তোমরা নরম মাটিতে অট্টালিকা নির্মান কর এবং পর্বত গাত্র খনন করে প্রকোষ্ঠ নির্মাণ কর। অতএব আল্লাহর অনুগ্রহ স্মরণ কর এবং পৃথিবীতে অনর্থ সৃষ্টি করো না।\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@mxxix{তার সম্প্রদায়ের দাম্ভিক সর্দাররা ঈমানদার দারিদ্রদেরকে জিজ্ঞেস করলঃ তোমরা কি বিশ্বাস কর যে সালেহ কে তার পালনকর্তা প্রেরণ করেছেন; তারা বলল আমরা তো তার আনীত বিষয়ের প্রতি বিশ্বাসী।\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@mxxx{দাম্ভিকরা বললঃ তোমরা যে বিষয়ে বিশ্বাস স্থাপন করেছ, আমরা তাতে অস্বীকৃত।\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@mxxxi{অতঃপর তারা উষ্ট্রীকে হত্যা করল এবং স্বীয় প্রতিপালকের আদেশ অমান্য করল। তারা বললঃ হে ছালেহ, নিয়ে এস যদ্দ্বারা আমাদেরকে ভয় দেখাতে, যদি তুমি রসূল হয়ে থাক।\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@mxxxii{অতঃপর পাকড়াও করল তাদেরকে ভূমিকম্প। ফলে সকাল বেলায় নিজ নিজ গৃহে উপুড় হয়ে পড়ে রইল।\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@mxxxiii{ছালেহ তাদের কাছ থেকে প্রস্থান করলো এবং বললঃ হে আমার সম্প্রদায়, আমি তোমাদের কাছে স্বীয় প্রতিপালকের পয়গাম পৌছিয়েছি এবং তোমাদের মঙ্গল কামনা করেছি কিন্তু তোমরা মঙ্গলকাঙ্খীদেরকে ভালবাস না।\qt@no{(79)}}
\qt@newcmd\qurantrans@bn@mxxxiv{এবং আমি লূতকে প্রেরণ করেছি। যখন সে স্বীয় সম্প্রদায়কে বললঃ তোমরা কি এমন অশ্লীল কাজ করছ, যা তোমাদের পূর্বে সারা বিশ্বের কেউ করেনি ?\qt@no{(80)}}
\qt@newcmd\qurantrans@bn@mxxxv{তোমরা তো কামবশতঃ পুরুষদের কাছে গমন কর নারীদেরকে ছেড়ে। বরং তোমরা সীমা অতিক্রম করেছ।\qt@no{(81)}}
\qt@newcmd\qurantrans@bn@mxxxvi{তাঁর সম্প্রদায় এ ছাড়া কোন উত্তর দিল না যে, বের করে দাও এদেরকে শহর থেকে। এরা খুব সাধু থাকতে চায়।\qt@no{(82)}}
\qt@newcmd\qurantrans@bn@mxxxvii{অতঃপর আমি তাকে ও তাঁর পরিবার পরিজনকে বাঁচিয়ে দিলাম, কিন্তু তার স্ত্রী। সে তাদের মধ্যেই রয়ে গেল, যারা রয়ে গিয়েছিল। আমি তাদের উপর প্রস্তর বৃষ্টি বর্ষণ করলাম।\qt@no{(83)}}
\qt@newcmd\qurantrans@bn@mxxxviii{অতএব, দেখ গোনাহগারদের পরিণতি কেমন হয়েছে।\qt@no{(84)}}
\qt@newcmd\qurantrans@bn@mxxxix{আমি মাদইয়ানের প্রতি তাদের ভাই শোয়ায়েবকে প্রেরণ করেছি। সে বললঃ হে আমার সম্প্রদায়! তোমরা আল্লাহর এবাদত কর। তিনি ব্যতীত তোমাদের কোন উপাস্য নেই। তোমাদের কাছে তোমাদের প্রতিপালকের পক্ষ থেকে প্রমাণ এসে গেছে। অতএব তোমরা মাপ ও ওজন পূর্ন কর এবং মানুষকে তাদের দ্রব্যদি কম দিয়ো না এবং ভুপৃষ্টের সংস্কার সাধন করার পর তাতে অনর্থ সৃষ্টি করো না। এই হল তোমাদের জন্যে কল্যাণকর, যদি তোমরা বিশ্বাসী হও।\qt@no{(85)}}
\qt@newcmd\qurantrans@bn@mxl{তোমরা পথে ঘাটে এ কারণে বসে থেকো না যে, আল্লাহ বিশ্বাসীদেরকে হুমকি দিবে, আল্লাহর পথে বাধা সৃষ্টি করবে এবং তাতে বক্রতা অনুসন্ধান করবে। স্মরণ কর, যখন তোমরা সংখ্যায় অল্প ছিলে অতঃপর আল্লাহ তোমাদেরকে অধিক করেছেন এবং লক্ষ্য কর কিরূপ অশুভ পরিণতি হয়েছে অনর্থকারীদের।\qt@no{(86)}}
\qt@newcmd\qurantrans@bn@mxli{আর যদি তোমাদের একদল ঐ বিষয়ের প্রতি বিশ্বাস স্থাপন করে যা নিয়ে আমি প্রেরিত হয়েছি এবং একদল বিশ্বাস স্থাপন করে যা নিয়ে আমি প্রেরিত হয়েছি এবং একদল বিশ্বাস স্থাপন না করে, তবে ছবর কর যে পর্যন্ত আল্লাহ আমাদের মধ্যে মীমাংসা না করে দেন। তিনিই শ্রেষ্ট মীমাংসাকারী।\qt@no{(87)}}
\qt@newcmd\qurantrans@bn@mxlii{তার সম্প্রদায়ের দাম্ভিক সর্দাররা বললঃ হে শোয়ায়েব, আমরা অবশ্যই তোমাকে এবং তোমার সাথে বিশ্বাস স্থাপনকারীদেরকে শহর থেকে বের করে দেব অথবা তোমরা আমাদের ধর্মে প্রত্যাবর্তন করবে। শোয়ায়েব বললঃ আমরা অপছন্দ করলেও কি ?\qt@no{(88)}}
\qt@newcmd\qurantrans@bn@mxliii{আমরা আল্লাহর প্রতি মিথ্যা অপবাদকারী হয়ে যাব যদি আমরা তোমাদের ধর্মে প্রত্যাবর্তন করি, অথচ তিনি আমাদেরকে এ থেকে মুক্তি দিয়েছেন। আমাদের কাজ নয় এ ধর্মে প্রত্যাবর্তন করা, কিন্তু আমাদের প্রতি পালক আল্লাহ যদি চান। আমাদের প্রতিপালক প্রত্যেক বস্তুকে স্বীয় জ্ঞান দ্বারা বেষ্টন করে আছেন। আল্লাহর প্রতিই আমরা ভরসা করেছি। হে আমাদের প্রতিপালক আমাদের ও আমাদের সম্প্রদায়ের মধ্যে ফয়সালা করে ছিল যথার্থ ফয়সালা। আপনিই শ্রেষ্টতম ফসলা ফয়সালাকারী।\qt@no{(89)}}
\qt@newcmd\qurantrans@bn@mxliv{তার সম্প্রদায়ের কাফের সর্দাররা বললঃ যদি তোমরা শোয়ায়েবের অনুসরণ কর, তবে নিশ্চিতই ক্ষতিগ্রস্ত হবে।\qt@no{(90)}}
\qt@newcmd\qurantrans@bn@mxlv{অনন্তর পাকড়াও করল তাদেরকে ভূমিকম্প। ফলে তারা সকাল বেলায় গৃহ মধ্যে উপুড় হয়ে পড়ে রইল।\qt@no{(91)}}
\qt@newcmd\qurantrans@bn@mxlvi{শোয়ায়েবের প্রতি মিথ্যারোপকারীরা যেন কোন দিন সেখানে বসবাসই করেনি। যারা শোয়ায়েবের প্রতি মিথ্যারোপ করেছিল, তারাই ক্ষতিগ্রস্থ হল।\qt@no{(92)}}
\qt@newcmd\qurantrans@bn@mxlvii{অনন্তর সে তাদের কাছ থেকে প্রস্থান করল এবং বললঃ হে আমার সম্প্রদায়, আমি তোমাদেরকে প্রতিপালকের পয়গাম পৌছে দিয়েছি এবং তোমাদের হিত কামনা করেছি। এখন আমি কাফেরদের জন্যে কেন দুঃখ করব।\qt@no{(93)}}
\qt@newcmd\qurantrans@bn@mxlviii{আর আমি কোন জনপদে কোন নবী পাঠাইনি, তবে (এমতাবস্থায়) যে পাকড়াও করেছি সে জনপদের অধিবাসীদিগকে কষ্ট ও কঠোরতার মধ্যে, যাতে তারা শিথিল হয়ে পড়ে।\qt@no{(94)}}
\qt@newcmd\qurantrans@bn@mxlix{অতঃপর অকল্যাণের স্থলে তা কল্যাণে বদলে দিয়েছে। এমনকি তারা অনেক বেড়ে গিয়েছি এবং বলতে শুরু করেছে, আমাদের বাপ-দাদাদের উপরও এমন আনন্দ-বেদনা এসেছে। অতঃপর আমি তাদেরকে পাকড়াও করেছি এমন আকস্মিকভাবে যে তারা টেরও পায়নি।\qt@no{(95)}}
\qt@newcmd\qurantrans@bn@ml{আর যদি সে জনপদের অধিবাসীরা ঈমান আনত এবং পরহেযগারী অবলম্বন করত, তবে আমি তাদের প্রতি আসমানী ও পার্থিব নেয়ামত সমূহ উম্মুক্ত করে দিতাম। কিন্তু তারা মিথ্যা প্রতিপন্ন করেছে। সুতরাং আমি তাদেরকে পাকড়াও করেছি তাদের কৃতকর্মের বদলাতে।\qt@no{(96)}}
\qt@newcmd\qurantrans@bn@mli{এখনও কি এই জনপদের অধিবাসীরা এ ব্যাপারে নিশ্চিন্ত যে, আমার আযাব তাদের উপর রাতের বেলায় এসে পড়বে অথচ তখন তারা থাকবে ঘুমে অচেতন।\qt@no{(97)}}
\qt@newcmd\qurantrans@bn@mlii{আর এই জনপদের অধিবাসীরা কি নিশ্চিন্ত হয়ে পড়েছে যে, তাদের উপর আমার আযাব দিনের বেলাতে এসে পড়বে অথচ তারা তখন থাকবে খেলা-ধুলায় মত্ত।\qt@no{(98)}}
\qt@newcmd\qurantrans@bn@mliii{তারা কি আল্লাহর পাকড়াওয়ের ব্যাপারে নিশ্চিন্ত হয়ে গেছে? বস্তুতঃ আল্লাহর পাকড়াও থেকে তারাই নিশ্চিন্ত হতে পারে, যাদের ধ্বংস ঘনিয়ে আসে।\qt@no{(99)}}
\qt@newcmd\qurantrans@bn@mliv{তাদের নিকট কি একথা প্রকাশিত হয়নি, যারা উত্তারাধিকার লাভ করেছে। সেখানকার লোকদের ধ্বংসপ্রাপ্ত হবার পর যদি আমি ইচ্ছা করতাম, , তবে তাদেরকে তাদের পাপের দরুন পাকড়াও করে ফেলতাম। বস্তুতঃ আমি মোহর এঁটে দিয়েছি তাদের অন্তরসমূহের উপর। কাজেই এরা শুনতে পায় না।\qt@no{(100)}}
\qt@newcmd\qurantrans@bn@mlv{এগুলো হল সে সব জনপদ যার কিছু বিবরণ আমি আপনাকে অবহিত করছি। আর নিশ্চিতই ওদের কাছে পৌছেছিলেন রসূল নিদর্শন সহকারে। অতঃপর কস্মিনকালও এরা ঈমান আনবার ছিল না, তারপরে যা তার ইতিপূর্বে মিথ্যা বলে প্রতিপন্ন করেছে। এভাবেই আল্লাহ কাফেরদের অন্তরে মোহর এঁটে দেন।\qt@no{(101)}}
\qt@newcmd\qurantrans@bn@mlvi{আর তাদের অধিকাংশ লোককেই আমি প্রতিজ্ঞা বাস্তবায়নকারীরূপে পাইনি; বরং তাদের অধিকাংশকে পেয়েছি হুকুম অমান্যকারী।\qt@no{(102)}}
\qt@newcmd\qurantrans@bn@mlvii{অতঃপর আমি তাদের পরে মূসাকে পাঠিয়েছি নিদর্শনাবলী দিয়ে ফেরাউন ও তার সভাসদদের নিকট। বস্তুতঃ ওরা তাঁর মোকাবেলায় কুফরী করেছে। সুতরাং চেয়ে দেখ, কি পরিণতি হয়েছে অনাচারীদের।\qt@no{(103)}}
\qt@newcmd\qurantrans@bn@mlviii{আর মূসা বললেন, হে ফেরাউন, আমি বিশ্ব-পালনকর্তার পক্ষ থেকে আগত রসূল।\qt@no{(104)}}
\qt@newcmd\qurantrans@bn@mlix{আল্লাহর পক্ষ থেকে যে সত্য এসেছে, তার ব্যতিক্রম কিছু না বলার ব্যাপারে আমি সুদৃঢ়। আমি তোমাদের পরওয়ারদেগারের নিদর্শন নিয়ে এসেছি। সুতরাং তুমি বনী ইসরাঈলদেরকে আমার সাথে পাঠিয়ে দাও।\qt@no{(105)}}
\qt@newcmd\qurantrans@bn@mlx{সে বলল, যদি তুমি কোন নিদর্শন নিয়ে এসে থাক, তাহলে তা উপস্থিত কর যদি তুমি সত্যবাদী হয়ে থাক।\qt@no{(106)}}
\qt@newcmd\qurantrans@bn@mlxi{তখন তিনি নিক্ষেপ করলেন নিজের লাঠিখানা এবং তাৎক্ষণাৎ তা জলজ্যান্ত এক অজগরে রূপান্তরিত হয়ে গেল।\qt@no{(107)}}
\qt@newcmd\qurantrans@bn@mlxii{আর বের করলেন নিজের হাত এবং তা সঙ্গে সঙ্গে দর্শকদের চোখে ধবধবে উজ্জ্বল দেখাতে লাগল।\qt@no{(108)}}
\qt@newcmd\qurantrans@bn@mlxiii{ফেরাউনের সাঙ্গ-পাঙ্গরা বলতে লাগল, নিশ্চয় লোকটি বিজ্ঞ-যাদুকর।\qt@no{(109)}}
\qt@newcmd\qurantrans@bn@mlxiv{সে তোমাদিগকে তোমাদের দেশ থেকে বের করে দিতে চায়। এ ব্যাপারে তোমাদের কি মত?\qt@no{(110)}}
\qt@newcmd\qurantrans@bn@mlxv{তারা বলল, আপনি তাকে ও তার ভাইকে অবকাশ দান করুন এবং শহরে বন্দরে লোক পাঠিয়ে দিন লোকদের সমবেত করার জন্য।\qt@no{(111)}}
\qt@newcmd\qurantrans@bn@mlxvi{যাতে তারা পরাকাষ্ঠাসম্পন্ন বিজ্ঞ যাদুকরদের এনে সমবেত করে।\qt@no{(112)}}
\qt@newcmd\qurantrans@bn@mlxvii{বস্তুতঃ যাদুকররা এসে ফেরাউনের কাছে উপস্থিত হল। তারা বলল, আমাদের জন্যে কি কোন পারিশ্রমিক নির্ধারিত আছে, যদি আমরা জয়লাভ করি?\qt@no{(113)}}
\qt@newcmd\qurantrans@bn@mlxviii{সে বলল, হ্যাঁ এবং অবশ্যই তোমরা আমার নিকটবর্তী লোক হয়ে যাবে।\qt@no{(114)}}
\qt@newcmd\qurantrans@bn@mlxix{তারা বলল, হে মূসা! হয় তুমি নিক্ষেপ কর অথবা আমরা নিক্ষেপ করছি।\qt@no{(115)}}
\qt@newcmd\qurantrans@bn@mlxx{তিনি বললেন, তোমরাই নিক্ষেপ কর। যখন তারা নিক্ষেপ করল তখন লোকদের চোখগুলোকে বাধিয়ে দিল, ভীত-সন্ত্রস্ত করে তুলল এবং মহাযাদু প্রদর্শন করল।\qt@no{(116)}}
\qt@newcmd\qurantrans@bn@mlxxi{তারপর আমি ওহীযোগে মূসাকে বললাম, এবার নিক্ষেপ কর তোমার লাঠিখানা। অতএব সঙ্গে সঙ্গে তা সে সমুদয়কে গিলতে লাগল, যা তারা বানিয়েছিল যাদু বলে।\qt@no{(117)}}
\qt@newcmd\qurantrans@bn@mlxxii{সুতরাং এভাবে প্রকাশ হয়ে গেল সত্য বিষয় এবং ভুল প্রতিপন্ন হয়ে গেল যা কিছু তারা করেছিল।\qt@no{(118)}}
\qt@newcmd\qurantrans@bn@mlxxiii{সুতরাং তারা সেখানেই পরাজিত হয়ে গেল এবং অতীব লাঞ্ছিত হল।\qt@no{(119)}}
\qt@newcmd\qurantrans@bn@mlxxiv{এবং যাদুকররা সেজদায় পড়ে গেল।\qt@no{(120)}}
\qt@newcmd\qurantrans@bn@mlxxv{বলল, আমরা ঈমান আনছি মহা বিশ্বের পরওয়ারদেগারের প্রতি।\qt@no{(121)}}
\qt@newcmd\qurantrans@bn@mlxxvi{যিনি মূসা ও হারুনের পরওয়ারদেগার।\qt@no{(122)}}
\qt@newcmd\qurantrans@bn@mlxxvii{ফেরাউন বলল, তোমরা কি (তাহলে) আমার অনুমতি দেয়ার আগেই ঈমান আনলে! এটা প্রতারণা, যা তোমরা এ নগরীতে প্রদর্শন করলে। যাতে করে এ শহরের অধিবাসীদিগকে শহর থেকে বের করে দিতে পার। সুতরাং তোমরা শীঘ্রই বুঝতে পারবে।\qt@no{(123)}}
\qt@newcmd\qurantrans@bn@mlxxviii{অবশ্যই আমি কেটে দেব তোমাদের হাত ও পা বিপরীত দিক থেকে। তারপর তোমাদের সবাইকে শূলীতে চড়িয়ে মারব।\qt@no{(124)}}
\qt@newcmd\qurantrans@bn@mlxxix{তারা বলল, আমাদেরকে তো মৃত্যুর পর নিজেদের পরওয়ারদেগারের নিকট ফিরে যেতেই হবে।\qt@no{(125)}}
\qt@newcmd\qurantrans@bn@mlxxx{বস্তুতঃ আমাদের সাথে তোমার শত্রুতা তো এ কারণেই যে, আমরা ঈমান এনেছি আমাদের পরওয়ারদেগারের নিদর্শনসমূহের প্রতি যখন তা আমাদের নিকট পৌঁছেছে। হে আমাদের পরওয়ারদেগার আমাদের জন্য ধৈর্য্যের দ্বার খুলে দাও এবং আমাদেরকে মুসলমান হিসাবে মৃত্যু দান কর।\qt@no{(126)}}
\qt@newcmd\qurantrans@bn@mlxxxi{ফেরাউনের সম্প্রদায়ের র্সদাররা বলল, তুমি কি এমনি ছেড়ে দেবে মূসা ও তার সম্প্রদায়কে। দেশময় হৈ-চৈ করার জন্য এবং তোমাকে ও তোমার দেব-দেবীকে বাতিল করে দেবার জন্য। সে বলল, আমি এখনি হত্যা করব তাদের পুত্র সন্তানদিগকে; আর জীবিত রাখব মেয়েদেরকে। বস্তুতঃ আমরা তাদের উপর প্রবল।\qt@no{(127)}}
\qt@newcmd\qurantrans@bn@mlxxxii{মূসা বললেন তার কওমকে, সাহায্য প্রার্থনা কর আল্লাহর নিকট এবং ধৈর্য্য ধারণ কর। নিশ্চয়ই এ পৃথিবী আল্লাহর। তিনি নিজের বান্দাদের মধ্যে যাকে ইচ্ছা এর উত্তরাধিকারী বানিয়ে দেন এবং শেষ কল্যাণ মুত্তাকীদের জন্যই নির্ধারিত রয়েছে।\qt@no{(128)}}
\qt@newcmd\qurantrans@bn@mlxxxiii{তারা বলল, আমাদের কষ্ট ছিল তোমার আসার পূর্বে এবং তোমার আসার পরে। তিনি বললেন, তোমাদের পরওয়ারদেগার শীঘ্রই তোমাদের শক্রদের ধ্বংস করে দেবেন এবং তোমাদেরকে দেশে প্রতিনিধিত্ব দান করবেন। তারপর দেখবেন, তোমরা কেমন কাজ কর।\qt@no{(129)}}
\qt@newcmd\qurantrans@bn@mlxxxiv{তারপর আমি পাকড়াও করেছি-ফেরাউনের অনুসারীদেরকে দুর্ভিক্ষের মাধ্যমে এবং ফল ফসলের ক্ষয়-ক্ষতির মাধ্যমে যাতে করে তারা উপদেশ গ্রহণ করে।\qt@no{(130)}}
\qt@newcmd\qurantrans@bn@mlxxxv{অতঃপর যখন শুভদিন ফিরে আসে, তখন তারা বলতে আরম্ভ করে যে, এটাই আমাদের জন্য উপযোগী। আর যদি অকল্যাণ এসে উপস্থিত হয় তবে তাতে মূসার এবং তাঁর সঙ্গীদের অলক্ষণ বলে অভিহিত করে। শুনে রাখ তাদের অলক্ষণ যে, আল্লাহরই এলেমে রয়েছে, অথচ এরা জানে না।\qt@no{(131)}}
\qt@newcmd\qurantrans@bn@mlxxxvi{তারা আরও বলতে লাগল, আমাদের উপর জাদু করার জন্য তুমি যে নিদর্শনই নিয়ে আস না কেন আমরা কিন্তু তোমার উপর ঈমান আনছি না।\qt@no{(132)}}
\qt@newcmd\qurantrans@bn@mlxxxvii{সুতরাং আমি তাদের উপর পাঠিয়ে দিলাম তুফান, পঙ্গপাল, উকুন, ব্যাঙ ও রক্ত প্রভৃতি বহুবিধ নিদর্শন একের পর এক। তারপরেও তারা গর্ব করতে থাকল। বস্তুতঃ তারা ছিল অপরাধপ্রবণ।\qt@no{(133)}}
\qt@newcmd\qurantrans@bn@mlxxxviii{আর তাদের উপর যখন কোন আযাব পড়ে তখন বলে, হে মূসা আমাদের জন্য তোমার পরওয়ারদেগারের নিকট সে বিষয়ে দোয়া কর যা তিনি তোমার সাথে ওয়াদা করে রেখেছেন। যদি তুমি আমাদের উপর থেকে এ আযাব সরিয়ে দাও, তবে অবশ্যই আমরা ঈমান আনব তোমার উপর এবং তোমার সাথে বনী-ইসরাঈলদেরকে যেতে দেব।\qt@no{(134)}}
\qt@newcmd\qurantrans@bn@mlxxxix{অতঃপর যখন আমি তাদের উপর থেকে আযাব তুলে নিতাম নির্ধারিত একটি সময় পর্যন্ত-যেখান পর্যন্ত তাদেরকে পৌছানোর উদ্দেশ্য ছিল, তখন তড়িঘড়ি তারা প্রতিশ্রুতি ভঙ্গ করত।\qt@no{(135)}}
\qt@newcmd\qurantrans@bn@mxc{সুতরাং আমি তাদের কাছে থেকে বদলা নিয়ে নিলাম-বস্তুতঃ তাদেরকে সাগরে ডুবিয়ে দিলাম। কারণ, তারা মিথ্যা প্রতিপন্ন করেছিল আমার নিদর্শনসমূহকে এবং তৎপ্রতি অনীহা প্রদর্শন করেছিল।\qt@no{(136)}}
\qt@newcmd\qurantrans@bn@mxci{আর যাদেরকে দুর্বল মনে করা হত তাদেরকেও আমি উত্তরাধিকার দান করেছি এ ভুখন্ডের পূর্ব ও পশ্চিম অঞ্চলের যাতে আমি বরকত সন্নিহিত রেখেছি এবং পরিপূর্ণ হয়ে গেছে তোমার পালনকর্তার প্রতিশ্রুত কল্যাণ বনী-ইসরাঈলদের জন্য তাদের ধৈর্য্যধারণের দরুন। আর ধ্বংস করে দিয়েছে সে সবকিছু যা তৈরী করেছিল ফেরাউন ও তার সম্প্রদায় এবং ধ্বংস করেছি যা কিছু তারা সুউচ্চ নির্মাণ করেছিল।\qt@no{(137)}}
\qt@newcmd\qurantrans@bn@mxcii{বস্তুতঃ আমি সাগর পার করে দিয়েছি বনী-ইসরাঈলদিগকে। তখন তারা এমন এক সম্প্রদায়ের কাছে গিয়ে পৌছাল, যারা স্বহস্তনির্মিত মূর্তিপুজায় নিয়োজিত ছিল। তারা বলতে লাগল, হে মূসা; আমাদের উপাসনার জন্যও তাদের মূর্তির মতই একটি মূর্তি নির্মাণ করে দিন। তিনি বললেন, তোমাদের মধ্যে বড়ই অজ্ঞতা রয়েছে।\qt@no{(138)}}
\qt@newcmd\qurantrans@bn@mxciii{এরা যে, কাজে নিয়োজিত রয়েছে তা ধ্বংস হবে এবং যা কিছু তারা করেছে তা যে ভুল!\qt@no{(139)}}
\qt@newcmd\qurantrans@bn@mxciv{তিনি বললেন, তাহলে কি আল্লাহকে ছাড়া তোমাদের জন্য অন্য কোন উপাস্য অনুসন্ধান করব, অথচ তিনিই তোমাদিগকে সারা বিশ্বে শ্রেষ্ঠত্ব দান করেছেন।\qt@no{(140)}}
\qt@newcmd\qurantrans@bn@mxcv{আর সে সময়ের কথা স্মরণ কর, যখন আমি তোমাদেরকে ফেরাউনের লোকদের কবল থেকে মুক্তি দিয়েছি; তারা তোমাদেরকে দিত নিকৃষ্ট শাস্তি, তোমাদের পুত্র-সন্তানদের মেরে ফেলত এবং মেয়েদের বাঁচিয়ে রাখত। এতে তোমাদের প্রতি তোমাদের পরওয়ারদেগারের বিরাট পরীক্ষা রয়েছে।\qt@no{(141)}}
\qt@newcmd\qurantrans@bn@mxcvi{আর আমি মূসাকে প্রতিশ্রুতি দিয়েছি ত্রিশ রাত্রির এবং সেগুলোকে পূর্ন করেছি আরো দশ দ্বারা। বস্তুতঃ এভাবে চল্লিশ রাতের মেয়াদ পূর্ণ হয়ে গেছে। আর মূসা তাঁর ভাই হারুনকে বললেন, আমার সম্প্রদায়ে তুমি আমার প্রতিনিধি হিসাবে থাক। তাদের সংশোধন করতে থাক এবং হাঙ্গামা সৃষ্টিকারীদের পথে চলো না।\qt@no{(142)}}
\qt@newcmd\qurantrans@bn@mxcvii{তারপর মূসা যখন আমার প্রতিশ্রুত সময় অনুযায়ী এসে হাযির হলেন এবং তাঁর সাথে তার পরওয়ারদেগার কথা বললেন, তখন তিনি বললেন, হে আমার প্রভু, তোমার দীদার আমাকে দাও, যেন আমি তোমাকে দেখতে পাই। তিনি বললেন, তুমি আমাকে কস্মিনকালেও দেখতে পাবে না, তবে তুমি পাহাড়ের দিকে দেখতে থাক, সেটি যদি স্বস্থানে দঁড়িয়ে থাকে তবে তুমিও আমাকে দেখতে পাবে। তারপর যখন তার পরওয়ারদগার পাহাড়ের উপর আপন জ্যোতির বিকিরণ ঘটালেন, সেটিকে বিধ্বস্ত করে দিলেন এবং মূসা অজ্ঞান হয়ে পড়ে গেলেন। অতঃপর যখন তাঁর জ্ঞান ফিরে এল; বললেন, হে প্রভু! তোমার সত্তা পবিত্র, তোমার দরবারে আমি তওবা করছি এবং আমিই সর্বপ্রথম বিশ্বাস স্থাপন করছি।\qt@no{(143)}}
\qt@newcmd\qurantrans@bn@mxcviii{(পরওয়ারদেগার) বললেন, হে মূসা, আমি তোমাকে আমার বার্তা পাঠানোর এবং কথা বলার মাধ্যমে লোকদের উপর বিশিষ্টতা দান করেছি। সুতরাং যা কিছু আমি তোমাকে দান করলাম, গ্রহণ কর এবং কৃতজ্ঞ থাক।\qt@no{(144)}}
\qt@newcmd\qurantrans@bn@mxcix{আর আমি তোমাকে পটে লিখে দিয়েছি সর্বপ্রকার উপদেশ ও বিস্তারিত সব বিষয়। অতএব, এগুলোকে দৃঢ়ভাবে ধারণ কর এবং স্বজাতিকে এর কল্যাণকর বিষয়সমূহ দৃঢ়তার সাথে পালনের নির্দেশ দাও।\qt@no{(145)}}
\qt@newcmd\qurantrans@bn@mc{আমি আমার নিদর্শনসমূহ হতে তাদেরকে ফিরিয়ে রাখি, যারা পৃথিবীতে অন্যায়ভাবে গর্ব করে। যদি তারা সমস্ত নিদর্শন প্রত্যক্ষ করে ফেলে, তবুও তা বিশ্বাস করবে না। আর যদি হেদায়েতের পথ দেখে, তবে সে পথ গ্রহণ করে না। অথচ গোমরাহীর পথ দেখলে তাই গ্রহণ করে নেয়। এর কারণ, তারা আমার নিদর্শনসমূহকে মিথ্যা বলে মনে করেছে এবং তা থেকে বেখবর রয়ে গেছে।\qt@no{(146)}}
\qt@newcmd\qurantrans@bn@mci{বস্তুতঃ যারা মিথ্যা জেনেছে আমার আয়াতসমূকে এবং আখেরাতের সাক্ষাতকে, তাদের যাবতীয় কাজকর্ম ধ্বংস হয়ে গেছে। তেমন বদলাই সে পাবে যেমন আমল করত।\qt@no{(147)}}
\qt@newcmd\qurantrans@bn@mcii{আর বানিয়ে নিল মূসার সম্প্রদায় তার অনুপস্থিতিতে নিজেদের অলংকারাদির দ্বারা একটি বাছুর তা থেকে বেরুচ্ছিল ‘হাম্বা হাম্বা’ শব্দ। তারা কি একথাও লক্ষ্য করল না যে, সেটি তাদের সাথে কথাও বলছে না এবং তাদেরকে কোন পথও বাতলে দিচ্ছে না! তারা সেটিকে উপাস্য বানিয়ে নিল। বস্তুতঃ তারা ছিল জালেম।\qt@no{(148)}}
\qt@newcmd\qurantrans@bn@mciii{অতঃপর যখন তারা অনুতপ্ত হল এবং বুঝতে পারল যে, আমরা নিশ্চিতই গোমরাহ হয়ে পড়েছি, তখন বলতে লাগল, আমাদের প্রতি যদি আমাদের পরওয়ারদেগার করুণা না করেন, তবে অবশ্যই আমরা ধবংস হয়ে যাব।\qt@no{(149)}}
\qt@newcmd\qurantrans@bn@mciv{তারপর যখন মূসা নিজ সম্প্রদায়ে ফিরে এলেন রাগাম্বিত ও অনুতপ্ত অবস্থায়, তখন বললেন, আমার অনুপস্থিতিতে তোমরা আমার কি নিকৃষ্ট প্রতিনিধিত্বটাই না করেছ। তোমরা নিজ পরওয়ারদেগারের হুকুম থেকে কি তাড়াহুড়া করে ফেললে এবং সে তখতীগুলো ছুঁড়ে ফেলে দিলেন এবং নিজের ভাইয়ের মাথার চুল চেপে ধরে নিজের দিকে টানতে লাগলেন। ভাই বললেন, হে আমার মায়ের পুত্র, লোকগুলো যে আমাকে দুর্বল মনে করল এবং আমাকে যে মেরে ফেলার উপক্রম করেছিল। সুতরাং আমার উপর আর শত্রুদের হাসিও না। আর আমাকে জালিমদের সারিতে গন্য করো না।\qt@no{(150)}}
\qt@newcmd\qurantrans@bn@mcv{মূসা বললেন, হে আমার পরওয়ারদেগার, ক্ষমা কর আমাকে আর আমার ভাইকে এবং আমাদেরকে তোমার রহমতের অন্তর্ভুক্ত কর। তুমি যে সর্বাধিক করুণাময়।\qt@no{(151)}}
\qt@newcmd\qurantrans@bn@mcvi{অবশ্য যারা গোবৎসকে উপাস্য বানিয়ে নিয়েছে, তাদের উপর তাদের পরওয়ারদেগারের পক্ষ থেকে পার্থিব এ জীবনেই গযব ও লাঞ্জনা এসে পড়বে। এমনি আমি অপবাদ আরোপকারীদেরকে শাস্তি দিয়ে থাকি।\qt@no{(152)}}
\qt@newcmd\qurantrans@bn@mcvii{আর যারা মন্দ কাজ করে, তারপরে তওবা করে নেয় এবং ঈমান নিয়ে আসে, তবে নিশ্চয়ই তোমার পরওয়ারদেগার তওবার পর অবশ্য ক্ষমাকারী, করুণাময়।\qt@no{(153)}}
\qt@newcmd\qurantrans@bn@mcviii{তারপর যখন মূসার রাগ পড়ে গেল, তখন তিনি তখতীগুলো তুলে নিলেন। আর যা কিছু তাতে লেখা ছিল, তা ছিল সে সমস্ত লোকের জন্য হেদায়েত ও রহমত যারা নিজেদের পরওয়ারদেগারকে ভয় করে।\qt@no{(154)}}
\qt@newcmd\qurantrans@bn@mcix{আর মূসা বেছে নিলেন নিজের সম্প্রদায় থেকে সত্তর জন লোক আমার প্রতিশ্রুত সময়ের জন্য। তারপর যখন তাদেরকে ভূমিকম্প পাকড়াও করল, তখন বললেন, হে আমার পরওয়ারদেগার, তুমি যদি ইচ্ছা করতে, তবে তাদেরকে আগেই ধ্বংস করে দিতে এবং আমাকেও। আমাদেরকে কি সে কর্মের কারণে ধ্বংস করছ, যা আমার সম্প্রদায়ের নির্বোধ লোকেরা করেছে? এসবই তোমার পরীক্ষা; তুমি যাকে ইচ্ছা এতে পথ ভ্রষ্ট করবে এবং যাকে ইচ্ছা সরলপথে রাখবে। তুমি যে আমাদের রক্ষক-সুতরাং আমাদেরকে ক্ষমা করে দাও এবং আমাদের উপর করুনা কর। তাছাড়া তুমিই তো সর্বাধিক ক্ষমাকারী।\qt@no{(155)}}
\qt@newcmd\qurantrans@bn@mcx{আর পৃথিবীতে এবং আখেরাতে আমাদের জন্য কল্যাণ লিখে দাও। আমরা তোমার দিকে প্রত্যাবর্তন করছি। আল্লাহ তা’আলা বললেন, আমার আযাব তারই উপর পরিব্যাপ্ত। সুতরাং তা তাদের জন্য লিখে দেব যারা ভয় রাখে, যাকাত দান করে এবং যারা আমার আয়তসমুহের উপর বিশ্বাস স্থাপন করে।\qt@no{(156)}}
\qt@newcmd\qurantrans@bn@mcxi{সেসমস্ত লোক, যারা আনুগত্য অবলম্বন করে এ রসূলের, যিনি উম্মী নবী, যাঁর সম্পর্কে তারা নিজেদের কাছে রক্ষিত তওরাত ও ইঞ্জিলে লেখা দেখতে পায়, তিনি তাদেরকে নির্দেশ দেন সৎকর্মের, বারণ করেন অসৎকর্ম থেকে; তাদের জন্য যাবতীয় পবিত্র বস্তু হালাল ঘোষনা করেন ও নিষিদ্ধ করেন হারাম বস্তুসমূহ এবং তাদের উপর থেকে সে বোঝা নামিয়ে দেন এবং বন্দীত্ব অপসারণ করেন যা তাদের উপর বিদ্যমান ছিল। সুতরাং যেসব লোক তাঁর উপর ঈমান এনেছে, তাঁর সাহচর্য অবলম্বন করেছে, তাঁকে সাহায্য করেছে এবং সে নূরের অনুসরণ করেছে যা তার সাথে অবতীর্ণ করা হয়েছে, শুধুমাত্র তারাই নিজেদের উদ্দেশ্য সফলতা অর্জন করতে পেরেছে।\qt@no{(157)}}
\qt@newcmd\qurantrans@bn@mcxii{বলে দাও, হে মানব মন্ডলী। তোমাদের সবার প্রতি আমি আল্লাহ প্রেরিত রসূল, সমগ্র আসমান ও যমীনে তার রাজত্ব। একমাত্র তাঁকে ছাড়া আর কারো উপাসনা নয়। তিনি জীবন ও মৃত্যু দান করেন। সুতরাং তোমরা সবাই বিশ্বাস স্থাপন করো আল্লাহর উপর তাঁর প্রেরিত উম্মী নবীর উপর, যিনি বিশ্বাস রাখেন আল্লাহর এবং তাঁর সমস্ত কালামের উপর। তাঁর অনুসরণ কর যাতে সরল পথপ্রাপ্ত হতে পার।\qt@no{(158)}}
\qt@newcmd\qurantrans@bn@mcxiii{বস্তুতঃ মূসার সম্প্রদায়ে একটি দল রয়েছে যারা সত্যপথ নির্দেশ করে এবং সে মতেই বিচার করে থাকে।\qt@no{(159)}}
\qt@newcmd\qurantrans@bn@mcxiv{আর আমি পৃথক পৃথক করে দিয়েছি তাদের বার জন পিতামহের সন্তানদেরকে বিরাট বিরাট দলে, এবং নির্দেশ দিয়েছি মুসাকে, যখন তার কাছে তার সম্প্রদায় পানি চাইল যে, স্বীয় যষ্টির দ্বারা আঘাত কর এ পাথরের উপর। অতঃপর এর ভেতর থেকে ফুটে বের হল বারটি প্রস্রবণ। প্রতিটি গোত্র চিনে নিল নিজ নিজ ঘাঁটি। আর আমি ছায়া দান করলাম তাদের উপর মেঘের এবং তাদের জন্য অবতীর্ন করলাম মান্না ও সালওয়া। যে পরিচ্ছন্ন বস্তুত জীবিকারূপে আমি তোমাদের দিয়েছি, তা থেকে তোমরা ভক্ষণ কর। বস্তুতঃ তারা আমার কোন ক্ষতি করেনি, বরং ক্ষতি করেছে নিজেদেরই।\qt@no{(160)}}
\qt@newcmd\qurantrans@bn@mcxv{আর যখন তাদের প্রতি নির্দেশ হল যে, তোমরা এ নগরীতে বসবাস কর এবং খাও তা থেকে যেখান থেকে ইচ্ছা এবং বল, আমাদের ক্ষমা করুন। আর দরজা দিয়ে প্রবেশ কর প্রণত অবস্থায়। তবে আমি ক্ষমা করে দেব তোমাদের পাপসমুহ। অবশ্য আমি সৎকর্মীদিগকে অতিরিক্ত দান করব।\qt@no{(161)}}
\qt@newcmd\qurantrans@bn@mcxvi{অনন্তর জালেমরা এতে অন্য শব্দ বদলে দিল তার পরিবর্তে, যা তাদেরকে বলা হয়েছিল। সুতরাং আমি তাদের উপর আযাব পাঠিয়েছি আসমান থেকে তাদের অপকর্মের কারণে।\qt@no{(162)}}
\qt@newcmd\qurantrans@bn@mcxvii{আর তাদের কাছে সে জনপদের অবস্থা সম্পর্কে জিজ্ঞেস কর যা ছিল নদীর তীরে অবস্থিত। যখন শনিবার দিনের নির্দেশের ব্যাপারে সীমাতিক্রম করতে লাগল, যখন আসতে লাগল মাছগুলো তাদের কাছে শনিবার দিন পানির উপর, আর যেদিন শনিবার হত না, আসত না। এভাবে আমি তাদেরকে পরীক্ষা করেছি। কারণ, তারা ছিল নাফরমান।\qt@no{(163)}}
\qt@newcmd\qurantrans@bn@mcxviii{আর যখন তাদের মধ্যে থেকে এক সম্প্রদায় বলল, কেন সে লোকদের সদুপদেশ দিচ্ছেন, যাদেরকে আল্লাহ ধ্বংস করে দিতে চান কিংবা আযাব দিতে চান কঠিন আযাব? সে বললঃ তোমাদের পালনকর্তার সামনে দোষ ফুরাবার জন্য এবং এজন্য যেন তারা ভীত হয়।\qt@no{(164)}}
\qt@newcmd\qurantrans@bn@mcxix{অতঃপর যখন তারা সেসব বিষয় ভুলে গেল, যা তাদেরকে বোঝানো হয়েছিল, তখন আমি সেসব লোককে মুক্তি দান করলাম যারা মন্দ কাজ থেকে বারণ করত। আর পাকড়াও করলাম, গোনাহগারদেরকে নিকৃষ্ট আযাবের মাধ্যমে তাদের না-ফরমানীর দরুন।\qt@no{(165)}}
\qt@newcmd\qurantrans@bn@mcxx{তারপর যখন তারা এগিয়ে যেতে লাগল সে কর্মে যা থেকে তাদের বারণ করা হয়েছিল, তখন আমি নির্দেশ দিলাম যে, তোমরা লাঞ্ছিত বানর হয়ে যাও।\qt@no{(166)}}
\qt@newcmd\qurantrans@bn@mcxxi{আর সে সময়ের কথা স্মরণ কর, যখন তোমার পালনকর্তা সংবাদ দিয়েছেন যে, অবশ্যই কেয়ামত দিবস পর্যন্ত ইহুদীদের উপর এমন লোক পাঠাতে থাকবেন যারা তাদেরকে নিকৃষ্ট শাস্তি দান করতে থাকবে। নিঃসন্দেহে তোমার পালনকর্তা শীঘ্র শাস্তি দানকারী এবং তিনি ক্ষমাশীল, দয়ালু।\qt@no{(167)}}
\qt@newcmd\qurantrans@bn@mcxxii{আর আমি তাদেরকে বিভক্ত করে দিয়েছি দেশময় বিভিন্ন শ্রেনীতে, তাদের মধ্যে কিছু রয়েছে ভাল আর কিছু রয়েছে অন্য রকম! তাছাড়া আমি তাদেরকে পরীক্ষা করেছি ভাল ও মন্দের মাধ্যমে যাতে তারা ফিরে আসে।\qt@no{(168)}}
\qt@newcmd\qurantrans@bn@mcxxiii{তারপর তাদের পেছনে এসেছে কিছু অপদার্থ, যারা উত্তরাধিকারী হয়েছে কিতাবের; তারা নিকৃষ্ট পার্থিব উপকরণ আহরণ করছে এবং বলছে, আমাদের ক্ষমা করে দেয়া হবে। বস্তুতঃ এমনি ধরনের উপকরণ যদি আবারো তাদের সামনে উপস্থিত হয়, তবে তাও তুলে নেবে। তাদের কাছথেকে কিতাবে কি অঙ্গীকার নেয়া হয়নি যে, আল্লাহর প্রতি সত্য ছাড়া কিছু বলবে না? অথচ তারা সে সবই পাঠ করেছে, যা তাতে লেখা রয়েছে। বস্তুতঃ আখেরাতের আলয় ভীতদের জন্য উত্তম-তোমরা কি তা বোঝ না ?\qt@no{(169)}}
\qt@newcmd\qurantrans@bn@mcxxiv{আর যেসব লোক সুদৃঢ়ভাবে কিতাবকে আঁকড়ে থাকে এবং নামায প্রতিষ্ঠা করে নিশ্চয়ই আমি বিনষ্ট করব না সৎকর্মীদের সওয়াব।\qt@no{(170)}}
\qt@newcmd\qurantrans@bn@mcxxv{আর যখন আমি তুলে ধরলাম পাহাড়কে তাদের উপরে সামিয়ানার মত এবং তারা ভয় করতে লাগল যে, সেটি তাদের উপর পড়বে, তখন আমি বললাম, ধর, যা আমি তোমাদের দিয়েছি, দৃঢ়ভাবে এবং স্মরণ রেখো যা তাতে রয়েছে, যেন তোমরা বাঁচতে পার।\qt@no{(171)}}
\qt@newcmd\qurantrans@bn@mcxxvi{আর যখন তোমার পালনকর্তা বনী আদমের পৃষ্টদেশ থেকে বের করলেন তাদের সন্তানদেরকে এবং নিজের উপর তাদেরকে প্রতিজ্ঞা করালেন, আমি কি তোমাদের পালনকর্তা নই ? তারা বলল, অবশ্যই, আমরা অঙ্গীকার করছি। আবার না কেয়ামতের দিন বলতে শুরু কর যে, এ বিষয়টি আমাদের জানা ছিল না।\qt@no{(172)}}
\qt@newcmd\qurantrans@bn@mcxxvii{অথবা বলতে শুরু কর যে, অংশীদারিত্বের প্রথা তো আমাদের বাপ-দাদারা উদ্ভাবন করেছিল আমাদের পূর্বেই। আর আমরা হলাম তাদের পশ্চাৎবর্তী সন্তান-সন্ততি। তাহলে কি সে কর্মের জন্য আমাদেরকে ধ্বংস করবেন, যা পথভ্রষ্টরা করেছে?\qt@no{(173)}}
\qt@newcmd\qurantrans@bn@mcxxviii{বস্তুতঃ এভাবে আমি বিষয়সমূহ সবিস্তারে বর্ণনা করি, যাতে তারা ফিরে আসে।\qt@no{(174)}}
\qt@newcmd\qurantrans@bn@mcxxix{আর আপনি তাদেরকে শুনিয়ে দিন, সে লোকের অবস্থা, যাকে আমি নিজের নিদর্শনসমূহ দান করেছিলাম, অথচ সে তা পরিহার করে বেরিয়ে গেছে। আর তার পেছনে লেগেছে শয়তান, ফলে সে পথভ্রষ্টদের অন্তর্ভূক্ত হয়ে পড়েছে।\qt@no{(175)}}
\qt@newcmd\qurantrans@bn@mcxxx{অবশ্য আমি ইচ্ছা করলে তার মর্যাদা বাড়িয়ে দিতাম সে সকল নিদর্শনসমূহের দৌলতে। কিন্তু সে যে অধঃপতিত এবং নিজের রিপুর অনুগামী হয়ে রইল। সুতরাং তার অবস্থা হল কুকুরের মত; যদি তাকে তাড়া কর তবুও হাঁপাবে আর যদি ছেড়ে দাও তবুও হাঁপাবে। এ হল সেসব লোকের উদাহরণ; যারা মিথ্যা প্রতিপন্ন করেছে আমার নিদর্শনসমূহকে। অতএব, আপনি বিবৃত করুন এসব কাহিনী, যাতে তারা চিন্তা করে।\qt@no{(176)}}
\qt@newcmd\qurantrans@bn@mcxxxi{তাদের উদাহরণ অতি নিকৃষ্ট, যারা মিথ্যা প্রতিপন্ন করেছে আমার আয়াত সমূহকে এবং তারা নিজেদেরই ক্ষতি সাধন করেছে।\qt@no{(177)}}
\qt@newcmd\qurantrans@bn@mcxxxii{যাকে আল্লাহ পথ দেখাবেন, সেই পথপ্রাপ্ত হবে। আর যাকে তিনি পথ ভ্রষ্ট করবেন, সে হবে ক্ষতিগ্রস্ত।\qt@no{(178)}}
\qt@newcmd\qurantrans@bn@mcxxxiii{আর আমি সৃষ্টি করেছি দোযখের জন্য বহু জ্বিন ও মানুষ। তাদের অন্তর রয়েছে, তার দ্বারা বিবেচনা করে না, তাদের চোখ রয়েছে, তার দ্বারা দেখে না, আর তাদের কান রয়েছে, তার দ্বারা শোনে না। তারা চতুষ্পদ জন্তুর মত; বরং তাদের চেয়েও নিকৃষ্টতর। তারাই হল গাফেল, শৈথিল্যপরায়ণ।\qt@no{(179)}}
\qt@newcmd\qurantrans@bn@mcxxxiv{আর আল্লাহর জন্য রয়েছে সব উত্তম নাম। কাজেই সে নাম ধরেই তাঁকে ডাক। আর তাদেরকে বর্জন কর, যারা তাঁর নামের ব্যাপারে বাঁকা পথে চলে। তারা নিজেদের কৃতকর্মের ফল শীঘ্রই পাবে।\qt@no{(180)}}
\qt@newcmd\qurantrans@bn@mcxxxv{আর যাদেরকে আমি সৃষ্টি করেছি, তাদের মধ্যে এমন এক দল রয়েছে যারা সত্য পথ দেখায় এবং সে অনুযায়ী ন্যায়চিার করে।\qt@no{(181)}}
\qt@newcmd\qurantrans@bn@mcxxxvi{বস্তুতঃ যারা মিথ্যা প্রতিপন্ন করেছে আমার আয়াতসমূহকে, আমি তাদেরকে ক্রমান্বয়ে পাকড়াও করব এমন জায়গা থেকে, যার সম্পর্কে তাদের ধারণাও হবে না।\qt@no{(182)}}
\qt@newcmd\qurantrans@bn@mcxxxvii{বস্তুতঃ আমি তাদেরকে ঢিল দিয়ে থাকি। নিঃসন্দেহে আমার কৌশল সুনিপুণ।\qt@no{(183)}}
\qt@newcmd\qurantrans@bn@mcxxxviii{তারা কি লক্ষ্য করেনি যে, তাদের সঙ্গী লোকটির মস্তিষ্কে কোন বিকৃতি নেই? তিনি তো ভীতি প্রদর্শনকারী প্রকৃষ্টভাবে।\qt@no{(184)}}
\qt@newcmd\qurantrans@bn@mcxxxix{তারা কি প্রত্যক্ষ করেনি আকাশ ও পৃথিবীর রাজ্য সম্পর্কে এবং যা কিছু সৃষ্টি করেছেন আল্লাহ তা’আলা বস্তু সামগ্রী থেকে এবং এ ব্যাপারে যে, তাদের সাথে কৃত ওয়াদার সময় নিকটবর্তী হয়ে এসেছে? বস্তুতঃ এরপর কিসের উপর ঈমান আনবে?\qt@no{(185)}}
\qt@newcmd\qurantrans@bn@mcxl{আল্লাহ যাকে পথভ্রষ্ট করেন। তার কোন পথপ্রদর্শক নেই। আর আল্লাহ তাদেরকে তাদের দুষ্টামীতে মত্ত অবস্তায় ছেড়ে দিয়ে রাখেন।\qt@no{(186)}}
\qt@newcmd\qurantrans@bn@mcxli{আপনাকে জিজ্ঞেস করে, কেয়ামত কখন অনুষ্ঠিত হবে? বলে দিন এর খবর তো আমার পালনকর্তার কাছেই রয়েছে। তিনিই তা অনাবৃত করে দেখাবেন নির্ধারিত সময়ে। আসমান ও যমীনের জন্য সেটি অতি কঠিন বিষয়। যখন তা তোমাদের উপর আসবে অজান্তেই এসে যাবে। আপনাকে জিজ্ঞেস করতে থাকে, যেন আপনি তার অনুসন্ধানে লেগে আছেন। বলে দিন, এর সংবাদ বিশেষ করে আল্লাহর নিকটই রয়েছে। কিন্তু তা অধিকাংশ লোকই উপলব্ধি করে না।\qt@no{(187)}}
\qt@newcmd\qurantrans@bn@mcxlii{আপনি বলে দিন, আমি আমার নিজের কল্যাণ সাধনের এবং অকল্যাণ সাধনের মালিক নই, কিন্তু যা আল্লাহ চান। আর আমি যদি গায়বের কথা জেনে নিতে পারতাম, তাহলে বহু মঙ্গল অর্জন করে নিতে পারতাম, ফলে আমার কোন অমঙ্গল কখনও হতে পারত না। আমি তো শুধুমাত্র একজন ভীতি প্রদর্শক ও সুসংবাদদাতা ঈমানদারদের জন্য।\qt@no{(188)}}
\qt@newcmd\qurantrans@bn@mcxliii{তিনিই সে সত্তা যিনি তোমাদিগকে সৃষ্টি করেছেন একটি মাত্র সত্তা থেকে; আর তার থেকেই তৈরী করেছেন তার জোড়া, যাতে তার কাছে স্বস্তি পেতে পারে। অতঃপর পুরুষ যখন নারীকে আবৃত করল, তখন, সে গর্ভবতী হল। অতি হালকা গর্ভ। সে তাই নিয়ে চলাফেরা করতে থাকল। তারপর যখন বোঝা হয়ে গেল, তখন উভয়েই আল্লাহকে ডাকল যিনি তাদের পালনকর্তা যে, তুমি যদি আমাদিগকে সুস্থ ও ভাল দান কর তবে আমরা তোমার শুকরিয়া আদায় করব।\qt@no{(189)}}
\qt@newcmd\qurantrans@bn@mcxliv{অতঃপর তাদেরকে যখন সুস্থ ও ভাল দান করা হল, তখন দানকৃত বিষয়ে তার অংশীদার তৈরী করতে লাগল। বস্তুতঃ আল্লাহ তাদের শরীক সাব্যস্ত করা থেকে বহু উর্ধে।\qt@no{(190)}}
\qt@newcmd\qurantrans@bn@mcxlv{তারা কি এমন কাউকে শরীক সাব্যস্ত করে, যে একটি বস্তুও সৃষ্টি করেনি, বরং তাদেরকে সৃষ্টি করা হয়েছে।\qt@no{(191)}}
\qt@newcmd\qurantrans@bn@mcxlvi{আর তারা, না তাদের সাহায্য করতে পারে, না নিজের সাহায্য করতে পারে।\qt@no{(192)}}
\qt@newcmd\qurantrans@bn@mcxlvii{আর তোমরা যদি তাদেরকে আহবান কর সুপথের দিকে, তবে তারা তোমাদের আহবান অনুযায়ী চলবে না। তাদেরকে আহবান জানানো কিংবা নীরব থাকা উভয়টিই তোমাদের জন্য সমান।\qt@no{(193)}}
\qt@newcmd\qurantrans@bn@mcxlviii{আল্লাহকে বাদ দিয়ে তোমরা যাদেরকে ডাক, তারা সবাই তোমাদের মতই বান্দা। অতএব, তোমরা যাদেরকে ডাক, তখন তাদের পক্ষেও তো তোমাদের সে ডাক কবুল করা উচিত যদি তোমরা সত্যবাদী হয়ে থাক?\qt@no{(194)}}
\qt@newcmd\qurantrans@bn@mcxlix{তাদের কি পা আছে, যদ্বারা তারা চলাফেরা করে, কিংবা তাদের কি হাত আছে, যদ্বারা তারা ধরে। অথবা তাদের কি চোখ আছে যদ্বারা তারা দেখতে পায় কিংবা তাদের কি কান আছে যদ্বারা শুনতে পায়? বলে দাও, তোমরা ডাক তোমাদের অংশীদারদিগকে, অতঃপর আমার অমঙ্গল কর এবং আমাকে অবকাশ দিও না।\qt@no{(195)}}
\qt@newcmd\qurantrans@bn@mcl{আমার সহায় তো হলেন আল্লাহ, যিনি কিতাব অবতীর্ণ করেছেন। বস্তুত; তিনিই সাহায্য করেন সৎকর্মশীল বান্দাদের।\qt@no{(196)}}
\qt@newcmd\qurantrans@bn@mcli{আর তোমরা তাঁকে বাদ দিয়ে যাদেরকে ডাক তারা না তোমাদের কোন সাহায্য করতে পারবে, না নিজেদের আত্নরক্ষা করতে পারবে।\qt@no{(197)}}
\qt@newcmd\qurantrans@bn@mclii{আর তুমি যদি তাদেরকে সুপথে আহবান কর, তবে তারা তা কিছুই শুনবে না। আর তুমি তো তাদের দেখছই, তোমার দিকে তাকিয়ে আছে, অথচ তারা কিছুই দেখতে পাচ্ছে না।\qt@no{(198)}}
\qt@newcmd\qurantrans@bn@mcliii{আর ক্ষমা করার অভ্যাস গড়ে তোল, সৎকাজের নির্দেশ দাও এবং মূর্খ জাহেলদের থেকে দূরে সরে থাক।\qt@no{(199)}}
\qt@newcmd\qurantrans@bn@mcliv{আর যদি শয়তানের প্ররোচনা তোমাকে প্ররোচিত করে, তাহলে আল্লাহর শরণাপন্ন হও তিনিই শ্রবণকারী, মহাজ্ঞানী।\qt@no{(200)}}
\qt@newcmd\qurantrans@bn@mclv{যাদের মনে ভয় রয়েছে, তাদের উপর শয়তানের আগমন ঘটার সাথে সাথেই তারা সতর্ক হয়ে যায় এবং তখনই তাদের বিবেচনাশক্তি জাগ্রত হয়ে উঠে।\qt@no{(201)}}
\qt@newcmd\qurantrans@bn@mclvi{পক্ষান্তরে যারা শয়তানের ভাই, তাদেরকে সে ক্রমাগত পথভ্রষ্ট তার দিকে নিয়ে যায় অতঃপর তাতে কোন কমতি করে না।\qt@no{(202)}}
\qt@newcmd\qurantrans@bn@mclvii{আর যখন আপনি তাদের নিকট কোন নিদর্শন নিয়ে না যান, তখন তারা বলে, আপনি নিজের পক্ষ থেকে কেন অমুকটি নিয়ে আসলেন না, তখন আপনি বলে দিন, আমি তো সে মতেই চলি যে হুকুম আমার নিকট আসে আমার পরওয়ারদেগারের কাছ থেকে। এটা ভাববার বিষয় তোমাদের পরওয়ারদেগারের পক্ষ থেকে এবং হেদায়েত ও রহমত সেসব লোকের জন্য যারা ঈমান এনেছে।\qt@no{(203)}}
\qt@newcmd\qurantrans@bn@mclviii{আর যখন কোরআন পাঠ করা হয়, তখন তাতে কান লাগিয়ে রাখ এবং নিশ্চুপ থাক যাতে তোমাদের উপর রহমত হয়।\qt@no{(204)}}
\qt@newcmd\qurantrans@bn@mclix{আর স্মরণ করতে থাক স্বীয় পালনকর্তাকে আপন মনে ক্রন্দনরত ও ভীত-সন্ত্রস্ত অবস্থায় এবং এমন স্বরে যা চিৎকার করে বলা অপেক্ষা কম; সকালে ও সন্ধ্যায়। আর বে-খবর থেকো না।\qt@no{(205)}}
\qt@newcmd\qurantrans@bn@mclx{নিশ্চয়ই যারা তোমার পরওয়ারদেগারের সান্নিধ্যে রয়েছেন, তারা তাঁর বন্দেগীর ব্যাপারে অহঙ্কার করেন না এবং স্মরণ করেন তাঁর পবিত্র সত্তাকে; আর তাঁকেই সেজদা করেন।\qt@no{(206)}}
\qt@newcmd\qurantrans@bn@mclxi{\basmalahbn আপনার কাছে জিজ্ঞেস করে, গনীমতের হুকুম। বলে দিন, গণীমতের মাল হল আল্লাহর এবং রসূলের। অতএব, তোমরা আল্লাহকে ভয় কর এবং নিজেদের অবস্থা সংশোধন করে নাও। আর আল্লাহ এবং তাঁর রসূলের হুকুম মান্য কর, যদি ঈমানদার হয়ে থাক।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mclxii{যারা ঈমানদার, তারা এমন যে, যখন আল্লাহর নাম নেয়া হয় তখন ভীত হয়ে পড়ে তাদের অন্তর। আর যখন তাদের সামনে পাঠ করা হয় কালাম, তখন তাদের ঈমান বেড়ে যায় এবং তারা স্বীয় পরওয়ার দেগারের প্রতি ভরসা পোষণ করে।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mclxiii{সে সমস্ত লোক যারা নামায প্রতিষ্ঠা করে এবং আমি তাদেরকে যে রুযী দিয়েছি তা থেকে ব্যয় করে।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mclxiv{তারাই হল সত্যিকার ঈমানদার! তাদের জন্য রয়েছে স্বীয় পরওয়ারদেগারের নিকট মর্যাদা, ক্ষমা এবং সম্মানজনক রুযী।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mclxv{যেমন করে তোমাকে তোমার পরওয়ারদেগার ঘর থেকে বের করেছেন ন্যায় ও সৎকাজের জন্য, অথচ ঈমানদারদের একটি দল (তাতে) সম্মত ছিল না।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mclxvi{তারা তোমার সাথে বিবাদ করছিল সত্য ও ন্যায় বিষয়ে, তা প্রকাশিত হবার পর; তারা যেন মৃত্যুর দিকে ধাবিত হচ্ছে দেখতে দেখতে।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mclxvii{আর যখন আল্লাহ দু’টি দলের একটির ব্যাপারে তোমাদের সাথে ওয়াদা করেছিলেন যে, সেটি তোমাদের হস্তগত হবে, আর তোমরা কামনা করছিলে যাতে কোন রকম কন্টক নেই, তাই তোমাদের ভাগে আসুক; অথচ আল্লাহ চাইতেন সত্যকে স্বীয় কালামের মাধ্যমে সত্যে পরিণত করতে এবং কাফেরদের মূল কর্তন করে দিতে,\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mclxviii{যাতে করে সত্যকে সত্য এবং মিথ্যাকে মিথ্যা প্রতিপন্ন করে দেন, যদিও পাপীরা অসন্তুষ্ট হয়।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mclxix{তোমরা যখন ফরিয়াদ করতে আরম্ভ করেছিলে স্বীয় পরওয়ারদেগারের নিকট, তখন তিনি তোমাদের ফরিয়াদের মঞ্জুরী দান করলেন যে, আমি তোমাদিগকে সাহায্য করব ধারাবহিকভাবে আগত হাজার ফেরেশতার মাধ্যমে।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mclxx{আর আল্লাহ তো শুধু সুসংবাদ দান করলেন যাতে তোমাদের মন আশ্বস্ত হতে পারে। আর সাহায্য আল্লাহর পক্ষ থেকে ছাড়া অন্য কারো পক্ষ থেকে হতে পারে না। নিঃসন্দেহে আল্লাহ মহাশক্তির অধিকারী হেকমত ওয়ালা।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mclxxi{যখন তিনি আরোপ করেন তোমাদের উপর তন্দ্রাচ্ছন্ন তা নিজের পক্ষ থেকে তোমাদের প্রশান্তির জন্য এবং তোমাদের উপর আকাশ থেকে পানি অবতরণ করেন, যাতে তোমাদিগকে পবিত্র করে দেন এবং যাতে তোমাদের থেকে অপসারিত করে দেন শয়তানের অপবিত্রতা। আর যাতে করে সুরক্ষিত করে দিতে পারেন তোমাদের অন্তরসমূহকে এবং তাতে যেন সুদৃঢ় করে দিতে পারেন তোমাদের পা গুলো।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mclxxii{যখন নির্দেশ দান করেন ফেরেশতাদিগকে তোমাদের পরওয়ারদেগার যে, আমি সাথে রয়েছি তোমাদের, সুতরাং তোমরা মুসলমানদের চিত্তসমূহকে ধীরস্থির করে রাখ। আমি কাফেরদের মনে ভীতির সঞ্চার করে দেব। কাজেই গর্দানের উপর আঘাত হান এবং তাদেরকে কাট জোড়ায় জোড়ায়।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mclxxiii{যেহেতু তারা অবাধ্য হয়েছে আল্লাহ এবং তাঁর রসূলের, সেজন্য এই নির্দেশ। বস্তুতঃ যে লোক আল্লাহ ও রসূলের অবাধ্য হয়, নিঃসন্দেহে আল্লাহর শাস্তি অত্যন্ত কঠোর।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mclxxiv{আপাততঃ বর্তমান এ শাস্তি তোমরা আস্বাদন করে নাও এবং জেনে রাখ যে, কাফেরদের জন্য রয়েছে দোযখের আযাব।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mclxxv{হে ঈমানদারগণ, তোমরা যখন কাফেরদের সাথে মুখোমুখী হবে, তখন পশ্চাদপসরণ করবে না।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mclxxvi{আর যে লোক সেদিন তাদের থেকে পশ্চাদপসরণ করবে, অবশ্য যে লড়াইয়ের কৌশল পরিবর্তনকল্পে কিংবা যে নিজ সৈন্যদের নিকট আশ্রয় নিতে আসে সে ব্যতীত অন্যরা আল্লাহর গযব সাথে নিয়ে প্রত্যাবর্তন করবে। আর তার ঠিকানা হল জাহান্নাম। বস্তুতঃ সেটা হল নিকৃষ্ট অবস্থান।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mclxxvii{সুতরাং তোমরা তাদেরকে হত্যা করনি, বরং আল্লাহই তাদেরকে হত্যা করেছেন। আর তুমি মাটির মুষ্ঠি নিক্ষেপ করনি, যখন তা নিক্ষেপ করেছিলে, বরং তা নিক্ষেপ করেছিলেন আল্লাহ স্বয়ং যেন ঈমানদারদের প্রতি এহসান করতে পারেন যথার্থভাবে। নিঃসন্দেহে আল্লাহ শ্রবণকারী; পরিজ্ঞাত।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mclxxviii{এটাতো গেল, আর জেনে রেখো, আল্লাহ নস্যাৎ করে দেবেন কাফেরদের সমস্ত কলা-কৌশল।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mclxxix{তোমরা যদি মীমাংসা কামনা কর, তাহলে তোমাদের নিকট মীমাংসা পৌছে গেছে। আর যদি তোমরা প্রত্যাবর্তন কর, তবে তা তোমাদের জন্য উত্তম এবং তোমরা যদি তাই কর, তবে আমি ও তেমনি করব। বস্তুতঃ তোমাদের কোনই কাজে আসবে না তোমাদের দল-বল, তা যত বেশীই হোক। জেনে রেখ আল্লাহ রয়েছেন ঈমানদারদের সাথে।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mclxxx{হে ঈমানদারগণ, আল্লাহ ও তাঁর রসূলের নির্দেশ মান্য কর এবং শোনার পর তা থেকে বিমুখ হয়ো না।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mclxxxi{আর তাদের অন্তর্ভুক্ত হয়ো না, যারা বলে যে, আমরা শুনেছি, অথচ তারা শোনেনা।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mclxxxii{নিঃসন্দেহে আল্লাহ তা’আলার নিকট সমস্ত প্রাণীর তুলনায় তারাই মূক ও বধির, যারা উপলদ্ধি করে না।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mclxxxiii{বস্তুতঃ আল্লাহ যদি তাদের মধ্যে কিছুমাত্র শুভ চিন্তা জানতেন, তবে তাদেরকে শুনিয়ে দিতেন। আর এখনই যদি তাদের শুনিয়ে দেন, তবে তারা মুখ ঘুরিয়ে পালিয়ে যাবে।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mclxxxiv{হে ঈমানদারগণ, আল্লাহ ও তাঁর রসূলের নির্দেশ মান্য কর, যখন তোমাদের সে কাজের প্রতি আহবান করা হয়, যাতে রয়েছে তোমাদের জীবন। জেনে রেখো, আল্লাহ মানুষের এবং তার অন্তরের মাঝে অন্তরায় হয়ে যান। বস্তুতঃ তোমরা সবাই তাঁরই নিকট সমবেত হবে।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mclxxxv{আর তোমরা এমন ফাসাদ থেকে বেঁচে থাক যা বিশেষতঃ শুধু তাদের উপর পতিত হবে না যারা তোমাদের মধ্যে জালেম এবং জেনে রেখ যে, আল্লাহর আযাব অত্যন্ত কঠোর।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mclxxxvi{আর স্মরণ কর, যখন তোমরা ছিলে অল্প, পরাজিত অবস্থায় পড়েছিলে দেশে; ভীত-সস্ত্রস্ত্র ছিলে যে, তোমাদের না অন্যেরা ছোঁ মেরে নিয়ে যায়। অতঃপর তিনি তোমাদিগকে আশ্রয়ের ঠিকানা দিয়েছেন, স্বীয় সাহায্যের দ্বারা তোমাদিগকে শক্তি দান করেছেন এবং পরিচ্ছন্ন জীবিকা দিয়েছেন যাতে তোমরা শুকরিয়া আদায় কর।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mclxxxvii{হে ঈমানদারগণ, খেয়ানত করোনা আল্লাহর সাথে ও রসূলের সাথে এবং খেয়ানত করো না নিজেদের পারস্পরিক আমানতে জেনে-শুনে।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mclxxxviii{আর জেনে রাখ, তোমাদের ধন-সম্পদ ও সন্তান-সন্ততি অকল্যাণের সম্মুখীনকারী। বস্তুতঃ আল্লাহর নিকট রয়েছে মহা সওয়াব।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mclxxxix{হে ঈমানদারগণ তোমরা যদি আল্লাহকে ভয় করতে থাক, তবে তোমাদের মধ্যে ফয়সালা করে দেবেন এবং তোমাদের থেকে তোমাদের পাপকে সরিয়ে দেবেন এবং তোমাদের ক্ষমা করবেন। বস্তুতঃ আল্লাহর অনুগ্রহ অত্যন্ত মহান।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mcxc{আর কাফেরেরা যখন প্রতারণা করত আপনাকে বন্দী অথবা হত্যা করার উদ্দেশ্যে কিংবা আপনাকে বের করে দেয়ার জন্য তখন তারা যেমন ছলনা করত তেমনি, আল্লাহও ছলনা করতেন। বস্তুতঃ আল্লাহর ছলনা সবচেয়ে উত্তম।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mcxci{আর কেউ যখন তাদের নিকট আমার আয়াতসমূহ পাঠ করে তবে বলে, আমরা শুনেছি, ইচ্ছা করলে আমরাও এমন বলতে পারি; এ তো পূর্ববর্তী ইতিকথা ছাড়া আর কিছুই নয়।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mcxcii{তাছাড়া তারা যখন বলতে আরম্ভ করে যে, ইয়া আল্লাহ, এই যদি তোমার পক্ষ থেকে (আগত) সত্য দ্বীন হয়ে থাকে, তবে আমাদের উপর আকাশ থেকে প্রস্তর বর্ষণ কর কিংবা আমাদের উপর বেদনাদায়ক আযাব নাযিল কর।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mcxciii{অথচ আল্লাহ কখনই তাদের উপর আযাব নাযিল করবেন না যতক্ষণ আপনি তাদের মাঝে অবস্থান করবেন। তাছাড়া তারা যতক্ষণ ক্ষমা প্রার্থনা করতে থাকবে আল্লাহ কখনও তাদের উপর আযাব দেবেন না।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mcxciv{আর তাদের মধ্যে এমন কি বিষয় রয়েছে, যার ফলে আল্লাহ তাদের উপর আযাব দান করবেন না। অথচ তারা মসজিদে-হারামে যেতে বাধাদান করে, অথচ তাদের সে অধিকার নেই। এর অধিকার তো তাদেরই রয়েছে যারা পরহেযগার। কিন্তু তাদের অধিকাংশই সে বিষয়ে অবহিত নয়।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mcxcv{আর কা’বার নিকট তাদের নামায বলতে শিস দেয়া আর তালি বাজানো ছাড়া অন্য কোন কিছুই ছিল না। অতএব, এবার নিজেদের কৃত কুফরীর আযাবের স্বাদ গ্রহণ কর।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mcxcvi{নিঃসন্দেহে যেসব লোক কাফের, তারা ব্যয় করে নিজেদের ধন-সম্পদ, যাতে করে বাধাদান করতে পারে আল্লাহর পথে। বস্তুতঃ এখন তারা আরো ব্যয় করবে। তারপর তাই তাদের জন্য আক্ষেপের কারণ হয়ে এবং শেষ পর্যন্ত তারা হেরে যাবে। আর যারা কাফের তাদেরকে দোযখের দিকে তাড়িয়ে নিয়ে যাওয়া হবে।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mcxcvii{যাতে পৃথক করে দেন আল্লাহ অপবিত্র ও না-পাককে পবিত্র ও পাক থেকে। আর যাতে একটির পর একটিকে স্থাপন করে সমবেত স্তুপে পরিণত করেন এবং পরে দোযখে নিক্ষেপ করেন। এরাই হল ক্ষতিগ্রস্ত।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mcxcviii{তুমি বলে দাও, কাফেরদেরকে যে, তারা যদি বিরত হয়ে যায়, তবে যা কিছু ঘটে গেছে ক্ষমা হবে যাবে। পক্ষান্তরে আবারও যদি তাই করে, তবে পুর্ববর্তীদের পথ নির্ধারিত হয়ে গেছে।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mcxcix{আর তাদের সাথে যুদ্ধ করতে থাক যতক্ষণ না ভ্রান্তি শেষ হয়ে যায়; এবং আল্লাহর সমস্ত হুকুম প্রতিষ্ঠিত হয়ে যায়। তারপর যদি তারা বিরত হয়ে যায়, তবে আল্লাহ তাদের কার্যকলাপ লক্ষ্য করেন।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mcc{আর তারা যদি না মানে, তবে জেনে রাখ, আল্লাহ তোমাদের সমর্থক; এবং কতই না চমৎকার সাহায্যকারী।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mcci{আর এ কথাও জেনে রাখ যে, কোন বস্তু-সামগ্রীর মধ্য থেকে যা কিছু তোমরা গনীমত হিসাবে পাবে, তার এক পঞ্চমাংশ হল আল্লাহর জন্য, রসূলের জন্য, তাঁর নিকটাত্নীয়-স্বজনের জন্য এবং এতীম-অসহায় ও মুসাফিরদের জন্য; যদি তোমাদের বিশ্বাস থাকে আল্লাহর উপর এবং সে বিষয়ের উপর যা আমি আমার বান্দার প্রতি অবতীর্ণ করেছি ফয়সালার দিনে, যেদিন সম্মুখীন হয়ে যায় উভয় সেনাদল। আর আল্লাহ সব কিছুর উপরই ক্ষমতাশীল।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mccii{আর যখন তোমরা ছিলে সমরাঙ্গনের এ প্রান্তে আর তারা ছিল সে প্রান্তে অথচ কাফেলা তোমাদের থেকে নীচে নেমে গিয়েছিল। এমতাবস্থায় যদি তোমরা পারস্পরিক অঙ্গীকারাবদ্ধ হতে, তবে তোমরা এক সঙ্গে সে ওয়াদা পালন করতে পারতে না। কিন্তু আল্লাহ তা’আলা এমন এক কাজ করতে চেয়েছিলেন, যা নির্ধারিত হয়ে গিয়েছিল যাতে সে সব লোক নিহত হওয়ার ছিল, প্রমাণ প্রতিষ্ঠার পর এবং যাদের বাঁচার ছিল, তারা বেঁচে থাকে প্রমাণ প্রতিষ্ঠার পর। আর নিশ্চিতই আল্লাহ শ্রবণকারী, বিজ্ঞ।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mcciii{আল্লাহ যখন তোমাকে স্বপ্নে সেসব কাফেরের পরিমাণ অল্প করে দেখালেন; বেশী করে দেখালে তোমরা কাপুরুষতা অবলম্বন করতে এবং কাজের বেলায় বিপদ সৃষ্টি করতে। কিন্তু আল্লাহ বাঁচিয়ে দিয়েছেন। তিনি অতি উত্তমভাবেই জানেন; যা কিছু অন্তরে রয়েছে।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mcciv{আর যখন তোমাদেরকে দেখালেন সে সৈন্যদল মোকাবেলার সময় তোমাদের চোখে অল্প এবং তোমাদেরকে দেখালেন তাদের চোখে বেশী, যাতে আল্লাহ সে কাজ করে নিতে পারেন যা ছিল নির্ধারিত। আর সব কাজই আল্লাহর নিকট গিয়ে পৌছায়।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mccv{হে ঈমানদারগণ, তোমরা যখন কোন বাহিনীর সাথে সংঘাতে লিপ্ত হও, তখন সুদৃঢ় থাক এবং আল্লাহকে অধিক পরিমাণে স্মরণ কর যাতে তোমরা উদ্দেশ্যে কৃতকার্য হতে পার।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mccvi{আর আল্লাহ তা’আলার নির্দেশ মান্য কর এবং তাঁর রসূলের। তাছাড়া তোমরা পরস্পরে বিবাদে লিপ্ত হইও না। যদি তা কর, তবে তোমরা কাপুরুষ হয়ে পড়বে এবং তোমাদের প্রভাব চলে যাবে। আর তোমরা ধৈর্য্যধারণ কর। নিশ্চয়ই আল্লাহ তা'আলা রয়েছেন ধৈর্য্যশীলদের সাথে।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mccvii{আর তাদের মত হয়ে যেয়ো না, যারা বেরিয়েছে নিজেদের অবস্থান থেকে গর্বিতভাবে এবং লোকদেরকে দেখাবার উদ্দেশে। আর আল্লাহর পথে তারা বাধা দান করত। বস্তুতঃ আল্লাহর আয়ত্বে রয়েছে সে সমস্ত বিষয় যা তারা করে।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mccviii{আর যখন সুদৃশ্য করে দিল শয়তান তাদের দৃষ্টিতে তাদের কার্যকলাপকে এবং বলল যে, আজকের দিনে কোন মানুষই তোমাদের উপর বিজয়ী হতে পারবে না আর আমি হলাম তোমাদের সমর্থক, অতঃপর যখন সামনাসামনী হল উভয় বাহিনী তখন সে অতি দ্রুত পায়ে পেছনে দিকে পালিয়ে গেল এবং বলল, আমি তোমাদের সাথে না-আমি দেখছি, যা তোমরা দেখছ না; আমি ভয় করি আল্লাহকে। আর আল্লাহর আযাব অত্যন্ত কঠিন।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mccix{যখন মোনাফেকরা বলতে লাগল এবং যাদের অন্তর ব্যাধিগ্রস্ত, এরা নিজেদের ধর্মের উপর গর্বিত। বস্তুতঃ যারা ভরসা করে আল্লাহর উপর, সে নিশ্চিন্ত, কেননা আল্লাহ অতি পরাক্রমশীল, সুবিজ্ঞ।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mccx{আর যদি তুমি দেখ, যখন ফেরেশতারা কাফেরদের জান কবজ করে; প্রহার করে, তাদের মুখে এবং তাদের পশ্চাদদেশে আর বলে, জ্বলন্ত আযাবের স্বাদ গ্রহণ কর।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mccxi{এই হলো সে সবের বিনিময় যা তোমরা তোমাদের পূর্বে পাঠিয়েছ নিজের হাতে। বস্তুতঃ এটি এ জন্য যে, আল্লাহ বান্দার উপর যুলুম করেন না।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mccxii{যেমন, রীতি রয়েছে ফেরাউনের অনুসারীদের এবং তাদের পূর্বে যারা ছিল তাদের ব্যাপারে যে, এরা আল্লাহর নির্দেশের প্রতি অস্বীকৃতি জ্ঞাপন করেছে এবং সেজন্য আল্লাহ তা’আলা তাদের পাকড়াও করেছেন তাদেরই পাপের দরুন। নিঃসন্দেহে আল্লাহ মহাশক্তিশালী, কঠিন শাস্তিদাতা।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mccxiii{তার কারণ এই যে, আল্লাহ কখনও পরিবর্তন করেন না, সে সব নেয়ামত, যা তিনি কোন জাতিকে দান করেছিলেন, যতক্ষণ না সে জাতি নিজেই পরিবর্তিত করে দেয় নিজের জন্য নির্ধারিত বিষয়। বস্তুতঃ আল্লাহ শ্রবণকারী, মহাজ্ঞানী।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mccxiv{যেমন ছিল রীতি ফেরাউনের বংশধর এবং যারা তাদের পূর্বে ছিল, তারা মিথ্যা প্রতিপন্ন করেছিল স্বীয় পালনকর্তার নিদর্শনসমূহকে। অতঃপর আমি তাদেরকে ধ্বংস করে দিয়েছি তাদের পাপের দরুন এবং ডুবিয়ে মেরেছি ফেরাউনের বংশধরদেরকে। বস্তুতঃ এরা সবাই ছিল যালেম।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mccxv{সমস্ত জীবের মাঝে আল্লাহর নিকট তারাই সবচেয়ে নিকৃষ্ট, যারা অস্বীকারকারী হয়েছে অতঃপর আর ঈমান আনেনি।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mccxvi{যাদের সাথে তুমি চুক্তি করেছ তাদের মধ্য থেকে অতঃপর প্রতিবার তারা নিজেদের কৃতচুক্তি লংঘন করে এবং ভয় করে না।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mccxvii{সুতরাং যদি কখনো তুমি তাদেরকে যুদ্ধে পেয়ে যাও, তবে তাদের এমন শাস্তি দাও, যেন তাদের উত্তরসূরিরা তাই দেখে পালিয়ে যায়; তাদেরও যেন শিক্ষা হয়।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mccxviii{তবে কোন সম্প্রদায়ের ধোঁকা দেয়ার ব্যাপারে যদি তোমাদের ভয় থাকে, তবে তাদের চুক্তি তাদের দিকেই ছুঁড়ে ফেলে দাও এমনভাবে যেন হয়ে যাও তোমরাও তারা সমান। নিশ্চয়ই আল্লাহ ধোকাবাজ, প্রতারককে পছন্দ করেন না।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mccxix{আর কাফেররা যেন একা যা মনে না করে যে, তারা বেঁচে গেছে; কখনও এরা আমাকে পরিশ্রান্ত করতে পারবে না।\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mccxx{আর প্রস্তুত কর তাদের সাথে যুদ্ধের জন্য যাই কিছু সংগ্রহ করতে পার নিজের শক্তি সামর্থ্যের মধ্যে থেকে এবং পালিত ঘোড়া থেকে, যেন প্রভাব পড়ে আল্লাহর শুত্রুদের উপর এবং তোমাদের শত্রুদের উপর আর তাদেরকে ছাড়া অন্যান্যদের উপর ও যাদেরকে তোমরা জান না; আল্লাহ তাদেরকে চেনেন। বস্তুতঃ যা কিছু তোমরা ব্যয় করবে আল্লাহর রাহে, তা তোমরা পরিপূর্ণভাবে ফিরে পাবে এবং তোমাদের কোন হক অপূর্ণ থাকবে না।\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mccxxi{আর যদি তারা সন্ধি করতে আগ্রহ প্রকাশ করে, তাহলে তুমিও সে দিকেই আগ্রহী হও এবং আল্লাহর উপর ভরসা কর। নিঃসন্দেহে তিনি শ্রবণকারী; পরিজ্ঞাত।\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mccxxii{পক্ষান্তরে তারা যদি তোমাকে প্রতারণা করতে চায়, তবে তোমার জন্য আল্লাহই যথেষ্ট, তিনিই তোমাকে শক্তি যুগিয়েছেন স্বীয় সাহায্যে ও মুসলমানদের মাধ্যমে।\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mccxxiii{আর প্রীতি সঞ্চার করেছেন তাদের অন্তরে। যদি তুমি সেসব কিছু ব্যয় করে ফেলতে, যা কিছু যমীনের বুকে রয়েছে, তাদের মনে প্রীতি সঞ্চার করতে পারতে না। কিন্তু আল্লাহ তাদের মনে প্রীতি সঞ্চার করেছেন। নিঃসন্দেহে তিনি পরাক্রমশালী, সুকৌশলী।\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mccxxiv{হে নবী, আপনার জন্য এবং যেসব মুসলমান আপনার সাথে রয়েছে তাদের সবার জন্য আল্লাহ যথেষ্ট।\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mccxxv{হে নবী, আপনি মুসলমানগণকে উৎসাহিত করুন জেহাদের জন্য। তোমাদের মধ্যে যদি বিশ জন দৃঢ়পদ ব্যক্তি থাকে, তবে জয়ী হবে দু’শর মোকাবেলায়। আর যদি তোমাদের মধ্যে থাকে একশ লোক, তবে জয়ী হবে হাজার কাফেরের উপর থেকে তার কারণ ওরা জ্ঞানহীন।\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mccxxvi{এখন বোঝা হালকা করে দিয়েছেন আল্লাহ তা’আলা তোমাদের উপর এবং তিনি জেনে নিয়েছেন যে, তোমাদের মধ্য দূর্বলতা রয়েছে। কাজেই তোমাদের মধ্যে যদি দৃঢ়চিত্ত একশ লোক বিদ্যমান থাকে, তবে জয়ী হবে দু’শর উপর। আর যদি তোমরা এক হাজার হও তবে আল্লাহর হুকুম অনুযায়ী জয়ী হবে দু’হাজারের উপর আর আল্লাহ রয়েছেন দৃঢ়চিত্ত লোকদের সাথে।\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mccxxvii{নবীর পক্ষে উচিত নয় বন্দীদিগকে নিজের কাছে রাখা, যতক্ষণ না দেশময় প্রচুর রক্তপাত ঘটাবে। তোমরা পার্থিব সম্পদ কামনা কর, অথচ আল্লাহ চান আখেরাত। আর আল্লাহ হচ্ছেন পরাক্রমশালী হেকমতওয়ালা।\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mccxxviii{যদি একটি বিষয় না হত যা পূর্ব থেকেই আল্লাহ লিখে রেখেছেন, তাহলে তোমরা যা গ্রহণ করছ সেজন্য বিরাট আযাব এসে পৌছাত।\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mccxxix{সুতরাং তোমরা খাও গনীমত হিসাবে তোমরা যে পরিচ্ছন্ন ও হালাল বস্তু অর্জন করেছ তা থেকে। আর আল্লাহকে ভয় করতে থাক। নিশ্চয়ই আল্লাহ ক্ষমাশীল, মেহেরবান।\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mccxxx{হে নবী, তাদেরকে বলে দাও, যারা তোমার হাতে বন্দী হয়ে আছে যে, আল্লাহ যদি তোমাদের অন্তরে কোন রকম মঙ্গলচিন্তা রয়েছে বলে জানেন, তবে তোমাদেরকে তার চেয়ে বহুগুণ বেশী দান করবেন যা তোমাদের কাছ থেকে বিনিময়ে নেয়া হয়েছে। তাছাড়া তোমাদেরকে তিনি ক্ষমা করে দিবেন। বস্তুতঃ আল্লাহ ক্ষমাশীল, করুণাময়।\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@mccxxxi{আর যদি তারা তোমার সাথে প্রতারণা করতে চায়-বস্তুতঃ তারা আল্লাহর সাথেও ইতিপূর্বে প্রতারণা করেছে, অতঃপর তিনি তাদেরকে ধরিয়ে দিয়েছেন। আর আল্লাহ সর্ববিষয়ে পরিজ্ঞাত, সুকৌশলী।\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@mccxxxii{এতে কোন সন্দেহ নেই যে, যারা ঈমান এনেছে, দেশ ত্যাগ করেছে, স্বীয় জান ও মাল দ্বারা আল্লাহর রাহে জেহাদ করেছে এবং যারা তাদেরকে আশ্রয় ও সাহায্য সহায়তা দিয়েছে, তারা একে অপরের সহায়ক। আর যারা ঈমান এনেছে কিন্তু দেশ ত্যাগ করেনি তাদের বন্ধুত্বে তোমাদের প্রয়োজন নেই যতক্ষণ না তারা দেশত্যাগ করে। অবশ্য যদি তারা ধর্মীয় ব্যাপারে তোমাদের সহায়তা কামনা করে, তবে তাদের সাহায্য করা তোমাদের কর্তব্য। কিন্তু তোমাদের সাথে যাদের সহযোগী চুক্তি বিদ্যমান রয়েছে, তাদের মোকাবেলায় নয়। বস্তুতঃ তোমরা যা কিছু কর, আল্লাহ সেসবই দেখেন।\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@mccxxxiii{আর যারা কাফের তারা পারস্পরিক সহযোগী, বন্ধু। তোমরা যদি এমন ব্যবস্থা না কর, তবে দাঙ্গা-হাঙ্গামা বিস্তার লাভ করবে এবং দেশময় বড়ই অকল্যাণ হবে।\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@mccxxxiv{আর যারা ঈমান এনেছে, নিজেদের ঘর-বাড়ী ছেড়েছে এবং আল্লাহর রাহে জেহাদ করেছে এবং যারা তাদেরকে আশ্রয় দিয়েছে, সাহায্য-সহায়তা করেছে, তাঁরা হলো সত্যিকার মুসলমান। তাঁদের জন্যে রয়েছে, ক্ষমা ও সম্মানজনক রুযী।\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@mccxxxv{আর যারা ঈমান এনেছে পরবর্তী পর্যায়ে এবং ঘর-বাড়ী ছেড়েছে এবং তোমাদের সাথে সম্মিলিত হয়ে জেহাদ করেছে, তারাও তোমাদেরই অন্তর্ভুক্ত। বস্তুতঃ যারা আত্নীয়, আল্লাহর বিধান মতে তারা পরস্পর বেশী হকদার। নিশ্চয়ই আল্লাহ যাবতীয় বিষয়ে সক্ষম ও অবগত।\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@mccxxxvi{\basmalahbn সম্পর্কচ্ছেদ করা হল আল্লাহ ও তাঁর রসূলের পক্ষ থেকে সেই মুশরিকদের সাথে, যাদের সাথে তোমরা চুক্তিবদ্ধ হয়েছিলে।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mccxxxvii{অতঃপর তোমরা পরিভ্রমণ কর এ দেশে চার মাসকাল। আর জেনে রেখো, তোমরা আল্লাহকে পরাভূত করতে পারবে না, আর নিশ্চয়ই আল্লাহ কাফেরদিগকে লাঞ্ছিত করে থাকেন।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mccxxxviii{আর মহান হজ্বের দিনে আল্লাহ ও তাঁর রসূলের পক্ষ থেকে লোকদের প্রতি ঘোষণা করে দেয়া হচ্ছে যে, আল্লাহ মুশরেকদের থেকে দায়িত্ব মুক্ত এবং তাঁর রসূলও। অবশ্য যদি তোমরা তওবা কর, তবে তা, তোমাদের জন্যেও কল্যাণকর, আর যদি মুখ ফেরাও, তবে জেনে রেখো, আল্লাহকে তোমরা পরাভূত করতে পারবে না। আর কাফেরদেরকে মর্মান্তিক শাস্তির সুসংবাদ দাও।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mccxxxix{তবে যে মুশরিকদের সাথে তোমরা চুক্তি বদ্ধ, অতপরঃ যারা তোমাদের ব্যাপারে কোন ত্রুটি করেনি এবং তোমাদের বিরুদ্ধে কাউকে সাহায্যও করেনি, তাদের সাথে কৃত চুক্তিকে তাদের দেয়া মেয়াদ পর্যন্ত পূরণ কর। অবশ্যই আল্লাহ সাবধানীদের পছন্দ করেন।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mccxl{অতঃপর নিষিদ্ধ মাস অতিবাহিত হলে মুশরিকদের হত্যা কর যেখানে তাদের পাও, তাদের বন্দী কর এবং অবরোধ কর। আর প্রত্যেক ঘাঁটিতে তাদের সন্ধানে ওঁৎ পেতে বসে থাক। কিন্তু যদি তারা তওবা করে, নামায কায়েম করে, যাকাত আদায় করে, তবে তাদের পথ ছেড়ে দাও। নিশ্চয় আল্লাহ অতি ক্ষমাশীল, পরম দয়ালু।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mccxli{আর মুশরিকদের কেউ যদি তোমার কাছে আশ্রয় প্রার্থনা করে, তবে তাকে আশ্রয় দেবে, যাতে সে আল্লাহর কালাম শুনতে পায়, অতঃপর তাকে তার নিরাপদ স্থানে পৌছে দেবে। এটি এজন্যে যে এরা জ্ঞান রাখে না।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mccxlii{মুশরিকদের চুক্তি আল্লাহর নিকট ও তাঁর রসূলের নিকট কিরূপে বলবৎ থাকবে। তবে যাদের সাথে তোমরা চুক্তি সম্পাদন করেছ মসজিদুল-হারামের নিকট। অতএব, যে পর্যন্ত তারা তোমাদের জন্যে সরল থাকে, তোমরাও তাদের জন্য সরল থাক। নিঃসন্দেহের আল্লাহ সাবধানীদের পছন্দ করেন।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mccxliii{কিরূপে? তারা তোমাদের উপর জয়ী হলে তোমাদের আত্নীয়তার ও অঙ্গীকারের কোন মর্যাদা দেবে না। তারা মুখে তোমাদের সন্তুষ্ট করে, কিন্তু তাদের অন্তরসমূহ তা অস্বীকার করে, আর তাদের অধিকাংশ প্রতিশ্রুতি ভঙ্গকারী।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mccxliv{তারা আল্লাহর আয়াত সমূহ নগন্য মুল্যে বিক্রয় করে, অতঃপর লোকদের নিবৃত রাখে তাঁর পথ থেকে, তারা যা করে চলছে, তা অতি নিকৃষ্ট।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mccxlv{তারা মর্যাদা দেয় না কোন মুসলমানের ক্ষেত্রে আত্নীয়তার, আর না অঙ্গীকারের। আর তারাই সীমালংঘনকারী।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mccxlvi{অবশ্য তারা যদি তওবা করে, নামায কায়েম করে আর যাকাত আদায় করে, তবে তারা তোমাদের দ্বীনী ভাই। আর আমি বিধানসমূহে জ্ঞানী লোকদের জন্যে সর্বস্তরে র্বণনা করে থাকি।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mccxlvii{আর যদি ভঙ্গ করে তারা তাদের শপথ প্রতিশ্রুতির পর এবং বিদ্রুপ করে তোমাদের দ্বীন সম্পর্কে, তবে কুফর প্রধানদের সাথে যুদ্ধ কর। কারণ, এদের কেন শপথ নেই যাতে তারা ফিরে আসে।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mccxlviii{তোমরা কি সেই দলের সাথে যুদ্ধ করবে না; যারা ভঙ্গ করেছে নিজেদের শপথ এবং সঙ্কল্প নিয়েছে রসূলকে বহিস্কারের? আর এরাই প্রথম তোমাদের সাথে বিবাদের সূত্রপাত করেছে। তোমরা কি তাদের ভয় কর? অথচ তোমাদের ভয়ের অধিকতর যোগ্য হলেন আল্লাহ, যদি তোমরা মুমিন হও।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mccxlix{যুদ্ধ কর ওদের সাথে, আল্লাহ তোমাদের হস্তে তাদের শাস্তি দেবেন। তাদের লাঞ্ছিত করবেন, তাদের বিরুদ্ধে তোমাদের জয়ী করবেন এবং মুসলমানদের অন্তরসমূহ শান্ত করবেন।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mccl{এবং তাদের মনের ক্ষোভ দূর করবেন। আর আল্লাহ যার প্রতি ইচ্ছা ক্ষমাশীল হবে, আল্লাহ সর্বজ্ঞ, প্রজ্ঞাময়।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mccli{তোমরা কি মনে কর যে, তোমাদের ছেড়ে দেয়া হবে এমনি, যতক্ষণ না আল্লাহ জেনে নেবেন তোমাদের কে যুদ্ধ করেছে এবং কে আল্লাহ, তাঁর রসূল ও মুসলমানদের ব্যতীত অন্য কাউকে অন্তরঙ্গ বন্ধুরূপে গ্রহণ করা থেকে বিরত রয়েছে। আর তোমরা যা কর সে বিষয়ে আল্লাহ সবিশেষ অবহিত।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mcclii{মুশরিকরা যোগ্যতা রাখে না আল্লাহর মসজিদ আবাদ করার, যখন তারা নিজেরাই নিজেদের কুফরীর স্বীকৃতি দিচ্ছে। এদের আমল বরবাদ হবে এবং এরা আগুনে স্থায়ীভাবে বসবাস করবে।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mccliii{নিঃসন্দেহে তারাই আল্লাহর মসজিদ আবাদ করবে যারা ঈমান এনেছে আল্লাহর প্রতি ও শেষ দিনের প্রতি এবং কায়েম করেছে নামায ও আদায় করে যাকাত; আল্লাহ ব্যতীত আর কাউকে ভয় করে না। অতএব, আশা করা যায়, তারা হেদায়েত প্রাপ্তদের অন্তর্ভূক্ত হবে।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mccliv{তোমরা কি হাজীদের পানি সরবরাহ ও মসজিদুল-হারাম আবাদকরণকে সেই লোকের সমান মনে কর, যে ঈমান রাখে আল্লাহ ও শেষ দিনের প্রতি এবং যুদ্ধ করেছে আল্লাহর রাহে, এরা আল্লাহর দৃষ্টিতে সমান নয়, আর আল্লাহ জালেম লোকদের হেদায়েত করেন না।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mcclv{যারা ঈমান এনেছে, দেশ ত্যাগ করেছে এবং আল্লাহর রাহে নিজেদের জান ও মাল দিয়ে জেহাদ করেছে, তাদের বড় মর্যাদা রয়েছে আল্লাহর কাছে আর তারাই সফলকাম।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mcclvi{তাদের সুসংবাদ দিচ্ছেন তাদের পরওয়ারদেগার স্বীয় দয়া ও সন্তোষের এবং জান্নাতের, সেখানে আছে তাদের জন্য স্থায়ী শান্তি।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mcclvii{তথায় তারা থাকবে চিরদিন। নিঃসন্দেহে আল্লাহর কাছে আছে মহাপুরস্কার।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mcclviii{হে ঈমানদারগণ! তোমরা স্বীয় পিতা ও ভাইদের অভিভাবকরূপে গ্রহণ করো না, যদি তারা ঈমান অপেক্ষা কুফরকে ভালবাসে। আর তোমাদের যারা তাদের অভিভাবকরূপে গ্রহণ করে তারা সীমালংঘনকারী।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mcclix{বল, তোমাদের নিকট যদি তোমাদের পিতা তোমাদের সন্তান, তোমাদের ভাই তোমাদের পত্নী, তোমাদের গোত্র তোমাদের অর্জিত ধন-সম্পদ, তোমাদের ব্যবসা যা বন্ধ হয়ে যাওয়ার ভয় কর এবং তোমাদের বাসস্থান-যাকে তোমরা পছন্দ কর-আল্লাহ, তাঁর রসূল ও তাঁর রাহে জেহাদ করা থেকে অধিক প্রিয় হয়, তবে অপেক্ষা কর, আল্লাহর বিধান আসা পর্যন্ত, আর আল্লাহ ফাসেক সম্প্রদায়কে হেদায়েত করেন না।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mcclx{আল্লাহ তোমাদের সাহায্য করেছেন অনেক ক্ষেত্রে এবং হোনাইনের দিনে, যখন তোমাদের সংখ্যধিক্য তোমাদের প্রফুল্ল করেছিল, কিন্তু তা তোমাদের কোন কাজে আসেনি এবং পৃথিবী প্রশস্ত হওয়া সত্তেও তোমাদের জন্য সংকুচিত হয়েছিল। অতঃপর পৃষ্ঠ প্রদর্শন করে পলায়ন করেছিলে।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mcclxi{তারপর আল্লাহ নাযিল করেন নিজের পক্ষ থেকে সান্ত্বনা, তাঁর রসূল ও মুমিনদের প্রতি এবং অবতীর্ণ করেন এমন সেনাবাহিনী যাদের তোমরা দেখতে পাওনি। আর শাস্তি প্রদান করেন কাফেরদের এবং এটি হল কাফেরদের কর্মফল।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mcclxii{এরপর আল্লাহ যাদের প্রতি ইচ্ছা তওবার তওফীক দেবেন, আর আল্লাহ অতীব ক্ষমাশীল, পরম দয়ালু।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mcclxiii{হে ঈমানদারগণ! মুশরিকরা তো অপবিত্র। সুতরাং এ বছরের পর তারা যেন মসজিদুল-হারামের নিকট না আসে। আর যদি তোমরা দারিদ্রে?480; আশংকা কর, তবে আল্লাহ চাইলে নিজ করুনায় ভবিষ্যতে তোমাদের অভাবমুক্ত করে দেবেন। নিঃসন্দেহে আল্লাহ সর্বজ্ঞ, প্রজ্ঞাময়।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mcclxiv{তোমরা যুদ্ধ কর আহলে-কিতাবের ঐ লোকদের সাথে, যারা আল্লাহ ও রোজ হাশরে ঈমান রাখে না, আল্লাহ ও তাঁর রসূল যা হারাম করে দিয়েছেন তা হারাম করে না এবং গ্রহণ করে না সত্য ধর্ম, যতক্ষণ না করজোড়ে তারা জিযিয়া প্রদান করে।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mcclxv{ইহুদীরা বলে ওযাইর আল্লাহর পুত্র এবং নাসারারা বলে ‘মসীহ আল্লাহর পুত্র’। এ হচ্ছে তাদের মুখের কথা। এরা পূর্ববর্তী কাফেরদের মত কথা বলে। আল্লাহ এদের ধ্বংস করুন, এরা কোন উল্টা পথে চলে যাচ্ছে।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mcclxvi{তারা তাদের পন্ডিত ও সংসার-বিরাগীদিগকে তাদের পালনকর্তারূপে গ্রহণ করেছে আল্লাহ ব্যতীত এবং মরিয়মের পুত্রকেও। অথচ তারা আদিষ্ট ছিল একমাত্র মাবুদের এবাদতের জন্য। তিনি ছাড়া কোন মাবুদ নেই, তারা তাঁর শরীক সাব্যস্ত করে, তার থেকে তিনি পবিত্র।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mcclxvii{তারা তাদের মুখের ফুৎকারে আল্লাহর নূরকে নির্বাপিত করতে চায়। কিন্তু আল্লাহ অবশ্যই তাঁর নূরের পূর্ণতা বিধান করবেন, যদিও কাফেররা তা অপ্রীতিকর মনে করে।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mcclxviii{তিনিই প্রেরণ করেছেন আপন রসূলকে হেদায়েত ও সত্য দ্বীন সহকারে, যেন এ দ্বীনকে অপরাপর দ্বীনের উপর জয়যুক্ত করেন, যদিও মুশরিকরা তা অপ্রীতিকর মনে করে।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mcclxix{হে ঈমানদারগণ! পন্ডিত ও সংসারবিরাগীদের অনেকে লোকদের মালামাল অন্যায়ভাবে ভোগ করে চলছে এবং আল্লাহর পথ থেকে লোকদের নিবৃত রাখছে। আর যারা স্বর্ণ ও রূপা জমা করে রাখে এবং তা ব্যয় করে না আল্লাহর পথে, তাদের কঠোর আযাবের সুসংবাদ শুনিয়ে দিন।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mcclxx{সে দিন জাহান্নামের আগুনে তা উত্তপ্ত করা হবে এবং তার দ্বারা তাদের ললাট, পার্শ্ব ও পৃষ্ঠদেশকে দগ্ধ করা হবে (সেদিন বলা হবে), এগুলো যা তোমরা নিজেদের জন্যে জমা রেখেছিলে, সুতরাং এক্ষণে আস্বাদ গ্রহণ কর জমা করে রাখার।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mcclxxi{নিশ্চয় আল্লাহর বিধান ও গননায় মাস বারটি, আসমানসমূহ ও পৃথিবী সৃষ্টির দিন থেকে। তন্মধ্যে চারটি সম্মানিত। এটিই সুপ্রতিষ্ঠিত বিধান; সুতরাং এর মধ্যে তোমরা নিজেদের প্রতি অত্যাচার করো না। আর মুশরিকদের সাথে তোমরা যুদ্ধ কর সমবেতভাবে, যেমন তারাও তোমাদের সাথে যুদ্ধ করে যাচ্ছে সমবেতভাবে। আর মনে রেখো, আল্লাহ মুত্তাকীনদের সাথে রয়েছেন।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mcclxxii{এই মাস পিছিয়ে দেয়ার কাজ কেবল কুফরীর মাত্রা বৃদ্ধি করে, যার ফলে কাফেরগণ গোমরাহীতে পতিত হয়। এরা হালাল করে নেয় একে এক বছর এবং হারাম করে নেয় অন্য বছর, যাতে তারা গণনা পূর্ণ করে নেয় আল্লাহর নিষিদ্ধ মাসগুলোর। অতঃপর হালাল করে নেয় আল্লাহর হারামকৃত মাসগুলোকে। তাদের মন্দকাজগুলো তাদের জন্যে শোভনীয় করে দেয়া হল। আর আল্লাহ কাফের সম্প্রদায়কে হেদায়েত করেন না।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mcclxxiii{হে ঈমানদারগণ, তোমাদের কি হল, যখন আল্লাহর পথে বের হবার জন্যে তোমাদের বলা হয়, তখন মাটি জড়িয়ে ধর, তোমরা কি আখেরাতের পরিবর্তে দুনিয়ার জীবনে পরিতুষ্ট হয়ে গেলে? অথচ আখেরাতের তুলনায় দুনিয়ার জীবনের উপকরণ অতি অল্প।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mcclxxiv{যদি বের না হও, তবে আল্লাহ তোমাদের মর্মন্তুদ আযাব দেবেন এবং অপর জাতিকে তোমাদের স্থলাভিষিক্ত করবেন। তোমরা তাঁর কোন ক্ষতি করতে পারবে না, আর আল্লাহ সর্ববিষয়ে শক্তিমান।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mcclxxv{যদি তোমরা তাকে (রসূলকে) সাহায্য না কর, তবে মনে রেখো, আল্লাহ তার সাহায্য করেছিলেন, যখন তাকে কাফেররা বহিষ্কার করেছিল, তিনি ছিলেন দু’জনের একজন, যখন তারা গুহার মধ্যে ছিলেন। তখন তিনি আপন সঙ্গীকে বললেন বিষন্ন হয়ো না, আল্লাহ আমাদের সাথে আছেন। অতঃপর আল্লাহ তার প্রতি স্বীয় সান্তনা নাযিল করলেন এবং তাঁর সাহায্যে এমন বাহিনী পাঠালেন, যা তোমরা দেখনি। বস্তুতঃ আল্লাহ কাফেরদের মাথা নীচু করে দিলেন আর আল্লাহর কথাই সদা সমুন্নত এবং আল্লাহ পরাক্রমশালী, প্রজ্ঞাময়।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mcclxxvi{তোমরা বের হয়ে পড় স্বল্প বা প্রচুর সরঞ্জামের সাথে এবং জেহাদ কর আল্লাহর পথে নিজেদের মাল ও জান দিয়ে, এটি তোমাদের জন্যে অতি উত্তম, যদি তোমরা বুঝতে পার।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mcclxxvii{যদি আশু লাভের সম্ভাবনা থাকতো এবং যাত্রাপথও সংক্ষিপ্ত হতো, তবে তারা অবশ্যই আপনার সহযাত্রী হতো, কিন্তু তাদের নিকট যাত্রাপথ সুদীর্ঘ মনে হল। আর তারা এমনই শপথ করে বলবে, আমাদের সাধ্য থাকলে অবশ্যই তোমাদের সাথে বের হতাম, এরা নিজেরাই নিজেদের বিনষ্ট করছে, আর আল্লাহ জানেন যে, এরা মিথ্যাবাদী।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mcclxxviii{আল্লাহ আপনাকে ক্ষমা করুন, আপনি কেন তাদের অব্যাহতি দিলেন, যে পর্যন্ত না আপনার কাছে পরিষ্কার হয়ে যেত সত্যবাদীরা এবং জেনে নিতেন মিথ্যাবাদীদের।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mcclxxix{আল্লাহ ও রোজ কেয়ামতের প্রতি যাদের ঈমান রয়েছে তারা মাল ও জান দ্বারা জেহাদ করা থেকে আপনার কাছে অব্যাহতি কামনা করবে না, আর আল্লাহ সাবধানীদের ভাল জানেন।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mcclxxx{নিঃসন্দেহে তারাই আপনার কাছে অব্যাহতি চায়, যারা আল্লাহ ও রোজ কেয়ামতে ঈমান রাখে না এবং তাদের অন্তর সন্দেহগ্রস্ত হয়ে পড়েছে, সুতরাং সন্দেহের আবর্তে তারা ঘুরপাক খেয়ে চলেছে।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mcclxxxi{আর যদি তারা বের হবার সংকল্প নিত, তবে অবশ্যই কিছু সরঞ্জাম প্রস্তুত করতো। কিন্তু তাদের উত্থান আল্লাহর পছন্দ নয়, তাই তাদের নিবৃত রাখলেন এবং আদেশ হল বসা লোকদের সাথে তোমরা বসে থাক।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mcclxxxii{যদি তোমাদের সাথে তারা বের হত, তবে তোমাদের অনিষ্ট ছাড়া আর কিছু বৃদ্ধি করতো না, আর অশ্ব ছুটাতো তোমাদের মধ্যে বিভেদ সৃষ্টির উদ্দেশে। আর তোমাদের মাঝে রয়েছে তাদের গুপ্তচর। বস্তুতঃ আল্লাহ যালিমদের ভালভাবেই জানেন।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mcclxxxiii{তারা পূর্বে থেকেই বিভেদ সৃষ্টির সুযোগ সন্ধানে ছিল এবং আপনার কার্যসমূহ উল্টা-পাল্টা করে দিচ্ছিল। শেষ পর্যন্ত সত্য প্রতিশ্রুতি এসে গেল এবং জয়ী হল আল্লাহর হুকুম, যে অবস্থায় তারা মন্দবোধ করল।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mcclxxxiv{আর তাদের কেউ বলে, আমাকে অব্যাহতি দিন এবং পথভ্রষ্ট করবেন না। শোনে রাখ, তারা তো পূর্ব থেকেই পথভ্রষ্ট এবং নিঃসন্দেহে জাহান্নাম এই কাফেরদের পরিবেষ্টন করে রয়েছে।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mcclxxxv{আপনার কোন কল্যাণ হলে তারা মন্দবোধ করে এবং কোন বিপদ উপস্থিত হলে তারা বলে, আমরা পূর্ব থেকেই নিজেদের কাজ সামলে নিয়েছি এবং ফিরে যায় উল্লসিত মনে।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mcclxxxvi{আপনি বলুন, আমাদের কাছে কিছুই পৌঁছবে না, কিন্তু যা আল্লাহ আমাদের জন্য রেখেছেন; তিনি আমাদের কার্যনির্বাহক। আল্লাহর উপরই মুমিনদের ভরসা করা উচিত।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mcclxxxvii{আপনি বলুন, তোমরা তো তোমাদের জন্যে দুটি কল্যাণের একটি প্রত্যাশা কর; আর আমরা প্রত্যাশায় আছি তোমাদের জন্যে যে, আল্লাহ তোমাদের আযাব দান করুন নিজের পক্ষ থেকে অথবা আমাদের হস্তে। সুতরাং তোমরা অপেক্ষা কর, আমরাও তোমাদের সাথে অপেক্ষমাণ।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mcclxxxviii{আপনি বলুন, তোমরা ইচ্ছায় অর্থ ব্যয় কর বা অনিচ্ছায়, তোমাদের থেকে তা কখনো কবুল হবে না, তোমরা নাফরমানের দল।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mcclxxxix{তাদের অর্থ ব্যয় কবুল না হওয়ার এছাড়া আর কোন কারণ নেই যে, তারা আল্লাহ ও তাঁর রসূলের প্রতি অবিশ্বাসী, তারা নামাযে আসে অলসতার সাথে ব্যয় করে সঙ্কুচিত মনে।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mccxc{সুতরাং তাদের ধন-সম্পদ ও সন্তান-সন্ততি যেন আপনাকে বিস্মিত না করে। আল্লাহর ইচ্ছা হল এগুলো দ্বারা দুনিয়ার জীবনে তাদের আযাবে নিপতিত রাখা এবং প্রাণবিয়োগ হওয়া কুফরী অবস্থায়।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mccxci{তারা আল্লাহর নামে হলফ করে বলে যে, তারা তোমাদেরই অন্তর্ভুক্ত, অথচ তারা তোমাদের অন্তর্ভূক্ত নয়, অবশ্য তারা তোমাদের ভয় করে।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mccxcii{তারা কোন আশ্রয়স্থল, কোন গুহা বা মাথা গোঁজার ঠাই পেলে সেদিকে পলায়ন করবে দ্রুতগতিতে।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mccxciii{তাদের মধ্যে এমন লোকও রয়েছে যারা সদকা বন্টনে আপনাকে দোষারূপ করে। এর থেকে কিছু পেলে সন্তুষ্ট হয় এবং না পেলে বিক্ষুব্ধ হয়।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mccxciv{কতই না ভাল হত, যদি তারা সন্তুষ্ট হত আল্লাহ ও তার রসূলের উপর এবং বলত, আল্লাহই আমাদের জন্যে যথেষ্ট, আল্লাহ আমাদের দেবেন নিজ করুণায় এবং তাঁর রসূলও, আমরা শুধু আল্লাহকেই কামনা করি।\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mccxcv{যাকাত হল কেবল ফকির, মিসকীন, যাকাত আদায় কারী ও যাদের চিত্ত আকর্ষণ প্রয়োজন তাদে হক এবং তা দাস-মুক্তির জন্যে-ঋণ গ্রস্তদের জন্য, আল্লাহর পথে জেহাদকারীদের জন্যে এবং মুসাফিরদের জন্যে, এই হল আল্লাহর নির্ধারিত বিধান। আল্লাহ সর্বজ্ঞ, প্রজ্ঞাময়।\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mccxcvi{আর তাদের মধ্যে কেউ কেউ নবীকে ক্লেশ দেয়, এবং বলে, এ লোকটি তো কানসর্বস্ব। আপনি বলে দিন, কান হলেও তোমাদেরই মঙ্গলের জন্য, আল্লাহর উপর বিশ্বাস রাখে এবং বিশ্বাস রাখে মুসলমানদের কথার উপর। বস্তুতঃ তোমাদের মধ্যে যারা ঈমানদার তাদের জন্য তিনি রহমতবিশেষ। আর যারা আল্লাহর রসূলের প্রতি কুৎসা রটনা করে, তাদের জন্য রয়েছে বেদনাদায়ক আযাব।\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mccxcvii{তোমাদের সামনে আল্লাহর কসম খায় যাতে তোমাদের রাযী করতে পারে। অবশ্য তারা যদি ঈমানদার হয়ে থাকে, তবে আল্লাহকে এবং তাঁর রসূলকে রাযী করা অত্যন্ত জরুরী।\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mccxcviii{তারা কি একথা জেনে নেয়নি যে, আল্লাহর সাথে এবং তাঁর রসূলের সাথে যে মোকাবেলা করে তার জন্যে নির্ধারিত রয়েছে দোযখ; তাতে সব সময় থাকবে। এটিই হল মহা-অপমান।\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mccxcix{মুনাফেকরা এ ব্যাপারে ভয় করে যে, মুসলমানদের উপর না এমন কোন সূরা নাযিল হয়, যাতে তাদের অন্তরের গোপন বিষয় অবহিত করা হবে। সুতরাং আপনি বলে দিন, ঠাট্টা-বিদ্রপ করতে থাক; আল্লাহ তা অবশ্যই প্রকাশ করবেন যার ব্যাপারে তোমরা ভয় করছ।\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mccc{আর যদি তুমি তাদের কাছে জিজ্ঞেস কর, তবে তারা বলবে, আমরা তো কথার কথা বলছিলাম এবং কৌতুক করছিলাম। আপনি বলুন, তোমরা কি আল্লাহর সাথে, তাঁর হুকুম আহকামের সাথে এবং তাঁর রসূলের সাথে ঠাট্টা করছিলে?\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mccci{ছলনা কর না, তোমরা যে কাফের হয়ে গেছ ঈমান প্রকাশ করার পর। তোমাদের মধ্যে কোন কোন লোককে যদি আমি ক্ষমা করে দেইও, তবে অবশ্য কিছু লোককে আযাবও দেব। কারণ, তারা ছিল গোনাহগার।\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mcccii{মুনাফেক নর-নারী সবারই গতিবিধি একরকম; শিখায় মন্দ কথা, ভাল কথা থেকে বারণ করে এবং নিজ মুঠো বন্ধ রাখে। আল্লাহকে ভুলে গেছে তার, কাজেই তিনিও তাদের ভূলে গেছেন নিঃসন্দেহে মুনাফেকরাই নাফরমান।\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mccciii{ওয়াদা করেছেন আল্লাহ, মুনাফেক পুরুষ ও মুনাফেক নারীদের এবং কাফেরদের জন্যে দোযখের আগুনের-তাতে পড়ে থাকবে সর্বদা। সেটাই তাদের জন্যে যথেষ্ট। আর আল্লাহ তাদের প্রতি অভিসম্পাত করেছেন এবং তাদের জন্যে রয়েছে স্থায়ী আযাব।\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mccciv{যেমন করে তোমাদের পূর্ববর্তী লোকেরা তোমাদের চেয়ে বেশী ছিল শক্তিতে এবং ধন-সম্পদের ও সন্তান-সন্ততির অধিকারীও ছিল বেশী; অতঃপর উপকৃত হয়েছে নিজেদের ভাগের দ্বারা আবার তোমরা ফায়দা উঠিয়েছ তোমাদের ভাগের দ্বারা-যেমন করে তোমাদের পূর্ববর্তীরা ফায়দা উঠিয়েছিল নিজেদের ভাগের দ্বারা। আর তোমরাও বলছ তাদেরই চলন অনুযায়ী। তারা ছিল সে লোক, যাদের আমলসমূহ নিঃশেষিত হয়ে গেছে দুনিয়া ও আখেরাতে। আর তারাই হয়েছে ক্ষতির সম্মুখীন।\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mcccv{তাদের সংবাদ কি এদের কানে এসে পৌঁছায়নি, যারা ছিল তাদের পূর্বে; নূহের আ’দের ও সামুদের সম্প্রদায় এবং ইব্রাহীমের সম্প্রদায়ের এবং মাদইয়ানবাসীদের? এবং সেসব জনপদের যেগুলোকে উল্টে দেয়া হয়েছিল? তাদের কাছে এসেছিলেন তাদের নবী পরিষ্কার নির্দেশ নিয়ে। বস্তুতঃ আল্লাহ তো এমন ছিলেন না যে, তাদের উপর জুলুম করতেন, কিন্তু তারা নিজেরাই নিজেদের উপর জুলুম করতো।\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@mcccvi{আর ঈমানদার পুরুষ ও ঈমানদার নারী একে অপরের সহায়ক। তারা ভাল কথার শিক্ষা দেয় এবং মন্দ থেকে বিরত রাখে। নামায প্রতিষ্ঠা করে, যাকাত দেয় এবং আল্লাহ ও তাঁর রসূলের নির্দেশ অনুযায়ী জীবন যাপন করে। এদেরই উপর আল্লাহ তা’আলা দয়া করবেন। নিশ্চয়ই আল্লাহ পরাক্রমশীল, সুকৌশলী।\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@mcccvii{আল্লাহ ঈমানদার পুরুষ ও ঈমানদার নারীদের প্রতিশ্রুতি দিয়েছেনে কানন-কুঞ্জের, যার তলদেশে প্রবাহিত হয় প্রস্রবণ। তারা সে গুলোরই মাঝে থাকবে। আর এসব কানন-কুঞ্জে থাকবে পরিচ্ছন্ন থাকার ঘর। বস্তুতঃ এ সমুদয়ের মাঝে সবচেয়ে বড় হল আল্লাহর সন্তুষ্টি। এটিই হল মহান কৃতকার্যতা।\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@mcccviii{হে নবী, কাফেরদের সাথে যুদ্ধ করুন এবং মুনাফেকদের সাথে তাদের সাথে কঠোরতা অবলম্বন করুন। তাদের ঠিকানা হল দোযখ এবং তাহল নিকৃষ্ট ঠিকানা।\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@mcccix{তারা কসম খায় যে, আমরা বলিনি, অথচ নিঃসন্দেহে তারা বলেছে কুফরী বাক্য এবং মুসলমান হবার পর অস্বীকৃতিজ্ঞাপনকারী হয়েছে। আর তারা কামনা করেছিল এমন বস্তুর যা তারা প্রাপ্ত হয়নি। আর এসব তারই পরিণতি ছিল যে, আল্লাহ ও তাঁর রসূল তাদেরকে সম্পদশালী করে দিয়েছিলেন নিজের অনুগ্রহের মাধ্যমে। বস্তুতঃ এরা যদি তওবা করে নেয়, তবে তাদের জন্য মঙ্গল। আর যদি তা না মানে, তবে তাদের কে আযাব দেবেন আল্লাহ তা’আলা, বেদনাদায়ক আযাব দুনিয়া ও আখেরাতে। অতএব, বিশ্বচরাচরে তাদের জন্য কোন সাহায্যকারী-সমর্থক নেই।\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@mcccx{তাদের মধ্যে কেউ কেউ রয়েছে যারা আল্লাহ তা’আলার সাথে ওয়াদা করেছিল যে, তিনি যদি আমাদের প্রতি অনুগ্রহ দান করেন, তবে অবশ্যই আমরা ব্যয় করব এবং সৎকর্মীদের অন্তর্ভুক্ত হয়ে থাকব।\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@mcccxi{অতঃপর যখন তাদেরকে স্বীয় অনুগ্রহের মাধ্যমে দান করা হয়, তখন তাতে কার্পণ্য করেছে এবং কৃত ওয়াদা থেকে ফিরে গেছে তা ভেঙ্গে দিয়ে।\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@mcccxii{তারপর এরই পরিণতিতে তাদের অন্তরে কপটতা স্থান করে নিয়েছে সেদিন পর্যন্ত, যেদিন তার তাঁর সাথে গিয়ে মিলবে। তা এজন্য যে, তারা আল্লাহর সাথে কৃত ওয়াদা লংঘন করেছিল এবং এজন্যে যে, তারা মিথ্যা কথা বলতো।\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@mcccxiii{তারা কি জেনে নেয়নি যে, আল্লাহ তাদের রহস্য ও শলা-পরামর্শ সম্পর্কে অবগত এবং আল্লাহ খুব ভাল করেই জানেন সমস্ত গোপন বিষয় ?\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@mcccxiv{সে সমস্ত লোক যারা ভৎর্সনা-বিদ্রূপ করে সেসব মুসলমানদের প্রতি যারা মন খুলে দান-খয়রাত করে এবং তাদের প্রতি যাদের কিছুই নেই শুধুমাত্র নিজের পরিশ্রমলব্দ বস্তু ছাড়া। অতঃপর তাদের প্রতি ঠাট্টা করে। আল্লাহ তাদের প্রতি ঠাট্টা করেছেন এবং তাদের জন্য রয়েছে বেদনাদায়ক আযাব।\qt@no{(79)}}
\qt@newcmd\qurantrans@bn@mcccxv{তুমি তাদের জন্য ক্ষমা প্রার্থনা কর আর না কর। যদি তুমি তাদের জন্য সত্তর বারও ক্ষমাপ্রার্থনা কর, তথাপি কখনোই তাদেরকে আল্লাহ ক্ষমা করবেন না। তা এজন্য যে, তারা আল্লাহকে এবং তাঁর রসূলকে অস্বীকার করেছে। বস্তুতঃ আল্লাহ না-ফারমানদেরকে পথ দেখান না।\qt@no{(80)}}
\qt@newcmd\qurantrans@bn@mcccxvi{পেছনে থেকে যাওয়া লোকেরা আল্লাহর রসূল থেকে বিচ্ছিন্ন হয়ে বসে থাকতে পেরে আনন্দ লাভ করেছে; আর জান ও মালের দ্বারা আল্লাহর রাহে জেহাদ করতে অপছন্দ করেছে এবং বলেছে, এই গরমের মধ্যে অভিযানে বের হয়ো না। বলে দাও, উত্তাপে জাহান্নামের আগুন প্রচন্ডতম। যদি তাদের বিবেচনা শক্তি থাকত।\qt@no{(81)}}
\qt@newcmd\qurantrans@bn@mcccxvii{অতএব, তারা সামান্য হেসে নিক এবং তারা তাদের কৃতকর্মের বদলাতে অনেক বেশী কাঁদবে।\qt@no{(82)}}
\qt@newcmd\qurantrans@bn@mcccxviii{বস্তুতঃ আল্লাহ যদি তোমাকে তাদের মধ্য থেকে কোন শ্রেণীবিশেষের দিকে ফিরিয়ে নিয়ে যান এবং অতঃপর তারা তোমার কাছে অভিযানে বেরোবার অনুমতি কামনা করে, তবে তুমি বলো যে, তোমরা কখনো আমার সাথে বেরোবে না এবং আমার পক্ষ হয়ে কোন শত্রুর সাথে যুদ্ধ করবে না, তোমরা তো প্রথমবারে বসে থাকা পছন্দ করেছ, কাজেই পেছনে পড়ে থাকা লোকদের সাথেই বসে থাক।\qt@no{(83)}}
\qt@newcmd\qurantrans@bn@mcccxix{আর তাদের মধ্য থেকে কারো মৃত্যু হলে তার উপর কখনও নামায পড়বেন না এবং তার কবরে দাঁড়াবেন না। তারা তো আল্লাহর প্রতি অস্বীকৃতি জ্ঞাপন করেছে এবং রসূলের প্রতিও। বস্তুতঃ তারা না ফরমান অবস্থায় মৃত্যু বরণ করেছে।\qt@no{(84)}}
\qt@newcmd\qurantrans@bn@mcccxx{আর বিস্মিত হয়ো না তাদের ধন সম্পদ ও সন্তান-সন্তুতির দরুন। আল্লাহ তো এই চান যে, এ সবের কারণে তাদেরকে আযাবের ভেতরে রাখবেন দুনিয়ায় এবং তাদের প্রাণ নির্গত হওয়া পর্যন্ত যেন তারা কাফেরই থাকে।\qt@no{(85)}}
\qt@newcmd\qurantrans@bn@mcccxxi{আর যখন নাযিল হয় কোন সূরা যে, তোমরা ঈমান আন আল্লাহর উপর, তাঁর রসূলের সাথে একাত্ন হয়ে; তখন বিদায় কামনা করে তাদের সামর্থ?476;ান লোকেরা এবং বলে আমাদের অব্যাহতি দিন, যাতে আমরা (নিস্ক্রিয়ভাবে) বসে থাকা লোকদের সাথে থেকে যেতে পারি।\qt@no{(86)}}
\qt@newcmd\qurantrans@bn@mcccxxii{তারা পেছনে পড়ে থাকা লোকদের সাথে থেকে যেতে পেরে আনন্দিত হয়েছে এবং মোহর এঁটে দেয়া হয়েছে তাদের অন্তরসমূহের উপর। বস্তুতঃ তারা বোঝে না।\qt@no{(87)}}
\qt@newcmd\qurantrans@bn@mcccxxiii{কিন্তু রসূল এবং সেসব লোক যারা ঈমান এনেছে, তাঁর সাথে তারা যুদ্ধ করেছে নিজেদের জান ও মালের দ্বারা। তাদেরই জন্য নির্ধারিত রয়েছে কল্যাণসমূহ এবং তারাই মুক্তির লক্ষ্যে উপনীত হয়েছে।\qt@no{(88)}}
\qt@newcmd\qurantrans@bn@mcccxxiv{আল্লাহ তাদের জন্য তৈরী করে রেখেছেন কানন-কুঞ্জ, যার তলদেশে প্রবাহিত রয়েছে প্রস্রবণ। তারা তাতে বাস করবে অনন্তকাল। এটাই হল বিরাট কৃতকার্যতা।\qt@no{(89)}}
\qt@newcmd\qurantrans@bn@mcccxxv{আর ছলনাকারী বেদুঈন লোকেরা এলো, যাতে তাদের অব্যাহতি লাভ হতে পারে এবং নিবৃত্ত থাকতে পারে তাদেরই যারা আল্লাহ ও রসূলের সাথে মিথ্যা বলে ছিল। এবার তাদের উপর শীগ্রই আসবে বেদনাদায়ক আযাব যারা কাফের।\qt@no{(90)}}
\qt@newcmd\qurantrans@bn@mcccxxvi{দূর্বল, রুগ্ন, ব্যয়ভার বহনে অসমর্থ লোকদের জন্য কোন অপরাধ নেই, যখন তারা মনের দিক থেকে পবিত্র হবে আল্লাহ ও রসূলের সাথে। নেককারদের উপর অভিযোগের কোন পথ নেই। আর আল্লাহ হচ্ছেন ক্ষমাকারী দয়ালু।\qt@no{(91)}}
\qt@newcmd\qurantrans@bn@mcccxxvii{আর না আছে তাদের উপর যারা এসেছে তোমার নিকট যেন তুমি তাদের বাহন দান কর এবং তুমি বলেছ, আমার কাছে এমন কোন বস্তু নেই যে, তার উপর তোমাদের সওয়ার করাব তখন তারা ফিরে গেছে অথচ তখন তাদের চোখ দিয়ে অশ্রু বইতেছিল এ দুঃখে যে, তারা এমন কোন বস্তু পাচ্ছে না যা ব্যয় করবে।\qt@no{(92)}}
\qt@newcmd\qurantrans@bn@mcccxxviii{অভিযোগের পথ তো তাদের ব্যাপারে রয়েছে, যারা তোমার নিকট অব্যাহতি কামনা করে অথচ তারা সম্পদশালী। যারা পেছনে পড়ে থাকা লোকদের সাথে থাকতে পেরে আনন্দিত হয়েছে। আর আল্লাহ মোহর এঁটে দিয়েছেন তাদের অন্তরসমূহে। বস্তুতঃ তারা জানতেও পারেনি।\qt@no{(93)}}
\qt@newcmd\qurantrans@bn@mcccxxix{তুমি যখন তাদের কাছে ফিরে আসবে, তখন তারা তোমাদের নিকট ছল-ছুতা নিয়ে উপস্থিত হবে; তুমি বলো, ছল কারো না, আমি কখনো তোমাদের কথা শুনব না; আমাকে আল্লাহ তা’আলা তোমাদের অবস্থা সম্পর্কে অবহিত করে দিয়েছেন। আর এখন তোমাদের কর্ম আল্লাহই দেখবেন এবং তাঁর রসূল। তারপর তোমরা প্রত্যাবর্তিত হবে সেই গোপন ও আগোপন বিষয়ে অবগত সত্তার নিকট। তিনিই তোমাদের বাতলে দেবেন যা তোমরা করছিলে।\qt@no{(94)}}
\qt@newcmd\qurantrans@bn@mcccxxx{এখন তারা তোমার সামনে আল্লাহর কসম খাবে, যখন তুমি তাদের কাছে ফিরে যাবে, যেন তুমি তাদের ক্ষমা করে দাও। সুতরাং তুমি তাদের ক্ষমা কর-নিঃসন্দেহে এরা অপবিত্র এবং তাদের কৃতকর্মের বদলা হিসাবে তাদের ঠিকানা হলো দোযখ।\qt@no{(95)}}
\qt@newcmd\qurantrans@bn@mcccxxxi{তারা তোমার সামনে কসম খাবে যাতে তুমি তাদের প্রতি রাযী হয়ে যাও। অতএব, তুমি যদি রাযী হয়ে যাও তাদের প্রতি তবু আল্লাহ তা’আলা রাযী হবেন না, এ নাফরমান লোকদের প্রতি।\qt@no{(96)}}
\qt@newcmd\qurantrans@bn@mcccxxxii{বেদুইনরা কুফর ও মোনাফেকীতে অত্যন্ত কঠোর হয়ে থাকে এবং এরা সেসব নীতি-কানুন না শেখারই যোগ্য যা আল্লাহ তা’আলা তাঁর রসূলের উপর নাযিল করেছেন। বস্তুতঃ আল্লাহ সব কিছুই জানেন এবং তিনি অত্যন্ত কুশলী।\qt@no{(97)}}
\qt@newcmd\qurantrans@bn@mcccxxxiii{আবার কোন কোন বেদুইন এমন ও রয়েছে যারা নিজেদের ব্যয় করাকে জরিমানা। বলে গন্য করে এবং তোমার উপর কোন দুর্দিন আসে কিনা সে অপেক্ষায় থাকে। তাদেরই উপর দুর্দিন আসুক। আর আল্লাহ হচ্ছেন শ্রবণকারী, পরিজ্ঞাত।\qt@no{(98)}}
\qt@newcmd\qurantrans@bn@mcccxxxiv{আর কোন কোন বেদুইন হল তারা, যারা ঈমান আনে আল্লাহর উপর, কেয়ামত দিনের উপর এবং নিজেদের ব্যয়কে আল্লাহর নৈকট্য এবং রসূলের দোয়া লাভের উপায় বলে গণ্য করে। জেনো! তাই হল তাদের ক্ষেত্রে নৈকট্য। আল্লাহ তাদেরকে নিজের রহমতের অন্তর্ভূক্ত করবেন। নিশ্চয়ই আল্লাহ ক্ষমাশীল, করুনাময়।\qt@no{(99)}}
\qt@newcmd\qurantrans@bn@mcccxxxv{আর যারা সর্বপ্রথম হিজরতকারী ও আনছারদের মাঝে পুরাতন, এবং যারা তাদের অনুসরণ করেছে, আল্লাহ সে সমস্ত লোকদের প্রতি সন্তুষ্ট হয়েছেন এবং তারাও তাঁর প্রতি সন্তুষ্ট হয়েছে। আর তাদের জন্য প্রস্তুত রেখেছেন কানন-কুঞ্জ, যার তলদেশ দিয়ে প্রবাহিত প্রস্রবণসমূহ। সেখানে তারা থাকবে চিরকাল। এটাই হল মহান কৃতকার্যতা।\qt@no{(100)}}
\qt@newcmd\qurantrans@bn@mcccxxxvi{আর কিছু কিছু তোমার আশ-পাশের মুনাফেক এবং কিছু লোক মদীনাবাসী কঠোর মুনাফেকীতে অনঢ়। তুমি তাদের জান না; আমি তাদের জানি। আমি তাদেরকে আযাব দান করব দু’বার, তারপর তাদেরকে নিয়ে যাওয়া হবে মহান আযাবের দিকে।\qt@no{(101)}}
\qt@newcmd\qurantrans@bn@mcccxxxvii{আর কোন কোন লোক রয়েছে যারা নিজেদের পাপ স্বীকার করেছে, তারা মিশ্রিত করেছে একটি নেককাজ ও অন্য একটি বদকাজ। শীঘ্রই আল্লাহ হয়ত তাদেরকে ক্ষমা করে দেবেন। নিঃঃসন্দেহে আল্লাহ ক্ষমাশীল করুণাময়।\qt@no{(102)}}
\qt@newcmd\qurantrans@bn@mcccxxxviii{তাদের মালামাল থেকে যাকাত গ্রহণ কর যাতে তুমি সেগুলোকে পবিত্র করতে এবং সেগুলোকে বরকতময় করতে পার এর মাধ্যমে। আর তুমি তাদের জন্য দোয়া কর, নিঃসন্দেহে তোমার দোয়া তাদের জন্য সান্ত্বনা স্বরূপ। বস্তুতঃ আল্লাহ সবকিছুই শোনেন, জানেন।\qt@no{(103)}}
\qt@newcmd\qurantrans@bn@mcccxxxix{তারা কি একথা জানতে পারেনি যে, আল্লাহ নিজেই স্বীয় বান্দাদের তওবা কবুল করেন এবং যাকাত গ্রহণ করেন? বস্তুতঃ আল্লাহই তওবা কবুলকারী, করুণাময়।\qt@no{(104)}}
\qt@newcmd\qurantrans@bn@mcccxl{আর তুমি বলে দাও, তোমরা আমল করে যাও, তার পরবর্তীতে আল্লাহ দেখবেন তোমাদের কাজ এবং দেখবেন রসূল ও মুসলমানগণ। তাছাড়া তোমরা শীগ্রই প্রত্যাবর্তিত হবে তাঁর সান্নিধ্যে যিনি গোপন ও প্রকাশ্য বিষয়ে অবগত। তারপর তিনি জানিয়ে দেবেন তোমাদেরকে যা করতে।\qt@no{(105)}}
\qt@newcmd\qurantrans@bn@mcccxli{আবার অনেক লোক রয়েছে যাদের কাজকর্ম আল্লাহর নির্দেশের উপর স্থগিত রয়েছে; তিনি হয় তাদের আযাব দেবেন না হয় তাদের ক্ষমা করে দেবেন। বস্তুতঃ আল্লাহ সব কিছুই জ্ঞাত, বিজ্ঞতাসম্পন্ন।\qt@no{(106)}}
\qt@newcmd\qurantrans@bn@mcccxlii{আর যারা নির্মাণ করেছে মসজিদ জিদের বশে এবং কুফরীর তাড়নায় মুমিনদের মধ্যে বিভেদ সৃস্টির উদ্দেশ্যে এবং ঐ লোকের জন্য ঘাটি স্বরূপ যে পূর্ব থেকে আল্লাহ ও তাঁর রসূলের সাথে যুদ্ধ করে আসছে, আর তারা অবশ্যই শপথ করবে যে, আমরা কেবল কল্যাণই চেয়েছি। পক্ষান্তরে আল্লাহ সাক্ষী যে, তারা সবাই মিথ্যুক।\qt@no{(107)}}
\qt@newcmd\qurantrans@bn@mcccxliii{তুমি কখনো সেখানে দাড়াবে না, তবে যে মসজিদের ভিত্তি রাখা হয়েছে তাকওয়ার উপর প্রথম দিন থেকে, সেটিই তোমার দাঁড়াবার যোগ্য স্থান। সেখানে রয়েছে এমন লোক, যারা পবিত্রতাকে ভালবাসে। আর আল্লাহ পবিত্র লোকদের ভালবাসেন।\qt@no{(108)}}
\qt@newcmd\qurantrans@bn@mcccxliv{যে ব্যাক্তি স্বীয় গৃহের ভিত্তি রেখেছে কোন গর্তের কিনারায় যা ধ্বসে পড়ার নিকটবর্তী এবং অতঃপর তা ওকে নিয়ে দোযখের আগুনে পতিত হয়। আর আল্লাহ জালেমদের পথ দেখান না।\qt@no{(109)}}
\qt@newcmd\qurantrans@bn@mcccxlv{তাদের নির্মিত গৃহটি তাদের অন্তরে সদা সন্দেহের উদ্রেক করে যাবে যে পর্যন্ত না তাদের অন্তরগুলো চৌচির হয়ে যায়। আর আল্লাহ সর্বজ্ঞ প্রজ্ঞাময়।\qt@no{(110)}}
\qt@newcmd\qurantrans@bn@mcccxlvi{আল্লাহ ক্রয় করে নিয়েছেন মুসলমানদের থেকে তাদের জান ও মাল এই মূল্যে যে, তাদের জন্য রয়েছে জান্নাত। তারা যুদ্ধ করে আল্লাহর রাহেঃ অতঃপর মারে ও মরে। তওরাত, ইঞ্জিল ও কোরআনে তিনি এ সত্য প্রতিশ্রুতিতে অবিচল। আর আল্লাহর চেয়ে প্রতিশ্রুতি রক্ষায় কে অধিক? সুতরাং তোমরা আনন্দিত হও সে লেন-দেনের উপর, যা তোমরা করছ তাঁর সাথে। আর এ হল মহান সাফল্য।\qt@no{(111)}}
\qt@newcmd\qurantrans@bn@mcccxlvii{তারা তওবাকারী, এবাদতকারী, শোকরগোযার, (দুনিয়ার সাথে) সম্পর্কচ্ছেদকারী, রুকু ও সিজদা আদায়কারী, সৎকাজের আদেশ দানকারী ও মন্দ কাজ থেকে নিবৃতকারী এবং আল্লাহর দেওয়া সীমাসমূহের হেফাযতকারী। বস্তুতঃ সুসংবাদ দাও ঈমানদারদেরকে।\qt@no{(112)}}
\qt@newcmd\qurantrans@bn@mcccxlviii{নবী ও মুমিনের উচিত নয় মুশরেকদের মাগফেরাত কামনা করে, যদিও তারা আত্নীয় হোক একথা সুস্পষ্ট হওয়ার পর যে তারা দোযখী।\qt@no{(113)}}
\qt@newcmd\qurantrans@bn@mcccxlix{আর ইব্রাহীম কর্তৃক স্বীয় পিতার মাগফেরাত কামনা ছিল কেবল সেই প্রতিশ্রুতির কারণে, যা তিনি তার সাথে করেছিলেন। অতঃপর যখন তাঁর কাছে একথা প্রকাশ পেল যে, সে আল্লাহর শত্রু তখন তার সাথে সম্পর্ক ছিন্ন করে নিলেন। নিঃসন্দেহে ইব্রাহীম ছিলেন বড় কোমল হৃদয়, সহনশীল।\qt@no{(114)}}
\qt@newcmd\qurantrans@bn@mcccl{আর আল্লাহ কোন জাতিকে হেদায়েত করার পর পথভ্রষ্ট করেন না যতক্ষণ না তাদের জন্য পরিষ্কারভাবে বলে দেন সেসব বিষয় যা থেকে তাদের বেঁচে থাকা দরকার। নিঃসন্দেহে আল্লাহ সব বিষয়ে ওয়াকেফহাল।\qt@no{(115)}}
\qt@newcmd\qurantrans@bn@mcccli{নিশ্চয় আল্লাহরই জন্য আসমানসমূহ ও যমীনের সাম্রাজ্য। তিনিই জিন্দা করেন ও মৃত্যু ঘটান, আর আল্লাহ ব্যতীত তোমাদের জন্য কোন সহায়ও নেই, কোন সাহায্যকারীও নেই।\qt@no{(116)}}
\qt@newcmd\qurantrans@bn@mccclii{আল্লাহ দয়াশীল নবীর প্রতি এবং মুহাজির ও আনসারদের প্রতি, যারা কঠিন মহূর্তে নবীর সঙ্গে ছিল, যখন তাদের এক দলের অন্তর ফিরে যাওয়ার উপক্রম হয়েছিল। অতঃপর তিনি দয়াপরবশ হন তাদের প্রতি। নিঃসন্দেহে তিনি তাদের প্রতি দয়াশীল ও করুনাময়।\qt@no{(117)}}
\qt@newcmd\qurantrans@bn@mcccliii{এবং অপর তিনজনকে যাদেরকে পেছনে রাখা হয়েছিল, যখন পৃথিবী বিস্তৃত হওয়া সত্বেও তাদের জন্য সঙ্কুচিত হয়ে গেল এবং তাদের জীবন দূর্বিসহ হয়ে উঠলো; আর তারা বুঝতে পারলো যে, আল্লাহ ব্যতীত আর কোন আশ্রয়স্থল নেই-অতঃপর তিনি সদয় হলেন তাদের প্রতি যাতে তারা ফিরে আসে। নিঃসন্দেহে আল্লাহ দয়াময় করুণাশীল।\qt@no{(118)}}
\qt@newcmd\qurantrans@bn@mcccliv{হে ঈমানদারগণ, আল্লাহকে ভয় কর এবং সত্যবাদীদের সাথে থাক।\qt@no{(119)}}
\qt@newcmd\qurantrans@bn@mccclv{মদীনাবাসী ও পাশ্ববর্তী পল্লীবাসীদের উচিত নয় রসূলুল্লাহর সঙ্গ ত্যাগ করে পেছনে থেকে যাওয়া এবং রসূলের প্রাণ থেকে নিজেদের প্রাণকে অধিক প্রিয় মনে করা। এটি এজন্য যে, আল্লাহর পথে যে তৃষ্ণা, ক্লান্তি ও ক্ষুধা তাদের স্পর্শ করে এবং তাদের এমন পদক্ষেপ যা কাফেরদের মনে ক্রোধের কারণ হয় আর শত্রুদের পক্ষ থেকে তারা যা কিছু প্রাপ্ত হয়-তার প্রত্যেকটির পরিবর্তে তাদের জন্য লিখিত হয়ে নেক আমল। নিঃসন্দেহে আল্লাহ সৎকর্মশীল লোকদের হক নষ্ট করেন না।\qt@no{(120)}}
\qt@newcmd\qurantrans@bn@mccclvi{আর তারা অল্প-বিস্তর যা কিছু ব্যয় করে, যত প্রান্তর তারা অতিক্রম করে, তা সবই তাদের নামে লেখা হয়, যেন আল্লাহ তাদের কৃতকর্মসমূহের উত্তম বিনিময় প্রদান করেন।\qt@no{(121)}}
\qt@newcmd\qurantrans@bn@mccclvii{আর সমস্ত মুমিনের অভিযানে বের হওয়া সঙ্গত নয়। তাই তাদের প্রত্যেক দলের একটি অংশ কেন বের হলো না, যাতে দ্বীনের জ্ঞান লাভ করে এবং সংবাদ দান করে স্বজাতিকে, যখন তারা তাদের কাছে প্রত্যাবর্তন করবে, যেন তারা বাঁচতে পারে।\qt@no{(122)}}
\qt@newcmd\qurantrans@bn@mccclviii{হে ঈমানদারগণ, তোমাদের নিকটবর্তী কাফেরদের সাথে যুদ্ধ চালিয়ে যাও এবং তারা তোমাদের মধ্যে কঠোরতা অনুভব করুক আর জেনে রাখ, আল্লাহ মুত্তাকীদের সাথে রয়েছেন।\qt@no{(123)}}
\qt@newcmd\qurantrans@bn@mccclix{আর যখন কোন সূরা অবতীর্ণ হয়, তখন তাদের কেউ কেউ বলে, এ সূরা তোমাদের মধ্যেকার ঈমান কতটা বৃদ্ধি করলো? অতএব যারা ঈমানদার, এ সূরা তাদের ঈমান বৃদ্ধি করেছে এবং তারা আনন্দিত হয়েছে।\qt@no{(124)}}
\qt@newcmd\qurantrans@bn@mccclx{বস্তুতঃ যাদের অন্তরে ব্যাধি রয়েছে এটি তাদের কলুষের সাথে আরো কলুষ বৃদ্ধি করেছে এবং তারা কাফের অবস্থায়ই মৃত্যু বরণ করলো।\qt@no{(125)}}
\qt@newcmd\qurantrans@bn@mccclxi{তারা কি লক্ষ্য করে না, প্রতি বছর তারা দু’একবার বিপর্যস্ত হচ্ছে, অথচ, তারা এরপরও তওবা করে না কিংবা উপদেশ গ্রহণ করে না।\qt@no{(126)}}
\qt@newcmd\qurantrans@bn@mccclxii{আর যখনই কোন সূরা অবতীর্ণ হয়, তখন তারা একে অন্যের দিকে তাকায় যে, কোন মুসলমান তোমাদের দেখছে কি-না-অতঃপর সরে পড়ে। আল্লাহ ওদের অন্তরকে সত্য বিমুখ করে দিয়েছেন! নিশ্চয়ই তারা নির্বোধ সম্প্রদায়।\qt@no{(127)}}
\qt@newcmd\qurantrans@bn@mccclxiii{তোমাদের কাছে এসেছে তোমাদের মধ্য থেকেই একজন রসূল। তোমাদের দুঃখ-কষ্ট তার পক্ষে দুঃসহ। তিনি তোমাদের মঙ্গলকামী, মুমিনদের প্রতি স্নেহশীল, দয়াময়।\qt@no{(128)}}
\qt@newcmd\qurantrans@bn@mccclxiv{এ সত্ত্বেও যদি তারা বিমুখ হয়ে থাকে, তবে বলে দাও, আল্লাহই আমার জন্য যথেষ্ট, তিনি ব্যতীত আর কারো বন্দেগী নেই। আমি তাঁরই ভরসা করি এবং তিনিই মহান আরশের অধিপতি।\qt@no{(129)}}
\qt@newcmd\qurantrans@bn@mccclxv{\basmalahbn আলিফ-লাম-র, এগুলো হেকমতপূর্ণ কিতাবের আয়াত।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mccclxvi{মানুষের কাছে কি আশ্চর্য লাগছে যে, আমি ওহী পাঠিয়েছি তাদেরই মধ্য থেকে একজনের কাছে যেন তিনি মানুষকে সতর্ক করেন এবং সুসংবাদ শুনিয়ে দেন ঈমনাদারগণকে যে, তাঁদের জন্য সত্য মর্যাদা রয়েছে তাঁদের পালনকর্তার কাছে। কাফেররা বলতে লাগল, নিঃসন্দেহে এ লোক প্রকাশ্য যাদুকর।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mccclxvii{নিশ্চয়ই তোমাদের পালনকর্তা আল্লাহ যিনি তৈরী করেছেন আসমান ও যমীনকে ছয় দিনে, অতঃপর তিনি আরশের উপর অধিষ্ঠিত হয়েছেন। তিনি কার্য পরিচালনা করেন। কেউ সুপারিশ করতে পাবে না তবে তাঁর অনুমতি ছাড়া ইনিই আল্লাহ তোমাদের পালনকর্তা। অতএব, তোমরা তাঁরই এবাদত কর। তোমরা কি কিছুই চিন্তা কর না ?\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mccclxviii{তাঁর কাছেই ফিরে যেতে হবে তোমাদের সবাইকে, আল্লাহর ওয়াদা সত্য, তিনিই সৃষ্টি করেন প্রথমবার আবার পুনর্বার তৈরী করবেন তাদেরকে বদলা দেয়ার জন্য যারা ঈমান এনেছে এবং নেক কাজ করেছে ইনসাফের সাথে। আর যারা কাফের হয়েছে, তাদের পান করতে হবে ফুটন্ত পানি এবং ভোগ করতে হবে যন্ত্রনাদায়ক আযাব এ জন্যে যে, তারা কুফরী করছিল।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mccclxix{তিনিই সে মহান সত্তা, যিনি বানিয়েছেন সুর্যকে উজ্জল আলোকময়, আর চন্দ্রকে স্নিগ্ধ আলো বিতরণকারীরূপে এবং অতঃপর নির্ধারিত করেছেন এর জন্য মনযিল সমূহ, যাতে করে তোমরা চিনতে পার বছরগুলোর সংখ্যা ও হিসাব। আল্লাহ এই সমস্ত কিছু এমনিতেই সৃষ্টি করেননি, কিন্তু যথার্থতার সাথে। তিনি প্রকাশ করেন লক্ষণসমূহ সে সমস্ত লোকের জন্য যাদের জ্ঞান আছে।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mccclxx{নিশ্চয়ই রাত-দিনের পরিবর্তনের মাঝে এবং যা কিছু তিনি সৃষ্টি করেছেন আসমান ও যমীনে, সবই হল নিদর্শন সেসব লোকের জন্য যারা ভয় করে।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mccclxxi{অবশ্যই যেসব লোক আমার সাক্ষাৎ লাভের আশা রাখে না এবং পার্থিব জীবন নিয়েই উৎফুল্ল রয়েছে, তাতেই প্রশান্তি অনুভব করেছে এবং যারা আমার নির্দশনসমূহ সম্পর্কে বেখবর।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mccclxxii{এমন লোকদের ঠিকানা হল আগুন সেসবের বদলা হিসাবে যা তারা অর্জন করছিল।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mccclxxiii{অবশ্য যেসব লোক ঈমান এনেছে এবং সৎকাজ করেছে, তাদেরকে হেদায়েত দান করবেন তাদের পালনকর্তা, তাদের ঈমানের মাধ্যমে। এমন সুসময় কানন-কুঞ্জের প্রতি যার তলদেশে প্রবাহিত হয় প্রস্রবণসমূহ।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mccclxxiv{সেখানে তাদের প্রার্থনা হল ‘পবিত্র তোমার সত্তা হে আল্লাহ’। আর শুভেচ্ছা হল সালাম আর তাদের প্রার্থনার সমাপ্তি হয়, ‘সমস্ত প্রশংসা বিশ্বপালক আল্লাহর জন্য’ বলে।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mccclxxv{আর যদি আল্লাহ তা’আলা মানুষকে যথাশীঘ্র অকল্যাণ পৌঁছে দেন যতশীঘ্র তার কামনা করে, তাহলে তাদের আশাই শেষ করে দিতে হত। সুতরাং যাদের মনে আমার সাক্ষাতের আশা নেই, আমি তাদেরকে তাদের দুষ্টুমিতে ব্যতিব্যস্ত ছেড়ে দিয়ে রাখি।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mccclxxvi{আর যখন মানুষ কষ্টের সম্মুখীন হয়, শুয়ে বসে, দাঁড়িয়ে আমাকে ডাকতে থাকে। তারপর আমি যখন তা থেকে মুক্ত করে দেই, সে কষ্ট যখন চলে যায় তখন মনে হয় কখনো কোন কষ্টেরই সম্মুখীন হয়ে যেন আমাকে ডাকেইনি। এমনিভাবে মনঃপুত হয়েছে নির্ভয় লোকদের যা তারা করেছে।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mccclxxvii{অবশ্য তোমাদের পূর্বে বহু দলকে ধ্বংস করে দিয়েছি, তখন তারা জালেম হয়ে গেছে। অথচ রসূল তাদের কাছেও এসব বিষয়ের প্রকৃষ্ট নির্দেশ নিয়ে এসেছিলেন। কিন্তু কিছুতেই তারা ঈমান আনল না। এমনিভাবে আমি শাস্তি দিয়ে থাকি পাপি সম্প্রদায়কে।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mccclxxviii{অতঃপর আমি তোমাদেরকে যমীনে তাদের পর প্রতিনিধি বানিয়েছি যাতে দেখতে পারি তোমরা কি কর।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mccclxxix{আর যখন তাদের কাছে আমার প্রকৃষ্ট আয়াত সমূহ পাঠ করা হয়, তখন সে সমস্ত লোক বলে, যাদের আশা নেই আমার সাক্ষাতের, নিয়ে এসো কোন কোরআন এটি ছাড়া, অথবা একে পরিবর্তিত করে দাও। তাহলে বলে দাও, একে নিজের পক্ষ থেকে পরিবর্তিত করা আমার কাজ নয়। আমি সে নির্দেশেরই আনুগত্য করি, যা আমার কাছে আসে। আমি যদি স্বীয় পরওয়ারদেগারের নাফরমানী করি, তবে কঠিন দিবসের আযাবের ভয় করি।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mccclxxx{বলে দাও, যদি আল্লাহ চাইতেন, তবে আমি এটি তোমাদের সামনে পড়তাম না, আর নাইবা তিনি তোমাদেরেকে অবহিত করতেন এ সম্পর্কে। কারণ আমি তোমাদের মাঝে ইতিপূর্বেও একটা বয়স অতিবাহিত করেছি। তারপরেও কি তোমরা চিন্তা করবে না?\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mccclxxxi{অতঃপর তার চেয়ে বড় জালেম, কে হবে, যে আল্লাহর প্রতি অপবাদ আরোপ করেছে কিংবা তাঁর আয়াতসমূহকে মিথ্যা বলে অভিহিত করছে? কস্মিনকালেও পাপীদের কোন কল্যাণ হয় না।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mccclxxxii{আর উপাসনা করে আল্লাহকে বাদ দিয়ে এমন বস্তুর, যা না তাদের কোন ক্ষতিসাধন করতে পারে, না লাভ এবং বলে, এরা তো আল্লাহর কাছে আমাদের সুপারিশকারী। তুমি বল, তোমরা কি আল্লাহকে এমন বিষয়ে অবহিত করছ, যে সম্পর্কে তিনি অবহিত নন আসমান ও যমীনের মাঝে ? তিনি পুতঃপবিত্র ও মহান সে সমস্ত থেকে যাকে তোমরা শরীক করছ।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mccclxxxiii{আর সমস্ত মানুষ একই উম্মতভুক্ত ছিল, পরে পৃথক হয়ে গেছে। আর একটি কথা যদি তোমার পরওয়ারদেগারের পক্ষ থেকে পূর্ব নির্ধারিত না হয়ে যেত; তবে তারা যে বিষয়ে বিরোধ করছে তার মীমাংসা হয়ে যেত।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mccclxxxiv{বস্তুতঃ তারা বলে, তাঁর কাছে তাঁর পরওয়ারদেগারের পক্ষ থেকে কোন নির্দেশ এল না কেন? বলে দাও গায়েবের কথা আল্লাহই জানেন। আমি ও তোমাদের সাথে অপেক্ষায় রইলাম।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mccclxxxv{আর যখন আমি আস্বাদন করাই স্বীয় রহমত সে কষ্টের পর, যা তাদের ভোগ করতে হয়েছিল, তখনই তারা আমার শক্তিমত্তার মাঝে নানা রকম ছলনা তৈরী করতে আরম্ভ করবে। আপনি বলে দিন, আল্লাহ সবচেয়ে দ্রুত কলা-কৌশল তৈরী করতে পারেন। নিশ্চয়ই আমাদের ফেরেশতারা লিখে রাখে তোমাদের ছল-চাতুরী।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mccclxxxvi{তিনিই তোমাদের ভ্রমন করান স্থলে ও সাগরে। এমনকি যখন তোমরা নৌকাসমূহে আরোহণ করলে আর তা লোকজনকে অনুকূল হাওয়ায় বয়ে নিয়ে চলল এবং তাতে তারা আনন্দিত হল, নৌকাগুলোর উপর এল তীব্র বাতাস, আর সর্বদিক থেকে সেগুলোর উপর ঢেউ আসতে লাগল এবং তারা জানতে পারল যে, তারা অবরুদ্ধ হয়ে পড়েছে, তখন ডাকতে লাগল আল্লাহকে তাঁর এবাদতে নিঃস্বার্থ হয়ে যদি তুমি আমাদেরকে এ বিপদ থেকে উদ্ধার করে তোল, তাহলে নিঃসন্দেহে আমরা কৃতজ্ঞ থাকব।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mccclxxxvii{তারপর যখন তাদেরকে আল্লাহ বাঁচিয়ে দিলেন, তখনই তারা পৃথিবীতে অনাচার করতে লাগল অন্যায় ভাবে। হে মানুষ! শোন, তোমাদের অনাচার তোমাদেরই উপর পড়বে। পার্থিব জীবনের সুফল ভোগ করে নাও-অতঃপর আমার নিকট প্রত্যাবর্তন করতে হবে। তখন আমি বাতলে দেব, যা কিছু তোমরা করতে।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mccclxxxviii{পার্থিব জীবনের উদাহরণ তেমনি, যেমনি আমি আসমান থেকে পানি বর্ষন করলাম, পরে তা মিলিত সংমিশ্রিত হয়ে তা থেকে যমীনের শ্যামল উদ্ভিদ বেরিয়ে এল যা মানুষ ও জীব-জন্তুরা খেয়ে থাকে। এমনকি যমীন যখন সৌন্দর্য সুষমায় ভরে উঠলো আর যমীনের অধিকর্তারা ভাবতে লাগল, এগুলো আমাদের হাতে আসবে, হঠাৎ করে তার উপর আমার নির্দেশ এল রাত্রে কিংবা দিনে, তখন সেগুলোকে কেটে স্তুপাকার করে দিল যেন কাল ও এখানে কোন আবাদ ছিল না। এমনিভাবে আমি খোলাখুলি বর্ণনা করে থাকি নিদর্শণসমূহ সে সমস্ত লোকদের জন্য যারা লক্ষ্য করে।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mccclxxxix{আর আল্লাহ শান্তি-নিরাপত্তার আলয়ের প্রতি আহবান জানান এবং যাকে ইচ্ছা সরলপথ প্রদর্শন করেন।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mcccxc{যারা সৎকর্ম করেছে তাদের জন্য রয়েছে কল্যাণ এবং তারও চেয়ে বেশী। আর তাদের মুখমন্ডলকে আবৃত করবে না মলিনতা কিংবা অপমান। তারাই হল জান্নাতবাসী, এতেই তারা বসবাস করতে থাকবে অনন্তকাল।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mcccxci{আর যারা সঞ্চয় করেছে অকল্যাণ অসৎ কর্মের বদলায় সে পরিমাণ অপমান তাদের চেহারাকে আবৃত করে ফেলবে। কেউ নেই তাদেরকে বাঁচাতে পারে আল্লাহর হাত থেকে। তাদের মুখমন্ডল যেন ঢেকে দেয়া হয়েছে আধাঁর রাতের টুকরো দিয়ে। এরা হল দোযখবাসী। এরা এতেই থাকবে অনন্তকাল।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mcccxcii{আর যেদিন আমি তাদের সবাইকে সমবেত করব; আর যারা শেরক করত তাদেরকে বলবঃ তোমরা এবং তোমাদের শরীকরা নিজ নিজ জায়গায় দাঁড়িয়ে যাও-অতঃপর তাদেরকে পারস্পরিক বিচ্ছিন্ন করে দেব, তখন তাদের শরীকরা বলবে, তোমরা তো আমাদের উপাসনা-বন্দেগী করনি।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mcccxciii{বস্তুতঃ আল্লাহ আমাদের ও তোমাদের মাঝে সাক্ষী হিসাবে যথেষ্ট। আমরা তোমাদের বন্দেগী সম্পর্কে জানতাম না।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mcccxciv{সেখানে প্রত্যেকে যাচাই করে নিতে পারবে যা কিছু সে ইতিপূর্বে করেছিল এবং আল্লাহর প্রতি প্রত্যাবর্তন করবে যিনি তাদের প্রকৃত মালিক, আর তাদের কাছ থেকে দূরে যেতে থাকবে যারা মিথ্যা বলত।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mcccxcv{তুমি জিজ্ঞেস কর, কে রুযী দান করে তোমাদেরকে আসমান থেকে ও যমীন থেকে, কিংবা কে তোমাদের কান ও চোখের মালিক? তাছাড়া কে জীবিতকে মৃতের ভেতর থেকে বের করেন এবং কেইবা মৃতকে জীবিতের মধ্য থেকে বের করেন? কে করেন কর্ম সম্পাদনের ব্যবস্থাপনা? তখন তারা বলে উঠবে, আল্লাহ! তখন তুমি বলো তারপরেও ভয় করছ না?\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mcccxcvi{অতএব, এ আল্লাহই তোমাদের প্রকৃত পালনকর্তা। আর সত্য প্রকাশের পরে (উদভ্রান্ত ঘুরার মাঝে) কি রয়েছে গোমরাহী ছাড়া? সুতরাং কোথায় ঘুরছ?\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mcccxcvii{এমনিভাবে সপ্রমাণিত হয়ে গেছে তোমার পরওয়ারদেগারের বাণী সেসব নাফরমানের ব্যাপারে যে, এরা ঈমান আনবে না।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mcccxcviii{বল, আছে কি কেউ তোমাদের শরীকদের মাঝে যে সৃষ্টি কে পয়দা করতে পারে এবং আবার জীবিত করতে পারে? বল, আল্লাহই প্রথমবার সৃষ্টি করেন এবং অতঃপর তার পুনরুদ্ভব করবেন। অতএব, কোথায় ঘুরপাক খাচ্ছে?\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mcccxcix{জিজ্ঞেস কর, আছে কি কেউ তোমাদের শরীকদের মধ্যে যে সত্য-সঠিক পথ প্রদর্শন করবে? বল, আল্লাহই সত্য-সঠিক পথ প্রদর্শন করেন, সুতরাং এমন যে লোক সঠিক পথ দেখাবে তার কথা মান্য করা কিংবা যে লোক নিজে নিজে পথ খুঁজে পায় না, তাকে পথ দেখানো কর্তব্য। অতএব, তোমাদের কি হল, কেমন তোমাদের বিচার?\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mcd{বস্তুতঃ তাদের অধিকাংশই শুধু আন্দাজ-অনুমানের উপর চলে, অথচ আন্দাজ-অনুমান সত্যের বেলায় কোন কাজেই আসে না। আল্লাহ ভাল করেই জানেন, তারা যা কিছু করে।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mcdi{আর কোরআন সে জিনিস নয় যে, আল্লাহ ব্যতীত কেউ তা বানিয়ে নেবে। অবশ্য এটি পূর্ববর্তী কালামের সত্যায়ন করে এবং সে সমস্ত বিষয়ের বিশ্লেষণ দান করে যা তোমার প্রতি দেয়া হয়েছে, যাতে কোন সন্দেহ নেই-তোমার বিশ্বপালনকর্তার পক্ষ থেকে।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mcdii{মানুষ কি বলে যে, এটি বানিয়ে এনেছ? বলে দাও, তোমরা নিয়ে এসো একটিই সূরা, আর ডেকে নাও, যাদেরকে নিতে সক্ষম হও আল্লাহ ব্যতীত, যদি তোমরা সত্যবাদী হয়ে থাক।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mcdiii{কিন্তু কথা হল এই যে, তারা মিথ্যা প্রতিপন্ন করতে আরম্ভ করেছে যাকে বুঝতে, তারা অক্ষম। অথচ এখনো এর বিশ্লেষণ আসেনি। এমনিভাবে মিথ্যা প্রতিপন্ন করেছে তাদের পূর্ববর্তীরা। অতএব, লক্ষ্য করে দেখ, কেমন হয়েছে পরিণতি।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mcdiv{আর তাদের মধ্যে কেউ কেউ কোরআনকে বিশ্বাস করবে এবং কেউ কেউ বিশ্বাস করবে না। বস্তুতঃ তোমার পরওয়ারদেগার যথার্থই জানেন দুরাচারদিগকে।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mcdv{আর যদি তোমাকে মিথ্যা প্রতিপন্ন করে, তবে বল, আমার জন্য আমার কর্ম, আর তোমাদের জন্য তোমাদের কর্ম। তোমাদের দায়-দায়িত্ব নেই আমার কর্মের উপর এবং আমারও দায়-দায়িত্ব নেই তোমরা যা কর সেজন্য।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mcdvi{তাদের কেউ কেউ কান রাখে তোমাদের প্রতি; তুমি বধিরদেরকে কি শোনাবে যদি তাদের বিবেক-বুদ্ধি না থাকে!\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mcdvii{আবার তাদের মধ্যে কেউ কেউ তোমাদের প্রতি দৃষ্টিনিবদ্ধ রাখে; তুমি অন্ধদেরকে কি পথ দেখাবে যদি তারা মোটেও দেখতে না পারে।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mcdviii{আল্লাহ জুলুম করেন না মানুষের উপর, বরং মানুষ নিজেই নিজের উপর জুলুম করে।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mcdix{আর যেদিন তাদেরকে সমবেত করা হবে, যেন তারা অবস্থান করেনি, তবে দিনের একদন্ড একজন অপরজনকে চিনবে। নিঃসন্দেহে ক্ষতিগ্রস্ত হয়েছে যারা মিথ্যা প্রতিপন্ন করেছে আল্লাহর সাথে সাক্ষাতকে এবং সরলপথে আসেনি।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mcdx{আর যদি আমি দেখাই তোমাকে সে ওয়াদাসমূহের মধ্য থেকে কোন কিছু যা আমি তাদের সাথে করেছি, অথবা তোমাকে মৃত্যুদান করি, যাহোক, আমার কাছেই তাদেরকে প্রত্যাবর্তন করতে হবে। বস্তুতঃ আল্লাহ সে সমস্ত কর্মের সাক্ষী যা তারা করে।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mcdxi{আর প্রত্যেক সম্প্রদায়ের একেকজন রসূল রয়েছে। যখন তাদের কাছে তাদের রসূল ন্যায়দন্ডসহ উপস্থিত হল, তখন আর তাদের উপর জুলুম হয় না।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mcdxii{তারা আরো বলে, এ ওয়াদা কবে আসবে, যদি তোমরা সত্যবাদী হয়ে থাক?\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mcdxiii{তুমি বল, আমি আমার নিজের ক্ষতি কিংবা লাভেরও মালিক নই, কিন্তু আল্লাহ যা ইচ্ছা করেন। প্রত্যেক সম্প্রদায়ের জন্যই একেকটি ওয়াদা রয়েছে, যখন তাদের সে ওয়াদা এসে পৌঁছে যাবে, তখন না একদন্ড পেছনে সরতে পারবে, না সামনে ফসকাতে পারবে,।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mcdxiv{তুমি বল, আচ্ছা দেখ তো দেখি, যদি তোমাদের উপর তার আযাব রাতারাতি অথবা দিনের বেলায় এসে পৌঁছে যায়, তবে এর আগে পাপীরা কি করবে?\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mcdxv{তাহলে কি আযাব সংঘটিত হয়ে যাবার পর এর প্রতি বিশ্বাস করবে? এখন স্বীকার করলে? অথচ তোমরা এরই তাকাদা করতে?\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mcdxvi{অতঃপর বলা হবে, গোনাহগারদিগকে, ভোগ করতে থাক অনন্ত আযাব-তোমরা যা কিছু করতে তার তাই প্রতিফল।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mcdxvii{আর তোমার কাছে সংবাদ জিজ্ঞেস করে, এটা কি সত্য ? বলে দাও, অবশ্যই আমার পরওয়ারদেগারের কসম এটা সত্য। আর তোমরা পরিশ্রান্ত করে দিতে পারবে না।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mcdxviii{বস্তুতঃ যদি প্রত্যেক গোনাহগারের কাছে এত পরিমাণ থাকে যা আছে সমগ্র যমীনের মাঝে, আর অবশ্যই যদি সেগুলো নিজের মুক্তির বিনিময়ে দিতে চাইবে আর গোপনে গোপনে অনুতাপ করবে, যখন আযাব দেখবে। বস্তুতঃ তাদের জন্য সিদ্ধান্ত হবে ন্যায়সঙ্গত এবং তাদের উপর জুলম হবে না।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mcdxix{শুনে রাখ, যা কিছু রয়েছে আসমানসমূহে ও যমীনে সবই আল্লাহর। শুনে রাখ, আল্লাহর প্রতিশ্রুতি সত্য। তবে অনেকেই জানে না।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mcdxx{তিনিই জীবন ও মরণ দান করেন এবং তাঁরই কাছে প্রত্যাবর্তন করতে হবে।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mcdxxi{হে মানবকুল, তোমাদের কাছে উপদেশবানী এসেছে তোমাদের পরওয়ারদেগারের পক্ষ থেকে এবং অন্তরের রোগের নিরাময়, হেদায়েত ও রহমত মুসলমানদের জন্য।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mcdxxii{বল, আল্লাহর দয়া ও মেহেরবাণীতে। সুতরাং এরই প্রতি তাদের সন্তুষ্ট থাকা উচিৎ। এটিই উত্তম সে সমুদয় থেকে যা সঞ্চয় করছ।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mcdxxiii{বল, আচ্ছা নিজেই লক্ষ্য করে দেখ, যা কিছু আল্লাহ তোমাদের জন্য রিযিক হিসাবে অবতীর্ণ করেছেন, তোমরা সেগুলোর মধ্য থেকে কোনটাকে হারাম আর কোনটাকে হালাল সাব্যস্ত করেছ? বল, তোমাদের কি আল্লাহ নির্দেশ দিয়েছেন, নাকি আল্লাহর উপর অপবাদ আরোপ করছ?\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mcdxxiv{আর আল্লাহর প্রতি মিথ্যা অপবাদ আরোপকারীদের কি ধারণা কেয়ামত সম্পর্কে? আল্লাহ তো মানুষের প্রতি অনুগ্রহই করেন, কিন্তু অনেকেই কৃতজ্ঞতা স্বীকার করে না।\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mcdxxv{বস্তুতঃ যে কোন অবস্থাতেই তুমি থাক এবং কোরআনের যে কোন অংশ থেকেই পাঠ করা কিংবা যে কোন কাজই তোমরা কর অথচ আমি তোমাদের নিকটে উপস্থিত থাকি যখন তোমরা তাতে আত্ননিয়োগ কর। আর তোমার পরওয়ারদেগার থেকে গোপন থাকে না একটি কনাও, না যমীনের এবং না আসমানের। না এর চেয়ে ক্ষুদ্র কোন কিছু আছে, না বড় যা এই প্রকৃষ্ট কিতাবে নেই।\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mcdxxvi{মনে রেখো যারা আল্লাহর বন্ধু, তাদের না কোন ভয় ভীতি আছে, না তারা চিন্তান্বিত হবে।\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mcdxxvii{যারা ঈমান এনেছে এবং ভয় করতে রয়েছে।\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mcdxxviii{তাদের জন্য সুসংবাদ পার্থিব জীবনে ও পরকালীন জীবনে। আল্লাহর কথার কখনো হের-ফের হয় না। এটাই হল মহা সফলতা।\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mcdxxix{আর তাদের কথায় দুঃখ নিয়ো না। আসলে সমস্ত ক্ষমতা আল্লাহর। তিনিই শ্রবণকারী, সর্বজ্ঞ।\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mcdxxx{শুনছ, আসমানসমূহে ও যমীনে যা কিছু রয়েছে সবই আল্লাহর। আর এরা যারা আল্লাহকে বাদ দিয়ে শরীকদের উপাসনার পেছনে পড়ে আছে-তা আসলে কিছুই নয়। এরা নিজেরই কল্পনার পেছনে পড়ে রয়েছে এবং এছাড়া আর কিছু নয় যে, এরা বুদ্ধি খাটাচ্ছে।\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mcdxxxi{তিনি তোমাদের জন্য তৈরী করেছেন রাত, যাতে করে তোমরা তাতে প্রশান্তি লাভ করতে পার, আর দিন দিয়েছেন দর্শন করার জন্য। নিঃসন্দেহে এতে নিদর্শন রয়েছে সে সব লোকের জন্য যারা শ্রবণ করে।\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mcdxxxii{তারা বলে, আল্লাহ পুত্র সাব্যস্ত করে নিয়েছেন-তিনি পবিত্র, তিনি অমুখাপেক্ষী। যাকিছু রয়েছে আসমান সমূহে ও যমীনে সবই তাঁর। তোমাদের কাছে তার কোন সনদ নেই। কেন তোমরা আল্লাহর প্রতি মিথ্যারোপ কর-যার কোন সনদই তোমাদের কাছে নেই?\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mcdxxxiii{বলে দাও, যারা এরূপ করে তারা অব্যাহতি পায় না।\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mcdxxxiv{পার্থিবজীবনে সামান্যই লাভ, অতঃপর আমার নিকট প্রত্যাবর্তন করতে হবে। তখন আমি তাদেরকে আস্বাদন করাব কঠিন আযাব-তাদেরই কৃত কুফরীর বদলাতে।\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@mcdxxxv{আর তাদেরকে শুনিয়ে দাও নূহের অবস্থা যখন সে স্বীয় সম্প্রদায়কে বলল, হে আমার সম্প্রদায়, যদি তোমাদের মাঝে আমার অবস্থিতি এবং আল্লাহর আয়াতসমূহের মাধ্যমে নসীহত করা ভারী বলে মনে হয়ে থাকে, তবে আমি আল্লাহর উপর ভরসা করছি। এখন তোমরা সবাই মিলে নিজেরদের কর্ম সাব্যস্ত কর এবং এতে তোমাদের শরীকদেরকে সমবেত করে নাও, যাতে তোমাদের মাঝে নিজেদের কাজের ব্যাপারে কোন সন্দেহ-সংশয় না থাকে। অতঃপর আমার সম্পর্কে যা কিছু করার করে ফেল এবং আমাকে অব্যাহতি দিও না।\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@mcdxxxvi{তারপরও যদি বিমুখতা অবলম্বন কর, তবে আমি তোমাদের কাছে কোন রকম বিনিময় কামনা করি না। আমার বিনিময় হল আল্লাহর দায়িত্বে। আর আমার প্রতি নির্দেশ রয়েছে যেন আমি আনুগত্য অবলম্বন করি।\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@mcdxxxvii{তারপরও এরা মিথ্যা প্রতিপন্ন করল। সুতরাং তাকে এবং তার সাথে নৌকায় যারা ছিল তাদের কে বাঁচিয়ে নিয়েছি এবং যথাস্থানে আবাদ করেছি। আর তাদেরকে ডুবিয়ে দিয়েছি যারা আমার কথাকে মিথ্যা প্রতিপন্ন করেছে। সুতরাং লক্ষ্য কর, কেমন পরিণতি ঘটেছে তাদের যাদেরকে ভীতি প্রদর্শন করা হয়েছিল।\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@mcdxxxviii{অনন্তর আমি নূহের পরে বহু নবী-রসূল পাঠিয়েছি তাদের সম্প্রদায়ের প্রতি। তারপর তাদের কাছে তারা প্রকাশ্য দলীল-প্রমাণ উপস্থাপন করেছে, কিন্তু তাদের দ্বারা এমনটি হয়নি যে, ঈমান আনবে সে ব্যাপারে, যাকে তারা ইতিপূর্বে মিথ্যা প্রতিপন্ন করেছিল। এভাবেই আমি মোহর এঁটে দেই সীমালংঘনকারীদের অন্তরসমূহের উপর।\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@mcdxxxix{অতঃপর তাদের পেছনে পাঠিয়েছি আমি মূসা ও হারুনকে, ফেরাউন ও তার সর্দারের প্রতি স্বীয় নির্দেশাবলী সহকারে। অথচ তারা অহংকার করতে আরম্ভ করেছে।\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@mcdxl{বস্তুতঃ তারা ছিল গোনাহগার। তারপর আমার পক্ষ থেকে যখন তাদের কাছে সত্য বিষয় উপস্থিত হল, তখন বলতে লাগলো, এগুলো তো প্রকাশ্য যাদু।\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@mcdxli{মূসা বলল, সত্যের ব্যাপারে একথা বলছ, তা তোমাদের কাছে পৌঁছার পর? একি যাদু? অথচ যারা যাদুকর, তারা সফল হতে পারে না।\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@mcdxlii{তারা বলল, তুমি কি আমাদেরকে সে পথ থেকে ফিরিয়ে দিতে এসেছ যাতে আমরা পেয়েছি আমাদের বাপ-দাদাদেরকে? আর যাতে তোমরা দুইজন এদেশের সর্দারী পেয়ে যেতে পার? আমরা তোমাদেরকে কিছুতেই মানব না।\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@mcdxliii{আর ফেরাউন বলল, আমার কাছে নিয়ে এস সুদক্ষ যাদুকরদিগকে।\qt@no{(79)}}
\qt@newcmd\qurantrans@bn@mcdxliv{তারপর যখন যাদুকররা এল, মূসা তাদেরকে বলল, নিক্ষেপ কর, তোমরা যা কিছু নিক্ষেপ করে থাক।\qt@no{(80)}}
\qt@newcmd\qurantrans@bn@mcdxlv{অতঃপর যখন তারা নিক্ষেপ করল, মূসা বলল, যা কিছু তোমরা এনেছ তা সবই যাদু-এবার আল্লাহ এসব ভন্ডুল করে দিচ্ছেন। নিঃসন্দেহে আল্লাহ দুস্কর্মীদের কর্মকে সুষ্ঠুতা দান করেন না।\qt@no{(81)}}
\qt@newcmd\qurantrans@bn@mcdxlvi{আল্লাহ সত্যকে সত্যে পরিণত করেন স্বীয় নির্দেশে যদিও পাপীদের তা মনঃপুত নয়।\qt@no{(82)}}
\qt@newcmd\qurantrans@bn@mcdxlvii{আর কেউ ঈমান আনল না মূসার প্রতি তাঁর কওমের কতিপয় বালক ছাড়া-ফেরাউন ও তার সর্দারদের ভয়ে যে, এরা না আবার কোন বিপদে ফেলে দেয়। ফেরাউন দেশময় কর্তꦣ2499;ত্বের শিখরে আরোহণ করেছিল। আর সে তার হাত ছেড়ে রেখেছিল।\qt@no{(83)}}
\qt@newcmd\qurantrans@bn@mcdxlviii{আর মূসা বলল, হে আমার সম্প্রদায়, তোমরা যদি আল্লাহর উপর ঈমান এনে থাক, তবে তারই উপর ভরসা কর যদি তোমরা ফরমাবরদার হয়ে থাক।\qt@no{(84)}}
\qt@newcmd\qurantrans@bn@mcdxlix{তখন তারা বলল, আমরা আল্লাহর উপর ভরসা করেছি। হে আমাদের পালনকর্তা, আমাদের উপর এ জালেম কওমের শক্তি পরীক্ষা করিও না।\qt@no{(85)}}
\qt@newcmd\qurantrans@bn@mcdl{আর আমাদেরকে অনুগ্রহ করে ছাড়িয়ে দাও এই কাফেরদের কবল থেকে।\qt@no{(86)}}
\qt@newcmd\qurantrans@bn@mcdli{আর আমি নির্দেশ পাঠালাম মূসা এবং তার ভাইয়ের প্রতি যে, তোমরা তোমাদের জাতির জন্য মিসরের মাটিতে বাস স্থান নির্ধারণ কর। আর তোমাদের ঘরগুলো বানাবে কেবলামুখী করে এবং নামায কায়েম কর আর যারা ঈমানদার তাদেরকে সুসংবাদ দান কর।\qt@no{(87)}}
\qt@newcmd\qurantrans@bn@mcdlii{মূসা বলল, হে আমার পরওয়ারদেগার, তুমি ফেরাউনকে এবং তার সর্দারদেরকে পার্থব জীবনের আড়ম্বর দান করেছ, এবং সম্পদ দান করেছ-হে আমার পরওয়ারদেগার, এ জন্যই যে তারা তোমার পথ থেকে বিপথগামী করব! হে আমার পরওয়ারদেগার, তাদের ধন-সম্পদ ধ্বংস করে দাও এবং তাদের অন্তরগুলোকে কাঠোর করে দাও যাতে করে তারা ততক্ষণ পর্যন্ত ঈমান না আনে যতক্ষণ না বেদনাদায়ক আযাব প্রত্যক্ষ করে নেয়।\qt@no{(88)}}
\qt@newcmd\qurantrans@bn@mcdliii{বললেন, তোমাদের দোয়া মঞ্জুর হয়েছে। অতএব তোমরা দুজন অটল থাকো এবং তাদের পথে চলো না যারা অজ্ঞ।\qt@no{(89)}}
\qt@newcmd\qurantrans@bn@mcdliv{আর বনী-ইসরাঈলকে আমি পার করে দিয়েছি নদী। তারপর তাদের পশ্চাদ্ধাবন করেছে ফেরাউন ও তার সেনাবাহিনী, দুরাচার ও বাড়াবাড়ির উদ্দেশে। এমনকি যখন তারা ডুবতে আরম্ভ করল, তখন বলল, এবার বিশ্বাস করে নিচ্ছি যে, কোন মা’বুদ নেই তাঁকে ছাড়া যাঁর উপর ঈমান এনেছে বনী-ইসরাঈলরা। বস্তুতঃ আমিও তাঁরই অনুগতদের অন্তর্ভুক্ত।\qt@no{(90)}}
\qt@newcmd\qurantrans@bn@mcdlv{এখন একথা বলছ! অথচ তুমি ইতিপূর্বে না-ফরমানী করছিলে। এবং পথভ্রষ্টদেরই অন্তর্ভুক্ত ছিলে।\qt@no{(91)}}
\qt@newcmd\qurantrans@bn@mcdlvi{অতএব আজকের দিনে বাঁচিয়ে দিচ্ছি আমি তোমার দেহকে যাতে তোমার পশ্চাদবর্তীদের জন্য নিদর্শন হতে পারে। আর নিঃসন্দেহে বহু লোক আমার মহাশক্তির প্রতি লক্ষ্য করে না।\qt@no{(92)}}
\qt@newcmd\qurantrans@bn@mcdlvii{আর আমি বনী-ইসরাঈলদিগকে দান করেছি উত্তম স্থান এবং তাদেরকে আহার্য দিয়েছি পবিত্র-পরিচ্ছন্ন বস্তু-সামগ্রী। বস্তুতঃ তাদের মধ্যে মতবিরোধ হয়নি যতক্ষণ না তাদের কাছে এসে পৌছেছে সংবাদ। নিঃসন্দেহে তোমার পরওয়ারদেগার তাদের মাঝে মীমাংসা করে দেবেন কেয়ামতের দিন; যে ব্যাপারে তাদের মাঝে মতবিরোধ হয়েছিল\qt@no{(93)}}
\qt@newcmd\qurantrans@bn@mcdlviii{সুতরাং তুমি যদি সে বস্তু সম্পর্কে কোন সন্দেহের সম্মুখীন হয়ে থাক যা তোমার প্রতি আমি নাযিল করেছি, তবে তাদেরকে জিজ্ঞেস করো যারা তোমার পূর্ব থেকে কিতাব পাঠ করছে। এতে কোন সন্দেহ নেই যে, তোমার পরওয়ারদেগারের নিকট থেকে তোমার নিকট সত্য বিষয় এসেছে। কাজেই তুমি কস্মিনকালেও সন্দেহকারী হয়ো না।\qt@no{(94)}}
\qt@newcmd\qurantrans@bn@mcdlix{এবং তাদের অন্তর্ভুক্তও হয়ো না যারা মিথ্যা প্রতিপন্ন করেছে আল্লাহর বাণীকে। তাহলে তুমিও অকল্যাণে পতিত হয়ে যাবে।\qt@no{(95)}}
\qt@newcmd\qurantrans@bn@mcdlx{যাদের ব্যাপারে তোমার পরওয়ারদেগারের সিদ্ধান্ত নির্ধারিত হয়ে গেছে তারা ঈমান আনবে না।\qt@no{(96)}}
\qt@newcmd\qurantrans@bn@mcdlxi{যদি তাদের সামনে সমস্ত নিদর্শনাবলী এসে উপস্থিত হয় তবুও যতক্ষণ না তারা দেখতে পায় বেদনাদায়ক আযাব।\qt@no{(97)}}
\qt@newcmd\qurantrans@bn@mcdlxii{সুতরাং কোন জনপদ কেন এমন হল না যা ঈমান এনেছে অতঃপর তার সে ঈমান গ্রহণ হয়েছে কল্যাণকর? অবশ্য ইউনুসের সম্প্রদায়ের কথা আলাদা। তারা যখন ঈমান আনে তখন আমি তুলে নেই তাদের উপর থেকে অপমানজনক আযাব-পার্থিব জীবনে এবং তাদের কে কল্যাণ পৌছাই এক নিধারিত সময় পর্যন্ত।\qt@no{(98)}}
\qt@newcmd\qurantrans@bn@mcdlxiii{আর তোমার পরওয়ারদেগার যদি চাইতেন, তবে পৃথিবীর বুকে যারা রয়েছে, তাদের সবাই ঈমান নিয়ে আসতে সমবেতভাবে। তুমি কি মানুষের উপর জবরদস্তী করবে ঈমান আনার জন্য?\qt@no{(99)}}
\qt@newcmd\qurantrans@bn@mcdlxiv{আর কারো ঈমান আনা হতে পারে না, যতক্ষণ না আল্লাহর হুকুম হয়। পক্ষান্তরে তিনি অপবিত্রতা আরোপ করেন যারা বুদ্ধি প্রয়োগ করে না তাদের উপর।\qt@no{(100)}}
\qt@newcmd\qurantrans@bn@mcdlxv{তাহলে আপনি বলে দিন, চেয়ে দেখ তো আসমানসমুহে ও যমীনে কি রয়েছে। আর কোন নিদর্শন এবং কোন ভীতিপ্রর্দশনই কোন কাজে আসে না সেসব লোকের জন্য যারা মান্য করে না।\qt@no{(101)}}
\qt@newcmd\qurantrans@bn@mcdlxvi{সুতরাং এখন আর এমন কিছু নেই, যার অপেক্ষা করবে, কিন্তু সেসব দিনের মতই দিন, যা অতীত হয়ে গেছে এর পূর্বে। আপনি বলুন; এখন পথ দেখ; আমিও তোমাদের সাথে পথ চেয়ে রইলাম।\qt@no{(102)}}
\qt@newcmd\qurantrans@bn@mcdlxvii{অতঃপর আমি বাঁচিয়ে নেই নিজের রসূলগণকে এবং তাদেরকে যারা ঈমান এনেছে এমনিভাবে। ঈমানদারদের বাঁচিয়ে নেয়া আমার দায়িত্বও বটে।\qt@no{(103)}}
\qt@newcmd\qurantrans@bn@mcdlxviii{বলে দাও-হে মানবকুল, তোমরা যদি আমার দ্বীনের ব্যাপারে সন্দিহান হয়ে থাক, তবে (জেনো) আমি তাদের এবাদত করি না যাদের এবাদত তোমরা কর আল্লাহ ব্যতীত। কিন্তু আমি এবাদত করি আল্লাহ ত’য়ালার, যিনি তুলে নেন তোমাদেরকে। আর আমার প্রতি নির্দেশ হয়েছে যাতে আমি ঈমানদারদের অন্তর্ভুক্ত থাকি।\qt@no{(104)}}
\qt@newcmd\qurantrans@bn@mcdlxix{আর যেন সোজা দ্বীনের প্রতি মুখ করি সরল হয়ে এবং যেন মুশরেকদের অন্তর্ভুক্ত না হই।\qt@no{(105)}}
\qt@newcmd\qurantrans@bn@mcdlxx{আর নির্দেশ হয়েছে আল্লাহ ব্যতীত এমন কাউকে ডাকবে না, যে তোমার ভাল করবে না মন্দও করবে না। বস্তুতঃ তুমি যদি এমন কাজ কর, তাহলে তখন তুমিও জালেমদের অন্তর্ভুক্ত হয়ে যাবে।\qt@no{(106)}}
\qt@newcmd\qurantrans@bn@mcdlxxi{আর আল্লাহ যদি তোমার উপর কোন কষ্ট আরোপ করেন তাহলে কেউ নেই তা খন্ডাবার মত তাঁকে ছাড়া। পক্ষান্তরে যদি তিনি কিছু কল্যাণ দান করেন, তবে তার মেহেরবানীকে রহিত করার মতও কেউ নেই। তিনি যার প্রতি অনুগ্রহ দান করতে চান স্বীয় বান্দাদের মধ্যে তাকেই দান করেন; বস্তুত; তিনিই ক্ষমাশীল দয়ালু।\qt@no{(107)}}
\qt@newcmd\qurantrans@bn@mcdlxxii{বলে দাও, হে মানবকুল, সত্য তোমাদের কাছে পৌঁছে গেছে তোমাদের পরওয়ারদেগারের তরফ থেকে। এমন যে কেউ পথে আসে সেপথ প্রাপ্ত হয় স্বীয় মঙ্গলের জন্য। আর যে বিভ্রান্ত ঘুরতে থাকে, সে স্বীয় অমঙ্গলের জন্য বিভ্রান্ত অবস্থায় ঘুরতে থাকবে। অনন্তর আমি তোমাদের উপর অধিকারী নই।\qt@no{(108)}}
\qt@newcmd\qurantrans@bn@mcdlxxiii{আর তুমি চল সে অনুযায়ী যেমন নির্দেশ আসে তোমার প্রতি এবং সবর কর, যতক্ষণ না ফয়সালা করেন আল্লাহ। বস্তুতঃ তিনি হচ্ছেন সর্বোত্তম ফয়সালাকারী।\qt@no{(109)}}
\qt@newcmd\qurantrans@bn@mcdlxxiv{\basmalahbn আলিফ, লা-ম, রা; এটি এমন এক কিতাব, যার আয়াত সমূহ সুপ্রতিষ্ঠিত অতঃপর সবিস্তারে বর্ণিত এক মহাজ্ঞানী, সর্বজ্ঞ সত্তার পক্ষ হতে।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mcdlxxv{যেন তোমরা আল্লাহ ব্যতীত অন্য কারো বন্দেগী না কর। নিশ্চয় আমি তোমাদের প্রতি তাঁরই পক্ষ হতে সতর্ককারী ও সুসংবাদ দাতা।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mcdlxxvi{আর তোমরা নিজেদের পালনকর্তা সমীপে ক্ষমা প্রার্থনা কর। অনন্তর তাঁরই প্রতি মনোনিবেশ কর। তাহলে তিনি তোমাদেরকে নির্দিষ্ট সময় পর্যন্ত উৎকৃষ্ট জীবনোপকরণ দান করবেন এবং অধিক আমলকারীকে বেশী করে দেবেন আর যদি তোমরা বিমুখ হতে থাক, তবে আমি তোমাদের উপর এক মহা দিবসের আযাবের আশঙ্কা করছি।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mcdlxxvii{আল্লাহর সান্নিধ্যেই তোমাদেরকে ফিরে যেতে হবে। আর তিনি সব কিছুর উপর ক্ষমতাবান।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mcdlxxviii{জেনে রাখ, নিশ্চয়ই তারা নিজেদের বক্ষদেশ ঘুরিয়ে দেয় যেন আল্লাহর নিকট হতে লুকাতে পারে। শুন, তারা তখন কাপড়ে নিজেদেরকে আচ্ছাদিত করে, তিনি তখনও জানেন যা কিছু তারা চুপিসারে বলে আর প্রকাশ্যভাবে বলে। নিশ্চয় তিনি জানেন যা কিছু অন্তর সমূহে নিহিত রয়েছে।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mcdlxxix{আর পৃথিবীতে কোন বিচরণশীল নেই, তবে সবার জীবিকার দায়িত্ব আল্লাহ নিয়েছেন তিনি জানেন তারা কোথায় থাকে এবং কোথায় সমাপিত হয়। সবকিছুই এক সুবিন্যস্ত কিতাবে রয়েছে।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mcdlxxx{তিনিই আসমান ও যমীন ছয় দিনে তৈরী করেছেন, তাঁর আরশ ছিল পানির উপরে, তিনি তোমাদেরকে পরীক্ষা করতে চান যে, তোমাদের মধ্যে কে সবচেয়ে ভাল কাজ করে। আর যদি আপনি তাদেরকে বলেন যে, ``নিশ্চয় তোমাদেরকে মৃত্যুর পরে জীবিত ওঠানো হবে, তখন কাফেরেরা অবশ্য বলে এটা তো স্পষ্ট যাদু!";\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mcdlxxxi{আর যদি আমি এক নির্ধারিত মেয়াদ পর্যন্ত তাদের আযাব স্থগিত রাখি, তাহলে তারা নিশ্চয়ই বলবে কোন জিনিসে আযাব ঠেকিয়ে রাখছে? শুনে রাখ, যেদিন তাদের উপর আযাব এসে পড়বে, সেদিন কিন্তু তা ফিরে যাওয়ার নয়; তারা যে ব্যাপারে উপহাস করত তাই তাদেরকে ঘিরে ফেলবে।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mcdlxxxii{আর অবশ্যই যদি আমি মানুষকে আমার রহমতের আস্বাদ গ্রহণ করতে দেই, অতঃপর তা তার থেকে ছিনিয়ে নেই; তাহলে সে হতাশ ও কৃতঘ্ন হয়।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mcdlxxxiii{আর যদি তার উপর আপতিত দুঃখ কষ্টের পরে তাকে সুখভোগ করতে দেই, তবে সে বলতে থাকে যে, আমার অমঙ্গল দূর হয়ে গেছে, আর সে আনন্দে আত্নহারা হয়, অহঙ্কারে উদ্দত হয়ে পড়ে।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mcdlxxxiv{তবে যারা ধৈর্য্যধারণ করেছে এবং সৎকার্য করেছে তাদের জন্য ক্ষমা ও বিরাট প্রতিদান রয়েছে।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mcdlxxxv{আর সম্ভবতঃ ঐসব আহকাম যা ওহীর মাধ্যমে তোমার নিকট পাঠানো হয়, তার কিছু অংশ বর্জন করবে? এবং এতে মন ছোট করে বসবে? তাদের এ কথায় যে, তাঁর উপর কোন ধন-ভান্ডার কেন অবতীর্ণ হয়নি? অথবা তাঁর সাথে কোন ফেরেশতা আসেনি কেন? তুমিতো শুধু সতর্ককারী মাত্র; আর সব কিছুরই দায়িত্বভার তো আল্লাহই নিয়েছেন।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mcdlxxxvi{তারা কি বলে? কোরআন তুমি তৈরী করেছ? তুমি বল, তবে তোমরাও অনুরূপ দশটি সূরা তৈরী করে নিয়ে আস এবং আল্লাহ ছাড়া যাকে পার ডেকে নাও, যদি তোমাদের কথা সত্য হয়ে থাকে।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mcdlxxxvii{অতঃপর তারা যদি তোমাদের কথা পুরণ করতে অপারগ হয়; তবে জেনে রাখ, এটি আল্লাহর এলম দ্বারা অবতীর্ণ হয়েছে; আরো একীন করে নাও যে, আল্লাহ ব্যতীত অন্য কোন মাবুদ নেই। অতএব, এখন কি তোমরা আত্নসমর্পন করবে?\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mcdlxxxviii{যে ব্যক্তি পার্থিবজীবন ও তার চাকচিক্যই কামনা করে, হয় আমি তাদের দুনিয়াতেই তাদের আমলের প্রতিফল ভোগ করিয়ে দেব এবং তাতে তাদের প্রতি কিছুমাত্র কমতি করা হয় না।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mcdlxxxix{এরাই হল সেসব লোক আখেরাতে যাদের জন্য আগুন ছাড়া নেই। তারা এখানে যা কিছু করেছিল সবই বরবাদ করেছে; আর যা কিছু উপার্জন করেছিল, সবই বিনষ্ট হল।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mcdxc{আচ্ছা বল তো, যে ব্যক্তি তার প্রভুর সুস্পষ্ট পথে রয়েছে, আর সাথে সাথে আল্লাহর তরফ থেকে একটি সাক্ষীও বর্তমান রয়েছে এবং তার পূর্ববর্তী মূসা (আঃ) এর কিতাবও সাক্ষী যা ছিল পথনির্দেশক ও রহমত স্বরূপ, (তিনি কি অন্যান্যের সমান) অতএব তাঁরা কোরআনের প্রতি ঈমান আনেন। আর ঐসব দলগুলি যে কেউ তা অস্বীকার করে, দোযখই হবে তার ঠিকানা। অতএব, আপনি তাতে কোন সন্দেহে থাকবেন না। নিঃসন্দেহে তা আপনার পালনকর্তার পক্ষ হতে ধ্রুব সত্য; তথাপি অনেকেই তা বিশ্বাস করে না।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mcdxci{আর তাদের চেয়ে বড় যালেম কে হতে পারে, যারা আল্লাহর প্রতি মিথ্যারোপ করে। এসব লোককে তাদের পালনকর্তার সাক্ষাত সম্মূখীন করা হবে আর সাক্ষিগণ বলতে থাকবে, এরাই ঐসব লোক, যারা তাদের পালনকর্তার প্রতি মিথ্যারোপ করেছিল। শুনে রাখ, যালেমদের উপর আল্লাহর অভিসম্পাত রয়েছে।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mcdxcii{যারা আল্লাহর পথে বাধা দেয়, আর তাতে বক্রতা খুজে বেড়ায়, এরাই আখরাতকে অস্বীকার করে।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mcdxciii{তারা পৃথিবীতেও আল্লাহকে অপারগ করতে পারবে না এবং আল্লাহ ব্যতীত তাদের কোন সাহায্যকারীও নেই, তাদের জন্য দ্বিগুণ শাস্তি রয়েছে; তারা শুনতে পারত না এবং দেখতেও পেত না।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mcdxciv{এরা সে লোক, যারা নিজেরাই নিজেদেরকে ক্ষতিগ্রস্ত করেছে, আর এরা যা কিছু মিথ্যা মা’বুদ সাব্যস্ত করেছিল, তা সবই তাদের থেকে হারিয়ে গেছে।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mcdxcv{আখেরাতে এরাই হবে সর্বাধিক ক্ষতিগ্রস্থ কোন সন্দেহ নেই।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mcdxcvi{নিশ্চয়ই যারা ঈমান এনেছে ও সৎকাজ করেছে এবং স্বীয় পালনকর্তার সমীপে বিনতি প্রকাশ করেছে তারাই বেহেশতবাসী, সেখানেই তারা চিরকাল থাকবে।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mcdxcvii{উভয় পক্ষের দৃষ্টান্ত হচ্ছে যেমন অন্ধ ও বধির এবং যে দেখতে পায় ও শুনতে পায় উভয়ের অবস্থা কি এক সমান? তবুও তোমরা কি ভেবে দেখ না?\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mcdxcviii{আর অবশ্যই আমি নূহ (আঃ) কে তাঁর জাতির প্রতি প্রেরণ করেছি, (তিনি বললেন) নিশ্চয় আমি তোমাদের জন্য প্রকাশ্য সতর্ককারী।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mcdxcix{তোমরা আল্লাহ ব্যতীত কারো এবাদত করবে না। নিশ্চয় আমি তোমাদের ব্যাপারে এক যন্ত্রণাদায়ক দিনের আযাবের ভয় করছি।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@md{তখন তাঁর কওমের কাফের প্রধানরা বলল আমরা তো আপনাকে আমাদের মত একজন মানুষ ব্যতীত আর কিছু মনে করি না; আর আমাদের মধ্যে যারা ইতর ও স্থুল-বুদ্ধিসম্পন্ন তারা ব্যতীত কাউকে তো আপনার আনুগত্য করতে দেখি না এবং আমাদের উপর আপনাদের কেন প্রাধান্য দেখি না, বরং আপনারা সবাই মিথ্যাবাদী বলে আমারা মনে করি।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mdi{নূহ (আঃ) বললেন-হে আমার জাতি! দেখ তো আমি যদি আমার পালনকর্তার পক্ষ হতে স্পষ্ট দলীলের উপর থাক, আর তিনি যদি তাঁর পক্ষ হতে আমাকে রহমত দান করে থাকেন, তারপরেও তা তোমাদের চোখে না পড়ে, তাহলে আমি কি উহা তোমাদের উপর তোমাদের ইচ্ছার বিরুদ্ধেই চাপিয়ে দিতে পারি ?\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mdii{আর হে আমার জাতি! আমি তো এজন্য তোমাদের কাছে কোন অর্থ চাই না; আমার পারিশ্রমিক তো আল্লাহর জিম্মায় রয়েছে। আমি কিন্তু ঈমানদারদের তাড়িয়ে দিতে পারি না। তারা অবশ্যই তাদের পালনকর্তার সাক্ষাত লাভ করবে। বরঞ্চ তোমাদেরই আমি অজ্ঞ সম্প্রদায় দেখছি।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mdiii{আর হে আমার জাতি! আমি যদি তাদের তাড়িয়ে দেই তাহলে আমাকে আল্লাহ হতে রেহাই দেবে কে? তোমরা কি চিন্তা করে দেখ না?\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mdiv{আর আমি তোমাদেরকে বলি না যে, আমার কাছে আল্লাহর ভান্ডার রয়েছে এবং একথাও বলি না যে, আমি গায়বী খবরও জানি; একথাও বলি না যে, আমি একজন ফেরেশতা; আর তোমাদের দৃষ্টিতে যারা লাঞ্ছিত আল্লাহ তাদের কোন কল্যাণ দান করবেন না। তাদের মনের কথা আল্লাহ ভাল করেই জানেন। সুতরাং এমন কথা বললে আমি অন্যায় কারী হব।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mdv{তারা বলল-হে নূহ! আমাদের সাথে আপনি তর্ক করেছেন এবং অনেক কলহ করেছেন। এখন আপনার সেই আযাব নিয়ে আসুন, যে সম্পর্কে আপনি আমাদিগকে সতর্ক করেছেন, যদি আপনি সত্যবাদী হয়ে থাকেন।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mdvi{তিনি বলেন, উহা তোমাদের কাছে আল্লাহই আনবেন, যদি তিনি ইচ্ছা করেন তখন তোমরা পালিয়ে তাঁকে অপারগ করতে পারবে না।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mdvii{আর আমি তোমাদের নসীহত করতে চাইলেও তা তোমাদের জন্য ফলপ্রসূ হবে না, যদি আল্লাহ তোমাদেরকে গোমরাহ করতে চান; তিনিই তোমাদের পালনকর্তা এবং তাঁর কাছেই তোমাদের ফিরে যেতে হবে।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mdviii{তারা কি বলে? আপনি কোরআন রচনা করে এনেছেন? আপনি বলে দিন আমি যদি রচনা করে এনে থাকি, তবে সে অপরাধ আমার, আর তোমরা যেসব অপরাধ কর তার সাথে আমার কোন সম্পর্ক নেই।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mdix{আর নূহ (আঃ) এর প্রতি ওহী প্রেরণ করা হলো যে, যারা ইতিমধ্যেই ঈমান এনেছে তাদের ছাড়া আপনার জাতির অন্য কেউ ঈমান আনবেনা এতএব তাদের কার্যকলাপে বিমর্ষ হবেন না।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mdx{আর আপনি আমার সম্মুখে আমারই নির্দেশ মোতাবেক একটি নৌকা তৈরী করুন এবং পাপিষ্ঠদের ব্যাপারে আমাকে কোন কথা বলবেন না। অবশ্যই তারা ডুবে মরবে।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mdxi{তিনি নৌকা তৈরী করতে লাগলেন, আর তাঁর কওমের নেতৃস্থানীয় ব্যক্তিরা যখন পার্শ্ব দিয়ে যেত, তখন তাঁকে বিদ্রুপ করত। তিনি বললেন, তোমরা যদি আমাদের উপহাস করে থাক, তবে তোমরা যেমন উপহাস করছ আমরাও তদ্রুপ তোমাদের উপহাস করছি।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mdxii{অতঃপর অচিরেই জানতে পারবে-লাঞ্ছনাজনক আযাব কার উপর আসে এবং চিরস্থায়ী আযাব কার উপর অবতরণ করে।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mdxiii{অবশেষে যখন আমার হুকুম এসে পৌঁছাল এবং ভুপৃষ্ঠ উচ্ছসিত হয়ে উঠল, আমি বললামঃ সর্বপ্রকার জোড়ার দুটি করে এবং যাদের উপরে পূর্ব-সিদ্ধান্ত হয়ে গেছে তাদের বাদ দিয়ে, আপনার পরিজনবর্গ ও সকল ঈমানদারগণকে নৌকায় তুলে নিন। বলাবাহুল্য অতি অল্পসংখ্যক লোকই তাঁর সাথে ঈমান এনেছিল।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mdxiv{আর তিনি বললেন, তোমরা এতে আরোহন কর। আল্লাহর নামেই এর গতি ও স্থিতি। আমার পালনকর্তা অতি ক্ষমাপরায়ন, মেহেরবান।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mdxv{আর নৌকাখানি তাদের বহন করে চলল পর্বত প্রমাণ তরঙ্গমালার মাঝে, আর নূহ (আঃ) তাঁর পুত্রকে ডাক দিলেন আর সে সরে রয়েছিল, তিনি বললেন, প্রিয় বৎস! আমাদের সাথে আরোহন কর এবং কাফেরদের সাথে থেকো না।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mdxvi{সে বলল, আমি অচিরেই কোন পাহাড়ে আশ্রয় নেব, যা আমাকে পানি হতে রক্ষা করবে। নূহ (আঃ) বল্লেন আজকের দিনে আল্লাহর হুকুম থেকে কোন রক্ষাকারী নেই। একমাত্র তিনি যাকে দয়া করবেন। এমন সময় উভয়ের মাঝে তরঙ্গ আড়াল হয়ে দাঁড়াল, ফলে সে নিমজ্জিত হল।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mdxvii{আর নির্দেশ দেয়া হল-হে পৃথিবী! তোমার পানি গিলে ফেল, আর হে আকাশ, ক্ষান্ত হও। আর পানি হ্রাস করা হল এবং কাজ শেষ হয়ে গেল, আর জুদী পর্বতে নৌকা ভিড়ল এবং ঘোষনা করা হল, দুরাত্না কাফেররা নিপাত যাক।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mdxviii{আর নূহ (আঃ) তাঁর পালনকর্তাকে ডেকে বললেন-হে পরওয়ারদেগার, আমার পুত্র তো আমার পরিজনদের অন্তর্ভুক্ত; আর আপনার ওয়াদাও নিঃসন্দেহে সত্য আর আপনিই সর্বাপেক্ষা বিজ্ঞ ফয়সালাকারী।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mdxix{আল্লাহ বলেন, হে নূহ! নিশ্চয় সে আপনার পরিবারভুক্ত নয়। নিশ্চই সে দুরাচার! সুতরাং আমার কাছে এমন দরখাস্ত করবেন না, যার খবর আপনি জানেন না। আমি আপনাকে উপপদেশ দিচ্ছি যে, আপনি অজ্ঞদের দলভুক্ত হবেন না।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mdxx{নূহ (আঃ) বলেন-হে আমার পালনকর্তা আমার যা জানা নেই এমন কোন দরখাস্ত করা হতে আমি আপনার কাছেই আশ্রয় প্রার্থনা করছি। আপনি যদি আমাকে ক্ষমা না করেন, দয়া না করেন, তাহলে আমি ক্ষতিগ্রস্ত হব।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mdxxi{হুকুম হল-হে নূহ (আঃ)! আমার পক্ষ হতে নিরাপত্তা এবং আপনার নিজের ও সঙ্গীয় সম্প্রদায়গুলির উপর বরকত সহকারে অবতরণ করুণ। আর অন্যান্য যেসব সম্প্রদায় রয়েছে আমি তাদের কেও উপকৃত হতে দেব। অতঃপর তাদের উপর আমার দরুন আযাব আপতিত হবে।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mdxxii{এটি গায়বের খবর, আমি আপনার প্রতি ওহী প্রেরন করছি। ইতিপূর্বে এটা আপনার এবং আপনার জাতির জানা ছিল না। আপনি ধৈর্য্যধারণ করুন। যারা ভয় করে চলে, তাদের পরিণাম ভাল, সন্দেহ নেই।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mdxxiii{আর আদ জাতির প্রতি আমি তাদের ভাই হুদকে প্রেরণ করেছি; তিনি বলেন-হে আমার জাতি, আল্লাহর বন্দেগী কর, তিনি ভিন্ন তোমাদের কোন মাবুদ নেই, তোমরা সবাই মিথ্যা আরোপ করছ।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mdxxiv{হে আমার জাতি! আমি এজন্য তোমাদের কাছে কোন মজুরী চাই না; আমার মজুরী তাঁরই কাছে যিনি আমাকে পয়দা করেছেন; তবু তোমরা কেন বোঝ না?\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mdxxv{আর হে আমার কওম! তোমাদের পালন কর্তার কাছে তোমরা ক্ষমা প্রার্থনা কর, অতঃপর তাঁরই প্রতি মনোনিবেশ কর; তিনি আসমান থেকে তোমাদের উপর বৃষ্টি ধারা প্রেরণ করবেন এবং তোমাদের শক্তির উপর শক্তি বৃদ্ধি করবেন, তোমরা কিন্তু অপরাধীদের মত বিমুখ হয়ো না।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mdxxvi{তারা বলল-হে হুদ, তুমি আমাদের কাছে কোন প্রমাণ নিয়ে আস নাই, আমরা তোমার কথায় আমাদের দেব-দেবীদের বর্জন করতে পারি না আর আমরা তোমার প্রতি ঈমান আনয়নকারীও নই।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mdxxvii{বরং আমরাও তো বলি যে, আমাদের কোন দেবতা তোমার উপরে শোচনীয় ভূত চাপিয়ে দিয়েছে। হুদ বললেন-আমি আল্লাহকে সাক্ষী করেছি আর তোমাও সাক্ষী থাক যে, আমার কোন সম্পর্ক নাই তাঁদের সাথে যাদের কে তোমরা শরিক করছ;\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mdxxviii{তাকে ছাড়া, তোমরা সবাই মিলে আমার অনিষ্ট করার প্রয়াস চালাও, অতঃপর আমাকে কোন অবকাশ দিও না।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mdxxix{আমি আল্লাহর উপর নিশ্চিত ভরসা করেছি যিনি আমার এবং তোমাদের পরওয়ারদেগার। পৃথিবীর বুকে বিচরণকারী এমন কোন প্রাণী নাই যা তাঁর র্পূণ আয়ত্তাধীন নয়। আমার পালকর্তার সরল পথে সন্দেহ নেই।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mdxxx{তথাপি যদি তোমরা মুখ ফেরাও, তবে আমি তোমাদেরকে তা পৌছিয়েছি যা আমার কাছে তোমাদের প্রতি প্রেরিত হয়েছে; আর আমার পালনকর্তা অন্য কোন জাতিকে তোমাদের স্থলাভিষিক্ত করবেন, আর তোমরা তাঁর কিছুই বিগড়াতে পারবে না; নিশ্চয়ই আমার পরওয়ারদেগারই প্রতিটি বস্তুর হেফাজতকারী।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mdxxxi{আর আমার আদেশ যখন উপস্থিত হল, তখন আমি নিজ রহমতে হুদ এবং তাঁর সঙ্গী ঈমানদারগণকে পরিত্রাণ করি এবং তাদেরকে এক কঠিন শাস্তি থেকে রক্ষা করি।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mdxxxii{এ ছিল আদ জাতি, যারা তাদের পালনকর্তার আয়াতকে অমান্য করেছে, আর তদীয় রসূলগণের অবাধ্যতা করেছে এবং প্রত্যেক উদ্ধত বিরোধীদের আদেশ পালন করেছে।\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mdxxxiii{এ দুনিয়ায় তাদের পিছনে পিছনে লা’নত রয়েছে এবং কেয়ামতের দিনেও; জেনে রাখ, আদ জাতি তাদের পালনকর্তাকে অস্বীকার করেছে, হুদের জ্ঞাতি আদ জাতির প্রতি অভিসম্পাত রয়েছে জেনে রাখ।\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mdxxxiv{আর সামুদ জাতি প্রতি তাদের ভাই সালেহ কে প্রেরণ করি; তিনি বললেন, হে আমার জাতি। আল্লাহর বন্দেগী কর, তিনি ছাড়া তোমাদের কোন উপাস্য নাই। তিনিই যমীন হতে তোমাদেরকে পয়দা করেছেন, তন্মধ্যে তোমাদেরকে বসতি দান করেছেন। অতএব; তাঁর কাছে ক্ষমা প্রার্থনা কর অতঃপর তাঁরই দিকে ফিরে চল আমার পালনকর্তা নিকটেই আছেন, কবুল করে থাকেন; সন্দেহ নেই।\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mdxxxv{তারা বলল-হে সালেহ, ইতিপূর্বে তোমার কাছে আমাদের বড় আশা ছিল। আমাদের বাপ-দাদা যা পূজা করত তুমি কি আমাদেরকে তার পূজা করতে নিষেধ কর? কিন্তু যার প্রতি তুমি আমাদের আহবান জানাচ্ছ আমাদের তাতে এমন সন্দেহ রয়েছে যে, মন মোটেই সায় দিচ্ছে না।\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mdxxxvi{সালেহ বললেন-হে আমার জাতি! তোমরা কি মনে কর, আমি যদি আমার পালনকর্তার পক্ষ হতে বুদ্ধি বিবেচনা লাভ করে থাকি আর তিনি যদি আমাকে নিজের তরফ হতে রহমত দান করে থাকেন, অতঃপর আমি যদি তাঁর অবাধ্য হই তবে তার থেকে কে আমায় রক্ষা করবে? তোমরা তো আমার ক্ষতি ছাড়া কিছুই বৃদ্ধি করতে পরবে না\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mdxxxvii{আর হে আমার জাতি! আল্লাহর এ উষ্ট্রীটি তোমাদের জন্য নিদর্শন, অতএব তাকে আল্লাহর যমীনে বিচরণ করে খেতে দাও, এবং তাকে মন্দভাবে স্পর্শও করবে না। নতুবা অতি সত্বর তোমাদেরকে আযাব পাকড়াও করবে।\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mdxxxviii{তবু তারা উহার পা কেটে দিল। তখন সালেহ বললেন-তোমরা নিজেদের গৃহে তিনটি দিন উপভোগ করে নাও। ইহা এমন ওয়াদা যা মিথ্যা হবে না।\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mdxxxix{অতঃপর আমার আযাব যখন উপস্থিত হল, তখন আমি সালেহকে ও তদীয় সঙ্গী ঈমানদারগণকে নিজ রহমতে উদ্ধার করি, এবং সেদিনকার অপমান হতে রক্ষা করি। নিশ্চয় তোমার পালনকর্তা তিনি সর্বশক্তিমান পরাক্রমশালী।\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mdxl{আর ভয়ঙ্কর গর্জন পাপিষ্ঠদের পাকড়াও করল, ফলে ভোর হতে না হতেই তারা নিজ নিজ গৃহসমূহে উপুর হয়ে পড়ে রইল।\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mdxli{যেন তাঁরা কোনদিনই সেখানে ছিল না। জেনে রাখ, নিশ্চয় সামুদ জাতি তাদের পালনকর্তার প্রতি অস্বীকার করেছিল। আরো শুনে রাখ, সামুদ জাতির জন্য অভিশাপ রয়েছে।\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mdxlii{আর অবশ্যই আমার প্রেরিত ফেরেশতারা ইব্রাহীমেরে কাছে সুসংবাদ নিয়ে এসেছিল তারা বলল সালাম, তিনিও বললেন-সালাম। অতঃপর অল্পক্ষণের মধ্যেই তিনি একটি ভুনা করা বাছুর নিয়ে এলেন!\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mdxliii{কিন্তু যখন দেখলেন যে, আহার্য্যের দিকে তাদের হস্ত প্রসারিত হচ্ছে না, তখন তিনি সন্ধিগ্ধ হলেন এবং মনে মনে তাঁদের সম্পর্কে ভয় অনুভব করতে লাগলেন। তারা বলল-ভয় পাবেন না। আমরা লূতের কওমের প্রতি প্রেরিত হয়েছি।\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@mdxliv{তাঁর স্ত্রীও নিকটেই দাড়িয়েছিল, সে হেসে ফেলল। অতঃপর আমি তাকে ইসহাকের জন্মের সুখবর দিলাম এবং ইসহাকের পরের ইয়াকুবেরও।\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@mdxlv{সে বলল-কি দুর্ভাগ্য আমার! আমি সন্তান প্রসব করব? অথচ আমি বার্ধক্যের শেষ প্রান্তে এসে উপনীত হয়েছি আর আমার স্বামীও বৃদ্ধ, এতো ভারী আশ্চর্য কথা।\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@mdxlvi{তারা বলল-তুমি আল্লাহর হুকুম সম্পর্কে বিস্ময়বোধ করছ? হে গৃহবাসীরা, তোমাদের উপর আল্লাহর রহমত ও প্রভুত বরকত রয়েছে। নিশ্চয় আল্লাহ প্রশংসিত মহিমাময়।\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@mdxlvii{অতঃপর যখন ইব্রাহীম (আঃ) এর আতঙ্ক দূর হল এবং তিনি সুসংবাদ প্রাপ্ত হলেন, তখন তিনি আমার সাথে তর্ক শুরু করলেন কওমে লূত সম্পর্কে।\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@mdxlviii{ইব্রাহীম (আঃ) বড়ই ধৈর্য্যশীল, কোমল অন্তর, আল্লাহমুখী সন্দেহ নেই।\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@mdxlix{ইব্রাহীম, এহেন ধারণা পরিহার কর; তোমার পালনকর্তার হুকুম এসে গেছে, এবং তাদের উপর সে আযাব অবশ্যই আপতিত হবে, যা কখনো প্রতিহত হবার নয়।\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@mdl{আর যখন আমার প্রেরিত ফেরেশতাগণ লূত (আঃ) এর নিকট উপস্থিত হল। তখন তাঁদের আগমনে তিনি দুচিন্তাগ্রস্ত হলেন এবং তিনি বলতে লাগলেন, আজ অত্যন্ত কঠিন দিন।\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@mdli{আর তাঁর কওমের লোকেরা স্বতঃস্ফুর্তভাবে তার (গৃহ) পানে ছুটে আসতে লাগল। পূর্ব থেকেই তারা কু-কর্মে তৎপর ছিল। লূত (আঃ) বললেন-হে আমার কওম, এ আমার কন্যারা রয়েছে, এরা তোমাদের জন্য অধিক পবিত্রতমা। সুতরাং তোমরা আল্লাহকে ভয় কর এবং অতিথিদের ব্যাপারে আমাকে লজ্জিত করো না, তোমাদের মধ্যে কি কোন ভাল মানুষ নেই।\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@mdlii{তারা বলল ু তুমি তো জানই, তোমার কন্যাদের নিয়ে আমাদের কোন গরজ নেই। আর আমরা কি চাই, তাও তুমি অবশ্যই জান।\qt@no{(79)}}
\qt@newcmd\qurantrans@bn@mdliii{লূত (আঃ) বললেন-হায়, তোমাদের বিরুদ্ধে যদি আমার শক্তি থাকত অথবা আমি কোন সূদৃঢ় আশ্রয় গ্রহণ করতে সক্ষম হতাম।\qt@no{(80)}}
\qt@newcmd\qurantrans@bn@mdliv{মেহমান ফেরেশতাগন বলল-হে লূত (আঃ) আমরা তোমাদের পালনকর্তার পক্ষ হতে প্রেরিত ফেরেশতা। এরা কখনো তোমার দিকে পৌঁছাতে পারবে না। ব্যস তুমি কিছুটা রাত থাকতে থাকতে নিজের লোকজন নিয়ে বাইরে চলে যাও। আর তোমাদের কেউ যেন পিছনে ফিরে না তাকায়। কিন্তু তোমার স্ত্রী নিশ্চয় তার উপরও তা আপতিত হবে, যা ওদের উপর আপতিত হবে। ভোর বেলাই তাদের প্রতিশ্রুতির সময়, ভোর কি খুব নিকটে নয়?\qt@no{(81)}}
\qt@newcmd\qurantrans@bn@mdlv{অবশেষে যখন আমার হুকুম এসে পৌঁছাল, তখন আমি উক্ত জনপদকে উপরকে নীচে করে দিলাম এবং তার উপর স্তরে স্তরে কাঁকর পাথর বর্ষণ করলাম।\qt@no{(82)}}
\qt@newcmd\qurantrans@bn@mdlvi{যার প্রতিটি তোমার পালনকর্তার নিকট চিহ্নিত ছিল। আর সেই পাপিষ্ঠদের থেকে খুব দূরেও নয়।\qt@no{(83)}}
\qt@newcmd\qurantrans@bn@mdlvii{আর মাদইয়ানবাসীদের প্রতি তাদের ভাই শোয়ায়েব (আঃ) কে প্রেরণ করেছি। তিনি বললেন-হে আমার কওম! আল্লাহর বন্দেগী কর, তিনি ছাড়া আমাদের কোন মাবুদ নাই। আর পরিমাপে ও ওজনে কম দিও না, আজ আমি তোমাদেরকে ভাল অবস্থায়ই দেখছি, কিন্তু আমি তোমাদের উপর এমন একদিনের আযাবের আশঙ্কা করছি যেদিনটি পরিবেষ্টনকারী।\qt@no{(84)}}
\qt@newcmd\qurantrans@bn@mdlviii{আর হে আমার জাতি, ন্যায়নিষ্ঠার সাথে ঠিকভাবে পরিমাপ কর ও ওজন দাও এবং লোকদের জিনিসপত্রে কোনরূপ ক্ষতি করো না, আর পৃথিবীতে ফাসাদ করে বেড়াবে না।\qt@no{(85)}}
\qt@newcmd\qurantrans@bn@mdlix{আল্লাহ প্রদত্ত উদ্ধৃত্ত তোমাদের জন্য উত্তম, যদি তোমরা ঈমানদার হও, আর আমি তো তোমাদের উপর সদা পর্যবেক্ষণকারী নই।\qt@no{(86)}}
\qt@newcmd\qurantrans@bn@mdlx{তারা বলল-হে শোয়ায়েব (আঃ) আপনার নামায কি আপনাকে ইহাই শিক্ষা দেয় যে, আমরা ঐসব উপাস্যদেরকে পরিত্যাগ করব আমাদের বাপ-দাদারা যাদের উপাসনা করত? অথবা আমাদের ধন-সম্পদে ইচ্ছামত যা কিছু করে থাকি, তা ছেড়ে দেব? আপনি তো একজন খাস মহৎ ব্যক্তি ও সৎপথের পথিক।\qt@no{(87)}}
\qt@newcmd\qurantrans@bn@mdlxi{শোয়ায়েব (আঃ) বললেন-হে দেশবাসী, তোমরা কি মনে কর! আমি যদি আমার পরওয়ারদেগারের পক্ষ হতে সুস্পষ্ট দলীলের উপর কায়েম থাকি আর তিনি যদি নিজের তরফ হতে আমাকে উত্তম রিযিক দান করে থাকেন, (তবে কি আমি তাঁর হুকুম অমান্য করতে পারি?) আর আমি চাই না যে তোমাদেরকে যা ছাড়াতে চাই পরে নিজেই সে কাজে লিপ্ত হব, আমি তো যথাসাধ্য শোধরাতে চাই। আল্লাহর মদদ দ্বারাই কিন্তু কাজ হয়ে থাকে, আমি তাঁর উপরই নির্ভর করি এবং তাঁরই প্রতি ফিরে যাই।\qt@no{(88)}}
\qt@newcmd\qurantrans@bn@mdlxii{আর হে আমার জাতি! আমার সাথে জিদ করে তোমরা নূহ বা হুদ অথবা সালেহ (আঃ) এর কওমের মত নিজেদের উপর আযাব ডেকে আনবে না। আর লূতের জাতি তো তোমাদের থেকে খুব দূরে নয়।\qt@no{(89)}}
\qt@newcmd\qurantrans@bn@mdlxiii{আর তোমাদের পালনকর্তার কাছে মার্জনা চাও এবং তাঁরই পানে ফিরে এসো নিশ্চয়ই আমার পরওয়ারদেগার খুবই মেহেরবান অতিস্নেহময়।\qt@no{(90)}}
\qt@newcmd\qurantrans@bn@mdlxiv{তারা বলল-হে শোয়ায়েব (আঃ) আপনি যা বলেছেন তার অনেক কথাই আমরা বুঝি নাই, আমারা তো আপনাকে আমাদের মধ্যে দূর্বল ব্যক্তি রূপে মনে করি। আপনার ভাই বন্ধুরা না থাকলে আমরা আপনাকে প্রস্তরাঘাতে হত্যা করতাম। আমাদের দৃষ্টিতে আপনি কোন মর্যাদাবান ব্যক্তি নন।\qt@no{(91)}}
\qt@newcmd\qurantrans@bn@mdlxv{শোয়ায়েব (আঃ) বলেন-হে আমার জাতি, আমার ভাই বন্ধুরা কি তোমাদের কাছে আল্লাহর চেয়ে প্রভাবশালী? আর তোমরা তাকে বিস্মৃত হয়ে পেছনে ফেলে রেখেছ, নিশ্চয় তোমাদের কার্যকলাপ আমার পালনকর্তার আয়ত্তে রয়েছে।\qt@no{(92)}}
\qt@newcmd\qurantrans@bn@mdlxvi{আর হে আমার জাতি, তোমরা নিজ স্থানে কাজ করে যাও, আমিও কাজ করছি, অচিরেই জানতে পারবে কার উপর অপমানকর আযাব আসে আর কে মিথ্যাবাদী? আর তোমরাও অপেক্ষায় থাক, আমিও তোমাদের সাথে অপেক্ষায় রইলাম।\qt@no{(93)}}
\qt@newcmd\qurantrans@bn@mdlxvii{আর আমার হুকুম যখন এল, আমি শোয়ায়েব (আঃ) ও তাঁর সঙ্গী ঈমানদারগণকে নিজ রহমতে রক্ষা করি আর পাপিষ্ঠদের উপর বিকট গর্জন পতিত হলো। ফলে ভোর না হতেই তারা নিজেদের ঘরে উপুড় হয়ে পড়ে রইল।\qt@no{(94)}}
\qt@newcmd\qurantrans@bn@mdlxviii{যেন তারা সেখানে কখনো বসবাসই করে নাই। জেনে রাখ, সামুদের প্রতি অভিসম্পাতের মত মাদইয়ানবাসীর উপরেও অভিসম্পাত।\qt@no{(95)}}
\qt@newcmd\qurantrans@bn@mdlxix{আর আমি মূসা (আঃ) কে প্রেরণ করি আমার নিদর্শনাদি ও সুস্পষ্ট সনদসহ;\qt@no{(96)}}
\qt@newcmd\qurantrans@bn@mdlxx{ফেরাউন ও তার পারিষদবর্গের কাছে, তবুও তারা ফেরাউনের হুকুমে চলতে থাকে, অথচ ফেরাউনের কোন কথা ন্যায় সঙ্গত ছিল না।\qt@no{(97)}}
\qt@newcmd\qurantrans@bn@mdlxxi{কেয়ামতের দিন সে তার জাতির লোকদের আগে আগে থাকবে এবং তাদেরকে জাহান্নামের আগুনে পৌঁছে দিবে। আর সেটা অতীব নিকৃষ্ট স্থান, সেখানে তারা পৌঁছেছে।।\qt@no{(98)}}
\qt@newcmd\qurantrans@bn@mdlxxii{আর এ জগতেও তাদের পেছনে লানত রয়েছে এবং কিয়ামতের দিনেও; অত্যন্ত জঘন্য প্রতিফল, যা তারা পেয়েছে।\qt@no{(99)}}
\qt@newcmd\qurantrans@bn@mdlxxiii{এ হচ্ছে কয়েকটি জনপদের সামান্য ইতিবৃত্ত, যা আমি আপনাকে শোনাচ্ছি। তন্মধ্যে কোন কোনটি এখনও বর্তমান আছে আর কোন কোনটির শিকড় কেটে দেয়া হয়েছে।\qt@no{(100)}}
\qt@newcmd\qurantrans@bn@mdlxxiv{আমি কিন্তু তাদের প্রতি জুলুম করি নাই বরং তারা নিজেরাই নিজের উপর অবিচার করেছে। ফলে আল্লাহকে বাদ দিয়ে তারা যেসব মাবুদকে ডাকতো আপনার পালনকর্তার হুকুম যখন এসে পড়ল, তখন কেউ কোন কাজে আসল না। তারা শুধু বিপর্যয়ই বৃদ্ধি করল।\qt@no{(101)}}
\qt@newcmd\qurantrans@bn@mdlxxv{আর তোমার পরওয়ারদেগার যখন কোন পাপপূর্ণ জনপদকে ধরেন, তখন এমনিভাবেই ধরে থাকেন। নিশ্চয় তাঁর পাকড়াও খুবই মারাত্নক, বড়ই কঠোর।\qt@no{(102)}}
\qt@newcmd\qurantrans@bn@mdlxxvi{নিশ্চয় ইহার মধ্যে নিদর্শন রয়েছে এমন প্রতিটি মানুষের জন্য যে আখেরাতের আযাবকে ভয় করে। উহা এমন একদিন, যে দিন সব মানুষেই সমবেত হবে, সেদিনটি যে হাযিরের দিন।\qt@no{(103)}}
\qt@newcmd\qurantrans@bn@mdlxxvii{আর আমি যে উহা বিলম্বিত করি, তা শুধু একটি ওয়াদার কারণে যা নির্ধারিত রয়েছে।\qt@no{(104)}}
\qt@newcmd\qurantrans@bn@mdlxxviii{যেদিন তা আসবে সেদিন আল্লাহর অনুমতি ছাড়া কেউ কোন কথা বলতে পারে না। অতঃপর কিছু লোক হবে হতভাগ্য আর কিছু লোক সৌভাগ্যবান।\qt@no{(105)}}
\qt@newcmd\qurantrans@bn@mdlxxix{অতএব যারা হতভাগ্য তারা দোযখে যাবে, সেখানে তারা আর্তনাদ ও চিৎকার করতে থাকবে।\qt@no{(106)}}
\qt@newcmd\qurantrans@bn@mdlxxx{তারা সেখানে চিরকাল থাকবে, যতদিন আসমান ও যমীন বর্তমান থাকবে। তবে তোমার প্রতিপালক অন্য কিছু ইচ্ছা করলে ভিন্ন কথা। নিশ্চয় তোমার পরওয়ারদেগার যা ইচ্ছা করতে পারেন।\qt@no{(107)}}
\qt@newcmd\qurantrans@bn@mdlxxxi{আর যারা সৌভাগ্যবান তারা বেহেশতের মাঝে, সেখানেই চিরদিন থাকবে, যতদিন আসমান ও যমীন বর্তমান থাকবে। তবে তোমার প্রভু অন্য কিছু ইচ্ছা করলে ভিন্ন কথা। এ দানের ধারাবাহিকতা কখনো ছিন্ন হওয়ার নয়।\qt@no{(108)}}
\qt@newcmd\qurantrans@bn@mdlxxxii{অতএব, তারা যেসবের উপাসনা করে তুমি সে ব্যাপারে কোনরূপ ধোঁকায় পড়বে না। তাদের পূর্ববর্তী বাপ-দাদারা যেমন পূজা উপাসনা করত, এরাও তেমন করছে। আর নিশ্চয় আমি তাদেরকে আযাবের ভাগ কিছু মাত্রও কম না করেই পুরোপুরি দান করবো।\qt@no{(109)}}
\qt@newcmd\qurantrans@bn@mdlxxxiii{আর আমি মূসা (আঃ)-কে অবশ্যই কিতাব দিয়েছিলাম অতঃপর তাতে বিরোধ সৃষ্টি হল; বলাবাহুল্য তোমার পালনকর্তার পক্ষ হতে, একটি কথা যদি আগেই বলা না হত, তাহলে তাদের মধ্যে চুড়ান্ত ফয়সালা হয়ে যেত তারা এ ব্যাপারে এমনই সন্দেহ প্রবণ যে, কিছুতেই নিশ্চিত হতে পারছে না।\qt@no{(110)}}
\qt@newcmd\qurantrans@bn@mdlxxxiv{আর যত লোকই হোক না কেন, যখন সময় হবে, তোমার প্রভু তাদের সকলেরই আমলের প্রতিদান পুরোপুরি দান করবেন। নিশ্চয় তিনি তাদের যাবতীয় কার্যকলাপের খবর রাখেন।\qt@no{(111)}}
\qt@newcmd\qurantrans@bn@mdlxxxv{অতএব, তুমি এবং তোমার সাথে যারা তওবা করেছে সবাই সোজা পথে চলে যাও-যেমন তোমায় হুকুম দেয়া হয়েছে এবং সীমা লঙ্ঘন করবে না, তোমরা যা কিছু করছ, নিশ্চয় তিনি তার প্রতি দৃষ্টি রাখেন।\qt@no{(112)}}
\qt@newcmd\qurantrans@bn@mdlxxxvi{আর পাপিষ্ঠদের প্রতি ঝুঁকবে না। নতুবা তোমাদেরকেও আগুনে ধরবে। আর আল্লাহ ব্যতীত তোমাদের কোন বন্ধু নাই। অতএব কোথাও সাহায্য পাবে না।\qt@no{(113)}}
\qt@newcmd\qurantrans@bn@mdlxxxvii{আর দিনের দুই প্রান্তেই নামায ঠিক রাখবে, এবং রাতের প্রান্তভাগে পূর্ণ কাজ অবশ্যই পাপ দূর করে দেয়, যারা স্মরণ রাখে তাদের জন্য এটি এক মহা স্মারক।\qt@no{(114)}}
\qt@newcmd\qurantrans@bn@mdlxxxviii{আর ধৈর্য্যধারণ কর, নিশ্চয়ই আল্লাহ পূণ্যবানদের প্রতিদান বিনষ্ট করেন না।\qt@no{(115)}}
\qt@newcmd\qurantrans@bn@mdlxxxix{কাজেই, তোমাদের পূর্ববতী জাতি গুলির মধ্যে এমন সৎকর্মশীল কেন রইল না, যারা পৃথিবীতে বিপর্যয় সৃষ্টি করতে বাধা দিত; তবে মুষ্টিমেয় লোক ছিল যাদেরকে আমি তাদের মধ্য হতে রক্ষা করেছি। আর পাপিষ্ঠরা তো ভোগ বিলাসে মত্ত ছিল যার সামগ্রী তাদেরকে যথেষ্ট দেয়া হয়েছিল। আসলে তারা ছিল মহা অপরাধী।\qt@no{(116)}}
\qt@newcmd\qurantrans@bn@mdxc{আর তোমার পালনকর্তা এমন নন যে, জনবসতিগুলোকে অন্যায়ভাবে ধ্বংস করে দেবেন, সেখানকার লোকেরা সৎকর্মশীল হওয়া সত্ত্বেও।\qt@no{(117)}}
\qt@newcmd\qurantrans@bn@mdxci{আর তোমার পালনকর্তা যদি ইচ্ছা করতেন, তবে অবশ্যই সব মানুষকে একই জাতিসত্তায় পরিনত করতে পারতেন আর তারা বিভিন্ন ভাগে বিভক্ত হতো না।\qt@no{(118)}}
\qt@newcmd\qurantrans@bn@mdxcii{তোমার পালনকর্তা যাদের উপর রহমত করেছেন, তারা ব্যতীত সবাই চিরদিন মতভেদ করতেই থাকবে এবং এজন্যই তাদেরকে সৃষ্টি করেছেন। আর তোমার আল্লাহর কথাই পূর্ণ হল যে, অবশ্যই আমি জাহান্নামকে জ্বিন ও মানুষ দ্বারা একযোগে ভর্তি করব।\qt@no{(119)}}
\qt@newcmd\qurantrans@bn@mdxciii{আর আমি রসূলগণের সব বৃত্তান্তই তোমাকে বলছি, যদ্দ্বারা তোমার অন্তরকে মজবুত করছি। আর এভাবে তোমার নিকট মহাসত্য এবং ঈমানদারদের জন্য নসীহত ও স্বরণীয় বিষয়বস্তু এসেছে।\qt@no{(120)}}
\qt@newcmd\qurantrans@bn@mdxciv{আর যারা ঈমান আনে না, তাদেরকে বলে দাও যে, তোমরা নিজ নিজ অবস্থায় কাজ করে যাও আমরাও কাজ করে যাই।\qt@no{(121)}}
\qt@newcmd\qurantrans@bn@mdxcv{এবং তোমরাও অপেক্ষা করে থাক, আমরাও অপেক্ষায় রইলাম।\qt@no{(122)}}
\qt@newcmd\qurantrans@bn@mdxcvi{আর আল্লাহর কাছেই আছে আসমান ও যমীনের গোপন তথ্য; আর সকল কাজের প্রত্যাবর্তন তাঁরই দিকে; অতএব, তাঁরই বন্দেগী কর এবং তাঁর উপর ভরসা রাখ, আর তোমাদের কার্যকলাপ সম্বন্ধে তোমার পালনকর্তা কিন্তু বে-খবর নন।\qt@no{(123)}}
\qt@newcmd\qurantrans@bn@mdxcvii{\basmalahbn আলিফ-লা-ম-রা; এগুলো সুস্পষ্ট গ্রন্থের আয়াত।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mdxcviii{আমি একে আরবী ভাষায় কোরআন রূপে অবতীর্ণ করেছি, যাতে তোমরা বুঝতে পার।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mdxcix{আমি তোমার নিকট উত্তম কাহিনী বর্ণনা করেছি, যেমতে আমি এ কোরআন তোমার নিকট অবতীর্ণ করেছি। তুমি এর আগে অবশ্যই এ ব্যাপারে অনবহিতদের অন্তর্ভূক্ত ছিলে।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mdc{যখন ইউসুফ পিতাকে বললঃ পিতা, আমি স্বপ্নে দেখেছি এগারটি নক্ষত্রকে। সুর্যকে এবং চন্দ্রকে। আমি তাদেরকে আমার উদ্দেশে সেজদা করতে দেখেছি।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mdci{তিনি বললেনঃ বৎস, তোমার ভাইদের সামনে এ স্বপ্ন বর্ণনা করো না। তাহলে তারা তোমার বিরুদ্ধে চক্রান্ত করবে। নিশ্চয় শয়তান মানুষের প্রকাশ্য।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mdcii{এমনিভাবে তোমার পালনকর্তা তোমাকে মনোনীত করবেন এবং তোমাকে বাণীসমূহের নিগুঢ় তত্ত্ব শিক্ষা দেবেন এবং পূর্ণ করবেন স্বীয় অনুগ্রহ তোমার প্রতি ও ইয়াকুব পরিবার-পরিজনের প্রতি; যেমন ইতিপূর্বে তোমার পিতৃপুরুষ ইব্রাহীম ও ইসহাকের প্রতি পূর্ণ করেছেন। নিশ্চয় তোমার পালনকর্তা অত্যন্ত জ্ঞানী, প্রজ্ঞাময়।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mdciii{অবশ্য ইউসুফ ও তাঁর ভাইদের কাহিনীতে জিজ্ঞাসুদের জন্যে নিদর্শনাবলী রয়েছে।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mdciv{যখন তারা বললঃ অবশ্যই ইউসুফ ও তাঁর ভাই আমাদের পিতার কাছে আমাদের চাইতে অধিক প্রিয় অথচ আমরা একটা সংহত শক্তি বিশেষ। নিশ্চয় আমাদের পিতা স্পষ্ট ভ্রান্তিতে রয়েছেন।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mdcv{হত্যা কর ইউসুফকে কিংবা ফেলে আস তাকে অন্য কোন স্থানে। এতে শুধু তোমাদের প্রতিই তোমাদের পিতার মনোযোগ নিবিষ্ট হবে এবং এরপর তোমরা যোগ্য বিবেচিত হয়ে থাকবে।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mdcvi{তাদের মধ্য থেকে একজন বলল, তোমরা ইউসুফ কে হত্যা করো না, বরং ফেলে দাও তাকে অন্ধকূপে যাতে কোন পথিক তাকে উঠিয়ে নিয়ে যায়, যদি তোমাদের কিছু করতেই হয়।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mdcvii{তারা বললঃ পিতাঃ ব্যাপার কি, আপনি ইউসুফের ব্যাপারে আমাদেরকে বিশ্বাস করেন না ? আমরা তো তার হিতাকাংখী।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mdcviii{আগামীকাল তাকে আমাদের সাথে প্রেরণ করুন-তৃপ্তিসহ খাবে এবং খেলাধুলা করবে এবং আমরা অবশ্যই তার রক্ষণাবেক্ষন করব।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mdcix{তিনি বললেনঃ আমার দুশ্চিন্তা হয় যে, তোমরা তাকে নিয়ে যাবে এবং আমি আশঙ্কা করি যে, ব্যাঘ্র তাঁকে খেয়ে ফেলবে এবং তোমরা তার দিক থেকে গাফেল থাকবে।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mdcx{তারা বললঃ আমরা একটি ভারী দল থাকা সত্ত্বেও যদি ব্যাঘ্র তাকে খেয়ে ফেলে, তবে আমরা সবই হারালাম।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mdcxi{অতঃপর তারা যখন তাকে নিয়ে চলল এবং অন্ধকূপে নিক্ষেপ করতে একমত হল এবং আমি তাকে ইঙ্গিত করলাম যে, তুমি তাদেরকে তাদের এ কাজের কথা বলবে এমতাবস্থায় যে, তারা তোমাকে চিনবে না।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mdcxii{তারা রাতের বেলায় কাঁদতে কাঁদতে পিতার কাছে এল।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mdcxiii{তারা বললঃ পিতাঃ আমরা দৌড় প্রতিযোগিতা করতে গিয়েছিলাম এবং ইউসুফকে আসবাব-পত্রের কাছে রেখে গিয়েছিলাম। অতঃপর তাকে বাঘে খেয়ে ফেলেছে। আপনি তো আমাদেরকে বিশ্বাস করবেন না, যদিও আমরা সত্যবাদী।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mdcxiv{এবং তারা তার জামায় কৃত্রিম রক্ত লাগিয়ে আনল। বললেনঃ এটা কখনই নয়; বরং তোমাদের মন তোমাদেরকে একটা কথা সাজিয়ে দিয়েছে। সুতরাং এখন ছবর করাই শ্রেয়। তোমরা যা বর্ণনা করছ, সে বিষয়ে একমাত্র আল্লাহই আমার সাহায্য স্থল।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mdcxv{এবং একটি কাফেলা এল। অতঃপর তাদের পানি সংগ্রাহককে প্রেরণ করল। সে বালতি ফেলল। বললঃ কি আনন্দের কথা। এ তো একটি কিশোর তারা তাকে পন্যদ্রব্য গণ্য করে গোপন করে ফেলল। আল্লাহ খুব জানেন যা কিছু তারা করেছিল।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mdcxvi{ওরা তাকে কম মূল্যে বিক্রি করে দিল গনাগুণতি কয়েক দেরহাম এবং তাঁর ব্যাপারে নিরাসক্ত ছিল।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mdcxvii{মিসরে যে ব্যক্তি তাকে ক্রয় করল, সে তার স্ত্রীকে বললঃ একে সম্মানে রাখ। সম্ভবতঃ সে আমাদের কাছে আসবে অথবা আমরা তাকে পুত্ররূপে গ্রহণ করে নেব। এমনিভাবে আমি ইউসুফকে এদেশে প্রতিষ্ঠিত করলাম এবং এ জন্যে যে তাকে বাক্যাদির পূর্ণ মর্ম অনুধাবনের পদ্ধতি বিষয়ে শিক্ষা দেই। আল্লাহ নিজ কাজে প্রবল থাকেন, কিন্তু অধিকাংশ লোক তা জানে না।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mdcxviii{যখন সে পূর্ণ যৌবনে পৌছে গেল, তখন তাকে প্রজ্ঞা ও ব্যুৎপত্তি দান করলাম। এমননিভাবে আমি সৎকর্মপরায়ণদেরকে প্রতিদান দেই।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mdcxix{আর সে যে মহিলার ঘরে ছিল, ঐ মহিলা তাকে ফুসলাতে লাগল এবং দরজাসমূহ বন্ধ করে দিল। সে মহিলা বললঃ শুন! তোমাকে বলছি, এদিকে আস, সে বললঃ আল্লাহ রক্ষা করুন; তোমার স্বামী আমার মালিক। তিনি আমাকে সযত্নে থাকতে দিয়েছেন। নিশ্চয় সীমা লংঘনকারীগণ সফল হয় না।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mdcxx{নিশ্চয় মহিলা তার বিষয়ে চিন্তা করেছিল এবং সেও মহিলার বিষয়ে চিন্তা করত। যদি না সে স্বীয় পালনকর্তার মহিমা অবলোকন করত। এমনিবাবে হয়েছে, যাতে আমি তার কাছ থেকে মন্দ বিষয় ও নিলজ্জ বিষয় সরিয়ে দেই। নিশ্চয় সে আমার মনোনীত বান্দাদের একজন।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mdcxxi{তারা উভয়ে ছুটে দরজার দিকে গেল এবং মহিলা ইউসুফের জামা পিছন দিক থেকে ছিঁড়ে ফেলল। উভয়ে মহিলার স্বামীকে দরজার কাছে পেল। মহিলা বললঃ যে ব্যক্তি তোমার পরিজনের সাথে কুকর্মের ইচ্ছা করে, তাকে কারাগারে পাঠানো অথবা অন্য কোন যন্ত্রণাদায়ক শাস্তি দেয়া ছাড়া তার আর কি শাস্তি হতে পারে?\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mdcxxii{ইউসুফ (আঃ) বললেন, সেই আমাকে আত্মসংবরণ না করতে ফুসলিয়েছে। মহিলার পরিবারে জনৈক সাক্ষী দিল যে, যদি তার জামা সামনের দিক থেকে ছিন্ন থাকে, তবে মহিলা সত্যবাদিনী এবং সে মিথ্যাবাদি।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mdcxxiii{এবং যদি তার জামা পেছনের দিক থেকে ছিন্ন থাকে, তবে মহিলা মিথ্যাবাদিনী এবং সে সত্যবাদী।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mdcxxiv{অতঃপর গৃহস্বামী যখন দেখল যে, তার জামা পেছন দিক থেকে ছিন্ন, তখন সে বলল, নিশ্চয় এটা তোমাদের ছলনা। নিঃসন্দেহে তোমাদের ছলনা খুবই মারাত্নক।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mdcxxv{ইউসুফ এ প্রসঙগ ছাড়! আর হে নারী, এ পাপের জন্য ক্ষমা প্রার্থনা কর নিঃসন্দেহে তুমি-ই পাপাচারিনী।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mdcxxvi{নগরে মহিলারা বলাবলি করতে লাগল যে, আযীযের স্ত্রী স্বীয় গোলামকে কুমতলব চরিতার্থ করার জন্য ফুসলায়। সে তার প্রেমে উম্মত্ত হয়ে গেছে। আমরা তো তাকে প্রকাশ্য ভ্রান্তিতে দেখতে পাচ্ছি।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mdcxxvii{যখন সে তাদের চক্রান্ত শুনল, তখন তাদেরকে ডেকে পাঠাল এবং তাদের জন্যে একটি ভোজ সভার আয়োজন করল। সে তাদের প্রত্যেককে একটি ছুরি দিয়ে বললঃ ইউসুফ এদের সামনে চলে এস। যখন তারা তাকে দেখল, হতভম্ব হয়ে গেল এবং আপন হাত কেটে ফেলল। তারা বললঃ কখনই নয় এ ব্যক্তি মানব নয়। এ তো কোন মহান ফেরেশতা।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mdcxxviii{মহিলা বললঃ এ ঐ ব্যক্তি, যার জন্যে তোমরা আমাকে ভৎর্সনা করছিলে। আমি ওরই মন জয় করতে চেয়েছিলাম। কিন্তু সে নিজেকে নিবৃত্ত রেখেছে। আর আমি যা আদেশ দেই, সে যদি তা না করে, তবে অবশ্যই সে কারাগারে প্রেরিত হবে এবং লাঞ্চিত হবে।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mdcxxix{ইউসুফ বললঃ হে পালনকর্তা তারা আমাকে যে কাজের দিকে আহবান করে, তার চাইতে আমি কারাগারই পছন্দ করি। যদি আপনি তাদের চক্রান্ত আমার উপর থেকে প্রতিহত না করেন, তবে আমি তাদের প্রতি আকৃষ্ট হয়ে পড়ব এবং অজ্ঞদের অন্তর্ভূক্ত হয়ে যাব।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mdcxxx{অতঃপর তার পালনকর্তা তার দোয়া কবুল করে নিলেন। অতঃপর তাদের চক্রান্ত প্রতিহত করলেন। নিশ্চয় তিনি সর্বশ্রোতা ও সর্বজ্ঞ।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mdcxxxi{অতঃপর এসব নিদর্শন দেখার পর তারা তাকে কিছুদিন কারাগারে রাখা সমীচীন মনে করল।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mdcxxxii{তাঁর সাথে কারাগারে দুজন যুবক প্রবেশ করল। তাদের একজন বললঃ আমি স্বপ্নে দেখলাম যে, আমি মদ নিঙড়াচ্ছি। অপরজন বললঃ আমি দেখলাম যে, নিজ মাথায় রুটি বহন করছি। তা থেকে পাখী ঠুকরিয়ে খাচ্ছে। আমাদের কে এর ব্যাখ্যা বলুন। আমরা আপনাকে সৎকর্মশীল দেখতে পাচ্ছি।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mdcxxxiii{তিনি বললেনঃ তোমাদেরকে প্রত্যহ যে খাদ্য দেয়া হয়, তা তোমাদের কাছে আসার আগেই আমি তার ব্যাখ্যা বলে দেব। এ জ্ঞান আমার পালনকর্তা আমাকে শিক্ষা দিয়েছেন। আমি ঐসব লোকের ধর্ম পরিত্যাগ করেছি যারা আল্লাহর প্রতি বিশ্বাস স্থাপন করে না এবং পরকালে অবিশ্বাসী।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mdcxxxiv{আমি আপন পিতৃপুরুষ ইব্রাহীম, ইসহাক ও ইয়াকুবের ধর্ম অনুসরণ করছি। আমাদের জন্য শোভা পায় না যে, কোন বস্তুকে আল্লাহর অংশীদার করি। এটা আমাদের প্রতি এবং অন্য সব লোকের প্রতি আল্লাহর অনুগ্রহ। কিন্ত অধিকাংশ লোক অনুগ্রহ স্বীকার করে না।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mdcxxxv{হে কারাগারের সঙ্গীরা! পৃথক পৃথক অনেক উপাস্য ভাল, না পরাক্রমশালী এক আল্লাহ?\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mdcxxxvi{তোমরা আল্লাহকে ছেড়ে নিছক কতগুলো নামের এবাদত কর, সেগুলো তোমরা এবং তোমাদের বাপ-দাদারা সাব্যস্ত করে নিয়েছে। আল্লাহ এদের কোন প্রমাণ অবতীর্ণ করেননি। আল্লাহ ছাড়া কারও বিধান দেবার ক্ষমতা নেই। তিনি আদেশ দিয়েছেন যে, তিনি ব্যতীত অন্য কারও এবাদত করো না। এটাই সরল পথ। কিন্তু অধিকাংশ লোক তা জানে না।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mdcxxxvii{হে কারাগারের সঙ্গীরা! তোমাদের একজন আপন প্রভুকে মদ্যপান করাবে এবং দ্বিতীয়জন, তাকে শুলে চড়ানো হবে। অতঃপর তার মস্তক থেকে পাখী আহার করবে। তোমরা যে, বিষয়ে জানার আগ্রহী তার সিদ্ধান্ত হয়ে গেছে।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mdcxxxviii{যে ব্যক্তি সম্পর্কে ধারণা ছিল যে, সে মুক্তি পাবে, তাকে ইউসুফ বলে দিলঃ আপন প্রভুর কাছে আমার আলোচনা করবে। অতঃপর শয়তান তাকে প্রভুর কাছে আলোচনার কথা ভুলিয়ে দিল। ফলে তাঁকে কয়েক বছর কারাগারে থাকতে হল।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mdcxxxix{বাদশাহ বললঃ আমি স্বপ্নে দেখলাম, সাতটি মোটাতাজা গাভী-এদেরকে সাতটি শীর্ণ গাভী খেয়ে যাচ্ছে এবং সাতটি সবুজ শীষ ও অন্যগুলো শুষ্ক। হে পরিষদবর্গ! তোমরা আমাকে আমার স্বপ্নের ব্যাখ্যা বল, যদি তোমরা স্বপ্নের ব্যাখ্যায় পারদর্শী হয়ে থাক।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mdcxl{তারা বললঃ এটা কল্পনাপ্রসূত স্বপ্ন। এরূপ স্বপ্নের ব্যাখ্যা আমাদের জানা নেই।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mdcxli{দু’জন কারারুদ্ধের মধ্য থেকে যে ব্যক্তি মুক্তি পেয়েছিল এবং দীর্ঘকাল পর স্মরণ হলে, সে বলল, আমি তোমাদেরকে এর ব্যাখ্যা বলছি। তোমরা আমাকে প্রেরণ কর।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mdcxlii{সে তথায় পৌঁছে বললঃ হে ইউসুফ! হে সত্যবাদী! সাতটি মোটাতাজা গাভী-তাদেরকে খাচ্ছে সাতটি শীর্ণ গাভী এবং সাতটি সবুজ শীর্ষ ও অন্যগুলো শুষ্ক; আপনি আমাদেরকে এ স্বপ্ন সম্পর্কে পথনির্দেশ প্রদান করুনঃ যাতে আমি তাদের কাছে ফিরে গিয়ে তাদের অবগত করাতে পারি।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mdcxliii{বললঃ তোমরা সাত বছর উত্তম রূপে চাষাবাদ করবে। অতঃপর যা কাটবে, তার মধ্যে যে সামান্য পরিমাণ তোমরা খাবে তা ছাড়া অবশিষ্ট শস্য শীষ সমেত রেখে দেবে।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mdcxliv{এবং এরপরে আসবে দূর্ভিক্ষের সাত বছর; তোমরা এ দিনের জন্যে যা রেখেছিলে, তা খেয়ে যাবে, কিন্তু অল্প পরিমাণ ব্যতীত, যা তোমরা তুলে রাখবে।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mdcxlv{এর পরেই আসবে একবছর-এতে মানুষের উপর বৃষ্টি বর্ষিত হবে এবং এতে তারা রস নিঙড়াবে।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mdcxlvi{বাদশাহ বললঃ ফিরে যাও তোমাদের প্রভুর কাছে এবং জিজ্ঞেস কর তাকে ঐ মহিলার স্বরূপ কি, যারা স্বীয় হস্ত কর্তন করেছিল! আমার পালনকর্তা তো তাদের ছলনা সবই জানেন।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mdcxlvii{বাদশাহ মহিলাদেরকে বললেনঃ তোমাদের হাল-হাকিকত কি, যখন তোমরা ইউসুফকে আত্মসংবরণ থেকে ফুসলিয়েছিলে? তারা বললঃ আল্লাহ মহান, আমরা তার সম্পর্কে মন্দ কিছু জানি না। আযীয-পত্মি বললঃ এখন সত্য কথা প্রকাশ হয়ে গেছে। আমিই তাকে আত্মসংবরণ থেকে ফুসলিয়েছিলাম এবং সে সত্যবাদী।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mdcxlviii{ইউসুফ বললেনঃ এটা এজন্য, যাতে আযীয জেনে নেয় যে, আমি গোপনে তার সাথে বিশ্বাসঘাতকতা করিনি। আরও এই যে, আল্লাহ বিশ্বাসঘাতকদের প্রতারণাকে এগুতে দেন না।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mdcxlix{আমি নিজেকে নির্দোষ বলি না। নিশ্চয় মানুষের মন মন্দ কর্মপ্রবণ কিন্তু সে নয়-আমার পালনকর্তা যার প্রতি অনুগ্রহ করেন। নিশ্চয় আমার পালনকর্তা ক্ষমাশীল, দয়ালু।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mdcl{বাদশাহ বললঃ তাকে আমার কাছে নিয়ে এসো। আমি তাকে নিজের বিশ্বস্ত সহচর করে রাখব। অতঃপর যখন তার সাথে মতবিনিময় করল, তখন বললঃ নিশ্চয়ই আপনি আমার কাছে আজ থেকে বিশ্বস্ত হিসাবে মর্যাদার স্থান লাভ করেছেন।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mdcli{ইউসুফ বললঃ আমাকে দেশের ধন-ভান্ডারে নিযুক্ত করুন। আমি বিশ্বস্ত রক্ষক ও অধিক জ্ঞানবান।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mdclii{এমনিভাবে আমি ইউসুফকে সে দেশের বুকে প্রতিষ্ঠা দান করেছি। সে তথায় যেখানে ইচ্ছা স্থান করে নিতে পারত। আমি স্বীয় রহমত যাকে ইচ্ছা পৌছে দেই এবং আমি পূণ্যবানদের প্রতিদান বিনষ্ট করি না।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mdcliii{এবং ঐ লোকদের জন্য পরকালে প্রতিদান উত্তম যারা ঈমান এনেছে ও সতর্কতা অবলম্বন করে।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mdcliv{ইউসুফের ভ্রাতারা আগমন করল, অতঃপর তার কাছে উপস্থিত হল। সে তাদেরকে চিনল এবং তারা তাকে চিনল না।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mdclv{এবং সে যখন তাদেরকে তাদের রসদ প্রস্তুত করে দিল, তখন সে বললঃ তোমাদের বৈমাত্রেয় ভাইকে আমার কাছে নিয়ে এসো। তোমরা কি দেখ না যে, আমি পুরা মাপ দেই এবং মেহমানদেরকে উত্তম সমাদার করি?\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mdclvi{অতঃপর যদি তাকে আমার কাছে না আন, তবে আমার কাছে তোমাদের কোন বরাদ্ধ নেই এবং তোমরা আমার কাছে আসতে পারবে না।\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mdclvii{তারা বললঃ আমরা তার সম্পর্কে তার পিতাকে সম্মত করার চেষ্টা করব এবং আমাদেরকে একাজ করতেই হবে।\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mdclviii{এবং সে ভৃত্যদেরকে বললঃ তাদের পণ্যমূল্য তাদের রসদ-পত্রের মধ্যে রেখে দাও-সম্ভবতঃ তারা গৃহে পৌঁছে তা বুঝতে পারবে, সম্ভবতঃ তারা পুনর্বার আসবে।\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mdclix{তারা যখন তাদের পিতার কাছে ফিরে এল তখন বললঃ হে আমাদের পিতা, আমাদের জন্যে খাদ্য শস্যের বরাদ্দ নিষিদ্ধ করা হয়েছে। অতএব আপনি আমাদের ভাইকে আমাদের সাথে প্রেরণ করুন; যাতে আমরা খাদ্য শস্যের বরাদ্দ আনতে পারি এবং আমরা অবশ্যই তার পুরোপুরি হেফাযত করব।\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mdclx{বললেন, আমি তার সম্পর্কে তোমাদেরকে কি সেরূপ বিশ্বাস করব, যেমন ইতিপূর্বে তার ভাই সম্পর্কে বিশ্বাস করেছিলাম? অতএব আল্লাহ উত্তম হেফাযতকারী এবং তিনিই সর্বাধিক দয়ালু।\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mdclxi{এবং যখন তারা আসবাবপত্র খুলল, তখন দেখতে পেল যে, তাদেরকে তাদের পন্যমুল্য ফেরত দেয়া হয়েছে। তারা বললঃ হে আমাদের পিতা, আমরা আর কি চাইতে পারি। এই আমাদের প্রদত্ত পন্যমূল্য, আমাদেরকে ফেরত দেয়া হয়েছে। এখন আমরা আবার আমাদের পরিবারবর্গের জন্যে রসদ আনব এবং আমাদের ভাইয়ের দেখাশোনা করব এবং এক এক উটের বরাদ্দ খাদ্যশস্য আমরা অতিরিক্ত আনব। ঐ বরাদ্দ সহজ।\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mdclxii{বললেন, তাকে ততক্ষণ তোমাদের সাথে পাঠাব না, যতক্ষণ তোমরা আমাকে আল্লাহর নামে অঙ্গীকার না দাও যে, তাকে অবশ্যই আমার কাছে পৌঁছে দেবে; কিন্তু যদি তোমরা সবাই একান্তই অসহায় না হয়ে যাও। অতঃপর যখন সবাই তাঁকে অঙ্গীকার দিল, তখন তিনি বললেনঃ আমাদের মধ্যে যা কথাবার্তা হলো সে ব্যাপারে আল্লাহই মধ্যস্থ রইলেন।\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mdclxiii{ইয়াকুব বললেনঃ হে আমার বৎসগণ! সবাই একই প্রবেশদ্বার দিয়ে যেয়ো না, বরং পৃথক পৃথক দরজা দিয়ে প্রবেশ করো। আল্লাহর কোন বিধান থেকে আমি তোমাদেরকে রক্ষা করতে পারি না। নির্দেশ আল্লাহরই চলে। তাঁরই উপর আমি ভরসা করি এবং তাঁরই উপর ভরসা করা উচিত ভরসাকারীদের।\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mdclxiv{তারা যখন পিতার কথামত প্রবেশ করল, তখন আল্লাহর বিধানের বিরুদ্ধে তা তাদের বাঁচাতে পারল না। কিন্তু ইয়াকুবের সিদ্ধান্তে তাঁর মনের একটি বাসনা ছিল, যা তিনি পূর্ণ করেছেন। এবং তিনি তো আমার শেখানো বিষয় অবগত ছিলেন। কিন্তু অনেক মানুষ অবগত নয়।\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mdclxv{যখন তারা ইউসুফের কাছে উপস্থিত হল, তখন সে আপন ভ্রাতাকে নিজের কাছে রাখল। বললঃ নিশ্চই আমি তোমার সহোদর। অতএব তাদের কৃতকর্মের জন্যে দুঃখ করো না।\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mdclxvi{অতঃপর যখন ইউসুফ তাদের রসদপত্র প্রস্তুত করে দিল, তখন পানপাত্র আপন ভাইয়ের রসদের মধ্যে রেখে দিল। অতঃপর একজন ঘোষক ডেকে বললঃ হে কাফেলার লোকজন, তোমরা অবশ্যই চোর।\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@mdclxvii{তারা ওদের দিকে মুখ করে বললঃ তোমাদের কি হারিয়েছে?\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@mdclxviii{তারা বললঃ আমরা বাদশাহর পানপাত্র হারিয়েছি এবং যে কেউ এটা এনে দেবে সে এক উটের বোঝা পরিমাণ মাল পাবে এবং আমি এর যামিন।\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@mdclxix{তারা বললঃ আল্লাহর কসম, তোমরা তো জান, আমরা অনর্থ ঘটাতে এদেশে আসিনি এবং আমরা কখনও চোর ছিলাম না।\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@mdclxx{তারা বললঃ যদি তোমরা মিথ্যাবাদী হও, তবে যে, চুরি করেছে তার কি শাস্তি?\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@mdclxxi{তারা বললঃ এর শাস্তি এই যে, যার রসদপত্র থেকে তা পাওয়া যাবে, এর প্রতিদানে সে দাসত্বে যাবে। আমরা যালেমদেরকে এভাবেই শাস্তি দেই।\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@mdclxxii{অতঃপর ইউসুফ আপন ভাইদের থলের পূর্বে তাদের থলে তল্লাশী শুরু করলেন। অবশেষে সেই পাত্র আপন ভাইয়ের থলের মধ্য থেকে বের করলেন। এমনিভাবে আমি ইউসুফকে কৌশল শিক্ষা দিয়েছিলাম। সে বাদশাহর আইনে আপন ভাইকে কখনও দাসত্বে দিতে পারত না, কিন্তু আল্লাহ যদি ইচ্ছা করেন। আমি যাকে ইচ্ছা, মর্যাদায় উন্নীত করি এবং প্রত্যেক জ্ঞানীর উপরে আছে অধিকতর এক জ্ঞানীজন।\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@mdclxxiii{তারা বলতে লাগলঃ যদি সে চুরি করে থাকে, তবে তার এক ভাইও ইতিপূর্বে চুরি করেছিল। তখন ইউসুফ প্রকৃত ব্যাপার নিজের মনে রাখলেন এবং তাদেরকে জানালেন না। মনে মনে বললেনঃ তোমরা লোক হিসাবে নিতান্ত মন্দ এবং আল্লাহ খুব জ্ঞাত রয়েছেন, যা তোমরা বর্ণনা করছ;\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@mdclxxiv{তারা বলতে লাগলঃ হে আযীয, তার পিতা আছেন, যিনি খুবই বৃদ্ধ বয়স্ক। সুতরাং আপনি আমাদের একজনকে তার বদলে রেখে দিন। আমরা আপনাকে অনুগ্রহশীল ব্যক্তিদের একজন দেখতে পাচ্ছি।\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@mdclxxv{তিনি বললেনঃ যার কাছে আমরা আমাদের মাল পেয়েছি, তাকে ছাড়া আর কাউকে গ্রেফতার করা থেকে আল্লাহ আমাদের রক্ষা করুন। তা হলে তো আমরা নিশ্চিতই অন্যায়কারী হয়ে যাব।\qt@no{(79)}}
\qt@newcmd\qurantrans@bn@mdclxxvi{অতঃপর যখন তারা তাঁর কাছ থেকে নিরাশ হয়ে গেল, তখন পরামর্শের জন্যে এখানে বসল। তাদের জ্যেষ্ঠ ভাই বললঃ তোমরা কি জান না যে, পিতা তোমাদের কাছ থেকে আল্লাহর নামে অঙ্গীকার নিয়েছেন এবং পূর্বে ইউসুফের ব্যাপারেও তোমরা অন্যায় করেছো? অতএব আমি তো কিছুতেই এদেশ ত্যাগ করব না, যে পর্যন্ত না পিতা আমাকে আদেশ দেন অথবা আল্লাহ আমার পক্ষে কোন ব্যবস্থা করে দেন। তিনিই সর্বোত্তম ব্যবস্থাপক।\qt@no{(80)}}
\qt@newcmd\qurantrans@bn@mdclxxvii{তোমরা তোমাদের পিতার কাছে ফিরে যাও এবং বলঃ পিতা আপনার ছেলে চুরি করেছে। আমরা তাই বলে দিলাম, যা আমাদের জানা ছিল এবং অদৃশ্য বিষয়ের প্রতি আমাদের লক্ষ্য ছিল না।\qt@no{(81)}}
\qt@newcmd\qurantrans@bn@mdclxxviii{জিজ্ঞেস করুন ঐ জনপদের লোকদেরকে যেখানে আমরা ছিলাম এবং ঐ কাফেলাকে, যাদের সাথে আমরা এসেছি। নিশ্চিতই আমরা সত্য বলছি।\qt@no{(82)}}
\qt@newcmd\qurantrans@bn@mdclxxix{তিনি বললেনঃ কিছুই না, তোমরা মনগড়া একটি কথা নিয়েই এসেছ। এখন ধৈর্য্যধারণই উত্তম। সম্ভবতঃ আল্লাহ তাদের সবাইকে একসঙ্গে আমার কাছে নিয়ে আসবেন তিনি সুবিজ্ঞ, প্রজ্ঞাময়।\qt@no{(83)}}
\qt@newcmd\qurantrans@bn@mdclxxx{এবং তাদের দিক থেকে তিনি মুখ ফিরিয়ে নিলেন এবং বললেনঃ হায় আফসোস ইউসুফের জন্যে। এবং দুঃখে তাঁর চক্ষুদ্বয় সাদা হয়ে গেল। এবং অসহনীয় মনস্তাপে তিনি ছিলেন ক্লিষ্ট।\qt@no{(84)}}
\qt@newcmd\qurantrans@bn@mdclxxxi{তারা বলতে লাগলঃ আল্লাহর কসম আপনি তো ইউসুফের স্মরণ থেকে নিবৃত হবেন না, যে পর্যন্ত মরণপন্ন না হয়ে যান কিংবা মৃতবরণ না করেন\qt@no{(85)}}
\qt@newcmd\qurantrans@bn@mdclxxxii{তিনি বললেনঃ আমি তো আমার দুঃখ ও অস্থিরতা আল্লাহর সমীপেই নিবেদন করছি এবং আল্লাহর পক্ষ থেকে আমি যা জানি, তা তোমরা জান না।\qt@no{(86)}}
\qt@newcmd\qurantrans@bn@mdclxxxiii{বৎসগণ! যাও, ইউসুফ ও তার ভাইকে তালাশ কর এবং আল্লাহর রহমত থেকে নিরাশ হয়ো না। নিশ্চয় আল্লাহর রহমত থেকে কাফের সম্প্রদায়, ব্যতীত অন্য কেউ নিরাশ হয় না।\qt@no{(87)}}
\qt@newcmd\qurantrans@bn@mdclxxxiv{অতঃপর যখন তারা ইউসুফের কাছে পৌঁছল তখন বললঃ হে আযীয, আমরা ও আমাদের পরিবারবর্গ কষ্টের সম্মুখীন হয়ে পড়েছি এবং আমরা অপর্যাপ্ত পুঁজি নিয়ে এসেছি। অতএব আপনি আমাদের পুরোপুরি বরাদ্দ দিন এবং আমাদের কে দান করুন। আল্লাহ দাতাদেরকে প্রতিদান দিয়ে থাকেন।\qt@no{(88)}}
\qt@newcmd\qurantrans@bn@mdclxxxv{ইউসুফ বললেনঃ তোমাদের জানা আছে কি, যা তোমরা ইউসুফ ও তার ভাইয়ের সাথে করেছ, যখন তোমরা অপরিণামদর্শী ছিলে?\qt@no{(89)}}
\qt@newcmd\qurantrans@bn@mdclxxxvi{তারা বলল, তবে কি তুমিই ইউসুফ! বললেনঃ আমিই ইউসুফ এবং এ হল আমার সহোদর ভাই। আল্লাহ আমাদের প্রতি অনুগ্রহ করেছেন। নিশ্চয় যে তাকওয়া অবলম্বন করে এবং সবর করে, আল্লাহ এহেন সৎকর্মশীলদের প্রতিদান বিনষ্ট করেন না।\qt@no{(90)}}
\qt@newcmd\qurantrans@bn@mdclxxxvii{তারা বললঃ আল্লাহর কসম, আমাদের চাইতে আল্লাহ তোমাকে পছন্দ করেছেন এবং আমরা অবশ্যই অপরাধী ছিলাম।\qt@no{(91)}}
\qt@newcmd\qurantrans@bn@mdclxxxviii{বললেন, আজ তোমাদের বিরুদ্ধে কোন অভিযোগ নেই। আল্লাহ তোমাদের কে ক্ষমা করুন। তিনি সব মেহেরবানদের চাইতে অধিক মেহেরবান।\qt@no{(92)}}
\qt@newcmd\qurantrans@bn@mdclxxxix{তোমরা আমার এ জামাটি নিয়ে যাও। এটি আমার পিতার মুখমন্ডলের উপর রেখে দিও, এতে তাঁর দৃষ্টি শক্তি ফিরে আসবে। আর তোমাদের পরিবারবর্গের সবাইকে আমার কাছে নিয়ে এস।\qt@no{(93)}}
\qt@newcmd\qurantrans@bn@mdcxc{যখন কাফেলা রওয়ানা হল, তখন তাদের পিতা বললেনঃ যদি তোমরা আমাকে অপ্রকৃতিস্থ না বল, তবে বলিঃ আমি নিশ্চিতরূপেই ইউসুফের গন্ধ পাচ্ছি।\qt@no{(94)}}
\qt@newcmd\qurantrans@bn@mdcxci{লোকেরা বললঃ আল্লাহর কসম, আপনি তো সেই পুরানো ভ্রান্তিতেই পড়ে আছেন।\qt@no{(95)}}
\qt@newcmd\qurantrans@bn@mdcxcii{অতঃপর যখন সুসংবাদদাতা পৌঁছল, সে জামাটি তাঁর মুখে রাখল। অমনি তিনি দৃষ্টি শক্তি ফিরে পেলেন। বললেনঃ আমি কি তোমাদেরকে বলিনি যে, আমি আল্লাহর পক্ষ থেকে যা জানি তোমরা তা জান না?\qt@no{(96)}}
\qt@newcmd\qurantrans@bn@mdcxciii{তারা বললঃ পিতা আমাদের অপরাধ ক্ষমা করান। নিশ্চয় আমরা অপরাধী ছিলাম।\qt@no{(97)}}
\qt@newcmd\qurantrans@bn@mdcxciv{বললেন, সত্বরই আমি পালনকর্তার কাছে তোমাদের জন্য ক্ষমা চাইব। নিশ্চয় তিনি ক্ষমাশীল, দয়ালূ।\qt@no{(98)}}
\qt@newcmd\qurantrans@bn@mdcxcv{অতঃপর যখন তারা ইউসুফের কাছে পৌঁছল, তখন ইউসুফ পিতা-মাতাকে নিজের কাছে জায়গা দিলেন এবং বললেনঃ আল্লাহ চাহেন তো শান্তি চিত্তে মিসরে প্রবেশ করুন।\qt@no{(99)}}
\qt@newcmd\qurantrans@bn@mdcxcvi{এবং তিনি পিতা-মাতাকে সিংহাসনের উপর বসালেন এবং তারা সবাই তাঁর সামনে সেজদাবনত হল। তিনি বললেনঃ পিতা এ হচ্ছে আমার ইতিপূর্বেকার স্বপ্নের বর্ণনা আমার পালনকর্তা একে সত্যে পরিণত করেছেন এবং তিনি আমার প্রতি অনুগ্রহ করেছেন। আমাকে জেল থেকে বের করেছেন এবং আপনাদেরকে গ্রাম থেকে নিয়ে এসেছেন, শয়তান আমার ও আমার ভাইদের মধ্যে কলহ সৃষ্টি করে দেয়ার পর। আমার পালনকর্তা যা চান, কৌশলে সম্পন্ন করেন। নিশ্চয় তিনি বিজ্ঞ, প্রজ্ঞাময়।\qt@no{(100)}}
\qt@newcmd\qurantrans@bn@mdcxcvii{হে পালনকর্তা আপনি আমাকে রাষ্ট্রক্ষমতাও দান করেছেন এবং আমাকে বিভিন্ন তাৎপর্য সহ ব্যাখ্যা করার বিদ্যা শিখিয়ে দিয়েছেন। হে নভোমন্ডল ও ভূ-মন্ডলের স্রষ্টা, আপনিই আমার কার্যনির্বাহী ইহকাল ও পরকালে। আমাকে ইসলামের উপর মৃত্যুদান করুন এবং আমাকে স্বজনদের সাথে মিলিত করুন।\qt@no{(101)}}
\qt@newcmd\qurantrans@bn@mdcxcviii{এগুলো অদৃশ্যের খবর, আমি আপনার কাছে প্রেরণ করি। আপনি তাদের কাছে ছিলেন না, যখন তারা স্বীয় কাজ সাব্যস্ত করছিল এবং চক্রান্ত করছিল।\qt@no{(102)}}
\qt@newcmd\qurantrans@bn@mdcxcix{আপনি যতই চান, অধিকাংশ লোক বিশ্বাসকারী নয়।\qt@no{(103)}}
\qt@newcmd\qurantrans@bn@mdcc{আপনি এর জন্যে তাদের কাছে কোন বিনিময় চান না। এটা তো সারা বিশ্বের জন্যে উপদেশ বৈ নয়।\qt@no{(104)}}
\qt@newcmd\qurantrans@bn@mdcci{অনেক নিদর্শন রয়েছে নভোমন্ডলে ও ভু-মন্ডলে যেগুলোর উপর দিয়ে তারা পথ অতিক্রম করে এবং তারা এসবের দিকে মনোনিবেশ করে না।\qt@no{(105)}}
\qt@newcmd\qurantrans@bn@mdccii{অনেক মানুষ আল্লাহর প্রতি বিশ্বাস স্থাপন করে, কিন্তু সাথে সাথে শিরকও করে।\qt@no{(106)}}
\qt@newcmd\qurantrans@bn@mdcciii{তারা কি নির্ভীক হয়ে গেছে এ বিষয়ে যে, আল্লাহর আযাবের কোন বিপদ তাদেরকে আবৃত করে ফেলবে অথবা তাদের কাছে হঠাৎ কেয়ামত এসে যাবে, অথচ তারা টেরও পাবে না?\qt@no{(107)}}
\qt@newcmd\qurantrans@bn@mdcciv{বলে দিনঃ এই আমার পথ। আমি আল্লাহর দিকে বুঝে সুঝে দাওয়াত দেই আমি এবং আমার অনুসারীরা। আল্লাহ পবিত্র। আমি অংশীবাদীদের অন্তর্ভুক্ত নই।\qt@no{(108)}}
\qt@newcmd\qurantrans@bn@mdccv{আপনার পূর্বে আমি যতজনকে রসূল করে পাঠিয়েছি, তারা সবাই পুরুষই ছিল জনপদবাসীদের মধ্য থেকে। আমি তাঁদের কাছে ওহী প্রেরণ করতাম। তারা কি দেশ-বিদেশ ভ্রমণ করে না, যাতে দেখে নিত কিরূপ পরিণতি হয়েছে তাদের যারা পূর্বে ছিল ? সংযমকারীদের জন্যে পরকালের আবাসই উত্তম। তারা কি এখনও বোঝে না?\qt@no{(109)}}
\qt@newcmd\qurantrans@bn@mdccvi{এমনকি যখন পয়গম্বরগণ নৈরাশ্যে পতিত হয়ে যেতেন, এমনকি এরূপ ধারণা করতে শুরু করতেন যে, তাদের অনুমান বুঝি মিথ্যায় পরিণত হওয়ার উপক্রম হয়েছিল, তখন তাদের কাছে আমার সাহায্য পৌছে। অতঃপর আমি যাদের চেয়েছি তারা উদ্ধার পেয়েছে। আমার শাস্তি অপরাধী সম্প্রদায় থেকে প্রতিহত হয় না।\qt@no{(110)}}
\qt@newcmd\qurantrans@bn@mdccvii{তাদের কাহিনীতে বুদ্ধিমানদের জন্য রয়েছে প্রচুর শিক্ষণীয় বিষয়, এটা কোন মনগড়া কথা নয়, কিন্তু যারা বিশ্বাস স্থাপন করে তাদের জন্যে পূর্বেকার কালামের সমর্থন এবং প্রত্যেক বস্তুর বিবরণ রহমত ও হেদায়েত।\qt@no{(111)}}
\qt@newcmd\qurantrans@bn@mdccviii{\basmalahbn আলিফ-লাম-মীম-রা; এগুলো কিতাবের আয়াত। যা কিছু আপনার পালনকর্তার পক্ষ থেকে অবতীর্ণ হয়েছে, তা সত্য। কিন্তু অধিকাংশ মানুষ এতে বিশ্বাস করে না।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mdccix{আল্লাহ, যিনি উর্ধ্বদেশে স্থাপন করেছেন আকাশমন্ডলীকে স্তম্ভ ব্যতীত। তোমরা সেগুলো দেখ। অতঃপর তিনি আরশের উপর অধিষ্ঠিত হয়েছেন। এবং সূর্য ও চন্দ্রকে কর্মে নিয়োজিত করেছেন। প্রত্যেকে নির্দিষ্ট সময় মোতাবেক আবর্তন করে। তিনি সকল বিষয় পরিচালনা করেন, নিদর্শনসমূহ প্রকাশ করেন, যাতে তোমরা স্বীয় পালনকর্তার সাথে সাক্ষাত সম্বন্ধে নিশ্চিত বিশ্বাসী হও।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mdccx{তিনিই ভুমন্ডলকে বিস্তৃত করেছেন এবং তাতে পাহাড় পর্বত ও নদ-নদী স্থাপন করেছেন এবং প্রত্যেক ফলের মধ্যে দু’দু প্রকার সৃষ্টি করে রেখেছেন। তিনি দিনকে রাত্রি দ্বারা আবৃত করেন। এতে তাদের জন্যে নিদর্শণ রয়েছে, যারা চিন্তা করে।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mdccxi{এবং যমিনে বিভিন্ন শস্য ক্ষেত্র রয়েছে-একটি অপরটির সাথে সংলগ্ন এবং আঙ্গুরের বাগান আছে আর শস্য ও খজ্জꦣ2497;র রয়েছে-একটির মূল অপরটির সাথে মিলিত এবং কতক মিলিত নয়। এগুলো কে একই পানি দ্বারা সেচ করা হয়। আর আমি স্বাদে একটিকে অপরটির চাইতে উৎকৃষ্টতর করে দেই। এগুলোর মধ্যে নিদর্শণ রয়েছে তাদের জন্য যারা চিন্তা ভাবনা করে।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mdccxii{যদি আপনি বিস্ময়ের বিষয় চান, তবে তাদের একথা বিস্ময়কর যে, আমরা যখন মাটি হয়ে যাব, তখনও কি নতুন ভাবে সৃজিত হব? এরাই স্বীয় পালনকর্তার সত্তায় অবিশ্বাসী হয়ে গেছে, এদের গর্দানেই লৌহ-শৃংখল পড়বে এবং এরাই দোযখী এরা তাতে চিরকাল থাকবে।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mdccxiii{এরা আপনার কাছে মঙ্গলের পরিবর্তে দ্রুত অমঙ্গল কামনা করে। তাদের পূর্বে অনুরূপ অনেক শাস্তিপ্রাপ্ত জনগোষ্ঠী অতিক্রান্ত হয়েছে। আপনার পালনকর্তা মানুষকে তাদের অন্যায় সত্বেও ক্ষমা করেন এবং আপনার পালনকর্তা কঠিন শাস্তিদাতা ও বটে।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mdccxiv{কাফেররা বলেঃ তাঁর প্রতি তাঁর পালনকর্তার পক্ষ থেকে কোন নিদর্শন অবতীর্ণ হল না কেন? আপনার কাজ তো ভয় প্রদর্শন করাই এবং প্রত্যেক সম্প্রদায়ের জন্যে পথপ্রদর্শক হয়েছে।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mdccxv{আল্লাহ জানেন প্রত্যেক নারী যা গর্ভধারণ করে এবং গর্ভাশয়ে যা সঙ্কুচিত ও বর্ধিত হয়। এবং তাঁর কাছে প্রত্যেক বস্তুরই একটা পরিমাণ রয়েছে।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mdccxvi{তিনি সকল গোপন ও প্রকাশ্য বিষয় অবগত, মহোত্তম, সর্বোচ্চ মর্যাদাবান।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mdccxvii{তোমাদের মধ্যে কেউ গোপনে কথা বলুক বা তা সশব্দে প্রকাশ করুক, রাতের অন্ধকারে সে আত্নগোপন করুক বা প্রকাশ্য দিবালোকে বিচরণ করুক, সবাই তাঁর নিকট সমান।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mdccxviii{তাঁর পক্ষ থেকে অনুসরণকারী রয়েছে তাদের অগ্রে এবং পশ্চাতে, আল্লাহর নির্দেশে তারা ওদের হেফাযত করে। আল্লাহ কোন জাতির অবস্থা পরিবর্তন করেন না, যে পর্যন্ত না তারা তাদের নিজেদের অবস্থা পরিবর্তন করে। আল্লাহ যখন কোন জাতির উপর বিপদ চান, তখন তা রদ হওয়ার নয় এবং তিনি ব্যতীত তাদের কোন সাহায্যকারী নেই।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mdccxix{তিনিই তোমাদেরকে বিদ্যুৎ দেখান ভয়ের জন্যে এবং আশার জন্যে এবং উক্ষিত করেন ঘন মেঘমালা।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mdccxx{তাঁর প্রশংসা পাঠ করে বজ্র এবং সব ফেরেশতা, সভয়ে। তিনি বজ্রপাত করেন, অতঃপর যাকে ইচছা, তাকে তা দ্বারা আঘাত করেন; তথাপি তারা আল্লাহ সম্পর্কে বিতন্ডা করে, অথচ তিনি মহাশক্তিশালী।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mdccxxi{সত্যের আহবান একমাত্র তাঁরই এবং তাকে ছাড়া যাদেরকে ডাকে, তারা তাদের কোন কাজে আসে না; ওদের দৃষ্টান্ত সেরূপ, যেমন কেউ দু’ হাত পানির দিকে প্রসারিত করে যাতে পানি তার মুখে পৌঁছে যায়। অথচ পানি কোন সময় পৌঁছাবে না। কাফেরদের যত আহবান তার সবই পথভ্রষ্টতা।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mdccxxii{আল্লাহকে সেজদা করে যা কিছু নভোমন্ডলে ও ভূমন্ডলে আছে ইচ্ছায় অথবা অনিচ্ছায় এবং তাদের প্রতিচ্ছায়াও সকাল-সন্ধ্যায়।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mdccxxiii{জিজ্ঞেস করুন নভোমন্ডল ও ভুমন্ডলের পালনকর্তা কে? বলে দিনঃ আল্লাহ! বলুনঃ তবে কি তোমরা আল্লাহ ব্যতীত এমন অভিভাবক স্থির করেছ, যারা নিজেদের ভাল-মন্দের ও মালিক নয়? বলুনঃ অন্ধ চক্ষুষ্মান কি সমান হয়? অথবা কোথাও কি অন্ধকার ও আলো সমান হয়। তবে কি তারা আল্লাহর জন্য এমন অংশীদার স্থির করেছে যে, তারা কিছু সৃষ্টি করেছে, যেমন সৃষ্টি করেছেন আল্লাহ? অতঃপর তাদের সৃষ্টি এরূপ বিভ্রান্তি ঘটিয়েছে? বলুনঃ আল্লাহই প্রত্যেক বস্তুর স্রষ্টা এবং তিনি একক, পরাক্রমশালী।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mdccxxiv{তিনি আকাশ থেকে পানি বর্ষণ করেন। অতঃপর স্রোতধারা প্রবাহিত হতে থাকে নিজ নিজ পরিমাণ অনুযায়ী। অতঃপর স্রোতধারা স্ফীত ফেনারাশি উপরে নিয়ে আসে। এবং অলঙ্কার অথবা তৈজসপত্রের জন্যে যে বস্তুকে আগুনে উত্তপ্ত করে, তাতেও তেমনি ফেনারাশি থাকে। এমনি ভাবে আল্লাহ সত্য ও অসত্যের দৃষ্টান্ত প্রদান করেন। অতএব, ফেনা তো শুকিয়ে খতম হয়ে যায় এবং যা মানুষের উপকারে আসে, তা জমিতে অবশিষ্ট থাকে। আল্লাহ এমনিভাবে দৃষ্টান্তসমূহ বর্ণনা করেন।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mdccxxv{যারা পালনকর্তার আদেশ পালন করে, তাদের জন্য উত্তম প্রতিদান রয়েছে এবং যারা আদেশ পালন করে না, যদি তাদের কাছে জগতের সবকিছু থাকে এবং তার সাথে তার সমপরিমাণ আরও থাকে, তবে সবই নিজেদের মুক্তিপণ স্বরূপ দিয়ে দেবে। তাদের জন্যে রয়েছে কঠোর হিসাব। তাদের আবাস হবে জাহান্নাম। সেটা কতইনা নিকৃষ্ট অবস্থান।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mdccxxvi{যে ব্যক্তি জানে যে, যা কিছু পালনকর্তার পক্ষ থেকে আপনার প্রতি অবর্তীর্ণ হয়েছে তা সত্য সে কি ঐ ব্যক্তির সমান, যে অন্ধ? তারাই বোঝে, যারা বোধশক্তি সম্পন্ন।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mdccxxvii{এরা এমন লোক, যারা আল্লাহর প্রতিশ্রুতি পূর্ণ করে এবং অঙ্গীকার ভঙ্গ করে না।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mdccxxviii{এবং যারা বজায় রাখে ঐ সম্পর্ক, যা বজায় রাখতে আল্লাহ আদেশ দিয়েছেন এবং স্বীয় পালনকর্তাকে ভয় করে এবং কঠোর হিসাবের আশঙ্কা রাখে।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mdccxxix{এবং যারা স্বীয় পালনকর্তার সন্তুষ্টির জন্যে সবর করে, নামায প্রতিষ্টা করে আর আমি তাদেরকে যা দিয়েছি, তা থেকে গোপনে ও প্রকাশ্য ব্যয় করে এবং যারা মন্দের বিপরীতে ভাল করে, তাদের জন্যে রয়েছে পরকালের গৃহ।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mdccxxx{তা হচ্ছে বসবাসের বাগান। তাতে তারা প্রবেশ করবে এবং তাদের সৎকর্মশীল বাপ-দাদা, স্বামী-স্ত্রী ও সন্তানেরা। ফেরেশতারা তাদের কাছে আসবে প্রত্যেক দরজা দিয়ে।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mdccxxxi{বলবেঃ তোমাদের সবরের কারণে তোমাদের উপর শান্তি বর্ষিত হোক। আর তোমাদের এ পরিণাম-গৃহ কতই না চমৎকার।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mdccxxxii{এবং যারা আল্লাহর অঙ্গীকারকে দৃঢ় ও পাকা-পোক্ত করার পর তা ভঙ্গ করে, আল্লাহ যে, সম্পর্ক বজায় রাখতে আদেশ করেছেন, তা ছিন্ন করে এবং পৃথিবীতে অশান্তি সৃষ্টি করে, ওরা ঐ সমস্ত লোক যাদের জন্যে রয়েছে অভিসম্পাত এবং ওদের জন্যে রয়েছে কঠিন আযাব।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mdccxxxiii{আল্লাহ যার জন্যে ইচ্ছা রুযী প্রশস্ত করেন এবং সংকুচিত করেন। তারা পার্থিব জীবনের প্রতি মুগ্ধ। পার্থিবজীবন পরকালের সামনে অতি সামান্য সম্পদ বৈ নয়।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mdccxxxiv{কাফেররা বলেঃ তাঁর প্রতি তাঁর পালনকর্তার পক্ষ থেকে কোন নিদর্শন কেন অবতীর্ণ হলো না? বলে দিন, আল্লাহ যাকে ইচ্ছা পথভ্রষ্ট করেন এবং যে, মনোনিবেশ করে, তাকে নিজের দিকে পথপ্রদর্শন করেন।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mdccxxxv{যারা বিশ্বাস স্থাপন করে এবং তাদের অন্তর আল্লাহর যিকির দ্বারা শান্তি লাভ করে; জেনে রাখ, আল্লাহর যিকির দ্বারাই অন্তর সমূহ শান্তি পায়।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mdccxxxvi{যারা বিশ্বাস স্থাপন করে এবং সৎকর্ম সম্পাদন করে, তাদের জন্যে রয়েছে সুসংবাদ এবং মনোরম প্রত্যাবর্তণস্থল।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mdccxxxvii{এমনিভাবে আমি আপনাকে একটি উম্মতের মধ্যে প্রেরণ করেছি। তাদের পূর্বে অনেক উম্মত অতিক্রান্ত হয়েছে। যাতে আপনি তাদেরকে ঐ নির্দেশ শুনিয়ে দেন, যা আমি আপনার কাছে প্রেরণ করেছি। তথাপি তারা দয়াময়কে অস্বীকার করে। বলুনঃ তিনিই আমার পালনকর্তা। তিনি ব্যতীত কারও উপাসনা নাই। আমি তাঁর উপরই ভরসা করেছি এবং তাঁর দিকেই আমার প্রত্যাবর্তণ।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mdccxxxviii{যদি কোন কোরআন এমন হত, যার সাহায্যে পাহাড় চলমান হয় অথবা যমীন খন্ডিত হয় অথবা মৃতরা কথা বলে, তবে কি হত? বরং সব কাজ তো আল্লাহর হাতে। ঈমানদাররা কি এ ব্যাপারে নিশ্চিত নয় যে, যদি আল্লাহ চাইতেন, তবে সব মানুষকে সৎপথে পরিচালিত করতেন? কাফেররা তাদের কৃতকর্মের কারণে সব সময় আঘাত পেতে থাকবে অথবা তাদের গৃহের নিকটবর্তী স্থানে আঘাত নেমে আসবে, যে, পর্যন্ত আল্লাহর ওয়াদা না আসে। নিশ্চয় আল্লাহ ওয়াদার খেলাফ করেন না।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mdccxxxix{আপনার পূর্বে কত রাসূলের সাথে ঠাট্টা করা হয়েছে। অতঃপর আমি কাফেরদেরকে কিছু অবকাশ দিয়েছি। , এর পর তাদেরকে পাকড়াও করেছি। অতএব কেমন ছিল আমার শাস্তি।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mdccxl{ওরা প্রত্যেকেই কি মাথার উপর স্ব স্ব কৃতকর্ম নিয়ে দন্ডায়মান নয়? এবং তারা আল্লাহর জন্য অংশীদার সাব্যস্ত করে। বলুন; নাম বল অথবা খবর দাও পৃথিবীর এমন কিছু জিনিস সম্পর্কে যা তিনি জানেন না? অথবা অসার কথাবার্তা বলছ? বরং সুশোভিত করা হয়েছে কাফেরদের জন্যে তাদের প্রতারণাকে এবং তাদেরকে সৎপথ থেকে বাধা দান করা হয়েছে। আল্লাহ যাকে পথভ্রষ্ট করেন, তার কোন পথ প্রদর্শক নেই।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mdccxli{দুনিয়ার জীবনেই এদের জন্য রয়েছে আযাব এবং অতি অবশ্য আখেরাতের জীবন কঠোরতম। আল্লাহর কবল থেকে তাদের কোন রক্ষাকারী নেই।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mdccxlii{পরহেযগারদের জন্যে প্রতিশ্রুত জান্নাতের অবস্থা এই যে, তার নিম্নে নির্ঝরিণীসমূহ প্রবাহিত হয়। তার ফলসমূহ চিরস্থায়ী এবং ছায়াও। এটা তাদের প্রতিদান, যারা সাবধান হয়েছে এবং কাফেরদের প্রতিফল অগ্নি।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mdccxliii{এবং যাদেরকে আমি গ্রন্থ দিয়েছি, তারা আপনার প্রতি যা অবতীর্ণ হয়েছে, তজ্জন্যে আনন্দিত হয় এবং কোন কোন দল এর কোন কোন বিষয় অস্বীকার করে। বলুন, আমাকে এরূপ আদেশই দেয়া হয়েছে যে, আমি আল্লাহর এবাদত করি। এবং তাঁর সাথে অংশীদার না করি। আমি তাঁর দিকেই দাওয়াত দেই এবং তাঁর কাছেই আমার প্রত্যাবর্তন।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mdccxliv{এমনিভাবেই আমি এ কোরআনকে আরবী ভাষায় নির্দেশরূপে অবতীর্ণ করেছি। যদি আপনি তাদের প্রবৃত্তির অনুসরণ করেন আপনার কাছে জ্ঞান পৌঁছার পর, তবে আল্লাহর কবল থেকে আপনার না কোন সাহায্যকারী আছে এবং না কোন রক্ষাকারী।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mdccxlv{আপনার পূর্বে আমি অনেক রসূল প্রেরণ করেছি এবং তাঁদেরকে পত্নী ও সন্তান-সন্ততি দিয়েছি। কোন রসূলের এমন সাধ্য ছিল না যে আল্লাহর নির্দেশ ছাড়া কোন নিদর্শন উপস্থিত করে। প্রত্যেকটি ওয়াদা লিখিত আছে।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mdccxlvi{আল্লাহ যা ইচ্ছা মিটিয়ে দেন এবং বহাল রাখেন এবং মূলগ্রন্থ তাঁর কাছেই রয়েছে।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mdccxlvii{আমি তাদের সাথে যে ওয়াদা করেছি, তার কোন একটি যদি আপনাকে দেখিয়ে দেই কিংবা আপনাকে উঠিয়ে নেই, তাতে কি আপনার দায়িত্ব তো পৌছে দেয়া এবং আমার দায়িত্ব হিসাব নেয়া।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mdccxlviii{তারা কি দেখে না যে, আমি তাদের দেশকে চতুর্দিক থেকে সমানে সঙ্কুচিত করে আসছি? আল্লাহ নির্দেশ দেন। তাঁর নির্দেশকে পশ্চাতে নিক্ষেপকারী কেউ নেই। তিনি দ্রুত হিসাব গ্রহণ করেন।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mdccxlix{তাদের পূর্বে যারা ছিল, তারা চক্রান্ত করেছে। আর সকল চক্রান্ত তো আল্লাহর হাতেই আছে। তিনি জানেন প্রত্যেক ব্যক্তি যা কিছু করে। কাফেররা জেনে নেবে যে, পর জীবনের আবাসস্থল কাদের জন্য রয়েছে।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mdccl{কাফেররা বলেঃ আপনি প্রেরিত ব্যক্তি নন। বলে দিন, আমার ও তোমাদের মধ্যে প্রকৃষ্ট সাক্ষী হচ্ছেন আল্লাহ এবং ঐ ব্যক্তি, যার কাছে গ্রন্থের জ্ঞান আছে।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mdccli{\basmalahbn আলিফ-লাম-রা; এটি একটি গ্রন্থ, যা আমি আপনার প্রতি নাযিল করেছি-যাতে আপনি মানুষকে অন্ধকার থেকে আলোর দিকে বের করে আনেন-পরাক্রান্ত, প্রশংসার যোগ্য পালনকর্তার নির্দেশে তাঁরই পথের দিকে।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mdcclii{তিনি আল্লাহ; যিনি নভোমন্ডল ও ভূ-মন্ডলের সবকিছুর মালিক। কাফেরদের জন্যে বিপদ রয়েছে, কঠোর আযাব;\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mdccliii{যারা পরকালের চাইতে পার্থিব জীবনকে পছন্দ করে; আল্লাহর পথে বাধা দান করে এবং তাতে বক্রতা অন্বেষণ করে, তারা পথ ভুলে দূরে পড়ে আছে।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mdccliv{আমি সব পয়গম্বরকেই তাদের স্বজাতির ভাষাভাষী করেই প্রেরণ করেছি, যাতে তাদেরকে পরিষ্কার বোঝাতে পারে। অতঃপর আল্লাহ যাকে ইচ্ছা, পথঃভ্রষ্ট করেন এবং যাকে ইচ্ছা সৎপথ প্রদর্শন করেন। তিনি পরাক্রান্ত, প্রজ্ঞাময়।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mdcclv{আমি মূসাকে নিদর্শনাবলী সহ প্রেরণ করেছিলাম যে, স্বজাতিকে অন্ধকার থেকে আলোর দিকে আনয়ন এবং তাদেরকে আল্লাহর দিনসমূহ স্মরণ করান। নিশ্চয় এতে প্রত্যেক ধৈর্যশীল কৃতজ্ঞের জন্যে নিদর্শনাবলী রয়েছে।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mdcclvi{যখন মূসা স্বজাতিকে বললেনঃ তোমাদের প্রতি আল্লাহর অনুগ্রহ স্মরণ কর যখন তিনি তোমাদেরকে ফেরাউনের সম্প্রদায়ের কবল থেকে মুক্তি দেন। তারা তোমাদেরকে অত্যন্ত নিকৃষ্ট ধরনের শাস্তি দিত, তোমাদের ছেলেদেরকে হত্যা করত এবং তোমাদের মেয়েদেরকে জীবিত রাখত। এবং এতে তোমাদের পালনকর্তার পক্ষ থেকে বিরাট পরীক্ষা হয়েছিল।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mdcclvii{যখন তোমাদের পালনকর্তা ঘোষণা করলেন যে, যদি কৃতজ্ঞতা স্বীকার কর, তবে তোমাদেরকে আরও দেব এবং যদি অকৃতজ্ঞ হও তবে নিশ্চয়ই আমার শাস্তি হবে কঠোর।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mdcclviii{এবং মূসা বললেনঃ তোমরা এবং পৃথিবীর সবাই যদি কুফরী কর, তথাপি আল্লাহ অমুখাপেক্ষী, যাবতীয় গুনের আধার।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mdcclix{তোমাদের কাছে কি তোমাদের পূর্ববর্তী কওমে নূহ, আদ ও সামুদের এবং তাদের পরবর্তীদের খবর পৌছেনি? তাদের বিষয়ে আল্লাহ ছাড়া আর কেউ জানে না। তাদের কাছে তাদের পয়গম্বর প্রমানাদি নিয়ে আগমন করেন। অতঃপর তারা নিজেদের হাত নিজেদের মুখে রেখে দিয়েছে এবং বলেছে, যা কিছু সহ তোমাদেরকে প্রেরণ করা হয়েছে, আমরা তা মানি না এবং যে পথের দিকে তোমরা আমাদেরকে দাওয়াত দাও, সে সম্পর্কে আমাদের মনে সন্দেহ আছে, যা আমাদেরকে উৎকন্ঠায় ফেলে রেখেছে।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mdcclx{তাদের পয়গম্বরগণ বলেছিলেনঃ আল্লাহ সম্পর্কে কি সন্দেহ আছে, যিনি নভোমন্ডল ও ভুমন্ডলের স্রষ্টা? তিনি তোমাদেরকে আহবান করেন যাতে তোমাদের কিছু গুনাহ ক্ষমা করেন এবং নির্দিষ্ট মেয়াদ পর্যন্ত তোমাদের সময় দেন। তারা বলতঃ তোমরা তো আমাদের মতই মানুষ! তোমরা আমাদেরকে ঐ উপাস্য থেকে বিরত রাখতে চাও, যার এবাদত আমাদের পিতৃপুরুষগণ করত। অতএব তোমরা কোন সুস্পষ্ট প্রমাণ আনয়ন কর।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mdcclxi{তাদের পয়গম্বর তাদেরকে বলেনঃ আমারাও তোমাদের মত মানুষ, কিন্তু আল্লাহ বান্দাদের মধ্য থেকে যার উপরে ইচ্ছা, অনুগ্রহ করেন। আল্লাহর নির্দেশ ব্যতীত তোমাদের কাছে প্রমাণ নিয়ে আসা আমাদের কাজ নয়; ঈমানদারদের আল্লাহর উপর ভরসা করা চাই।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mdcclxii{আমাদের আল্লাহর উপর ভরসা না করার কি কারণ থাকতে পারে, অথচ তিনি আমাদেরকে আমাদের পথ বলে দিয়েছেন। তোমরা আমাদেরকে যে পীড়ন করেছ, তজ্জন্যে আমরা সবর করব। ভরসাকারিগণের আল্লাহর উপরই ভরসা করা উচিত।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mdcclxiii{কাফেররা পয়গম্বরগণকে বলেছিলঃ আমরা তোমাদেরকে দেশ থেকে বের করে দেব অথবা তোমরা আমাদের ধর্মে ফিরে আসবে। তখন তাদের কাছে তাদের পালনকর্তা ওহী প্রেরণ করলেন যে, আমি জালিমদেরকে অবশ্যই ধ্বংস করে দেব।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mdcclxiv{তাদের পর তোমাদেরকে দেশে আবাদ করব। এটা ঐ ব্যক্তি পায়, যে আমার সামনে দন্ডায়মান হওয়াকে এবং আমার আযাবের ওয়াদাকে ভয় করে।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mdcclxv{পয়গম্বরগণ ফয়সালা চাইতে লাগলেন এবং প্রত্যেক অবাধ্য, হঠকারী ব্যর্থ কাম হল।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mdcclxvi{তার পেছনে দোযখ রয়েছে। তাতে পূঁজ মিশানো পানি পান করানো হবে।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mdcclxvii{ঢোক গিলে তা পান করবে। এবং গলার ভিতরে প্রবেশ করতে পারবে না। প্রতি দিক থেকে তার কাছে মৃত্যু আগমন করবে এবং সে মরবে না। তার পশ্চাতেও রয়েছে কঠোর আযাব।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mdcclxviii{যারা স্বীয় পালনকর্তার সত্তার অবিশ্বাসী তাদের অবস্থা এই যে, তাদের কর্মসমূহ ছাইভস্মের মত যার উপর দিয়ে প্রবল বাতাস বয়ে যায় ধূলিঝড়ের দিন। তাদের উপার্জনের কোন অংশই তাদের করতলগত হবে না। এটাই দুরবর্তী পথভ্রষ্টতা।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mdcclxix{তুমি কি দেখনি যে, আল্লাহ নভোমন্ডল ও ভুমন্ডল যথাবিধি সৃষ্টি করেছেন? যদি তিনি ইচ্ছা করেন, তবে তোমাদেরকে বিলুপ্তিতে নিয়ে যাবেন এবং নতুন সৃষ্টি আনয়ন করবেন।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mdcclxx{এটা আল্লাহর পক্ষে মোটেই কঠিন নয়।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mdcclxxi{সবাই আল্লাহর সামনে দন্ডায়মান হবে এবং দুর্বলেরা বড়দেরকে বলবেঃ আমরা তো তোমাদের অনুসারী ছিলাম-অতএব, তোমরা আল্লাহর আযাব থেকে আমাদেরকে কিছুমাত্র রক্ষা করবে কি? তারা বলবেঃ যদি আল্লাহ আমাদেরকে সৎপথ দেখাতেন, তবে আমরা অবশ্যই তোমাদের কে সৎপথ দেখাতাম। এখন তো আমাদের ধৈর্য্যচ্যুত হই কিংবা সবর করি-সবই আমাদের জন্যে সমান আমাদের রেহাই নেই।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mdcclxxii{যখন সব কাজের ফায়সলা হয়ে যাবে, তখন শয়তান বলবেঃ নিশ্চয় আল্লাহ তোমাদেরকে সত্য ওয়াদা দিয়েছিলেন এবং আমি তোমাদের সাথে ওয়াদা করেছি, অতঃপর তা ভঙ্গ করেছি। তোমাদের উপর তো আমার কোন ক্ষমতা ছিল না, কিন্তু এতটুকু যে, আমি তোমাদেরকে ডেকেছি, অতঃপর তোমরা আমার কথা মেনে নিয়েছ। অতএব তোমরা আমাকে ভৎর্সনা করো না এবং নিজেদেরকেই ভৎর্সনা কর। আমি তোমাদের উদ্ধারে সাহায্যকারী নই। এবং তোমরাও আমার উদ্ধারে সাহায্যকারী নও। ইতোপূর্বে তোমরা আমাকে যে আল্লাহর শরীক করেছিলে, আমি তা অস্বীকার করি। নিশ্চয় যারা জালেম তাদের জন্যে রয়েছে যন্ত্রণাদায়ক শাস্তি।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mdcclxxiii{এবং যারা বিশ্বাস স্থাপণ করে এবং সৎকর্ম সম্পাদন করে তাদেরকে এমন উদ্যানে প্রবেশ করানো হবে, যার পাদদেশ দিয়ে নির্ঝরিনী সমূহ প্রবাহিত হবে তারা তাতে পালনকর্তার নির্দেশে অনন্তকাল থাকবে। যেখানে তাদের সম্ভাষণ হবে সালাম।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mdcclxxiv{তুমি কি লক্ষ্য কর না, আল্লাহ তা’আলা কেমন উপমা বর্ণনা করেছেনঃ পবিত্র বাক্য হলো পবিত্র বৃক্ষের মত। তার শিকড় মজবুত এবং শাখা আকাশে উত্থিত।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mdcclxxv{সে পালনকর্তার নির্দেশে অহরহ ফল দান করে। আল্লাহ মানুষের জন্যে দৃষ্টান্ত বর্ণণা করেন-যাতে তারা চিন্তা-ভাবনা করে।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mdcclxxvi{এবং নোংরা বাক্যের উদাহরণ হলো নোংরা বৃক্ষ। একে মাটির উপর থেকে উপড়ে নেয়া হয়েছে। এর কোন স্থিতি নেই।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mdcclxxvii{আল্লাহ তা’আলা মুমিনদেরকে মজবুত বাক্য দ্বারা মজবুত করেন। পার্থিবজীবনে এবং পরকালে। এবং আল্লাহ জালেমদেরকে পথভ্রষ্ট করেন। আল্লাহ যা ইচ্ছা, তা করেন।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mdcclxxviii{তুমি কি তাদের কে দেখনি, যারা আল্লাহর নেয়ামতকে কুফরে পরিণত করেছে এবং স্ব-জাতিকে সম্মুখীন করেছে ধ্বংসের আলয়ে।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mdcclxxix{দোযখের? তারা তাতে প্রবেশ করবে সেটা কতই না মন্দ আবাস।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mdcclxxx{এবং তারা আল্লাহর জন্যে সমকক্ষ স্থির করেছে, যাতে তারা তার পথ থেকে বিচ্যুত করে দেয়। বলুনঃ মজা উপভোগ করে নাও। অতঃপর তোমাদেরকে অগ্নির দিকেই ফিরে যেতে হবে।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mdcclxxxi{আমার বান্দাদেরকে বলে দিন যারা বিশ্বাস স্থাপন করেছে, তারা নামায কায়েম রাখুক এবং আমার দেয়া রিযিক থেকে গোপনে ও প্রকাশ্যে ব্যয় করুক ঐদিন আসার আগে, যেদিন কোন বেচা কেনা নেই এবং বন্ধুত্বও নেই।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mdcclxxxii{তিনিই আল্লাহ, যিনি নভোমন্ডল ও ভুমন্ডল সৃজন করেছেন এবং আকাশ থেকে পানি বর্ষণ করে অতঃপর তা দ্বারা তোমাদের জন্যে ফলের রিযিক উৎপন্ন করেছেন এবং নৌকাকে তোমাদের আজ্ঞাবহ করেছেন, যাতে তাঁর আদেশে সমুদ্রে চলা ফেরা করে এবং নদ-নদীকে তোমাদের সেবায় নিয়োজিত করেছেন।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mdcclxxxiii{এবং তোমাদের সেবায় নিয়োজিত করেছেন সূর্যকে এবং চন্দ্রকে সর্বদা এক নিয়মে এবং রাত্রি ও দিবাকে তোমাদের কাজে লাগিয়েছেন।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mdcclxxxiv{যে সকল বস্তু তোমরা চেয়েছ, তার প্রত্যেকটি থেকেই তিনি তোমাদেরকে দিয়েছেন। যদি আল্লাহর নেয়ামত গণনা কর, তবে গুণে শেষ করতে পারবে না। নিশ্চয় মানুষ অত্যন্ত অন্যায়কারী, অকৃতজ্ঞ।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mdcclxxxv{যখন ইব্রাহীম বললেনঃ হে পালনকর্তা, এ শহরকে শান্তিময় করে দিন এবং আমাকে ও আমার সন্তান সন্ততিকে মূর্তি পূজা থেকে দূরে রাখুন।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mdcclxxxvi{হে পালনকর্তা, এরা অনেক মানুষকে বিপথগামী করেছে। অতএব যে আমার অনুসরণ করে, সে আমার এবং কেউ আমার অবাধ্যতা করলে নিশ্চয় আপনি ক্ষমাশীল, পরম দয়ালু।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mdcclxxxvii{হে আমাদের পালনকর্তা, আমি নিজের এক সন্তানকে তোমার পবিত্র গৃহের সন্নিকটে চাষাবাদহীন উপত্যকায় আবাদ করেছি; হে আমাদের পালনকর্তা, যাতে তারা নামায কায়েম রাখে। অতঃপর আপনি কিছু লোকের অন্তরকে তাদের প্রতি আকৃষ্ট করুন এবং তাদেরকে ফলাদি দ্বারা রুযী দান করুন, সম্ভবতঃ তারা কৃতজ্ঞতা প্রকাশ করবে\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mdcclxxxviii{হে আমাদের পালনকর্তা, আপনি তো জানেন আমরা যা কিছু গোপনে করি এবং যা কিছু প্রকাশ্য করি। আল্লাহর কাছে পৃথিবীতে ও আকাশে কোন কিছুই গোপন নয়।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mdcclxxxix{সমস্ত প্রশংসা আল্লাহরই, যিনি আমাকে এই বার্ধক্যে ইসমাঈল ও ইসহাক দান করেছেন নিশ্চয় আমার পালনকর্তা দোয়া শ্রবণ করেন।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mdccxc{হে আমার পালনকর্তা, আমাকে নামায কায়েমকারী করুন এবং আমার সন্তানদের মধ্যে থেকেও। হে আমাদের পালনকর্তা, এবং কবুল করুন আমাদের দোয়া।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mdccxci{হে আমাদের পালনকর্তা, আমাকে, আমার পিতা-মাতাকে এবং সব মুমিনকে ক্ষমা করুন, যেদিন হিসাব কায়েম হবে।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mdccxcii{জালেমরা যা করে, সে সম্পর্কে আল্লাহকে কখনও বেখবর মনে করো না তাদেরকে তো ঐ দিন পর্যন্ত অবকাশ দিয়ে রেখেছেন, যেদিন চক্ষুসমূহ বিস্ফোরিত হবে।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mdccxciii{তারা মস্তক উপরে তুলে ভীত-বিহবল চিত্তে দৌড়াতে থাকবে। তাদের দিকে তাদের দৃষ্টি ফিরে আসবে না এবং তাদের অন্তর উড়ে যাবে।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mdccxciv{মানুষকে ঐ দিনের ভয় প্রদর্শন করুন, যেদিন তাদের কাছে আযাব আসবে। তখন জালেমরা বলবেঃ হে আমাদের পালনকর্তা, আমাদেরকে সামান্য মেয়াদ পর্যন্ত সময় দিন, যাতে আমরা আপনার আহবানে সাড়া দিতে এবং পয়গম্বরগণের অনুসরণ করতে পারি। তোমরা কি ইতোপূর্বে কসম খেতে না যে, তোমাদেরকে দুনিয়া থেকে যেতে হবে না?\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mdccxcv{তোমরা তাদের বাসভূমিতেই বসবাস করতে, যারা নিজেদের উপর জুলুম করেছে এবং তোমাদের জানা হয়ে গিয়েছিল যে, আমি তাদের সাথে কিরূপ ব্যবহার করেছি এবং আমি তোমাদেরকে ওদের সব কাহিনীই বর্ণনা করেছি।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mdccxcvi{তারা নিজেদের মধ্যে ভীষণ চক্রান্ত করে নিয়েছে এবং আল্লাহর সামনে রক্ষিত আছে তাদের কু-চক্রান্ত। তাদের কুটকৌশল পাহাড় টলিয়ে দেয়ার মত হবে না।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mdccxcvii{অতএব আল্লাহর প্রতি ধারণা করো না যে, তিনি রসূলগণের সাথে কৃত ওয়াদা ভঙ্গ করবেন নিশ্চয় আল্লাহ পরাক্রমশালী, প্রতিশোধ গ্রহণকারী।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mdccxcviii{যেদিন পরিবর্তিত করা হবে এ পৃথিবীকে অন্য পৃথিবীতে এবং পরিবর্তিত করা হবে আকাশ সমূহকে এবং লোকেরা পরাক্রমশালী এবং আল্লাহর সামনে পেশ হবে।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mdccxcix{তুমি ঐদিন পাপীদেরকে পরস্পরে শৃংখলা বদ্ধ দেখবে।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mdccc{তাদের জামা হবে দাহ্য আলকাতরার এবং তাদের মুখমন্ডলকে আগুন আচ্ছন্ন করে ফেলবে।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mdccci{যাতে আল্লাহ প্রত্যেককে তার কৃতকর্মের প্রতিদান দেন। নিশ্চয় আল্লাহ দ্রুত হিসাব গ্রহণকারী।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mdcccii{এটা মানুষের একটি সংবাদনামা এবং যাতে এতদ্বারা ভীত হয় এবং যাতে জেনে নেয় যে, উপাস্য তিনিই-একক; এবং যাতে বুদ্ধিমানরা চিন্তা-ভাবনা করে।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mdccciii{\basmalahbn আলিফ-লা-ম-রা; এগুলো পরিপূর্ণ গ্রন্থ ও সুস্পষ্ট কোরআনের আয়াত।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mdccciv{কোন সময় কাফেররা আকাঙ্ক্ষা করবে যে, কি চমৎকার হত, যদি তারা মুসলমান হত।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mdcccv{আপনি ছেড়ে দিন তাদেরকে, খেয়ে নিক এবং ভোগ করে নিক এবং আশায় ব্যাপৃত থাকুক। অতি সত্বর তারা জেনে নেবে।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mdcccvi{আমি কোন জনপদ ধবংস করিনি; কিন্ত তার নির্দিষ্ট সময় লিখিত ছিল।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mdcccvii{কোন সম্প্রদায় তার নির্দিষ্ট সময়ের অগ্রে যায় না এবং পশ্চাতে থাকে না।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mdcccviii{তারা বললঃ হে ঐ ব্যক্তি, যার প্রতি কোরআন নাযিল হয়েছে, আপনি তো একজন উম্মাদ।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mdcccix{যদি আপনি সত্যবাদী হন, তবে আমাদের কাছে ফেরেশতাদেরকে আনেন না কেন?\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mdcccx{আমি ফেরেশতাদেরকে একমাত্র ফায়সালার জন্যেই নাযিল করি। তখন তাদেরকে অবকাশ দেয়া হবে না।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mdcccxi{আমি স্বয়ং এ উপদেশ গ্রন্থ অবতারণ করেছি এবং আমি নিজেই এর সংরক্ষক।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mdcccxii{আমি আপনার পূর্বে পূর্ববর্তী সম্প্রদায়ের মধ্যে রসূল প্রেরণ করেছি।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mdcccxiii{ওদের কাছে এমন কোন রসূল আসেননি, যাদের সাথে ওরা ঠাট্টাবিদ্রূপ করতে থাকেনি।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mdcccxiv{এমনিভাবে আমি এ ধরনের আচরণ পাপীদের অন্তরে বদ্ধমূল করে দেই।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mdcccxv{ওরা এর প্রতি বিশ্বাস করবে না। পূর্ববর্তীদের এমন রীতি চলে আসছে।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mdcccxvi{যদি আমি ওদের সামনে আকাশের কোন দরজাও খুলে দেই আর তাতে ওরা দিনভর আরোহণ ও করতে থাকে।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mdcccxvii{তবুও ওরা একথাই বলবে যে, আমাদের দৃষ্টির বিভ্রাট ঘটানো হয়েছে না বরং আমরা যাদুগ্রস্ত হয়ে পড়েছি।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mdcccxviii{নিশ্চয় আমি আকাশে রাশিচক্র সৃষ্টি করেছি এবং তাকে দর্শকদের জন্যে সুশোভিত করে দিয়েছি।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mdcccxix{আমি আকাশকে প্রত্যেক বিতাড়িত শয়তান থেকে নিরাপদ করে দিয়েছি।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mdcccxx{কিন্তু যে চুরি করে শুনে পালায়, তার পশ্চাদ্ধাবন করে উজ্জ্বল উল্কাপিন্ড।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mdcccxxi{আমি ভু-পৃষ্ঠকে বিস্তৃত করেছি এবং তার উপর পর্বতমালা স্থাপন করেছি এবং তাতে প্রত্যেক বস্তু সুপরিমিতভাবে উৎপন্ন করেছি।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mdcccxxii{আমি তোমাদের জন্যে তাতে জীবিকার উপকরন সৃষ্টি করছি এবং তাদের জন্যেও যাদের অন্নদাতা তোমরা নও।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mdcccxxiii{আমার কাছে প্রত্যেক বস্তুর ভান্ডার রয়েছে। আমি নির্দিষ্ট পরিমানেই তা অবতরণ করি।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mdcccxxiv{আমি বৃষ্টিগর্ভ বায়ু পরিচালনা করি অতঃপর আকাশ থেকে পানি বর্ষণ করি, এরপর তোমাদেরকে তা পান করাই। বস্তুতঃ তোমাদের কাছে এর ভান্ডার নেই।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mdcccxxv{আমিই জীবনদান করি, মৃত্যুদান করি এবং আমিই চুড়ান্ত মালিকানার অধিকারী।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mdcccxxvi{আমি জেনে রেখেছি তোমাদের অগ্রগামীদেরকে এবং আমি জেনে রেখেছি পশ্চাদগামীদেরকে।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mdcccxxvii{আপনার পালনকর্তাই তাদেরকে একত্রিত করে আনবেন। নিশ্চয় তিনি প্রজ্ঞাবান, জ্ঞানময়।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mdcccxxviii{আমি মানবকে পচা কর্দম থেকে তৈরী বিশুস্ক ঠনঠনে মাটি দ্বারা সৃষ্টি করেছি।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mdcccxxix{এবং জিনকে এর আগে লু এর আগুনের দ্বারা সৃজিত করেছি।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mdcccxxx{আর আপনার পালনকর্তা যখন ফেরেশতাদেরকে বললেনঃ আমি পচা কর্দম থেকে তৈরী বিশুষ্ক ঠনঠনে মাটি দ্বারা সৃষ্ট একটি মানব জাতির পত্তন করব।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mdcccxxxi{অতঃপর যখন তাকে ঠিকঠাক করে নেব এবং তাতে আমার রূহ থেকে ফঁুক দেব, তখন তোমরা তার সামনে সেজদায় পড়ে যেয়ো।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mdcccxxxii{তখন ফেরেশতারা সবাই মিলে সেজদা করল।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mdcccxxxiii{কিন্তু ইবলীস-সে সেজদাকারীদের অন্তর্ভূক্ত হতে স্বীকৃত হল না।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mdcccxxxiv{আল্লাহ বললেনঃ হে ইবলিস, তোমার কি হলো যে তুমি সেজদাকারীদের অন্তর্ভূক্ত হতে স্বীকৃত হলে না?\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mdcccxxxv{বললঃ আমি এমন নই যে, একজন মানবকে সেজদা করব, যাকে আপনি পচা কর্দম থেকে তৈরী ঠনঠনে বিশুষ্ক মাটি দ্বারা সৃষ্টি করেছেন।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mdcccxxxvi{আল্লাহ বললেনঃ তবে তুমি এখান থেকে বের হয়ে যাও। তুমি বিতাড়িত।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mdcccxxxvii{এবং তোমার প্রতি ন্যায় বিচারের দিন পর্যন্ত অভিসম্পাত।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mdcccxxxviii{সে বললঃ হে আমার পালনকর্তা, আপনি আমাকে পুনরুত্থান দিবস পর্যন্ত অবকাশ দিন।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mdcccxxxix{আল্লাহ বললেনঃ তোমাকে অবকাশ দেয়া হল।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mdcccxl{সেই অবধারিত সময় উপস্থিত হওয়ার দিন পর্যন্ত।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mdcccxli{সে বললঃ হে আমার পলনকর্তা, আপনি যেমন আমাকে পথ ভ্রষ্ট করেছেন, আমিও তাদের সবাইকে পৃথিবীতে নানা সৌন্দর্যে আকৃষ্ট করব এবং তাদের সবাইকে পথ ভ্রষ্ঠ করে দেব।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mdcccxlii{আপনার মনোনীত বান্দাদের ব্যতীত।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mdcccxliii{আল্লাহ বললেনঃ এটা আমা পর্যন্ত সোজা পথ।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mdcccxliv{যারা আমার বান্দা, তাদের উপর তোমার কোন ক্ষমতা নেই; কিন্তু পথভ্রান্তদের মধ্য থেকে যারা তোমার পথে চলে।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mdcccxlv{তাদের সবার নির্ধারিত স্থান হচ্ছে জাহান্নাম।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mdcccxlvi{এর সাতটি দরজা আছে। প্রত্যেক দরজার জন্যে এক একটি পৃথক দল আছে।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mdcccxlvii{নিশ্চয় খোদাভীরুরা বাগান ও নির্ঝরিনীসহূহে থাকবে।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mdcccxlviii{বলা হবেঃ এগুলোতে নিরাপত্তা ও শান্তি সহকরে প্রবেশ কর।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mdcccxlix{তাদের অন্তরে যে ক্রোধ ছিল, আমি তা দূর করে দেব। তারা ভাই ভাইয়ের মত সামনা-সামনি আসনে বসবে।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mdcccl{সেখানে তাদের মোটেই কষ্ট হবে না এবং তারা সেখান থেকে বহিস্কৃত হবে না।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mdcccli{আপনি আমার বান্দাদেরকে জানিয়ে দিন যে, আমি অত্যন্ত ক্ষমাশীল দয়ালু।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mdccclii{এবং ইহাও যে, আমার শাস্তিই যন্ত্রনাদায়ক শাস্তি।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mdcccliii{আপনি তাদেরকে ইব্রাহীমের মেহমানদের অবস্থা শুনিয়ে দিন।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mdcccliv{যখন তারা তাঁর গৃহে আগমন করল এবং বললঃ সালাম। তিনি বললেনঃ আমরা তোমাদের ব্যাপারে ভীত।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mdccclv{তারা বললঃ ভয় করবেন না। আমরা আপনাকে একজন জ্ঞানবান ছেলে-সন্তানের সুসংবাদ দিচ্ছি।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mdccclvi{তিনি বললেনঃ তোমরা কি আমাকে এমতাবস্থায় সুসংবাদ দিচ্ছ, যখন আমি বার্ধক্যে পৌছে গেছি ?\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mdccclvii{তারা বললঃ আমরা আপনাকে সত্য সু-সংবাদ দিচ্ছি! অতএব আপনি নিরাশ হবেন না।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mdccclviii{তিনি বললেনঃ পালনকর্তার রহমত থেকে পথভ্রষ্টরা ছাড়া কে নিরাশ হয় ?\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mdccclix{তিনি বললেনঃ অতঃপর তোমাদের প্রধান উদ্দেশ্য কি হে আল্লাহর প্রেরিতগণ ?\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mdccclx{তারা বললঃ আমরা একটি অপরাধী সম্প্রদায়ের প্রতি প্রেরিত হয়েছি।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mdccclxi{কিন্তু লূতের পরিবার-পরিজন। আমরা অবশ্যই তাদের সবাইকে বাঁচিয়ে নেব।\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mdccclxii{তবে তার স্ত্রী। আমরা স্থির করেছি যে, সে থেকে যাওয়াদের দলভূক্ত হবে।\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mdccclxiii{অতঃপর যখন প্রেরিতরা লূতের গৃহে পৌছল।\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mdccclxiv{তিনি বললেনঃ তোমরা তো অপরিচিত লোক।\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mdccclxv{তারা বললঃ না বরং আমরা আপনার কাছে ঐ বস্তু নিয়ে এসেছি, যে সম্পর্কে তারা বিবাদ করত।\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mdccclxvi{এবং আমরা আপনার কাছে সত্য বিষয় নিয়ে এসেছি এবং আমরা সত্যবাদী।\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mdccclxvii{অতএব আপনি শেষরাত্রে পরিবারের সকলকে নিয়ে চলে যান এবং আপনি তাদের পশ্চাদনুসরণ করবেন না এবং আপনাদের মধ্যে কেউ যেন পিছন ফিরে না দেখে। আপনারা যেখানে আদেশ প্রাপ্ত হচ্ছেন সেখানে যান।\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mdccclxviii{আমি লূতকে এ বিষয় পরিজ্ঞাত করে দেই যে, সকাল হলেই তাদেরকে সমুলে বিনাশ করে দেয়া হবে।\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mdccclxix{শহরবাসীরা আনন্দ-উল্লাস করতে করতে পৌছল।\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mdccclxx{লূত বললেনঃ তারা আমার মেহমান। অতএব আমাকে লাঞ্ছিত করো না।\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mdccclxxi{তোমরা আল্লাহকে ভয় কর এবং আমার ইযযত নষ্ট করো না।\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mdccclxxii{তার বললঃ আমরা কি আপনাকে জগৎদ্বাসীর সমর্থন করতে নিষেধ করিনি।\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@mdccclxxiii{তিনি বললেনঃ যদি তোমরা একান্ত কিছু করতেই চাও, তবে আমার কন্যারা উপস্থিত আছে।\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@mdccclxxiv{আপনার প্রাণের কসম, তারা আপন নেশায় প্রমত্ত ছিল।\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@mdccclxxv{অতঃপর সুর্যোদয়ের সময় তাদেরকে প্রচন্ড একটি শব্দ এসে পাকড়াও করল।\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@mdccclxxvi{অতঃপর আমি জনপদটিকে উল্টে দিলাম এবং তাদের উপর কঙ্করের প্রস্থর বর্ষণ করলাম।\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@mdccclxxvii{নিশ্চয় এতে চিন্তাশীলদের জন্যে নিদর্শনাবলী রয়েছে।\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@mdccclxxviii{জনপদটি সোজা পথে অবস্থিত রয়েছে।\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@mdccclxxix{নিশ্চয় এতে ঈমানদারদের জন্যে নিদর্শণ আছে।\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@mdccclxxx{নিশ্চয় গহীন বনের অধিবাসীরা পাপী ছিল।\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@mdccclxxxi{অতঃপর আমি তাদের কাছ থেকে প্রতিশোধ নিয়েছি। উভয় বস্তি প্রকাশ্য রাস্তার উপর অবস্থিত।\qt@no{(79)}}
\qt@newcmd\qurantrans@bn@mdccclxxxii{নিশ্চয় হিজরের বাসিন্দারা পয়গম্বরগণের প্রতি মিথ্যারোপ করেছে।\qt@no{(80)}}
\qt@newcmd\qurantrans@bn@mdccclxxxiii{আমি তাদেরকে নিজের নিদর্শনাবলী দিয়েছি। অতঃপর তারা এগুলো থেকে মুখ ফিরিয়ে নেয়।\qt@no{(81)}}
\qt@newcmd\qurantrans@bn@mdccclxxxiv{তারা পাহাড়ে নিশ্চিন্তে ঘর খোদাই করত।\qt@no{(82)}}
\qt@newcmd\qurantrans@bn@mdccclxxxv{অতঃপর এক প্রত্যুষে তাদের উপর একটা শব্দ এসে আঘাত করল।\qt@no{(83)}}
\qt@newcmd\qurantrans@bn@mdccclxxxvi{তখন কোন উপকারে আসল না যা তারা উপার্জন করেছিল।\qt@no{(84)}}
\qt@newcmd\qurantrans@bn@mdccclxxxvii{আমি নভোমন্ডল, ভুমন্ডল এবং এতদুভয়ের মধ্যবর্তী যা আছে তা তাৎপর্যহীন সৃষ্টি করিনি। কেয়ামত অবশ্যই আসবে। অতএব পরম ঔদাসীন্যের সাথে ওদের ক্রিয়াকর্ম উপক্ষো করুন।\qt@no{(85)}}
\qt@newcmd\qurantrans@bn@mdccclxxxviii{নিশ্চয় আপনার পালনকর্তাই স্রষ্টা, সর্বজ্ঞ।\qt@no{(86)}}
\qt@newcmd\qurantrans@bn@mdccclxxxix{আমি আপনাকে সাতটি বার বার পঠিতব্য আয়াত এবং মহান কোরআন দিয়েছি।\qt@no{(87)}}
\qt@newcmd\qurantrans@bn@mdcccxc{আপনি চক্ষু তুলে ঐ বস্তুর প্রতি দেখবেন না, যা আমি তাদের মধ্যে কয়েক প্রকার লোককে ভোগ করার জন্যে দিয়েছি, তাদের জন্যে চিন্তিত হবেন না আর ঈমানদারদের জন্যে স্বীয় বাহু নত করুন।\qt@no{(88)}}
\qt@newcmd\qurantrans@bn@mdcccxci{আর বলুনঃ আমি প্রকাশ্য ভয় প্রদর্শক।\qt@no{(89)}}
\qt@newcmd\qurantrans@bn@mdcccxcii{যেমন আমি নাযিল করেছি যারা বিভিন্ন মতে বিভক্ত তাদের উপর।\qt@no{(90)}}
\qt@newcmd\qurantrans@bn@mdcccxciii{যারা কোরআনকে খন্ড খন্ড করেছে।\qt@no{(91)}}
\qt@newcmd\qurantrans@bn@mdcccxciv{অতএব আপনার পালনকর্তার কসম, আমি অবশ্যই ওদের সবাইকে জিজ্ঞাসাবাদ করব।\qt@no{(92)}}
\qt@newcmd\qurantrans@bn@mdcccxcv{ওদের কাজকর্ম সম্পর্কে।\qt@no{(93)}}
\qt@newcmd\qurantrans@bn@mdcccxcvi{অতএব আপনি প্রকাশ্যে শুনিয়ে দিন যা আপনাকে আদেশ করা হয় এবং মুশরিকদের পরওয়া করবেন না।\qt@no{(94)}}
\qt@newcmd\qurantrans@bn@mdcccxcvii{বিদ্রুপকারীদের জন্যে আমি আপনার পক্ষ থেকে যথেষ্ট।\qt@no{(95)}}
\qt@newcmd\qurantrans@bn@mdcccxcviii{যারা আল্লাহর সাথে অন্য উপাস্য সাব্যস্ত করে। অতএব অতিসত্তর তারা জেনে নেবে।\qt@no{(96)}}
\qt@newcmd\qurantrans@bn@mdcccxcix{আমি জানি যে আপনি তাদের কথাবর্তায় হতোদ্যম হয়ে পড়েন।\qt@no{(97)}}
\qt@newcmd\qurantrans@bn@mcm{অতএব আপনি পালনকর্তার সৌন্দর্য স্মরণ করুন এবং সেজদাকারীদের অন্তর্ভূক্ত হয়ে যান।\qt@no{(98)}}
\qt@newcmd\qurantrans@bn@mcmi{এবং পালনকর্তার এবাদত করুন, যে পর্যন্ত আপনার কাছে নিশ্চিত কথা না আসে।\qt@no{(99)}}
\qt@newcmd\qurantrans@bn@mcmii{\basmalahbn আল্লাহর নির্দেশ এসে গেছে। অতএব এর জন্যে তাড়াহুড়া করো না। ওরা যেসব শরীক সাব্যস্ত করছে সেসব থেকে তিনি পবিত্র ও বহু উর্ধ্বে।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mcmiii{তিনি স্বীয় নির্দেশে বান্দাদের মধ্যে যার কাছে ইচ্ছা, নির্দেশসহ ফেরেশতাদেরকে এই মর্মে নাযিল করেন যে, হুশিয়ার করে দাও, আমি ছাড়া কোন উপাস্য নেই। অতএব আমাকে ভয় কর।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mcmiv{যিনি যথাবিধি আকাশরাজি ও ভূ-মন্ডল সৃষ্টি করেছেন। তারা যাকে শরীক করে তিনি তার বহু উর্ধ্বে।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mcmv{তিনি মানবকে এক ফোটা বীর্য থেকে সৃষ্টি করেছেন। এতদসত্বেও সে প্রকাশ্য বিতন্ডাকারী হয়ে গেছে।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mcmvi{চতুষ্পদ জন্তুকে তিনি সৃষ্টি করেছেন। এতে তোমাদের জন্যে শীত বস্ত্রের উপকরণ আছে। আর অনেক উপকার হয়েছে এবং কিছু সংখ্যককে তোমরা আহার্যে?2474;রিণত করে থাক।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mcmvii{এদের দ্বারা তোমাদের সম্মান হয়, যখন বিকালে চারণভূমি থেকে নিয়ে আস এবং সকালে চারণ ভূমিতে নিয়ে যাও।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mcmviii{এরা তোমাদের বোঝা এমন শহর পর্যন্ত বহন করে নিয়ে যায়, যেখানে তোমরা প্রাণান্তকর পরিশ্রম ব্যতীত পৌছাতে পারতে না। নিশ্চয় তোমাদের প্রভু অত্যন্ত দয়াদ্র, পরম দয়ালু।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mcmix{তোমাদের আরোহণের জন্যে এবং শোভার জন্যে তিনি ঘোড়া, খচ্চর ও গাধা সৃষ্টি করেছেন। আর তিনি এমন জিনিস সৃষ্টি করেন যা তোমরা জান না।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mcmx{সরল পথ আল্লাহ পর্যন্ত পৌছে এবং পথগুলোর মধ্যে কিছু বক্র পথও রয়েছে। তিনি ইচ্ছা করলে তোমাদের সবাইকে সৎপথে পরিচালিত করতে পারতেন।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mcmxi{তিনি তোমাদের জন্যে আকাশ থেকে পানি বর্ষণ করেছেন। এই পানি থেকে তোমরা পান কর এবং এ থেকেই উদ্ভিদ উৎপন্ন হয়, যাতে তোমরা পশুচারণ কর।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mcmxii{এ পানি দ্বারা তোমাদের জন্যে উৎপাদন করেন ফসল, যয়তুন, খেজুর, আঙ্গুর ও সর্বপ্রকার ফল। নিশ্চয় এতে চিন্তাশীলদের জন্যে নিদর্শন রয়েছে।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mcmxiii{তিনিই তোমাদের কাজে নিয়োজিত করেছেন রাত্রি, দিন, সূর্য এবং চন্দ্রকে। তারকাসমূহ তাঁরই বিধানের কর্মে নিয়োজিত রয়েছে। নিশ্চয়ই এতে বোধশক্তিসম্পন্নদের জন্যে নিদর্শনাবলী রয়েছে।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mcmxiv{তোমাদের জন্যে পৃথিবীতে যেসব রং-বেরঙের বস্তু ছড়িয়ে দিয়েছেন, সেগুলোতে নিদর্শন রয়েছে তাদের জন্যে যারা চিন্তা-ভাবনা করে।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mcmxv{তিনিই কাজে লাগিয়ে দিয়েছেন সমুদ্রকে, যাতে তা থেকে তোমরা তাজা মাংস খেতে পার এবং তা থেকে বের করতে পার পরিধেয় অলঙ্কার। তুমি তাতে জলযান সমূহকে পানি চিরে চলতে দেখবে এবং যাতে তোমরা আল্লাহর কৃপা অন্বেষণ কর এবং যাতে তার অনুগ্রহ স্বীকার কর।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mcmxvi{এবং তিনি পৃথিবীর উপর বোঝা রেখেছেন যে, কখনো যেন তা তোমাদেরকে নিয়ে হেলে-দুলে না পড়ে এবং নদী ও পথ তৈরী করেছেন, যাতে তোমরা পথ প্রদর্শিত হও।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mcmxvii{এবং তিনি পথ নির্ণয়ক বহু চিহ্ন সৃষ্টি করেছেন, এবং তারকা দ্বারা ও মানুষ পথের নির্দেশ পায়।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mcmxviii{যিনি সৃষ্টি করে, তিনি কি সে লোকের সমতুল্য যে সৃষ্টি করতে পারে না? তোমরা কি চিন্তা করবে না?\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mcmxix{যদি আল্লাহর নেয়ামত গণনা কর, শেষ করতে পারবে না। নিশ্চয় আল্লাহ ক্ষমাশীল, দয়ালু।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mcmxx{আল্লাহ জানেন যা তোমরা গোপন কর এবং যা তোমরা প্রকাশ কর।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mcmxxi{এবং যারা আল্লাহকে ছেড়ে অন্যদের ডাকে, ওরা তো কোন বস্তুই সৃষ্টি করে না; বরং ওরা নিজেরাই সৃজিত।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mcmxxii{তারা মৃত-প্রাণহীন এবং কবে পুনরুত্থিত হবে, জানে না।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mcmxxiii{আমাদের ইলাহ একক ইলাহ। অনন্তর যারা পরজীবনে বিশ্বাস করে না, তাদের অন্তর সত্যবিমুখ এবং তারা অহংকার প্রদর্শন করেছে।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mcmxxiv{নিঃসন্দেহে আল্লাহ তাদের গোপন ও প্রকাশ্য যাবতীয় বিষয়ে অবগত। নিশ্চিতই তিনি অহংকারীদের পছন্দ করেন না।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mcmxxv{যখন তাদেরকে বলা হয়ঃ তোমাদের পালনকর্তা কি নাযিল করেছেন? তারা বলেঃ পূর্ববর্তীদের কিসসা-কাহিনী।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mcmxxvi{ফলে কেয়ামতের দিন ওরা পূর্ণমাত্রায় বহন করবে ওদের পাপভার এবং পাপভার তাদেরও যাদেরকে তারা তাদের অজ্ঞতাহেতু বিপথগামী করে শুনে নাও, খুবই নিকৃষ্ট বোঝা যা তারা বহন করে।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mcmxxvii{নিশ্চয় চক্রান্ত করেছে তাদের পূর্ববর্তীরা, অতঃপর আল্লাহ তাদের চক্রান্তের ইমারতের ভিত্তিমূলে আঘাত করেছিলেন। এরপর উপর থেকে তাদের মাথায় ছাদ ধ্বসে পড়ে গেছে এবং তাদের উপর আযাব এসেছে যেখান থেকে তাদের ধারণা ছিল না।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mcmxxviii{অতঃপর কেয়ামতের দিন তিনি তাদেরকে লাঞ্ছিত করবেন এবং বলবেনঃ আমার অংশীদাররা কোথায়, যাদের ব্যাপারে তোমরা খুব হঠকারিতা করতে ? যারা জ্ঞানপ্রাপ্ত হয়েছিল তারা বলবেঃ নিশ্চয়ই আজকের দিনে লাঞ্ছনা ও দুর্গতি কাফেরদের জন্যে,\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mcmxxix{ফেরেশতারা তাদের জান এমতাঅবস্থায় কবজ করে যে, তারা নিজেদের উপর যুলুম করেছে। তখন তারা অনুগত্য প্রকাশ করবে যে, আমরা তো কোন মন্দ কাজ করতাম না। হঁ্যা নিশ্চয় আল্লাহ সববিষয় অবগত আছেন, যা তোমরা করতে।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mcmxxx{অতএব, জাহান্নামের দরজসমূহে প্রবেশ কর, এতেই অনন্তকাল বাস কর। আর অহংকারীদের আবাসস্থল কতই নিকৃষ্ট।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mcmxxxi{পরহেযগারদেরকে বলা হয়ঃ তোমাদের পালনকর্তা কি নাযিল করেছেন? তারা বলেঃ মহাকল্যাণ। যারা এ জগতে সৎকাজ করে, তাদের জন্যে কল্যাণ রয়েছে এবং পরকালের গৃহ আরও উত্তম। পরহেযগারদের গৃহ কি চমৎকার?\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mcmxxxii{সর্বদা বসবাসের উদ্যান, তারা যাতে প্রবেশ করবে। এর পাদদেশে দিয়ে স্রোতস্বিনী প্রবাহিত হয় তাদের জন্যে তাতে তা-ই রয়েছে, যা তারা চায় এমনিভাবে প্রতিদান দেবেন আল্লাহর পরহেযগারদেরকে,\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mcmxxxiii{ফেরেশতা যাদের জান কবজ করেন তাদের পবিত্র থাকা অবস্থায়। ফেরেশতারা বলেঃ তোমাদের প্রতি শাস্তি বর্ষিত হোক। তোমরা যা করতে, তার প্রতিদানে জান্নাতে প্রবেশ কর।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mcmxxxiv{কাফেররা কি এখন অপেক্ষা করছে যে, তাদের কাছে ফেরেশতারা আসবে কিংবা আপনার পালনকর্তার নির্দেশ পৌছবে? তাদের পূর্ববর্তীরা এমনই করেছিল। আল্লাহ তাদের প্রতি অবিচার করেননি; কিন্তু তারা স্বয়ং নিজেদের প্রতি জুলুম করেছিল।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mcmxxxv{সুতরাং তাদের মন্দ কাজের শাস্তি তাদেরই মাথায় আপতিত হয়েছে এবং তারা যে ঠাট্টা বিদ্রুপ করত, তাই উল্টে তাদের উপর পড়েছে।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mcmxxxvi{মুশরিকরা বললঃ যদি আল্লাহ চাইতেন, তবে আমরা তাঁকে ছাড়া কারও এবাদত করতাম না এবং আমাদের পিতৃপুরুষেরাও করত না এবং তাঁর নির্দেশ ছাড়া কোন বস্তুই আমরা হারাম করতাম না। তাদের পূর্ববর্তীরা এমনই করেছে। রাসূলের দায়িত্ব তো শুধুমাত্র সুস্পষ্ট বাণী পৌছিয়ে দেয়া।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mcmxxxvii{আমি প্রত্যেক উম্মতের মধ্যেই রাসূল প্রেরণ করেছি এই মর্মে যে, তোমরা আল্লাহর এবাদত কর এবং তাগুত থেকে নিরাপদ থাক। অতঃপর তাদের মধ্যে কিছু সংখ্যককে আল্লাহ হেদায়েত করেছেন এবং কিছু সংখ্যকের জন্যে বিপথগামিতা অবধারিত হয়ে গেল। সুতরাং তোমরা পৃথিবীতে ভ্রমণ কর এবং দেখ মিথ্যারোপকারীদের কিরূপ পরিণতি হয়েছে।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mcmxxxviii{আপনি তাদেরকে সুপথে আনতে আগ্রহী হলেও আল্লাহ যাকে বিপথগামী করেন তিনি তাকে পথ দেখান না এবং তাদের কোন সাহায্যকারী ও নেই।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mcmxxxix{তারা আল্লাহর নামে কঠোর শপথ করে যে, যার মৃত্যু হয় আল্লাহ তাকে পুনরুজ্জীবিত করবেন না। অবশ্যই এর পাকাপোক্ত ওয়াদা হয়ে গেছে। কিন্তু, অধিকাংশ লোক জানে না।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mcmxl{তিনি পুনরুজ্জীবিত করবেনই, যাতে যে বিষয়ে তাদের মধ্যে মতানৈক্য ছিল তা প্রকাশ করা যায় এবং যাতে কাফেরেরা জেনে নেয় যে, তারা মিথ্যাবাদী ছিল।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mcmxli{আমি যখন কোন কিছু করার ইচ্ছা করি; তখন তাকে কেবল এতটুকুই বলি যে, হয়ে যাও,। সুতরাং তা হয়ে যায়।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mcmxlii{যারা নির্যাতিত হওয়ার পর আল্লাহর জন্যে গৃহত্যাগ করেছে, আমি অবশ্যই তাদেরকে দুনিয়াতে উত্তম আবাস দেব এবং পরকালের পুরস্কার তো সর্বাধিক; হায়! যদি তারা জানত।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mcmxliii{যারা দৃঢ়পদ রয়েছে এবং তাদের পালনকর্তার উপর ভরসা করেছে।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mcmxliv{আপনার পূর্বেও আমি প্রত্যাদেশসহ মানবকেই তাদের প্রতি প্রেরণ করেছিলাম অতএব জ্ঞানীদেরকে জিজ্ঞেস কর, যদি তোমাদের জানা না থাকে;\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mcmxlv{প্রেরণ করেছিলাম তাদেরকে নিꦣ2503;দশাবলী ও অবতীর্ণ গ্রন্থসহ এবং আপনার কাছে আমি স্মরণিকা অবতীর্ণ করেছি, যাতে আপনি লোকদের সামনে ঐসব বিষয় বিবৃত করেন, যে গুলো তোদের প্রতি নাযিল করা হয়েছে, যাতে তারা চিন্তা-ভাবনা করে।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mcmxlvi{যারা কুচক্র করে, তারা কি এ বিষয়ে ভয় করে না যে, আল্লাহ তাদেরকে ভূগর্ভে বিলীন করে দিবেন কিংবা তাদের কাছে এমন জায়গা থেকে আযাব আসবে যা তাদের ধারণাতীত।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mcmxlvii{কিংবা চলাফেরার মধ্যেই তাদেরকে পাকড়াও করবে, তারা তো তা ব্যর্থ করতে পারবে না।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mcmxlviii{কিংবা ভীতি প্রদর্শনের পর তাদেরকে পাকড়াও করবেন? তোমাদের পালনকর্তা তো অত্যন্ত নম্র, দয়ালু।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mcmxlix{তারা কি আল্লাহর সৃজিত বস্তু দেখে না, যার ছায়া আল্লাহর প্রতি বিনীতভাবে সেজদাবনত থেকে ডান ও বাম দিকে ঝুঁকে পড়ে।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mcml{আল্লাহকে সেজদা করে যা কিছু নভোমন্ডলে আছে এবং যা কিছু ভুমন্ডলে আছে এবং ফেরেশতাগণ; তারা অহংকার করে না।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mcmli{তারা তাদের উপর পরাক্রমশালী তাদের পালনকর্তাকে ভয় করে এবং তারা যা আদেশ পায়, তা করে\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mcmlii{আল্লাহ বললেনঃ তোমরা দুই উপাস্য গ্রহণ করো না উপাস্য তো মাত্র একজনই। অতএব আমাকেই ভয় কর।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mcmliii{যা কিছু নভোমন্ডল ও ভুমন্ডলে আছে তা তাঁরই এবাদত করা শাশ্বত কর্তব্য। তোমরা কি আল্লাহ ব্যতীত কাউকে ভয় করবে?\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mcmliv{তোমাদের কাছে যে সমস্ত নেয়ামত আছে, তা আল্লাহরই পক্ষ থেকে। অতঃপর তোমরা যখন দুঃখে-কষ্টে পতিত হও তখন তাঁরই নিকট কান্নাকাটি কর।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mcmlv{এরপর যখন আল্লাহ তোমাদের কষ্ট দুরীভূত করে দেন, তখনই তোমাদের একদল স্বীয় পালনকর্তার সাথে অংশীদার সাব্যস্ত করতে থাকে।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mcmlvi{যাতে ঐ নেয়ামত অস্বীকার করে, যা আমি তাদেরকে দিয়েছি। অতএব মজা ভোগ করে নাও-সত্বরই তোমরা জানতে পারবে।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mcmlvii{তারা আমার দেয়া জীবনোপকরণ থেকে তাদের জন্যে একটি অংশ নির্ধারিত করে, যাদের কোন খবরই তারা রাখে না। আল্লাহর কসম, তোমরা যে অপবাদ আরোপ করছ, সে সম্পর্কে অবশ্যই জিজ্ঞাসিত হবে।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mcmlviii{তারা আল্লাহর জন্যে কন্যা সন্তান নির্ধারণ করে-তিনি পবিত্র মহিমান্বিত এবং নিজেদের জন্যে ওরা তাই স্থির করে যা ওরা চায়।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mcmlix{যখন তাদের কাউকে কন্যা সন্তানের সুসংবাদ দেয়া হয়, তখন তারা মুখ কাল হয়ে যায় এবং অসহ্য মনস্তাপে ক্লিষ্ট হতে থাকে।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mcmlx{তাকে শোনানো সুসংবাদের দুঃখে সে লোকদের কাছ থেকে মুখ লুকিয়ে থাকে। সে ভাবে, অপমান সহ্য করে তাকে থাকতে দেবে, না তাকে মাটির নীচে পুতে ফেলবে। শুনে রাখ, তাদের ফয়সালা খুবই নিকৃষ্ট।\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mcmlxi{যারা পরকাল বিশ্বাস করে না, তাদের উদাহরণ নিকৃষ্ট এবং আল্লাহর উদাহরণই মহান, তিনি পরাক্রমশালী, প্রজ্ঞাময়।\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mcmlxii{যদি আল্লাহ লোকদেরকে তাদের অন্যায় কাজের কারণে পাকড়াও করতেন, তবে ভুপৃষ্ঠে চলমান কোন কিছুকেই ছাড়তেন না। কিন্তু তিনি প্রতিশ্রুতি সময় পর্যন্ত তাদেরকে অবকাশ দেন। অতঃপর নির্ধারিত সময়ে যখন তাদের মৃত্যু এসে যাবে, তখন এক মুহুর্তও বিলম্বিত কিংবা তরাম্বিত করতে পারবে না।\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mcmlxiii{যা নিজেদের মন চায় না তারই তারা আল্লাহর জন্যে সাব্যস্ত করে এবং তাদের জিহবা মিথ্যা বর্ণনা করে যে, তাদের জন্যে রয়েছে কল্যাণ। স্বতঃসিদ্ধ কথা যে, তাদের জন্যে রয়েছে আগুন এবং তাদেরকেই সর্বাগ্রে নিক্ষেপ করা হবে।\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mcmlxiv{আল্লাহর কসম, আমি আপনার পূর্বে বিভিন্ন সম্প্রদায়ে রাসূল প্রেরণ করেছি, অতঃপর শয়তান তাদেরকে কর্ম সমূহ শোভনীয় করে দেখিয়েছে। আজ সেই তাদের অভিভাবক এবং তাদের জন্যে রয়েছে যন্ত্রণাদায়ক শাস্তি।\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mcmlxv{আমি আপনার প্রতি এ জন্যেই গ্রন্থ নাযিল করেছি, যাতে আপনি সরল পথ প্রদর্শনের জন্যে তাদের কে পরিষ্কার বর্ণনা করে দেন, যে বিষয়ে তারা মতবিরোধ করছে এবং ঈমানদারকে ক্ষমা করার জন্যে।\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mcmlxvi{আল্লাহ আকাশ থেকে পানি বর্ষণ করেছেন, তদ্বারা যমীনকে তার মৃত্যুর পর পুনর্জীবিত করেছেন। নিশ্চয় এতে তাদের জন্যে নিদর্শন রয়েছে, যারা শ্রবণ করে।\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mcmlxvii{তোমাদের জন্যে চতুস্পদ জন্তুদের মধ্যে চিন্তা করার অবকাশ রয়েছে। আমি তোমাদেরকে পান করাই তাদের উদরস্থিত বস্তুসমুহের মধ্যে থেকে গোবর ও রক্ত নিঃসৃত দুগ্ধ যা পানকারীদের জন্যে উপাদেয়।\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mcmlxviii{এবং খেজুর বৃক্ষ ও আঙ্গুর ফল থেকে তোমরা মধ্য ও উত্তম খাদ্য তৈরী করে থাক, এতে অবশ্যই বোধশক্তি সম্পন্ন সম্প্রদায়ের জন্যে নিদর্শন রয়েছে।\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mcmlxix{আপনার পালনকর্তা মধু মক্ষিকাকে আদেশ দিলেনঃ পর্বতগাহ্রে, বৃক্ষ এবং উঁচু চালে গৃহ তৈরী কর,\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mcmlxx{এরপর সর্বপ্রকার ফল থেকে ভক্ষণ কর এবং আপন পালনকর্তার উম্মুক্ত পথ সমূহে চলমান হও। তার পেট থেকে বিভিন্ন রঙে পানীয় নির্গত হয়। তাতে মানুষের জন্যে রয়েছে রোগের প্রতিকার। নিশ্চয় এতে চিন্তাশীল সম্প্রদায়ের জন্যে নিদর্শন রয়েছে।\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mcmlxxi{আল্লাহ তোমাদেরকে সৃষ্টি করেছেন এরপর তোমাদের মৃত্যুদান করেন। তোমাদের মধ্যে কেউ কেউ পৌছে যায় জরাগ্রস্ত অকর্মন্য বয়সে, ফলে যা কিছু তারা জানত সে সম্পর্কে তারা সজ্ঞান থাকবে না। নিশ্চয় আল্লাহ সু-বিজ্ঞ সর্বশক্তিমান।\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@mcmlxxii{আল্লাহ তা’আলা জীবনোপকরণে তোমাদের একজনকে অন্যজনের চাইতে শ্রেষ্টত্ব দিয়েছেন। অতএব যাদেরকে শ্রেষ্ঠত্ব দেয়া হয়েছে, তারা তাদের অধীনস্থ দাস-দাসীদেরকে স্বীয় জীবিকা থেকে এমন কিছু দেয় না, যাতে তারা এ বিষয়ে তাদের সমান হয়ে যাবে। তবে কি তারা আল্লাহর নেয়ামত অস্বীকার করে।\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@mcmlxxiii{আল্লাহ তোমাদের জন্যে তোমাদেরই শ্রেণী থেকে জোড়া পয়দা করেছেন এবং তোমাদের যুগল থেকে তোমাদেরকে পুত্র ও পৌত্রাদি দিয়েছেন এবং তোমাদেরকে উত্তম জীবনোপকরণ দান করেছেন। অতএব তারা কি মিথ্যা বিষয়ে বিশ্বাস স্থাপন করে এবং আল্লাহর অনুগ্রহ অস্বীকার করে?\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@mcmlxxiv{তারা আল্লাহ ব্যতীত এমন বস্তুর ইবাদত করে, যে তাদের জন্যে ভুমন্ডল ও নভোমন্ডল থেকে সামান্য রুযী দেওয়ার ও অধিকার রাখে না এবং মুক্তি ও রাখে না।\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@mcmlxxv{অতএব, আল্লাহর কোন সদৃশ সাব্যস্ত করো না, নিশ্চয় আল্লাহ জানেন এবং তোমরা জান না।\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@mcmlxxvi{আল্লাহ একটি দৃষ্টান্ত বর্ণনা করেছেন, অপরের মালিকানাধীন গোলামের যে, কোন কিছুর উপর শক্তি রাখে না এবং এমন একজন যাকে আমি নিজের পক্ষ থেকে চমৎকার রুযী দিয়েছি। অতএব, সে তা থেকে ব্যয় করে গোপনে ও প্রকাশ্যে উভয়ে কি সমান হয়? সব প্রশংসা আল্লাহর, কিন্তু অনেক মানুষ জানে না।\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@mcmlxxvii{আল্লাহ আরেকটি দৃষ্টান্ত বর্ণনা করেছেন, দু’ব্যক্তির, একজন বোবা কোন কাজ করতে পারে না। সে মালিকের উপর বোঝা। যেদিকে তাকে পাঠায়, কোন সঠিক কাজ করে আসে না। সে কি সমান হবে ঐ ব্যক্তির, যে ন্যায় বিচারের আদেশ করে এবং সরল পথে কায়েম রয়েছে।\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@mcmlxxviii{নভোমন্ডল ও ভূমন্ডলের গোপন রহস্য আল্লাহর কাছেই রয়েছে। কিয়ামতের ব্যাপারটি তো এমন, যেমন চোখের পলক অথবা তার চাইতেও নিকটবর্তী। নিশ্চয় আল্লাহ সব কিছুর উপর শক্তিমান।\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@mcmlxxix{আল্লাহ তোমাদেরকে তোমাদের মায়ের গর্ভ থেকে বের করেছেন। তোমরা কিছুই জানতে না। তিনি তোমাদেরকে কর্ণ, চক্ষু ও অন্তর দিয়েছেন, যাতে তোমরা অনুগ্রহ স্বীকার কর।\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@mcmlxxx{তারা কি উড়ন্ত পাখীকে দেখে না? এগুলো আকাশের অন্তরীক্ষে আজ্ঞাধীন রয়েছে। আল্লাহ ছাড়া কেউ এগুলোকে আগলে রাখে না। নিশ্চয় এতে বিশ্বাসীদের জন্যে নিদর্শনবলী রয়েছে।\qt@no{(79)}}
\qt@newcmd\qurantrans@bn@mcmlxxxi{আল্লাহ করে দিয়েছেন তোমাদের গৃহকে অবস্থানের জায়গা এবং চতুস্পদ জন্তুর চামড়া দ্বারা করেছেন তোমার জন্যে তাঁবুর ব্যবস্থা। তোমরা এগুলোকে সফরকালে ও অবস্থান কালে পাও। ভেড়ার পশম, উটের বাবরি চুল ও ছাগলের লোম দ্বারা কত আসবাবপত্র ও ব্যবহারের সামগ্রী তৈরী করেছেন এক নির্দিষ্ট সময় পর্যন্ত।\qt@no{(80)}}
\qt@newcmd\qurantrans@bn@mcmlxxxii{আল্লাহ তোমাদের জন্যে সৃজিত বস্তু দ্বারা ছায়া করে দিয়েছেন এবং পাহাড় সমূহে তোমাদের জন্যে আত্ন গোপনের জায়গা করেছেন এবং তোমাদের জন্যে পোশাক তৈরী করে দিয়েছেন, যা তোমাদেরকে গ্রীষ্ম এবং বিপদের সময় রক্ষা করে। এমনিভাবে তিনি তোমাদের প্রতি স্বীয় অনুগ্রহের পূর্ণতা দান করেন, যাতে তোমরা আত্নসমর্পণ কর।\qt@no{(81)}}
\qt@newcmd\qurantrans@bn@mcmlxxxiii{অতঃপর যদি তারা পৃষ্ঠ প্রদর্শন করে, তবে আপনার কাজ হল সুস্পষ্ট ভাবে পৌছে দেয়া মাত্র।\qt@no{(82)}}
\qt@newcmd\qurantrans@bn@mcmlxxxiv{তারা আল্লাহর অনুগ্রহ চিনে, এরপর অস্বীকার করে এবং তাদের অধিকাংশই অকৃতজ্ঞ।\qt@no{(83)}}
\qt@newcmd\qurantrans@bn@mcmlxxxv{যেদিন আমি প্রত্যেক উম্মত থেকে একজন বর্ণনাকারী দাঁড় করাব, তখন কাফেরদেরকে অনুমতি দেয়া হবে না এবং তাদের তওবা ও গ্রহণ করা হবে না।\qt@no{(84)}}
\qt@newcmd\qurantrans@bn@mcmlxxxvi{যখন জালেমরা আযাব প্রত্যক্ষ করবে, তখন তাদের থেকে তা লঘু করা হবে না এবং তাদেরকে কোন অবকাশ দেয়া হবে না।\qt@no{(85)}}
\qt@newcmd\qurantrans@bn@mcmlxxxvii{মুশরিকরা যখন ঐ সব বস্তুকে দেখবে, যেসবকে তারা আল্লাহর সাথে শরীক সাব্যস্ত করেছিল, তখন বলবেঃ হে আমাদের পালনকর্তা এরাই তারা যারা আমাদের শেরেকীর উপাদান, তোমাকে ছেড়ে আমরা যাদেরকে ডাকতাম। তখন ওরা তাদেরকে বলবেঃ তোমরা মিথ্যাবাদী।\qt@no{(86)}}
\qt@newcmd\qurantrans@bn@mcmlxxxviii{সেদিন তারা আল্লাহর সামনে আত্নসমর্পন করবে এবং তারা যে মিথ্যা অপবাদ দিত তা বিস্মৃত হবে।\qt@no{(87)}}
\qt@newcmd\qurantrans@bn@mcmlxxxix{যারা কাফের হয়েছে এবং আল্লাহর পথে বাধা সৃষ্টি করেছে, আমি তাদেরকে আযাবের পর আযাব বাড়িয়ে দেব। কারণ, তারা অশান্তি সৃষ্টি করত।\qt@no{(88)}}
\qt@newcmd\qurantrans@bn@mcmxc{সেদিন প্রত্যেক উম্মতের মধ্যে আমি একজন বর্ণনাকারী দাঁড় করাব তাদের বিপক্ষে তাদের মধ্য থেকেই এবং তাদের বিষয়ে আপনাকে সাক্ষী স্বরূপ উপস্থাপন করব। আমি আপনার প্রতি গ্রন্থ নাযিল করেছি যেটি এমন যে তা প্রত্যেক বস্তুর সুস্পষ্ট বর্ণনা, হেদায়েত, রহমত এবং মুসলমানদের জন্যে সুসংবাদ।\qt@no{(89)}}
\qt@newcmd\qurantrans@bn@mcmxci{আল্লাহ ন্যায়পরায়ণতা, সদাচরণ এবং আত্নীয়-স্বজনকে দান করার আদেশ দেন এবং তিনি অশ্লীলতা, অসঙ্গত কাজ এবং অবাধ্যতা করতে বারণ করেন। তিনি তোমাদের উপদেশ দেন যাতে তোমরা স্মরণ রাখ।\qt@no{(90)}}
\qt@newcmd\qurantrans@bn@mcmxcii{আল্লাহর নামে অঙ্গীকার করার পর সে অঙ্গীকার পূর্ণ কর এবং পাকাপাকি কসম করার পর তা ভঙ্গ করো না, অথচ তোমরা আল্লাহকে জামিন করেছ। তোমরা যা কর আল্লাহ তা জানেন।\qt@no{(91)}}
\qt@newcmd\qurantrans@bn@mcmxciii{তোমরা ঐ মহিলার মত হয়ো না, যে পরিশ্রমের পর কাটা সূতা টুকরো টুকরো করে ছিড়ে ফেলে, তোমরা নিজেদের কসমসমূহকে পারস্পরিক প্রবঞ্চনার বাহানা রূপে গ্রহণ কর এজন্যে যে, অন্য দল অপেক্ষা এক দল অধিক ক্ষমতাবান হয়ে যায়। এতদ্বারা তো আল্লাহ শুধু তোমাদের পরীক্ষা করেন। আল্লাহ অবশ্যই কিয়ামতের দিন প্রকাশ করে দেবেন, যে বিষয়ে তোমরা কলহ করতে।\qt@no{(92)}}
\qt@newcmd\qurantrans@bn@mcmxciv{আল্লাহ ইচ্ছা করলে তোমাদের সবাইকে এক জাতি করে দিতে পারতেন, কিন্তু তিনি যাকে ইচ্ছা বিপথগামী করেন এবং যাকে ইচ্ছা পথ প্রদর্শন করেন। তোমরা যা কর সে বিষয়ে অবশ্যই জিজ্ঞাসিত হবে।\qt@no{(93)}}
\qt@newcmd\qurantrans@bn@mcmxcv{তোমরা স্বীয় কসমসমূহকে পারস্পরিক কলহ দ্বন্দ্বের বাহানা করো না। তা হলে দৃঢ়ভাবে প্রতিষ্ঠিত হওয়ার পর পা ফসকে যাবে এবং তোমরা শাস্তির স্বাদ আস্বাদন করবে এ কারণে যে, তোমরা আমার পথে বাধা দান করেছ এবং তোমাদের কঠোর শাস্তি হবে।\qt@no{(94)}}
\qt@newcmd\qurantrans@bn@mcmxcvi{তোমরা আল্লাহর অঙ্গীকারের বিনিময়ে সামান্য মূল্য গ্রহণ করো না। নিশ্চয় আল্লাহর কাছে যা আছে, তা উত্তম তোমাদের জন্যে, যদি তোমরা জ্ঞানী হও।\qt@no{(95)}}
\qt@newcmd\qurantrans@bn@mcmxcvii{তোমাদের কাছে যা আছে নিঃশেষ হয়ে যাবে এবং আল্লাহর কাছে যা আছে, কখনও তা শেষ হবে না। যারা সবর করে, আমি তাদেরকে প্রাপ্য প্রতিদান দেব তাদের উত্তম কর্মের প্রতিদান স্বরূপ যা তারা করত।\qt@no{(96)}}
\qt@newcmd\qurantrans@bn@mcmxcviii{যে সৎকর্ম সম্পাদন করে এবং সে ঈমাণদার, পুরুষ হোক কিংবা নারী আমি তাকে পবিত্র জীবন দান করব এবং প্রতিদানে তাদেরকে তাদের উত্তম কাজের কারণে প্রাপ্য পুরষ্কার দেব যা তারা করত।\qt@no{(97)}}
\qt@newcmd\qurantrans@bn@mcmxcix{অতএব, যখন আপনি কোরআন পাঠ করেন তখন বিতাড়িত শয়তান থেকে আল্লাহর আশ্রয় গ্রহণ করুন।\qt@no{(98)}}
\qt@newcmd\qurantrans@bn@mm{তার আধিপত্য চলে না তাদের উপর যারা বিশ্বাস স্থাপন করে এবং আপন পালন কর্তার উপর ভরসা রাখে।\qt@no{(99)}}
\qt@newcmd\qurantrans@bn@mmi{তার আধিপত্য তো তাদের উপরই চলে, যারা তাকে বন্ধু মনে করে এবং যারা তাকে অংশীদার মানে।\qt@no{(100)}}
\qt@newcmd\qurantrans@bn@mmii{এবং যখন আমি এক আয়াতের স্থলে অন্য আয়াত উপস্থিত করি এবং আল্লাহ যা অবতীর্ণ করেন তিনিই সে সম্পর্কে ভাল জানেন; তখন তারা বলেঃ আপনি তো মনগড়া উক্তি করেন; বরং তাদের অধিকাংশ লোকই জানে না।\qt@no{(101)}}
\qt@newcmd\qurantrans@bn@mmiii{বলুন, একে পবিত্র ফেরেশতা পালনকর্তার পক্ষ থেকে নিশ্চিত সত্যসহ নাযিল করেছেন, যাতে মুমিনদেরকে প্রতিষ্ঠিত করেন এবং এটা মুসলমানদের জন্যে পথ নির্দেশ ও সু-সংবাদ স্বরূপ।\qt@no{(102)}}
\qt@newcmd\qurantrans@bn@mmiv{আমি তো ভালভাবেই জানি যে, তারা বলেঃ তাকে জনৈক ব্যক্তি শিক্ষা দেয়। যার দিকে তারা ইঙ্গিত করে, তার ভাষা তো আরবী নয় এবং এ কোরআন পরিষ্কার আরবী ভাষায়।\qt@no{(103)}}
\qt@newcmd\qurantrans@bn@mmv{যারা আল্লাহর কথায় বিশ্বাস করে না, তাদেরকে আল্লাহ পথ প্রদর্শন করেন না এবং তাদের জন্যে রয়েছে যন্ত্রণাদায়ক শাস্তি।\qt@no{(104)}}
\qt@newcmd\qurantrans@bn@mmvi{মিথ্যা কেবল তারা রচনা করে, যারা আল্লাহর নিদর্শনে বিশ্বাস করে না এবং তারাই মিথ্যাবাদী।\qt@no{(105)}}
\qt@newcmd\qurantrans@bn@mmvii{যার উপর জবরদস্তি করা হয় এবং তার অন্তর বিশ্বাসে অটল থাকে সে ব্যতীত যে কেউ বিশ্বাসী হওয়ার পর আল্লাহতে অবিশ্বাসী হয় এবং কুফরীর জন্য মন উম্মুক্ত করে দেয় তাদের উপর আপতিত হবে আল্লাহর গযব এবং তাদের জন্যে রয়েছে শাস্তি।\qt@no{(106)}}
\qt@newcmd\qurantrans@bn@mmviii{এটা এ জন্যে যে, তারা পার্থিব জীবনকে পরকালের চাইতে প্রিয় মনে করেছে এবং আল্লাহ অবিশ্বাসীদেরকে পথ প্রদর্শন করেন না।\qt@no{(107)}}
\qt@newcmd\qurantrans@bn@mmix{এরাই তারা, আল্লাহ তা’য়ালা এদেরই অন্তর, কর্ণ ও চক্ষুর উপর মোহর মেরে দিয়েছেন এবং এরাই কান্ড জ্ঞানহীন।\qt@no{(108)}}
\qt@newcmd\qurantrans@bn@mmx{বলাবাহুল্য পরকালে এরাই ক্ষতি গ্রস্ত হবে।\qt@no{(109)}}
\qt@newcmd\qurantrans@bn@mmxi{যারা দুঃখ-কষ্ট ভোগের পর দেশত্যাগী হয়েছে অতঃপর জেহাদ করেছে, নিশ্চয় আপনার পালনকর্তা এসব বিষয়ের পরে অবশ্যই ক্ষমাশীল, পরম দয়ালু।\qt@no{(110)}}
\qt@newcmd\qurantrans@bn@mmxii{যেদিন প্রত্যেক ব্যক্তি আত্ন-সমর্থনে সওয়াল জওয়াব করতে করতে আসবে এবং প্রত্যেক ব্যক্তি তাদের কৃতকর্মের পূর্ণ ফল পাবে এবং তাদের উপর জুলুম করা হবে না।\qt@no{(111)}}
\qt@newcmd\qurantrans@bn@mmxiii{আল্লাহ দৃষ্টান্ত বর্ণনা করেছেন একটি জনপদের, যা ছিল নিরাপদ ও নিশ্চিন্ত, তথায় প্রত্যেক জায়গা থেকে আসত প্রচুর জীবনোপকরণ। অতঃপর তারা আল্লাহর নেয়ামতের প্রতি অকৃতজ্ঞতা প্রকাশ করল। তখন আল্লাহ তাদেরকে তাদের কৃতকর্মের কারণে স্বাদ আস্বাদন করালেন, ক্ষুধা ও ভীতির।\qt@no{(112)}}
\qt@newcmd\qurantrans@bn@mmxiv{তাদের কাছে তাদের মধ্য থেকেই একজন রাসূল আগমন করেছিলেন। অনন্তর ওরা তাঁর প্রতি মিথ্যারোপ করল। তখন আযাব এসে তাদরকে পাকড়াও করল এবং নিশ্চিতই ওরা ছিল পাপাচারী।\qt@no{(113)}}
\qt@newcmd\qurantrans@bn@mmxv{অতএব, আল্লাহ তোমাদেরকে যেসব হালাল ও পবিত্র বস্তু দিয়েছেন, তা তোমরা আহার কর এবং আল্লাহর অনুগ্রহের জন্যে কৃতজ্ঞতা প্রকাশ কর যদি তোমরা তাঁরই এবাদতকারী হয়ে থাক।\qt@no{(114)}}
\qt@newcmd\qurantrans@bn@mmxvi{অবশ্যই আল্লাহ তোমাদের জন্যে হারাম করেছেন রক্ত, শুকরের মাংস এবং যা জবাই কালে আল্লাহ ছাড়া অন্যের নাম উচ্চারণ করা হয়েছে। অতঃপর কেউ সীমালঙ্ঘন কারী না হয়ে নিরুপায় হয়ে পড়লে তবে, আল্লাহ ক্ষমাশীল, পরম দয়ালু।\qt@no{(115)}}
\qt@newcmd\qurantrans@bn@mmxvii{তোমাদের মুখ থেকে সাধারনতঃ যেসব মিথ্যা বের হয়ে আসে তেমনি করে তোমরা আল্লাহর বিরুদ্ধে মিথ্যা অপবাদ আরোপ করে বল না যে, এটা হালাল এবং ওটা হারাম। নিশ্চয় যারা আল্লাহর বিরুদ্ধে মিথ্যা আরোপ করে, তাদের মঙ্গল হবে না।\qt@no{(116)}}
\qt@newcmd\qurantrans@bn@mmxviii{যৎসামান্য সুখ-সম্ভোগ ভোগ করে নিক। তাদের জন্যে যন্ত্রনাদায়ক শাস্তি রয়েছে।\qt@no{(117)}}
\qt@newcmd\qurantrans@bn@mmxix{ইহুদীদের জন্যে আমি তো কেবল তাই হারাম করেছিলাম যা ইতিপূর্বে আপনার নিকট উল্লেখ করেছি। আমি তাদের প্রতি কোন জুলুম করিনি, কিন্তু তারাই নিজেদের উপর জুলুম করত।\qt@no{(118)}}
\qt@newcmd\qurantrans@bn@mmxx{অনন্তর যারা অজ্ঞতাবশতঃ মন্দ কাজ করে, অতঃপর তওবা করে এবং নিজেকে সংশোধন করে নেয়, আপনার পালনকর্তা এসবের পরে তাদের জন্যে অবশ্যই ক্ষমাশীল, দয়ালু।\qt@no{(119)}}
\qt@newcmd\qurantrans@bn@mmxxi{নিশ্চয় ইব্রাহীম ছিলেন এক সম্প্রদায়ের প্রতীক, সবকিছু থেকে মুখ ফিরিয়ে এক আল্লাহরই অনুগত এবং তিনি শেরককারীদের অন্তর্ভুক্ত ছিলেন না।\qt@no{(120)}}
\qt@newcmd\qurantrans@bn@mmxxii{তিনি তাঁর অনুগ্রহের প্রতি কৃতজ্ঞতা প্রকাশকারী ছিলেন। আল্লাহ তাঁকে মনোনীত করেছিলেন এবং সরল পথে পরিচালিত করেছিলেন।\qt@no{(121)}}
\qt@newcmd\qurantrans@bn@mmxxiii{আমি তাঁকে দুনিয়াতে দান করেছি কল্যাণ এবং তিনি পরকালেও সৎকর্মশীলদের অন্তর্ভূক্ত।\qt@no{(122)}}
\qt@newcmd\qurantrans@bn@mmxxiv{অতঃপর আপনার প্রতি প্রত্যাদেশ প্রেরণ করেছি যে, ইব্রাহীমের দ্বীন অনুসরণ করুন, যিনি একনিষ্ঠ ছিলেন এবং শিরককারীদের অন্তর্ভূক্ত ছিলেন না।\qt@no{(123)}}
\qt@newcmd\qurantrans@bn@mmxxv{শনিবার দিন পালন যে, নির্ধারণ করা হয়েছিল, তা তাদের জন্যেই যারা এতে মতবিরোধ করেছিল। আপনার পালনকর্তা কিয়ামতের দিন তাদের মধ্যে ফয়সালা করবেন যে বিষয়ে তারা মতবিরোধ করত।\qt@no{(124)}}
\qt@newcmd\qurantrans@bn@mmxxvi{আপন পালনকর্তার পথের প্রতি আহবান করুন জ্ঞানের কথা বুঝিয়ে ও উপদেশ শুনিয়ে উত্তমরূপে এবং তাদের সাথে বিতর্ক করুন পছন্দ যুক্ত পন্থায়। নিশ্চয় আপনার পালনকর্তাই ঐ ব্যক্তি সম্পর্কে বিশেষ ভাবে জ্ঞাত রয়েছেন, যে তাঁর পথ থেকে বিচ্যুত হয়ে পড়েছে এবং তিনিই ভাল জানেন তাদেরকে, যারা সঠিক পথে আছে।\qt@no{(125)}}
\qt@newcmd\qurantrans@bn@mmxxvii{আর যদি তোমরা প্রতিশোধ গ্রহণ কর, তবে ঐ পরিমাণ প্রতিশোধ গ্রহণ করবে, যে পরিমাণ তোমাদেরকে কষ্ট দেয়া হয়। যদি সবর কর, তবে তা সবরকারীদের জন্যে উত্তম।\qt@no{(126)}}
\qt@newcmd\qurantrans@bn@mmxxviii{আপনি সবর করবেন। আপনার সবর আল্লাহর জন্য ব্যতীত নয়, তাদের জন্যে দুঃখ করবেন না এবং তাদের চক্রান্তের কারণে মন ছোট করবেন না।\qt@no{(127)}}
\qt@newcmd\qurantrans@bn@mmxxix{নিশ্চয় আল্লাহ তাদের সঙ্গে আছেন, যারা পরহেযগার এবং যারা সৎকর্ম করে।\qt@no{(128)}}
\qt@newcmd\qurantrans@bn@mmxxx{\basmalahbn পরম পবিত্র ও মহিমাময় সত্তা তিনি, যিনি স্বীয় বান্দাকে রাত্রি বেলায় ভ্রমণ করিয়েছিলেন মসজিদে হারাম থেকে মসজিদে আকসা পর্যান্ত-যার চার দিকে আমি পর্যাপ্ত বরকত দান করেছি যাতে আমি তাঁকে কুদরতের কিছু নিদর্শন দেখিয়ে দেই। নিশ্চয়ই তিনি পরম শ্রবণকারী ও দর্শনশীল।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmxxxi{আমি মূসাকে কিতাব দিয়েছি এবং সেটিকে বনী-ইসরাঈলের জন্যে হেদায়েতে পরিণত করেছি যে, তোমরা আমাকে ছাড়া কাউকে কার্যনিবাহী স্থির করো না।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmxxxii{তোমরা তাদের সন্তান, যাদেরকে আমি নূহের সাথে সওয়ার করিয়েছিলাম। নিশ্চয় সে ছিল কৃতজ্ঞ বান্দা।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmxxxiii{আমি বনী ইসরাঈলকে কিতাবে পরিষ্কার বলে দিয়েছি যে, তোমরা পৃথিবীর বুকে দুবার অনর্থ সৃষ্টি করবে এবং অত্যন্ত বড় ধরনের অবাধ্যতায় লিপ্ত হবে।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmxxxiv{অতঃপর যখন প্রতিশ্রুতি সেই প্রথম সময়টি এল, তখন আমি তোমাদের বিরুদ্ধে প্রেরণ করলাম আমার কঠোর যোদ্ধা বান্দাদেরকে। অতঃপর তারা প্রতিটি জনপদের আনাচে-কানাচে পর্যন্ত ছড়িয়ে পড়ল। এ ওয়াদা পূর্ণ হওয়ারই ছিল।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmxxxv{অতঃপর আমি তোমাদের জন্যে তাদের বিরুদ্ধে পালা ঘুয়িয়ে দিলাম, তোমাদেরকে ধন-সম্পদ ও পুত্রসন্তান দ্বারা সাহায্য করলাম এবং তোমাদেরকে জনসংখ্যার দিক দিয়ে একটা বিরাট বাহিনীতে পরিণত করলাম।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmxxxvi{তোমরা যদি ভাল কর, তবে নিজেদেরই ভাল করবে এবং যদি মন্দ কর তবে তাও নিজেদের জন্যেই। এরপর যখন দ্বিতীয় সে সময়টি এল, তখন অন্য বান্দাদেরকে প্রেরণ করলাম, যাতে তোমাদের মুখমন্ডল বিকৃত করে দেয়, আর মসজিদে ঢুকে পড়ে যেমন প্রথমবার ঢুকেছিল এবং যেখানেই জয়ী হয়, সেখানেই পুরোপুরি ধ্বংসযজ্ঞ চালায়।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmxxxvii{হয়ত তোমাদের পালনকর্তা তোমাদের প্রতি অনুগ্রহ করবেন। কিন্তু যদি পুনরায় তদ্রূপ কর, আমিও পুনরায় তাই করব। আমি জাহান্নামকে কাফেরদের জন্যে কয়েদখানা করেছি।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmxxxviii{এই কোরআন এমন পথ প্রদর্শন করে, যা সর্বাধিক সরল এবং সৎকর্ম পরায়ণ মুমিনদেরকে সুসংবাদ দেয় যে, তাদের জন্যে মহা পুরস্কার রয়েছে।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmxxxix{এবং যারা পরকালে বিশ্বাস করে না, আমি তাদের জন্যে যন্ত্রণাদায়ক শাস্তি প্রস্তুত করেছি।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmxl{মানুষ যেভাবে কল্যাণ কামনা করে, সেভাবেই অকল্যাণ কামনা করে। মানুষ তো খুবই দ্রুততা প্রিয়।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmxli{আমি রাত্রি ও দিনকে দুটি নিদর্শন করেছি। অতঃপর নিস্প্রভ করে দিয়েছি রাতের নিদর্শন এবং দিনের নিদর্শনকে দেখার উপযোগী করেছি, যাতে তোমরা তোমাদের পালনকর্তার অনুগ্রহ অন্বেষণ কর এবং যাতে তোমরা স্থির করতে পার বছরসমূহের গণনা ও হিসাব এবং আমি সব বিষয়কে বিস্তারিত ভাবে বর্ণনা করেছি।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmxlii{আমি প্রত্যেক মানুষের কর্মকে তার গ্রীবলগ্ন করে রেখেছি। কেয়ামতের দিন বের করে দেখাব তাকে একটি কিতাব, যা সে খোলা অবস্থায় পাবে।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmxliii{পাঠ কর তুমি তোমার কিতাব। আজ তোমার হিসাব গ্রহণের জন্যে তুমিই যথেষ্ট।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmxliv{যে কেউ সৎপথে চলে, তারা নিজের মঙ্গলের জন্যেই সৎ পথে চলে। আর যে পথভ্রষ্ট হয়, তারা নিজের অমঙ্গলের জন্যেই পথ ভ্রষ্ট হয়। কেউ অপরের বোঝা বহন করবে না। কোন রাসূল না পাঠানো পর্যন্ত আমি কাউকেই শাস্তি দান করি না।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmxlv{যখন আমি কোন জনপদকে ধ্বংস করার ইচ্ছা করি তখন তার অবস্থাপন্ন লোকদেরকে উদ্ধুদ্ধ করি অতঃপর তারা পাপাচারে মেতে উঠে। তখন সে জনগোষ্টীর উপর আদেশ অবধারিত হয়ে যায়। অতঃপর আমি তাকে উঠিয়ে আছাড় দেই।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmxlvi{নূহের পর আমি অনেক উম্মতকে ধ্বংস করেছি। আপনার পালনকর্তাই বান্দাদের পাপাচারের সংবাদ জানা ও দেখার জন্যে যথেষ্ট।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmxlvii{যে কেউ ইহকাল কামনা করে, আমি সেসব লোককে যা ইচ্ছা সত্ত্বর দিয়ে দেই। অতঃপর তাদের জন্যে জাহান্নাম নির্ধারণ করি। ওরা তাতে নিন্দিত-বিতাড়িত অবস্থায় প্রবেশ করবে।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmxlviii{আর যারা পরকাল কামনা করে এবং মুমিন অবস্থায় তার জন্য যথাযথ চেষ্টা-সাধনা করে, এমন লোকদের চেষ্টা স্বীকৃত হয়ে থাকে।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmxlix{এদেরকে এবং ওদেরকে প্রত্যেককে আমি আপনার পালনকর্তার দান পৌছে দেই এবং আপনার পালকর্তার দান অবধারিত।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mml{দেখুন, আমি তাদের একদলকে অপরের উপর কিভাবে শ্রেষ্ঠত্ব দান করলাম। পরকাল তো নিশ্চয়ই মর্তবায় শ্রেষ্ঠ এবং ফযীলতে শ্রেষ্ঠতম।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmli{স্থির করো না আল্লাহর সাথে অন্য কোন উপাস্য। তাহলে তুমি নিন্দিত ও অসহায় হয়ে পড়বে।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmlii{তোমার পালনকর্তা আদেশ করেছেন যে, তাঁকে ছাড়া অন্য কারও এবাদত করো না এবং পিতা-মাতার সাথে সদ্ব-ব্যবহার কর। তাদের মধ্যে কেউ অথবা উভয়েই যদি তোমার জীবদ্দশায় বার্ধক্যে উপনীত হয়; তবে তাদেরকে ‘উহ’ শব্দটিও বলো না এবং তাদেরকে ধমক দিও না এবং বল তাদেরকে শিষ্ঠাচারপূর্ণ কথা।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmliii{তাদের সামনে ভালবাসার সাথে, নম্রভাবে মাথা নত করে দাও এবং বলঃ হে পালনকর্তা, তাদের উভয়ের প্রতি রহম কর, যেমন তারা আমাকে শৈশবকালে লালন-পালন করেছেন।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmliv{তোমাদের পালনকর্তা তোমাদের মনে যা আছে তা ভালই জানেন। যদি তোমরা সৎ হও, তবে তিনি তওবাকারীদের জন্যে ক্ষমাশীল।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmlv{আত্নীয়-স্বজনকে তার হক দান কর এবং অভাবগ্রস্ত ও মুসাফিরকেও। এবং কিছুতেই অপব্যয় করো না।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmlvi{নিশ্চয় অপব্যয়কারীরা শয়তানের ভাই। শয়তান স্বীয় পালনকর্তার প্রতি অতিশয় অকৃতজ্ঞ।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmlvii{এবং তোমার পালনকর্তার করুণার প্রত্যাশায় অপেক্ষামান থাকাকালে যদি কোন সময় তাদেরকে বিমুখ করতে হয়, তখন তাদের সাথে নম্রভাবে কথা বল।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmlviii{তুমি একেবারে ব্যয়-কুষ্ঠ হয়োনা এবং একেবারে মুক্ত হস্তও হয়ো না। তাহলে তুমি তিরস্কৃতি, নিঃস্ব হয়ে বসে থাকবে।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmlix{নিশ্চয় তোমার পালকর্তা যাকে ইচ্ছা অধিক জীবনোপকরণ দান করেন এবং তিনিই তা সংকুচিতও করে দেন। তিনিই তাঁর বান্দাদের সম্পর্কে ভালোভাবে অবহিত,-সব কিছু দেখছেন।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmlx{দারিদ্রের ভয়ে তোমাদের সন্তানদেরকে হত্যা করো না। তাদেরকে এবং তোমাদেরকে আমিই জীবনোপকরণ দিয়ে থাকি। নিশ্চয় তাদেরকে হত্যা করা মারাত্নক অপরাধ।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmlxi{আর ব্যভিচারের কাছেও যেয়ো না। নিশ্চয় এটা অশ্লীল কাজ এবং মন্দ পথ।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmlxii{সে প্রাণকে হত্যা করো না, যাকে আল্লাহ হারাম করেছেন; কিন্তু ন্যায়ভাবে। যে ব্যক্তি অন্যায়ভাবে নিহত হয়, আমি তার উত্তরাধিকারীকে ক্ষমতা দান করি। অতএব, সে যেন হত্যার ব্যাপারে সীমা লঙ্ঘন না করে। নিশ্চয় সে সাহায্যপ্রাপ্ত।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmlxiii{আর, এতিমের মালের কাছেও যেয়ো না, একমাত্র তার কল্যাণ আকাংখা ছাড়া; সংশ্লিষ্ট ব্যক্তির যৌবনে পদার্পন করা পর্যন্ত এবং অঙ্গীকার পূর্ন কর। নিশ্চয় অঙ্গীকার সম্পর্কে জিজ্ঞাসাবাদ করা হবে।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmlxiv{মেপে দেয়ার সময় পূর্ণ মাপে দেবে এবং সঠিক দাঁড়িপালায় ওজন করবে। এটা উত্তম; এর পরিণাম শুভ।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmlxv{যে বিষয়ে তোমার কোন জ্ঞান নেই, তার পিছনে পড়ো না। নিশ্চয় কান, চক্ষু ও অন্তঃকরণ এদের প্রত্যেকটিই জিজ্ঞাসিত হবে।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmlxvi{পৃথিবীতে দম্ভভরে পদচারণা করো না। নিশ্চয় তুমি তো ভূ পৃষ্ঠকে কখনই বিদীর্ণ করতে পারবে না এবং উচ্চতায় তুমি কখনই পর্বত প্রমাণ হতে পারবে না।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmlxvii{এ সবের মধ্যে যেগুলো মন্দকাজ, সেগুলো তোমার পালনকর্তার কাছে অপছন্দনীয়।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmlxviii{এটা ঐ হিকমতের অন্তর্ভূক্ত, যা আপনার পালনকর্তা আপনাকে ওহী মারফত দান করেছেন। আল্লাহর সাথে অন্য কোন উপাস্য স্থির করবেন না। তাহলে অভিযুক্ত ও আল্লাহর অনুগ্রহ থেকে বিতাড়িত অবস্থায় জাহান্নামে নিক্ষিপ্ত হবেন।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmlxix{তোমাদের পালনকর্তা কি তোমাদের জন্যে পুত্র সন্তান নির্ধারিত করেছেন এবং নিজের জন্যে ফেরেশতাদেরকে কন্যারূপে গ্রহণ করেছেন? নিশ্চয় তোমরা গুরুতর গর্হিত কথাবার্তা বলছ।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmlxx{আমি এই কোরআনে নানাভাবে বুঝিয়েছি, যাতে তারা চিন্তা করে। অথচ এতে তাদের কেবল বিমুখতাই বৃদ্ধি পায়।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmlxxi{বলুনঃ তাদের কথামত যদি তাঁর সাথে অন্যান্য উপাস্য থাকত; তবে তারা আরশের মালিক পর্যন্ত পৌছার পথ অন্বেষন করত।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmlxxii{তিনি নেহায়েত পবিত্র ও মহিমান্বিত এবং তারা যা বলে থাকে তা থেকে বহু উর্ধ্বে।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmlxxiii{সপ্ত আকাশ ও পৃথিবী এবং এগুলোর মধ্যে যাকিছু আছে সমস্ত কিছু তাঁরই পবিত্রতা ও মহিমা ঘোষণা করে। এবং এমন কিছু নেই যা তার সপ্রশংস পবিত্রতা ও মহিমা ঘোষনা করে না। কিন্তু তাদের পবিত্রতা, মহিমা ঘোষণা তোমরা অনুধাবন করতে পার না। নিশ্চয় তিনি অতি সহনশীল, ক্ষমাপরায়ণ।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmlxxiv{যখন আপনি কোরআন পাঠ করেন, তখন আমি আপনার মধ্যে ও পরকালে অবিশ্বাসীদের মধ্যে প্রচ্ছন্ন পর্দা ফেলে দেই।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmlxxv{আমি তাদের অন্তরের উপর আবরণ রেখে দেই, যাতে তারা একে উপলব্ধি করতে না পারে এবং তাদের কর্ণকুহরে বোঝা চাপিয়ে দেই। যখন আপনি কোরআনে পালনকর্তার একত্ব আবৃত্তি করেন, তখন ও অনীহাবশতঃ ওরা পৃষ্ট প্রদর্শন করে চলে যায়।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmlxxvi{যখন তারা কান পেতে আপনার কথা শোনে, তখন তারা কেন কান পেতে তা শোনে, তা আমি ভাল জানি এবং এও জানি গোপনে আলোচনাকালে যখন জালেমরা বলে, তোমরা তো এক যাদুগ্রস্থ ব্যক্তির অনুসরণ করছ।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmlxxvii{দেখুন, ওরা আপনার জন্যে কেমন উপমা দেয়। ওরা পথভ্রষ্ট হয়েছে। অতএব, ওরা পথ পেতে পারে না।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmlxxviii{তারা বলেঃ যখন আমরা অস্থিতে পরিণত ও চূর্ণ বিচূর্ণ হয়ে যাব, তখনও কি নতুন করে সৃজিত হয়ে উত্থিত হব?\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmlxxix{বলুনঃ তোমরা পাথর হয়ে যাও কিংবা লোহা।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmlxxx{অথবা এমন কোন বস্তু, যা তোমাদের ধারণায় খুবই কঠিন; তথাপি তারা বলবেঃ আমাদের কে পুর্নবার কে সৃষ্টি করবে। বলুনঃ যিনি তোমাদেরকে প্রথমবার সৃজন করেছেন। অতঃপর তারা আপনার সামনে মাথা নাড়বে এবং বলবেঃ এটা কবে হবে? বলুনঃ হবে, সম্ভবতঃ শ্রীঘ্রই।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmlxxxi{যেদিন তিনি তোমাদেরকে আহবান করবেন, অতঃপর তোমরা তাঁর প্রশংসা করতে করতে চলে আসবে। এবং তোমরা অনুমান করবে যে, সামান্য সময়ই অবস্থান করেছিলে।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmlxxxii{আমার বান্দাদেরকে বলে দিন, তারা যেন যা উত্তম এমন কথাই বলে। শয়তান তাদের মধ্যে সংঘর্ষ বাধায়। নিশ্চয় শয়তান মানুষের প্রকাশ্য শত্রু।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmlxxxiii{তোমাদের পালনকর্তা তোমাদের সম্পর্কে ভালভাবে জ্ঞাত আছেন। তিনি যদি চান, তোমাদের প্রতি রহমত করবেন কিংবা যদি চান, তোমাদের আযাব দিবেন। আমি আপনাকে ওদের সবার তত্ত্বাবধায়ক রূপে প্রেরণ করিনি।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmlxxxiv{আপনার পালনকর্তা তাদের সম্পর্কে ভালভাবে জ্ঞাত আছেন, যারা আকাশসমূহে ও ভুপৃষ্ঠে রয়েছে। আমি তো কতক পয়গম্বরকে কতক পয়গম্বরের উপর শ্রেষ্ঠত্ব দান করেছি এবং দাউদকে যবুর দান করেছি।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mmlxxxv{বলুনঃ আল্লাহ ব্যতীত যাদেরকে তোমরা উপাস্য মনে কর, তাদেরকে আহবান কর। অথচ ওরা তো তোমাদের কষ্ট দুর করার ক্ষমতা রাখে না এবং তা পরিবর্তনও করতে পারে না।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mmlxxxvi{যাদেরকে তারা আহবান করে, তারা নিজেরাই তো তাদের পালনকর্তার নৈকট্য লাভের জন্য মধ্যস্থ তালাশ করে যে, তাদের মধ্যে কে নৈকট্যশীল। তারা তাঁর রহমতের আশা করে এবং তাঁর শাস্তিকে ভয় করে। নিশ্চয় আপনার পালনকর্তার শাস্তি ভয়াবহ।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mmlxxxvii{এমন কোন জনপদ নেই, যাকে আমি কেয়ামত দিবসের পূর্বে ধ্বংস করব না অথবা যাকে কঠোর শাস্তি দেব না। এটা তো গ্রন্থে লিপিবদ্ধ হয়ে গেছে।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mmlxxxviii{পূর্ববর্তীগণ কতৃꦣ2453; নিদর্শন অস্বীকার করার ফলেই আমাকে নিদর্শনাবলী প্রেরণ থেকে বিরত থাকতে হয়েছে। আমি তাদেরকে বোঝাবার জন্যে সামুদকে উষ্ট্রী দিয়েছিলাম। অতঃপর তারা তার প্রতি জুলুম করেছিল। আমি ভীতি প্রদর্শনের উদ্দেশেই নিদর্শন প্রেরণ করি।\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mmlxxxix{এবং স্মরণ করুন, আমি আপনাকে বলে দিয়েছিলাম যে, আপনার পালনকর্তা মানুষকে পরিবেষ্টন করে রেখেছেন এবং যে দৃশ্য আমি আপনাকে দেখিয়েছি তাও কোরআনে উল্লেখিত অভিশপ্ত বৃক্ষ কেবল মানুষের পরীক্ষার জন্যে। আমি তাদেরকে ভয় প্রদর্শন করি। কিন্তু এতে তাদের অবাধ্যতাই আরও বৃদ্ধি পায়।\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mmxc{স্মরণ কর, যখন আমি ফেরেশতাদেরকে বললামঃ আদমকে সেজদা কর, তখন ইবলীস ব্যতীত সবাই সেজদায় পড়ে গেল। কিন্তু সে বললঃ আমি কি এমন ব্যক্তিকে সেজদা করব, যাকে আপনি মাটির দ্বারা সৃষ্টি করেছেন?\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mmxci{সে বললঃ দেখুন তো, এনা সে ব্যক্তি, যাকে আপনি আমার চাইতেও উচ্চ মার্যাদা দিয়ে দিয়েছেন। যদি আপনি আমাকে কেয়ামত দিবস পর্যন্ত সময় দেন, তবে আমি সামান্য সংখ্যক ছাড়া তার বংশধরদেরকে সমূলে নষ্ট করে দেব।\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mmxcii{আল্লাহ বলেনঃ চলে যা, অতঃপর তাদের মধ্য থেকে যে তোর অনুগামী হবে, জাহান্নামই হবে তাদের সবার শাস্তি-ভরপুর শাস্তি।\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mmxciii{তুই সত্যচ্যুত করে তাদের মধ্য থেকে যাকে পারিস স্বীয় আওয়ায দ্বারা, স্বীয় অশ্বারোহী ও পদাতিক বাহিনী নিয়ে তাদেরকে আক্রমণ কর, তাদের অর্থ-সম্পদ ও সন্তান-সন্ততিতে শরীক হয়ে যা এবং তাদেরকে প্রতিশ্রুতি দে। ছলনা ছাড়া শয়তান তাদেরকে কোন প্রতিশ্রুতি দেয় না।\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mmxciv{আমার বান্দাদের উপর তোর কোন ক্ষমতা নেই আপনার পালনকর্তা যথেষ্ট কার্যনির্বাহী।\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mmxcv{তোমাদের পালনকর্তা তিনিই, যিনি তোমাদের জন্যে সমুদ্রে জলযান চালনা করেন, যাতে তোমরা তার অনুগ্রহ অন্বেষন করতে পারো। নিঃ সন্দেহে তিনি তোমাদের প্রতি পরম দয়ালূ।\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mmxcvi{যখন সমুদ্রে তোমাদের উপর বিপদ আসে, তখন শুধু আল্লাহ ব্যতীত যাদেরকে তোমরা আহবান করে থাক তাদেরকে তোমরা বিস্মৃত হয়ে যাও। অতঃপর তিনি যখন তোমাদেরকে স্থলে ভিড়িয়ে উদ্ধার করে নেন, তখন তোমরা মুখ ফিরিয়ে নাও। মানুষ বড়ই অকৃতজ্ঞ।\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mmxcvii{তোমরা কি এ বিষয়ে নিশ্চিন্ত রয়েছ যে, তিনি তোমাদেরকে স্থলভাগে কোথাও ভূগর্ভস্থ করবেন না। অথবা তোমাদের উপর প্রস্তর বর্ষণকারী ঘুর্ণিঝড় প্রেরণ করবেন না, তখন তোমরা নিজেদের জন্যে কোন কর্মবিধায়ক পাবে না।\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mmxcviii{অথবা তোমরা কি এ বিষয়ে নিশ্চিন্ত যে, তিনি তোমাদেরকে আরেকবার সমুদ্রে নিয়ে যাবেন না, অতঃপর তোমাদের জন্যে মহা ঝটিকা প্রেরণ করবেন না, অতঃপর অকৃতজ্ঞতার শাস্তিস্বরূপ তোমাদেরকে নিমজ্জত করবেন না, তখন তোমরা আমার বিরুদ্ধে এ বিষয়ে সাহায্যকারী কাউকে পাবে না।\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mmxcix{নিশ্চয় আমি আদম সন্তানকে মর্যাদা দান করেছি, আমি তাদেরকে স্থলে ও জলে চলাচলের বাহন দান করেছি; তাদেরকে উত্তম জীবনোপকরণ প্রদান করেছি এবং তাদেরকে অনেক সৃষ্ট বস্তুর উপর শ্রেষ্ঠত্ব দান করেছি।\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@mmc{স্মরণ কর, যেদিন আমি প্রত্যেক দলকে তাদের নেতাসহ আহবান করব, অতঃপর যাদেরকে তাদের ডান হাতে আমলনামা দেয়া হবে, তারা নিজেদের আমলনামা পাঠ করবে এবং তাদের প্রতি সামান্য পরিমাণও জুলুম হবে না।\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@mmci{যে ব্যক্তি ইহকালে অন্ধ ছিল সে পরকালেও অন্ধ এবং অধিকতর পথভ্রান্ত।\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@mmcii{তারা তো আপনাকে হটিয়ে দিতে চাচ্ছিল যে বিষয় আমি আপনার প্রতি ওহীর মাধ্যমে যা প্রেরণ করেছি তা থেকে আপনার পদঙ্খলন ঘটানোর জন্যে তারা চুড়ান্ত চেষ্টা করেছে, যাতে আপনি আমার প্রতি কিছু মিথ্যা সম্বন্ধযুক্ত করেন। এতে সফল হলে তারা আপনাকে বন্ধুরূপে গ্রহণ করে নিত।\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@mmciii{আমি আপনাকে দৃঢ়পদ না রাখলে আপনি তাদের প্রতি কিছুটা ঝুঁকেই পড়তেন।\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@mmciv{তখন আমি অবশ্যই আপনাকে ইহজীবনে ও পরজীবনে দ্বিগুণ শাস্তির আস্বাদন করাতাম। এ সময় আপনি আমার মোকাবিলায় কোন সাহায্যকারী পেতেন না।\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@mmcv{তারা তো আপনাকে এ ভুখন্ড থেকে উৎখাত করে দিতে চুড়ান্ত চেষ্টা করেছিল যাতে আপনাকে এখান থেকে বহিস্কার করে দেয়া যায়। তখন তারাও আপনার পর সেখানে অল্প কালই মাত্র টিকে থাকত।\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@mmcvi{আপনার পূর্বে আমি যত রসূল প্রেরণ করেছি, তাদের ক্ষেত্রেও এরূপ নিয়ম ছিল। আপনি আমার নিয়মের কোন ব্যতিক্রম পাবেন না।\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@mmcvii{সূর্য ঢলে পড়ার সময় থেকে রাত্রির অন্ধকার পর্যন্ত নামায কায়েম করুন এবং ফজরের কোরআন পাঠও। নিশ্চয় ফজরের কোরআন পাঠ মুখোমুখি হয়।\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@mmcviii{রাত্রির কিছু অংশ কোরআন পাঠ সহ জাগ্রত থাকুন। এটা আপনার জন্যে অতিরিক্ত। হয়ত বা আপনার পালনকর্তা আপনাকে মোকামে মাহমুদে পৌঁছাবেন।\qt@no{(79)}}
\qt@newcmd\qurantrans@bn@mmcix{বলুনঃ হে পালনকর্তা! আমাকে দাখিল করুন সত্যরূপে এবং আমাকে বের করুন সত্যরূপে এবং দান করুন আমাকে নিজের কাছ থেকে রাষ্ট্রীয় সাহায্য।\qt@no{(80)}}
\qt@newcmd\qurantrans@bn@mmcx{বলুনঃ সত্য এসেছে এবং মিথ্যা বিলুপ্ত হয়েছে। নিশ্চয় মিথ্যা বিলুপ্ত হওয়ারই ছিল।\qt@no{(81)}}
\qt@newcmd\qurantrans@bn@mmcxi{আমি কোরআনে এমন বিষয় নাযিল করি যা রোগের সুচিকিৎসা এবং মুমিনের জন্য রহমত। গোনাহগারদের তো এতে শুধু ক্ষতিই বৃদ্ধি পায়।\qt@no{(82)}}
\qt@newcmd\qurantrans@bn@mmcxii{আমি মানুষকে নেয়ামত দান করলে সে মুখ ফিরিয়ে নেয় এবং অহংকারে দুরে সরে যায়; যখন তাকে কোন অনিষ্ট স্পর্শ করে, তখন সে একেবারে হতাশ হয়ে পড়ে।\qt@no{(83)}}
\qt@newcmd\qurantrans@bn@mmcxiii{বলুনঃ প্রত্যেকেই নিজ রীতি অনুযায়ী কাজ করে। অতঃপর আপনার পালনকর্তা বিশেষ রূপে জানেন, কে সর্বাপেক্ষা নির্ভূল পথে আছে।\qt@no{(84)}}
\qt@newcmd\qurantrans@bn@mmcxiv{তারা আপনাকে রূহ সম্পর্কে জিজ্ঞেস করে। বলে দিনঃ রূহ আমার পালনকর্তার আদেশ ঘটিত। এ বিষয়ে তোমাদেরকে সামান্য জ্ঞানই দান করা হয়েছে।\qt@no{(85)}}
\qt@newcmd\qurantrans@bn@mmcxv{আমি ইচ্ছা করলে আপনার কাছে ওহীর মাধমে যা প্রেরণ করেছি তা অবশ্যই প্রত্যাহার করতে পারতাম। অতঃপর আপনি নিজের জন্যে তা আনয়নের ব্যাপারে আমার মোকাবিলায় কোন দায়িত্ব বহনকারী পাবেন না।\qt@no{(86)}}
\qt@newcmd\qurantrans@bn@mmcxvi{এ প্রত্যাহার না করা আপনার পালনকর্তার মেহেরবানী। নিশ্চয় আপনার প্রতি তাঁর করুণা বিরাট।\qt@no{(87)}}
\qt@newcmd\qurantrans@bn@mmcxvii{বলুনঃ যদি মানব ও জ্বিন এই কোরআনের অনুরূপ রচনা করে আনয়নের জন্যে জড়ো হয়, এবং তারা পরস্পরের সাহায্যকারী হয়; তবুও তারা কখনও এর অনুরূপ রচনা করে আনতে পারবে না।\qt@no{(88)}}
\qt@newcmd\qurantrans@bn@mmcxviii{আমি এই কোরআনে মানুষকে বিভিন্ন উপকার দ্বারা সব রকম বিষয়বস্তু বুঝিয়েছি। কিন্তু অধিকাংশ লোক অস্বীকার না করে থাকেনি।\qt@no{(89)}}
\qt@newcmd\qurantrans@bn@mmcxix{এবং তারা বলেঃ আমরা কখনও আপনাকে বিশ্বাস করব না, যে পর্যন্ত না আপনি ভূপৃষ্ঠ থেকে আমাদের জন্যে একটি ঝরণা প্রবাহিত করে দিন।\qt@no{(90)}}
\qt@newcmd\qurantrans@bn@mmcxx{অথবা আপনার জন্যে খেজুরের ও আঙ্গুরের একটি বাগান হবে, অতঃপর আপনি তার মধ্যে নির্ঝরিনীসমূহ প্রবাহিত করে দেবেন।\qt@no{(91)}}
\qt@newcmd\qurantrans@bn@mmcxxi{অথবা আপনি যেমন বলে থাকেন, তেমনিভাবে আমাদের উপর আসমানকে খন্ড-বিখন্ড করে ফেলে দেবেন অথবা আল্লাহ ও ফেরেশতাদেরকে আমাদের সামনে নিয়ে আসবেন।\qt@no{(92)}}
\qt@newcmd\qurantrans@bn@mmcxxii{অথবা আপনার কোন সোনার তৈরী গৃহ হবে অথবা আপনি আকাশে আরোহণ করবেন এবং আমরা আপনার আকাশে আরোহণকে কখনও বিশ্বাস করবনা, যে পর্যন্ত না আপনি অবতীর্ণ করেন আমাদের প্রতি এক গ্রন্থ, যা আমরা পাঠ করব। বলুনঃ পবিত্র মহান আমার পালনকর্তা, একজন মানব, একজন রসূল বৈ আমি কে?\qt@no{(93)}}
\qt@newcmd\qurantrans@bn@mmcxxiii{আল্লাহ কি মানুষকে পয়গম্বর করে পাঠিয়েছেন? তাদের এই উক্তিই মানুষকে ঈমান আনয়ন থেকে বিরত রাখে, যখন তাদের নিকট আসে হেদায়েত।\qt@no{(94)}}
\qt@newcmd\qurantrans@bn@mmcxxiv{বলুনঃ যদি পৃথিবীতে ফেরেশতারা স্বচ্ছন্দে বিচরণ করত, তবে আমি আকাশ থেকে কোন ফেরেশতাকেই তাদের নিকট পয়গাম্বর করে প্রেরণ করতাম।\qt@no{(95)}}
\qt@newcmd\qurantrans@bn@mmcxxv{বলুনঃ আমার ও তোমাদের মধ্যে সত্য প্রতিষ্ঠাকারী হিসেবে আল্লাহই যথেষ্ট। তিনি তো স্বীয় বান্দাদের বিষয়ে খবর রাখেন ও দেখেন।\qt@no{(96)}}
\qt@newcmd\qurantrans@bn@mmcxxvi{আল্লাহ যাকে পথ প্রদর্শন করেন, সেই তো সঠিক পথ প্রাপ্ত এবং যাকে পথ ভ্রষ্ট করেন, তাদের জন্যে আপনি আল্লাহ ছাড়া কোন সাহায্যকারী পাবেন না। আমি কেয়ামতের দিন তাদের সমবেত করব তাদের মুখে ভর দিয়ে চলা অবস্থায়, অন্ধ অবস্থায়, মুক অবস্থায় এবং বধির অবস্থায়। তাদের আবাসস্থল জাহান্নাম। যখনই নির্বাপিত হওয়ার উপক্রম হবে আমি তখন তাদের জন্যে অগ্নি আরও বৃদ্ধি করে দিব।\qt@no{(97)}}
\qt@newcmd\qurantrans@bn@mmcxxvii{এটাই তাদের শাস্তি। কারণ, তারা আমার নিদর্শনসমূহ অস্বীকার করেছে এবং বলেছেঃ আমরা যখন অস্থিতে পরিণত ও চুর্ণ-বিচুর্ণ হয়ে যাব, তখনও কি আমরা নতুনভাবে সৃজিত হয়ে উত্থিত হব?\qt@no{(98)}}
\qt@newcmd\qurantrans@bn@mmcxxviii{তারা কি দেখেনি যে, যে আল্লাহ আসমান ও যমিন সৃজিত করেছেন, তিনি তাদের মত মানুষও পুনরায় সৃষ্টি করতে সক্ষম? তিনি তাদের জন্যে স্থির করেছেন একটি নির্দিষ্ট কাল, এতে কোন সন্দেহ নেই; অতঃপর জালেমরা অস্বীকার ছাড়া কিছু করেনি।\qt@no{(99)}}
\qt@newcmd\qurantrans@bn@mmcxxix{বলুনঃ যদি আমার পালনকর্তার রহমতের ভান্ডার তোমাদের হাতে থাকত, তবে ব্যয়িত হয়ে যাওয়ার আশঙ্কায় অবশ্যই তা ধরে রাখতে। মানুষ তো অতিশয় কৃপণ।\qt@no{(100)}}
\qt@newcmd\qurantrans@bn@mmcxxx{আপনি বণী-ইসরাঈলকে জিজ্ঞেস করুন, আমি মূসাকে নয়টি প্রকাশ্য নিদর্শন দান করেছি। যখন তিনি তাদের কাছে আগমন করেন, ফেরাউন তাকে বললঃ হে মূসা, আমার ধারনায় তুমি তো জাদুগ্রস্থ।\qt@no{(101)}}
\qt@newcmd\qurantrans@bn@mmcxxxi{তিনি বললেনঃ তুমি জান যে, আসমান ও যমীনের পালনকর্তাই এসব নিদর্শনাবলী প্রত্যক্ষ প্রমাণস্বরূপ নাযিল করেছেন। হে ফেরাউন, আমার ধারণায় তুমি ধ্বংস হতে চলেছো।\qt@no{(102)}}
\qt@newcmd\qurantrans@bn@mmcxxxii{অতঃপর সে বনী ইসরাঈলকে দেশ থেকে উৎখাত করতে চাইল, তখন আমি তাকে ও তার সঙ্গীদের সবাইকে নিমজ্জত করে দিলাম।\qt@no{(103)}}
\qt@newcmd\qurantrans@bn@mmcxxxiii{তারপর আমি বনী ইসলাঈলকে বললামঃ এ দেশে তোমরা বসবাস কর। অতঃপর যখন পরকালের ওয়াদা বাস্তবায়িত হবে, তখন তোমাদের কে জড়ো করে নিয়ে উপস্থিত হব।\qt@no{(104)}}
\qt@newcmd\qurantrans@bn@mmcxxxiv{আমি সত্যসহ এ কোরআন নাযিল করেছি এবং সত্য সহ এটা নাযিল হয়েছে। আমি তো আপনাকে শুধু সুসংবাদাতা ও ভয়প্রদর্শক করেই প্রেরণ করেছি।\qt@no{(105)}}
\qt@newcmd\qurantrans@bn@mmcxxxv{আমি কোরআনকে যতিচিহ্ন সহ পৃথক পৃথকভাবে পাঠের উপযোগী করেছি, যাতে আপনি একে লোকদের কাছে ধীরে ধীরে পাঠ করেন এবং আমি একে যথাযথ ভাবে অবতীর্ণ করেছি।\qt@no{(106)}}
\qt@newcmd\qurantrans@bn@mmcxxxvi{বলুনঃ তোমরা কোরআনকে মান্য কর অথবা অমান্য কর; যারা এর পূর্ব থেকে এলেম প্রাপ্ত হয়েছে, যখন তাদের কাছে এর তেলাওয়াত করা হয়, তখন তারা নতমস্তকে সেজদায় লুটিয়ে পড়ে।\qt@no{(107)}}
\qt@newcmd\qurantrans@bn@mmcxxxvii{এবং বলেঃ আমাদের পালনকর্তা পবিত্র, মহান। নিঃসন্দেহে আমাদের পালকর্তার ওয়াদা অবশ্যই পূর্ণ হবে।\qt@no{(108)}}
\qt@newcmd\qurantrans@bn@mmcxxxviii{তারা ক্রন্দন করতে করতে নতমস্তকে ভুমিতে লুটিয়ে পড়ে এবং তাদের বিনয়ভাব আরো বৃদ্ধি পায়।\qt@no{(109)}}
\qt@newcmd\qurantrans@bn@mmcxxxix{বলুনঃ আল্লাহ বলে আহবান কর কিংবা রহমান বলে, যে নামেই আহবান কর না কেন, সব সুন্দর নাম তাঁরই। আপনি নিজের নামায আদায়কালে স্বর উচ্চগ্রাসে নিয়ে গিয়ে পড়বেন না এবং নিঃশব্দেও পড়বেন না। এতদুভয়ের মধ্যমপন্থা অবলম্বন করুন।\qt@no{(110)}}
\qt@newcmd\qurantrans@bn@mmcxl{বলুনঃ সমস্ত প্রশংসা আল্লাহর যিনি না কোন সন্তান রাখেন, না তাঁর সার্বভৌমত্বে কোন শরীক আছে এবং যিনি দুর্দশাগ্রস্ত হন না, যে কারণে তাঁর কোন সাহয্যকারীর প্রয়োজন হতে পারে। সুতরাং আপনি স-সম্ভ্রমে তাঁর মাহাত্ন?2476;র্ণনা করতে থাকুন।\qt@no{(111)}}
\qt@newcmd\qurantrans@bn@mmcxli{\basmalahbn সব প্রশংসা আল্লাহর যিনি নিজের বান্দার প্রতি এ গ্রন্থ নাযিল করেছেন এবং তাতে কোন বক্রতা রাখেননি।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmcxlii{একে সুপ্রতিষ্ঠিত করেছেন যা আল্লাহর পক্ষ থেকে একটি ভীষণ বিপদের ভয় প্রদর্শন করে এবং মুমিনদেরকে যারা সৎকর্ম সম্পাদন করে-তাদেরকে সুসংবাদ দান করে যে, তাদের জন্যে উত্তম প্রতিদান রয়েছে।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmcxliii{তারা তাতে চিরকাল অবস্থান করবে।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmcxliv{এবং তাদেরকে ভয় প্রদর্শন করার জন্যে যারা বলে যে, আল্লাহর সন্তান রয়েছে।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmcxlv{এ সম্পর্কে তাদের কোন জ্ঞান নেই এবং তাদের পিতৃপুরুষদেরও নেই। কত কঠিন তাদের মুখের কথা। তারা যা বলে তা তো সবই মিথ্যা।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmcxlvi{যদি তারা এই বিষয়বস্তুর প্রতি বিশ্বাস স্থাপন না করে, তবে তাদের পশ্চাতে সম্ভবতঃ আপনি পরিতাপ করতে করতে নিজের প্রাণ নিপাত করবেন।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmcxlvii{আমি পৃথিবীস্থ সব কিছুকে পৃথিবীর জন্যে শোভা করেছি, যাতে লোকদের পরীক্ষা করি যে, তাদের মধ্যে কে ভাল কাজ করে।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmcxlviii{এবং তার উপর যাকিছু রয়েছে, অবশ্যই তা আমি উদ্ভিদশূন্য মাটিতে পরিণত করে দেব।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmcxlix{আপনি কি ধারণা করেন যে, গুহা ও গর্তের অধিবাসীরা আমার নিদর্শনাবলীর মধ্যে বিস্ময়কর ছিল ?\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmcl{যখন যুবকরা পাহাড়ের গুহায় আশ্রয়গ্রহণ করে তখন দোআ করেঃ হে আমাদের পালনকর্তা, আমাদেরকে নিজের কাছ থেকে রহমত দান করুন এবং আমাদের জন্যে আমাদের কাজ সঠিকভাবে পূর্ণ করুন।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmcli{তখন আমি কয়েক বছরের জন্যে গুহায় তাদের কানের উপর নিদ্রার পর্দা ফেলে দেই।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmclii{অতঃপর আমি তাদেরকে পুনরত্থিত করি, একথা জানার জন্যে যে, দুই দলের মধ্যে কোন দল তাদের অবস্থানকাল সম্পর্কে অধিক নির্ণয় করতে পারে।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmcliii{আপনার কাছে তাদের ইতিবৃত্তান্ত সঠিকভাবে বর্ণনা করছি। তারা ছিল কয়েকজন যুবক। তারা তাদের পালনকর্তার প্রতি বিশ্বাস স্থাপন করেছিল এবং আমি তাদের সৎপথে চলার শক্তি বাড়িয়ে দিয়েছিলাম।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmcliv{আমি তাদের মন দৃঢ় করেছিলাম, যখন তারা উঠে দাঁড়িয়েছিল। অতঃপর তারা বললঃ আমাদের পালনকর্তা আসমান ও যমীনের পালনকর্তা আমরা কখনও তার পরিবর্তে অন্য কোন উপাস্যকে আহবান করব না। যদি করি, তবে তা অত্যন্ত গর্হিত কাজ হবে।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmclv{এরা আমাদেরই স্ব-জাতি, এরা তাঁর পরিবর্তে অনেক উপাস্য গ্রহণ করেছে। তারা এদের সম্পর্কে প্রকাশ্য প্রমাণ উপস্থিত করে না কেন? যে আল্লাহ সম্পর্কে মিথ্যা উদ্ভাবন করে, তার চাইতে অধিক গোনাহগার আর কে?\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmclvi{তোমরা যখন তাদের থেকে পৃথক হলে এবং তারা আল্লাহর পরিবর্তে যাদের এবাদত করে তাদের থেকে, তখন তোমরা গুহায় আশ্রয়গ্রহণ কর। তোমাদের পালনকর্তা তোমাদের জন্যে দয়া বিস্তার করবেন এবং তিনি তোমাদের জন্য তোমাদের কাজ কর্মকে ফলপ্রসু করার ব্যবস্থা করবেন।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmclvii{তুমি সূর্যকে দেখবে, যখন উদিত হয়, তাদের গুহা থেকে পাশ কেটে ডান দিকে চলে যায় এবং যখন অস্ত যায়, তাদের থেকে পাশ কেটে বামদিকে চলে যায়, অথচ তারা গুহার প্রশস্ত চত্বরে অবস্থিত। এটা আল্লাহর নিদর্শনাবলীর অন্যতম। আল্লাহ যাকে সৎপথে চালান, সেই সৎপথ প্রাপ্ত এবং তিনি যাকে পথভ্রষ্ট করেন, আপনি কখনও তার জন্যে পথপ্রদর্শনকারী ও সাহায্যকারী পাবেন না।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmclviii{তুমি মনে করবে তারা জাগ্রত, অথচ তারা নিদ্রিত। আমি তাদেরকে পার্শ্ব পরিবর্তন করাই ডান দিকে ও বাম দিকে। তাদের কুকুর ছিল সামনের পা দুটি গুহাদ্বারে প্রসারিত করে। যদি তুমি উঁকি দিয়ে তাদেরকে দেখতে, তবে পেছন ফিরে পলায়ন করতে এবং তাদের ভয়ে আতংক গ্রস্ত হয়ে পড়তে।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmclix{আমি এমনি ভাবে তাদেরকে জাগ্রত করলাম, যাতে তারা পরস্পর জিজ্ঞাসাবাদ করে। তাদের একজন বললঃ তোমরা কতকাল অবস্থান করেছ? তাদের কেউ বললঃ একদিন অথবা একদিনের কিছু অংশ অবস্থান করছি। কেউ কেউ বললঃ তোমাদের পালনকর্তাই ভাল জানেন তোমরা কতকাল অবস্থান করেছ। এখন তোমাদের একজনকে তোমাদের এই মুদ্রাসহ শহরে প্রেরণ কর; সে যেন দেখে কোন খাদ্য পবিত্র। অতঃপর তা থেকে যেন কিছু খাদ্য নিয়ে আসে তোমাদের জন্য; সে যেন নম্রতা সহকারে যায় ও কিছুতেই যেন তোমাদের খবর কাউকে না জানায়।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmclx{তারা যদি তোমাদের খবর জানতে পারে, তবে পাথর মেরে তোমাদেরকে হত্যা করবে, অথবা তোমাদেরকে তাদের ধর্মে ফিরিয়ে নেবে। তাহলে তোমরা কখনই সাফল্য লাভ করবে না।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmclxi{এমনিভাবে আমি তাদের খবর প্রকাশ করে দিলাম, যাতে তারা জ্ঞাত হয় যে, আল্লাহর ওয়াদা সত্য এবং কেয়ামতে কোন সন্দেহ নেই। যখন তারা নিজেদের কর্তব্য বিষয়ে পরস্পর বিতর্ক করছিল, তখন তারা বললঃ তাদের উপর সৌধ নির্মাণ কর। তাদের পালনকর্তা তাদের বিষয়ে ভাল জানেন। তাদের কর্তব্য বিষয়ে যাদের মত প্রবল হল, তারা বললঃ আমরা অবশ্যই তাদের স্থানে মসজিদ নির্মান করব।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmclxii{অজ্ঞাত বিষয়ে অনুমানের উপর ভিত্তি করে এখন তারা বলবেঃ তারা ছিল তিন জন; তাদের চতুর্থটি তাদের কুকুর। একথাও বলবে; তারা পাঁচ জন। তাদের ছষ্ঠটি ছিল তাদের কুকুর। আরও বলবেঃ তারা ছিল সাত জন। তাদের অষ্টমটি ছিল তাদের কুকুর। বলুনঃ আমার পালনকর্তা তাদের সংখ্যা ভাল জানেন। তাদের খবর অল্প লোকই জানে। সাধারণ আলোচনা ছাড়া আপনি তাদের সম্পর্কে বিতর্ক করবেন না এবং তাদের অবস্থা সম্পর্কে তাদের কাউকে জিজ্ঞাসাবাদ ও করবেন না।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmclxiii{আপনি কোন কাজের বিষয়ে বলবেন না যে, সেটি আমি আগামী কাল করব।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmclxiv{‘আল্লাহ ইচ্ছা করলে’ বলা ব্যতিরেকে। যখন ভুলে যান, তখন আপনার পালনকর্তাকে স্মরণ করুন এবং বলুনঃ আশা করি আমার পালনকর্তা আমাকে এর চাইতেও নিকটতম সত্যের পথ নির্দেশ করবেন।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmclxv{তাদের উপর তাদের গুহায় তিনশ বছর, অতিরিক্ত আরও নয় বছর অতিবাহিত হয়েছে।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmclxvi{বলুনঃ তারা কতকাল অবস্থান করেছে, তা আল্লাহই ভাল জানেন। নভোমন্ডল ও ভুমন্ডলের অদৃশ্য বিষয়ের জ্ঞান তাঁরই কাছে রয়েছে। তিনি কত চমৎকার দেখেন ও শোনেন। তিনি ব্যতীত তাদের জন্য কোন সাহায্যকারী নেই। তিনি কাউকে নিজ কর্তৃত্বে শরীক করেন না।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmclxvii{আপনার প্রতি আপনার পালনকর্তার যে, কিতাব প্রত্যাদিষ্ট করা হয়েছে, তা পাঠ করুন। তাঁর বাক্য পরিবর্তন করার কেউ নাই। তাঁকে ব্যতীত আপনি কখনই কোন আশ্রয় স্থল পাবেন না।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmclxviii{আপনি নিজেকে তাদের সংসর্গে আবদ্ধ রাখুন যারা সকাল ও সন্ধ্যায় তাদের পালনকর্তাকে তাঁর সন্তুষ্টি অর্জনের উদ্দেশ্যে আহবান করে এবং আপনি পার্থিব জীবনের সৌন্দর্য কামনা করে তাদের থেকে নিজের দৃষ্টি ফিরিয়ে নেবেন না। যার মনকে আমার স্মরণ থেকে গাফেল করে দিয়েছি, যে, নিজের প্রবৃত্তির অনুসরণ করে এবং যার কার্য কলাপ হচ্ছে সীমা অতিক্রম করা, আপনি তার অনুগত্য করবেন না।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmclxix{বলুনঃ সত্য তোমাদের পালনকর্তার পক্ষ থেকে আগত। অতএব, যার ইচ্ছা, বিশ্বাস স্থাপন করুক এবং যার ইচ্ছা অমান্য করুক। আমি জালেমদের জন্যে অগ্নি প্রস্তুত করে রেখেছি, যার বেষ্টনী তাদের কে পরিবেষ্টন করে থাকবে। যদি তারা পানীয় প্রার্থনা করে, তবে পুঁজের ন্যায় পানীয় দেয়া হবে যা তাদের মুখমন্ডল দগ্ধ করবে। কত নিকৃষ্ট পানীয় এবং খুবই মন্দ আশ্রয়।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmclxx{যারা বিশ্বাস স্থাপন করে এবং সৎকর্ম সম্পাদন করে আমি সৎকর্মশীলদের পুরস্কার নষ্ট করি না।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmclxxi{তাদেরই জন্যে আছে বসবাসের জান্নাত। তাদের পাদদেশে প্রবাহিত হয় নহরসমূহ। তাদের তথায় স্বর্ণ-কংকনে অলংকৃত করা হবে এবং তারা পাতলা ও মোটা রেশমের সবুজ কাপর পরিধান করবে এমতাবস্থায় যে, তারা সিংহাসনে সমাসীন হবে। চমৎকার প্রতিদান এবং কত উত্তম আশ্রয়।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmclxxii{আপনি তাদের কাছে দু ব্যক্তির উদাহরণ বর্ণনা করুন। আমি তাদের একজনকে দুটি আঙ্গুরের বাগান দিয়েছি এবং এ দু’টিকে খর্জুর বৃক্ষ দ্বারা পরিবেষ্টিত করেছি এবং দু এর মাঝখানে করেছি শস্যক্ষেত্র।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmclxxiii{উভয় বাগানই ফলদান করে এবং তা থেকে কিছুই হ্রাস করত না এবং উভয়ের ফাঁকে ফাঁকে আমি নহর প্রবাহিত করেছি।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmclxxiv{সে ফল পেল। অতঃপর কথা প্রসঙ্গে সঙ্গীকে বললঃ আমার ধন-সম্পদ তোমার চাইতে বেশী এবং জনবলে আমি অধিক শক্তিশালী।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmclxxv{নিজের প্রতি জুলুম করে সে তার বাগানে প্রবেশ করল। সে বললঃ আমার মনে হয় না যে, এ বাগান কখনও ধ্বংস হয়ে যাবে।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmclxxvi{এবং আমি মনে করি না যে, কেয়ামত অনুষ্ঠিত হবে। যদি কখনও আমার পালনকর্তার কাছে আমাকে পৌঁছে দেয়া হয়, তবে সেখানে এর চাইতে উৎকৃষ্ট পাব।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmclxxvii{তার সঙ্গী তাকে কথা প্রসঙ্গে বললঃ তুমি তাঁকে অস্বীকার করছ, যিনি তোমাকে সৃষ্টি করেছেন মাটি থেকে, অতঃপর বীর্য থেকে, অতঃপর র্পূনাঙ্গ করেছেন তোমাকে মানবাকৃতিতে?\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmclxxviii{কিন্তু আমি তো একথাই বলি, আল্লাহই আমার পালনকর্তা এবং আমি কাউকে আমার পালনকর্তার শরীক মানি না।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmclxxix{যদি তুমি আমাকে ধনে ও সন্তানে তোমার চাইতে কম দেখ, তবে যখন তুমি তোমার বাগানে প্রবেশ করলে, তখন একথা কেন বললে না; আল্লাহ যা চান, তাই হয়। আল্লাহর দেয়া ব্যতীত কোন শক্তি নেই।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmclxxx{আশাকরি আমার পালকর্তা আমাকে তোমার বাগান অপেক্ষা উৎকৃষ্টতর কিছু দেবেন এবং তার (তোমার বাগানের) উপর আসমান থেকে আগুন প্রেরণ করবেন। অতঃপর সকাল বেলায় তা পরিষ্কার ময়দান হয়ে যাবে।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmclxxxi{অথবা সকালে তার পানি শুকিয়ে যাবে। অতঃপর তুমি তা তালাশ করে আনতে পারবে না।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmclxxxii{অতঃপর তার সব ফল ধ্বংস হয়ে গেল এবং সে তাতে যা ব্যয় করেছিল, তার জন্য সকালে হাত কচলিয়ে আক্ষেপ করতে লাগল। বাগনটি কাঠসহ পুড়ে গিয়েছিল। সে বলতে লাগলঃ হায়, আমি যদি কাউকে আমার পালনকর্তার সাথে শরীক না করতাম।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmclxxxiii{আল্লাহ ব্যতীত তাকে সাহায্য করার কোন লোক হল না এবং সে নিজেও প্রতিকার করতে পারল না।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmclxxxiv{এরূপ ক্ষেত্রে সব অধিকার সত্য আল্লাহর। তারই পুরস্কার উত্তম এবং তারই প্রদত্ত প্রতিদান শ্রেষ্ঠ।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmclxxxv{তাদের কাছে পার্থিব জীবনের উপমা বর্ণনা করুন। তা পানির ন্যায়, যা আমি আকাশ থেকে নাযিল করি। অতঃপর এর সংমিশ্রণে শ্যামল সবুজ ভূমিজ লতা-পাতা নির্গত হয়; অতঃপর তা এমন শুস্ক চুর্ণ-বিচুর্ণ হয় যে, বাতাসে উড়ে যায়। আল্লাহ এ সবকিছুর উপর শক্তিমান।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmclxxxvi{ধনৈশ্বর্য ও সন্তান-সন্ততি পার্থিব জীবনের সৌন্দর্য এবং স্থায়ী সৎকর্মসমূহ আপনার পালনকর্তার কাছে প্রতিদান প্রাপ্তি ও আশা লাভের জন্যে উত্তম।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmclxxxvii{যেদিন আমি পর্বতসমূহকে পরিচালনা করব এবং আপনি পৃথিবীকে দেখবেন একটি উম্মুক্ত প্রান্তর এবং আমি মানুষকে একত্রিত করব অতঃপর তাদের কাউকে ছাড়ব না।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmclxxxviii{তারা আপনার পালনকর্তার সামনে পেশ হবে সারিবদ্ধ ভাবে এবং বলা হবেঃ তোমরা আমার কাছে এসে গেছ; যেমন তোমাদেরকে প্রথম বার সৃষ্টি করেছিলাম। না, তোমরা তো বলতে যে, আমি তোমাদের জন্যে কোন প্রতিশ্রুত সময় নির্দিষ্ট করব না।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmclxxxix{আর আমলনামা সামনে রাখা হবে। তাতে যা আছে; তার কারণে আপনি অপরাধীদেরকে ভীত-সন্ত্রস্ত দেখবেন। তারা বলবেঃ হায় আফসোস, এ কেমন আমলনামা। এ যে ছোট বড় কোন কিছুই বাদ দেয়নি-সবই এতে রয়েছে। তারা তাদের কৃতকর্মকে সামনে উপস্থিত পাবে। আপনার পালনকর্তা কারও প্রতি জুলুম করবেন না।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmcxc{যখন আমি ফেরেশতাদেরকে বললামঃ আদমকে সেজদা কর, তখন সবাই সেজদা করল ইবলীস ব্যতীত। সে ছিল জিনদের একজন। সে তার পালনকর্তার আদেশ অমান্য করল। অতএব তোমরা কি আমার পরিবর্তে তাকে এবং তার বংশধরকে বন্ধুরূপে গ্রহণ করছ? অথচ তারা তোমাদের শত্রু। এটা জালেমদের জন্যে খুবই নিকৃষ্ট বদল।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmcxci{নভোমন্ডল ও ভুমন্ডলের সৃজনকালে আমি তাদেরকে সাক্ষ্য রাখিনি এবং তাদের নিজেদের সৃজনকালেও না। এবং আমি এমনও নই যে, বিভ্রান্ত কারীদেরকে সাহায্যকারীরূপে গ্রহণ করবো।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmcxcii{যেদিন তিনি বলবেনঃ তোমরা যাদেরকে আমার শরীক মনে করতে তাদেরকে ডাক। তারা তখন তাদেরকে ডাকবে, কিন্তু তারা এ আহবানে সাড়া দেবে না। আমি তাদের মধ্যস্থলে রেখে দেব একটি মৃত্যু গহবর।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmcxciii{অপরাধীরা আগুন দেখে বোঝে নেবে যে, তাদেরকে তাতে পতিত হতে হবে এবং তারা তা থেকে রাস্তা পরিবর্তন করতে পারবে না।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmcxciv{নিশ্চয় আমি এ কোরআনে মানুষকে নানাভাবে বিভিন্ন উপমার দ্বারা আমার বাণী বুঝিয়েছি। মানুষ সব বস্তু থেকে অধিক তর্কপ্রিয়।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmcxcv{হেদায়েত আসার পর এ প্রতীক্ষাই শুধু মানুষকে বিশ্বাস স্থাপন করতে এবং তাদের পালনকর্তার কাছে ক্ষমা প্রার্থনা করতে বিরত রাখে যে, কখন আসবে তাদের কাছে পূর্ববর্তীদের রীতিনীতি অথবা কখন আসবে তাদের কাছেআযাব সামনাসামনি।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mmcxcvi{আমি রাসূলগনকে সুসংবাদ দাতা ও ভয় প্রদর্শন কারীরূপেই প্রেরণ করি এবং কাফেররাই মিথ্যা অবলম্বনে বিতর্ক করে, তা দ্বারা সত্যকে ব্যর্থ করে দেয়ার উদ্দেশে এবং তারা আমার নিদর্শনাবলীও যদ্বারা তাদেরকে ভয় প্রদর্শন করা হয়, সেগুলোকে ঠাট্টারূপে গ্রহণ করেছে।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mmcxcvii{তার চাইতে অধিক জালেম কে, যাকে তার পালনকর্তার কালাম দ্বারা বোঝানো হয়, অতঃপর সে তা থেকে মুখ ফিরিয়ে নেয় এবং তার পূর্ববর্তী কৃতকর্মসমূহ ভুলে যায়? আমি তাদের অন্তরের উপর পর্দা রেখে দিয়েছি, যেন তা না বোঝে এবং তাদের কানে রয়েছে বধিরতার বোঝা। যদি আপনি তাদেরকে সৎপথের প্রতি দাওয়াত দেন, তবে কখনই তারা সৎপথে আসবে না।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mmcxcviii{আপনার পালনকর্তা ক্ষমাশীল, দয়ালু, যদি তিনি তাদেরকে তাদের কৃতকর্মের জন্যে পাকড়াও করেন তবে তাদের শাস্তি ত্বরাম্বিত করতেন, কিন্তু তাদের জন্য রয়েছে একটি প্রতিশ্রুত সময়, যা থেকে তারা সরে যাওয়ার জায়গা পাবে না।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mmcxcix{এসব জনপদও তাদেরকে আমি ধংস করে দিয়েছি, যখন তারা জালেম হয়ে গিয়েছিল এবং আমি তাদের ধ্বংসের জন্যে একটি প্রতিশ্রুত সময় নির্দিষ্ট করেছিলাম।\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mmcc{যখন মূসা তাঁর যুবক (সঙ্গী) কে বললেনঃ দুই সমুদ্রের সঙ্গমস্থলে না পৌছা পর্যন্ত আমি আসব না অথবা আমি যুগ যুগ ধরে চলতে থাকব।\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mmcci{অতঃপর যখন তাঁরা দুই সুমুদ্রের সঙ্গমস্থলে পৌছালেন, তখন তাঁরা নিজেদের মাছের কথা ভুলে গেলেন। অতঃপর মাছটি সমুদ্রে সুড়ঙ্গ পথ সৃষ্টি করে নেমে গেল।\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mmccii{যখন তাঁরা সে স্থানটি অতিক্রম করে গেলেন, মূসা সঙ্গী কে বললেনঃ আমাদের নাশতা আন। আমরা এই সফরে পরিশ্রান্ত হয়ে পড়েছি।\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mmcciii{সে বললঃ আপনি কি লক্ষ্য করেছেন, আমরা যখন প্রস্তর খন্ডে আশ্রয় নিয়েছিলাম, তখন আমি মাছের কথা ভুলে গিয়েছিলাম। শয়তানই আমাকে একথা স্মরণ রাখতে ভুলিয়ে দিয়েছিল। মাছটি আশ্চর্য জনক ভাবে সমুদ্রে নিজের পথ করে নিয়েছে।\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mmcciv{মূসা বললেনঃ আমরা তো এ স্থানটিই খুঁজছিলাম। অতঃপর তাঁরা নিজেদের চিহ্ন ধরে ফিরে চললেন।\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mmccv{অতঃপর তাঁরা আমার বান্দাদের মধ্যে এমন একজনের সাক্ষাত পেলেন, যাকে আমি আমার পক্ষ থেকে রহমত দান করেছিলাম ও আমার পক্ষ থেকে দিয়েছিলাম এক বিশেষ জ্ঞান।\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mmccvi{মূসা তাঁকে বললেনঃ আমি কি এ শর্তে আপনার অনুসরণ করতে পারি যে, সত্যপথের যে জ্ঞান আপনাকে শেখানো হয়েছে, তা থেকে আমাকে কিছু শিক্ষা দেবেন?\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mmccvii{তিনি বললেনঃ আপনি আমার সাথে কিছুতেই ধৈর্য্যধারণ করে থাকতে পারবেন না।\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mmccviii{যে বিষয় বোঝা আপনার আয়ত্তাধীন নয়, তা দেখে আপনি ধৈর্য্যধারণ করবেন কেমন করে?\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mmccix{মূসা বললেনঃ আল্লাহ চাহেন তো আপনি আমাকে ধৈর্য্যশীল পাবেন এবং আমি আপনার কোন আদেশ অমান্য করব না।\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mmccx{তিনি বললেনঃ যদি আপনি আমার অনুসরণ করেনই তবে কোন বিষয়ে আমাকে প্রশ্ন করবেন না, যে পর্যন্ত না আমি নিজেই সে সম্পর্কে আপনাকে কিছু বলি।\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@mmccxi{অতঃপর তারা চলতে লাগলঃ অবশেষে যখন তারা নৌকায় আরোহণ করল, তখন তিনি তাতে ছিদ্র করে দিলেন। মূসা বললেনঃ আপনি কি এর আরোহীদেরকে ডুবিয়ে দেয়ার জন্যে এতে ছিদ্র করে দিলেন? নিশ্চয়ই আপনি একটি গুরুতর মন্দ কাজ করলেন।\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@mmccxii{তিনি বললেনঃ আমি কি বলিনি যে, আপনি আমার সাথে কিছুতেই ধৈর্য্য ধরতে পারবেন না ?\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@mmccxiii{মূসা বললেনঃ আমাকে আমার ভুলের জন্যে অপরাধী করবেন না এবং আমার কাজে আমার উপর কঠোরতা আরোপ করবেন না।\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@mmccxiv{অতঃপর তারা চলতে লাগল। অবশেষে যখন একটি বালকের সাক্ষাত পেলেন, তখন তিনি তাকে হত্যা করলেন। মূসা বললেন? আপনি কি একটি নিস্পাপ জীবন শেষ করে দিলেন প্রাণের বিনিময় ছাড়াই? নিশ্চয়ই আপনি তো এক গুরুতর অন্যায় কাজ করলেন।\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@mmccxv{তিনি বললেনঃ আমি কি বলিনি যে, আপনি আমার সাথে ধৈর্য্য ধরে থাকতে পারবেন না।\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@mmccxvi{মূসা বললেনঃ এরপর যদি আমি আপনাকে কোন বিষয়ে প্রশ্ন করি, তবে আপনি আমাকে সাথে রাখবেন না। আপনি আমার পক্ষ থেকে অভিযোগ মুক্ত হয়ে গেছেন।\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@mmccxvii{অতঃপর তারা চলতে লাগল, অবশেষে যখন একটি জনপদের অধিবাসীদের কাছে পৌছে তাদের কাছে খাবার চাইল, তখন তারা তাদের অতিথেয়তা করতে অস্বীকার করল। অতঃপর তারা সেখানে একটি পতনোম্মুখ প্রাচীর দেখতে পেলেন, সেটি তিনি সোজা করে দাঁড় করিয়ে দিলেন। মূসা বললেনঃ আপনি ইচ্ছা করলে তাদের কাছ থেকে এর পারিশ্রমিক আদায় করতে পারতেন।\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@mmccxviii{তিনি বললেনঃ এখানেই আমার ও আপনার মধ্যে সম্পর্কচ্ছেদ হল। এখন যে বিষয়ে আপনি ধৈর্য্য ধরতে পারেননি, আমি তার তাৎপর্য বলে দিচ্ছি।\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@mmccxix{নৌকাটির ব্যাপারে-সেটি ছিল কয়েকজন দরিদ্র ব্যক্তির। তারা সমুদ্রে জীবিকা অন্বেষন করত। আমি ইচ্ছা করলাম যে, সেটিকে ক্রটিযুক্ত করে দেই। তাদের অপরদিকে ছিল এক বাদশাহ। সে বলপ্রয়োগে প্রত্যেকটি নৌকা ছিনিয়ে নিত।\qt@no{(79)}}
\qt@newcmd\qurantrans@bn@mmccxx{বালকটির ব্যাপার তার পিতা-মাতা ছিল ঈমানদার। আমি আশঙ্কা করলাম যে, সে অবাধ্যতা ও কুফর দ্বারা তাদেরকে প্রভাবিত করবে।\qt@no{(80)}}
\qt@newcmd\qurantrans@bn@mmccxxi{অতঃপর আমি ইচ্ছা করলাম যে, তাদের পালনকর্তা তাদেরকে মহত্তর, তার চাইতে পবিত্রতায় ও ভালবাসায় ঘনিষ্ঠতর একটি শ্রেষ্ঠ সন্তান দান করুক।\qt@no{(81)}}
\qt@newcmd\qurantrans@bn@mmccxxii{প্রাচীরের ব্যাপার-সেটি ছিল নগরের দুজন পিতৃহীন বালকের। এর নীচে ছিল তাদের গুপ্তধন এবং তাদের পিতা ছিল সৎকর্ম পরায়ন। সুতরাং আপনার পালনকর্তা দায়বশতঃ ইচ্ছা করলেন যে, তারা যৌবনে পদার্পন করুক এবং নিজেদের গুপ্তধন উদ্ধার করুক। আমি নিজ মতে এটা করিনি। আপনি যে বিষয়ে ধৈর্য্যধারণ করতে অক্ষম হয়েছিলেন, এই হল তার ব্যাখ্যা।\qt@no{(82)}}
\qt@newcmd\qurantrans@bn@mmccxxiii{তারা আপনাকে যুলকারনাইন সম্পর্কে জিজ্ঞাসা করে। বলুনঃ আমি তোমাদের কাছে তাঁর কিছু অবস্থা বর্ণনা করব।\qt@no{(83)}}
\qt@newcmd\qurantrans@bn@mmccxxiv{আমি তাকে পৃথিবীতে প্রতিষ্ঠিত করেছিলাম এবং প্রত্যেক বিষয়ের কার্যোপকরণ দান করেছিলাম।\qt@no{(84)}}
\qt@newcmd\qurantrans@bn@mmccxxv{অতঃপর তিনি এক কার্যোপকরণ অবলম্বন করলেন।\qt@no{(85)}}
\qt@newcmd\qurantrans@bn@mmccxxvi{অবশেষে তিনি যখন সুর্যের অস্তাচলে পৌছলেন; তখন তিনি সুর্যকে এক পঙ্কিল জলাশয়ে অস্ত যেতে দেখলেন এবং তিনি সেখানে এক সম্প্রদায়কে দেখতে পেলেন। আমি বললাম, হে যুলকারনাইন! আপনি তাদেরকে শাস্তি দিতে পারেন অথবা তাদেরকে সদয়ভাবে গ্রহণ করতে পারেন।\qt@no{(86)}}
\qt@newcmd\qurantrans@bn@mmccxxvii{তিনি বললেনঃ যে কেউ সীমালঙ্ঘনকারী হবে আমি তাকে শাস্তি দেব। অতঃপর তিনি তাঁর পালনকর্তার কাছে ফিরে যাবেন। তিনি তাকে কঠোর শাস্তি দেবেন।\qt@no{(87)}}
\qt@newcmd\qurantrans@bn@mmccxxviii{এবং যে বিশ্বাস স্থাপন করে ও সৎকর্ম করে তার জন্য প্রতিদান রয়েছে কল্যাণ এবং আমার কাজে তাকে সহজ নির্দেশ দেব।\qt@no{(88)}}
\qt@newcmd\qurantrans@bn@mmccxxix{অতঃপর তিনি এক উপায় অবলম্বন করলেন।\qt@no{(89)}}
\qt@newcmd\qurantrans@bn@mmccxxx{অবশেষে তিনি যখন সূর্যের উদয়াচলে পৌছলেন, তখন তিনি তাকে এমন এক সম্প্রদায়ের উপর উদয় হতে দেখলেন, যাদের জন্যে সূর্যতাপ থেকে আত্নরক্ষার কোন আড়াল আমি সৃষ্টি করিনি।\qt@no{(90)}}
\qt@newcmd\qurantrans@bn@mmccxxxi{প্রকৃত ঘটনা এমনিই। তার বৃত্তান্ত আমি সম্যক অবগত আছি।\qt@no{(91)}}
\qt@newcmd\qurantrans@bn@mmccxxxii{আবার তিনি এক পথ ধরলেন।\qt@no{(92)}}
\qt@newcmd\qurantrans@bn@mmccxxxiii{অবশেষে যখন তিনি দুই পর্বত প্রচীরের মধ্যস্থলে পৌছলেন, তখন তিনি সেখানে এক জাতিকে পেলেন, যারা তাঁর কথা একেবারেই বুঝতে পারছিল না।\qt@no{(93)}}
\qt@newcmd\qurantrans@bn@mmccxxxiv{তারা বললঃ হে যুলকারনাইন, ইয়াজুজ ও মাজুজ দেশে অশান্তি সৃষ্টি করেছে। আপনি বললে আমরা আপনার জন্যে কিছু কর ধার্য করব এই শর্তে যে, আপনি আমাদের ও তাদের মধ্যে একটি প্রাচীর নির্মাণ করে দেবেন।\qt@no{(94)}}
\qt@newcmd\qurantrans@bn@mmccxxxv{তিনি বললেনঃ আমার পালনকর্তা আমাকে যে সামর্থ?2470;িয়েছেন, তাই যথেষ্ট। অতএব, তোমরা আমাকে শ্রম দিয়ে সাহায্য কর। আমি তোমাদের ও তাদের মধ্যে একটি সুদৃঢ় প্রাচীর নির্মাণ করে দেব।\qt@no{(95)}}
\qt@newcmd\qurantrans@bn@mmccxxxvi{তোমরা আমাকে লোহার পাত এনে দাও। অবশেষে যখন পাহাড়ের মধ্যবর্তী ফাঁকা স্থান পূর্ণ হয়ে গেল, তখন তিনি বললেনঃ তোমরা হাঁপরে দম দিতে থাক। অবশেষে যখন তা আগুনে পরিণত হল, তখন তিনি বললেনঃ তোমরা গলিত তামা নিয়ে এস, আমি তা এর উপরে ঢেলে দেই।\qt@no{(96)}}
\qt@newcmd\qurantrans@bn@mmccxxxvii{অতঃপর ইয়াজুজ ও মাজুজ তার উপরে আরোহণ করতে পারল না এবং তা ভেদ করতে ও সক্ষম হল না।\qt@no{(97)}}
\qt@newcmd\qurantrans@bn@mmccxxxviii{যুলকারনাইন বললেনঃ এটা আমার পালনকর্তার অনুগ্রহ। যখন আমার পালনকর্তার প্রতিশ্রুত সময় আসবে, তখন তিনি একে চূর্ণ-বিচূর্ণ করে দেবেন এবং আমার পালনকর্তার প্রতিশ্রুতি সত্য।\qt@no{(98)}}
\qt@newcmd\qurantrans@bn@mmccxxxix{আমি সেদিন তাদেরকে দলে দলে তরঙ্গের আকারে ছেড়ে দেব এবং শিঙ্গায় ফুঁৎকার দেয়া হবে। অতঃপর আমি তাদের সবাইকে একত্রিত করে আনব।\qt@no{(99)}}
\qt@newcmd\qurantrans@bn@mmccxl{সেদিন আমি কাফেরদের কাছে জাহান্নামকে প্রত্যক্ষ ভাবে উপস্থিত করব।\qt@no{(100)}}
\qt@newcmd\qurantrans@bn@mmccxli{যাদের চক্ষুসমূহের উপর পর্দা ছিল আমার স্মরণ থেকে এবং যারা শুনতেও সক্ষম ছিল না।\qt@no{(101)}}
\qt@newcmd\qurantrans@bn@mmccxlii{কাফেররা কি মনে করে যে, তারা আমার পরিবর্তে আমার বান্দাদেরকে অভিভাবক রূপে গ্রহণ করবে? আমি কাফেরদের অভ্যর্থনার জন্যে জাহান্নামকে প্রস্তুত করে রেখেছি।\qt@no{(102)}}
\qt@newcmd\qurantrans@bn@mmccxliii{বলুনঃ আমি কি তোমাদেরকে সেসব লোকের সংবাদ দেব, যারা কর্মের দিক দিয়ে খুবই ক্ষতিগ্রস্ত।\qt@no{(103)}}
\qt@newcmd\qurantrans@bn@mmccxliv{তারাই সে লোক, যাদের প্রচেষ্টা পার্থিবজীবনে বিভ্রান্ত হয়, অথচ তারা মনে করে যে, তারা সৎকর্ম করেছে।\qt@no{(104)}}
\qt@newcmd\qurantrans@bn@mmccxlv{তারাই সে লোক, যারা তাদের পালনকর্তার নিদর্শনাবলী এবং তাঁর সাথে সাক্ষাতের বিষয় অস্বীকার করে। ফলে তাদের কর্ম নিষ্ফল হয়ে যায়। সুতরাং কেয়ামতের দিন তাদের জন্য আমি কোন গুরুত্ব স্থির করব না।\qt@no{(105)}}
\qt@newcmd\qurantrans@bn@mmccxlvi{জাহান্নাম-এটাই তাদের প্রতিফল; কারণ, তারা কাফের হয়েছে এবং আমার নিদর্শনাবলী ও রসূলগণকে বিদ্রূপের বিষয় রূপে গ্রহণ করেছে।\qt@no{(106)}}
\qt@newcmd\qurantrans@bn@mmccxlvii{যারা বিশ্বাস স্থাপন করে ও সৎকর্ম সম্পাদন করে, তাদের অভ্যর্থনার জন্যে আছে জান্নাতুল ফেরদাউস।\qt@no{(107)}}
\qt@newcmd\qurantrans@bn@mmccxlviii{সেখানে তারা চিরকাল থাকবে, সেখান থেকে স্থান পরিবর্তন করতে চাইবে না।\qt@no{(108)}}
\qt@newcmd\qurantrans@bn@mmccxlix{বলুনঃ আমার পালনকর্তার কথা, লেখার জন্যে যদি সমুদ্রের পানি কালি হয়, তবে আমার পালনকর্তার কথা, শেষ হওয়ার আগেই সে সমুদ্র নিঃশেষিত হয়ে যাবে। সাহায্যার্থে অনুরূপ আরেকটি সমুদ্র এনে দিলেও।\qt@no{(109)}}
\qt@newcmd\qurantrans@bn@mmccl{বলুনঃ আমি ও তোমাদের মতই একজন মানুষ, আমার প্রতি প্রত্যাদেশ হয় যে, তোমাদের ইলাহই একমাত্র ইলাহ। অতএব, যে ব্যক্তি তার পালনকর্তার সাক্ষাত কামনা করে, সে যেন, সৎকর্ম সম্পাদন করে এবং তার পালনকর্তার এবাদতে কাউকে শরীক না করে।\qt@no{(110)}}
\qt@newcmd\qurantrans@bn@mmccli{\basmalahbn কাফ-হা-ইয়া-আইন-সাদ\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmcclii{এটা আপনার পালনকর্তার অনুগ্রহের বিবরণ তাঁর বান্দা যাকারিয়ার প্রতি।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmccliii{যখন সে তাঁর পালনকর্তাকে আহবান করেছিল নিভৃতে।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmccliv{সে বললঃ হে আমার পালনকর্তা আমার অস্থি বয়স-ভারাবনত হয়েছে; বার্ধক্যে মস্তক সুশুভ্র হয়েছে; হে আমার পালনকর্তা! আপনাকে ডেকে আমি কখনও বিফলমনোরথ হইনি।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmcclv{আমি ভয় করি আমার পর আমার স্বগোত্রকে এবং আমার স্ত্রী বন্ধ্যা; কাজেই আপনি নিজের পক্ষ থেকে আমাকে এক জন কর্তব্য পালনকারী দান করুন।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmcclvi{সে আমার স্থলাভিষিক্ত হবে ইয়াকুব বংশের এবং হে আমার পালনকর্তা, তাকে করুন সন্তোষজনক।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmcclvii{হে যাকারিয়া, আমি তোমাকে এক পুত্রের সুসংবাদ দিচ্ছি, তার নাম হবে ইয়াহইয়া। ইতিপূর্বে এই নামে আমি কারও নাম করণ করিনি।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmcclviii{সে বললঃ হে আমার পালনকর্তা কেমন করে আমার পুত্র হবে অথচ আমার স্ত্রী যে বন্ধ্যা, আর আমিও যে বার্ধক্যের শেষ প্রান্তে উপনীত।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmcclix{তিনি বললেনঃ এমনিতেই হবে। তোমার পালনকর্তা বলে দিয়েছেনঃ এটা আমার পক্ষে সহজ। আমি তো পুর্বে তোমাকে সৃষ্টি করেছি এবং তুমি কিছুই ছিলে না।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmcclx{সে বললঃ হে আমার পালনকর্তা, আমাকে একটি নির্দশন দিন। তিনি বললেন তোমার নিদর্শন এই যে, তুমি সুস্থ অবস্থায় তিন দিন মানুষের সাথে কথাবার্তা বলবে না।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmcclxi{অতঃপর সে কক্ষ থেকে বের হয়ে তার সম্প্রদায়ের কাছে এল এবং ইঙ্গিতে তাদেরকে সকাল সন্ধ্যায় আল্লাহকে স্মরণ করতে বললঃ\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmcclxii{হে ইয়াহইয়া দৃঢ়তার সাথে এই গ্রন্থ ধারণ কর। আমি তাকে শৈশবেই বিচারবুদ্ধি দান করেছিলাম।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmcclxiii{এবং নিজের পক্ষ থেকে আগ্রহ ও পবিত্রতা দিয়েছি। সে ছিল পরহেযগার।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmcclxiv{পিতা-মাতার অনুগত এবং সে উদ্ধত, নাফরমান ছিল না।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmcclxv{তার প্রতি শান্তি-যেদিন সে জন্মগ্রহণ করে এবং যেদিন মৃত্যুবরণ করবে এবং যেদিন জীবিতাবস্থায় পুনরুত্থিত হবে।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmcclxvi{এই কিতাবে মারইয়ামের কথা বর্ণনা করুন, যখন সে তার পরিবারের লোকজন থেকে পৃথক হয়ে পূর্বদিকে এক স্থানে আশ্রয় নিল।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmcclxvii{অতঃপর তাদের থেকে নিজেকে আড়াল করার জন্যে সে পর্দা করলো। অতঃপর আমি তার কাছে আমার রূহ প্রেরণ করলাম, সে তার নিকট পুর্ণ মানবাকৃতিতে আত্নপ্রকাশ করল।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmcclxviii{মারইয়াম বললঃ আমি তোমা থেকে দয়াময়ের আশ্রয় প্রার্থনা করি যদি তুমি আল্লাহভীরু হও।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmcclxix{সে বললঃ আমি তো শুধু তোমার পালনকর্তা প্রেরিত, যাতে তোমাকে এক পবিত্র পুত্র দান করে যাব।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmcclxx{মরিইয়াম বললঃ কিরূপে আমার পুত্র হবে, যখন কোন মানব আমাকে স্পর্শ করেনি এবং আমি ব্যভিচারিণীও কখনও ছিলাম না ?\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmcclxxi{সে বললঃ এমনিতেই হবে। তোমার পালনকর্তা বলেছেন, এটা আমার জন্যে সহজ সাধ্য এবং আমি তাকে মানুষের জন্যে একটি নিদর্শন ও আমার পক্ষ থেকে অনুগ্রহ স্বরূপ করতে চাই। এটা তো এক স্থিরীকৃত ব্যাপার।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmcclxxii{অতঃপর তিনি গর্ভে সন্তান ধারণ করলেন এবং তৎসহ এক দূরবর্তী স্থানে চলে গেলেন।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmcclxxiii{প্রসব বেদনা তাঁকে এক খেজুর বৃক্ষ-মূলে আশ্রয় নিতে বাধ্য করল। তিনি বললেনঃ হায়, আমি যদি কোনরূপে এর পূর্বে মরে যেতাম এবং মানুষের স্মৃতি থেকে বিলুপ্ত হয়ে, যেতাম!\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmcclxxiv{অতঃপর ফেরেশতা তাকে নিম্নদিক থেকে আওয়ায দিলেন যে, তুমি দুঃখ করো না। তোমার পালনকর্তা তোমার পায়ের তলায় একটি নহর জারি করেছেন।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmcclxxv{আর তুমি নিজের দিকে খেজুর গাছের কান্ডে নাড়া দাও, তা থেকে তোমার উপর সুপক্ক খেজুর পতিত হবে।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmcclxxvi{যখন আহার কর, পান কর এবং চক্ষু শীতল কর। যদি মানুষের মধ্যে কাউকে তুমি দেখ, তবে বলে দিওঃ আমি আল্লাহর উদ্দেশে রোযা মানত করছি। সুতরাং আজ আমি কিছুতেই কোন মানুষের সাথে কথা বলব না।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmcclxxvii{অতঃপর তিনি সন্তানকে নিয়ে তার সম্প্রদায়ের কাছে উপস্থিত হলেন। তারা বললঃ হে মারইয়াম, তুমি একটি অঘটন ঘটিয়ে বসেছ।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmcclxxviii{হে হারূণ-ভাগিনী, তোমার পিতা অসৎ ব্যক্তি ছিলেন না এবং তোমার মাতাও ছিল না ব্যভিচারিনী।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmcclxxix{অতঃপর তিনি হাতে সন্তানের দিকে ইঙ্গিত করলেন। তারা বললঃ যে কোলের শিশু তার সাথে আমরা কেমন করে কথা বলব?\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmcclxxx{সন্তান বললঃ আমি তো আল্লাহর দাস। তিনি আমাকে কিতাব দিয়েছেন এবং আমাকে নবী করেছেন।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmcclxxxi{আমি যেখানেই থাকি, তিনি আমাকে বরকতময় করেছেন। তিনি আমাকে নির্দেশ দিয়েছেন, যতদিন জীবিত থাকি, ততদিন নামায ও যাকাত আদায় করতে।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmcclxxxii{এবং জননীর অনুগত থাকতে এবং আমাকে তিনি উদ্ধত ও হতভাগ্য করেননি।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmcclxxxiii{আমার প্রতি সালাম যেদিন আমি জন্মগ্রহণ করেছি, যেদিন মৃত্যুবরণ করব এবং যেদিন পুনরুজ্জীবিত হয়ে উত্থিত হব।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmcclxxxiv{এই মারইয়ামের পুত্র ঈসা। সত্যকথা, যে সম্পর্কে লোকেরা বিতর্ক করে।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmcclxxxv{আল্লাহ এমন নন যে, সন্তান গ্রহণ করবেন, তিনি পবিত্র ও মহিমাময় সত্তা, তিনি যখন কোন কাজ করা সিদ্ধান্ত করেন, তখন একথাই বলেনঃ হও এবং তা হয়ে যায়।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmcclxxxvi{তিনি আরও বললেনঃ নিশ্চয় আল্লাহ আমার পালনকর্তা ও তোমাদের পালনকর্তা। অতএব, তোমরা তার এবাদত কর। এটা সরল পথ।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmcclxxxvii{অতঃপর তাদের মধ্যে দলগুলো পৃথক পৃথক পথ অবলম্বন করল। সুতরাং মহাদিবস আগমনকালে কাফেরদের জন্যে ধবংস।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmcclxxxviii{সেদিন তারা কি চমৎকার শুনবে এবং দেখবে, যেদিন তারা আমার কাছে আগমন করবে। কিন্তু আজ জালেমরা প্রকাশ্য বিভ্রান্তিতে রয়েছে।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmcclxxxix{আপনি তাদেরকে পরিতাপের দিবস সম্পর্কে হুশিয়ার করে দিন যখন সব ব্যাপারের মীমাংসা হয়ে যাবে। এখন তারা অনবধানতায় আছে এবং তারা বিশ্বাস স্থাপন করছে না।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmccxc{আমিই চুড়ান্ত মালিকানার অধিকারী হব পৃথিবীর এবং তার উপর যারা আছে তাদের এবং আমারই কাছে তারা প্রত্যাবর্তিত হবে।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmccxci{আপনি এই কিতাবে ইব্রাহীমের কথা বর্ণনা করুন। নিশ্চয় তিনি ছিলেন সত্যবাদী, নবী।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmccxcii{যখন তিনি তার পিতাকে বললেনঃ হে আমার পিতা, যে শোনে না, দেখে না এবং তোমার কোন উপকারে আসে না, তার এবাদত কেন কর?\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmccxciii{হে আমার পিতা, আমার কাছে এমন জ্ঞান এসেছে; যা তোমার কাছে আসেনি, সুতরাং আমার অনুসরণ কর, আমি তোমাকে সরল পথ দেখাব।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmccxciv{হে আমার পিতা, শয়তানের এবাদত করো না। নিশ্চয় শয়তান দয়াময়ের অবাধ্য।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmccxcv{হে আমার পিতা, আমি আশঙ্কা করি, দয়াময়ের একটি আযাব তোমাকে স্পর্শ করবে, অতঃপর তুমি শয়তানের সঙ্গী হয়ে যাবে।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmccxcvi{পিতা বললঃ যে ইব্রাহীম, তুমি কি আমার উপাস্যদের থেকে মুখ ফিরিয়ে নিচ্ছ? যদি তুমি বিরত না হও, আমি অবশ্যই প্রস্তরাঘাতে তোমার প্রাণনাশ করব। তুমি চিরতরে আমার কাছ থেকে দূর হয়ে যাও।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmccxcvii{ইব্রাহীম বললেনঃ তোমার উপর শান্তি হোক, আমি আমার পালনকর্তার কাছে তোমার জন্যে ক্ষমা প্রার্থনা করব। নিশ্চয় তিনি আমার প্রতি মেহেরবান।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmccxcviii{আমি পরিত্যাগ করছি তোমাদেরকে এবং তোমরা আল্লাহ ব্যতীত যাদের এবাদত কর তাদেরকে; আমি আমার পালনকর্তার এবাদত করব। আশা করি, আমার পালনকর্তার এবাদত করে আমি বঞ্চিত হব না।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmccxcix{অতঃপর তিনি যখন তাদেরকে এবং তার আল্লাহ ব্যতীত যাদের এবাদত করত, তাদের সবাইকে পরিত্যাগ করলেন, তখন আমি তাকে দান করলাম ইসহাক ও ইয়াকুব এবং প্রত্যেককে নবী করলাম।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmccc{আমি তাদেরকে দান করলাম আমার অনুগ্রহ এবং তাদেরকে দিলাম সমুচ্চ সুখ্যাতি।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmccci{এই কিতাবে মূসার কথা বর্ণনা করুন, তিনি ছিলেন মনোনীত এবং তিনি ছিলেন রাসূল, নবী।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmcccii{আমি তাকে আহবান করলাম তূর পাহাড়ের ডান দিক থেকে এবং গুঢ়তত্ত্ব আলোচনার উদ্দেশে তাকে নিকটবর্তী করলাম।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmccciii{আমি নিজ অনুগ্রহে তাঁকে দান করলাম তাঁর ভাই হারুনকে নবীরূপে।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmccciv{এই কিতাবে ইসমাঈলের কথা বর্ণনা করুন, তিনি প্রতিশ্রুতি পালনে সত্যাশ্রয়ী এবং তিনি ছিলেন রসূল, নবী।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmcccv{তিনি তাঁর পরিবারবর্গকে নামায ও যাকাত আদায়ের নির্দেশ দিতেন এবং তিনি তাঁর পালনকর্তার কাছে পছন্দনীয় ছিলেন।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mmcccvi{এই কিতাবে ইদ্রীসের কথা আলোচনা করুন, তিনি ছিলেন সত্যবাদী নবী।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mmcccvii{আমি তাকে উচ্চে উন্নীত করেছিলাম।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mmcccviii{এরাই তারা-নবীগণের মধ্য থেকে যাদেরকে আল্লাহ তা’আলা নেয়ামত দান করেছেন। এরা আদমের বংশধর এবং যাদেরকে আমি নূহের সাথে নৌকায় আরোহন করিয়েছিলাম, তাদের বংশধর, এবং ইব্রাহীম ও ইসরাঈলের বংশধর এবং যাদেরকে আমি পথ প্রদর্শন করেছি ও মনোনীত করেছি, তাদের বংশোদ্ভূত। তাদের কাছে যখন দয়াময় আল্লাহর আয়াতসমূহ পাঠ করা হত, তখন তারা সেজদায় লুটিয়ে পড়ত এবং ক্রন্দন করত।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mmcccix{অতঃপর তাদের পরে এল অপদার্থ পরবর্তীরা। তারা নামায নষ্ট করল এবং কুপ্রবৃত্তির অনুবর্তী হল। সুতরাং তারা অচিরেই পথভ্রষ্টতা প্রত্যক্ষ করবে।\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mmcccx{কিন্তু তারা ব্যতীত, যারা তওবা করেছে, বিশ্বাস স্থাপন করেছে। সুতরাং তারা জান্নাতে প্রবেশ করবে এবং তাদের উপর কোন জুলুম করা হবে না।\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mmcccxi{তাদের স্থায়ী বসবাস হবে যার ওয়াদা দয়াময় আল্লাহ তাঁর বান্দাদেরকে অদৃশ্যভাবে দিয়েছেন। অবশ্যই তাঁর ওয়াদার তারা পৌঁছাবে।\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mmcccxii{তারা সেখানে সালাম ব্যতীত কোন অসার কথাবার্তা শুনবে না এবং সেখানে সকাল-সন্ধ্যা তাদের জন্যে রুযী থাকবে।\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mmcccxiii{এটা ঐ জান্নাত যার অধিকারী করব আমার বান্দাদের মধ্যে পরহেযগারদেরকে।\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mmcccxiv{(জিব্রাইল বললঃ) আমি আপনার পালনকর্তার আদেশ ব্যতীত অবতরণ করি না, যা আমাদের সামনে আছে, যা আমাদের পশ্চাতে আছে এবং যা এ দুই-এর মধ্যস্থলে আছে, সবই তাঁর এবং আপনার পালনকর্তা বিস্মৃত হওয়ার নন।\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mmcccxv{তিনি নভোমন্ডল, ভূমন্ডলে এতদুভয়ের মধ্যবর্তী সবার পালনকর্তা। সুতরাং তাঁরই বন্দেগী করুন এবং তাতে দৃঢ় থাকুন আপনি কি তাঁর সমনাম কাউকে জানেন?\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mmcccxvi{মানুষ বলেঃ আমার মৃত্যু হলে পর আমি কি জীবিত অবস্থায় পুনরুত্থিত হব?\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mmcccxvii{মানুষ কি স্মরণ করে না যে, আমি তাকে ইতি পূর্বে সৃষ্টি করেছি এবং সে তখন কিছুই ছিল না।\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mmcccxviii{সুতরাং আপনার পালনকর্তার কসম, আমি অবশ্যই তাদেরকে এবং শয়তানদেরকে একত্রে সমবেত করব, অতঃপর অবশ্যই তাদেরকে নতজানু অবস্থায় জাহান্নামের চারপাশে উপস্থিত করব।\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mmcccxix{অতঃপর প্রত্যেক সম্প্রদায়ের মধ্যে যে দয়াময় আল্লাহর সর্বাধিক অবাধ্য আমি অবশ্যই তাকে পৃথক করে নেব।\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mmcccxx{অতঃপর তাদের মধ্যে যারা জাহান্নামে প্রবেশের অধিক যোগ্য, আমি তাদের বিষয়ে ভালোভাবে জ্ঞাত আছি।\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@mmcccxxi{তোমাদের মধ্যে এমন কেউ নেই যে তথায় পৌছবে না। এটা আপনার পালনকর্তার অনিবার্য ফায়সালা।\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@mmcccxxii{অতঃপর আমি পরহেযগারদেরকে উদ্ধার করব এবং জালেমদেরকে সেখানে নতজানু অবস্থায় ছেড়ে দেব।\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@mmcccxxiii{যখন তাদের কাছে আমার সুস্পষ্ট আয়াতসমূহ তেলাওয়াত করা হয়, তখন কাফেররা মুমিনদেরকে বলেঃ দুই দলের মধ্যে কোনটি মর্তবায় শ্রেষ্ঠ এবং কার মজলিস উত্তম?\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@mmcccxxiv{তাদের পূর্বে কত মানব গোষ্ঠীকে আমি বিনাশ করেছি, তারা তাদের চাইতে সম্পদে ও জাঁক-জমকে শ্রেষ্ঠ ছিল।\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@mmcccxxv{বলুন, যারা পথভ্রষ্টতায় আছে, দয়াময় আল্লাহ তাদেরকে যথেষ্ট অবকাশ দেবেন; এমনকি অবশেষে তারা প্রত্যক্ষ করবে যে বিষয়ে তাদেরকে ওয়াদা দেয়া হচ্ছে, তা আযাব হোক অথবা কেয়ামতই হোক। সুতরাং তখন তারা জানতে পারবে কে মর্তবায় নিকৃষ্ট ও দলবলে দূর্বল।\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@mmcccxxvi{যারা সৎপথে চলে আল্লাহ তাদের পথপ্রাপ্তি বৃদ্ধি করেন এবং স্থায়ী সৎকর্মসমূহ তোমার পালনকর্তার কাছে সওয়াবের দিক দিয়ে শ্রেষ্ঠ এবং প্রতিদান হিসেবেও শ্রেষ্ট।\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@mmcccxxvii{আপনি কি তাকে লক্ষ্য করেছেন যে, আমার নিদর্শনাবলীতে বিশ্বাস করে না এবং বলেঃ আমাকে অর্থ-সম্পদ ও সন্তান-সন্ততি অবশ্যই দেয়া হবে।\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@mmcccxxviii{সে কি অদৃশ্য বিষয় জেনে ফেলেছে, অথবা দয়াময় আল্লাহর নিকট থেকে কোন প্রতিশ্রুতি প্রাপ্ত হয়েছে?\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@mmcccxxix{না, এটা ঠিক নয়। সে যা বলে আমি তা লিখে রাখব এবং তার শাস্তি দীর্ঘায়িত করতে থাকব।\qt@no{(79)}}
\qt@newcmd\qurantrans@bn@mmcccxxx{সে যা বলে, মৃত্যুর পর আমি তা নিয়ে নেব এবং সে আমার কাছে আসবে একাকী।\qt@no{(80)}}
\qt@newcmd\qurantrans@bn@mmcccxxxi{তারা আল্লাহ ব্যতীত অন্যান্য ইলাহ গ্রহণ করেছে, যাতে তারা তাদের জন্যে সাহায্যকারী হয়।\qt@no{(81)}}
\qt@newcmd\qurantrans@bn@mmcccxxxii{কখনই নয়, তারা তাদের এবাদত অস্বীকার করবে এবং তাদের বিপক্ষে চলে যাবে।\qt@no{(82)}}
\qt@newcmd\qurantrans@bn@mmcccxxxiii{আপনি কি লক্ষ্য করেননি যে, আমি কাফেরদের উপর শয়তানদেরকে ছেড়ে দিয়েছি। তারা তাদেরকে বিশেষভাবে (মন্দকর্মে) উৎসাহিত করে।\qt@no{(83)}}
\qt@newcmd\qurantrans@bn@mmcccxxxiv{সুতরাং তাদের ব্যাপারে আপনি তাড়াহুড়া করবেন না। আমি তো তাদের গণনা পূর্ণ করছি মাত্র।\qt@no{(84)}}
\qt@newcmd\qurantrans@bn@mmcccxxxv{সেদিন দয়াময়ের কাছে পরহেযগারদেরকে অতিথিরূপে সমবেত করব,\qt@no{(85)}}
\qt@newcmd\qurantrans@bn@mmcccxxxvi{এবং অপরাধীদেরকে পিপাসার্ত অবস্থায় জাহান্নামের দিকে হাঁকিয়ে নিয়ে যাব।\qt@no{(86)}}
\qt@newcmd\qurantrans@bn@mmcccxxxvii{যে দয়াময় আল্লাহর কাছ থেকে প্রতিশ্রুতি গ্রহণ করেছে, সে ব্যতীত আর কেউ সুপারিশ করার অধিকারী হবে না।\qt@no{(87)}}
\qt@newcmd\qurantrans@bn@mmcccxxxviii{তারা বলেঃ দয়াময় আল্লাহ সন্তান গ্রহণ করেছেন।\qt@no{(88)}}
\qt@newcmd\qurantrans@bn@mmcccxxxix{নিশ্চয় তোমরা তো এক অদ্ভুত কান্ড করেছ।\qt@no{(89)}}
\qt@newcmd\qurantrans@bn@mmcccxl{হয় তো এর কারণেই এখনই নভোমন্ডল ফেটে পড়বে, পৃথিবী খন্ড-বিখন্ড হবে এবং পর্বতমালা চূর্ণ-বিচুর্ণ হবে।\qt@no{(90)}}
\qt@newcmd\qurantrans@bn@mmcccxli{এ কারণে যে, তারা দয়াময় আল্লাহর জন্যে সন্তান আহবান করে।\qt@no{(91)}}
\qt@newcmd\qurantrans@bn@mmcccxlii{অথচ সন্তান গ্রহণ করা দয়াময়ের জন্য শোভনীয় নয়।\qt@no{(92)}}
\qt@newcmd\qurantrans@bn@mmcccxliii{নভোমন্ডল ও ভূ-মন্ডলে কেউ নেই যে, দয়াময় আল্লাহর কাছে দাস হয়ে উপস্থিত হবে না।\qt@no{(93)}}
\qt@newcmd\qurantrans@bn@mmcccxliv{তাঁর কাছে তাদের পরিসংখ্যান রয়েছে এবং তিনি তাদেরকে গণনা করে রেখেছেন।\qt@no{(94)}}
\qt@newcmd\qurantrans@bn@mmcccxlv{কেয়ামতের দিন তাদের সবাই তাঁর কাছে একাকী অবস্থায় আসবে।\qt@no{(95)}}
\qt@newcmd\qurantrans@bn@mmcccxlvi{যারা বিশ্বাস স্থাপন করে এবং সৎকর্ম সম্পাদন করে, তাদেরকে দয়াময় আল্লাহ ভালবাসা দেবেন।\qt@no{(96)}}
\qt@newcmd\qurantrans@bn@mmcccxlvii{আমি কোরআনকে আপনার ভাষায় সহজ করে দিয়েছি, যাতে আপনি এর দ্বারা পরহেযগারদেরকে সুসংবাদ দেন এবং কলহকারী সম্প্রদায়কে সতর্ক করেন।\qt@no{(97)}}
\qt@newcmd\qurantrans@bn@mmcccxlviii{তাদের পূর্বে আমি কত মানবগোষ্ঠীকে ধ্বংস করেছি। আপনি কি তাদের কাহারও সাড়া পান, অথবা তাদের ক্ষীনতম আওয়ায ও শুনতে পান?\qt@no{(98)}}
\qt@newcmd\qurantrans@bn@mmcccxlix{\basmalahbn তোয়া-হা\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmcccl{আপনাকে ক্লেশ দেবার জন্য আমি আপনার প্রতি কোরআন অবতীর্ণ করিনি।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmcccli{কিন্তু তাদেরই উপদেশের জন্য যারা ভয় করে।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmccclii{এটা তাঁর কাছ থেকে অবতীর্ণ, যিনি ভূমন্ডল ও সমুচ্চ নভোমন্ডল সৃষ্টি করেছেন।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmcccliii{তিনি পরম দয়াময়, আরশে সমাসীন হয়েছেন।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmcccliv{নভোমন্ডলে, ভুমন্ডলে, এতদুভয়ের মধ্যবর্তী স্থানে এবং সিক্ত ভূগর্ভে যা আছে, তা তাঁরই।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmccclv{যদি তুমি উচ্চকন্ঠেও কথা বল, তিনি তো গুপ্ত ও তদপেক্ষাও গুপ্ত বিষয়বস্তু জানেন।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmccclvi{আল্লাহ তিনি ব্যতীত কোন উপাস্য ইলাহ নেই। সব সৌন্দর্যমন্ডিত নাম তাঁরই।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmccclvii{আপনার কাছে মূসার বৃত্তান্ত পৌঁছেছে কি।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmccclviii{তিনি যখন আগুন দেখলেন, তখন পরিবারবর্গকে বললেনঃ তোমরা এখানে অবস্থান কর আমি আগুন দেখেছি। সম্ভবতঃ আমি তা থেকে তোমাদের কাছে কিছু আগুন জালিয়ে আনতে পারব অথবা আগুনে পৌছে পথের সন্ধান পাব।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmccclix{অতঃপর যখন তিনি আগুনের কাছে পৌছলেন, তখন আওয়াজ আসল হে মূসা,\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmccclx{আমিই তোমার পালনকর্তা, অতএব তুমি জুতা খুলে ফেল, তুমি পবিত্র উপত্যকা তুয়ায় রয়েছ।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmccclxi{এবং আমি তোমাকে মনোনীত করেছি, অতএব যা প্রত্যাদেশ করা হচ্ছে, তা শুনতে থাক।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmccclxii{আমিই আল্লাহ আমি ব্যতীত কোন ইলাহ নেই। অতএব আমার এবাদত কর এবং আমার স্মরণার্থে নামায কায়েম কর।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmccclxiii{কেয়ামত অবশ্যই আসবে, আমি তা গোপন রাখতে চাই; যাতে প্রত্যেকেই তার কর্মানুযায়ী ফল লাভ করে।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmccclxiv{সুতরাং যে ব্যক্তি কেয়ামতে বিশ্বাস রাখে না এবং নিজ খাহেশের অনুসরণ করে, সে যেন তোমাকে তা থেকে নিবৃত্ত না করে। নিবৃত্ত হলে তুমি ধবংস হয়ে যাবে।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmccclxv{হে মূসা, তোমার ডানহাতে ওটা কি?\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmccclxvi{তিনি বললেনঃ এটা আমার লাঠি, আমি এর উপর ভর দেই এবং এর দ্বারা আমার ছাগপালের জন্যে বৃক্ষপত্র ঝেড়ে ফেলি এবং এতে আমার অন্যান্য কাজ ও চলে।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmccclxvii{আল্লাহ বললেনঃ হে মূসা, তুমি ওটা নিক্ষেপ কর।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmccclxviii{অতঃপর তিনি তা নিক্ষেপ করলেন, অমনি তা সাপ হয়ে ছুটাছুটি করতে লাগল।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmccclxix{আল্লাহ বললেনঃ তুমি তাকে ধর এবং ভয় করো না, আমি এখনি একে পূর্বাবস্থায় ফিরিয়ে দেব।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmccclxx{তোমার হাত বগলে রাখ, তা বের হয়ে আসবে নির্মল উজ্জ্বল হয়ে অন্য এক নিদর্শন রূপে; কোন দোষ ছাড়াই।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmccclxxi{এটা এজন্যে যে, আমি আমার বিরাট নিদর্শনাবলীর কিছু তোমাকে দেখাই।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmccclxxii{ফেরাউনের নিকট যাও, সে দারুণ উদ্ধত হয়ে গেছে।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmccclxxiii{মূসা বললেনঃ হে আমার পালনকর্তা আমার বক্ষ প্রশস্ত করে দিন।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmccclxxiv{এবং আমার কাজ সহজ করে দিন।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmccclxxv{এবং আমার জিহবা থেকে জড়তা দূর করে দিন।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmccclxxvi{যাতে তারা আমার কথা বুঝতে পারে।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmccclxxvii{এবং আমার পরিবারবর্গের মধ্য থেকে আমার একজন সাহায্যকারী করে দিন।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmccclxxviii{আমার ভাই হারুনকে।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmccclxxix{তার মাধ্যমে আমার কোমর মজবুত করুন।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmccclxxx{এবং তাকে আমার কাজে অংশীদার করুন।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmccclxxxi{যাতে আমরা বেশী করে আপনার পবিত্রতা ও মহিমা ঘোষনা করতে পারি।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmccclxxxii{এবং বেশী পরিমাণে আপনাকে স্মরণ করতে পারি।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmccclxxxiii{আপনি তো আমাদের অবস্থা সবই দেখছেন।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmccclxxxiv{আল্লাহ বললেনঃ হে মূসা, তুমি যা চেয়েছ তা তোমাকে দেয়া হল।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmccclxxxv{আমি তোমার প্রতি আরও একবার অনুগ্রহ করেছিলাম।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmccclxxxvi{যখন আমি তোমার মাতাকে নির্দেশ দিয়েছিলাম যা অতঃপর বর্ণিত হচ্ছে।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmccclxxxvii{যে, তুমি (মূসাকে) সিন্দুকে রাখ, অতঃপর তা দরিয়ায় ভাসিয়ে দাও, অতঃপর দরিয়া তাকে তীরে ঠেলে দেবে। তাকে আমার শক্র ও তার শক্র উঠিয়ে নেবে। আমি তোমার প্রতি মহব্বত সঞ্চারিত করেছিলাম আমার নিজের পক্ষ থেকে, যাতে তুমি আমার দৃষ্টির সামনে প্রতি পালিত হও।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmccclxxxviii{যখন তোমার ভগিনী এসে বললঃ আমি কি তোমাদেরকে বলে দেব কে তাকে লালন পালন করবে। অতঃপর আমি তোমাকে তোমার মাতার কাছে ফিরিয়ে দিলাম, যাতে তার চক্ষু শীতল হয় এবং দুঃখ না পায়। তুমি এক ব্যক্তিকে হত্যা করেছিলে, অতঃপর আমি তোমাকে এই দুশ্চিন্তা থেকে মুক্তি দেই; আমি তোমাকে অনেক পরীক্ষা করেছি। অতঃপর তুমি কয়েক বছর মাদইয়ান বাসীদের মধ্যে অবস্থান করেছিলে; হে মূসা, অতঃপর তুমি নির্ধারিত সময়ে এসেছ।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmccclxxxix{এবং আমি তোমাকে আমার নিজের জন্য তৈরী করে নিয়েছি।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmcccxc{তুমি ও তোমার ভাই আমার নিদর্শনাবলীসহ যাও এবং আমার স্মরণে শৈথিল্য করো না।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmcccxci{তোমরা উভয়ে ফেরআউনের কাছে যাও সে খুব উদ্ধত হয়ে গেছে।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmcccxcii{অতঃপর তোমরা তাকে নম্র কথা বল, হয়তো সে চিন্তা-ভাবনা করবে অথবা ভীত হবে।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmcccxciii{তারা বললঃ হে আমাদের পালনকর্তা, আমরা আশঙ্কা করি যে, সে আমাদের প্রতি জুলুম করবে কিংবা উত্তেজিত হয়ে উঠবে।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmcccxciv{আল্লাহ বললেনঃ তোমরা ভয় করো না, আমি তোমাদের সাথে আছি, আমি শুনি ও দেখি।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmcccxcv{অতএব তোমরা তার কাছে যাও এবং বলঃ আমরা উভয়েই তোমার পালনকর্তার প্রেরিত রসূল, অতএব আমাদের সাথে বনী ইসরাঈলকে যেতে দাও এবং তাদেরকে নিপীড়ন করো না। আমরা তোমার পালনকর্তার কাছ থেকে নিদর্শন নিয়ে তোমার কাছে আগমন করেছি। এবং যে সৎপথ অনুসরণ করে, তার প্রতি শান্তি।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmcccxcvi{আমরা ওহী লাভ করেছি যে, যে ব্যক্তি মিথ্যারোপ করে এবং মুখ ফিরিয়ে নেয়, তার উপর আযাব পড়বে।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmcccxcvii{সে বললঃ তবে হে মূসা, তোমাদের পালনকর্তা কে?\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmcccxcviii{মূসা বললেনঃ আমাদের পালনকর্তা তিনি, যিনি প্রত্যেক বস্তুকে তার যোগ্য আকৃতি দান করেছেন, অতঃপর পথপ্রদর্শন করেছেন।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmcccxcix{ফেরাউন বললঃ তাহলে অতীত যুগের লোকদের অবস্থা কি?\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmcd{মূসা বললেনঃ তাদের খবর আমার পালনকর্তার কাছে লিখিত আছে। আমার পালনকর্তা ভ্রান্ত হন না এং বিস্মৃতও হন না।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmcdi{তিনি তোমাদের জন্যে পৃথিবীকে শয্যা করেছেন এবং তাতে চলার পথ করেছেন, আকাশ থেকে বৃষ্টি বর্ষণ করেছেন এবং তা দ্বারা আমি বিভিন্ন প্রকার উদ্ভিদ উৎপন্ন করেছি।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmcdii{তোমরা আহার কর এবং তোমাদের চতুস্পদ জন্তু চরাও। নিশ্চয় এতে বিবেক বানদের জন্যে নিদর্শন রয়েছে।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmcdiii{এ মাটি থেকেই আমি তোমাদেরকে সৃজন করেছি, এতেই তোমাদেরকে ফিরিয়ে দিব এবং পুনরায় এ থেকেই আমি তোমাদেরকে উত্থিত করব।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mmcdiv{আমি ফেরাউনকে আমার সব নিদর্শন দেখিয়ে দিয়েছি, অতঃপর সে মিথ্যা আরোপ করেছে এবং অমান্য করেছে।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mmcdv{সে বললঃ হে মূসা, তুমি কি যাদুর জোরে আমাদেরকে দেশ থেকে বহিষ্কার করার জন্যে আগমন করেছ?\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mmcdvi{অতএব, আমরাও তোমার মোকাবেলায় তোমার নিকট অনুরূপ যাদু উপস্থিত করব। সুতরাং আমাদের ও তোমার মধ্যে একটি ওয়াদার দিন ঠিক কর, যার খেলাফ আমরাও করব না এবং তুমিও করবে না একটি পরিষ্কার প্রান্তরে।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mmcdvii{মূসা বললঃ তোমাদের ওয়াদার দিন উৎসবের দিন এবং পূর্বাহেߠলোকজন সমবেত হবে।\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mmcdviii{অতঃপর ফেরাউন প্রস্থান করল এবং তার সব কলাকৌশল জমা করল অতঃপর উপস্থিত হল।\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mmcdix{মূসা (আঃ) তাদেরকে বললেনঃ দুর্ভাগ্য তোমাদের; তোমরা আল্লাহর প্রতি মিথ্যা আরোপ করো না। তাহলে তিনি তোমাদেরকে আযাব দ্বারা ধবংস করে দেবেন। যে মিথ্যা উদভাবন করে, সেই বিফল মনোরথ হয়েছে।\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mmcdx{অতঃপর তারা তাদের কাজে নিজেদের মধ্যে বিতর্ক করল এবং গোপনে পরামর্শ করল।\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mmcdxi{তারা বললঃ এই দুইজন নিশ্চিতই যাদুকর, তারা তাদের যাদু দ্বারা তোমাদেরকে তোমাদের দেশ থেকে বহিস্কার করতে চায় এবং তোমাদের উৎকৃষ্ট জীবন ব্যবস্থা রহিত করতে চায়।\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mmcdxii{অতএব, তোমরা তোমাদের কলাকৌশল সুসংহত কর, অতঃপর সারিবদ্ধ হয়ে আস। আজ যে জয়ী হবে, সেই সফলকাম হবে।\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mmcdxiii{তারা বললঃ হে মূসা, হয় তুমি নিক্ষেপ কর, না হয় আমরা প্রথমে নিক্ষেপ করি।\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mmcdxiv{মূসা বললেনঃ বরং তোমরাই নিক্ষেপ কর। তাদের যাদুর প্রভাবে হঠাৎ তাঁর মনে হল, যেন তাদের রশিগুলো ও লাঠিগুলো চুটাছুটি করছে।\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mmcdxv{অতঃপর মূসা মনে মনে কিছুটা ভীতি অনুভব করলেন।\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mmcdxvi{আমি বললামঃ ভয় করো না, তুমি বিজয়ী হবে।\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mmcdxvii{তোমার ডান হাতে যা আছে তুমি তা নিক্ষেপ কর। এটা যা কিছু তারা করেছে তা গ্রাস করে ফেলবে। তারা যা করেছে তা তো কেবল যাদুকরের কলাকৌশল। যাদুকর যেখানেই থাকুক, সফল হবে না।\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mmcdxviii{অতঃপর যাদুকররা সেজদায় পড়ে গেল। তারা বললঃ আমরা হারুন ও মূসার পালনকর্তার প্রতি বিশ্বাস স্থাপন করলাম।\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@mmcdxix{ফেরাউন বললঃ আমার অনুমতি দানের পূর্বেই? তোমরা কি তার প্রতি বিশ্বাস স্থাপন করলে; দেখছি সেই তোমাদের প্রধান, সে তোমাদেরকে যাদু শিক্ষা দিয়েছে। অতএব আমি অবশ্যই তোমাদের হস্তপদ বিপরীত দিক থেকে কর্তন করব এবং আমি তোমাদেরকে খর্জুর বৃক্ষের কান্ডে শূলে চড়াব এবং তোমরা নিশ্চিত রূপেই জানতে পারবে আমাদের মধ্যে কার আযাব কঠোরতর এবং অধিক্ষণ স্থায়ী।\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@mmcdxx{যাদুকররা বললঃ আমাদের কাছে যে, সুস্পষ্ট প্রমাণ এসেছে তার উপর এবং যিনি আমাদের কে সৃষ্টি করেছেন, তাঁর উপর আমরা কিছুতেই তোমাকে প্রাধান্য দেব না। অতএব, তুমি যা ইচ্ছা করতে পার। তুমি তো শুধু এই পার্থিব জীবনেই যা করার করবে।\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@mmcdxxi{আমরা আমাদের পালনকর্তার প্রতি বিশ্বাস স্থাপন করেছি যাতে তিনি আমাদের পাপ এবং তুমি আমাদেরকে যে যাদু করতে বাধ্য করেছ, তা মার্জনা করেন। আল্লাহ শ্রেষ্ঠ ও চিরস্থায়ী।\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@mmcdxxii{নিশ্চয়ই যে তার পালনকর্তার কাছে অপরাধী হয়ে আসে, তার জন্য রয়েছে জাহান্নাম। সেখানে সে মরবে না এবং বাঁচবেও না।\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@mmcdxxiii{আর যারা তাঁর কাছে আসে এমন ঈমানদার হয়ে যায় সৎকর্ম সম্পাদন করেছে, তাদের জন্যে রয়েছে সুউচ্চ মর্তবা।\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@mmcdxxiv{বসবাসের এমন পুষ্পোদ্যান রয়েছে যার তলদেশে দিয়ে নির্ঝরিণীসমূহ প্রবাহিত হয়। সেখানে তারা চিরকাল থাকবে এটা তাদেরই পুরস্কার, যারা পবিত্র হয়।\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@mmcdxxv{আমি মূসা প্রতি এই মর্মে ওহী করলাম যে, আমার বান্দাদেরকে নিয়ে রাত্রিযোগে বের হয়ে যাও এবং তাদের জন্যে সমুদ্রে শুষ্কপথ নির্মাণ কর। পেছন থেকে এসে তোমাদের ধরে ফেলার আশঙ্কা করো না এবং পানিতে ডুবে যাওয়ার ভয় করো না।\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@mmcdxxvi{অতঃপর ফেরাউন তার সৈন্যবাহিনী নিয়ে তাদের পশ্চাদ্ধাবন করল এবং সমুদ্র তাদেরকে সম্পূর্ণরূপে নিমজ্জত করল।\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@mmcdxxvii{ফেরআউন তার সম্প্রদায়কে বিভ্রান্ত করেছিল এবং সৎপথ দেখায়নি।\qt@no{(79)}}
\qt@newcmd\qurantrans@bn@mmcdxxviii{হে বনী-ইসরাঈল! আমি তোমাদেরকে তোমাদের শক্রুর কবল থেকে উদ্ধার করেছি, তুর পাহাড়ের দক্ষিণ পার্শ্বে তোমাদেরকে প্রতিশ্রুতি দান করেছি এবং তোমাদের কাছে ‘মান্না’ ও ‘সালওয়া’ নাযিল করেছি।\qt@no{(80)}}
\qt@newcmd\qurantrans@bn@mmcdxxix{বলেছিঃ আমার দেয়া পবিত্র বস্তুসমূহ খাও এবং এতে সীমালংঘন করো না, তা হলে তোমাদের উপর আমার ক্রোধ নেমে আসবে এবং যার উপর আমার ক্রোধ নেমে আসে সে ধবংস হয়ে যায়।\qt@no{(81)}}
\qt@newcmd\qurantrans@bn@mmcdxxx{আর যে তওবা করে, ঈমান আনে এবং সৎকর্ম করে অতঃপর সৎপথে অটল থাকে, আমি তার প্রতি অবশ্যই ক্ষমাশীল।\qt@no{(82)}}
\qt@newcmd\qurantrans@bn@mmcdxxxi{হে মূসা, তোমার সম্প্রদায়কে পেছনে ফেলে তুমি ত্বরা করলে কেন?\qt@no{(83)}}
\qt@newcmd\qurantrans@bn@mmcdxxxii{তিনি বললেনঃ এই তো তারা আমার পেছনে আসছে এবং হে আমার পালনকর্তা, আমি তাড়াতাড়ি তোমার কাছে এলাম, যাতে তুমি সন্তুষ্ট হও।\qt@no{(84)}}
\qt@newcmd\qurantrans@bn@mmcdxxxiii{বললেনঃ আমি তোমার সম্প্রদায়কে পরীক্ষা করেছি তোমার পর এবং সামেরী তাদেরকে পথভ্রষ্ট করেছে।\qt@no{(85)}}
\qt@newcmd\qurantrans@bn@mmcdxxxiv{অতঃপর মূসা তাঁর সম্প্রদায়ের কাছে ফিরে গেলেন ক্রদ্ধ ও অনুতপ্ত অবস্থায়। তিনি বললেনঃ হে আমার সম্প্রদায়, তোমাদের পালনকর্তা কি তোমাদেরকে একটি উত্তম প্রতিশ্রুতি দেননি? তবে কি প্রতিশ্রুতির সময়কাল তোমাদের কাছে দীর্ঘ হয়েছে, না তোমরা চেয়েছ যে, তোমাদের উপর তোমাদের পালনকর্তার ক্রোধ নেমে আসুক, যে কারণে তোমরা আমার সাথে কৃত ওয়াদা ভঙ্গ করলে?\qt@no{(86)}}
\qt@newcmd\qurantrans@bn@mmcdxxxv{তারা বললঃ আমরা তোমার সাথে কৃত ওয়াদা স্বেচ্ছায় ভঙ্গ করিনি; কিন্তু আমাদের উপর ফেরউনীদের অলংকারের বোঝা চাপিয়ে দেয়া হয়েছিল। অতঃপর আমরা তা নিক্ষেপ করে দিয়েছি। এমনি ভাবে সামেরীও নিক্ষেপ করেছে।\qt@no{(87)}}
\qt@newcmd\qurantrans@bn@mmcdxxxvi{অতঃপর সে তাদের জন্য তৈরী করে বের করল একটি গো-বৎস, একটা দেহ, যার মধ্যে গরুর শব্দ ছিল। তারা বললঃ এটা তোমাদের উপাস্য এবং মূসার ও উপাস্য, অতঃপর মূসা ভুলে গেছে।\qt@no{(88)}}
\qt@newcmd\qurantrans@bn@mmcdxxxvii{তারা কি দেখে না যে, এটা তাদের কোন কথার উত্তর দেয় না এবং তারে কোন ক্ষতি ও উপকার করার ক্ষমতাও রাখে না?\qt@no{(89)}}
\qt@newcmd\qurantrans@bn@mmcdxxxviii{হারুন তাদেরকে পুর্বেই বলেছিলেনঃ হে আমার কওম, তোমরা তো এই গো-বৎস দ্বারা পরীক্ষায় নিপতিত হয়েছ এবং তোমাদের পালনকর্তা দয়াময়। অতএব, তোমরা আমার অনুসরণ কর এবং আমার আদেশ মেনে চল।\qt@no{(90)}}
\qt@newcmd\qurantrans@bn@mmcdxxxix{তারা বললঃ মূসা আমাদের কাছে ফিরে আসা পর্যন্ত আমরা সদাসর্বদা এর সাথেই সংযুক্ত হয়ে বসে থাকব।\qt@no{(91)}}
\qt@newcmd\qurantrans@bn@mmcdxl{মূসা বললেনঃ হে হারুন, তুমি যখন তাদেরকে পথ ভ্রষ্ট হতে দেখলে, তখন তোমাকে কিসে নিবৃত্ত করল ?\qt@no{(92)}}
\qt@newcmd\qurantrans@bn@mmcdxli{আমার পদাঙ্ক অনুসরণ করা থেকে? তবে তুমি কি আমার আদেশ অমান্য করেছ?\qt@no{(93)}}
\qt@newcmd\qurantrans@bn@mmcdxlii{তিনি বললেনঃ হে আমার জননী-তনয়, আমার শ্মশ্রু ও মাথার চুল ধরে আকর্ষণ করো না; আমি আশঙ্কা করলাম যে, তুমি বলবেঃ তুমি বনী-ইসরাঈলের মধ্যে বিভেদ সৃষ্টি করেছ এবং আমার কথা স্মরণে রাখনি।\qt@no{(94)}}
\qt@newcmd\qurantrans@bn@mmcdxliii{মূসা বললেন হে সামেরী, এখন তোমার ব্যাপার কি?\qt@no{(95)}}
\qt@newcmd\qurantrans@bn@mmcdxliv{সে বললঃ আমি দেখলাম যা অন্যেরা দেখেনি। অতঃপর আমি সেই প্রেরিত ব্যক্তির পদচিহ্নের নীচ থেকে এক মুঠি মাটি নিয়ে নিলাম। অতঃপর আমি তা নিক্ষেপ করলাম। আমাকে আমার মন এই মন্ত্রণাই দিল।\qt@no{(96)}}
\qt@newcmd\qurantrans@bn@mmcdxlv{মূসা বললেনঃ দূর হ, তোর জন্য সারা জীবন এ শাস্তিই রইল যে, তুই বলবি; আমাকে স্পর্শ করো না, এবং তোর জন্য একটি নির্দিষ্ট ওয়াদা আছে, যার ব্যতিক্রম হবে না। তুই তোর সেই ইলাহের প্রতি লক্ষ্য কর, যাকে তুই ঘিরে থাকতি। আমরা সেটি জালিয়ে দেবই। অতঃপর একে বিক্ষিপ্ত করে সাগরে ছড়িয়ে দেবই।\qt@no{(97)}}
\qt@newcmd\qurantrans@bn@mmcdxlvi{তোমাদের ইলাহ তো কেবল আল্লাহই, যিনি ব্যতীত অন্য কোন ইলাহ নেই। সব বিষয় তাঁর জ্ঞানের পরিধিভুক্ত।\qt@no{(98)}}
\qt@newcmd\qurantrans@bn@mmcdxlvii{এমনিভাবে আমি পূর্বে যা ঘটেছে, তার সংবাদ আপনার কাছে বর্ণনা করি। আমি আমার কাছ থেকে আপনাকে দান করেছি পড়ার গ্রন্থ।\qt@no{(99)}}
\qt@newcmd\qurantrans@bn@mmcdxlviii{যে এ থেকে মুখ ফিরিয়ে নেবে, সে কেয়ামতের দিন বোঝা বহন করবে।\qt@no{(100)}}
\qt@newcmd\qurantrans@bn@mmcdxlix{তারা তাতে চিরকাল থাকবে এবং কেয়ামতের দিন এই বোঝা তাদের জন্যে মন্দ হবে।\qt@no{(101)}}
\qt@newcmd\qurantrans@bn@mmcdl{যেদিন সিঙ্গায় ফূৎকার দেয়া হবে, সেদিন আমি অপরাধীদেরকে সমবেত করব নীল চক্ষু অবস্থায়।\qt@no{(102)}}
\qt@newcmd\qurantrans@bn@mmcdli{তারা চুপিসারে পরস্পরে বলাবলি করবেঃ তোমরা মাত্র দশ দিন অবস্থান করেছিলে।\qt@no{(103)}}
\qt@newcmd\qurantrans@bn@mmcdlii{তারা কি বলে তা আমি ভালোভাবে জানি। তাদের মধ্যে যে, অপেক্ষাকৃত উত্তম পথের অনুসারী সে বলবেঃ তোমরা মাত্র একদিন অবস্থান করেছিলে।\qt@no{(104)}}
\qt@newcmd\qurantrans@bn@mmcdliii{তারা আপনাকে পাহাড় সম্পর্কে প্রশ্ন করা। অতএব, আপনি বলুনঃ আমার পালনকর্তা পহাড়সমূহকে সমূলে উৎপাটন করে বিক্ষিপ্ত করে দিবেন।\qt@no{(105)}}
\qt@newcmd\qurantrans@bn@mmcdliv{অতঃপর পৃথিবীকে মসৃণ সমতলভূমি করে ছাড়বেন।\qt@no{(106)}}
\qt@newcmd\qurantrans@bn@mmcdlv{তুমি তাতে মোড় ও টিলা দেখবে না।\qt@no{(107)}}
\qt@newcmd\qurantrans@bn@mmcdlvi{সেই দিন তারা আহবানকারীর অনুসরণ করবে, যার কথা এদিক-সেদিক হবে না এবং দয়াময় আল্লাহর ভয়ে সব শব্দ ক্ষীণ হয়ে যাবে। সুতরাং মৃদু গুঞ্জন ব্যতীত তুমি কিছুই শুনবে না।\qt@no{(108)}}
\qt@newcmd\qurantrans@bn@mmcdlvii{দয়াময় আল্লাহ যাকে অনুমতি দেবেন এবং যার কথায় সন্তুষ্ট হবেন সে ছাড়া কারও সুপারিশ সেদিন কোন উপকারে আসবে না।\qt@no{(109)}}
\qt@newcmd\qurantrans@bn@mmcdlviii{তিনি জানেন যা কিছু তাদের সামনে ও পশ্চাতে আছে এবং তারা তাকে জ্ঞান দ্বারা আয়ত্ত করতে পারে না।\qt@no{(110)}}
\qt@newcmd\qurantrans@bn@mmcdlix{সেই চিরঞ্জীব চিরস্থায়ীর সামনে সব মুখমন্ডল অবনমিত হবে এবং সে ব্যর্থ হবে যে জুলুমের বোঝা বহন করবে।\qt@no{(111)}}
\qt@newcmd\qurantrans@bn@mmcdlx{যে ঈমানদার অবস্থায় সৎকর্ম সম্পাদন করে, সে জুলুম ও ক্ষতির আশঙ্কা করবে না।\qt@no{(112)}}
\qt@newcmd\qurantrans@bn@mmcdlxi{এমনিভাবে আমি আরবী ভাষায় কোরআন নাযিল করেছি এবং এতে নানাভাবে সতর্কবাণী ব্যক্ত করেছি, যাতে তারা আল্লাহভীরু হয় অথবা তাদের অন্তরে চিন্তার খোরাক যোগায়।\qt@no{(113)}}
\qt@newcmd\qurantrans@bn@mmcdlxii{সত্যিকার অধীশ্বর আল্লাহ মহান। আপনার প্রতি আল্লাহর ওহী সম্পুর্ণ হওয়ার পূর্বে আপনি কোরআন গ্রহণের ব্যপারে তাড়াহুড়া করবেন না এবং বলুনঃ হে আমার পালনকর্তা, আমার জ্ঞান বৃদ্ধি করুন।\qt@no{(114)}}
\qt@newcmd\qurantrans@bn@mmcdlxiii{আমি ইতিপূর্বে আদমকে নির্দেশ দিয়েছিলাম। অতঃপর সে ভুলে গিয়েছিল এবং আমি তার মধ্যে দৃঢ়তা পাইনি।\qt@no{(115)}}
\qt@newcmd\qurantrans@bn@mmcdlxiv{যখন আমি ফেরেশতাদেরকে বললামঃ তোমরা আদমকে সেজদা কর, তখন ইবলীস ব্যতীত সবাই সেজদা করল। সে অমান্য করল।\qt@no{(116)}}
\qt@newcmd\qurantrans@bn@mmcdlxv{অতঃপর আমি বললামঃ হে আদম, এ তোমার ও তোমার স্ত্রীর শত্রু, সুতরাং সে যেন বের করে না দেয় তোমাদের জান্নাত থেকে। তাহলে তোমরা কষ্টে পতিত হবে।\qt@no{(117)}}
\qt@newcmd\qurantrans@bn@mmcdlxvi{তোমাকে এই দেয়া হল যে, তুমি এতে ক্ষুধার্ত হবে না এবং বস্ত্রহীণ হবে না।\qt@no{(118)}}
\qt@newcmd\qurantrans@bn@mmcdlxvii{এবং তোমার পিপাসাও হবে না এবং রৌদ্রেও কষ্ট পাবে না।\qt@no{(119)}}
\qt@newcmd\qurantrans@bn@mmcdlxviii{অতঃপর শয়তান তাকে কুমন্ত্রনা দিল, বললঃ হে আদম, আমি কি তোমাকে বলে দিব অনন্তকাল জীবিত থাকার বৃক্ষের কথা এবং অবিনশ্বর রাজত্বের কথা?\qt@no{(120)}}
\qt@newcmd\qurantrans@bn@mmcdlxix{অতঃপর তারা উভয়েই এর ফল ভক্ষণ করল, তখন তাদের সামনে তাদের লজ্জাস্থান খুলে গেল এবং তারা জান্নাতের বৃক্ষ-পত্র দ্বারা নিজেদেরকে আবৃত করতে শুরু করল। আদম তার পালনকর্তার অবাধ্যতা করল, ফলে সে পথ ভ্রষ্ঠ হয়ে গেল।\qt@no{(121)}}
\qt@newcmd\qurantrans@bn@mmcdlxx{এরপর তার পালনকর্তা তাকে মনোনীত করলেন, তার প্রতি মনোযোগী হলেন এবং তাকে সুপথে আনয়ন করলেন।\qt@no{(122)}}
\qt@newcmd\qurantrans@bn@mmcdlxxi{তিনি বললেনঃ তোমরা উভয়েই এখান থেকে এক সঙ্গে নেমে যাও। তোমরা একে অপরের শত্রু। এরপর যদি আমার পক্ষ থেকে তোমাদের কাছে হেদায়েত আসে, তখন যে আমার বর্ণিত পথ অনুসরণ করবে, সে পথভ্রষ্ঠ হবে না এবং কষ্টে পতিত হবে না।\qt@no{(123)}}
\qt@newcmd\qurantrans@bn@mmcdlxxii{এবং যে আমার স্মরণ থেকে মুখ ফিরিয়ে নেবে, তার জীবিকা সংকীর্ণ হবে এবং আমি তাকে কেয়ামতের দিন অন্ধ অবস্থায় উত্থিত করব।\qt@no{(124)}}
\qt@newcmd\qurantrans@bn@mmcdlxxiii{সে বলবেঃ হে আমার পালনকর্তা আমাকে কেন অন্ধ অবস্থায় উত্থিত করলেন? আমি তো চক্ষুমান ছিলাম।\qt@no{(125)}}
\qt@newcmd\qurantrans@bn@mmcdlxxiv{আল্লাহ বলবেনঃ এমনিভাবে তোমার কাছে আমার আয়াতসমূহ এসেছিল, অতঃপর তুমি সেগুলো ভুলে গিয়েছিলে। তেমনিভাবে আজ তোমাকে ভুলে যাব।\qt@no{(126)}}
\qt@newcmd\qurantrans@bn@mmcdlxxv{এমনিভাবে আমি তাকে প্রতিফল দেব, যে সীমালঙ্ঘন করে এবং পালনকর্তার কথায় বিশ্বাস স্থাপন না করে। তার পরকালের শাস্তি কঠোরতর এবং অনেক স্থায়ী।\qt@no{(127)}}
\qt@newcmd\qurantrans@bn@mmcdlxxvi{আমি এদের পূর্বে অনেক সম্প্রদায়কে ধবংস করেছি। যাদের বাসভুমিতে এরা বিচরণ করে, এটা কি এদেরকে সৎপথ প্রদর্শন করল না? নিশ্চয় এতে বুদ্ধিমানদের জন্যে নিদর্শনাবলী রয়েছে।\qt@no{(128)}}
\qt@newcmd\qurantrans@bn@mmcdlxxvii{আপনার পালনকর্তার পক্ষ থেকে পূর্ব সিদ্ধান্ত এবং একটি কাল নির্দিষ্ট না থাকলে শাস্তি অবশ্যম্ভাবী হয়ে যেত।\qt@no{(129)}}
\qt@newcmd\qurantrans@bn@mmcdlxxviii{সুতরাং এরা যা বলে সে বিষয়ে ধৈর্য্য ধারণ করুন এবং আপনার পালনকর্তার প্রশংসা পবিত্রতা ও মহিমা ঘোষনা করুন সূর্যোদয়ের পূর্বে, সূর্যাস্তের পূর্বে এবং পবিত্রতা ও মহিমা ঘোষনা করুন রাত্রির কিছু অংশ ও দিবাভাগে, সম্ভবতঃ তাতে আপনি সন্তুষ্ট হবেন।\qt@no{(130)}}
\qt@newcmd\qurantrans@bn@mmcdlxxix{আমি এদের বিভিন্ন প্রকার লোককে পরীক্ষা করার জন্যে পার্থিবজীবনের সৌন্দর্য স্বরূপ ভোগ-বিলাসের যে উপকরণ দিয়েছি, আপনি সেই সব বস্তুর প্রতি দৃষ্টি নিক্ষেপ করবেন না। আপনার পালনকর্তার দেয়া রিযিক উৎকৃষ্ট ও অধিক স্থায়ী।\qt@no{(131)}}
\qt@newcmd\qurantrans@bn@mmcdlxxx{আপনি আপনার পরিবারের লোকদেরকে নামাযের আদেশ দিন এবং নিজেও এর ওপর অবিচল থাকুন। আমি আপনার কাছে কোন রিযিক চাই না। আমি আপনাকে রিযিক দেই এবং আল্লাহ ভীরুতার পরিণাম শুভ।\qt@no{(132)}}
\qt@newcmd\qurantrans@bn@mmcdlxxxi{এরা বলেঃ সে আমাদের কাছে তার পালনকর্তার কাছ থেকে কোন নিদর্শন আনয়ন করে না কেন? তাদের কাছে কি প্রমাণ আসেনি, যা পূর্ববর্তী গ্রন্থসমূহে আছে?\qt@no{(133)}}
\qt@newcmd\qurantrans@bn@mmcdlxxxii{যদি আমি এদেরকে ইতিপূর্বে কোন শাস্তি দ্বারা ধ্বংস করতাম, তবে এরা বলতঃ হে আমাদের পালনকর্তা, আপনি আমাদের কাছে একজন রসূল প্রেরণ করলেন না কেন? তাহলে তো আমরা অপমানিত ও হেয় হওয়ার পূর্বেই আপনার নিদর্শন সমূহ মেনে চলতাম।\qt@no{(134)}}
\qt@newcmd\qurantrans@bn@mmcdlxxxiii{বলুন, প্রত্যেকেই পথপানে চেয়ে আছে, সুতরাং তোমরাও পথপানে চেয়ে থাক। অদূর ভবিষ্যতে তোমরা জানতে পারবে কে সরল পথের পথিক এবং কে সৎপথ প্রাপ্ত হয়েছে।\qt@no{(135)}}
\qt@newcmd\qurantrans@bn@mmcdlxxxiv{\basmalahbn মানুষের হিসাব-কিতাবের সময় নিকটবর্তী; অথচ তারা বেখবর হয়ে মুখ ফিরিয়ে নিচ্ছে।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmcdlxxxv{তাদের কাছে তাদের পালনকর্তার পক্ষ থেকে যখনই কোন নতুন উপদেশ আসে, তারা তা খেলার ছলে শ্রবণ করে।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmcdlxxxvi{তাদের অন্তর থাকে খেলায় মত্ত। জালেমরা গোপনে পরামর্শ করে, সে তো তোমাদেরই মত একজন মানুষ; এমতাবস্থায় দেখে শুনে তোমরা তার যাদুর কবলে কেন পড়?\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmcdlxxxvii{পয়গম্বর বললেনঃ নভোমন্ডল ও ভুমন্ডলের কথাই আমার পালনকর্তা জানেন। তিনি সবকিছু শোনেন, সবকিছু জানেন।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmcdlxxxviii{এছাড়া তারা আরও বলেঃ অলীক স্বপ্ন; না সে মিথ্যা উদ্ভাবন করেছে, না সে একজন কবি। অতএব সে আমাদের কাছে কোন নিদর্শন আনয়ন করুক, যেমন নিদর্শন সহ আগমন করেছিলেন পূর্ববর্তীগন।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmcdlxxxix{তাদের পূর্বে যেসব জনপদ আমি ধবংস করে দিয়েছি, তারা বিশ্বাস স্থাপন করেনি; এখন এরা কি বিশ্বাস স্থাপন করবে?\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmcdxc{আপনার পূর্বে আমি মানুষই প্রেরণ করেছি, যাদের কাছে আমি ওহী পাঠাতাম। অতএব তোমরা যদি না জান তবে যারা স্মরণ রাখে তাদেরকে জিজ্ঞেস কর।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmcdxci{আমি তাদেরকে এমন দেহ বিশিষ্ট করিনি যে, তারা খাদ্য ভক্ষণ করত না এবং তারা চিরস্থায়ীও ছিল না।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmcdxcii{অতঃপর আমি তাদেরকে দেয়া আমার প্রতিশ্রুতি পূর্ণ করলাম সুতরাং তাদেরকে এবং যাদেরকে ইচ্ছা বাঁচিয়ে দিলাম এবং ধবংস করে ছিলাম সীমালঙ্ঘনকারীদেরকে।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmcdxciii{আমি তোমাদের প্রতি একটি কিতাব অবর্তীর্ণ করেছি; এতে তোমাদের জন্যে উপদেশ রয়েছে। তোমরা কি বোঝ না?\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmcdxciv{আমি কত জনপদের ধ্বংস সাধন করেছি যার অধিবাসীরা ছিল পাপী এবং তাদের পর সৃষ্টি করেছি অন্য জাতি।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmcdxcv{অতঃপর যখন তারা আমার আযাবের কথা টের পেল, তখনই তারা সেখান থেকে পলায়ন করতে লাগল।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmcdxcvi{পলায়ন করো না এবং ফিরে এস, যেখানে তোমরা বিলাসিতায় মত্ত ছিলে ও তোমাদের আবাসগৃহে; সম্ভবত; কেউ তোমাদের জিজ্ঞেস করবে।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmcdxcvii{তারা বললঃ হায়, দুর্ভোগ আমাদের, আমরা অবশ্যই পাপী ছিলাম।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmcdxcviii{তাদের এই আর্তনাদ সব সময় ছিল, শেষ পর্যন্ত আমি তাদেরকে করে দিলাম যেন কর্তিত শস্য ও নির্বাপিত অগ্নি।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmcdxcix{আকাশ পৃথিবী এতদুভয়ের মধ্যে যা আছে, তা আমি ক্রীড়াচ্ছলে সৃষ্টি করিনি।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmd{আমি যদি ক্রীড়া উপকরণ সৃষ্টি করতে চাইতাম, তবে আমি আমার কাছে যা আছে তা দ্বারাই তা করতাম, যদি আমাকে করতে হত।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmdi{বরং আমি সত্যকে মিথ্যার উপর নিক্ষেপ করি, অতঃপর সত্য মিথ্যার মস্তক চুর্ণ-বিচূর্ণ করে দেয়, অতঃপর মিথ্যা তৎক্ষণাৎ নিশ্চিহ্ন হয়ে যায়। তোমরা যা বলছ, তার জন্যে তোমাদের দুর্ভোগ।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmdii{নভোমন্ডল ও ভুমন্ডলে যারা আছে, তারা তাঁরই। আর যারা তাঁর সান্নিধ্যে আছে তারা তাঁর ইবাদতে অহংকার করে না এবং অলসতাও করে না।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmdiii{তারা রাত্রিদিন তাঁর পবিত্রতা ও মহিমা বর্ণনা করে এবং ক্লান্ত হয় না।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmdiv{তারা কি মৃত্তিকা দ্বারা তৈরী উপাস্য গ্রহণ করেছে, যে তারা তাদেরকে জীবিত করবে?\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmdv{যদি নভোমন্ডল ও ভুমন্ডলে আল্লাহ ব্যতীত অন্যান্য উপাস্য থাকত, তবে উভয়ের ধ্বংস হয়ে যেত। অতএব তারা যা বলে, তা থেকে আরশের অধিপতি আল্লাহ পবিত্র।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmdvi{তিনি যা করেন, তৎসম্পর্কে তিনি জিজ্ঞাসিত হবেন না এবং তাদেরকে জিজ্ঞেস করা হবে।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmdvii{তারা কি আল্লাহ ব্যতীত অন্যান্য উপাস্য গ্রহণ করেছে? বলুন, তোমরা তোমাদের প্রমাণ আন। এটাই আমার সঙ্গীদের কথা এবং এটাই আমার পুর্ববর্তীদের কথা। বরং তাদের অধিকাংশই সত্য জানে না; অতএব তারা টালবাহানা করে।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmdviii{আপনার পূর্বে আমি যে রাসূলই প্রেরণ করেছি, তাকে এ আদেশই প্রেরণ করেছি যে, আমি ব্যতীত অন্য কোন উপাস্য নেই। সুতরাং আমারই এবাদত কর।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmdix{তারা বললঃ দয়াময় আল্লাহ সন্তান গ্রহণ করেছে। তাঁর জন্য কখনও ইহা যোগ্য নয়; বরং তারা তো তাঁর সম্মানিত বান্দা।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmdx{তারা আগে বেড়ে কথা বলতে পারে না এবং তারা তাঁর আদেশেই কাজ করে।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmdxi{তাদের সম্মুখে ও পশ্চাতে যা আছে, তা তিনি জানেন। তারা শুধু তাদের জন্যে সুপারিশ করে, যাদের প্রতি আল্লাহ সন্তুষ্ট এবং তারা তাঁর ভয়ে ভীত।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmdxii{তাদের মধ্যে যে বলে যে, তিনি ব্যতীত আমিই উপাস্য, তাকে আমি জাহান্নামের শাস্তি দেব। আমি জালেমদেরকে এভাবেই প্রতিফল দিয়ে থাকি।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmdxiii{কাফেররা কি ভেবে দেখে না যে, আকাশমন্ডলী ও পৃথিবীর মুখ বন্ধ ছিল, অতঃপর আমি উভয়কে খুলে দিলাম এবং প্রাণবন্ত সবকিছু আমি পানি থেকে সৃষ্টি করলাম। এরপরও কি তারা বিশ্বাস স্থাপন করবে না?\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmdxiv{আমি পৃথিবীতে ভারী বোঝা রেখে দিয়েছি যাতে তাদেরকে নিয়ে পৃথিবী ঝুঁকে না পড়ে এবং তাতে প্রশস্ত পথ রেখেছি, যাতে তারা পথ প্রাপ্ত হয়।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmdxv{আমি আকাশকে সুরক্ষিত ছাদ করেছি; অথচ তারা আমার আকাশস্থ নিদর্শনাবলী থেকে মুখ ফিরিয়ে রাখে।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmdxvi{তিনিই সৃষ্টি করেছেন রাত্রি ও দিন এবং সূর্য ও চন্দ্র। সবাই আপন আপন কক্ষপথে বিচরণ করে।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmdxvii{আপনার পূর্বেও কোন মানুষকে আমি অনন্ত জীবন দান করিনি। সুতরাং আপনার মৃত্যু হলে তারা কি চিরঞ্জীব হবে?\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmdxviii{প্রত্যেককে মৃত্যুর স্বাদ আস্বাদন করতে হবে। আমি তোমাদেরকে মন্দ ও ভাল দ্বারা পরীক্ষা করে থাকি এবং আমারই কাছে তোমরা প্রত্যাবর্তিত হবে।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmdxix{কাফেররা যখন আপনাকে দেখে তখন আপনার সাথে ঠাট্টা করা ছাড়া তাদের আর কোন কাজ থাকে না, একি সেই ব্যক্তি, যে তোমাদের দেব-দেবীদের সমালোচনা করে? এবং তারাই তো রহমান’ এর আলোচনায় অস্বীকার করে।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmdxx{সৃষ্টিগত ভাবে মানুষ ত্বরাপ্রবণ, আমি সত্তরই তোমাদেরকে আমার নিদর্শনাবলী দেখাব। অতএব আমাকে শীঘ্র করতে বলো না।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmdxxi{এবং তারা বলেঃ যদি তোমরা সত্যবাদী হও তবে এই ওয়াদা কবে পুর্ণ হবে?\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmdxxii{যদি কাফেররা ঐ সময়টি জানত, যখন তারা তাদের সম্মুখ ও পৃষ্ঠদেশ থেকে অগ্নি প্রতিরোধ করতে পারবে না এবং তারা সাহায্য প্রাপ্ত হবে না।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmdxxiii{বরং তা আসবে তাদের উপর অতর্কিত ভাবে, অতঃপর তাদেরকে তা হতবুদ্ধি করে দেবে, তখন তারা তা রোধ করতেও পারবে না এবং তাদেরকে অবকাশও দেয়া হবে না।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmdxxiv{আপনার পূর্বেও অনেক রাসূলের সাথে ঠাট্টা-বিদ্রূপ করা হয়েছে। অতঃপর যে বিষয়ে তারা ঠাট্টা করত তা উল্টো ঠাট্টাকারীদের উপরই আপতিত হয়েছে।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmdxxv{বলুনঃ ‘রহমান’ থেকে কে তোমাদেরকে হেফাযত করবে রাত্রে ও দিনে। বরং তারা তাদের পালনকর্তার স্মরণ থেকে মুখ ফিরিয়ে রাখে।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmdxxvi{তবে কি আমি ব্যতীত তাদের এমন দেব-দেবী আছে যারা তাদেরকে রক্ষা করবে? তারা তো নিজেদেরই সাহায্য করতে সক্ষম নয় এবং তারা আমার মোকাবেলায় সাহায্যকারীও পাবে না।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmdxxvii{বরং আমি তাদেরকে এবং তাদের বাপ-দাদাকে ভোগসম্বার দিয়েছিলাম, এমনকি তাদের আয়ুস্কালও দীর্ঘ হয়েছিল। তারা কি দেখে না যে, আমি তাদের দেশকে চতুর্দিক থেকে হ্রাস করে আনছি। এরপরও কি তারা বিজয়ী হবে?\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmdxxviii{বলুনঃ আমি তো কেবল ওহীর মাধ্যমেই তোমাদেরকে সতর্ক করি, কিন্তু বধিরদেরকে যখন সতর্ক করা হয়, তখন তারা সে সতর্কবাণী শোনে না।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmdxxix{আপনার পালনকর্তার আযাবের কিছুমাত্রও তাদেরকে স্পর্শ করলে তারা বলতে থাকবে, হায় আমাদের দুর্ভাগ্য, আমরা অবশ্যই পাপী ছিলাম।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmdxxx{আমি কেয়ামতের দিন ন্যায়বিচারের মানদন্ড স্থাপন করব। সুতরাং কারও প্রতি জুলুম হবে না। যদি কোন আমল সরিষার দানা পরিমাণও হয়, আমি তা উপস্থিত করব এবং হিসাব গ্রহণের জন্যে আমিই যথেষ্ট।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmdxxxi{আমি মূসা ও হারুণকে দান করেছিলাম মীমাংসাকারী গ্রন্থ, আলো ও উপদেশ, আল্লাহ ভীরুদের জন্যে\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmdxxxii{যারা না দেখেই তাদের পালনকর্তাকে ভয় করে এবং কেয়ামতের ভয়ে শঙ্কিত।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmdxxxiii{এবং এটা একটা বরকতময় উপদেশ, যা আমি নাযিল করেছি। অতএব তোমরা কি একে অস্বীকার কর?\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmdxxxiv{আর, আমি ইতিপূর্বে ইব্রাহীমকে তার সৎপন্থা দান করেছিলাম এবং আমি তার সম্পর্কে সম্যক পরিজ্ঞাত ও ছিলাম।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmdxxxv{যখন তিনি তাঁর পিতা ও তাঁর সম্প্রদায়কে বললেনঃ এই মূর্তিগুলো কী, যাদের তোমরা পূজারী হয়ে বসে আছ।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmdxxxvi{তারা বললঃ আমরা আমাদের বাপ-দাদাকে এদের পুজা করতে দেখেছি।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmdxxxvii{তিনি বললেনঃ তোমরা প্রকাশ্য গোমরাহীতে আছ এবং তোমাদের বাপ-দাদারাও।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmdxxxviii{তারা বললঃ তুমি কি আমাদের কাছে সত্যসহ আগমন করেছ, না তুমি কৌতুক করছ?\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mmdxxxix{তিনি বললেনঃ না, তিনিই তোমাদের পালনকর্তা যিনি নভোমন্ডল ও ভুমন্ডলের পালনকর্তা, যিনি এগুলো সৃষ্টি করেছেন; এবং আমি এই বিষয়েরই সাক্ষ্যদাতা।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mmdxl{আল্লাহর কসম, যখন তোমরা পৃষ্ঠ প্রদর্শন করে চলে যাবে, তখন আমি তোমাদের মূর্তিগুলোর ব্যাপারে একটা ব্যবস্থা অবলম্বন করব।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mmdxli{অতঃপর তিনি সেগুলোকে চূর্ণ-বিচুর্ণ করে দিলেন ওদের প্রধানটি ব্যতীতঃ যাতে তারা তাঁর কাছে প্রত্যাবর্তন করে।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mmdxlii{তারা বললঃ আমাদের উপাস্যদের সাথে এরূপ ব্যবহার কে করল? সে তো নিশ্চয়ই কোন জালিম।\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mmdxliii{কতক লোকে বললঃ আমরা এক যুবককে তাদের সম্পর্কে বিরূপ আলোচনা করতে শুনেছি; তাকে ইব্রাহীম বলা হয়।\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mmdxliv{তারা বললঃ তাকে জনসমক্ষে উপস্থিত কর, যাতে তারা দেখে।\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mmdxlv{তারা বললঃ হে ইব্রাহীম তুমিই কি আমাদের উপাস্যদের সাথে এরূপ ব্যবহার করেছ?\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mmdxlvi{তিনি বললেনঃ না এদের এই প্রধানই তো একাজ করেছে। অতএব তাদেরকে জিজ্ঞেস কর, যদি তারা কথা বলতে পারে।\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mmdxlvii{অতঃপর মনে মনে চিন্তা করল এবং বললঃ লোক সকল; তোমরাই বে ইনসাফ।\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mmdxlviii{অতঃপর তারা ঝুঁকে গেল মস্তক নত করে, তুমি তো জান যে, এরা কথা বলে না\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mmdxlix{তিনি বললেনঃ তোমরা কি আল্লাহর পরিবর্তে এমন কিছুর এবাদত কর, যা তোমাদের কোন উপকার ও করতে পারে না এবং ক্ষতিও করতে পারে না ?\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mmdl{ধিক তোমাদের জন্যে এবং তোমরা আল্লাহ ব্যতীত যাদেরই এবাদত কর, ওদের জন্যে। তোমরা কি বোঝ না?\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mmdli{তারা বললঃ একে পুড়িয়ে দাও এবং তোমাদের উপাস্যদের সাহায্য কর, যদি তোমরা কিছু করতে চাও।\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mmdlii{আমি বললামঃ হে অগ্নি, তুমি ইব্রাহীমের উপর শীতল ও নিরাপদ হয়ে যাও।\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mmdliii{তারা ইব্রাহীমের বিরুদ্ধে ফন্দি আঁটতে চাইল, অতঃপর আমি তাদেরকেই সর্বাধিক ক্ষতিগ্রস্থ করে দিলাম।\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@mmdliv{আমি তাঁকে ও লূতকে উদ্ধার করে সেই দেশে পৌঁছিয়ে দিলাম, যেখানে আমি বিশ্বের জন্যে কল্যাণ রেখেছি।\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@mmdlv{আমি তাকে দান করলাম ইসহাক ও পুরস্কার স্বরূপ দিলাম ইয়াকুব এবং প্রত্যেককেই সৎকর্ম পরায়ণ করলাম।\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@mmdlvi{আমি তাঁদেরকে নেতা করলাম। তাঁরা আমার নির্দেশ অনুসারে পথ প্রদর্শন করতেন। আমি তাঁদের প্রতি ওহী নাযিল করলাম সৎকর্ম করার, নামায কায়েম করার এবং যাকাত দান করার। তাঁরা আমার এবাদতে ব্যাপৃত ছিল।\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@mmdlvii{এবং আমি লূতকে দিয়েছিলাম প্রজ্ঞা ও জ্ঞান এবং তাঁকে ঐ জনপদ থেকে উদ্ধার করেছিলাম, যারা নোংরা কাজে লিপ্ত ছিল। তারা মন্দ ও নাফরমান সম্প্রদায় ছিল।\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@mmdlviii{আমি তাকে আমার অনুগ্রহের অন্তর্ভুক্ত করেছিলাম। সে ছিল সৎকর্মশীলদের একজন।\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@mmdlix{এবং স্মরণ করুন নূহকে; যখন তিনি এর পূর্বে আহবান করেছিলেন। তখন আমি তাঁর দোয়া কবুল করেছিলাম, অতঃপর তাঁকে ও তাঁর পরিবারবর্গকে মহা সংকট থেকে উদ্ধার করেছিলাম।\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@mmdlx{এবং আমি তাঁকে ঐ সম্প্রদায়ের বিপক্ষে সাহায্য করেছিলাম, যারা আমার নিদর্শনাবলীকে অস্বীকার করেছিল। নিশ্চয়, তারা ছিল এক মন্দ সম্প্রদায়। অতঃপর আমি তাদের সবাইকে নিমজ্জত করেছিলাম।\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@mmdlxi{এবং স্মরণ করুন দাউদ ও সুলায়মানকে, যখন তাঁরা শস্যক্ষেত্র সম্পর্কে বিচার করেছিলেন। তাতে রাত্রিকালে কিছু লোকের মেষ ঢুকে পড়েছিল। তাদের বিচার আমার সম্মুখে ছিল।\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@mmdlxii{অতঃপর আমি সুলায়মানকে সে ফায়সালা বুঝিয়ে দিয়েছিলাম এবং আমি উভয়কে প্রজ্ঞা ও জ্ঞান দিয়েছিলাম। আমি পর্বত ও পক্ষীসমূহকে দাউদের অনুগত করে দিয়েছিলাম; তারা আমার পবিত্রতা ও মহিমা ঘোষণা করত। এই সমস্ত আমিই করেছিলাম।\qt@no{(79)}}
\qt@newcmd\qurantrans@bn@mmdlxiii{আমি তাঁকে তোমাদের জন্যে বর্ম নির্মান শিক্ষা দিয়েছিলাম, যাতে তা যুদ্ধে তোমাদেরকে রক্ষা করে। অতএব তোমরা কি কৃতজ্ঞ হবে?\qt@no{(80)}}
\qt@newcmd\qurantrans@bn@mmdlxiv{এবং সুলায়মানের অধীন করে দিয়েছিলাম প্রবল বায়ুকে; তা তাঁর আদেশে প্রবাহিত হত ঐ দেশের দিকে, যেখানে আমি কল্যাণ দান করেছি। আমি সব বিষয়েই সম্যক অবগত রয়েছি।\qt@no{(81)}}
\qt@newcmd\qurantrans@bn@mmdlxv{এবং অধীন করেছি শয়তানদের কতককে, যারা তার জন্যে ডুবুরীর কাজ করত এবং এ ছাড়া অন্য আরও অনেক কাজ করত। আমি তাদেরকে নিয়ন্ত্রন করে রাখতাম।\qt@no{(82)}}
\qt@newcmd\qurantrans@bn@mmdlxvi{এবং স্মরণ করুন আইয়্যুবের কথা, যখন তিনি তাঁর পালনকর্তাকে আহবান করে বলেছিলেনঃ আমি দুঃখকষ্টে পতিত হয়েছি এবং আপনি দয়াবানদের চাইতেও সর্বশ্রেষ্ট দয়াবান।\qt@no{(83)}}
\qt@newcmd\qurantrans@bn@mmdlxvii{অতঃপর আমি তাঁর আহবানে সাড়া দিলাম এবং তাঁর দুঃখকষ্ট দূর করে দিলাম এবং তাঁর পরিবরাবর্গ ফিরিয়ে দিলাম, আর তাদের সাথে তাদের সমপরিমাণ আরও দিলাম আমার পক্ষ থেকে কৃপাবশতঃ আর এটা এবাদত কারীদের জন্যে উপদেশ স্বরূপ।\qt@no{(84)}}
\qt@newcmd\qurantrans@bn@mmdlxviii{এবং ইসমাঈল, ই’দ্রীস ও যুলকিফলের কথা স্মরণ করুন, তাঁরা প্রত্যেকেই ছিলেন সবরকারী।\qt@no{(85)}}
\qt@newcmd\qurantrans@bn@mmdlxix{আমি তাঁদেরকে আমার রহমাতপ্রাপ্তদের অন্তর্ভূক্ত করেছিলাম। তাঁরা ছিলেন সৎকর্মপরায়ণ।\qt@no{(86)}}
\qt@newcmd\qurantrans@bn@mmdlxx{এবং মাছওয়ালার কথা স্মরণ করুন তিনি ক্রুদ্ধ হয়ে চলে গিয়েছিলেন, অতঃপর মনে করেছিলেন যে, আমি তাঁকে ধৃত করতে পারব না। অতঃপর তিনি অন্ধকারের মধ্যে আহবান করলেনঃ তুমি ব্যতীত কোন উপাস্য নেই; তুমি নির্দোষ আমি গুনাহগার।\qt@no{(87)}}
\qt@newcmd\qurantrans@bn@mmdlxxi{অতঃপর আমি তাঁর আহবানে সাড়া দিলাম এবং তাঁকে দুশ্চিন্তা থেকে মুক্তি দিলাম। আমি এমনি ভাবে বিশ্ববাসীদেরকে মুক্তি দিয়ে থাকি।\qt@no{(88)}}
\qt@newcmd\qurantrans@bn@mmdlxxii{এবং যাকারিয়ার কথা স্মরণ করুন, যখন সে তার পালনকর্তাকে আহবান করেছিল; হে আমার পালনকর্তা আমাকে একা রেখো না। তুমি তো উত্তম ওয়ারিস।\qt@no{(89)}}
\qt@newcmd\qurantrans@bn@mmdlxxiii{অতঃপর আমি তার দোয়া কবুল করেছিলাম, তাকে দান করেছিলাম ইয়াহইয়া এবং তার জন্যে তার স্ত্রীকে প্রসব যোগ্য করেছিলাম। তারা সৎকর্মে ঝাঁপিয়ে পড়ত, তারা আশা ও ভীতি সহকারে আমাকে ডাকত এবং তারা ছিল আমার কাছে বিনীত।\qt@no{(90)}}
\qt@newcmd\qurantrans@bn@mmdlxxiv{এবং সেই নারীর কথা আলোচনা করুন, যে তার কামপ্রবৃত্তিকে বশে রেখেছিল, অতঃপর আমি তার মধ্যে আমার রূহ ফুঁকে দিয়েছিলাম এবং তাকে তার পুত্রকে বিশ্ববাসীর জন্য নিদর্শন করেছিলাম।\qt@no{(91)}}
\qt@newcmd\qurantrans@bn@mmdlxxv{তারা সকলেই তোমাদের ধর্মের; একই ধর্মে তো বিশ্বাসী সবাই এবং আমিই তোমাদের পালনকর্তা, অতএব আমার বন্দেগী কর।\qt@no{(92)}}
\qt@newcmd\qurantrans@bn@mmdlxxvi{এবং মানুষ তাদের কার্যকলাপ দ্বারা পারস্পরিক বিষয়ে ভেদ সৃষ্টি করেছে। প্রত্যেকেই আমার কাছে প্রত্যাবর্তিত হবে।\qt@no{(93)}}
\qt@newcmd\qurantrans@bn@mmdlxxvii{অতঃপর যে বিশ্বাসী অবস্থায় সৎকর্ম সম্পাদন করে, তার প্রচেষ্টা অস্বীকৃত হবে না এবং আমি তা লিপিবদ্ধ করে রাখি।\qt@no{(94)}}
\qt@newcmd\qurantrans@bn@mmdlxxviii{যেসব জনপদকে আমি ধ্বংস করে দিয়েছি, তার অধিবাসীদের ফিরে না আসা অবধারিত।\qt@no{(95)}}
\qt@newcmd\qurantrans@bn@mmdlxxix{যে পর্যন্ত না ইয়াজুজ ও মাজুজকে বন্ধন মুক্ত করে দেয়া হবে এবং তারা প্রত্যেক উচ্চভুমি থেকে দ্রুত ছুটে আসবে।\qt@no{(96)}}
\qt@newcmd\qurantrans@bn@mmdlxxx{আমোঘ প্রতিশ্রুত সময় নিকটবর্তী হলে কাফেরদের চক্ষু উচ্চে স্থির হয়ে যাবে; হায় আমাদের দূর্ভাগ্য, আমরা এ বিষয়ে বেখবর ছিলাম; বরং আমরা গোনাহগরই ছিলাম।\qt@no{(97)}}
\qt@newcmd\qurantrans@bn@mmdlxxxi{তোমরা এবং আল্লাহর পরিবর্তে তোমরা যাদের পুজা কর, সেগুলো দোযখের ইন্ধন। তোমরাই তাতে প্রবেশ করবে।\qt@no{(98)}}
\qt@newcmd\qurantrans@bn@mmdlxxxii{এই মূর্তিরা যদি উপাস্য হত, তবে জাহান্নামে প্রবেশ করত না। প্রত্যেকেই তাতে চিরস্থায়ী হয়ে পড়ে থাকবে।\qt@no{(99)}}
\qt@newcmd\qurantrans@bn@mmdlxxxiii{তারা সেখানে চীৎকার করবে এবং সেখানে তারা কিছুই শুনতে পাবে না।\qt@no{(100)}}
\qt@newcmd\qurantrans@bn@mmdlxxxiv{যাদের জন্য প্রথম থেকেই আমার পক্ষ থেকে কল্যাণ নির্ধারিত হয়েছে তারা দোযখ থেকে দূরে থাকবে।\qt@no{(101)}}
\qt@newcmd\qurantrans@bn@mmdlxxxv{তারা তার ক্ষীণতম শব্দও শুনবে না এবং তারা তাদের মনের বাসনা অনুযায়ী চিরকাল বসবাস করবে।\qt@no{(102)}}
\qt@newcmd\qurantrans@bn@mmdlxxxvi{মহা ত্রাস তাদেরকে চিন্তান্বিত করবে না এবং ফেরেশতারা তাদেরকে অভ্যর্থনা করবেঃ আজ তোমাদের দিন, যে দিনের ওয়াদা তোমাদেরকে দেয়া হয়েছিল।\qt@no{(103)}}
\qt@newcmd\qurantrans@bn@mmdlxxxvii{সেদিন আমি আকাশকে গুটিয়ে নেব, যেমন গুটানো হয় লিখিত কাগজপত্র। যেভাবে আমি প্রথমবার সৃষ্টি করেছিলাম, সেভাবে পুনরায় সৃষ্টি করব। আমার ওয়াদা নিশ্চিত, আমাকে তা পূর্ণ করতেই হবে।\qt@no{(104)}}
\qt@newcmd\qurantrans@bn@mmdlxxxviii{আমি উপদেশের পর যবুরে লিখে দিয়েছি যে, আমার সৎকর্মপরায়ণ বান্দাগণ অবশেষে পৃথিবীর অধিকারী হবে।\qt@no{(105)}}
\qt@newcmd\qurantrans@bn@mmdlxxxix{এতে এবাদতকারী সম্প্রদায়ের জন্যে পর্যাপ্ত বিষয়বস্তু আছে।\qt@no{(106)}}
\qt@newcmd\qurantrans@bn@mmdxc{আমি আপনাকে বিশ্ববাসীর জন্যে রহমত স্বরূপই প্রেরণ করেছি।\qt@no{(107)}}
\qt@newcmd\qurantrans@bn@mmdxci{বলুনঃ আমাকে তো এ আদেশই দেয়া হয়েছে যে, তোমাদের উপাস্য একমাত্র উপাস্য। সুতরাংতোমরা কি আজ্ঞাবহ হবে?\qt@no{(108)}}
\qt@newcmd\qurantrans@bn@mmdxcii{অতঃপর যদি তারা মুখ ফিরিয়ে নেয়, তবে বলে দিনঃ আমি তোমাদেরকে পরিস্কার ভাবে সতর্ক করেছি এবং আমি জানি না, তোমাদেরকে যে ওয়াদা দেয়া হয়েছে, তা নিকটবর্তী না দূরবর্তী।\qt@no{(109)}}
\qt@newcmd\qurantrans@bn@mmdxciii{তিনি জানেন, যে কথা সশব্দে বল এবং যে কথা তোমরা গোপন কর।\qt@no{(110)}}
\qt@newcmd\qurantrans@bn@mmdxciv{আমি জানি না সম্ভবতঃ বিলম্বের মধ্যে তোমাদের জন্যে একটি পরীক্ষা এবং এক সময় পর্যন্ত ভোগ করার সুযোগ।\qt@no{(111)}}
\qt@newcmd\qurantrans@bn@mmdxcv{পয়গাম্বর বললেনঃ হে আমার পালনকর্তা, আপনি ন্যায়ানুগ ফয়সালা করে দিন। আমাদের পালনকর্তা তো দয়াময়, তোমরা যা বলছ, সে বিষয়ে আমরা তাঁর কাছেই সাহায্য প্রার্থনা করি।\qt@no{(112)}}
\qt@newcmd\qurantrans@bn@mmdxcvi{\basmalahbn হে লোক সকল! তোমাদের পালনকর্তাকে ভয় কর। নিশ্চয় কেয়ামতের প্রকম্পন একটি ভয়ংকর ব্যাপার।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmdxcvii{যেদিন তোমরা তা প্রত্যক্ষ করবে, সেদিন প্রত্যেক স্তন্যধাত্রী তার দুধের শিশুকে বিস্মৃত হবে এবং প্রত্যেক গর্ভবতী তার গর্ভপাত করবে এবং মানুষকে তুমি দেখবে মাতাল; অথচ তারা মাতাল নয় বস্তুতঃ আল্লাহর আযাব সুকঠিন।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmdxcviii{কতক মানুষ অজ্ঞানতাবশতঃ আল্লাহ সম্পꦣ2503;ক বিতর্ক করে এবং প্রত্যেক অবাধ্য শয়তানের অনুসরণ করে।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmdxcix{শয়তান সম্পর্কে লিখে দেয়া হয়েছে যে, যে কেউ তার সাথী হবে, সে তাকে বিভ্রান্ত করবে এবং দোযখের আযাবের দিকে পরিচালিত করবে।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmdc{হে লোকসকল! যদি তোমরা পুনরুত্থানের ব্যাপারে সন্দিগ্ধ হও, তবে (ভেবে দেখ-) আমি তোমাদেরকে মৃত্তিকা থেকে সৃষ্টি করেছি। এরপর বীর্য থেকে, এরপর জমাট রক্ত থেকে, এরপর পূর্ণাকৃতিবিশিষ্ট ও অপূর্ণাকৃতিবিশিষ্ট মাংসপিন্ড থেকে, তোমাদের কাছে ব্যক্ত করার জন্যে। আর আমি এক নির্দিষ্ট কালের জন্যে মাতৃগর্ভে যা ইচ্ছা রেখে দেই, এরপর আমি তোমাদেরকে শিশু অবস্থায় বের করি; তারপর যাতে তোমরা যৌবনে পদার্পণ কর। তোমাদের মধ্যে কেউ কেউ মৃত্যুমুখে পতিত হয় এবং তোমাদের মধ্যে কাউকে নিষ্কর্মা বয়স পর্যন্ত পৌছানো হয়, যাতে সে জানার পর জ্ঞাত বিষয় সম্পর্কে সজ্ঞান থাকে না। তুমি ভূমিকে পতিত দেখতে পাও, অতঃপর আমি যখন তাতে বৃষ্টি বর্ষণ করি, তখন তা সতেজ ও স্ফীত হয়ে যায় এবং সর্বপ্রকার সুদৃশ্য উদ্ভিদ উৎপন্ন করে।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmdci{এগুলো এ কারণে যে, আল্লাহ সত্য এবং তিনি মৃতকে জীবিত করেন এবং তিনি সবকিছুর উপর ক্ষমতাবান।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmdcii{এবং এ কারণে যে, কেয়ামত অবশ্যম্ভাবী, এতে সন্দেহ নেই এবং এ কারণে যে, কবরে যারা আছে, আল্লাহ তাদেরকে পুনরুত্থিত করবেন।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmdciii{কতক মানুষ জ্ঞান; প্রমাণ ও উজ্জ্বল কিতাব ছাড়াই আল্লাহ সম্পর্কে বিতর্ক করে।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmdciv{সে পার্শ্ব পরিবর্তন করে বিতর্ক করে, যাতে আল্লাহর পথ থেকে বিভ্রান্ত করে দেয়। তার জন্যে দুনিয়াতে লাঞ্ছনা আছে এবং কেয়ামতের দিন আমি তাকে দহন-যন্ত্রণা আস্বাদন করাব।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmdcv{এটা তোমার দুই হাতের কর্মের কারণে, আল্লাহ বান্দাদের প্রতি জুলুম করেন না।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmdcvi{মানুষের মধ্যে কেউ কেউ দ্বিধা-দ্বন্দ্বে জড়িত হয়ে আল্লাহর এবাদত করে। যদি সে কল্যাণ প্রাপ্ত হয়, তবে এবাদতের উপর কায়েম থাকে এবং যদি কোন পরীক্ষায় পড়ে, তবে পূর্বাবস্থায় ফিরে যায়। সে ইহকালে ও পরকালে ক্ষতিগ্রস্ত। এটাই প্রকাশ্য ক্ষতি\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmdcvii{সে আল্লাহর পরিবর্তে এমন কিছুকে ডাকে, যে তার অপকার করতে পারে না এবং উপকারও করতে পারে না। এটাই চরম পথভ্রষ্টতা।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmdcviii{সে এমন কিছুকে ডাকে, যার অপকার উপকারের আগে পৌছে। কত মন্দ এই বন্ধু এবং কত মন্দ এই সঙ্গী।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmdcix{যারা বিশ্বাস স্থাপন করে ও সৎকর্ম সম্পাদন করে, আল্লাহ তাদেরকে জান্নাতে দাখিল করবেন, যার তলদেশ দিয়ে নির্ঝরণীসমূহ প্রবাহিত হয়। আল্লাহ যা ইচ্ছা তাই করেন।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmdcx{সে ধারণা করে যে, আল্লাহ কখনই ইহকালে ও পরকালে রাসূলকে সাহায্য করবেন না, সে একটি রশি আকাশ পর্যন্ত ঝুলিয়ে নিক; এরপর কেটে দিক; অতঃপর দেখুক তার এই কৌশল তার আক্রোশ দূর করে কিনা।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmdcxi{এমনিভাবে আমি সুস্পষ্ট আয়াত রূপে কোরআন নাযিল করেছি এবং আল্লাহ-ই যাকে ইচ্ছা হেদায়েত করেন।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmdcxii{যারা মুসলমান, যারা ইহুদী, সাবেয়ী, খ্রীষ্টান, অগ্নিপুজক এবং যারা মুশরেক, কেয়ামতের দিন আল্লাহ অবশ্যই তাদের মধ্যে ফায়সালা করে দেবেন। সবকিছুই আল্লাহর দৃষ্টির সামনে।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmdcxiii{তুমি কি দেখনি যে, আল্লাহকে সেজদা করে যা কিছু আছে নভোমন্ডলে, যা কিছু আছে ভুমন্ডলে, সূর্য, চন্দ্র, তারকারাজি পর্বতরাজি বৃক্ষলতা, জীবজন্তু এবং অনেক মানুষ। আবার অনেকের উপর অবধারিত হয়েছে শাস্তি। আল্লাহ যাকে ইচ্ছা লাঞ্ছিত করেন, তাকে কেউ সম্মান দিতে পারে না। আল্লাহ যা ইচ্ছা তাই করেন\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmdcxiv{এই দুই বাদী বিবাদী, তারা তাদের পালনকর্তা সম্পর্কে বিতর্ক করে। অতএব যারা কাফের, তাদের জন্যে আগুনের পোশাক তৈরী করা হয়েছে। তাদের মাথার উপর ফুটন্ত পানি ঢেলে দেয়া হবে।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmdcxv{ফলে তাদের পেটে যা আছে, তা এবং চর্ম গলে বের হয়ে যাবে।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmdcxvi{তাদের জন্যে আছে লোহার হাতুড়ি।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmdcxvii{তারা যখনই যন্ত্রনায় অতিষ্ঠ হয়ে জাহান্নাম থেকে বের হতে চাইবে, তখনই তাদেরকে তাতে ফিরিয়ে দেয়া হবে। বলা হবেঃ দহন শাস্তি আস্বাদন কর।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmdcxviii{নিশ্চয় যারা বিশ্বাস স্থাপন করে এবং সৎকর্ম করে, আল্লাহ তাদেরকে দাখিল করবেন উদ্যান সমূহে, যার তলদেশ দিয়ে নির্ঝরিণীসমূহ প্রবাহিত হবে। তাদেরকে তথায় স্বর্ণ-কংকন ও মুক্তা দ্বারা অলংকৃত করা হবে এবং তথায় তাদের পোশাক হবে রেশমী।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmdcxix{তারা পথপ্রদর্শিত হয়েছিল সৎবাক্যের দিকে এবং পরিচালিত হয়েছিল প্রশংসিত আল্লাহর পথপানে।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmdcxx{যারা কুফর করে ও আল্লাহর পথে বাধা সৃষ্টি করে এবং সেই মসজিদে হারাম থেকে বাধা দেয়, যাকে আমি প্রস্তুত করেছি স্থানীয় ও বহিরাগত সকল মানুষের জন্যে সমভাবে এবং যে মসজিদে হারামে অন্যায়ভাবে কোন ধর্মদ্রোহী কাজ করার ইচছা করে, আমি তাদেরকে যন্ত্রানাদায়ক শাস্তি আস্বাদন করাব।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmdcxxi{যখন আমি ইব্রাহীমকে বায়তুল্লাহর স্থান ঠিক করে দিয়েছিলাম যে, আমার সাথে কাউকে শরীক করো না এবং আমার গৃহকে পবিত্র রাখ তাওয়াফকারীদের জন্যে, নামাযে দন্ডায়মানদের জন্যে এবং রকু সেজদাকারীদের জন্যে।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmdcxxii{এবং মানুষের মধ্যে হজ্বের জন্যে ঘোষণা প্রচার কর। তারা তোমার কাছে আসবে পায়ে হেঁটে এবং সর্বপ্রকার কৃশকায় উটের পিঠে সওয়ার হয়ে দূর-দূরান্ত থেকে।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmdcxxiii{যাতে তারা তাদের কল্যাণের স্থান পর্যন্ত পৌছে এবং নির্দিষ্ট দিনগুলোতে আল্লাহর নাম স্মরণ করে তাঁর দেয়া চতুস্পদ জন্তু যবেহ করার সময়। অতঃপর তোমরা তা থেকে আহার কর এবং দুঃস্থ-অভাবগ্রস্থকে আহার করাও।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmdcxxiv{এরপর তারা যেন দৈহিক ময়লা দূর করে দেয়, তাদের মানত পূর্ণ করে এবং এই সুসংরক্ষিত গৃহের তাওয়াফ করে।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmdcxxv{এটা শ্রবণযোগ্য। আর কেউ আল্লাহর সম্মানযোগ্য বিধানাবলীর প্রতি সম্মান প্রদর্শন করলে পালনকর্তার নিকট তা তার জন্যে উত্তম। উল্লেখিত ব্যতিক্রমগুলো ছাড়া তোমাদের জন্যে চতুস্পদ জন্তু হালাল করা হয়েছে। সুতরাং তোমরা মূর্তিদের অপবিত্রতা থেকে বেঁচে থাক এবং মিথ্যা কথন থেকে দূরে সরে থাক;\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmdcxxvi{আল্লাহর দিকে একনিষ্ট হয়ে, তাঁর সাথে শরীক না করে; এবং যে কেউ আল্লাহর সাথে শরীক করল; সে যেন আকাশ থেকে ছিটকে পড়ল, অতঃপর মৃতভোজী পাখী তাকে ছোঁ মেরে নিয়ে গেল অথবা বাতাস তাকে উড়িয়ে নিয়ে কোন দূরবর্তী স্থানে নিক্ষেপ করল।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmdcxxvii{এটা শ্রবণযোগ্য কেউ আল্লাহর নামযুক্ত বস্তুসমুহের প্রতি সম্মান প্রদর্শন করলে তা তো তার হৃদয়ের আল্লাহভীতি প্রসূত।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmdcxxviii{চতুস্পদ জন্তুসমূহের মধ্যে তোমাদের জন্যে নির্দিষ্টকাল পর্যন্ত উপকার রয়েছে। অতঃপর এগুলোকে পৌছাতে হবে মুক্ত গৃহ পর্যন্ত।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmdcxxix{আমি প্রত্যেক উম্মতের জন্যে কোরবানী নির্ধারণ করেছি, যাতে তারা আল্লাহর দেয়া চতুস্পদ জন্তু যবেহ কারার সময় আল্লাহর নাম উচ্চারণ করে। অতএব তোমাদের আল্লাহ তো একমাত্র আল্লাহ সুতরাং তাঁরই আজ্ঞাধীন থাক এবং বিনয়ীগণকে সুসংবাদ দাও;\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmdcxxx{যাদের অন্তর আল্লাহর নাম স্মরণ করা হলে ভীত হয় এবং যারা তাদের বিপদাপদে ধৈর্য্যধারণ করে এবং যারা নামায কায়েম করে ও আমি যা দিয়েছি, তা থেকে ব্যয় করে।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmdcxxxi{এবং কা’বার জন্যে উৎসর্গীকৃত উটকে আমি তোমাদের জন্যে আল্লাহর অন্যতম নিদর্শন করেছি। এতে তোমাদের জন্যে মঙ্গল রয়েছে। সুতরাং সারিবদ্ধভাবে বাঁধা অবস্থায় তাদের যবেহ করার সময় তোমরা আল্লাহর নাম উচ্চারণ কর। অতঃপর যখন তারা কাত হয়ে পড়ে যায় তখন তা থেকে তোমরা আহার কর এবং আহার করাও যে কিছু যাচ্ঞা করে না তাকে এবং যে যাচ্ঞা করে তাকে। এমনিভাবে আমি এগুলোকে তোমাদের বশীভূত করে দিয়েছি, যাতে তোমরা কৃতজ্ঞতা প্রকাশ কর।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmdcxxxii{এগুলোর গোশত ও রক্ত আল্লাহর কাছে পৌঁছে না, কিন্তু পৌঁছে তাঁর কাছে তোমাদের মনের তাকওয়া। এমনিভাবে তিনি এগুলোকে তোমাদের বশ করে দিয়েছেন, যাতে তোমরা আল্লাহর মহত্ত্ব ঘোষণা কর এ কারণে যে, তিনি তোমাদের পথ প্রদর্শন করেছেন। সুতরাং সৎকর্মশীলদের সুসংবাদ শুনিয়ে দিন।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmdcxxxiii{আল্লাহ মুমিনদের থেকে শত্রুদেরকে হটিয়ে দেবেন। আল্লাহ কোন বিশ্বাসঘাতক অকৃতজ্ঞকে পছন্দ করেন না।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmdcxxxiv{যুদ্ধে অনুমতি দেয়া হল তাদেরকে যাদের সাথে কাফেররা যুদ্ধ করে; কারণ তাদের প্রতি অত্যাচার করা হয়েছে। আল্লাহ তাদেরকে সাহায্য করতে অবশ্যই সক্ষম।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmdcxxxv{যাদেরকে তাদের ঘর-বাড়ী থেকে অন্যায়ভাবে বহিস্কার করা হয়েছে শুধু এই অপরাধে যে, তারা বলে আমাদের পালনকর্তা আল্লাহ। আল্লাহ যদি মানবজাতির একদলকে অপর দল দ্বারা প্রতিহত না করতেন, তবে (খ্রীষ্টানদের) নির্ঝন গির্জা, এবাদত খানা, (ইহুদীদের) উপাসনালয় এবং মসজিদসমূহ বিধ্বস্ত হয়ে যেত, যেগুলাতে আল্লাহর নাম অধিক স্মরণ করা হয়। আল্লাহ নিশ্চয়ই তাদেরকে সাহায্য করবেন, যারা আল্লাহর সাহায্য করে। নিশ্চয়ই আল্লাহ পরাক্রমশালী শক্তিধর।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmdcxxxvi{তারা এমন লোক যাদেরকে আমি পৃথিবীতে শক্তি-সামর্থ?2470;ান করলে তারা নামায কায়েম করবে, যাকাত দেবে এবং সৎকাজে আদেশ ও অসৎকাজে নিষেধ করবে। প্রত্যেক কর্মের পরিণাম আল্লাহর এখতিয়ারভূক্ত।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmdcxxxvii{তারা যদি আপনাকে মিথ্যাবাদী বলে, তবে তাদের পূর্বে মিথ্যাবাদী বলেছে কওমে নূহ, আদ, সামুদ,\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmdcxxxviii{ইব্রাহীম ও লূতের সম্প্রদায়ও।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmdcxxxix{এবং মাদইয়ানের অধিবাসীরা এবং মিথ্যাবাদী বলা হয়েছিল মূসাকেও। অতঃপর আমি কাফেরদেরকে সুযোগ দিয়েছিলাম এরপর তাদেরকে পাকড়াও করেছিলাম অতএব কি ভীষণ ছিল আমাকে অস্বীকৃতির পরিণাম।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmdcxl{আমি কত জনপদ ধ্বংস করেছি এমতাবস্থায় যে, তারা ছিল গোনাহগার। এই সব জনপদ এখন ধ্বংসস্তুপে পরিণত হয়েছে এবং কত কূপ পরিত্যক্ত হয়েছে ও কত সুদৃঢ় প্রাসাদ ধ্বংস হয়েছে।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmdcxli{তারা কি এই উদ্দেশ্যে দেশ ভ্রমণ করেনি, যাতে তারা সমঝদার হৃদয় ও শ্রবণ শক্তি সম্পন্ন কর্ণের অধিকারী হতে পারে? বস্তুতঃ চক্ষু তো অন্ধ হয় না, কিন্তু বক্ষ স্থিত অন্তরই অন্ধ হয়।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmdcxlii{তারা আপনাকে আযাব ত্বরান্বিত করতে বলে। অথচ আল্লাহ কখনও তাঁর ওয়াদা ভঙ্গ করেন না। আপনার পালনকর্তার কাছে একদিন তোমাদের গণনার এক হাজার বছরের সমান।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmdcxliii{এবং আমি কত জনপদকে অবকাশ দিয়েছি এমতাবস্থায় যে, তারা গোনাহগার ছিল। এরপর তাদেরকে পাকড়াও করেছি এবং আমার কাছেই প্রত্যাবর্তন করতে হবে।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmdcxliv{বলুনঃ হে লোক সকল! আমি তো তোমাদের জন্যে স্পষ্ট ভাষায় সতর্ককারী।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmdcxlv{সুতরাং যারা বিশ্বাস স্থাপন করেছে এবং সৎকর্ম করেছে, তাদের জন্যে আছে পাপ মার্জনা এবং সম্মানজনক রুযী।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmdcxlvi{এবং যারা আমার আয়াতসমূহকে ব্যর্থ করার জন্যে চেষ্টা করে, তারাই দোযখের অধিবাসী।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmdcxlvii{আমি আপনার পূর্বে যে সমস্ত রাসূল ও নবী প্রেরণ করেছি, তারা যখনই কিছু কল্পনা করেছে, তখনই শয়তান তাদের কল্পনায় কিছু মিশ্রণ করে দিয়েছে। অতঃপর আল্লাহ দূর করে দেন শয়তান যা মিশ্রণ করে। এরপর আল্লাহ তাঁর আয়াতসমূহকে সু-প্রতিষ্ঠিত করেন এবং আল্লাহ জ্ঞানময়, প্রজ্ঞাময়।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmdcxlviii{এ কারণে যে, শয়তান যা মিশ্রণ করে, তিনি তা পরীক্ষাস্বরূপ করে দেন, তাদের জন্যে, যাদের অন্তরে রোগ আছে এবং যারা পাষাণহৃদয়। গোনাহগাররা দূরবর্তী বিরোধিতায় লিপ্ত আছে।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmdcxlix{এবং এ কারণেও যে, যাদেরকে জ্ঞানদান করা হয়েছে; তারা যেন জানে যে এটা আপনার পালনকর্তার পক্ষ থেকে সত্য; অতঃপর তারা যেন এতে বিশ্বাস স্তাপন করে এবং তাদের অন্তর যেন এর প্রতি বিজয়ী হয়। আল্লাহই বিশ্বাস স্থাপনকারীকে সরল পথ প্রদর্শন করেন।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmdcl{কাফেররা সর্বদাই সন্দেহ পোষন করবে যে পর্যন্ত না তাদের কাছে আকস্মিকভাবে কেয়ামত এসে পড়ে অথবা এসে পড়ে তাদের কাছে এমন দিবসের শাস্তি যা থেকে রক্ষার উপায় নেই।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mmdcli{রাজত্ব সেদিন আল্লাহরই; তিনিই তাদের বিচার করবেন। অতএব যারা বিশ্বাস স্থাপন করে এবং সৎকর্ম সম্পাদন করে তারা নেয়ামত পূর্ণ কাননে থাকবে।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mmdclii{এবং যারা কুফরি করে এবং আমার আয়াত সমূহকে মিথ্যা বলে তাদের জন্যে লাঞ্ছনাকর শাস্তি রয়েছে।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mmdcliii{যারা আল্লাহর পথে গৃহ ত্যাগ করেছে, এরপর নিহত হয়েছে অথবা মরে গেছে; আল্লাহ তাদেরকে অবশ্যই উৎকৃষ্ট জীবিকা দান করবেন এবং আল্লাহ সর্বোৎকৃষ্ট রিযিক দাতা।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mmdcliv{তাদেরকে অবশ্যই এমন এক স্থানে পৌছাবেন, যাকে তারা পছন্দ করবে এবং আল্লাহ জ্ঞানময়, সহনশীল।\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mmdclv{এ তো শুনলে, যে ব্যক্তি নিপীড়িত হয়ে নিপীড়ন পরিমাণে প্রতিশোধ গ্রহণ করে এবং পুনরায় সে নিপীড়িত হয়, আল্লাহ অবশ্যই তাকে সাহায্য করবেন। নিশ্চয় আল্লাহ মার্জনাকারী ক্ষমাশীল।\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mmdclvi{এটা এ জন্যে যে, আল্লাহ রাত্রিকে দিনের মধ্যে এবং দিনকে রাত্রির মধ্য দাখিল করে দেন এবং আল্লাহ সবকিছু শোনেন, দেখেন।\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mmdclvii{এটা এ কারণেও যে, আল্লাহই সত্য; আর তাঁর পরিবর্তে তারা যাকে ডাকে, তা অসত্য এবং আল্লাহই সবার উচ্চে, মহান।\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mmdclviii{তুমি কি দেখ না যে, আল্লাহ আকাশ থেকে পানি বর্ষণ করেন, অতঃপর ভূপৃষ্ট সবুজ-শ্যামল হয়ে উঠে। নিশ্চয় আল্লাহ সুক্ষদর্শী, সর্ববিষয়ে খবরদার।\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mmdclix{নভোমন্ডল ও ভুপৃষ্ঠে যা কিছু আছে, সব তাঁরই এবং আল্লাহই অভাবমুক্ত প্রশংসার অধিকারী।\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mmdclx{তুমি কি দেখ না যে, ভূপৃষ্টে যা আছে এবং সমুদ্রে চলমান নৌকা তৎসমুদয়কে আল্লাহ নিজ আদেশে তোমাদের অধীন করে দিয়েছেন এবং তিনি আকাশ স্থির রাখেন, যাতে তাঁর আদেশ ব্যতীত ভূপৃষ্টে পতিত না হয়। নিশ্চয় আল্লাহ মানুষের প্রতি করুণাশীল, দয়াবান।\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mmdclxi{তিনিই তোমাদেরকে জীবিত করেছেন, অতঃপর তিনিই তোমাদেরকে মৃত্যুদান করবেন ও পুনরায় জীবিত করবেন। নিশ্চয় মানুষ বড় অকৃতজ্ঞ।\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mmdclxii{আমি প্রত্যেক উম্মতের জন্যে এবাদতের একটি নিয়ম-কানুন নির্ধারণ করে দিয়েছি, যা তারা পালন করে। অতএব তারা যেন এ ব্যাপারে আপনার সাথে বিতর্ক না করে। আপনি তাদেরকে পালনকর্তার দিকে আহবান করুন। নিশ্চয় আপনি সরল পথেই আছেন।\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mmdclxiii{তারা যদি আপনার সাথে বিতর্ক করে, তবে বলে দিন, তোমরা যা কর, সে সর্ম্পকে আল্লাহ অধিক জ্ঞাত।\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mmdclxiv{তোমরা যে বিষয়ে মতবিরোধ করছ, আল্লাহ কিয়ামতের দিন সেই বিষয়ে তোমাদের মধ্যে ফায়সালা করবেন।\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mmdclxv{তুমি কি জান না যে, আল্লাহ জানেন যা কিছু আকাশে ও ভুমন্ডলে আছে এসব কিতাবে লিখিত আছে। এটা আল্লাহর কাছে সহজ।\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@mmdclxvi{তারা আল্লাহর পরিবর্তে এমন কিছুর পূজা করে, যার কোন সনদ নাযিল করা হয়নি এবং সে সম্পর্কে তাদের কোন জ্ঞান নেই। বস্তুতঃ জালেমদের কোন সাহায্যকারী নেই।\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@mmdclxvii{যখন তাদের কাছে আমার সুস্পষ্ট আয়াতসমূহ আবৃত্তি করা হয়, তখন তুমি কাফেরদের চোখে মুখে অসন্তোষের লক্ষণ প্রত্যক্ষ করতে পারবে। যারা তাদের কাছে আমার আয়াত সমূহ পাঠ করে, তারা তাদের প্রতি মার মুখো হয়ে উঠে। বলুন, আমি কি তোমাদেরকে তদপেক্ষা মন্দ কিছুর সংবাদ দেব? তা আগুন; আল্লাহ কাফেরদেরকে এর ওয়াদা দিয়েছেন। এটা কতই না নিকৃষ্ট প্রত্যাবর্তনস্থল।\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@mmdclxviii{হে লোক সকল! একটি উপমা বর্ণনা করা হলো, অতএব তোমরা তা মনোযোগ দিয়ে শোন; তোমরা আল্লাহর পরিবর্তে যাদের পূজা কর, তারা কখনও একটি মাছি সৃষ্টি করতে পারবে না, যদিও তারা সকলে একত্রিত হয়। আর মাছি যদি তাদের কাছ থেকে কোন কিছু ছিনিয়ে নেয়, তবে তারা তার কাছ থেকে তা উদ্ধার করতে পারবে না, প্রার্থনাকারী ও যার কাছে প্রার্থনা করা হয়, উভয়েই শক্তিহীন।\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@mmdclxix{তারা আল্লাহর যথাযোগ্য মর্যাদা বোঝেনি। নিশ্চয় আল্লাহ শক্তিধর, মহাপরাক্রমশীল।\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@mmdclxx{আল্লাহ ফেরেশতা ও মানুষের মধ্য থেকে রাসূল মনোনীত করেন। আল্লাহ সর্বশ্রোতা, সর্ব দ্রষ্টা!\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@mmdclxxi{তিনি জানেন যা তাদের সামনে আছে এবং যা পশ্চাতে আছে এবং সবকিছু আল্লাহর দিকে প্রত্যাবর্তিত হবে।\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@mmdclxxii{হে মুমিনগণ! তোমরা রুকু কর, সেজদা কর, তোমাদের পালনকর্তার এবাদত কর এবং সৎকাজ সম্পাদন কর, যাতে তোমরা সফলকাম হতে পার।\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@mmdclxxiii{তোমরা আল্লাহর জন্যে শ্রম স্বীকার কর যেভাবে শ্রম স্বীকার করা উচিত। তিনি তোমাদেরকে পছন্দ করেছেন এবং ধর্মের ব্যাপারে তোমাদের উপর কোন সংকীর্ণতা রাখেননি। তোমরা তোমাদের পিতা ইব্রাহীমের ধর্মে কায়েম থাক। তিনিই তোমাদের নাম মুসলমান রেখেছেন পূর্বেও এবং এই কোরআনেও, যাতে রসূল তোমাদের জন্যে সাক্ষ্যদাতা এবং তোমরা সাক্ষ্যদাতা হও মানবমন্ডলির জন্যে। সুতরাং তোমরা নামায কায়েম কর, যাকাত দাও এবং আল্লাহকে শক্তভাবে ধারণ কর। তিনিই তোমাদের মালিক। অতএব তিনি কত উত্তম মালিক এবং কত উত্তম সাহায্যকারী।\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@mmdclxxiv{\basmalahbn মুমিনগণ সফলকাম হয়ে গেছে,\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmdclxxv{যারা নিজেদের নামাযে বিনয়-নম্র;\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmdclxxvi{যারা অনর্থক কথা-বার্তায় নির্লিপ্ত,\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmdclxxvii{যারা যাকাত দান করে থাকে\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmdclxxviii{এবং যারা নিজেদের যৌনাঙ্গকে সংযত রাখে।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmdclxxix{তবে তাদের স্ত্রী ও মালিকানাভুক্ত দাসীদের ক্ষেত্রে সংযত না রাখলে তারা তিরস্কৃত হবে না।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmdclxxx{অতঃপর কেউ এদেরকে ছাড়া অন্যকে কামনা করলে তারা সীমালংঘনকারী হবে।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmdclxxxi{এবং যারা আমানত ও অঙ্গীকার সম্পর্কে হুশিয়ার থাকে।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmdclxxxii{এবং যারা তাদের নামাযসমূহের খবর রাখে।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmdclxxxiii{তারাই উত্তরাধিকার লাভ করবে।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmdclxxxiv{তারা শীতল ছায়াময় উদ্যানের উত্তরাধিকার লাভ করবে। তারা তাতে চিরকাল থাকবে।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmdclxxxv{আমি মানুষকে মাটির সারাংশ থেকে সৃষ্টি করেছি।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmdclxxxvi{অতঃপর আমি তাকে শুক্রবিন্দু রূপে এক সংরক্ষিত আধারে স্থাপন করেছি।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmdclxxxvii{এরপর আমি শুক্রবিন্দুকে জমাট রক্তরূপে সৃষ্টি করেছি, অতঃপর জমাট রক্তকে মাংসপিন্ডে পরিণত করেছি, এরপর সেই মাংসপিন্ড থেকে অস্থি সৃষ্টি করেছি, অতঃপর অস্থিকে মাংস দ্বারা আবৃত করেছি, অবশেষে তাকে নতুন রূপে দাঁড় করিয়েছি। নিপুণতম সৃষ্টিকর্তা আল্লাহ কত কল্যাণময়।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmdclxxxviii{এরপর তোমরা মৃত্যুবরণ করবে\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmdclxxxix{অতঃপর কেয়ামতের দিন তোমরা পুনরুত্থিত হবে।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmdcxc{আমি তোমাদের উপর সুপ্তপথ সৃষ্টি করেছি এবং আমি সৃষ্টি সম্বন্ধে অনবধান নই।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmdcxci{আমি আকাশ থেকে পানি বর্ষণ করে থাকি পরিমাণ মত অতঃপর আমি জমিনে সংরক্ষণ করি এবং আমি তা অপসারণও করতে সক্ষম।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmdcxcii{অতঃপর আমি তা দ্বারা তোমাদের জন্যে খেজুর ও আঙ্গুরের বাগান সৃষ্টি করেছি। তোমাদের জন্যে এতে প্রচুর ফল আছে এবং তোমরা তা থেকে আহার করে থাক।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmdcxciii{এবং ঐ বৃক্ষ সৃষ্টি করেছি, যা সিনাই পর্বতে জন্মায় এবং আহারকারীদের জন্যে তৈল ও ব্যঞ্জন উৎপন্ন করে।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmdcxciv{এবং তোমাদের জন্যে চতুস্পদ জন্তু সমূহের মধ্যে চিন্তা করার বিষয় রয়েছে। আমি তোমাদেরকে তাদের উদরস্থিত বস্তু থেকে পান করাই এবং তোমাদের জন্যে তাদের মধ্যে প্রচুর উপকারিতা আছে। তোমরা তাদের কতককে ভক্ষণ কর।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmdcxcv{তাদের পিঠে ও জলযানে তোমরা আরোহণ করে চলাফেরা করে থাক।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmdcxcvi{আমি নূহকে তার সম্প্রদায়ের কাছে প্রেরণ করেছিলাম। সে বলেছিলঃ হে আমার সম্প্রদায়, তোমরা আল্লাহর বন্দেগী কর। তিনি ব্যতীত তোমাদের কোন মাবুদ নেই। তোমরা কি ভয় কর না।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmdcxcvii{তখন তার সম্প্রদায়ের কাফের-প্রধানরা বলেছিলঃ এ তো তোমাদের মতই একজন মানুষ বৈ নয়। সে তোমাদের উপর নেতৃত্ব করতে চায়। আল্লাহ ইচ্ছা করলে ফেরেশতাই নাযিল করতেন। আমরা আমাদের পূর্বপুরুষদের মধ্যে এরূপ কথা শুনিনি।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmdcxcviii{সে তো এক উম্মাদ ব্যক্তি বৈ নয়। সুতরাং কিছুকাল তার ব্যাপারে অপেক্ষা কর।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmdcxcix{নূহ বলেছিলঃ হে আমার পালনকর্তা, আমাকে সাহায্য কর; কেননা, তারা আমাকে মিথ্যাবাদী বলছে।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmdcc{অতঃপর আমি তার কাছে আদেশ প্রেরণ করলাম যে, তুমি আমার দৃষ্টির সামনে এবং আমার নির্দেশে নৌকা তৈরী কর। এরপর যখন আমার আদেশ আসে এবং চুল্লী প্লাবিত হয়, তখন নৌকায় তুলে নাও, প্রত্যেক জীবের এক এক জোড়া এবং তোমার পরিবারবর্গকে, তাদের মধ্যে যাদের বিপক্ষে পূর্বে সিদ্ধান্ত নেয়া হয়েছে তাদের ছাড়া। এবং তুমি জালেমদের সম্পর্কে আমাকে কিছু বলো না। নিশ্চয় তারা নিমজ্জত হবে।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmdcci{যখন তুমি ও তোমার সঙ্গীরা নৌকায় আরোহণ করবে, তখন বলঃ আল্লাহর শোকর, যিনি আমাদেরকে জালেম সম্প্রদায়ের কবল থেকে উদ্ধার করেছেন।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmdccii{আরও বলঃ পালনকর্তা, আমাকে কল্যাণকর ভাবে নামিয়ে দাও, তুমি শ্রেষ্ঠ অবতারণকারী।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmdcciii{এতে নিদর্শনাবলী রয়েছে এবং আমি পরীক্ষাকারী।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmdcciv{অতঃপর অন্য এক সম্প্রদায় আমি তার স্থলাভিষিক্ত করেছিলাম।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmdccv{এবং তাদেরই একজনকে তাদের মধ্যে রসূলরূপে প্রেরণ করেছিলাম এই বলে যে, তোমরা আল্লাহর বন্দেগী কর। তিনি ব্যতীত তোমাদের অন্য কোন মাবুদ নেই। তবুও কি তোমরা ভয় করবে না?\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmdccvi{তাঁর সম্প্রদায়ের প্রধানরা যারা কাফের ছিল, পরকালের সাক্ষাতকে মিথ্যা বলত এবং যাদেরকে আমি পার্থিব জীবনে সুখ-স্বাচ্ছন্দ্য দিয়েছিলাম, তারা বললঃ এতো আমাদের মতই একজন মানুষ বৈ নয়। তোমরা যা খাও, সেও তাই খায় এবং তোমরা যা পান কর, সেও তাই পান করে।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmdccvii{যদি তোমরা তোমাদের মতই একজন মানুষের আনুগত্য কর, তবে তোমরা নিশ্চিতরূপেই ক্ষতিগ্রস্ত হবে।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmdccviii{সে কি তোমাদেরকে এই ওয়াদা দেয় যে, তোমরা মারা গেলে এবং মৃত্তিকা ও অস্থিতে পরিণত হলে তোমাদেরকে পুনরুজ্জীবিত করা হবে?\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmdccix{তোমাদেরকে যে ওয়াদা দেয়া হচ্ছে, তা কোথায় হতে পারে?\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmdccx{আমাদের পার্থিবজীবনই একমাত্র জীবন। আমরা মরি ও বাঁচি এখানেই এবং আমারা পুনরুত্থিত হবো না।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmdccxi{সে তো এমন ব্যক্তি বৈ নয়, যে আল্লাহ সম্বন্ধে মিথ্যা উদ্ভাবন করেছে এবং আমরা তাকে বিশ্বাস করি না।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmdccxii{তিনি বললেনঃ হে আমার পালনকর্তা, আমাকে সাহায্য কর, কারণ তারা আমাকে মিথ্যাবাদী বলছে।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmdccxiii{আল্লাহ বললেনঃ কিছু দিনের মধ্যে তারা সকাল বেলা অনুতপ্ত হবে।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmdccxiv{অতঃপর সত্য সত্যই এক ভয়ংকর শব্দ তাদেরকে হতচকিত করল এবং আমি তাদেরকে বাত্যা-তাড়িত আবর্জনা সদৃশ করে দিলাম। অতঃপর ধ্বংস হোক পাপী সম্প্রদায়।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmdccxv{এরপর তাদের পরে আমি বহু সম্প্রদায় সৃষ্টি করেছি।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmdccxvi{কোন সম্প্রদায় তার নির্দিষ্ট কালের অগ্রে যেতে পারে না। এবং পশ্চাতেও থকাতে পারে না।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmdccxvii{এরপর আমি একাদিক্রমে আমার রসূল প্রেরণ করেছি। যখনই কোন উম্মতের কাছে তাঁর রসূল আগমন করেছেন, তখনই তারা তাঁকে মিথ্যাবাদী বলেছে। অতঃপর আমি তাদের একের পর এক ধ্বংস করেছি এবং তাদেরকে কাহিনীর বিষয়ে পরিণত করেছি। সুতরাং ধ্বংস হোক অবিশ্বাসীরা।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmdccxviii{অতঃপর আমি মূসা ও হারুণকে প্রেরণ করেছিলাম আমার নিদর্শনাবলী ও সুস্পষ্ট সনদসহ,\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmdccxix{ফেরআউন ও তার অমাত্যদের কাছে। অতঃপর তারা অহংকার করল এবং তারা উদ্ধত সম্প্রদায় ছিল।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmdccxx{তারা বললঃ আমরা কি আমাদের মতই এ দুই ব্যক্তিতে বিশ্বাস স্থাপন করব; অথচ তাদের সম্প্রদায় আমাদের দাস?\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmdccxxi{অতঃপর তারা উভয়কে মিথ্যাবাদী বলল। ফলে তারা ধ্বংস প্রাপ্ত হল।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmdccxxii{আমি মূসাকে কিতাব দিয়েছিলাম যাতে তারা সৎপথ পায়।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmdccxxiii{এবং আমি মরিয়ম তনয় ও তাঁর মাতাকে এক নিদর্শন দান করেছিলাম। এবং তাদেরকে এক অবস্থানযোগ্য স্বচ্ছ পানি বিশিষ্ট টিলায় আশ্রয় দিয়েছিলাম।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmdccxxiv{হে রসূলগণ, পবিত্র বস্তু আহার করুন এবং সৎকাজ করুন। আপনারা যা করেন সে বিষয়ে আমি পরিজ্ঞাত।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmdccxxv{আপনাদের এই উম্মত সব তো একই ধর্মের অনুসারী এবং আমি আপনাদের পালনকর্তা; অতএব আমাকে ভয় করুন।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmdccxxvi{অতঃপর মানুষ তাদের বিষয়কে বহুধা বিভক্ত করে দিয়েছে। প্রত্যেক সম্প্রদায় নিজ নিজ মতবাদ নিয়ে আনন্দিত হচ্ছে।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmdccxxvii{অতএব তাদের কিছু কালের জন্যে তাদের অজ্ঞানতায় নিমজ্জত থাকতে দিন।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmdccxxviii{তারা কি মনে করে যে, আমি তাদেরকে ধন-সম্পদ ও সন্তান-সন্ততি দিয়ে যাচ্ছি।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mmdccxxix{তাতে করে তাদেরকে দ্রুত মঙ্গলের দিকে নিয়ে যাচ্ছি? বরং তারা বোঝে না।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mmdccxxx{নিশ্চয় যারা তাদের পালনকর্তার ভয়ে সন্ত্রস্ত,\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mmdccxxxi{যারা তাদের পালনকর্তার কথায় বিশ্বাস স্থাপন করে,\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mmdccxxxii{যারা তাদের পালনকর্তার সাথে কাউকে শরীক করে না\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mmdccxxxiii{এবং যারা যা দান করবার, তা ভীত, কম্পিত হৃদয়ে এ কারণে দান করে যে, তারা তাদের পালনকর্তার কাছে প্রত্যাবর্তন করবে,\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mmdccxxxiv{তারাই কল্যাণ দ্রুত অর্জন করে এবং তারা তাতে অগ্রগামী।\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mmdccxxxv{আমি কাউকে তার সাধ্যাতীত দায়িত্ব অর্পন করি না। আমার এক কিতাব আছে, যা সত্য ব্যক্ত করে এবং তাদের প্রতি জুলুম করা হবে না।\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mmdccxxxvi{না, তাদের অন্তর এ বিষয়ে অজ্ঞানতায় আচ্ছন্ন, এ ছাড়া তাদের আরও কাজ রয়েছে, যা তারা করছে।\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mmdccxxxvii{এমনকি, যখন আমি তাদের ঐশ্বর্যশালী লোকদেরকে শাস্তি দ্বারা পাকড়াও করব, তখনই তারা চীৎকার জুড়ে দেবে।\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mmdccxxxviii{অদ্য চীৎকার করো না। তোমরা আমার কাছ থেকে নিস্কৃতি পাবে না।\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mmdccxxxix{তোমাদেরকে আমার আয়াতসমূহ শোনানো হত, তখন তোমরা উল্টো পায়ে সরে পড়তে।\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mmdccxl{অহংকার করে এ বিষয়ে অর্থহীন গল্প-গুজব করে যেতে।\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mmdccxli{অতএব তারা কি এই কালাম সম্পꦣ2503;ক চিন্তা-ভাবনা করে না? না তাদের কাছে এমন কিছু এসেছে, যা তাদের পিতৃপুরুষদের কাছে আসেনি?\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mmdccxlii{না তারা তাদের রসূলকে চেনে না, ফলে তারা তাঁকে অস্বীকার করে?\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mmdccxliii{না তারা বলে যে, তিনি পাগল ? বরং তিনি তাদের কাছে সত্য নিয়ে আগমন করেছেন এবং তাদের অধিকাংশ সত্যকে অপছন্দ করে।\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@mmdccxliv{সত্য যদি তাদের কাছে কামনা-বাসনার অনুসারী হত, তবে নভোমন্ডল ও ভূমন্ডল এবং এগুলোর মধ্যবর্তꦣ2496; সবকিছুই বিশৃঙ্খল হয়ে পড়ত। বরং আমি তাদেরকে দান করেছি উপদেশ, কিন্তু তারা তাদের উপদেশ অনুধাবন করে না।\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@mmdccxlv{না আপনি তাদের কাছে কোন প্রতিদান চান? আপনার পালনকর্তার প্রতিদান উত্তম এবং তিনিই রিযিকদাতা।\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@mmdccxlvi{আপনি তো তাদেরকে সোজা পথে দাওয়াত দিচ্ছেন;\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@mmdccxlvii{আর যারা পরকালে বিশ্বাস করে না, তারা সোজা পথ থেকে বিচ্যুত হয়ে গেছে।\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@mmdccxlviii{যদি আমি তাদের প্রতি দয়া করি এবং তাদের কষ্ট দূর করে দেই, তবুও তারা তাদের অবাধ্যতায় দিশেহারা হয়ে লেগে থাকবে।\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@mmdccxlix{আমি তাদেরকে শাস্তি দ্বারা পাকড়াও করেছিলাম, কিন্তু তারা তাদের পালনকর্তার সামনে নত হল না এবং কাকুতি-মিনুতিও করল না।\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@mmdccl{অবশেষে যখন আমি তাদের জন্য কঠিন শাস্তির দ্বার খুলে দেব, তখন তাতে তাদের আশা ভঙ্গ হবে।\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@mmdccli{তিনি তোমাদের কান, চোখ ও অন্তঃকরণ সৃষ্টি করেছেন; তোমরা খুবই অল্প কৃতজ্ঞতা স্বীকার করে থাক।\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@mmdcclii{তিনিই তোমাদেরকে পৃথিবীতে ছড়িয়ে রেখেছেন এবং তারই দিকে তোমাদেরকে সমবেত করা হবে।\qt@no{(79)}}
\qt@newcmd\qurantrans@bn@mmdccliii{তিনিই প্রাণ দান করেন এবং মৃত্যু ঘটান এবং দিবা-রাত্রির বিবর্তন তাঁরই কাজ, তবু ও কি তোমরা বুঝবে না?\qt@no{(80)}}
\qt@newcmd\qurantrans@bn@mmdccliv{বরং তারা বলে যেমন তাদের পূর্ববর্তীরা বলত।\qt@no{(81)}}
\qt@newcmd\qurantrans@bn@mmdcclv{তারা বলেঃ যখন আমরা মরে যাব এবং মৃত্তিকা ও অস্থিতে পরিণত হব, তখনও কি আমরা পুনরুত্থিত হব ?\qt@no{(82)}}
\qt@newcmd\qurantrans@bn@mmdcclvi{অতীতে আমাদেরকে এবং আমাদের পিতৃপুরুষদেরকে এই ওয়াদাই দেয়া হয়েছে। এটা তো পূর্ববতীদের কল্প-কথা বৈ কিছুই নয়।\qt@no{(83)}}
\qt@newcmd\qurantrans@bn@mmdcclvii{বলুন পৃথিবী এবং পৃথিবীতে যারা আছে, তারা কার? যদি তোমরা জান, তবে বল।\qt@no{(84)}}
\qt@newcmd\qurantrans@bn@mmdcclviii{এখন তারা বলবেঃ সবই আল্লাহর। বলুন, তবুও কি তোমরা চিন্তা কর না?\qt@no{(85)}}
\qt@newcmd\qurantrans@bn@mmdcclix{বলুনঃ সপ্তাকাশ ও মহা-আরশের মালিক কে?\qt@no{(86)}}
\qt@newcmd\qurantrans@bn@mmdcclx{এখন তারা বলবেঃ আল্লাহ। বলুন, তবুও কি তোমরা ভয় করবে না?\qt@no{(87)}}
\qt@newcmd\qurantrans@bn@mmdcclxi{বলুনঃ তোমাদের জানা থাকলে বল, কার হাতে সব বস্তুর কতৃর্ꦣ2468;্ব, যিনি রক্ষা করেন এবং যার কবল থেকে কেউ রক্ষা করতে পারে না ?\qt@no{(88)}}
\qt@newcmd\qurantrans@bn@mmdcclxii{এখন তারা বলবেঃ আল্লাহর। বলুনঃ তাহলে কোথা থেকে তোমাদেরকে জাদু করা হচ্ছে?\qt@no{(89)}}
\qt@newcmd\qurantrans@bn@mmdcclxiii{কিছুই নয়, আমি তাদের কাছে সত্য পৌঁছিয়েছি, আর তারা তো মিথ্যাবাদী।\qt@no{(90)}}
\qt@newcmd\qurantrans@bn@mmdcclxiv{আল্লাহ কোন সন্তান গ্রহণ করেননি এবং তাঁর সাথে কোন মাবুদ নেই। থাকলে প্রত্যেক মাবুদ নিজ নিজ সৃষ্টি নিয়ে চলে যেত এবং একজন অন্যজনের উপর প্রবল হয়ে যেত। তারা যা বলে, তা থেকে আল্লাহ পবিত্র।\qt@no{(91)}}
\qt@newcmd\qurantrans@bn@mmdcclxv{তিনি দৃশ্য ও অদৃশ্যের জ্ঞানী। তারা শরীক করে, তিনি তা থেকে উর্ধ্বে।\qt@no{(92)}}
\qt@newcmd\qurantrans@bn@mmdcclxvi{বলুনঃ হে আমার পালনকর্তা! যে বিষয়ে তাদেরকে ওয়াদা দেয়া হয়েছে তা যদি আমাকে দেখান,\qt@no{(93)}}
\qt@newcmd\qurantrans@bn@mmdcclxvii{হে আমার পালনকর্তা! তবে আপনি আমাকে গোনাহগার সম্প্রদায়ের অন্তর্ভূক্ত করবেন না।\qt@no{(94)}}
\qt@newcmd\qurantrans@bn@mmdcclxviii{আমি তাদেরকে যে বিষয়ের ওয়াদা দিয়েছি, তা আপনাকে দেখাতে অবশ্যই সক্ষম।\qt@no{(95)}}
\qt@newcmd\qurantrans@bn@mmdcclxix{মন্দের জওয়াবে তাই বলুন, যা উত্তম। তারা যা বলে, আমি সে বিষয়ে সবিশেষ অবগত।\qt@no{(96)}}
\qt@newcmd\qurantrans@bn@mmdcclxx{বলুনঃ হে আমার পালনকর্তা! আমি শয়তানের প্ররোচনা থেকে আপনার আশ্রয় প্রার্থনা করি,\qt@no{(97)}}
\qt@newcmd\qurantrans@bn@mmdcclxxi{এবং হে আমার পালনকর্তা! আমার নিকট তাদের উপস্থিতি থেকে আপনার আশ্রয় প্রার্থনা করি।\qt@no{(98)}}
\qt@newcmd\qurantrans@bn@mmdcclxxii{যখন তাদের কারও কাছে মৃত্যু আসে, তখন সে বলেঃ হে আমার পালণকর্তা! আমাকে পুনরায় (দুনিয়াতে ) প্রেরণ করুন।\qt@no{(99)}}
\qt@newcmd\qurantrans@bn@mmdcclxxiii{যাতে আমি সৎকর্ম করতে পারি, যা আমি করিনি। কখনই নয়, এ তো তার একটি কথার কথা মাত্র। তাদের সামনে পর্দা আছে পুনরুত্থান দিবস পর্যন্ত।\qt@no{(100)}}
\qt@newcmd\qurantrans@bn@mmdcclxxiv{অতঃপর যখন শিংগায় ফুৎকার দেয়া হবে, সেদিন তাদের পারস্পরিক আত্নীয়তার বন্ধন থাকবে না এবং একে অপরকে জিজ্ঞাসাবাদ করবে না।\qt@no{(101)}}
\qt@newcmd\qurantrans@bn@mmdcclxxv{যাদের পাল্লা ভারী হবে, তারাই হবে সফলকাম,\qt@no{(102)}}
\qt@newcmd\qurantrans@bn@mmdcclxxvi{এবং যাদের পাল্লা হাল্কা হবে তারাই নিজেদের ক্ষতিসাধন করেছে, তারা দোযখেই চিরকাল বসবাস করবে।\qt@no{(103)}}
\qt@newcmd\qurantrans@bn@mmdcclxxvii{আগুন তাদের মুখমন্ডল দগ্ধ করবে এবং তারা তাতে বীভৎস আকার ধারন করবে।\qt@no{(104)}}
\qt@newcmd\qurantrans@bn@mmdcclxxviii{তোমাদের সামনে কি আমার আয়াত সমূহ পঠিত হত না? তোমরা তো সেগুলোকে মিথ্যা বলতে।\qt@no{(105)}}
\qt@newcmd\qurantrans@bn@mmdcclxxix{তারা বলবেঃ হে আমাদের পালনকর্তা, আমরা দূর্ভাগ্যের হাতে পরাভূত ছিলাম এবং আমরা ছিলাম বিভ্রান্ত জাতি।\qt@no{(106)}}
\qt@newcmd\qurantrans@bn@mmdcclxxx{হে আমাদের পালনকর্তা! এ থেকে আমাদেরকে উদ্ধার কর; আমরা যদি পুনরায় তা করি, তবে আমরা গোনাহগার হব।\qt@no{(107)}}
\qt@newcmd\qurantrans@bn@mmdcclxxxi{আল্লাহ বলবেনঃ তোমরা ধিকৃত অবস্থায় এখানেই পড়ে থাক এবং আমার সাথে কোন কথা বলো না।\qt@no{(108)}}
\qt@newcmd\qurantrans@bn@mmdcclxxxii{আমার বান্দাদের একদলে বলতঃ হে আমাদের পালনকর্তা! আমরা বিশ্বাস স্থাপন করেছি। অতএব তুমি আমাদেরকে ক্ষমা কর ও আমাদের প্রতি রহম কর। তুমি তো দয়ালুদের মধ্যে শ্রেষ্ঠ দয়ালু।\qt@no{(109)}}
\qt@newcmd\qurantrans@bn@mmdcclxxxiii{অতঃপর তোমরা তাদেরকে ঠাট্টার পাত্ররূপে গ্রহণ করতে। এমনকি, তা তোমাদেরকে আমার স্মরণ ভুলিয়ে দিয়েছিল এবং তোমরা তাদেরকে দেখে পরিহাস করতে।\qt@no{(110)}}
\qt@newcmd\qurantrans@bn@mmdcclxxxiv{আজ আমি তাদেরকে তাদের সবরের কারণে এমন প্রতিদান দিয়েছি যে, তারাই সফলকাম।\qt@no{(111)}}
\qt@newcmd\qurantrans@bn@mmdcclxxxv{আল্লাহ বলবেনঃ তোমরা পৃথিবীতে কতদিন অবস্থান করলে বছরের গণনায়?\qt@no{(112)}}
\qt@newcmd\qurantrans@bn@mmdcclxxxvi{তারা বলবে, আমরা একদিন অথবা দিনের কিছু অংশ অবস্থান করেছি। অতএব আপনি গণনাকারীদেরকে জিজ্ঞেস করুন।\qt@no{(113)}}
\qt@newcmd\qurantrans@bn@mmdcclxxxvii{আল্লাহ বলবেনঃ তোমরা তাতে অল্পদিনই অবস্থান করেছ, যদি তোমরা জানতে?\qt@no{(114)}}
\qt@newcmd\qurantrans@bn@mmdcclxxxviii{তোমরা কি ধারণা কর যে, আমি তোমাদেরকে অনর্থক সৃষ্টি করেছি এবং তোমরা আমার কাছে ফিরে আসবে না?\qt@no{(115)}}
\qt@newcmd\qurantrans@bn@mmdcclxxxix{অতএব শীর্ষ মহিমায় আল্লাহ, তিনি সত্যিকার মালিক, তিনি ব্যতীত কোন মাবুদ নেই। তিনি সম্মানিত আরশের মালিক।\qt@no{(116)}}
\qt@newcmd\qurantrans@bn@mmdccxc{যে কেউ আল্লাহর সাথে অন্য উপাস্যকে ডাকে, তার কাছে যার সনদ নেই, তার হিসাব তার পালণকর্তার কাছে আছে। নিশ্চয় কাফেররা সফলকাম হবে না।\qt@no{(117)}}
\qt@newcmd\qurantrans@bn@mmdccxci{বলূনঃ হে আমার পালনকর্তা, ক্ষমা করুন ও রহম করুন। রহমকারীদের মধ্যে আপনি শ্রেষ্ট রহমকারী।\qt@no{(118)}}
\qt@newcmd\qurantrans@bn@mmdccxcii{\basmalahbn এটা একটা সূরা যা আমি নাযিল করেছি, এবং দায়িত্বে অপরিহার্য করেছি। এতে আমি সুস্পষ্ট আয়াতসমূহ অবতীর্ণ করেছি, যাতে তোমরা স্মরণ রাখ।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmdccxciii{ব্যভিচারিণী নারী ব্যভিচারী পুরুষ; তাদের প্রত্যেককে একশ’ করে বেত্রাঘাত কর। আল্লাহর বিধান কার্যকর কারণে তাদের প্রতি যেন তোমাদের মনে দয়ার উদ্রেক না হয়, যদি তোমরা আল্লাহর প্রতি ও পরকালের প্রতি বিশ্বাসী হয়ে থাক। মুসলমানদের একটি দল যেন তাদের শাস্তি প্রত্যক্ষ করে।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmdccxciv{ব্যভিচারী পুরুষ কেবল ব্যভিচারিণী নারী অথবা মুশরিকা নারীকেই বিয়ে করে এবং ব্যভিচারিণীকে কেবল ব্যভিচারী অথবা মুশরিক পুরুষই বিয়ে করে এবং এদেরকে মুমিনদের জন্যে হারাম করা হয়েছে।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmdccxcv{যারা সতী-সাধ্বী নারীর প্রতি অপবাদ আরোপ করে অতঃপর স্বপক্ষে চার জন পুরুষ সাক্ষী উপস্থিত করে না, তাদেরকে আশিটি বেত্রাঘাত করবে এবং কখনও তাদের সাক্ষ্য কবুল করবে না। এরাই না’ফারমান।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmdccxcvi{কিন্তু যারা এরপর তওবা করে এবং সংশোধিত হয়, আল্লাহ ক্ষমাশীল, পরম মেহেরবান।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmdccxcvii{এবং যারা তাদের স্ত্রীদের প্রতি অপবাদ আরোপ করে এবং তারা নিজেরা ছাড়া তাদের কোন সাক্ষী নেই, এরূপ ব্যক্তির সাক্ষ্য এভাবে হবে যে, সে আল্লাহর কসম খেয়ে চারবার সাক্ষ্য দেবে যে, সে অবশ্যই সত্যবাদী।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmdccxcviii{এবং পঞ্চমবার বলবে যে, যদি সে মিথ্যাবাদী হয় তবে তার উপর আল্লাহর লানত।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmdccxcix{এবং স্ত্রীর শাস্তি রহিত হয়ে যাবে যদি সে আল্লাহর কসম খেয়ে চার বার সাক্ষ্য দেয় যে, তার স্বামী অবশ্যই মিথ্যাবাদী;\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmdccc{এবং পঞ্চমবার বলে যে, যদি তার স্বামী সত্যবাদী হয় তবে তার ওপর আল্লাহর গযব নেমে আসবে।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmdccci{তোমাদের প্রতি আল্লাহর অনুগ্রহ ও দয়া না থাকলে এবং আল্লাহ তওবা কবুল কারী, প্রজ্ঞাময় না হলে কত কিছুই যে হয়ে যেত।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmdcccii{যারা মিথ্যা অপবাদ রটনা করেছে, তারা তোমাদেরই একটি দল। তোমরা একে নিজেদের জন্যে খারাপ মনে করো না; বরং এটা তোমাদের জন্যে মঙ্গলজনক। তাদের প্রত্যেকের জন্যে ততটুকু আছে যতটুকু সে গোনাহ করেছে এবং তাদের মধ্যে যে এ ব্যাপারে অগ্রণী ভূমিকা নিয়েছে, তার জন্যে রয়েছে বিরাট শাস্তি।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmdccciii{তোমরা যখন একথা শুনলে, তখন ঈমানদার পুরুষ ও নারীগণ কেন নিজেদের লোক সম্পর্কে উত্তম ধারণা করনি এবং বলনি যে, এটা তো নির্জলা অপবাদ?\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmdccciv{তারা কেন এ ব্যাপারে চার জন সাক্ষী উপস্থিত করেনি; অতঃপর যখন তারা সাক্ষী উপস্থিত করেনি, তখন তারাই আল্লাহর কাছে মিথ্যাবাদী।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmdcccv{যদি ইহকালে ও পরকালে তোমাদের প্রতি আল্লাহর অনুগ্রহ ও দয়া না থাকত, তবে তোমরা যা চর্চা করছিলে, তজ্জন্যে তোমাদেরকে গুরুতর আযাব স্পর্শ করত।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmdcccvi{যখন তোমরা একে মুখে মুখে ছড়াচ্ছিলে এবং মুখে এমন বিষয় উচ্চারণ করছিলে, যার কোন জ্ঞান তোমাদের ছিল না। তোমরা একে তুচ্ছ মনে করছিলে, অথচ এটা আল্লাহর কাছে গুরুতর ব্যাপার ছিল।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmdcccvii{তোমরা যখন এ কথা শুনলে তখন কেন বললে না যে, এ বিষয়ে কথা বলা আমাদের উচিত নয়। আল্লাহ তো পবিত্র, মহান। এটা তো এক গুরুতর অপবাদ।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmdcccviii{আল্লাহ তোমাদেরকে উপদেশ দিচ্ছেন, তোমরা যদি ঈমানদার হও, তবে তখনও পুনরায় এ ধরণের আচরণের পুনরাবৃত্তি করো না।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmdcccix{আল্লাহ তোমাদের জন্যে কাজের কথা স্পষ্ট করে বর্ণনা করেন। আল্লাহ সর্বজ্ঞ, প্রজ্ঞাময়।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmdcccx{যারা পছন্দ করে যে, ঈমানদারদের মধ্যে ব্যভিচার প্রসার লাভ করুক, তাদের জন্যে ইহাকাল ও পরকালে যন্ত্রণাদায়ক শাস্তি রয়েছে। আল্লাহ জানেন, তোমরা জান না।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmdcccxi{যদি তোমাদের প্রতি আল্লাহর অনুগ্রহ ও দয়া না থাকত এবং আল্লাহ দয়ালু, মেহেরবান না হতেন, তবে কত কিছুই হয়ে যেত।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmdcccxii{হে ঈমানদারগণ, তোমরা শয়তানের পদাঙ্ক অনুসরণ করো না। যে কেউ শয়তানের পদাঙ্ক অনুসরণ করবে, তখন তো শয়তান নির্লজ্জতা ও মন্দ কাজেরই আদেশ করবে। যদি আল্লাহর অনুগ্রহ ও দয়া তোমাদের প্রতি না থাকত, তবে তোমাদের কেউ কখনও পবিত্র হতে পারতে না। কিন্তু আল্লাহ যাকে ইচ্ছা পবিত্র করেন। আল্লাহ সবকিছু শোনেন, জানেন।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmdcccxiii{তোমাদের মধ্যে যারা উচ্চমর্যাদা ও আর্থিক প্রাচুর্যের অধিকারী, তারা যেন কসম না খায় যে, তারা আত্নীয়-স্বজনকে, অভাবগ্রস্তকে এবং আল্লাহর পথে হিজরতকারীদেরকে কিছুই দেবে না। তাদের ক্ষমা করা উচিত এবং দোষক্রটি উপেক্ষা করা উচিত। তোমরা কি কামনা কর না যে, আল্লাহ তোমাদেরকে ক্ষমা করেন? আল্লাহ ক্ষমাশীল, পরম করুণাময়।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmdcccxiv{যারা সতী-সাধ্বী, নিরীহ ঈমানদার নারীদের প্রতি অপবাদ আরোপ করে, তারা ইহকালে ও পরকালে ধিকৃত এবং তাদের জন্যে রয়েছে গুরুতর শাস্তি।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmdcccxv{যেদিন প্রকাশ করে দেবে তাদের জিহবা, তাদের হাত ও তাদের পা, যা কিছু তারা করত;\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmdcccxvi{সেদিন আল্লাহ তাদের সমুচিত শাস্তি পুরোপুরি দেবেন এবং তারা জানতে পারবে যে, অল্লাহই সত্য, স্পষ্ট ব্যক্তকারী।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmdcccxvii{দুশ্চরিত্রা নারীকূল দুশ্চরিত্র পুরুষকুলের জন্যে এবং দুশ্চরিত্র পুরুষকুল দুশ্চরিত্রা নারীকুলের জন্যে। সচ্চরিত্রা নারীকুল সচ্চরিত্র পুরুষকুলের জন্যে এবং সচ্চরিত্র পুরুষকুল সচ্চরিত্রা নারীকুলের জন্যে। তাদের সম্পর্কে লোকে যা বলে, তার সাথে তারা সম্পর্কহীন। তাদের জন্যে আছে ক্ষমা ও সম্মানজনক জীবিকা।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmdcccxviii{হে মুমিনগণ, তোমরা নিজেদের গৃহ ব্যতীত অন্য গৃহে প্রবেশ করো না, যে পর্যন্ত আলাপ-পরিচয় না কর এবং গৃহবাসীদেরকে সালাম না কর। এটাই তোমাদের জন্যে উত্তম, যাতে তোমরা স্মরণ রাখ।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmdcccxix{যদি তোমরা গৃহে কাউকে না পাও, তবে অনুমতি গ্রহণ না করা পর্যন্ত সেখানে প্রবেশ করো না। যদি তোমাদেরকে বলা হয় ফিরে যাও, তবে ফিরে যাবে। এতে তোমাদের জন্যে অনেক পবিত্রতা আছে এবং তোমরা যা কর, আল্লাহ তা ভালোভাবে জানেন।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmdcccxx{যে গৃহে কেউ বাস করে না, যাতে তোমাদের সামগ্রী আছে এমন গৃহে প্রবেশ করাতে তোমাদের কোন পাপ নেই এবং আল্লাহ জানেন তোমরা যা প্রকাশ কর এবং যা গোপন কর।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmdcccxxi{মুমিনদেরকে বলুন, তারা যেন তাদের দৃষ্টি নত রাখে এবং তাদের যৌনাঙ্গর হেফাযত করে। এতে তাদের জন্য খুব পবিত্রতা আছে। নিশ্চয় তারা যা করে আল্লাহ তা অবহিত আছেন।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmdcccxxii{ঈমানদার নারীদেরকে বলুন, তারা যেন তাদের দৃষ্টিকে নত রাখে এবং তাদের যৌন অঙ্গের হেফাযত করে। তারা যেন যা সাধারণতঃ প্রকাশমান, তা ছাড়া তাদের সৌন্দর্য প্রদর্শন না করে এবং তারা যেন তাদের মাথার ওড়না বক্ষ দেশে ফেলে রাখে এবং তারা যেন তাদের স্বামী, পিতা, শ্বশুর, পুত্র, স্বামীর পুত্র, ভ্রাতা, ভ্রাতুস্পুত্র, ভগ্নিপুত্র, স্ত্রীলোক অধিকারভুক্ত বাঁদী, যৌনকামনামুক্ত পুরুষ, ও বালক, যারা নারীদের গোপন অঙ্গ সম্পর্কে অজ্ঞ, তাদের ব্যতীত কারো আছে তাদের সৌন্দর্য প্রকাশ না করে, তারা যেন তাদের গোপন সাজ-সজ্জা প্রকাশ করার জন্য জোরে পদচারণা না করে। মুমিনগণ, তোমরা সবাই আল্লাহর সামনে তওবা কর, যাতে তোমরা সফলকাম হও।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmdcccxxiii{তোমাদের মধ্যে যারা বিবাহহীন, তাদের বিবাহ সম্পাদন করে দাও এবং তোমাদের দাস ও দাসীদের মধ্যে যারা সৎকর্মপরায়ন, তাদেরও। তারা যদি নিঃস্ব হয়, তবে আল্লাহ নিজ অনুগ্রহে তাদেরকে সচ্ছল করে দেবেন। আল্লাহ প্রাচুর্যময়, সর্বজ্ঞ।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmdcccxxiv{যারা বিবাহে সামর্থ নয়, তারা যেন সংযম অবলম্বন করে যে পর্যন্ত না আল্লাহ নিজ অনুগ্রহে তাদেরকে অভাবমুক্ত করে দেন। তোমাদের অধিকারভুক্তদের মধ্যে যারা মুক্তির জন্য লিখিত চুক্তি করতে চায়, তাদের সাথে তোমরা লিখিত চুক্তি কর যদি জান যে, তাদের মধ্যে কল্যাণ আছে। আল্লাহ তোমাদেরকে যে, অর্থ-কড়ি দিয়েছেন, তা থেকে তাদেরকে দান কর। তোমাদের দাসীরা নিজেদের পবিত্রতা রক্ষা করতে চাইলে তোমরা পার্থিব জীবনের সম্পদের লালসায় তাদেরকে ব্যভিচারে বাধ্য কারো না। যদি কেহ তাদের উপর জোর-জবরদস্তি করে, তবে তাদের উপর জোর-জবরদস্তির পর আল্লাহ তাদের প্রতি ক্ষমাশীল, পরম দয়ালু।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmdcccxxv{আমি তোমাদের প্রতি অবতীর্ণ করেছি সুস্পষ্ট আয়াতসমূহ, তোমাদের পূর্ববর্তীদের কিছু দৃষ্টান্ত এবং আল্লাহ ভীরুদের জন্যে দিয়েছি উপদেশ।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmdcccxxvi{আল্লাহ নভোমন্ডল ও ভূমন্ডলের জ্যোতি, তাঁর জ্যোতির উদাহরণ যেন একটি কুলঙ্গি, যাতে আছে একটি প্রদীপ, প্রদীপটি একটি কাঁচপাত্রে স্থাপিত, কাঁচপাত্রটি উজ্জ্বল নক্ষত্র সদৃশ্য। তাতে পুতঃপবিত্র যয়তুন বৃক্ষের তৈল প্রজ্বলিত হয়, যা পূর্বমুখী নয় এবং পশ্চিমমুখীও নয়। অগ্নি স্পর্শ না করলেও তার তৈল যেন আলোকিত হওয়ার নিকটবর্তী। জ্যোতির উপর জ্যোতি। আল্লাহ যাকে ইচ্ছা পথ দেখান তাঁর জ্যোতির দিকে। আল্লাহ মানুষের জন্যে দৃষ্টান্তসমূহ বর্ণনা করেন এবং আল্লাহ সব বিষয়ে জ্ঞাত।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmdcccxxvii{আল্লাহ যেসব গৃহকে মর্যাদায় উন্নীত করার এবং সেগুলোতে তাঁর নাম উচ্চারণ করার আদেশ দিয়েছেন, সেখানে সকাল ও সন্ধ্যায় তাঁর পবিত্রতা ও মহিমা ঘোষণা করে;\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmdcccxxviii{এমন লোকেরা, যাদেরকে ব্যবসা-বাণিজ্য ও ক্রয়-বিক্রয় আল্লাহর স্মরণ থেকে, নামায কায়েম করা থেকে এবং যাকাত প্রদান করা থেকে বিরত রাখে না। তারা ভয় করে সেই দিনকে, যেদিন অন্তর ও দৃষ্টিসমূহ উল্টে যাবে।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmdcccxxix{(তারা আল্লাহর পবিত্রতা ঘোষণা করে) যাতে আল্লাহ তাদের উৎকৃষ্টতর কাজের প্রতিদান দেন এবং নিজ অনুগ্রহে আরও অধিক দেন। আল্লাহ যাকে ইচ্ছা অপরিমিত রুযী দান করেন।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmdcccxxx{যারা কাফের, তাদের কর্ম মরুভুমির মরীচিকা সদৃশ, যাকে পিপাসার্ত ব্যক্তি পানি মনে করে। এমনকি, সে যখন তার কাছে যায়, তখন কিছুই পায় না এবং পায় সেখানে আল্লাহকে, অতঃপর আল্লাহ তার হিসাব চুকিয়ে দেন। আল্লাহ দ্রুত হিসাব গ্রহণকারী।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmdcccxxxi{অথবা (তাদের কর্ম) প্রমত্ত সমুদ্রের বুকে গভীর অন্ধকারের ন্যায়, যাকে উদ্বেলিত করে তরঙ্গের উপর তরঙ্গ, যার উপরে ঘন কালো মেঘ আছে। একের উপর এক অন্ধকার। যখন সে তার হাত বের করে, তখন তাকে একেবারেই দেখতে পায় না। আল্লাহ যাকে জ্যোতি দেন না, তার কোন জ্যোতিই নেই।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmdcccxxxii{তুমি কি দেখ না যে, নভোমন্ডল ও ভূমন্ডলে যারা আছে, তারা এবং উড়ন্ত পক্ষীকুল তাদের পাখা বিস্তার করতঃ আল্লাহর পবিত্রতা ও মহিমা ঘোষণা করে? প্রত্যেকেই তার যোগ্য এবাদত এবং পবিত্রতা ও মহিমা ঘোষণার পদ্ধতি জানে। তারা যা করে, আল্লাহ সে বিষয়ে সম্যক জ্ঞাত।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmdcccxxxiii{নভোমন্ডল ও ভূমন্ডলের সার্বভৌমত্ব আল্লাহরই এবং তাঁরই দিকে প্রত্যাবর্তন করতে হবে।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmdcccxxxiv{তুমি কি দেখ না যে, আল্লাহ মেঘমালাকে সঞ্চালিত করেন, অতঃপর তাকে পুঞ্জীভূত করেন, অতঃপর তাকে স্তরে স্তরে রাখেন; অতঃপর তুমি দেখ যে, তার মধ্য থেকে বারিধারা নির্গত হয়। তিনি আকাশস্থিত শিলাস্তুপ থেকে শিলাবর্ষণ করেন এবং তা দ্বারা যাকে ইচ্ছা আঘাত করেন এবং যার কাছ থেকে ইচ্ছা, তা অন্যদিকে ফিরিয়ে দেন। তার বিদ্যুৎঝলক দৃষ্টিশক্তি যেন বিলীন করে দিতে চায়।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmdcccxxxv{আল্লাহ দিন ও রাত্রির পরিবর্তন ঘটান। এতে অর্ন্তদৃষ্টি-সম্পন্নগণের জন্যে চিন্তার উপকরণ রয়েছে।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmdcccxxxvi{আল্লাহ প্রত্যেক চলন্ত জীবকে পানি দ্বারা সৃষ্টি করেছেন। তাদের কতক বুকে ভয় দিয়ে চলে, কতক দুই পায়ে ভর দিয়ে চলে এবং কতক চার পায়ে ভর দিয়ে চলে; আল্লাহ যা ইচ্ছা সৃষ্টি করেন। নিশ্চয়ই আল্লাহ সবকিছু করতে সক্ষম।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmdcccxxxvii{আমি তো সুস্পষ্ট আয়াত সমূহ অবর্তীর্ণ করেছি। আল্লাহ যাকে ইচ্ছা সরল পথে পরিচালনা করেন।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmdcccxxxviii{তারা বলেঃ আমরা আল্লাহ ও রসূলের প্রতি বিশ্বাস স্থাপন করেছি এবং আনুগত্য করি; কিন্তু অতঃপর তাদের একদল মুখ ফিরিয়ে নেয় এবং তারা বিশ্বাসী নয়।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmdcccxxxix{তাদের মধ্যে ফয়সালা করার জন্য যখন তাদেরকে আল্লাহ ও রসূলের দিকে আহবান করা হয তখন তাদের একদল মুখ ফিরিয়ে নেয়।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmdcccxl{সত্য তাদের স্বপক্ষে হলে তারা বিনীতভাবে রসূলের কাছে ছুটে আসে।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmdcccxli{তাদের অন্তরে কি রোগ আছে, না তারা ধোঁকায় পড়ে আছে; না তারা ভয় করে যে, আল্লাহ ও তাঁর রাসূল তাদের প্রতি অবিচার করবেন? বরং তারাই তো অবিচারকারী ?\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmdcccxlii{মুমিনদের বক্তব্য কেবল এ কথাই যখন তাদের মধ্যে ফয়সালা করার জন্যে আল্লাহ ও তাঁর রসূলের দিকে তাদেরকে আহবান করা হয়, তখন তারা বলেঃ আমরা শুনলাম ও আদেশ মান্য করলাম। তারাই সফলকাম।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmdcccxliii{যারা আল্লাহ ও তাঁর রসূলের আনুগত্য করে আল্লাহকে ভয় করে ও তাঁর শাস্তি থেকে বেঁচে থাকে তারাই কৃতকার্য।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmdcccxliv{তারা দৃঢ়ভাবে আল্লাহর কসম খেয়ে বলে যে, আপনি তাদেরকে আদেশ করলে তারা সবকিছু ছেড়ে বের হবেই। বলুনঃ তোমরা কসম খেয়ো না। নিয়মানুযায়ী তোমাদের আনুগত্য, তোমরা যা কিছু কর নিশ্চয় আল্লাহ সে বিষয়ে জ্ঞাত।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmdcccxlv{বলুনঃ আল্লাহর আনুগত্য কর এবং রসূলের আনুগত্য কর। অতঃপর যদি তোমরা মুখ ফিরিয়ে নাও, তবে তার উপর ন্যস্ত দায়িত্বের জন্যে সে দায়ী এবং তোমাদের উপর ন্যস্ত দায়িত্বের জন্যে তোমরা দায়ী। তোমরা যদি তাঁর আনুগত্য কর, তবে সৎ পথ পাবে। রসূলের দায়িত্ব তো কেবল সুস্পষ্টরূপে পৌছে দেয়া।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmdcccxlvi{তোমাদের মধ্যে যারা বিশ্বাস স্থাপন করে ও সৎকর্ম করে, আল্লাহ তাদেরকে ওয়াদা দিয়েছেন যে, তাদেরকে অবশ্যই পৃথিবীতে শাসনকর্তৃত্ব দান করবেন। যেমন তিনি শাসনকতৃꦣ2468;্ব দান করেছেন তাদের পূর্ববতীদেরকে এবং তিনি অবশ্যই সুদৃঢ় করবেন তাদের ধর্মকে, যা তিনি তাদের জন্যে পছন্দ করেছেন এবং তাদের ভয়-ভীতির পরিবর্তে অবশ্যই তাদেরকে শান্তি দান করবেন। তারা আমার এবাদত করবে এবং আমার সাথে কাউকে শরীক করবে না। এরপর যারা অকৃতজ্ঞ হবে, তারাই অবাধ্য।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mmdcccxlvii{নামায কায়েম কর, যাকাত প্রদান কর এবং রসূলের আনুগত্য কর যাতে তোমরা অনুগ্রহ প্রাপ্ত হও।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mmdcccxlviii{তোমরা কাফেরদেরকে পৃথিবীতে পরাক্রমশালী মনে করো না। তাদের ঠিকানা অগ্নি। কতই না নিকৃষ্ট এই প্রত্যাবর্তনস্থল।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mmdcccxlix{হে মুমিনগণ! তোমাদের দাসদাসীরা এবং তোমাদের মধ্যে যারা প্রাপ্ত বয়স্ক হয়নি তারা যেন তিন সময়ে তোমাদের কাছে অনুমতি গ্রহণ করে, ফজরের নামাযের পূর্বে, দুপুরে যখন তোমরা বস্ত্র খুলে রাখ এবং এশার নামাযের পর। এই তিন সময় তোমাদের দেহ খোলার সময়। এ সময়ের পর তোমাদের ও তাদের জন্যে কোন দোষ নেই। তোমাদের একে অপরের কাছে তো যাতায়াত করতেই হয়, এমনি ভাবে আল্লাহ তোমাদের কাছে সুস্পষ্ট আয়াতসমূহ বিবৃত করেন। আল্লাহ সর্বজ্ঞ, প্রজ্ঞাময়।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mmdcccl{তোমাদের সন্তান-সন্ততিরা যখন বায়োপ্রাপ্ত হয়, তারাও যেন তাদের পূর্ববর্তীদের ন্যায় অনুমতি চায়। এমনিভাবে আল্লাহ তাঁর আয়াতসমূহ তোমাদের কাছে বর্ণনা করেন। আল্লাহ সর্বজ্ঞ, প্রজ্ঞাময়।\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mmdcccli{বৃদ্ধা নারী, যারা বিবাহের আশা রাখে না, যদি তারা তাদের সৌন্দর্য?2474;্রকাশ না করে তাদের বস্ত্র খুলে রাখে। তাদের জন্যে দোষ নেই, তবে এ থেকে বিরত থাকাই তাদের জন্যে উত্তম। আল্লাহ সর্বশ্রোতা, সর্বজ্ঞ।\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mmdccclii{অন্ধের জন্যে দোষ নেই, খঞ্জের জন্যে দোষ নেই, রোগীর জন্যে দোষ নেই, এবং তোমাদের নিজেদের জন্যেও দোষ নেই যে, তোমরা আহার করবে তোমাদের গৃহে অথবা তোমাদের পিতাদের গৃহে অথবা তোমাদের মাতাদের গৃহে অথবা তোমাদের ভ্রাতাদের গৃহে অথবা তোমাদের ভগিণীদের গৃহে অথবা তোমাদের পিতৃব্যদের গৃহে অথবা তোমাদের ফুফুদের গৃহে অথবা তোমাদের মামাদের গৃহে অথবা তোমাদের খালাদের গৃহে অথবা সেই গৃহে, যার চাবি আছে তোমাদের হাতে অথবা তোমাদের বন্ধুদের গৃহে। তোমরা একত্রে আহার কর অথবা পৃথকভবে আহার কর, তাতে তোমাদের কোন দোষ নেই। অতঃপর যখন তোমরা গৃহে প্রবেশ কর, তখন তোমাদের স্বজনদের প্রতি সালাম বলবে। এটা আল্লাহর কাছ থেকে কল্যাণময় ও পবিত্র দোয়া। এমনিভাবে আল্লাহ তোমাদের জন্যে আয়াতসমূহ বিশদভাবে বর্ননা করেন, যাতে তোমরা বুঝে নাও।\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mmdcccliii{মুমিন তো তারাই; যারা আল্লাহর ও রসূলের প্রতি বিশ্বাস স্থাপন করে এবং রসূলের সাথে কোন সমষ্টিগত কাজে শরীক হলে তাঁর কাছ থেকে অনুমতি গ্রহণ ব্যতীত চলে যায় না। যারা আপনার কাছে অনুমতি প্রার্থনা করে, তারাই আল্লাহ ও তাঁর রসূলের প্রতি বিশ্বাস স্থাপন করে। অতএব তারা আপনার কাছে তাদের কোন কাজের জন্যে অনুমতি চাইলে আপনি তাদের মধ্যে যাকে ইচ্ছা অনুমতি দিন এবং তাদের জন্যে আল্লাহর কাছে ক্ষমা প্রার্থনা করুন। আল্লাহ ক্ষমাশীল, মেহেরবান।\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mmdcccliv{রসূলের আহবানকে তোমরা তোমাদের একে অপরকে আহ্বানের মত গণ্য করো না। আল্লাহ তাদেরকে জানেন, যারা তোমাদের মধ্যে চুপিসারে সরে পড়ে। অতএব যারা তাঁর আদেশের বিরুদ্ধাচরণ করে, তারা এ বিষয়ে সতর্ক হোক যে, বিপর্যয় তাদেরকে স্পর্শ করবে অথবা যন্ত্রণাদায়ক শাস্তি তাদেরকে গ্রাস করবে।\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mmdccclv{মনে রেখো নভোমন্ডল ও ভূমন্ডলে যা আছে, তা আল্লাহরই। তোমরা যে অবস্থায় আছ তা তিনি জানেন। যেদিন তারা তাঁর কাছে প্রত্যাবর্তিত হবে, সেদিন তিনি বলে দেবেন তারা যা করেছে। আল্লাহ প্রত্যেক বিষয়ই জানেন।\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mmdccclvi{\basmalahbn পরম কল্যাণময় তিনি যিনি তাঁর বান্দার প্রতি ফয়সালার গ্রন্থ অবর্তীণ করেছেন, যাতে সে বিশ্বজগতের জন্যে সতর্ককারী হয়,।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmdccclvii{তিনি হলেন যাঁর রয়েছে নভোমন্ডল ও ভূমন্ডলের রাজত্ব। তিনি কোন সন্তান গ্রহণ করেননি। রাজত্বে তাঁর কোন অংশীদার নেই। তিনি প্রত্যেক বস্তু সৃষ্টি করেছেন, অতঃপর তাকে শোধিত করেছেন পরিমিতভাবে।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmdccclviii{তারা তাঁর পরিবর্তে কত উপাস্য গ্রহণ করেছে, যারা কিছুই সৃষ্টি করে না এবং তারা নিজেরাই সৃষ্ট এবং নিজেদের ভালও করতে পারে না, মন্দও করতে পারে না এবং জীবন, মরণ ও পুনরুজ্জীবনের ও তারা মালিক নয়।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmdccclix{কাফেররা বলে, এটা মিথ্যা বৈ নয়, যা তিনি উদ্ভাবন করেছেন এবং অন্য লোকেরা তাঁকে সাহায্য করেছে। অবশ্যই তারা অবিচার ও মিথ্যার আশ্রয় নিয়েছে।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmdccclx{তারা বলে, এগুলো তো পুরাকালের রূপকথা, যা তিনি লিখে রেখেছেন। এগুলো সকাল-সন্ধ্যায় তাঁর কাছে শেখানো হয়।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmdccclxi{বলুন, একে তিনিই অবতীর্ণ করেছেন, যিনি নভোমন্ডল ও ভূমন্ডলের গোপন রহস্য অবগত আছেন। তিনি ক্ষমাশীল, মেহেরবান।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmdccclxii{তারা বলে, এ কেমন রসূল যে, খাদ্য আহার করে এবং হাটে-বাজারে চলাফেরা করে? তাঁর কাছে কেন কোন ফেরেশতা নাযিল করা হল না যে, তাঁর সাথে সতর্ককারী হয়ে থাকত?\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmdccclxiii{অথবা তিনি ধন-ভান্ডার প্রাপ্ত হলেন না কেন, অথবা তাঁর একটি বাগান হল না কেন, যা থেকে তিনি আহার করতেন? জালেমরা বলে, তোমরা তো একজন জাদুগ্রস্ত ব্যক্তিরই অনুসরণ করছ।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmdccclxiv{দেখুন, তারা আপনার কেমন দৃষ্টান্ত বর্ণনা করে! অতএব তারা পথভ্রষ্ট হয়েছে, এখন তারা পথ পেতে পারে না।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmdccclxv{কল্যানময় তিনি, যিনি ইচ্ছা করলে আপনাকে তদপেক্ষা উত্তম বস্তু দিতে পারেন-বাগ-বাগিচা, যার তলদেশে নহর প্রবাহিত হয় এবং দিতে পারেন আপনাকে প্রাসাদসমূহ।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmdccclxvi{বরং তারা কেয়ামতকে অস্বীকার করে এবং যে কেয়ামতকে অস্বীকার করে, আমি তার জন্যে অগ্নি প্রস্তুত করেছি।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmdccclxvii{অগ্নি যখন দূর থেকে তাদেরকে দেখবে, তখন তারা শুনতে পাবে তার গর্জন ও হুঙ্কার।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmdccclxviii{যখন এক শিকলে কয়েকজন বাঁধা অবস্থায় জাহান্নামের কোন সংকীর্ণ স্থানে নিক্ষেপ করা হবে, তখন সেখানে তারা মৃত্যুকে ডাকবে।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmdccclxix{বলা হবে, আজ তোমরা এক মৃত্যুকে ডেকো না অনেক মৃত্যুকে ডাক।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmdccclxx{বলুন এটা উত্তম, না চিরকাল বসবাসের জান্নাত, যার সুসংবাদ দেয়া হয়েছে মুত্তাকীদেরকে? সেটা হবে তাদের প্রতিদান ও প্রত্যাবর্তন স্থান।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmdccclxxi{তারা চিরকাল বসবাসরত অবস্থায় সেখানে যা চাইবে, তাই পাবে। এই প্রার্থিত ওয়াদা পূরণ আপনার পালনকর্তার দায়িত্ব।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmdccclxxii{সেদিন আল্লাহ একত্রিত করবেন তাদেরকে এবং তারা আল্লাহর পরিবর্তে যাদের এবাদত করত তাদেরকে, সেদিন তিনি উপাস্যদেরকে বলবেন, তোমরাই কি আমার এই বান্দাদেরকে পথভ্রান্ত করেছিলে, না তারা নিজেরাই পথভ্রান্ত হয়েছিল?\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmdccclxxiii{তারা বলবে-আপনি পবিত্র, আমরা আপনার পরিবর্তে অন্যকে মুরুব্বীরূপে গ্রহণ করতে পারতাম না; কিন্তু আপনিই তো তাদেরকে এবং তাদের পিতৃপুরুষদেরকে ভোগসম্ভার দিয়েছিলেন, ফলে তারা আপনার স্মৃতি বিস্মৃত হয়েছিল এবং তারা ছিল ধ্বংসপ্রাপ্ত জাতি।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmdccclxxiv{আল্লাহ মুশরিকদেরকে বলবেন, তোমাদের কথা তো তারা মিথ্যা সাব্যস্ত করল, এখন তোমরা শাস্তি প্রতিরোধ করতে পারবে না এবং সাহায্যও করতে পারবে না। তোমাদের মধ্যে যে গোনাহগার আমি তাকে গুরুতর শাস্তি আস্বাদন করাব।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmdccclxxv{আপনার পূর্বে যত রসূল প্রেরণ করেছি, তারা সবাই খাদ্য গ্রহণ করত এবং হাটে-বাজারে চলাফেরা করত। আমি তোমাদের এককে অপরের জন্যে পরীক্ষাস্বরূপ করেছি। দেখি, তোমরা সবর কর কিনা। আপনার পালনকর্তা সব কিছু দেখেন।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmdccclxxvi{যারা আমার সাক্ষাৎ আশা করে না, তারা বলে, আমাদের কাছে ফেরেশতা অবতীর্ণ করা হল না কেন? অথবা আমরা আমাদের পালনকর্তাকে দেখি না কেন? তারা নিজেদের অন্তরে অহংকার পোষণ করে এবং গুরুতর অবাধ্যতায় মেতে উঠেছে।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmdccclxxvii{যেদিন তারা ফেরেশতাদেরকে দেখবে, সেদিন অপরাধীদের জন্যে কোন সুসংবাদ থাকবে না এবং তারা বলবে, কোন বাধা যদি তা আটকে রাখত।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmdccclxxviii{আমি তাদের কৃতকর্মের প্রতি মনোনিবেশ করব, অতঃপর সেগুলোকে বিক্ষিপ্ত ধুলিকণারূপে করে দেব।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmdccclxxix{সেদিন জান্নাতীদের বাসস্থান হবে উত্তম এবং বিশ্রামস্থল হবে মনোরম।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmdccclxxx{সেদিন আকাশ মেঘমালাসহ বিদীর্ণ হবে এবং সেদিন ফেরেশতাদের নামিয়ে দেয়া হবে,\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmdccclxxxi{সেদিন সত্যিকার রাজত্ব হবে দয়াময় আল্লাহর এবং কাফেরদের পক্ষে দিনটি হবে কঠিন।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmdccclxxxii{জালেম সেদিন আপন হস্তদ্বয় দংশন করতে করতে বলবে, হায় আফসোস! আমি যদি রসূলের সাথে পথ অবলম্বন করতাম।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmdccclxxxiii{হায় আমার দূর্ভাগ্য, আমি যদি অমুককে বন্ধুরূপে গ্রহণ না করতাম।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmdccclxxxiv{আমার কাছে উপদেশ আসার পর সে আমাকে তা থেকে বিভ্রান্ত করেছিল। শয়তান মানুষকে বিপদকালে ধোঁকা দেয়।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmdccclxxxv{রসূল বললেনঃ হে আমার পালনকর্তা, আমার সম্প্রদায় এই কোরআনকে প্রলাপ সাব্যস্ত করেছে।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmdccclxxxvi{এমনিভাবে প্রত্যেক নবীর জন্যে আমি অপরাধীদের মধ্য থেকে শত্রু করেছি। আপনার জন্যে আপনার পালনকর্তা পথপ্রদর্শক ও সাহায্যকারীরূপে যথেষ্ট।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmdccclxxxvii{সত্য প্রত্যাখানকারীরা বলে, তাঁর প্রতি সমগ্র কোরআন একদফায় অবতীর্ণ হল না কেন? আমি এমনিভাবে অবতীর্ণ করেছি এবং ক্রমে ক্রমে আবৃত্তি করেছি আপনার অন্তকরণকে মজবুত করার জন্যে।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmdccclxxxviii{তারা আপনার কাছে কোন সমস্যা উপস্থাপিত করলেই আমি আপনাকে তার সঠিক জওয়াব ও সুন্দর ব্যাখ্যা দান করি।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmdccclxxxix{যাদেরকে মুখ থুবড়ে পড়ে থাকা অবস্থায় জাহান্নামের দিকে একত্রিত করা হবে, তাদেরই স্থান হবে নিকৃষ্ট এবং তারাই পথভ্রষ্ট।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmdcccxc{আমি তো মূসাকে কিতাব দিয়েছি এবং তাঁর সাথে তাঁর ভ্রাতা হারুনকে সাহায্যকারী করেছি।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmdcccxci{অতঃপর আমি বলেছি, তোমরা সেই সম্প্রদায়ের কাছে যাও, যারা আমার আয়াতসমূহকে মিথ্যা অভিহিত করেছে। অতঃপর আমি তাদেরকে সমূলে ধ্বংস করে দিয়েছি।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmdcccxcii{নূহের সম্প্রদায় যখন রসূলগণের প্রতি মিথ্যারোপ করল, তখন আমি তাদেরকে নিমজ্জত করলাম এবং তাদেরকে মানবমন্ডলীর জন্যে নিদর্শন করে দিলাম। জালেমদের জন্যে আমি যন্ত্রণাদায়ক শাস্তি প্রস্তুত করে রেখেছি।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmdcccxciii{আমি ধ্বংস করেছি আদ, সামুদ, কপবাসী এবং তাদের মধ্যবর্তী অনেক সম্প্রদায়কে।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmdcccxciv{আমি প্রত্যেকের জন্যেই দৃষ্টান্ত বর্ণনা করেছি এবং প্রত্যেককেই সম্পুর্ণরূপে ধ্বংস করেছি।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmdcccxcv{তারা তো সেই জনপদের উপর দিয়েই যাতায়াত করে, যার ওপর বর্ষিত হয়েছে মন্দ বৃষ্টি। তবে কি তারা তা প্রত্যক্ষ করে না? বরং তারা পুনরুজ্জীবনের আশঙ্কা করে না।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmdcccxcvi{তারা যখন আপনাকে দেখে, তখন আপনাকে কেবল বিদ্রুপের পাত্ররূপে গ্রহণ করে, বলে, এ-ই কি সে যাকে আল্লাহ ‘রসূল’ করে প্রেরণ করেছেন?\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmdcccxcvii{সে তো আমাদেরকে আমাদের উপাস্যগণের কাছ থেকে সরিয়েই দিত, যদি আমরা তাদেরকে আঁকড়ে ধরে না থাকতাম। তারা যখন শাস্তি প্রত্যক্ষ করবে, তখন জানতে পারবে কে অধিক পথভ্রষ্ট।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmdcccxcviii{আপনি কি তাকে দেখেন না, যে তারা প্রবৃত্তিকে উপাস্যরূপে গ্রহণ করে? তবুও কি আপনি তার যিম্মাদার হবেন?\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmdcccxcix{আপনি কি মনে করেন যে, তাদের অধিকাংশ শোনে অথবা বোঝে ? তারা তো চতুস্পদ জন্তুর মত; বরং আরও পথভ্রান্ত\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmcm{তুমি কি তোমার পালনকর্তাকে দেখ না, তিনি কিভাবে ছায়াকে বিলম্বিত করেন? তিনি ইচ্ছা করলে একে স্থির রাখতে পারতেন। এরপর আমি সূর্যকে করেছি এর নির্দেশক।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmcmi{অতঃপর আমি একে নিজের দিকে ধীরে ধীরে গুটিয়ে আনি।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmcmii{তিনিই তো তোমাদের জন্যে রাত্রিকে করেছেন আবরণ, নিদ্রাকে বিশ্রাম এবং দিনকে করেছেন বাইরে গমনের জন্যে।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmcmiii{তিনিই স্বীয় রহমতের প্রাক্কালে বাতাসকে সুসংবাদবাহীরূপে প্রেরণ করেন। এবং আমি আকাশ থেকে পবিত্রতা অর্জনের জন্যে পানি বর্ষণ করি।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmcmiv{তদ্দ্বারা মৃত ভূভাগকে সঞ্জীবিত করার জন্যে এবং আমার সৃষ্ট জীবজন্তু ও অনেক মানুষের তৃষ্ণা নিবারণের জন্যে।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmcmv{এবং আমি তা তাদের মধ্যে বিভিন্নভাবে বিতরণ করি, যাতে তারা স্মরণ করে। কিন্তু অধিকাংশ লোক অকৃতজ্ঞতা ছাড়া কিছুই করে না।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmcmvi{আমি ইচ্ছা করলে প্রত্যেক জনপদে একজন ভয় প্রদর্শনকারী প্রেরণ করতে পারতাম।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmcmvii{অতএব আপনি কাফেরদের আনুগত্য করবেন না এবং তাদের সাথে এর সাহায্যে কঠোর সংগ্রাম করুন।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmcmviii{তিনিই সমান্তরালে দুই সমুদ্র প্রবাহিত করেছেন, এটি মিষ্ট, তৃষ্ণা নিবারক ও এটি লোনা, বিস্বাদ; উভয়ের মাঝখানে রেখেছেন একটি অন্তরায়, একটি দুর্ভেদ্য আড়াল।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmcmix{তিনিই পানি থেকে সৃষ্টি করেছেন মানবকে, অতঃপর তাকে রক্তগত, বংশ ও বৈবাহিক সম্পর্কশীল করেছেন। তোমার পালনকর্তা সবকিছু করতে সক্ষম।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmcmx{তারা এবাদত করে আল্লাহর পরিবর্তে এমন কিছুর, যা তাদের উপকার করতে পারে না এবং ক্ষতিও করতে পারে না। কাফের তো তার পালনকর্তার প্রতি পৃষ্ঠপ্রদর্শনকারী।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mmcmxi{আমি আপনাকে সুসংবাদ ও সতর্ককারীরূপেই প্রেরণ করেছি।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mmcmxii{বলুন, আমি তোমাদের কাছে এর কোন বিনিময় চাই না, কিন্তু যে ইচ্ছা করে, সে তার পালনকর্তার পথ অবলম্বন করুক।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mmcmxiii{আপনি সেই চিরঞ্জীবের উপর ভরসা করুন, যার মৃত্যু নেই এবং তাঁর প্রশংসাসহ পবিত্রতা ঘোষণা করুন। তিনি বান্দার গোনাহ সম্পর্কে যথেষ্ট খবরদার।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mmcmxiv{তিনি নভোমন্ডল, ভূমন্ডল ও এতদুভয়ের অন্তর্বর্তী সবকিছু ছয়দিনে সৃস্টি করেছেন, অতঃপর আরশে সমাসীন হয়েছেন। তিনি পরম দয়াময়। তাঁর সম্পর্কে যিনি অবগত, তাকে জিজ্ঞেস কর।\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mmcmxv{তাদেরকে যখন বলা হয়, দয়াময়কে সেজদা কর, তখন তারা বলে, দয়াময় আবার কে? তুমি কাউকে সেজদা করার আদেশ করলেই কি আমরা সেজদা করব? এতে তাদের পলায়নপরতাই বৃদ্ধি পায়।\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mmcmxvi{কল্যাণময় তিনি, যিনি নভোমন্ডলে রাশিচক্র সৃষ্টি করেছেন এবং তাতে রেখেছেন সূর্য ও দীপ্তিময় চন্দ্র।\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mmcmxvii{যারা অনুসন্ধানপ্রিয় অথবা যারা কৃতজ্ঞতাপ্রিয় তাদের জন্যে তিনি রাত্রি ও দিবস সৃষ্টি করেছেন পরিবর্তনশীলরূপে।\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mmcmxviii{রহমান-এর বান্দা তারাই, যারা পৃথিবীতে নম্রভাবে চলাফেরা করে এবং তাদের সাথে যখন মুর্খরা কথা বলতে থাকে, তখন তারা বলে, সালাম।\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mmcmxix{এবং যারা রাত্রি যাপন করে পালনকর্তার উদ্দেশ্যে সেজদাবনত হয়ে ও দন্ডায়মান হয়ে;\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mmcmxx{এবং যারা বলে, হে আমার পালনকর্তা, আমাদের কাছথেকে জাহান্নামের শাস্তি হটিয়ে দাও। নিশ্চয় এর শাস্তি নিশ্চিত বিনাশ;\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mmcmxxi{বসবাস ও অবস্থানস্থল হিসেবে তা কত নিকৃষ্ট জায়গা।\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mmcmxxii{এবং তারা যখন ব্যয় করে, তখন অযথা ব্যয় করে না কৃপণতাও করে না এবং তাদের পন্থা হয় এতদুভয়ের মধ্যবর্তী।\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mmcmxxiii{এবং যারা আল্লাহর সাথে অন্য উপাস্যের এবাদত করে না, আল্লাহ যার হত্যা অবৈধ করেছেন, সঙ্গত কারণ ব্যতীত তাকে হত্যা করে না এবং ব্যভিচার করে না। যারা একাজ করে, তারা শাস্তির সম্মুখীন হবে।\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mmcmxxiv{কেয়ামতের দিন তাদের শাস্তি দ্বিগুন হবে এবং তথায় লাঞ্ছিত অবস্থায় চিরকাল বসবাস করবে।\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mmcmxxv{কিন্তু যারা তওবা করে বিশ্বাস স্থাপন করে এবং সৎকর্ম করে, আল্লাহ তাদের গোনাহকে পুন্য দ্বারা পরিবর্তত করে এবং দেবেন। আল্লাহ ক্ষমাশীল, পরম দয়ালু।\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@mmcmxxvi{যে তওবা করে ও সৎকর্ম করে, সে ফিরে আসার স্থান আল্লাহর দিকে ফিরে আসে।\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@mmcmxxvii{এবং যারা মিথ্যা কাজে যোগদান করে না এবং যখন অসার ক্রিয়াকর্মের সম্মুখীন হয়, তখন মান রক্ষার্থে ভদ্রভাবে চলে যায়।\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@mmcmxxviii{এবং যাদেরকে তাদের পালনকর্তার আয়াতসমূহ বোঝানো হলে তাতে অন্ধ ও বধির সদৃশ আচরণ করে না।\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@mmcmxxix{এবং যারা বলে, হে আমাদের পালনকর্তা, আমাদের স্ত্রীদের পক্ষ থেকে এবং আমাদের সন্তানের পক্ষ থেকে আমাদের জন্যে চোখের শীতলতা দান কর এবং আমাদেরকে মুত্তাকীদের জন্যে আদর্শস্বরূপ কর।\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@mmcmxxx{তাদেরকে তাদের সবরের প্রতিদানে জান্নাতে কক্ষ দেয়া হবে এবং তাদেরকে তথায় দোয়া ও সালাম সহকারে অভ্যর্থনা করা হবে।\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@mmcmxxxi{তথায় তারা চিরকাল বসবাস করবে। অবস্থানস্থল ও বাসস্থান হিসেবে তা কত উত্তম।\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@mmcmxxxii{বলুন, আমার পালনকর্তা পরওয়া করেন না যদি তোমরা তাঁকে না ডাক। তোমরা মিথ্যা বলেছ। অতএব সত্বর নেমে আসবে অনিবার্য শাস্তি।\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@mmcmxxxiii{\basmalahbn ত্বা, সীন, মীম।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmcmxxxiv{এগুলো সুস্পষ্ট কিতাবের আয়াত।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmcmxxxv{তারা বিশ্বাস করে না বলে আপনি হয়তো মর্মব্যথায় আত্নঘাতী হবেন।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmcmxxxvi{আমি যদি ইচ্ছা করি, তবে আকাশ থেকে তাদের কাছে কোন নিদর্শন নাযিল করতে পারি। অতঃপর তারা এর সামনে নত হয়ে যাবে।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmcmxxxvii{যখনই তাদের কাছে রহমান এর কোন নতুন উপদেশ আসে, তখনই তারা তা থেকে মুখ ফিরিয়ে নেয়।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmcmxxxviii{অতএব তারা তো মিথ্যারোপ করেছেই; সুতরাং যে বিষয় নিয়ে তারা ঠাট্টা-বিদ্রুপ করত, তার যথার্থ স্বরূপ শীঘ্রই তাদের কাছে পৌছবে।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmcmxxxix{তারা কি ভুপৃষ্ঠের প্রতি দৃষ্টিপাত করে না? আমি তাতে সর্বপ্রকার বিশেষ-বস্তু কত উদগত করেছি।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmcmxl{নিশ্চয় এতে নিদর্শন আছে, কিন্তু তাদের অধিকাংশই বিশ্বাসী নয়।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmcmxli{আপনার পালনকর্তা তো পরাক্রমশালী পরম দয়ালু।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmcmxlii{যখন আপনার পালনকর্তা মূসাকে ডেকে বললেনঃ তুমি পাপিষ্ঠ সম্প্রদায়ের নিকট যাও;\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmcmxliii{ফেরাউনের সম্প্রদায়ের নিকট; তারা কি ভয় করে না?\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmcmxliv{সে বলল, হে আমার পালনকর্তা, আমার আশংকা হচ্ছে যে, তারা আমাকে মিথ্যাবাদী বলে দেবে।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmcmxlv{এবং আমার মন হতবল হয়ে পড়ে এবং আমার জিহবা অচল হয়ে যায়। সুতরাং হারুনের কাছে বার্তা প্রেরণ করুন।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmcmxlvi{আমার বিরুদ্ধে তাদের অভিযোগ আছে। অতএব আমি আশংকা করি যে, তারা আমাকে হত্যা করবে।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmcmxlvii{আল্লাহ বলেন, কখনই নয় তোমরা উভয়ে যাও আমার নিদর্শনাবলী নিয়ে। আমি তোমাদের সাথে থেকে শোনব।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmcmxlviii{অতএব তোমরা ফেরআউনের কাছে যাও এবং বল, আমরা বিশ্বজগতের পালনকর্তার রসূল।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmcmxlix{যাতে তুমি বনী-ইসরাঈলকে আমাদের সাথে যেতে দাও।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmcml{ফেরাউন বলল, আমরা কি তোমাকে শিশু অবস্থায় আমাদের মধ্যে লালন-পালন করিনি? এবং তুমি আমাদের মধ্যে জীবনের বহু বছর কাটিয়েছ।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmcmli{তুমি সেই-তোমরা অপরাধ যা করবার করেছ। তুমি হলে কৃতঘ্ন।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmcmlii{মূসা বলল, আমি সে অপরাধ তখন করেছি, যখন আমি ভ্রান্ত ছিলাম।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmcmliii{অতঃপর আমি ভীত হয়ে তোমাদের কাছ থেকে পলায়ন করলাম। এরপর আমার পালনকর্তা আমাকে প্রজ্ঞা দান করেছেন এবং আমাকে পয়গম্বর করেছেন।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmcmliv{আমার প্রতি তোমার যে অনুগ্রহের কথা বলছ, তা এই যে, তুমি বনী-ইসলাঈলকে গোলাম বানিয়ে রেখেছ।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmcmlv{ফেরাউন বলল, বিশ্বজগতের পালনকর্তা আবার কি?\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmcmlvi{মূসা বলল, তিনি নভোমন্ডল, ভূমন্ডল ও এতদুভয়ের মধ্যবর্তী সবকিছুর পালনকর্তা যদি তোমরা বিশ্বাসী হও।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmcmlvii{ফেরাউন তার পরিষদবর্গকে বলল, তোমরা কি শুনছ না?\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmcmlviii{মূসা বলল, তিনি তোমাদের পালনকর্তা এবং তোমাদের পূর্ববর্তীদেরও পালনকর্তা।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmcmlix{ফেরাউন বলল, তোমাদের প্রতি প্রেরিত তোমাদের রসূলটি নিশ্চয়ই বদ্ধ পাগল।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmcmlx{মূসা বলল, তিনি পূর্ব, পশ্চিম ও এতদুভয়ের মধ্যবর্তী সব কিছুর পালনকর্তা, যদি তোমরা বোঝ।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmcmlxi{ফেরাউন বলল, তুমি যদি আমার পরিবর্তে অন্যকে উপাস্যরূপে গ্রহণ কর তবে আমি অবশ্যই তোমাকে কারাগারে নিক্ষেপ করব।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmcmlxii{মূসা বলল, আমি তোমার কাছে কোন স্পষ্ট বিষয় নিয়ে আগমন করলেও কি?\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmcmlxiii{ফেরাউন বলল, তুমি সত্যবাদী হলে তা উপস্থিত কর।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmcmlxiv{অতঃপর তিনি লাঠি নিক্ষেপ করলে মুহূর্তের মধ্যে তা সুস্পষ্ট অজগর হয়ে গেল।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmcmlxv{আর তিনি তার হাত বের করলেন, তৎক্ষণাৎ তা দর্শকদের কাছে সুশুভ্র প্রতিভাত হলো।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmcmlxvi{ফেরাউন তার পরিষদবর্গকে বলল, নিশ্চয় এ একজন সুদক্ষ জাদুকর।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmcmlxvii{সে তার জাদু বলে তোমাদেরকে তোমাদের দেশ থেকে বহিস্কার করতে চায়। অতএব তোমাদের মত কি?\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmcmlxviii{তারা বলল, তাকে ও তার ভাইকে কিছু অবকাশ দিন এবং শহরে শহরে ঘোষক প্রেরণ করুন।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmcmlxix{তারা যেন আপনার কাছে প্রত্যেকটি দক্ষ জাদুকর কে উপস্থিত করে।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmcmlxx{অতঃপর এক নির্দিষ্ট দিনে জাদুকরদেরকে একত্রিত করা হল।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmcmlxxi{এবং জনগণের মধ্যে ঘোষণা করা হল, তোমরাও সমবেত হও।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmcmlxxii{যাতে আমরা জাদুকরদের অনুসরণ করতে পারি-যদি তারাই বিজয়ী হয়।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmcmlxxiii{যখন যাদুকররা আগমণ করল, তখন ফেরআউনকে বলল, যদি আমরা বিজয়ী হই, তবে আমরা পুরস্কার পাব তো?\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmcmlxxiv{ফেরাউন বলল, হঁ্যা এবং তখন তোমরা আমার নৈকট্যশীলদের অন্তর্ভুক্ত হবে।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmcmlxxv{মূসা (আঃ) তাদেরকে বললেন, নিক্ষেপ কর তোমরা যা নিক্ষেপ করবে।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmcmlxxvi{অতঃপর তারা তাদের রশি ও লাঠি নিক্ষেপ করল এবং বলল, ফেরাউনের ইযযতের কসম, আমরাই বিজয়ী হব।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmcmlxxvii{অতঃপর মূসা তাঁর লাঠি নিক্ষেপ করল, হঠাৎ তা তাদের অলীক কীর্তিগুলোকে গ্রাস করতে লাগল।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmcmlxxviii{তখন জাদুকররা সেজদায় নত হয়ে গেল।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmcmlxxix{তারা বলল, আমরা রাব্বুল আলামীনের প্রতি বিশ্বাস স্থাপন করলাম।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmcmlxxx{যিনি মূসা ও হারুনের রব।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmcmlxxxi{ফেরাউন বলল, আমার অনুমতি দানের পূর্বেই তোমরা কি তাকে মেনে নিলে? নিশ্চয় সে তোমাদের প্রধান, যে তোমাদেরকে জাদু শিক্ষা দিয়েছে। শীঘ্রই তোমরা পরিণাম জানতে পারবে। আমি অবশ্যই তোমাদের হাত ও পা বিপরীত দিক থেকে কর্তন করব। এবং তোমাদের সবাইকে শূলে চড়াব।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmcmlxxxii{তারা বলল, কোন ক্ষতি নেই। আমরা আমাদের পালনকর্তার কাছে প্রত্যাবর্তন করব।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmcmlxxxiii{আমরা আশা করি, আমাদের পালনকর্তা আমাদের ক্রটি-বিচ্যুতি মার্জনা করবেন। কারণ, আমরা বিশ্বাস স্থাপনকারীদের মধ্যে অগ্রণী।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmcmlxxxiv{আমি মূসাকে আদেশ করলাম যে, আমার বান্দাদেরকে নিয়ে রাত্রিযোগে বের হয়ে যাও, নিশ্চয় তোমাদের পশ্চাদ্ধাবন করা হবে।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmcmlxxxv{অতঃপর ফেরাউন শহরে শহরে সংগ্রাহকদেরকে প্রেরণ করল,\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmcmlxxxvi{নিশ্চয় এরা (বনী-ইসরাঈলরা) ক্ষুদ্র একটি দল।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmcmlxxxvii{এবং তারা আমাদের ক্রোধের উদ্রেক করেছে।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mmcmlxxxviii{এবং আমরা সবাই সদা শংকিত।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mmcmlxxxix{অতঃপর আমি ফেরআউনের দলকে তাদের বাগ-বাগিচা ও ঝর্ণাসমূহ থেকে বহিষ্কার করলাম।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mmcmxc{এবং ধন-ভান্ডার ও মনোরম স্থানসমূহ থেকে।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mmcmxci{এরূপই হয়েছিল এবং বনী-ইসলাঈলকে করে দিলাম এসবের মালিক।\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mmcmxcii{অতঃপর সুর্যোদয়ের সময় তারা তাদের পশ্চাদ্ধাবন করল।\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mmcmxciii{যখন উভয় দল পরস্পরকে দেখল, তখন মূসার সঙ্গীরা বলল, আমরা যে ধরা পড়ে গেলাম।\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mmcmxciv{মূসা বলল, কখনই নয়, আমার সাথে আছেন আমার পালনকর্তা। তিনি আমাকে পথ বলে দেবেন।\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mmcmxcv{অতঃপর আমি মূসাকে আদেশ করলাম, তোমার লাঠি দ্বারা সমূদ্রকে আঘাত কর। ফলে, তা বিদীর্ণ হয়ে গেল এবং প্রত্যেক ভাগ বিশাল পর্বতসদৃশ হয়ে গেল।\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mmcmxcvi{আমি সেথায় অপর দলকে পৌঁছিয়ে দিলাম।\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mmcmxcvii{এবং মূসা ও তাঁর সংগীদের সবাইকে বাঁচিয়ে দিলাম।\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mmcmxcviii{অতঃপর অপর দলটিকে নিমজ্জত কললাম।\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mmcmxcix{নিশ্চয় এতে একটি নিদর্শন আছে এবং তাদের অধিকাংশই বিশ্বাসী ছিল না।\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mmm{আপনার পালনকর্তা অবশ্যই পরাক্রমশালী, পরম দয়ালু।\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mmmi{আর তাদেরকে ইব্রাহীমের বৃত্তান্ত শুনিয়ে দিন।\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mmmii{যখন তাঁর পিতাকে এবং তাঁর সম্প্রদায়কে বললেন, তোমরা কিসের এবাদত কর?\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@mmmiii{তারা বলল, আমরা প্রতিমার পূজা করি এবং সারাদিন এদেরকেই নিষ্ঠার সাথে আঁকড়ে থাকি।\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@mmmiv{ইব্রাহীম (আঃ) বললেন, তোমরা যখন আহবান কর, তখন তারা শোনে কি?\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@mmmv{অথবা তারা কি তোমাদের উপকার কিংবা ক্ষতি করতে পারে?\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@mmmvi{তারা বললঃ না, তবে আমরা আমাদের পিতৃপুরুষদেরকে পেয়েছি, তারা এরূপই করত।\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@mmmvii{ইব্রাহীম বললেন, তোমরা কি তাদের সম্পর্কে ভেবে দেখেছ, যাদের পূজা করে আসছ।\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@mmmviii{তোমরা এবং তোমাদের পূর্ববর্তী পিতৃপুরুষেরা ?\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@mmmix{বিশ্বপালনকর্তা ব্যতীত তারা সবাই আমার শত্রু।\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@mmmx{যিনি আমাকে সৃষ্টি করেছেন, অতঃপর তিনিই আমাকে পথপ্রদর্শন করেন,\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@mmmxi{যিনি আমাকে আহার এবং পানীয় দান করেন,\qt@no{(79)}}
\qt@newcmd\qurantrans@bn@mmmxii{যখন আমি রোগাক্রান্ত হই, তখন তিনিই আরোগ্য দান করেন।\qt@no{(80)}}
\qt@newcmd\qurantrans@bn@mmmxiii{যিনি আমার মৃত্যু ঘটাবেন, অতঃপর পুনর্জীবন দান করবেন।\qt@no{(81)}}
\qt@newcmd\qurantrans@bn@mmmxiv{আমি আশা করি তিনিই বিচারের দিনে আমার ক্রটি-বিচ্যুতি মাফ করবেন।\qt@no{(82)}}
\qt@newcmd\qurantrans@bn@mmmxv{হে আমার পালনকর্তা, আমাকে প্রজ্ঞা দান কর এবং আমাকে সৎকর্মশীলদের অন্তর্ভুক্ত কর\qt@no{(83)}}
\qt@newcmd\qurantrans@bn@mmmxvi{এবং আমাকে পরবর্তীদের মধ্যে সত্যভাষী কর।\qt@no{(84)}}
\qt@newcmd\qurantrans@bn@mmmxvii{এবং আমাকে নেয়ামত উদ্যানের অধিকারীদের অন্তর্ভূক্ত কর।\qt@no{(85)}}
\qt@newcmd\qurantrans@bn@mmmxviii{এবং আমার পিতাকে ক্ষমা কর। সে তো পথভ্রষ্টদের অন্যতম।\qt@no{(86)}}
\qt@newcmd\qurantrans@bn@mmmxix{এবং পূনরুত্থান দিবসে আমাকে লাঞ্ছিত করো না,\qt@no{(87)}}
\qt@newcmd\qurantrans@bn@mmmxx{যে দিবসে ধন-সম্পদ ও সন্তান সন্ততি কোন উপকারে আসবে না;\qt@no{(88)}}
\qt@newcmd\qurantrans@bn@mmmxxi{কিন্তু যে সুস্থ অন্তর নিয়ে আল্লাহর কাছে আসবে।\qt@no{(89)}}
\qt@newcmd\qurantrans@bn@mmmxxii{জান্নাত আল্লাহভীরুদের নিকটবর্তী করা হবে।\qt@no{(90)}}
\qt@newcmd\qurantrans@bn@mmmxxiii{এবং বিপথগামীদের সামনে উম্মোচিত করা হবে জাহান্নাম।\qt@no{(91)}}
\qt@newcmd\qurantrans@bn@mmmxxiv{তাদেরকে বলা হবেঃ তারা কোথায়, তোমরা যাদের পূজা করতে।\qt@no{(92)}}
\qt@newcmd\qurantrans@bn@mmmxxv{আল্লাহর পরিবর্তে? তারা কি তোমাদের সাহায্য করতে পারে, অথবা তারা প্রতিশোধ নিতে পারে?\qt@no{(93)}}
\qt@newcmd\qurantrans@bn@mmmxxvi{অতঃপর তাদেরকে এবং পথভ্রষ্টদেরকে আধোমুখি করে নিক্ষেপ করা হবে জাহান্নামে।\qt@no{(94)}}
\qt@newcmd\qurantrans@bn@mmmxxvii{এবং ইবলীস বাহিনীর সকলকে।\qt@no{(95)}}
\qt@newcmd\qurantrans@bn@mmmxxviii{তারা তথায় কথা কাটাকাটিতে লিপ্ত হয়ে বলবেঃ\qt@no{(96)}}
\qt@newcmd\qurantrans@bn@mmmxxix{আল্লাহর কসম, আমরা প্রকাশ্য বিভ্রান্তিতে লিপ্ত ছিলাম।\qt@no{(97)}}
\qt@newcmd\qurantrans@bn@mmmxxx{যখন আমরা তোমাদেরকে বিশ্ব-পালনকর্তার সমতুল্য গন্য করতাম।\qt@no{(98)}}
\qt@newcmd\qurantrans@bn@mmmxxxi{আমাদেরকে দুষ্টকর্মীরাই গোমরাহ করেছিল।\qt@no{(99)}}
\qt@newcmd\qurantrans@bn@mmmxxxii{অতএব আমাদের কোন সুপারিশকারী নেই।\qt@no{(100)}}
\qt@newcmd\qurantrans@bn@mmmxxxiii{এবং কোন সহৃদয় বন্ধু ও নেই।\qt@no{(101)}}
\qt@newcmd\qurantrans@bn@mmmxxxiv{হায়, যদি কোনরুপে আমরা পৃথিবীতে প্রত্যাবর্তনের সুযোগ পেতাম, তবে আমরা বিশ্বাস স্থাপনকারী হয়ে যেতাম।\qt@no{(102)}}
\qt@newcmd\qurantrans@bn@mmmxxxv{নিশ্চয়, এতে নিদর্শন আছে এবং তাদের অধিকাংশই বিশ্বাসী নয়।\qt@no{(103)}}
\qt@newcmd\qurantrans@bn@mmmxxxvi{আপনার পালনকর্তা প্রবল পরাক্রমশালী, পরম দয়ালু।\qt@no{(104)}}
\qt@newcmd\qurantrans@bn@mmmxxxvii{নূহের সম্প্রদায় পয়গম্বরগণকে মিথ্যারোপ করেছে।\qt@no{(105)}}
\qt@newcmd\qurantrans@bn@mmmxxxviii{যখন তাদের ভ্রাতা নূহ তাদেরকে বললেন, তোমাদের কি ভয় নেই?\qt@no{(106)}}
\qt@newcmd\qurantrans@bn@mmmxxxix{আমি তোমাদের জন্য বিশ্বস্ত বার্তাবাহক।\qt@no{(107)}}
\qt@newcmd\qurantrans@bn@mmmxl{অতএব, তোমরা আল্লাহকে ভয় কর এবং আমার আনুগত্য কর।\qt@no{(108)}}
\qt@newcmd\qurantrans@bn@mmmxli{আমি তোমাদের কাছে এর জন্য কোন প্রতিদান চাই না, আমার প্রতিদান তো বিশ্ব-পালনকর্তাই দেবেন।\qt@no{(109)}}
\qt@newcmd\qurantrans@bn@mmmxlii{অতএব, তোমরা আল্লাহকে ভয় কর এবং আমার আনুগত্য কর।\qt@no{(110)}}
\qt@newcmd\qurantrans@bn@mmmxliii{তারা বলল, আমরা কি তোমাকে মেনে নেব যখন তোমার অনুসরণ করছে ইতরজনেরা?\qt@no{(111)}}
\qt@newcmd\qurantrans@bn@mmmxliv{নূহ বললেন, তারা কি কাজ করছে, তা জানা আমার কি দরকার?\qt@no{(112)}}
\qt@newcmd\qurantrans@bn@mmmxlv{তাদের হিসাব নেয়া আমার পালনকর্তারই কাজ; যদি তোমরা বুঝতে!\qt@no{(113)}}
\qt@newcmd\qurantrans@bn@mmmxlvi{আমি মুমিনগণকে তাড়িয়ে দেয়ার লোক নই।\qt@no{(114)}}
\qt@newcmd\qurantrans@bn@mmmxlvii{আমি তো শুধু একজন সুস্পষ্ট সতর্ককারী।\qt@no{(115)}}
\qt@newcmd\qurantrans@bn@mmmxlviii{তারা বলল, হে নূহ যদি তুমি বিরত না হও, তবে তুমি নিশ্চিতই প্রস্তরাঘাতে নিহত হবে।\qt@no{(116)}}
\qt@newcmd\qurantrans@bn@mmmxlix{নূহ বললেন, হে আমার পালনকর্তা, আমার সম্প্রদায় তো আমাকে মিথ্যাবাদী বলছে।\qt@no{(117)}}
\qt@newcmd\qurantrans@bn@mmml{অতএব, আমার ও তাদের মধ্যে কোন ফয়সালা করে দিন এবং আমাকে ও আমার সংগী মুমিনগণকে রক্ষা করুন।\qt@no{(118)}}
\qt@newcmd\qurantrans@bn@mmmli{অতঃপর আমি তাঁকে ও তাঁর সঙ্গিগণকে বোঝাই করা নৌকায় রক্ষা করলাম।\qt@no{(119)}}
\qt@newcmd\qurantrans@bn@mmmlii{এরপর অবশিষ্ট সবাইকে নিমজ্জত করলাম।\qt@no{(120)}}
\qt@newcmd\qurantrans@bn@mmmliii{নিশ্চয় এতে নিদর্শন আছে এবং তাদের অধিকাংশই বিশ্বাসী নয়।\qt@no{(121)}}
\qt@newcmd\qurantrans@bn@mmmliv{নিশ্চয় আপনার পালনকর্তা প্রবল পরাক্রমশালী, পরম দয়ালু।\qt@no{(122)}}
\qt@newcmd\qurantrans@bn@mmmlv{আদ সম্প্রদায় পয়গম্বরগণকে মিথ্যাবাদী বলেছে।\qt@no{(123)}}
\qt@newcmd\qurantrans@bn@mmmlvi{তখন তাদের ভাই হুদ তাদেরকে বললেনঃ তোমাদের কি ভয় নেই?\qt@no{(124)}}
\qt@newcmd\qurantrans@bn@mmmlvii{আমি তোমাদের বিশ্বস্ত রসূল।\qt@no{(125)}}
\qt@newcmd\qurantrans@bn@mmmlviii{অতএব, তোমরা আল্লাহকে ভয় কর এবং আমার আনুগত্য কর।\qt@no{(126)}}
\qt@newcmd\qurantrans@bn@mmmlix{আমি তোমাদের কাছে এর জন্যে প্রতিদান চাই না। আমার প্রতিদান তো পালনকর্তা দেবেন।\qt@no{(127)}}
\qt@newcmd\qurantrans@bn@mmmlx{তোমরা কি প্রতিটি উচ্চস্থানে অযথা নিদর্শন নির্মান করছ?\qt@no{(128)}}
\qt@newcmd\qurantrans@bn@mmmlxi{এবং বড় বড় প্রাসাদ নির্মাণ করছ, যেন তোমরা চিরকাল থাকবে?\qt@no{(129)}}
\qt@newcmd\qurantrans@bn@mmmlxii{যখন তোমরা আঘাত হান, তখন জালেম ও নিষ্ঠুরের মত আঘাত হান।\qt@no{(130)}}
\qt@newcmd\qurantrans@bn@mmmlxiii{অতএব, আল্লাহকে ভয় কর এবং আমার অনুগত্য কর।\qt@no{(131)}}
\qt@newcmd\qurantrans@bn@mmmlxiv{ভয় কর তাঁকে, যিনি তোমাদেরকে সেসব বস্তু দিয়েছেন, যা তোমরা জান।\qt@no{(132)}}
\qt@newcmd\qurantrans@bn@mmmlxv{তোমাদেরকে দিয়েছেন চতুষ্পদ জন্তু ও পুত্র-সন্তান,\qt@no{(133)}}
\qt@newcmd\qurantrans@bn@mmmlxvi{এবং উদ্যান ও ঝরণা।\qt@no{(134)}}
\qt@newcmd\qurantrans@bn@mmmlxvii{আমি তোমাদের জন্যে মহাদিবসের শাস্তি আশংকা করি।\qt@no{(135)}}
\qt@newcmd\qurantrans@bn@mmmlxviii{তারা বলল, তুমি উপদেশ দাও অথবা উপদেশ নাই দাও, উভয়ই আমাদের জন্যে সমান।\qt@no{(136)}}
\qt@newcmd\qurantrans@bn@mmmlxix{এসব কথাবার্তা পূর্ববর্তী লোকদের অভ্যাস বৈ নয়।\qt@no{(137)}}
\qt@newcmd\qurantrans@bn@mmmlxx{আমরা শাস্তিপ্রাপ্ত হব না।\qt@no{(138)}}
\qt@newcmd\qurantrans@bn@mmmlxxi{অতএব, তারা তাঁকে মিথ্যাবাদী বলতে লাগল এবং আমি তাদেরকে নিপাত করে দিলাম। এতে অবশ্যই নিদর্শন আছে; কিন্তু তাদের অধিকাংশই বিশ্বাসী নয়।\qt@no{(139)}}
\qt@newcmd\qurantrans@bn@mmmlxxii{এবং আপনার পালনকর্তা, তিনি তো প্রবল পরাক্রমশালী, পরম দয়ালু।\qt@no{(140)}}
\qt@newcmd\qurantrans@bn@mmmlxxiii{সামুদ সম্প্রদায় পয়গম্বরগণকে মিথ্যাবাদী বলেছে।\qt@no{(141)}}
\qt@newcmd\qurantrans@bn@mmmlxxiv{যখন তাদের ভাই সালেহ, তাদেরকে বললেন, তোমরা কি ভয় কর না?\qt@no{(142)}}
\qt@newcmd\qurantrans@bn@mmmlxxv{আমি তোমাদের বিশ্বস্ত পয়গম্বর।\qt@no{(143)}}
\qt@newcmd\qurantrans@bn@mmmlxxvi{অতএব, আল্লাহকে ভয় কর এবং আমার আনুগত্য কর।\qt@no{(144)}}
\qt@newcmd\qurantrans@bn@mmmlxxvii{আমি এর জন্যে তোমাদের কাছে কোন প্রতিদান চাই না। আমার প্রতিদান তো বিশ্ব-পালনকর্তাই দেবেন।\qt@no{(145)}}
\qt@newcmd\qurantrans@bn@mmmlxxviii{তোমাদেরকে কি এ জগতের ভোগ-বিলাসের মধ্যে নিরাপদে রেখে দেয়া হবে?\qt@no{(146)}}
\qt@newcmd\qurantrans@bn@mmmlxxix{উদ্যানসমূহের মধ্যে এবং ঝরণাসমূহের মধ্যে ?\qt@no{(147)}}
\qt@newcmd\qurantrans@bn@mmmlxxx{শস্যক্ষেত্রের মধ্যে এবং মঞ্জুরিত খেজুর বাগানের মধ্যে ?\qt@no{(148)}}
\qt@newcmd\qurantrans@bn@mmmlxxxi{তোমরা পাহাড় কেটে জাঁক জমকের গৃহ নির্মাণ করছ।\qt@no{(149)}}
\qt@newcmd\qurantrans@bn@mmmlxxxii{সুতরাং তোমরা আল্লাহকে ভয় কর এবং আমার অনুগত্য কর।\qt@no{(150)}}
\qt@newcmd\qurantrans@bn@mmmlxxxiii{এবং সীমালংঘনকারীদের আদেশ মান্য কর না;\qt@no{(151)}}
\qt@newcmd\qurantrans@bn@mmmlxxxiv{যারা পৃথিবীতে অনর্থ সৃষ্টি করে এবং শান্তি স্থাপন করে না;\qt@no{(152)}}
\qt@newcmd\qurantrans@bn@mmmlxxxv{তারা বলল, তুমি তো জাদুগ্রস্থুরেদ একজন।\qt@no{(153)}}
\qt@newcmd\qurantrans@bn@mmmlxxxvi{তুমি তো আমাদের মতই একজন মানুষ বৈ নও। সুতরাং যদি তুমি সত্যবাদী হও, তবে কোন নিদর্শন উপস্থিত কর।\qt@no{(154)}}
\qt@newcmd\qurantrans@bn@mmmlxxxvii{সালেহ বললেন এই উষ্ট্রী, এর জন্যে আছে পানি পানের পালা এবং তোমাদের জন্যে আছে পানি পানের পালা নির্দিষ্ট এক-এক দিনের।\qt@no{(155)}}
\qt@newcmd\qurantrans@bn@mmmlxxxviii{তোমরা একে কোন কষ্ট দিও না। তাহলে তোমাদেরকে মহাদিবসের আযাব পাকড়াও করবে।\qt@no{(156)}}
\qt@newcmd\qurantrans@bn@mmmlxxxix{তারা তাকে বধ করল ফলে, তারা অনুতপ্ত হয়ে গেল।\qt@no{(157)}}
\qt@newcmd\qurantrans@bn@mmmxc{এরপর আযাব তাদেরকে পাকড়াও করল। নিশ্চয় এতে নিদর্শন আছে। কিন্তু তাদের অধিকাংশই বিশ্বাসী নয়।\qt@no{(158)}}
\qt@newcmd\qurantrans@bn@mmmxci{আপনার পালনকর্তা প্রবল পরাক্রমশালী, পরম দয়ালু।\qt@no{(159)}}
\qt@newcmd\qurantrans@bn@mmmxcii{লূতের সম্প্রদায় পয়গম্বরগণকে মিথ্যাবাদী বলেছে।\qt@no{(160)}}
\qt@newcmd\qurantrans@bn@mmmxciii{যখন তাদের ভাই লূত তাদেরকে বললেন, তোমরা কি ভয় কর না ?\qt@no{(161)}}
\qt@newcmd\qurantrans@bn@mmmxciv{আমি তোমাদের বিশ্বস্ত পয়গম্বর।\qt@no{(162)}}
\qt@newcmd\qurantrans@bn@mmmxcv{অতএব, তোমরা আল্লাহকে ভয় কর এবং আমার আনুগত্য কর।\qt@no{(163)}}
\qt@newcmd\qurantrans@bn@mmmxcvi{আমি এর জন্যে তোমাদের কাছে কোন প্রতিদান চাই না। আমার প্রতিদান তো বিশ্ব-পালনকর্তা দেবেন।\qt@no{(164)}}
\qt@newcmd\qurantrans@bn@mmmxcvii{সারা জাহানের মানুষের মধ্যে তোমরাই কি পুরূষদের সাথে কুকর্ম কর?\qt@no{(165)}}
\qt@newcmd\qurantrans@bn@mmmxcviii{এবং তোমাদের পালনকর্তা তোমাদের জন্যে যে স্ত্রীগনকে সৃষ্টি করেছেন, তাদেরকে বর্জন কর? বরং তোমরা সীমালঙ্ঘনকারী সম্প্রদায়।\qt@no{(166)}}
\qt@newcmd\qurantrans@bn@mmmxcix{তারা বলল, হে লূত, তুমি যদি বিরত না হও, তবে অবশ্যই তোমাকে বহিস্কৃত করা হবে।\qt@no{(167)}}
\qt@newcmd\qurantrans@bn@mmmc{লূত বললেন, আমি তোমাদের এই কাজকে ঘৃণা করি।\qt@no{(168)}}
\qt@newcmd\qurantrans@bn@mmmci{হে আমার পালনকর্তা, আমাকে এবং আমার পরিবারবর্গকে তারা যা করে, তা থেকে রক্ষা কর।\qt@no{(169)}}
\qt@newcmd\qurantrans@bn@mmmcii{অতঃপর আমি তাঁকে ও তাঁর পরিবারবর্গকে রক্ষা করলাম।\qt@no{(170)}}
\qt@newcmd\qurantrans@bn@mmmciii{এক বৃদ্ধা ব্যতীত, সে ছিল ধ্বংস প্রাপ্তদের অন্তর্ভুক্ত।\qt@no{(171)}}
\qt@newcmd\qurantrans@bn@mmmciv{এরপর অন্যদেরকে নিপাত করলাম।\qt@no{(172)}}
\qt@newcmd\qurantrans@bn@mmmcv{তাদের উপর এক বিশেষ বৃষ্টি বর্ষণ করলাম। ভীতি-প্রদর্শিত দের জন্যে এই বৃষ্টি ছিল কত নিকৃষ্ট।\qt@no{(173)}}
\qt@newcmd\qurantrans@bn@mmmcvi{নিশ্চয়ই এতে নিদর্শন রয়েছে; কিন্তু তাদের অধিকাংশই বিশ্বাসী নয়।\qt@no{(174)}}
\qt@newcmd\qurantrans@bn@mmmcvii{নিশ্চয়ই আপনার পালনকর্তা প্রবল পরাক্রমশালী, পরম দয়ালু।\qt@no{(175)}}
\qt@newcmd\qurantrans@bn@mmmcviii{বনের অধিবাসীরা পয়গম্বরগণকে মিথ্যাবাদী বলেছে।\qt@no{(176)}}
\qt@newcmd\qurantrans@bn@mmmcix{যখন শো’আয়ব তাদের কে বললেন, তোমরা কি ভয় কর না?\qt@no{(177)}}
\qt@newcmd\qurantrans@bn@mmmcx{আমি তোমাদের বিশ্বস্ত পয়গম্বর।\qt@no{(178)}}
\qt@newcmd\qurantrans@bn@mmmcxi{অতএব, তোমরা আল্লাহকে ভয় কর এবং আমার আনুগত্য কর।\qt@no{(179)}}
\qt@newcmd\qurantrans@bn@mmmcxii{আমি তোমাদের কাছে এর জন্য কোন প্রতিদান চাই না। আমার প্রতিদান তো বিশ্ব-পালনকর্তাই দেবেন।\qt@no{(180)}}
\qt@newcmd\qurantrans@bn@mmmcxiii{মাপ পূর্ণ কর এবং যারা পরিমাপে কম দেয়, তাদের অন্তর্ভুক্ত হয়ো না।\qt@no{(181)}}
\qt@newcmd\qurantrans@bn@mmmcxiv{সোজা দাঁড়ি-পাল্লায় ওজন কর।\qt@no{(182)}}
\qt@newcmd\qurantrans@bn@mmmcxv{মানুষকে তাদের বস্তু কম দিও না এবং পৃথিবীতে অনর্থ সৃষ্টি করে ফিরো না।\qt@no{(183)}}
\qt@newcmd\qurantrans@bn@mmmcxvi{ভয় কর তাঁকে, যিনি তোমাদেরকে এবং তোমাদের পূর্ববর্তী লোক-সম্প্রদায়কে সৃষ্টি করেছেন।\qt@no{(184)}}
\qt@newcmd\qurantrans@bn@mmmcxvii{তারা বলল, তুমি তো জাদুগ্রস্তদের অন্যতম।\qt@no{(185)}}
\qt@newcmd\qurantrans@bn@mmmcxviii{তুমি আমাদের মত মানুষ বৈ তো নও। আমাদের ধারণা-তুমি মিথ্যাবাদীদের অন্তর্ভুক্ত।\qt@no{(186)}}
\qt@newcmd\qurantrans@bn@mmmcxix{অতএব, যদি সত্যবাদী হও, তবে আকাশের কোন টুকরো আমাদের উপর ফেলে দাও।\qt@no{(187)}}
\qt@newcmd\qurantrans@bn@mmmcxx{শো’আয়ব বললেন, তোমরা যা কর, সে সম্পর্কে আমার পালনকর্তা ভালরূপে অবহিত।\qt@no{(188)}}
\qt@newcmd\qurantrans@bn@mmmcxxi{অতঃপর তারা তাঁকে মিথ্যাবাদী বলে দিল। ফলে তাদেরকে মেঘাচ্ছন্ন দিবসের আযাব পাকড়াও করল। নিশ্চয় সেটা ছিল এক মহাদিবসের আযাব।\qt@no{(189)}}
\qt@newcmd\qurantrans@bn@mmmcxxii{নিশ্চয় এতে নিদর্শন রয়েছে; কিন্তু তাদের অধিকাংশই বিশ্বাস করে না।\qt@no{(190)}}
\qt@newcmd\qurantrans@bn@mmmcxxiii{নিশ্চয় আপনার পালনকর্তা প্রবল পরাক্রমশালী, পরম দয়ালু।\qt@no{(191)}}
\qt@newcmd\qurantrans@bn@mmmcxxiv{এই কোরআন তো বিশ্ব-জাহানের পালনকর্তার নিকট থেকে অবতীর্ণ।\qt@no{(192)}}
\qt@newcmd\qurantrans@bn@mmmcxxv{বিশ্বস্ত ফেরেশতা একে নিয়ে অবতরণ করেছে।\qt@no{(193)}}
\qt@newcmd\qurantrans@bn@mmmcxxvi{আপনার অন্তরে, যাতে আপনি ভীতি প্রদর্শণকারীদের অন্তর্ভুক্ত হন,\qt@no{(194)}}
\qt@newcmd\qurantrans@bn@mmmcxxvii{সুস্পষ্ট আরবী ভাষায়।\qt@no{(195)}}
\qt@newcmd\qurantrans@bn@mmmcxxviii{নিশ্চয় এর উল্লেখ আছে পূর্ববর্তী কিতাবসমূহে।\qt@no{(196)}}
\qt@newcmd\qurantrans@bn@mmmcxxix{তাদের জন্যে এটা কি নিদর্শন নয় যে, বনী-ইসরাঈলের আলেমগণ এটা অবগত আছে?\qt@no{(197)}}
\qt@newcmd\qurantrans@bn@mmmcxxx{যদি আমি একে কোন ভিন্নভাষীর প্রতি অবতীর্ণ করতাম,\qt@no{(198)}}
\qt@newcmd\qurantrans@bn@mmmcxxxi{অতঃপর তিনি তা তাদের কাছে পাঠ করতেন, তবে তারা তাতে বিশ্বাস স্থাপন করত না।\qt@no{(199)}}
\qt@newcmd\qurantrans@bn@mmmcxxxii{এমনিভাবে আমি গোনাহগারদের অন্তরে অবিশ্বাস সঞ্চার করেছি।\qt@no{(200)}}
\qt@newcmd\qurantrans@bn@mmmcxxxiii{তারা এর প্রতি বিশ্বাস স্থাপন করবে না, যে পর্যন্ত প্রত্যক্ষ না করে মর্মন্তুদ আযাব।\qt@no{(201)}}
\qt@newcmd\qurantrans@bn@mmmcxxxiv{অতঃপর তা আকস্মিকভাবে তাদের কাছে এসে পড়বে, তারা তা বুঝতে ও পারবে না।\qt@no{(202)}}
\qt@newcmd\qurantrans@bn@mmmcxxxv{তখন তারা বলবে, আমরা কি অবকাশ পাব না?\qt@no{(203)}}
\qt@newcmd\qurantrans@bn@mmmcxxxvi{তারা কি আমার শাস্তি দ্রুত কামনা করে?\qt@no{(204)}}
\qt@newcmd\qurantrans@bn@mmmcxxxvii{আপনি ভেবে দেখুন তো, যদি আমি তাদেরকে বছরের পর বছর ভোগ-বিলাস করতে দেই,\qt@no{(205)}}
\qt@newcmd\qurantrans@bn@mmmcxxxviii{অতঃপর যে বিষয়ে তাদেরকে ওয়াদা দেয়া হত, তা তাদের কাছে এসে পড়ে।\qt@no{(206)}}
\qt@newcmd\qurantrans@bn@mmmcxxxix{তখন তাদের ভোগ বিলাস তা তাদের কি কোন উপকারে আসবে?\qt@no{(207)}}
\qt@newcmd\qurantrans@bn@mmmcxl{আমি কোন জনপদ ধ্বংস করিনি; কিন্তু এমতাবস্থায় যে, তারা সতর্ককারী ছিল।\qt@no{(208)}}
\qt@newcmd\qurantrans@bn@mmmcxli{স্মরণ করানোর জন্যে, এবং আমার কাজ অন্যায়াচরণ নয়।\qt@no{(209)}}
\qt@newcmd\qurantrans@bn@mmmcxlii{এই কোরআন শয়তানরা অবতীর্ণ করেনি।\qt@no{(210)}}
\qt@newcmd\qurantrans@bn@mmmcxliii{তারা এ কাজের উপযুক্ত নয় এবং তারা এর সামর্থ?451; রাখে না।\qt@no{(211)}}
\qt@newcmd\qurantrans@bn@mmmcxliv{তাদেরকে তো শ্রবণের জায়গা থেকে দূরে রাখা রয়েছে।\qt@no{(212)}}
\qt@newcmd\qurantrans@bn@mmmcxlv{অতএব, আপনি আল্লাহর সাথে অন্য উপাস্যকে আহবান করবেন না। করলে শাস্তিতে পতিত হবেন।\qt@no{(213)}}
\qt@newcmd\qurantrans@bn@mmmcxlvi{আপনি নিকটতম আত্মীয়দেরকে সতর্ক করে দিন।\qt@no{(214)}}
\qt@newcmd\qurantrans@bn@mmmcxlvii{এবং আপনার অনুসারী মুমিনদের প্রতি সদয় হোন।\qt@no{(215)}}
\qt@newcmd\qurantrans@bn@mmmcxlviii{যদি তারা আপনার অবাধ্য করে, তবে বলে দিন, তোমরা যা কর, তা থেকে আমি মুক্ত।\qt@no{(216)}}
\qt@newcmd\qurantrans@bn@mmmcxlix{আপনি ভরসা করুন পরাক্রমশালী, পরম দয়ালুর উপর,\qt@no{(217)}}
\qt@newcmd\qurantrans@bn@mmmcl{যিনি আপনাকে দেখেন যখন আপনি নামাযে দন্ডায়মান হন,\qt@no{(218)}}
\qt@newcmd\qurantrans@bn@mmmcli{এবং নামাযীদের সাথে উঠাবসা করেন।\qt@no{(219)}}
\qt@newcmd\qurantrans@bn@mmmclii{নিশ্চয় তিনি সর্বশ্রোতা, সর্বজ্ঞানী।\qt@no{(220)}}
\qt@newcmd\qurantrans@bn@mmmcliii{আমি আপনাকে বলব কি কার নিকট শয়তানরা অবতরণ করে?\qt@no{(221)}}
\qt@newcmd\qurantrans@bn@mmmcliv{তারা অবতীর্ণ হয় প্রত্যেক মিথ্যাবাদী, গোনাহগারের উপর।\qt@no{(222)}}
\qt@newcmd\qurantrans@bn@mmmclv{তারা শ্রুত কথা এনে দেয় এবং তাদের অধিকাংশই মিথ্যাবাদী।\qt@no{(223)}}
\qt@newcmd\qurantrans@bn@mmmclvi{বিভ্রান্ত লোকেরাই কবিদের অনুসরণ করে।\qt@no{(224)}}
\qt@newcmd\qurantrans@bn@mmmclvii{তুমি কি দেখ না যে, তারা প্রতি ময়দানেই উদভ্রান্ত হয়ে ফিরে?\qt@no{(225)}}
\qt@newcmd\qurantrans@bn@mmmclviii{এবং এমন কথা বলে, যা তারা করে না।\qt@no{(226)}}
\qt@newcmd\qurantrans@bn@mmmclix{তবে তাদের কথা ভিন্ন, যারা বিশ্বাস স্থাপন করে ও সৎকর্ম করে এবং আল্লাহ কে খুব স্মরণ করে এবং নিপীড়িত হওয়ার পর প্রতিশোধ গ্রহণ করে। নিপীড়নকারীরা শীঘ্রই জানতে পারবে তাদের গন্তব্যস্থল কিরূপ।\qt@no{(227)}}
\qt@newcmd\qurantrans@bn@mmmclx{\basmalahbn ত্বা-সীন; এগুলো আল-কোরআনের আয়াত এবং আয়াত সুস্পষ্ট কিতাবের।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmclxi{মুমিনদের জন্যে পথ নির্দেশ ও সুসংবাদ।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmclxii{যারা নামায কায়েম করে, যাকাত প্রদান করে এবং পরকালে নিশ্চিত বিশ্বাস করে।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmclxiii{যারা পরকালে বিশ্বাস করে না, আমি তাদের দৃষ্টিতে তাদের কর্মকান্ডকে সুশোভিত করে দিয়েছি। অতএব, তারা উদভ্রান্ত হয়ে ঘুরে বেড়ায়।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmclxiv{তাদের জন্যেই রয়েছে মন্দ শাস্তি এবং তারাই পরকালে অধিক ক্ষতিগ্রস্ত।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmclxv{এবং আপনাকে কোরআন প্রদত্ত হচ্ছে প্রজ্ঞাময়, জ্ঞানময় আল্লাহর কাছ থেকে।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmclxvi{যখন মূসা তাঁর পরিবারবর্গকে বললেনঃ আমি অগ্নি দেখেছি, এখন আমি সেখান থেকে তোমাদের জন্যে কোন খবর আনতে পারব অথবা তোমাদের জন্যে জ্বলন্ত অঙ্গার নিয়ে আসতে পারব যাতে তোমরা আগুন পোহাতে পার।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmclxvii{অতঃপর যখন তিনি আগুনের কাছে আসলেন তখন আওয়াজ হল ধন্য তিনি, যিনি আগুনের স্থানে আছেন এবং যারা আগুনের আশেপাশে আছেন। বিশ্ব জাহানের পালনকর্তা আল্লাহ পবিত্র ও মহিমান্বিত।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmclxviii{হে মূসা, আমি আল্লাহ, প্রবল পরাক্রমশালী, প্রজ্ঞাময়।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmclxix{আপনি নিক্ষেপ করুন আপনার লাঠি। অতঃপর যখন তিনি তাকে সর্পের ন্যায় ছুটাছুটি করতে দেখলেন, তখন তিনি বিপরীত দিকে ছুটতে লাগলেন এবং পেছন ফিরেও দেখলেন না। হে মূসা, ভয় করবেন না। আমি যে রয়েছি, আমার কাছে পয়গম্বরগণ ভয় করেন না।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmclxx{তবে যে বাড়াবাড়ি করে এরপর মন্দ কর্মের পরিবর্তে সৎকর্ম করে। নিশ্চয় আমি ক্ষমাশীল, পরম দয়ালু।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmclxxi{আপনার হাত আপনার বগলে ঢুকিয়ে দিন, সুশুভ্র হয়ে বের হবে নির্দোষ অবস্থায়। এগুলো ফেরাউন ও তার সম্প্রদায়ের কাছে আনীত নয়টি নিদর্শনের অন্যতম। নিশ্চয় তারা ছিল পাপাচারী সম্প্রদায়।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmclxxii{অতঃপর যখন তাদের কাছে আমার উজ্জল নিদর্শনাবলী আগমন করল, তখন তারা বলল, এটা তো সুস্পষ্ট জাদু।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmclxxiii{তারা অন্যায় ও অহংকার করে নিদর্শনাবলীকে প্রত্যাখ্যান করল, যদিও তাদের অন্তর এগুলো সত্য বলে বিশ্বাস করেছিল। অতএব দেখুন, অনর্থকারীদের পরিণাম কেমন হয়েছিল?\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmclxxiv{আমি অবশ্যই দাউদ ও সুলায়মানকে জ্ঞান দান করেছিলাম। তাঁরা বলে ছিলেন, আল্লাহর প্রশংসা, যিনি আমাদেরকে তাঁর অনেক মুমিন বান্দার উপর শ্রেষ্ঠত্ব দান করেছেন।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmclxxv{সুলায়মান দাউদের উত্তরাধিকারী হয়েছিলেন। বলেছিলেন, ‘হে লোক সকল, আমাকে উড়ন্ত পক্ষীকূলের ভাষা শিক্ষা দেয়া হয়েছে এবং আমাকে সব কিছু দেয়া হয়েছে। নিশ্চয় এটা সুস্পষ্ট শ্রেষ্ঠত্ব। ’\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmclxxvi{সুলায়মানের সামনে তার সেনাবাহিনীকে সমবেত করা হল। জ্বিন-মানুষ ও পক্ষীকুলকে, অতঃপর তাদেরকে বিভিন্ন ব্যূহে বিভক্ত করা হল।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmclxxvii{যখন তারা পিপীলিকা অধ্যূষিত উপত্যকায় পৌঁছাল, তখন এক পিপীলিকা বলল, হে পিপীলিকার দল, তোমরা তোমাদের গৃহে প্রবেশ কর। অন্যথায় সুলায়মান ও তার বাহিনী অজ্ঞাতসারে তোমাদেরকে পিষ্ট করে ফেলবে।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmclxxviii{তার কথা শুনে সুলায়মান মুচকি হাসলেন এবং বললেন, হে আমার পালনকর্তা, তুমি আমাকে সামর্থ?2470;াও যাতে আমি তোমার সেই নিয়ামতের কৃতজ্ঞতা প্রকাশ করতে পারি, যা তুমি আমাকে ও আমার পিতা-মাতাকে দান করেছ এবং যাতে আমি তোমার পছন্দনীয় সৎকর্ম করতে পারি এবং আমাকে নিজ অনুগ্রহে তোমার সৎকর্মপরায়ন বান্দাদের অন্তর্ভুক্ত কর।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmclxxix{সুলায়মান পক্ষীদের খোঁজ খবর নিলেন, অতঃপর বললেন, কি হল, হুদহুদকে দেখছি না কেন? নাকি সে অনুপস্থিত?\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmclxxx{আমি অবশ্যই তাকে কঠোর শাস্তি দেব কিংবা হত্যা করব অথবা সে উপস্থিত করবে উপযুক্ত কারণ।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmclxxxi{কিছুক্ষণ পড়েই হুদ এসে বলল, আপনি যা অবগত নন, আমি তা অবগত হয়েছি। আমি আপনার কাছে সাবা থেকে নিশ্চিত সংবাদ নিয়ে আগমন করেছি।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmclxxxii{আমি এক নারীকে সাবাবাসীদের উপর রাজত্ব করতে দেখেছি। তাকে সবকিছুই দেয়া হয়েছে এবং তার একটা বিরাট সিংহাসন আছে।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmclxxxiii{আমি তাকে ও তার সম্প্রদায়কে দেখলাম তারা আল্লাহর পরিবর্তে সূর্যকে সেজদা করছে। শয়তান তাদের দৃষ্টিতে তাদের কার্যাবলী সুশোভিত করে দিয়েছে। অতঃপর তাদেরকে সৎপথ থেকে নিবৃত্ত করেছে। অতএব তারা সৎপথ পায় না।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmclxxxiv{তারা আল্লাহকে সেজদা করে না কেন, যিনি নভোমন্ডল ও ভুমন্ডলের গোপন বস্তু প্রকাশ করেন এবং জানেন যা তোমরা গোপন কর ও যা প্রকাশ কর।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmclxxxv{আল্লাহ ব্যতীত কোন উপাস্য নেই; তিনি মহা আরশের মালিক।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmclxxxvi{সুলায়মান বললেন, এখন আমি দেখব তুমি সত্য বলছ, না তুমি মিথ্যবাদী।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmclxxxvii{তুমি আমার এই পত্র নিয়ে যাও এবং এটা তাদের কাছে অর্পন কর। অতঃপর তাদের কাছ থেকে সরে পড় এবং দেখ, তারা কি জওয়াব দেয়।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmclxxxviii{বিলকীস বলল, হে পরিষদবর্গ, আমাকে একটি সম্মানিত পত্র দেয়া হয়েছে।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmclxxxix{সেই পত্র সুলায়মানের পক্ষ থেকে এবং তা এইঃ সসীম দাতা, পরম দয়ালু, আল্লাহর নামে শুরু;\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmcxc{আমার মোকাবেলায় শক্তি প্রদর্শন করো না এবং বশ্যতা স্বীকার করে আমার কাছে উপস্থিত হও।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmcxci{বিলকীস বলল, হে পরিষদবর্গ, আমাকে আমার কাজে পরামর্শ দাও। তোমাদের উপস্থিতি ব্যতিরেকে আমি কোন কাজে সিদ্ধান্ত গ্রহণ করি না।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmcxcii{তারা বলল, আমরা শক্তিশালী এবং কঠোর যোদ্ধা। এখন সিদ্ধান্ত গ্রহণের ক্ষমতা আপনারই। অতএব আপনি ভেবে দেখুন, আমাদেরকে কি আদেশ করবেন।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmcxciii{সে বলল, রাজা বাদশারা যখন কোন জনপদে প্রবেশ করে, তখন তাকে বিপর্যস্ত করে দেয় এবং সেখানকার সম্ভ্রান্ত ব্যক্তিবর্গকে অপদস্থ করে। তারাও এরূপই করবে।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmcxciv{আমি তাঁর কাছে কিছু উপঢৌকন পাঠাচ্ছি; দেখি প্রেরিত লোকেরা কি জওয়াব আনে।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmcxcv{অতঃপর যখন দূত সুলায়মানের কাছে আগমন করল, তখন সুলায়মান বললেন, তোমরা কি ধনসম্পদ দ্বারা আমাকে সাহায্য করতে চাও? আল্লাহ আমাকে যা দিয়েছেন, তা তোমাদেরকে প্রদত্ত বস্তু থেকে উত্তম। বরং তোমরাই তোমাদের উপঢৌকন নিয়ে সুখে থাক।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmcxcvi{ফিরে যাও তাদের কাছে। এখন অবশ্যই আমি তাদের বিরুদ্ধে এক সৈন্যবাহিনী নিয়ে আসব, যার মোকাবেলা করার শক্তি তাদের নেই। আমি অবশ্যই তাদেরকে অপদস্থ করে সেখান থেকে বহিষ্কৃত করব এবং তারা হবে লাঞ্ছিত।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmcxcvii{সুলায়মান বললেন, হে পরিষদবর্গ, তারা আত্নসমর্পণ করে আমার কাছে আসার পূর্বে কে বিলকীসের সিংহাসন আমাকে এনে দেবে?\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmcxcviii{জনৈক দৈত্য-জিন বলল, আপনি আপনার স্থান থেকে উঠার পূর্বে আমি তা এনে দেব এবং আমি একাজে শক্তিবান, বিশ্বস্ত।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmcxcix{কিতাবের জ্ঞান যার ছিল, সে বলল, আপনার দিকে আপনার চোখের পলক ফেলার পূর্বেই আমি তা আপনাকে এনে দেব। অতঃপর সুলায়মান যখন তা সামনে রক্ষিত দেখলেন, তখন বললেন এটা আমার পালনকর্তার অনুগ্রহ, যাতে তিনি আমাকে পরীক্ষা করেন যে, আমি কৃতজ্ঞতা প্রকাশ করি, না অকৃতজ্ঞতা প্রকাশ করি। যে কৃতজ্ঞতা প্রকাশ করে, সে নিজের উপকারের জন্যেই কৃতজ্ঞতা প্রকাশ করে এবং যে অকৃতজ্ঞতা প্রকাশ করে সে জানুক যে, আমার পালনকর্তা অভাবমুক্ত কৃপাশীল।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmcc{সুলায়মান বললেন, বিলকীসের সামনে তার সিংহাসনের আকার-আকৃতি বদলিয়ে দাও, দেখব সে সঠিক বুঝতে পারে, না সে তাদের অন্তর্ভুক্ত, যাদের দিশা নেই ?\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmcci{অতঃপর যখন বিলকীস এসে গেল, তখন তাকে জিজ্ঞাসা করা হল, তোমার সিংহাসন কি এরূপই? সে বলল, মনে হয় এটা সেটাই। আমরা পূর্বেই সমস্ত অবগত হয়েছি এবং আমরা আজ্ঞাবহও হয়ে গেছি।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmccii{আল্লাহর পরিবর্তে সে যার এবাদত করত, সেই তাকে ঈমান থেকে নিবৃত্ত করেছিল। নিশ্চয় সে কাফের সম্প্রদায়ের অন্তর্ভুক্ত ছিল।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmcciii{তাকে বলা হল, এই প্রাসাদে প্রবেশ কর। যখন সে তার প্রতি দৃষ্টিপাত করল সে ধারণা করল যে, এটা স্বচ্ছ গভীর জলাশয়। সে তার পায়ের গোছা খুলে ফেলল। সুলায়মান বলল, এটা তো স্বচ্ছ স্ফটিক নির্মিত প্রাসাদ। বিলকীস বলল, হে আমার পালনকর্তা, আমি তো নিজের প্রতি জুলুম করেছি। আমি সুলায়মানের সাথে বিশ্ব জাহানের পালনকর্তা আল্লাহর কাছে আত্নসমর্পন করলাম।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmcciv{আমি সামুদ সম্প্রদায়ের কাছে তাদের ভাই সালেহকে এই মর্মে প্রেরণ করেছি যে, তোমরা আল্লাহর এবাদত কর। অতঃপর তারা দ্বিধাবিভক্ত হয়ে বিতর্কে প্রবৃত্ত হল।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmmccv{সালেহ বললেন, হে আমার সম্প্রদায়, তোমরা কল্যাণের পূর্বে দ্রুত অকল্যাণ কামনা করছ কেন? তোমরা আল্লাহর কাছে ক্ষমা প্রার্থনা করছ না কেন? সম্ভবতঃ তোমরা দয়াপ্রাপ্ত হবে।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmmccvi{তারা বলল, তোমাকে এবং তোমার সাথে যারা আছে, তাদেরকে আমরা অকল্যাণের প্রতীক মনে করি। সালেহ বললেন, তোমাদের মঙ্গলামঙ্গল আল্লাহর কাছে; বরং তোমরা এমন সম্প্রদায়, যাদেরকে পরীক্ষা করা হচ্ছে।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmmccvii{আর সেই শহরে ছিল এমন একজন ব্যক্তি, যারা দেশময় অনর্থ সৃষ্টি করে বেড়াত এবং সংশোধন করত না।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmmccviii{তারা বলল, তোমরা পরস্পরে আল্লাহর নামে শপথ গ্রহণ কর যে, আমরা রাত্রিকালে তাকে ও তার পরিবারবর্গকে হত্যা করব। অতঃপর তার দাবীদারকে বলে দেব যে, তার পরিবারবর্গের হত্যাকান্ড আমরা প্রত্যক্ষ করিনি। আমরা নিশ্চয়ই সত্যবাদী।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmmccix{তারা এক চক্রান্ত করেছিল এবং আমিও এক চক্রান্ত করেছিলাম। কিন্তু তারা বুঝতে পারেনি।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmmccx{অতএব, দেখ তাদের চক্রান্তের পরিনাম, আমি অবশ্রই তাদেরকে এবং তাদের সম্প্রদায়কে নাস্তনাবুদ করে দিয়েছি।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmmccxi{এই তো তাদের বাড়ীঘর-তাদের অবিশ্বাসের কারণে জনশূন্য অবস্থায় পড়ে আছে। নিশ্চয় এতে জ্ঞানী সম্প্রদায়ের জন্যে নিদর্শন আছে।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmmccxii{যারা বিশ্বাস স্থাপন করেছিল এবং পরহেযগার ছিল, তাদেরকে আমি উদ্ধার করেছি।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmmccxiii{স্মরণ কর লূতের কথা, তিনি তাঁর কওমকে বলেছিলেন, তোমরা কেন অশ্লীল কাজ করছ? অথচ এর পরিণতির কথা তোমরা অবগত আছ!\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmmccxiv{তোমরা কি কামতৃপ্তির জন্য নারীদেরকে ছেড়ে পুরুষে উপগত হবে? তোমরা তো এক বর্বর সম্প্রদায়।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mmmccxv{উত্তরে তাঁর কওম শুধু এ কথাটিই বললো, লূত পরিবারকে তোমাদের জনপদ থেকে বের করে দাও। এরা তো এমন লোক যারা শুধু পাকপবিত্র সাজতে চায়।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mmmccxvi{অতঃপর তাঁকে ও তাঁর পরিবারবর্গকে উদ্ধার করলাম তাঁর স্ত্রী ছাড়া। কেননা, তার জন্যে ধ্বংসপ্রাপ্তদের ভাগ্যই নির্ধারিত করেছিলাম।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mmmccxvii{আর তাদের উপর বর্ষণ করেছিলাম মুষলধারে বৃষ্টি। সেই সতর্ককৃতদের উপর কতই না মারাত্নক ছিল সে বৃষ্টি।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mmmccxviii{বল, সকল প্রশংসাই আল্লাহর এবং শান্তি তাঁর মনোনীত বান্দাগণের প্রতি! শ্রেষ্ঠ কে? আল্লাহ না ওরা-তারা যাদেরকে শরীক সাব্যস্ত করে।\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mmmccxix{বল তো কে সৃষ্টি করেছেন নভোমন্ডল ও ভূমন্ডল এবং আকাশ থেকে তোমাদের জন্যে বর্ষণ করেছেন পানি; অতঃপর তা দ্বারা আমি মনোরম বাগান সৃষ্টি করেছি। তার বৃক্ষাদি উৎপন্ন করার শক্তিই তোমাদের নেই। অতএব, আল্লাহর সাথে অন্য কোন উপাস্য আছে কি? বরং তারা সত্যবিচ্যুত সম্প্রদায়।\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mmmccxx{বল তো কে পৃথিবীকে বাসোপযোগী করেছেন এবং তার মাঝে মাঝে নদ-নদী প্রবাহিত করেছেন এবং তাকে স্থিত রাখার জন্যে পর্বত স্থাপন করেছেন এবং দুই সমুদ্রের মাঝখানে অন্তরায় রেখেছেন। অতএব, আল্লাহর সাথে অন্য কোন উপাস্য আছে কি? বরং তাদের অধিকাংশই জানে না।\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mmmccxxi{বল তো কে নিঃসহায়ের ডাকে সাড়া দেন যখন সে ডাকে এবং কষ্ট দূরীভূত করেন এবং তোমাদেরকে পৃথিবীতে পুর্ববর্তীদের স্থলাভিষিক্ত করেন। সুতরাং আল্লাহর সাথে অন্য কোন উপাস্য আছে কি? তোমরা অতি সামান্যই ধ্যান কর।\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mmmccxxii{বল তো কে তোমাদেরকে জলে ও স্থলে অন্ধকারে পথ দেখান এবং যিনি তাঁর অনুগ্রহের পূর্বে সুসংবাদবাহী বাতাস প্রেরণ করেন? অতএব, আল্লাহর সাথে অন্য কোন উপাস্য আছে কি? তারা যাকে শরীক করে, আল্লাহ তা থেকে অনেক ঊর্ধ্বে।\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mmmccxxiii{বল তো কে প্রথমবার সৃষ্টি করেন, অতঃপর তাকে পুনরায় সৃষ্টি করবেন এবং কে তোমাদেরকে আকাশ ও মর্ত?2469;েকে রিযিক দান করেন। সুতরাং আল্লাহর সাথে অন্য কোন উপাস্য আছে কি? বলুন, তোমরা যদি সত্যবাদী হও তবে তোমাদের প্রমাণ উপস্থিত কর।\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mmmccxxiv{বলুন, আল্লাহ ব্যতীত নভোমন্ডল ও ভূমন্ডলে কেউ গায়বের খবর জানে না এবং তারা জানে না যে, তারা কখন পুনরুজ্জীবিত হবে।\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mmmccxxv{বরং পরকাল সম্পর্কে তাদের জ্ঞান নিঃশেষ হয়ে গেছে; বরং তারা এ বিষয়ে সন্দেহ পোষন করছে বরং এ বিষয়ে তারা অন্ধ।\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mmmccxxvi{কাফেররা বলে, যখন আমরা ও আমাদের বাপ-দাদারা মৃত্তিকা হয়ে যাব, তখনও কি আমাদেরকে পুনরুত্থিত করা হবে?\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mmmccxxvii{এই ওয়াদাপ্রাপ্ত হয়েছি আমরা এবং পূর্ব থেকেই আমাদের বাপ-দাদারা। এটা তো পূর্ববর্তীদের উপকথা বৈ কিছু নয়।\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mmmccxxviii{বলুন, পৃথিবী পরিভ্রমণ কর এবং দেখ অপরাধীদের পরিণতি কি হয়েছে।\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mmmccxxix{তাদের কারণে আপনি দুঃখিত হবেন না এবং তারা যে চক্রান্ত করেছে এতে মনঃক্ষুন্ন হবেন না।\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@mmmccxxx{তারা বলে, তোমরা যদি সত্যবাদী হও তবে বল, এই ওয়াদা কখন পূর্ণ হবে?\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@mmmccxxxi{বলুন, অসম্ভব কি, তোমরা যত দ্রুত কামনা করছ তাদের কিয়দংশ তোমাদের পিঠের উপর এসে গেছে।\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@mmmccxxxii{আপনার পালনকর্তা মানুষের প্রতি অনুগ্রহশীল, কিন্তু তাদের অধিকাংশই কৃতজ্ঞতা প্রকাশ করে না।\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@mmmccxxxiii{তাদের অন্তর যা গোপন করে এবং যা প্রকাশ করে আপনার পালনকর্তা অবশ্যই তা জানেন।\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@mmmccxxxiv{আকাশে ও পৃথিবীতে এমন কোন গোপন ভেদ নেই, যা সুস্পষ্ট কিতাবে না আছে।\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@mmmccxxxv{এই কোরআন বণী ইসরাঈল যেসব বিষয়ে মতবিরোধ করে, তার অধিকাংশ তাদের কাছে বর্ণনা করে।\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@mmmccxxxvi{এবং নিশ্চিতই এটা মুমিনদের জন্যে হেদায়েত ও রহমত।\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@mmmccxxxvii{আপনার পালনকর্তা নিজ শাসনক্ষমতা অনুযায়ী তাদের মধ্যে ফয়সালা করে দেবেন। তিনি পরাক্রমশালী, সুবিজ্ঞ।\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@mmmccxxxviii{অতএব, আপনি আল্লাহর উপর ভরসা করুন। নিশ্চয় আপনি সত্য ও স্পষ্ট পথে আছেন।\qt@no{(79)}}
\qt@newcmd\qurantrans@bn@mmmccxxxix{আপনি আহবান শোনাতে পারবেন না মৃতদেরকে এবং বধিরকেও নয়, যখন তারা পৃষ্ঠ প্রদর্শন করে চলে যায়।\qt@no{(80)}}
\qt@newcmd\qurantrans@bn@mmmccxl{আপনি অন্ধদেরকে তাদের পথভ্রষ্টতা থেকে ফিরিয়ে সৎপথে আনতে পারবেন না। আপনি কেবল তাদেরকে শোনাতে পারবেন, যারা আমার আয়াতসমূহে বিশ্বাস করে। অতএব, তারাই আজ্ঞাবহ।\qt@no{(81)}}
\qt@newcmd\qurantrans@bn@mmmccxli{যখন প্রতিশ্রুতি (কেয়ামত) সমাগত হবে, তখন আমি তাদের সামনে ভূগর্ভ থেকে একটি জীব নির্গত করব। সে মানুষের সাথে কথা বলবে। এ কারণে যে মানুষ আমার নিদর্শনসমূহে বিশ্বাস করত না।\qt@no{(82)}}
\qt@newcmd\qurantrans@bn@mmmccxlii{যেদিন আমি একত্রিত করব একেকটি দলকে সেসব সম্প্রদায় থেকে, যারা আমার আয়াতসমূহকে মিথ্যা বলত; অতঃপর তাদেরকে বিভিন্ন দলে বিভক্ত করা হবে।\qt@no{(83)}}
\qt@newcmd\qurantrans@bn@mmmccxliii{যখন তারা উপস্থিত হয়ে যাবে, তখন আল্লাহ বলবেন, তোমরা কি আমার আয়াতসমূহকে মিথ্যা বলেছিলে? অথচ এগুলো সম্পর্কে তোমাদের পুর্ণ জ্ঞান ছিল না। না তোমরা অন্য কিছু করছিলে?\qt@no{(84)}}
\qt@newcmd\qurantrans@bn@mmmccxliv{জুলুমের কারণে তাদের কাছে আযাবের ওয়াদা এসে গেছে। এখন তারা কোন কিছু বলতে পারবে না।\qt@no{(85)}}
\qt@newcmd\qurantrans@bn@mmmccxlv{তারা কি দেখে না যে, আমি রাত্রি সৃষ্টি করেছি তাদের বিশ্রামের জন্যে এবং দিনকে করেছি আলোকময়। নিশ্চয় এতে ঈমানদার সম্প্রদায়ের জন্যে নিদর্শনাবলী রয়েছে।\qt@no{(86)}}
\qt@newcmd\qurantrans@bn@mmmccxlvi{যেদিন সিঙ্গায় ফুৎকার দেওয়া হবে, অতঃপর আল্লাহ যাদেরকে ইচ্ছা করবেন, তারা ব্যতীত নভোমন্ডলে ও ভূমন্ডলে যারা আছে, তারা সবাই ভীতবিহ্বল হয়ে পড়বে এবং সকলেই তাঁর কাছে আসবে বিনীত অবস্থায়।\qt@no{(87)}}
\qt@newcmd\qurantrans@bn@mmmccxlvii{তুমি পর্বতমালাকে দেখে অচল মনে কর, অথচ সেদিন এগুলো মেঘমালার মত চলমান হবে। এটা আল্লাহর কারিগরী, যিনি সবকিছুকে করেছেন সুসংহত। তোমরা যা কিছু করছ, তিনি তা অবগত আছেন।\qt@no{(88)}}
\qt@newcmd\qurantrans@bn@mmmccxlviii{যে কেউ সৎকর্ম নিয়ে আসবে, সে উৎকৃষ্টতর প্রতিদান পাবে এবং সেদিন তারা গুরুতর অস্থিরতা থেকে নিরাপদ থাকবে।\qt@no{(89)}}
\qt@newcmd\qurantrans@bn@mmmccxlix{এবং যে মন্দ কাজ নিয়ে আসবে, তাকে অগ্নিতে অধঃমূখে নিক্ষেপ করা হবে। তোমরা যা করছিলে, তারই প্রতিফল তোমরা পাবে।\qt@no{(90)}}
\qt@newcmd\qurantrans@bn@mmmccl{আমি তো কেবল এই নগরীর প্রভুর এবাদত করতে আদিষ্ট হয়েছি, যিনি একে সম্মানিত করেছেন। এবং সব কিছু তাঁরই। আমি আরও আদিষ্ট হয়েছি যেন আমি আজ্ঞাবহদের একজন হই।\qt@no{(91)}}
\qt@newcmd\qurantrans@bn@mmmccli{এবং যেন আমি কোরআন পাঠ করে শোনাই। পর যে ব্যক্তি সৎপথে চলে, সে নিজের কল্যাণার্থেই সৎপথে চলে এবং কেউ পথভ্রষ্ট হলে আপনি বলে দিন, আমি তো কেবল একজন ভীতি প্রদর্শনকারী।\qt@no{(92)}}
\qt@newcmd\qurantrans@bn@mmmcclii{এবং আরও বলুন, সমস্ত প্রশংসা আল্লাহর। সত্বরই তিনি তাঁর নিদর্শনসমূহ তোমাদেরকে দেখাবেন। তখন তোমরা তা চিনতে পারবে। এবং তোমরা যা কর, সে সম্পর্কে আপনার পালনকর্তা গাফেল নন।\qt@no{(93)}}
\qt@newcmd\qurantrans@bn@mmmccliii{\basmalahbn ত্বা-সীন-মীম।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmccliv{এগুলো সুস্পষ্ট কিতাবের আয়াত।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmcclv{আমি আপনার কাছে মূসা ও ফেরাউনের বৃত্তান্ত সত্য সহকারে বর্ণনা করছি ঈমানদার সম্প্রদায়ের জন্যে।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmcclvi{ফেরাউন তার দেশে উদ্ধত হয়েছিল এবং সে দেশবাসীকে বিভিন্ন দলে বিভক্ত করে তাদের একটি দলকে দূর্বল করে দিয়েছিল। সে তাদের পুত্র-সন্তানদেরকে হত্যা করত এবং নারীদেরকে জীবিত রাখত। নিশ্চয় সে ছিল অনর্থ সৃষ্টিকারী।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmcclvii{দেশে যাদেরকে দূর্বল করা হয়েছিল, আমার ইচ্ছা হল তাদের প্রতি অনুগ্রহ করার, তাদেরকে নেতা করার এবং তাদেরকে দেশের উত্তরাধিকারী করার।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmcclviii{এবং তাদেরকে দেশের ক্ষমতায় আসীন করার এবং ফেরাউন, হামান ও তাদের সৈন্য-বাহিনীকে তা দেখিয়ে দেয়ার, যা তারা সেই দূর্বল দলের তরফ থেকে আশংকা করত।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmcclix{আমি মূসা-জননীকে আদেশ পাঠালাম যে, তাকে স্তন্য দান করতে থাক। অতঃপর যখন তুমি তার সম্পর্কে বিপদের আশংকা কর, তখন তাকে দরিয়ায় নিক্ষেপ কর এবং ভয় করো না, দুঃখও করো না। আমি অবশ্যই তাকে তোমার কাছে ফিরিয়ে দেব এবং তাকে পয়গম্বরগণের একজন করব।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmcclx{অতঃপর ফেরাউন পরিবার মূসাকে কুড়িয়ে নিল, যাতে তিনি তাদের শত্রু ও দুঃখের কারণ হয়ে যান। নিশ্চয় ফেরাউন, হামান, ও তাদের সৈন্যবাহিনী অপরাধী ছিল।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmcclxi{ফেরাউনের স্ত্রী বলল, এ শিশু আমার ও তোমার নয়নমণি, তাকে হত্যা করো না। এ আমাদের উপকারে আসতে পারে অথবা আমরা তাকে পুত্র করে নিতে পারি। প্রকৃতপক্ষে পরিণাম সম্পর্কে তাদের কোন খবর ছিল না।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmcclxii{সকালে মূসা জননীর অন্তর অস্থির হয়ে পড়ল। যদি আমি তাঁর হৃদয়কে দৃঢ় করে না দিতাম, তবে তিনি মূসাজনিত অস্থিরতা প্রকাশ করেই দিতেন। দৃঢ় করলাম, যাতে তিনি থাকেন বিশ্ববাসীগণের মধ্যে।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmcclxiii{তিনি মূসার ভগিণীকে বললেন, তার পেছন পেছন যাও। সে তাদের অজ্ঞাতসারে অপরিচিতা হয়ে তাকে দেখে যেতে লাগল।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmcclxiv{পূর্ব থেকেই আমি ধাত্রীদেরকে মূসা থেকে বিরত রেখেছিলাম। মূসার ভগিনী বলল, আমি তোমাদেরকে এমন এক পরিবারের কথা বলব কি, যারা তোমাদের জন্যে একে লালন-পালন করবে এবং তারা হবে তার হিতাকাঙ্ক্ষী?\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmcclxv{অতঃপর আমি তাকে জননীর কাছে ফিরিয়ে দিলাম, যাতে তার চক্ষু জুড়ায় এবং তিনি দুঃখ না করেন এবং যাতে তিনি জানেন যে, আল্লাহর ওয়াদা সত্য, কিন্তু অনেক মানুষ তা জানে না।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmcclxvi{যখন মূসা যৌবনে পদার্পন করলেন এবং পরিণত বয়স্ক হয়ে গেলেন, তখন আমি তাঁকে প্রজ্ঞা ও জ্ঞানদান করলাম। এমনিভাবে আমি সৎকর্মীদেরকে প্রতিদান দিয়ে থাকি।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmcclxvii{তিনি শহরে প্রবেশ করলেন, যখন তার অধিবাসীরা ছিল বেখবর। তথায় তিনি দুই ব্যক্তিকে লড়াইরত দেখলেন। এদের একজন ছিল তাঁর নিজ দলের এবং অন্য জন তাঁর শত্রু দলের। অতঃপর যে তাঁর নিজ দলের সে তাঁর শত্রু দলের লোকটির বিরুদ্ধে তাঁর কাছে সাহায্য প্রার্থনা করল। তখন মূসা তাকে ঘুষি মারলেন এবং এতেই তার মৃত্যু হয়ে গেল। মূসা বললেন, এটা শয়তানের কাজ। নিশ্চয় সে প্রকাশ্য শত্রু, বিভ্রান্তকারী।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmcclxviii{তিনি বললেন, হে আমার পালনকর্তা, আমি তো নিজের উপর জুলুম করে ফেলেছি। অতএব, আমাকে ক্ষমা করুন। আল্লাহ তাকে ক্ষমা করলেন। নিশ্চয় তিনি ক্ষমাশীল, দয়ালু।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmcclxix{তিনি বললেন, হে আমার পালনকর্তা, আপনি আমার প্রতি যে অনুগ্রহ করেছেন, এরপর আমি কখনও অপরাধীদের সাহায্যকারী হব না।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmcclxx{অতঃপর তিনি প্রভাতে উঠলেন সে শহরে ভীত-শংকিত অবস্থায়। হঠাৎ তিনি দেখলেন, গতকল্য যে ব্যক্তি তাঁর সাহায্য চেয়েছিল, সে চিৎকার করে তাঁর সাহায্য প্রার্থনা করছে। মূসা তাকে বললেন, তুমি তো একজন প্রকাশ্য পথভ্রষ্ট ব্যক্তি।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmcclxxi{অতঃপর মূসা যখন উভয়ের শত্রুকে শায়েস্তা করতে চাইলেন, তখন সে বলল, গতকল্য তুমি যেমন এক ব্যক্তিকে হত্যা করেছিলে, সে রকম আমাকেও কি হত্যা করতে চাও? তুমি তো পৃথিবীতে স্বৈরাচারী হতে চাচ্ছ এবং সন্ধি স্থাপনকারী হতে চাও না।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmcclxxii{এসময় শহরের প্রান্ত থেকে একব্যক্তি ছুটে আসল এবং বলল, হে মূসা, রাজ্যের পরিষদবর্গ তোমাকে হত্যা করার পরমর্শ করছে। অতএব, তুমি বের হয়ে যাও। আমি তোমার হিতাকাঙ্ক্ষী।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmcclxxiii{অতঃপর তিনি সেখান থেকে ভীত অবস্থায় বের হয়ে পড়লেন পথ দেখতে দেখতে। তিনি বললেন, হে আমার পালনকর্তা, আমাকে জালেম সম্প্রদায়ের কবল থেকে রক্ষা কর।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmcclxxiv{যখন তিনি মাদইয়ান অভিমুখে রওয়ানা হলেন তখন বললেন, আশা করা যায় আমার পালনকর্তা আমাকে সরল পথ দেখাবেন।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmcclxxv{যখন তিনি মাদইয়ানের কূপের ধারে পৌছলেন, তখন কূপের কাছে একদল লোককে পেলেন তারা জন্তুদেরকে পানি পান করানোর কাজে রত। এবং তাদের পশ্চাতে দূ’জন স্ত্রীলোককে দেখলেন তারা তাদের জন্তুদেরকে আগলিয়ে রাখছে। তিনি বললেন, তোমাদের কি ব্যাপার? তারা বলল, আমরা আমাদের জন্তুদেরকে পানি পান করাতে পারি না, যে পর্যন্ত রাখালরা তাদের জন্তুদেরকে নিয়ে সরে না যায়। আমাদের পিতা খুবই বৃদ্ধ।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmcclxxvi{অতঃপর মূসা তাদের জন্তুদেরকে পানি পান করালেন। অতঃপর তিনি ছায়ার দিকে সরে গেলেন এবং বললেন, হে আমার পালনকর্তা, তুমি আমার প্রতি যে অনুগ্রহ নাযিল করবে, আমি তার মুখাপেক্ষী।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmcclxxvii{অতঃপর বালিকাদ্বয়ের একজন লজ্জাজড়িত পদক্ষেপে তাঁর কাছে আগমন করল। বলল, আমার পিতা আপনাকে ডাকছেন, যাতে আপনি যে আমাদেরকে পানি পান করিয়েছেন, তার বিনিময়ে পুরস্কার প্রদান করেন। অতঃপর মূসা যখন তাঁর কাছে গেলেন এবং সমস্ত বৃত্তান্ত বর্ণনা করলেন, তখন তিনি বললেন, ভয় করো না, তুমি জালেম সম্প্রদায়ের কবল থেকে রক্ষা পেয়েছ।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmcclxxviii{বালিকাদ্বয়ের একজন বলল পিতাঃ তাকে চাকর নিযুক্ত করুন। কেননা, আপনার চাকর হিসেবে সে-ই উত্তম হবে, যে শক্তিশালী ও বিশ্বস্ত।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmcclxxix{পিতা মূসাকে বললেন, আমি আমার এই কন্যাদ্বয়ের একজনকে তোমার সাথে বিবাহে দিতে চাই এই শর্তে যে, তুমি আট বছর আমার চাকুরী করবে, যদি তুমি দশ বছর পূর্ণ কর, তা তোমার ইচ্ছা। আমি তোমাকে কষ্ট দিতে চাই না। আল্লাহ চাহেন তো তুমি আমাকে সৎকর্মপরায়ণ পাবে।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmcclxxx{মূসা বললেন, আমার ও আপনার মধ্যে এই চুক্তি স্থির হল। দু’টি মেয়াদের মধ্য থেকে যে কোন একটি পূর্ণ করলে আমার বিরুদ্ধে কোন অভিযোগ থাকবে না। আমরা যা বলছি, তাতে আল্লাহর উপর ভরসা।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmcclxxxi{অতঃপর মূসা (আঃ) যখন সেই মেয়াদ পূর্ণ করল এবং সপরিবারে যাত্রা করল, তখন সে তুর পর্বতের দিক থেকে আগুন দেখতে পেল। সে তার পরিবারবর্গকে বলল, তোমরা অপেক্ষা কর, আমি আগুন দেখেছি। সম্ভবতঃ আমি সেখান থেকে তোমাদের কাছে কোন খবর নিয়ে আসতে পারি অথবা কোন জ্বলন্ত কাষ্ঠখন্ড আনতে পারি, যাতে তোমরা আগুন পোহাতে পার।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmcclxxxii{যখন সে তার কাছে পৌছল, তখন পবিত্র ভূমিতে অবস্থিত উপত্যকার ডান প্রান্তের বৃক্ষ থেকে তাকে আওয়াজ দেয়া হল, হে মূসা! আমি আল্লাহ, বিশ্ব পালনকর্তা।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmcclxxxiii{আরও বলা হল, তুমি তোমার লাঠি নিক্ষেপ কর। অতঃপর যখন সে লাঠিকে সর্পের ন্যায় দৌড়াদৌড়ি করতে দেখল, তখন সে মুখ ফিরিয়ে বিপরীত দিকে পালাতে লাগল এবং পেছন ফিরে দেখল না। হে মূসা, সামনে এস এবং ভয় করো না। তোমার কোন আশংকা নেই।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmcclxxxiv{তোমার হাত বগলে রাখ। তা বের হয়ে আসবে নিরাময় উজ্জ্বল হয়ে এবং ভয় হেতু তোমার হাত তোমার উপর চেপে ধর। এই দু’টি ফেরাউন ও তার পরিষদবর্গের প্রতি তোমার পালনকর্তার তরফ থেকে প্রমাণ। নিশ্চয় তারা পাপাচারী সম্প্রদায়।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmcclxxxv{মূসা বলল, হে আমার পালনকর্তা, আমি তাদের এক ব্যক্তিকে হত্যা করেছি। কাজেই আমি ভয় করছি যে, তারা আমাকে হত্যা করবে।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmcclxxxvi{আমার ভাই হারুণ, সে আমা অপেক্ষা প্রাঞ্জলভাষী। অতএব, তাকে আমার সাথে সাহায্যের জন্যে প্রেরণ করুন। সে আমাকে সমর্থন জানাবে। আমি আশংকা করি যে, তারা আমাকে মিথ্যাবাদী বলবে।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmcclxxxvii{আল্লাহ বললেন, আমি তোমার বাহু শক্তিশালী করব তোমার ভাই দ্বারা এবং তোমাদের প্রধান্য দান করব। ফলে, তারা তোমার কাছে পৌছাতে পারবে না। আমার নিদর্শনাবলীর জোরে তোমরা এবং তোমাদের অনুসারীরা প্রবল থাকবে।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmcclxxxviii{অতঃপর মূসা যখন তাদের কাছে আমার সুস্পষ্ট নিদর্শনাবলী নিয়ে পৌছল, তখন তারা বলল, এতো অলীক জাদু মাত্র। আমরা আমাদের পূর্বপুরুষদের মধ্যে এ কথা শুনিনি।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmcclxxxix{মূসা বলল, আমার পালনকর্তা সম্যক জানেন যে তার নিকট থেকে হেদায়েতের কথা নিয়ে আগমন করেছে এবং যে প্রাপ্ত হবে পরকালের গৃহ। নিশ্চয় জালেমরা সফলকাম হবে না।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmccxc{ফেরাউন বলল, হে পরিষদবর্গ, আমি জানি না যে, আমি ব্যতীত তোমাদের কোন উপাস্য আছে। হে হামান, তুমি ইট পোড়াও, অতঃপর আমার জন্যে একটি প্রাসাদ নির্মাণ কর, যাতে আমি মূসার উপাস্যকে উকি মেরে দেখতে পারি। আমার তো ধারণা এই যে, সে একজন মিথ্যাবাদী।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmccxci{ফেরাউন ও তার বাহিনী অন্যায়ভাবে পৃথিবীতে অহংকার করতে লাগল এবং তারা মনে করল যে, তারা আমার কাছে প্রত্যাবর্তিত হবে না।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmccxcii{অতঃপর আমি তাকে ও তার বাহিনীকে পাকড়াও করলাম, তৎপর আমি তাদেরকে সমুদ্রে নিক্ষেপ করলাম। অতএব, দেখ জালেমদের পরিণাম কি হয়েছে।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmccxciii{আমি তাদেরকে নেতা করেছিলাম। তারা জাহান্নামের দিকে আহবান করত। কেয়ামতের দিন তারা সাহায্য প্রাপ্ত হবে না।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmccxciv{আমি এই পৃথিবীতে অভিশাপকে তাদের পশ্চাতে লাগিয়ে দিয়েছি এবং কেয়ামতের দিন তারা হবে দুর্দশাগ্রস্ত।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmccxcv{আমি পূর্ববর্তী অনেক সম্প্রদায়কে ধ্বংস করার পর মূসাকে কিতাব দিয়েছি মানুষের জন্যে জ্ঞানবর্তিকা। হেদায়েত ও রহমত, যাতে তারা স্মরণ রাখে।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmccxcvi{মূসাকে যখন আমি নির্দেশনামা দিয়েছিলাম, তখন আপনি পশ্চিম প্রান্তে ছিলেন না এবং আপনি প্রত্যক্ষদর্শীও ছিলেন না।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmccxcvii{কিন্তু আমি অনেক সম্প্রদায় সৃষ্টি করেছিলাম, অতঃপর তাদের অনেক যুগ অতিবাহিত হয়েছে। আর আপনি মাদইয়ানবাসীদের মধ্যে ছিলেন না যে, তাদের কাছে আমার আয়াতসমূহ পাঠ করতেন। কিন্তু আমিই ছিলাম রসূল প্রেরণকারী।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmmccxcviii{আমি যখন মূসাকে আওয়াজ দিয়েছিলাম, তখন আপনি তুর পর্বতের পার্শ্বে ছিলেন না। কিন্তু এটা আপনার পালনকর্তার রহমত স্বরূপ, যাতে আপনি এমন এক সম্প্রদায়কে ভীতি প্রদর্শন করেন, যাদের কাছে আপনার পূꦣ2503;ব কোন ভীতি প্রদর্শনকারী আগমন করেনি, যাতে তারা স্মরণ রাখে।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmmccxcix{আর এ জন্য যে, তাদের কৃতকর্মের জন্যে তাদের কোন বিপদ হলে তারা বলত, হে আমাদের পালনকর্তা, তুমি আমাদের কাছে কোন রসূল প্রেরণ করলে না কেন? করলে আমরা তোমার আয়াতসমূহের অনুসরণ করতাম এবং আমরা বিশ্বাস স্থাপনকারী হয়ে যেতাম।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmmccc{অতঃপর আমার কাছ থেকে যখন তাদের কাছে সত্য আগমন করল, তখন তারা বলল, মূসাকে যেরূপ দেয়া হয়েছিল, এই রসূলকে সেরূপ দেয়া হল না কেন? পূর্বে মূসাকে যা দেয়া হয়েছিল, তারা কি তা অস্বীকার করেনি? তারা বলেছিল, উভয়ই জাদু, পরস্পরে একাত্ম। তারা আরও বলেছিল, আমরা উভয়কে মানি না।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmmccci{বলুন, তোমরা সত্যবাদী হলে এখন আল্লাহর কাছ থেকে কোন কিতাব আন, যা এতদুভয় থেকে উত্তম পথপ্রদর্শক হয়। আমি সেই কিতাব অনুসরণ করব।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmmcccii{অতঃপর তারা যদি আপনার কথায় সাড়া না দেয়, তবে জানবেন, তারা শুধু নিজের প্রবৃত্তির অনুসরণ করে। আল্লাহর হেদায়েতের পরিবর্তে যে ব্যক্তি নিজ প্রবৃত্তির অনুসরণ করে, তার চাইতে অধিক পথভ্রষ্ট আর কে? নিশ্চয় আল্লাহ জালেম সম্প্রদায়কে পথ দেখান না।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmmccciii{আমি তাদের কাছে উপর্যুপরি বাণী পৌছিয়েছি। যাতে তারা অনুধাবন করে।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmmccciv{কোরআনের পূর্বে আমি যাদেরকে কিতাব দিয়েছি, তারা এতে বিশ্বাস করে।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmmcccv{যখন তাদের কাছে এটা পাঠ করা হয়, তখন তারা বলে, আমরা এর প্রতি বিশ্বাস স্থাপন করলাম। এটা আমাদের পালনকর্তার পক্ষ থেকে সত্য। আমরা এর পূর্বেও আজ্ঞাবহ ছিলাম।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmmcccvi{তারা দুইবার পুরস্কৃত হবে তাদের সবরের কারণে। তারা মন্দের জওয়াবে ভাল করে এবং আমি তাদেরকে যা দিয়েছি, তা থেকে ব্যয় করে।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmmcccvii{তারা যখন অবাঞ্চিত বাজে কথাবার্তা শ্রবণ করে, তখন তা থেকে মুখ ফিরিয়ে নেয় এবং বলে, আমাদের জন্যে আমাদের কাজ এবং তোমাদের জন্যে তোমাদের কাজ। তোমাদের প্রতি সালাম। আমরা অজ্ঞদের সাথে জড়িত হতে চাই না।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mmmcccviii{আপনি যাকে পছন্দ করেন, তাকে সৎপথে আনতে পারবেন না, তবে আল্লাহ তা’আলাই যাকে ইচ্ছা সৎপথে আনয়ন করেন। কে সৎপথে আসবে, সে সম্পর্কে তিনিই ভাল জানেন।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mmmcccix{তারা বলে, যদি আমরা আপনার সাথে সুপথে আসি, তবে আমরা আমাদের দেশ থেকে উৎখাত হব। আমি কি তাদের জন্যে একটি নিরাপদ হরম প্রতিষ্ঠিত করিনি? এখানে সর্বপ্রকার ফল-মূল আমদানী হয় আমার দেয়া রিযিকস্বরূপ। কিন্তু তাদের অধিকাংশই জানে না।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mmmcccx{আমি অনেক জনপদ ধবংস করেছি, যার অধিবাসীরা তাদের জীবন যাপনে মদমত্ত ছিল। এগুলোই এখন তাদের ঘর-বাড়ী। তাদের পর এগুলোতে মানুষ সামান্যই বসবাস করেছে। অবশেষে আমিই মালিক রয়েছি।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mmmcccxi{আপনার পালনকর্তা জনপদসমূহকে ধ্বংস করেন না, যে পর্যন্ত তার কেন্দ্রস্থলে রসূল প্রেরণ না করেন, যিনি তাদের কাছে আমার আয়াতসমূহ পাঠ করেন এবং আমি জনপদসমূহকে তখনই ধ্বংস করি, যখন তার বাসিন্দারা জুলুম করে।\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mmmcccxii{তোমাদেরকে যা কিছু দেয়া হয়েছে, তা পার্থিব জীবনের ভোগ ও শোভা বৈ নয়। আর আল্লাহর কাছে যা আছে, তা উত্তম ও স্থায়ী। তোমরা কি বোঝ না ?\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mmmcccxiii{যাকে আমি উত্তম প্রতিশ্রুতি দিয়েছি, যা সে পাবে, সে কি ঐ ব্যক্তির সমান, যাকে আমি পার্থিব জীবনের ভোগ-সম্ভার দিয়েছি, অতঃপর তাকে কেয়ামতের দিন অপরাধীরূপে হাযির করা হবে?\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mmmcccxiv{যেদিন আল্লাহ তাদেরকে আওয়াজ দিয়ে বলবেন, তোমরা যাদেরকে আমার শরীক দাবী করতে, তারা কোথায়?\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mmmcccxv{যাদের জন্যে শাস্তির আদেশ অবধারিত হয়েছে, তারা বলবে, হে আমাদের পালনকর্তা। এদেরকেই আমরা পথভ্রষ্ট করেছিলাম। আমরা তাদেরকে পথভ্রষ্ট করেছিলাম, যেমন আমরা পথভ্রষ্ট হয়েছিলাম। আমরা আপনার সামনে দায়মুক্ত হচ্ছি। তারা কেবল আমাদেরই এবাদত করত না।\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mmmcccxvi{বলা হবে, তোমরা তোমাদের শরীকদের আহবান কর। তখন তারা ডাকবে,। অতঃপর তারা তাদের ডাকে সাড়া দিবে না এবং তারা আযাব দেখবে। হায়! তারা যদি সৎপথ প্রাপ্ত হত।\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mmmcccxvii{যে দিন আল্লাহ তাদেরকে ডেকে বলবেন, তোমরা রসূলগণকে কি জওয়াব দিয়েছিলে?\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mmmcccxviii{অতঃপর তাদের কথাবার্তা বন্ধ হয়ে যাবে এবং তারা একে অপরকে জিজ্ঞাসাবাদ করতে পারবে না।\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mmmcccxix{তবে যে তওবা করে, বিশ্বাস স্থাপন করে ও সৎকর্ম করে, আশা করা যায়, সে সফলকাম হবে।\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mmmcccxx{আপনার পালনকর্তা যা ইচ্ছা সৃষ্টি করেন এবং পছন্দ করেন। তাদের কোন ক্ষমতা নেই। আল্লাহ পবিত্র এবং তারা যাকে শরীক করে, তা থেকে উর্ধ্বে।\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mmmcccxxi{তাদের অন্তর যা গোপন করে এবং যা প্রকাশ করে, আপনার পালনকর্তা তা জানেন।\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mmmcccxxii{তিনিই আল্লাহ তিনি ব্যতীত কোন উপাস্য নেই। ইহকাল ও পরকালে তাঁরই প্রশংসা। বিধান তাঁরই ক্ষমতাধীন এবং তোমরা তাঁরই কাছে প্রত্যাবর্তিত হবে।\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@mmmcccxxiii{বলুন, ভেবে দেখ তো, আল্লাহ যদি রাত্রিকে কেয়ামতের দিন পর্যন্ত স্থায়ী করেন, তবে আল্লাহ ব্যতীত এমন উপাস্য কে আছে, যে তোমাদেরকে আলোক দান করতে পারে? তোমরা কি তবুও কর্ণꦣ2474;াত করবে না?\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@mmmcccxxiv{বলুন, ভেবে দেখ তো, আল্লাহ যদি দিনকে কেয়ামতের দিন পর্যন্ত স্থায়ী করেন, তবে আল্লাহ ব্যতীত এমন উপাস্য কে আছে যে, তোমাদেরকে রাত্রি দান করতে পারে, যাতে তোমরা বিশ্রাম করবে ? তোমরা কি তবুও ভেবে দেখবে না ?\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@mmmcccxxv{তিনিই স্বীয় রহমতে তোমাদের জন্যে রাত ও দিন করেছেন, যাতে তোমরা তাতে বিশ্রাম গ্রহণ কর ও তাঁর অনুগ্রহ অন্বেষণ কর এবং যাতে তোমরা কৃতজ্ঞতা প্রকাশ কর।\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@mmmcccxxvi{যেদিন আল্লাহ তাদেরকে ডেকে বলবেন, তোমরা যাদেরকে আমার শরীক মনে করতে, তারা কোথায়?\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@mmmcccxxvii{প্রত্যেক সম্প্রদায় থেকে আমি একজন সাক্ষী আলাদা করব; অতঃপর বলব, তোমাদের প্রমাণ আন। তখন তারা জানতে পারবে যে, সত্য আল্লাহর এবং তারা যা গড়ত, তা তাদের কাছ থেকে উধাও হয়ে যাবে।\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@mmmcccxxviii{কারুন ছিল মূসার সম্প্রদায়ভুক্ত। অতঃপর সে তাদের প্রতি দুষ্টামি করতে আরম্ভ করল। আমি তাকে এত ধন-ভান্ডার দান করেছিলাম যার চাবি বহন করা কয়েকজন শক্তিশালী লোকের পক্ষে কষ্টসাধ্য ছিল। যখন তার সম্প্রদায় তাকে বলল, দম্ভ করো না, আল্লাহ দাম্ভিকদেরকে ভালবাসেন না।\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@mmmcccxxix{আল্লাহ তোমাকে যা দান করেছেন, তদ্বারা পরকালের গৃহ অনুসন্ধান কর, এবং ইহকাল থেকে তোমার অংশ ভূলে যেয়ো না। তুমি অনুগ্রহ কর, যেমন আল্লাহ তোমার প্রতি অনুগ্রহ করেছেন এবং পৃথিবীতে অনর্থ সৃষ্টি করতে প্রয়াসী হয়ো না। নিশ্চয় আল্লাহ অনর্থ সৃষ্টিকারীদেরকে পছন্দ করেন না।\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@mmmcccxxx{সে বলল, আমি এই ধন আমার নিজস্ব জ্ঞান-গরিমা দ্বারা প্রাপ্ত হয়েছি। সে কি জানে না যে, আল্লাহ তার পূর্বে অনেক সম্প্রদায়কে ধ্বংস করেছেন, যারা শক্তিতে ছিল তার চাইতে প্রবল এবং ধন-সম্পদে অধিক প্রাচুর্যশীল? পাপীদেরকে তাদের পাপকর্ম সম্পর্কে জিজ্ঞেস করা হবে না।\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@mmmcccxxxi{অতঃপর কারুন জাঁকজমক সহকারে তার সম্প্রদায়ের সামনে বের হল। যারা পার্থিব জীবন কামনা করত, তারা বলল, হায়, কারুন যা প্রাপ্ত হয়েছে, আমাদেরকে যদি তা দেয়া হত! নিশ্চয় সে বড় ভাগ্যবান।\qt@no{(79)}}
\qt@newcmd\qurantrans@bn@mmmcccxxxii{আর যারা জ্ঞান প্রাপ্ত হয়েছিল, তার বলল, ধিক তোমাদেরকে, যারা ঈমানদার এবং সৎকর্মী, তাদের জন্যে আল্লাহর দেয়া সওয়াবই উৎকৃষ্ট। এটা তারাই পায়, যারা সবরকারী।\qt@no{(80)}}
\qt@newcmd\qurantrans@bn@mmmcccxxxiii{অতঃপর আমি কারুনকে ও তার প্রাসাদকে ভূগর্ভে বিলীন করে দিলাম। তার পক্ষে আল্লাহ ব্যতীত এমন কোন দল ছিল না, যারা তাকে সাহায্য করতে পারে এবং সে নিজেও আত্মরক্ষা করতে পারল না।\qt@no{(81)}}
\qt@newcmd\qurantrans@bn@mmmcccxxxiv{গতকল্য যারা তার মত হওয়ার বাসনা প্রকাশ করেছিল, তারা প্রত্যুষে বলতে লাগল, হায়, আল্লাহ তাঁর বান্দাদের মধ্যে যার জন্যে ইচ্ছা রিযিক বর্ধিত করেন ও হ্রাস করেন। আল্লাহ আমাদের প্রতি অনুগ্রহ না করলে আমাদেরকেও ভূগর্ভে বিলীন করে দিতেন। হায়, কাফেররা সফলকাম হবে না।\qt@no{(82)}}
\qt@newcmd\qurantrans@bn@mmmcccxxxv{এই পরকাল আমি তাদের জন্যে নির্ধারিত করি, যারা দুনিয়ার বুকে ঔদ্ধত্য প্রকাশ করতে ও অনর্থ সৃষ্টি করতে চায় না। খোদাভীরুদের জন্যে শুভ পরিণাম।\qt@no{(83)}}
\qt@newcmd\qurantrans@bn@mmmcccxxxvi{যে সৎকর্ম নিয়ে আসবে, সে তদপেক্ষা উত্তম ফল পাবে এবং যে মন্দ কর্ম নিয়ে আসবে, এরূপ মন্দ কর্মীরা সে মন্দ কর্ম পরিমানেই প্রতিফল পাবে।\qt@no{(84)}}
\qt@newcmd\qurantrans@bn@mmmcccxxxvii{যিনি আপনার প্রতি কোরআনের বিধান পাঠিয়েছেন, তিনি অবশ্যই আপনাকে স্বদেশে ফিরিয়ে আনবেন। বলুন আমার পালনকর্তা ভাল জানেন কে হেদায়েত নিয়ে এসেছে এবং কে প্রকাশ্য বিভ্রান্তিতে আছে।\qt@no{(85)}}
\qt@newcmd\qurantrans@bn@mmmcccxxxviii{আপনি আশা করতেন না যে, আপনার প্রতি কিতাব অবর্তীর্ণ হবে। এটা কেবল আপনার পালনকর্তার রহমত। অতএব আপনি কাফেরদের সাহায্যকারী হবেন না।\qt@no{(86)}}
\qt@newcmd\qurantrans@bn@mmmcccxxxix{কাফেররা যেন আপনাকে আল্লাহর আয়াত থেকে বিমুখ না করে সেগুলো আপনার প্রতি অবর্তীর্ণ হওয়ার পর আপনি আপনার পালনকর্তার প্রতি দাওয়াত দিন এবং কিছুতেই মুশরিকদের অন্তর্ভুক্ত হবেন না।\qt@no{(87)}}
\qt@newcmd\qurantrans@bn@mmmcccxl{আপনি আল্লাহর সাথে অন্য উপাস্যকে আহবান করবেন না। তিনি ব্যতীত অন্য কোন উপাস্য নেই। আল্লাহর সত্তা ব্যতীত সবকিছু ধবংস হবে। বিধান তাঁরই এবং তোমরা তাঁরই কাছে প্রত্যাবর্তিত হবে।\qt@no{(88)}}
\qt@newcmd\qurantrans@bn@mmmcccxli{\basmalahbn আলিফ-লাম-মীম।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmcccxlii{মানুষ কি মনে করে যে, তারা একথা বলেই অব্যাহতি পেয়ে যাবে যে, আমরা বিশ্বাস করি এবং তাদেরকে পরীক্ষা করা হবে না?\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmcccxliii{আমি তাদেরকেও পরীক্ষা করেছি, যারা তাদের পূর্বে ছিল। আল্লাহ অবশ্যই জেনে নেবেন যারা সত্যবাদী এবং নিশ্চয়ই জেনে নেবেন মিথ্যুকদেরকে।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmcccxliv{যারা মন্দ কাজ করে, তারা কি মনে করে যে, তারা আমার হাত থেকে বেঁচে যাবে? তাদের ফয়সালা খুবই মন্দ।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmcccxlv{যে আল্লাহর সাক্ষাত কামনা করে, আল্লাহর সেই নির্ধারিত কাল অবশ্যই আসবে। তিনি সর্বশ্রোতা, সর্বজ্ঞানী।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmcccxlvi{যে কষ্ট স্বীকার করে, সে তো নিজের জন্যেই কষ্ট স্বীকার করে। আল্লাহ বিশ্ববাসী থেকে বে-পরওয়া।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmcccxlvii{আর যারা বিশ্বাস স্থাপন করে ও সৎকর্ম করে, আমি অবশ্যই তাদের মন্দ কাজ গুলো মিটিয়ে দেব এবং তাদেরকে কর্মের উৎকৃষ্টতর প্রতিদান দেব।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmcccxlviii{আমি মানুষকে পিতা-মাতার সাথে সদ্ব্যবহার করার জোর নির্দেশ দিয়েছি। যদি তারা তোমাকে আমার সাথে এমন কিছু শরীক করার জোর প্রচেষ্টা চালায়, যার সম্পর্কে তোমার কোন জ্ঞান নেই, তবে তাদের আনুগত্য করো না। আমারই দিকে তোমাদের প্রত্যাবর্তন। অতঃপর আমি তোমাদেরকে বলে দেব যা কিছু তোমরা করতে।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmcccxlix{যারা বিশ্বাস স্থাপন করে ও সৎকাজ করে, আমি অবশ্যই তাদেরকে সৎকর্মীদের অন্তর্ভুক্ত করব।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmcccl{কতক লোক বলে, আমরা আল্লাহর উপর বিশ্বাস স্থাপন করেছি; কিন্তু আল্লাহর পথে যখন তারা নির্যাতিত হয়, তখন তারা মানুষের নির্যাতনকে আল্লাহর আযাবের মত মনে করে। যখন আপনার পালনকর্তার কাছ থেকে কোন সাহায্য আসে তখন তারা বলতে থাকে, আমরা তো তোমাদের সাথেই ছিলাম। বিশ্ববাসীর অন্তরে যা আছে, আল্লাহ কি তা সম্যক অবগত নন?\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmcccli{আল্লাহ অবশ্যই জেনে নেবেন যারা বিশ্বাস স্থাপন করেছে এবং নিশ্চয় জেনে নেবেন যারা মুনাফেক।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmccclii{কাফেররা মুমিনদেরকে বলে, আমাদের পথ অনুসরণ কর। আমরা তোমাদের পাপভার বহন করব। অথচ তারা পাপভার কিছুতেই বহন করবে না। নিশ্চয় তারা মিথ্যাবাদী।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmcccliii{তারা নিজেদের পাপভার এবং তার সাথে আরও কিছু পাপভার বহন করবে। অবশ্য তারা যে সব মিথ্যা কথা উদ্ভাবন করে, সে সম্পর্কে কেয়ামতের দিন জিজ্ঞাসিত হবে।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmcccliv{আমি নূহ (আঃ) কে তাঁর সম্প্রদায়ের কাছে প্রেরণ করেছিলাম। তিনি তাদের মধ্যে পঞ্চাশ কম এক হাজার বছর অবস্থান করেছিলেন। অতঃপর তাদেরকে মহাপ্লাবণ গ্রাস করেছিল। তারা ছিল পাপী।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmccclv{অতঃপর আমি তাঁকে ও নৌকারোহীগণকে রক্ষা করলাম এবং নৌকাকে নিদর্শন করলাম বিশ্ববাসীর জন্যে।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmccclvi{স্মরণ কর ইব্রাহীমকে। যখন তিনি তাঁর সম্প্রদায়কে বললেন; তোমরা আল্লাহর এবাদত কর এবং তাঁকে ভয় কর। এটাই তোমাদের জন্যে উত্তম যদি তোমরা বোঝ।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmccclvii{তোমরা তো আল্লাহর পরিবর্তে কেবল প্রতিমারই পূজা করছ এবং মিথ্যা উদ্ভাবন করছ। তোমরা আল্লাহর পরিবর্তে যাদের এবাদত করছ, তারা তোমাদের রিযিকের মালিক নয়। কাজেই আল্লাহর কাছে রিযিক তালাশ কর, তাঁর এবাদত কর এবং তাঁর কৃতজ্ঞতা প্রকাশ কর। তাঁরই কাছে তোমরা প্রত্যাবর্তিত হবে।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmccclviii{তোমরা যদি মিথ্যাবাদী বল, তবে তোমাদের পূর্ববর্তীরাও তো মিথ্যাবাদী বলেছে। স্পষ্টভাবে পয়গাম পৌছে দেয়াই তো রসূলের দায়িত্ব।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmccclix{তারা কি দেখে না যে, আল্লাহ কিভাবে সৃষ্টিকর্ম শুরু করেন অতঃপর তাকে পুনরায় সৃষ্টি করবেন? এটা আল্লাহর জন্যে সহজ।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmccclx{বলুন, তোমরা পৃথিবীতে ভ্রমণ কর এবং দেখ, কিভাবে তিনি সৃষ্টিকর্ম শুরু করেছেন। অতঃপর আল্লাহ পুর্নবার সৃষ্টি করবেন। নিশ্চয় আল্লাহ সবকিছু করতে সক্ষম।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmccclxi{তিনি যাকে ইচ্ছা শাস্তি দেন এবং যার প্রতি ইচ্ছা রহমত করেন। তাঁরই দিকে তোমরা প্রত্যাবর্তিত হবে।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmccclxii{তোমরা স্থলে ও অন্তরীক্ষে আল্লাহকে অপারগ করতে পারবে না এবং আল্লাহ ব্যতীত তোমাদের কোন হিতাকাঙ্খী নেই, সাহায্যকারীও নেই।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmccclxiii{যারা আল্লাহর আয়াত সমূহ ও তাঁর সাক্ষাত অস্বীকার করে, তারাই আমার রহমত থেকে নিরাশ হবে এবং তাদের জন্যেই যন্ত্রণাদায়ক শাস্তি রয়েছে।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmccclxiv{তখন ইব্রাহীমের সম্প্রদায়ের এছাড়া কোন জওয়াব ছিল না যে তারা বলল, তাকে হত্যা কর অথবা অগ্নিদগ্ধ কর। অতঃপর আল্লাহ তাকে অগ্নি থেকে রক্ষা করলেন। নিশ্চয় এতে বিশ্বাসী লোকদের জন্যে নিদর্শনাবলী রয়েছে।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmccclxv{ইব্রাহীম বললেন, পার্থিব জীবনে তোমাদের পারস্পরিক ভালবাসা রক্ষার জন্যে তোমরা আল্লাহর পরিবর্তে প্রতিমাগুলোকে উপাস্যরূপে গ্রহণ করেছ। এরপর কেয়ামতের দিন তোমরা একে অপরকে অস্বীকার করবে এবং একে অপরকে লানত করবে। তোমাদের ঠিকানা জাহান্নাম এবং তোমাদের কোন সাহায্যকারী নেই।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmccclxvi{অতঃপর তার প্রতি বিশ্বাস স্থাপন করলেন লূত। ইব্রাহীম বললেন, আমি আমার পালনকর্তার উদ্দেশে দেশত্যাগ করছি। নিশ্চয় তিনি পরাক্রমশালী, প্রজ্ঞাময়।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmccclxvii{আমি তাকে দান করলাম ইসহাক ও ইয়াকুব, তাঁর বংশধরদের মধ্যে নবুওয়ত ও কিতাব রাখলাম এবং দুনিয়াতে তাঁকে পুরস্কৃত করলাম। নিশ্চয় পরকালে ও সে সৎলোকদর অন্তর্ভূক্ত হবে।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmccclxviii{আর প্রেরণ করেছি লূতকে। যখন সে তার সম্প্রদায়কে বলল, তোমরা এমন অশ্লীল কাজ করছ, যা তোমাদের পূর্বে পৃথিবীর কেউ করেনি।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmccclxix{তোমরা কি পুংমৈথুনে লিপ্ত আছ, রাহাজানি করছ এবং নিজেদের মজলিসে গর্হিত কর্ম করছ? জওয়াবে তাঁর সম্প্রদায় কেবল একথা বলল, আমাদের উপর আল্লাহর আযাব আন যদি তুমি সত্যবাদী হও।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmccclxx{সে বলল, হে আমার পালনকর্তা, দুস্কৃতকারীদের বিরুদ্ধে আমাকে সাহায্য কর।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmccclxxi{যখন আমার প্রেরিত ফেরেশতাগণ সুসংবাদ নিয়ে ইব্রাহীমের কাছে আগমন করল, তখন তারা বলল, আমরা এই জনপদের অধিবাসীদেরকে ধ্বংস করব। নিশ্চয় এর অধিবাসীরা জালেম।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmccclxxii{সে বলল, এই জনপদে তো লূতও রয়েছে। তারা বলল, সেখানে কে আছে, তা আমরা ভাল জানি। আমরা অবশ্যই তাকে ও তাঁর পরিবারবর্গকে রক্ষা করব তাঁর স্ত্রী ব্যতীত; সে ধ্বংসপ্রাপ্তদের অন্তর্ভূক্ত থাকবে।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmccclxxiii{যখন আমার প্রেরিত ফেরেশতাগণ লূতের কাছে আগমন করল, তখন তাদের কারণে সে বিষন্ন হয়ে পড়ল এবং তার মন সংকীর্ণ হয়ে গেল। তারা বলল, ভয় করবেন না এবং দুঃখ করবেন না। আমরা আপনাকে ও আপনার পরিবারবর্গকে রক্ষা করবই আপনার স্ত্রী ব্যতীত, সে ধ্বংস প্রাপ্তদের অন্তর্ভূক্ত থাকবে।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmccclxxiv{আমরা এই জনপদের অধিবাসীদের উপর আকাশ থেকে আযাব নাজিল করব তাদের পাপাচারের কারণে।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmccclxxv{আমি বুদ্ধিমান লোকদের জন্যে এতে একটি স্পষ্ট নিদর্শন রেখে দিয়েছি।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmccclxxvi{আমি মাদইয়ানবাসীদের প্রতি তাদের ভাই শোআয়বকে প্রেরণ করেছি। সে বলল, হে আমার সম্প্রদায় তোমরা আল্লাহর এবাদত কর, শেষ দিবসের আশা রাখ এবং পৃথিবীতে অনর্থ সৃষ্টি করো না।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmccclxxvii{কিন্তু তারা তাঁকে মিথ্যাবাদী বলল; অতঃপর তারা ভূমিকম্প দ্বারা আক্রান্ত হল এবং নিজেদের গৃহে উপুড় হয়ে পড়ে রইল।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmccclxxviii{আমি আ’দ ও সামুদকে ধ্বংস করে দিয়েছি। তাদের বাড়ী-ঘর থেকেই তাদের অবস্থা তোমাদের জানা হয়ে গেছে। শয়তান তাদের কর্মকে তাদের দৃষ্টিতে সুশোভিত করেছিল, অতঃপর তাদেরকে সৎপথ অবলম্বনে বাধা দিয়েছিল এবং তারা ছিল হুশিয়ার।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmccclxxix{আমি কারুন, ফেরাউন ও হামানকে ধ্বংস করেছি। মূসা তাদের কাছে সুস্পষ্ট নিদর্শনাবলী নিয়ে আগমন করেছিল অতঃপর তারা দেশে দম্ভ করেছিল। কিন্তু তারা জিতে যায়নি।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmccclxxx{আমি প্রত্যেককেই তার অপরাধের কারণে পাকড়াও করেছি। তাদের কারও প্রতি প্রেরণ করেছি প্রস্তরসহ প্রচন্ড বাতাস, কাউকে পেয়েছে বজ্রপাত, কাউকে আমি বিলীন করেছি ভূগর্ভে এবং কাউকে করেছি নিমজ্জত। আল্লাহ তাদের প্রতি যুলুম করার ছিলেন না; কিন্তু তারা নিজেরাই নিজেদের প্রতি যুলুম করেছে।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmccclxxxi{যারা আল্লাহর পরিবর্তে অপরকে সাহায্যকারীরূপে গ্রহণ করে তাদের উদাহরণ মাকড়সা। সে ঘর বানায়। আর সব ঘরের মধ্যে মাকড়সার ঘরই তো অধিক দুর্বল, যদি তারা জানত।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmccclxxxii{তারা আল্লাহর পরিবর্তে যা কিছুকে ডাকে, আল্লাহ তা জানেন। তিনি শক্তিশালী, প্রজ্ঞাময়।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmccclxxxiii{এ সকল উদাহরণ আমি মানুষের জন্যে দেই; কিন্তু জ্ঞানীরাই তা বোঝে।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmccclxxxiv{আল্লাহ যথার্থরূপে নভোমন্ডল ও ভূমন্ডল সৃষ্টি করেছেন। এতে নিদর্শন রয়েছে ঈমানদার সম্প্রদায়ের জন্যে।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmccclxxxv{আপনি আপনার প্রতি প্রত্যাদিষ্ট কিতাব পাঠ করুন এবং নামায কায়েম করুন। নিশ্চয় নামায অশ্লীল ও গর্হিত কার্য থেকে বিরত রাখে। আল্লাহর স্মরণ সর্বশ্রেষ্ঠ। আল্লাহ জানেন তোমরা যা কর।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmmccclxxxvi{তোমরা কিতাবধারীদের সাথে তর্ক-বিতর্ক করবে না, কিন্তু উত্তম পন্থায়; তবে তাদের সাথে নয়, যারা তাদের মধ্যে বে-ইনসাফ। এবং বল, আমাদের প্রতি ও তোমাদের প্রতি যা নাযিল করা হয়েছে, তাতে আমরা বিশ্বাস স্থাপন করেছি। আমাদের উপাস্য ও তোমাদের উপাস্য একই এবং আমরা তাঁরই আজ্ঞাবহ।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmmccclxxxvii{এভাবেই আমি আপনার প্রতি কিতাব অবর্তীণ করেছি। অতঃপর যাদের কে আমি কিতাব দিয়েছিলাম, তারা একে মেনে চলে এবং এদেরও (মক্কাবাসীদেরও) কেউ কেউ এতে বিশ্বাস রাখে। কেবল কাফেররাই আমার আয়াতসমূহ অস্বীকার করে।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmmccclxxxviii{আপনি তো এর পূর্বে কোন কিতাব পাঠ করেননি এবং স্বীয় দক্ষিণ হস্ত দ্বারা কোন কিতাব লিখেননি। এরূপ হলে মিথ্যাবাদীরা অবশ্যই সন্দেহ পোষণ করত।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmmccclxxxix{বরং যাদেরকে জ্ঞান দেয়া হয়েছে, তাদের অন্তরে ইহা (কোরআন) তো স্পষ্ট আয়াত। কেবল বে-ইনসাফরাই আমার আয়াতসমূহ অস্বীকার করে।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmmcccxc{তারা বলে, তার পালনকর্তার পক্ষ থেকে তার প্রতি কিছু নিদর্শন অবতীর্ণ হল না কেন? বলুন, নিদর্শন তো আল্লাহর ইচ্ছাধীন। আমি তো একজন সুস্পষ্ট সতর্ককারী মাত্র।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmmcccxci{এটাকি তাদের জন্যে যথেষ্ট নয় যে, আমি আপনার প্রতি কিতাব নাযিল করেছি, যা তাদের কাছে পাঠ করা হয়। এতে অবশ্যই বিশ্বাসী লোকদের জন্যে রহমত ও উপদেশ আছে।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmmcccxcii{বলুন, আমার মধ্যে ও তোমাদের মধ্যে আল্লাহই সাক্ষীরূপে যথেষ্ট। তিনি জানেন যা কিছু নভোমন্ডলে ও ভূ-মন্ডলে আছে। আর যারা মিথ্যায় বিশ্বাস করে ও আল্লাহকে অস্বীকার করে, তারাই ক্ষতিগ্রস্ত।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmmcccxciii{তারা আপনাকে আযাব ত্বরান্বিত করতে বলে। যদি আযাবের সময় নির্ধারিত না থাকত, তবে আযাব তাদের উপর এসে যেত। নিশ্চয়ই আকস্মিকভাবে তাদের কাছে আযাব এসে যাবে, তাদের খবরও থাকবে না।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmmcccxciv{তারা আপনাকে আযাব ত্বরান্বিত করতে বলে; অথচ জাহান্নাম কাফেরদেরকে ঘেরাও করছে।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmmcccxcv{যেদিন আযাব তাদেরকে ঘেরাও করবে মাথার উপর থেকে এবং পায়ের নীচ থেকে। আল্লাহ বললেন, তোমরা যা করতে, তার স্বাদ গ্রহণ কর।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mmmcccxcvi{হে আমার ঈমানদার বান্দাগণ, আমার পৃথিবী প্রশস্ত। অতএব তোমরা আমারই এবাদত কর।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mmmcccxcvii{জীবমাত্রই মৃত্যুর স্বাদ গ্রহণ করবে। অতঃপর তোমরা আমারই কাছে প্রত্যাবর্তিত হবে।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mmmcccxcviii{যারা বিশ্বাস স্থাপন করে ও সৎকর্ম করে, আমি অবশ্যই তাদেরকে জান্নাতের সুউচ্চ প্রাসাদে স্থান দেব, যার তলদেশে প্রস্রবণসমূহ প্রবাহিত। সেখানে তারা চিরকাল থাকবে। কত উত্তম পুরস্কার কর্মীদের।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mmmcccxcix{যারা সবর করে এবং তাদের পালনকর্তার উপর ভরসা করে।\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mmmcd{এমন অনেক জন্তু আছে, যারা তাদের খাদ্য সঞ্চিত রাখে না। আল্লাহই রিযিক দেন তাদেরকে এবং তোমাদেরকেও। তিনি সর্বশ্রোতা, সর্বজ্ঞ।\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mmmcdi{যদি আপনি তাদেরকে জিজ্ঞেস করেন, কে নভোমন্ডল ও ভূ-মন্ডল সৃষ্টি করেছে, চন্দ্র ও সূর্যকে কর্মে নিয়োজিত করেছে? তবে তারা অবশ্যই বলবে আল্লাহ। তাহলে তারা কোথায় ঘুরে বেড়াচ্ছে?\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mmmcdii{আল্লাহ তাঁর বান্দাদের মধ্যে যার জন্য ইচ্ছা রিযিক প্রশস্ত করে দেন এবং যার জন্য ইচ্ছা হ্রাস করেন। নিশ্চয়, আল্লাহ সর্ববিষয়ে সম্যক পরিজ্ঞাত।\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mmmcdiii{যদি আপনি তাদেরকে জিজ্ঞেস করেন, কে আকাশ থেকে বারি বর্ষণ করে, অতঃপর তা দ্বারা মৃত্তিকাকে উহার মৃত হওয়ার পর সঞ্জীবিত করে? তবে তারা অবশ্যই বলবে, আল্লাহ। বলুন, সমস্ত প্রশংসা আল্লাহরই। কিন্তু তাদের অধিকাংশই তা বোঝে না।\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mmmcdiv{এই পার্থিব জীবন ক্রীড়া-কৌতুক বৈ তো কিছুই নয়। পরকালের গৃহই প্রকৃত জীবন; যদি তারা জানত।\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mmmcdv{তারা যখন জলযানে আরোহণ করে তখন একনিষ্ঠভাবে আল্লাহকে ডাকে। অতঃপর তিনি যখন স্থলে এনে তাদেরকে উদ্ধার করেন, তখনই তারা শরীক করতে থাকে।\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mmmcdvi{যাতে তারা তাদের প্রতি আমার দান অস্বীকার করে এবং ভোগ-বিলাসে ডুবে থাকে। সত্বরই তারা জানতে পারবে।\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mmmcdvii{তারা কি দেখে না যে, আমি একটি নিরাপদ আশ্রয়স্থল করেছি। অথচ এর চতুপার্শ্বে যারা আছে, তাদের উপর আক্রমণ করা হয়। তবে কি তারা মিথ্যায়ই বিশ্বাস করবে এবং আল্লাহর নেয়ামত অস্বীকার করবে?\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mmmcdviii{যে আল্লাহ সম্পর্কে মিথ্যা কথা গড়ে অথবা তার কাছে সত্য আসার পর তাকে অস্বীকার করে, তার কি স্মরণ রাখা উচিত নয় যে, জাহান্নামই সেসব কাফেরের আশ্রয়স্থল হবে?\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mmmcdix{যারা আমার পথে সাধনায় আত্মনিয়োগ করে, আমি অবশ্যই তাদেরকে আমার পথে পরিচালিত করব। নিশ্চয় আল্লাহ সৎকর্মপরায়ণদের সাথে আছেন।\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mmmcdx{\basmalahbn আলিফ-লাম-মীম,\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmcdxi{রোমকরা পরাজিত হয়েছে,\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmcdxii{নিকটবর্তী এলাকায় এবং তারা তাদের পরাজয়ের পর অতিসত্বর বিজয়ী হবে,\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmcdxiii{কয়েক বছরের মধ্যে। অগ্র-পশ্চাতের কাজ আল্লাহর হাতেই। সেদিন মুমিনগণ আনন্দিত হবে।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmcdxiv{আল্লাহর সাহায্যে। তিনি যাকে ইচ্ছা সাহায্য করেন এবং তিনি পরাক্রমশালী, পরম দয়ালু।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmcdxv{আল্লাহর প্রতিশ্রুতি হয়ে গেছে। আল্লাহ তার প্রতিশ্রুতি খেলাফ করবেন না। কিন্তু অধিকাংশ লোক জানে না।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmcdxvi{তারা পার্থিব জীবনের বাহ্যিক দিক জানে এবং তারা পরকালের খবর রাখে না।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmcdxvii{তারা কি তাদের মনে ভেবে দেখে না যে, আল্লাহ নভোমন্ডল, ভূমন্ডল ও এতদুভয়ের মধ্যবর্তী সবকিছু সৃষ্টি করেছেন যথাযথরূপে ও নির্দিষ্ট সময়ের জন্য, কিন্তু অনেক মানুষ তাদের পালনকর্তার সাক্ষাতে অবিশ্বাসী।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmcdxviii{তারা কি পৃথিবীতে ভ্রমণ করে না অতঃপর দেখে না যে; তাদের পূর্ববর্তীদের পরিণাম কি কি হয়েছে? তারা তাদের চাইতে শক্তিশালী ছিল, তারা যমীন চাষ করত এবং তাদের চাইতে বেশী আবাদ করত। তাদের কাছে তাদের রসূলগণ সুস্পষ্ট নির্দেশ নিয়ে এসেছিল। বস্তুতঃ আল্লাহ তাদের প্রতি জুলুমকারী ছিলেন না। কিন্তু তারা নিজেরাই নিজেদের প্রতি জুলুম করেছিল।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmcdxix{অতঃপর যারা মন্দ কর্ম করত, তাদের পরিণাম হয়েছে মন্দ। কারণ, তারা আল্লাহর আয়াতসমূহকে মিথ্যা বলত এবং সেগুলো নিয়ে ঠাট্টা-বিদ্রূপ করত।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmcdxx{আল্লাহ প্রথমবার সৃষ্টি করেন, অতঃপর তিনি পুনরায় সৃষ্টি করবেন। এরপর তোমরা তাঁরই দিকে প্রত্যাবর্তিত হবে।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmcdxxi{যে দিন কেয়ামত সংঘটিত হবে, সেদিন অপরাধীরা হতাশ হয়ে যাবে।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmcdxxii{তাদের দেবতা গুলোর মধ্যে কেউ তাদের সুপারিশ করবে না। এবং তারা তাদের দেবতাকে অস্বীকার করবে।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmcdxxiii{যেদিন কেয়ামত সংঘটিত হবে, সেদিন মানুষ বিভক্ত হয়ে পড়বে।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmcdxxiv{যারা বিশ্বাস স্থাপন করেছে ও সৎকর্ম করেছে, তারা জান্নাতে সমাদৃত হবে;\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmcdxxv{আর যারা কাফের এবং আমার আয়াতসমূহ ও পরকালের সাক্ষাতকারকে মিথ্যা বলছে, তাদেরকেই আযাবের মধ্যে উপস্থিত করা হবে।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmcdxxvi{অতএব, তোমরা আল্লাহর পবিত্রতা স্মরণ কর সন্ধ্যায় ও সকালে,\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmcdxxvii{এবং অপরাহ্নে ও মধ্যাহ্নে নভোমন্ডল ও ভূমন্ডলে, তাঁরই প্রসংসা।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmcdxxviii{তিনি মৃত থেকে জীবিতকে বহির্গত করেন জীবিত থেকে মৃতকে বহির্গত করেন, এবং ভূমির মৃত্যুর পর তাকে পুনরুজ্জীবিত করেন। এভাবে তোমরা উত্থিত হবে।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmcdxxix{তাঁর নিদর্শনাবলীর মধ্যে এক নিদর্শন এই যে, তিনি মৃত্তিকা থেকে তোমাদের সৃষ্টি করেছেন। এখন তোমরা মানুষ, পৃথিবীতে ছড়িয়ে আছ।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmcdxxx{আর এক নিদর্শন এই যে, তিনি তোমাদের জন্যে তোমাদের মধ্য থেকে তোমাদের সংগিনীদের সৃষ্টি করেছেন, যাতে তোমরা তাদের কাছে শান্তিতে থাক এবং তিনি তোমাদের মধ্যে পারস্পরিক সম্প্রীতি ও দয়া সৃষ্টি করেছেন। নিশ্চয় এতে চিন্তাশীল লোকদের জন্যে নিদর্শনাবলী রয়েছে।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmcdxxxi{তাঁর আর ও এক নিদর্শন হচ্ছে নভোমন্ডল ও ভূমন্ডলের সৃজন এবং তোমাদের ভাষা ও বর্ণের বৈচিত্র। নিশ্চয় এতে জ্ঞানীদের জন্যে নিদর্শনাবলী রয়েছে।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmcdxxxii{তাঁর আরও নিদর্শনঃ রাতে ও দিনে তোমাদের নিদ্রা এবং তাঁর কৃপা অন্বেষণ। নিশ্চয় এতে মনোযোগী সম্প্রদায়ের জন্যে নিদর্শনাবলী রয়েছে।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmcdxxxiii{তাঁর আরও নিদর্শনঃ তিনি তোমাদেরকে দেখান বিদ্যুৎ, ভয় ও ভরসার জন্যে এবং আকাশ থেকে পানি বর্ষণ করেন, অতঃপর তদ্দ্বারা ভূমির মৃত্যুর পর তাকে পুনরুজ্জীবিত করেন। নিশ্চয় এতে বুদ্ধিমান লোকদের জন্যে নিদর্শনাবলী রয়েছে।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmcdxxxiv{তাঁর অন্যতম নিদর্শন এই যে, তাঁরই আদেশে আকাশ ও পৃথিবী প্রতিষ্ঠিত আছে। অতঃপর যখন তিনি মৃত্তিকা থেকে উঠার জন্যে তোমাদের ডাক দেবেন, তখন তোমরা উঠে আসবে।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmcdxxxv{নভোমন্ডলে ও ভুমন্ডলে যা কিছু আছে, সব তাঁরই। সবাই তাঁর আজ্ঞাবহ।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmcdxxxvi{তিনিই প্রথমবার সৃষ্টিকে অস্তিত্বে আনয়ন করেন, অতঃপর তিনি সৃষ্টি করবেন। এটা তাঁর জন্যে সহজ। আকাশ ও পৃথিবীতে সর্বোচ্চ মর্যাদা তাঁরই এবং তিনিই পরাক্রমশালী, প্রজ্ঞাময়।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmcdxxxvii{আল্লাহ তোমাদের জন্যে তোমাদেরই মধ্য থেকে একটি দৃষ্টান্ত বর্ণনা করেছেনঃ তোমাদের আমি যে রুযী দিয়েছি, তোমাদের অধিকারভুক্ত দাস-দাসীরা কি তাতে তোমাদের সমান সমান অংশীদার? তোমরা কি তাদেরকে সেরূপ ভয় কর, যেরূপ নিজেদের লোককে ভয় কর? এমনিভাবে আমি সমঝদার সম্প্রদায়ের জন্যে নিদর্শনাবলী বিস্তারিত বর্ণনা করি।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmcdxxxviii{বরং যারা যে-ইনসাফ, তারা অজ্ঞানতাবশতঃ তাদের খেয়াল-খূশীর অনুসরণ করে থাকে। অতএব, আল্লাহ যাকে পথভ্রষ্ট করেন, তাকে কে বোঝাবে? তাদের কোন সাহায্যকারী নেই।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmcdxxxix{তুমি একনিষ্ঠ ভাবে নিজেকে ধর্মের উপর প্রতিষ্ঠিত রাখ। এটাই আল্লাহর প্রকৃতি, যার উপর তিনি মানব সৃষ্টি করেছেন। আল্লাহর সৃষ্টির কোন পরিবর্তন নেই। এটাই সরল ধর্ম। কিন্তু অধিকাংশ মানুষ জানে না।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmcdxl{সবাই তাঁর অভিমুখী হও এবং ভয় কর, নামায কায়েম কর এবং মুশরিকদের অন্তর্ভুক্ত হয়ো না।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmcdxli{যারা তাদের ধর্মে বিভেদ সৃষ্টি করেছে এবং অনেক দলে বিভক্ত হয়ে পড়েছে। প্রত্যেক দলই নিজ নিজ মতবাদ নিয়ে উল্লসিত।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmcdxlii{মানুষকে যখন দুঃখ-কষ্ট স্পর্শ করে, তখন তারা তাদের পালনকর্তাকে আহবান করে তাঁরই অভিমুখী হয়ে। অতঃপর তিনি যখন তাদেরকে রহমতের স্বাদ আস্বাদন করান, তখন তাদের একদল তাদের পালনকর্তার সাথে শিরক করতে থাকে,\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmcdxliii{যাতে তারা অস্বীকার করে যা আমি তাদেরকে দিয়েছি। অতএব, মজা লুটে নাও, সত্বরই জানতে পারবে।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmcdxliv{আমি কি তাদের কাছে এমন কোন দলীল নাযিল করেছি, যে তাদেরকে আমার শরীক করতে বলে?\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmcdxlv{আর যখন আমি মানুষকে রহমতের স্বাদ আস্বাদন করাই, তারা তাতে আনন্দিত হয় এবং তাদের কৃতকর্মের ফলে যদি তাদেরকে কোন দুদর্শা পায়, তবে তারা হতাশ হয়ে পড়ে।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmcdxlvi{তারা কি দেখে না যে, আল্লাহ যার জন্যে ইচ্ছা রিযিক বর্ধিত করেন এবং হ্রাস করেন। নিশ্চয় এতে বিশ্বাসী সম্প্রদায়ের জন্যে নিদর্শনাবলী রয়েছে।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmcdxlvii{আত্নীয়-স্বজনকে তাদের প্রাপ্য দিন এবং মিসকীন ও মুসাফিরদেরও। এটা তাদের জন্যে উত্তম, যারা আল্লাহর সন্তুষ্টি কামনা করে। তারাই সফলকাম।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmcdxlviii{মানুষের ধন-সম্পদে তোমাদের ধন-সম্পদ বৃদ্ধি পাবে, এই আশায় তোমরা সুদে যা কিছু দাও, আল্লাহর কাছে তা বৃদ্ধি পায় না। পক্ষান্তরে, আল্লাহর সন্তুষ্টি লাভের আশায় পবিত্র অন্তরে যারা দিয়ে থাকে, অতএব, তারাই দ্বিগুণ লাভ করে।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmcdxlix{আল্লাহই তোমাদের সৃষ্টি করেছেন, অতঃপর রিযিক দিয়েছেন, এরপর তোমাদের মৃত্যু দেবেন, এরপর তোমাদের জীবিত করবেন। তোমাদের শরীকদের মধ্যে এমন কেউ আছে কি, যে এসব কাজের মধ্যে কোন একটিও করতে পারবে? তারা যাকে শরীক করে, আল্লাহ তা থেকে পবিত্র ও মহান।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmcdl{স্থলে ও জলে মানুষের কৃতকর্মের দরুন বিপর্যয় ছড়িয়ে পড়েছে। আল্লাহ তাদেরকে তাদের কর্মের শাস্তি আস্বাদন করাতে চান, যাতে তারা ফিরে আসে।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmcdli{বলুন, তোমরা পৃথিবীতে পরিভ্রমণ কর এবং দেখ তোমাদের পুর্ববর্তীদের পরিণাম কি হয়েছে। তাদের অধিকাংশই ছিল মুশরিক।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmcdlii{যে দিবস আল্লাহর পক্ষ থেকে প্রত্যাহূত হবার নয়, সেই দিবসের পূর্বে আপনি সরল ধর্মে নিজেকে প্রতিষ্ঠিত করুন। সেদিন মানুষ বিভক্ত হয়ে পড়বে।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmcdliii{যে কুফরী করে, তার কফুরের জন্যে সে-ই দায়ী এবং যে সৎকর্ম করে, তারা নিজেদের পথই শুধরে নিচ্ছে।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmcdliv{যারা বিশ্বাস করেছে ও সৎকর্ম করেছে যাতে, আল্লাহ তা’আলা তাদেরকে নিজ অনুগ্রহে প্রতিদান দেন। নিশ্চয় তিনি কাফেরদের ভালবাসেন না।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmmcdlv{তাঁর নিদর্শনসমূহের মধ্যে একটি এই যে, তিনি সুসংবাদবাহী বায়ু প্রেরণ করেন, যাতে তিনি তাঁর অনুগ্রহ তোমাদের আস্বাদন করান এবং যাতে তাঁর নির্দেশে জাহাজসমূহ বিচরণ করে এবং যাতে তোমরা তাঁর অনুগ্রহ তালাশ কর এবং তাঁর প্রতি কৃতজ্ঞ হও।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmmcdlvi{আপনার পূর্বে আমি রসূলগণকে তাঁদের নিজ নিজ সম্প্রদায়ের কাছে প্রেরণ করেছি। তাঁরা তাদের কাছে সুস্পষ্ট নিদর্শনাবলী নিয়ে আগমন করেন। অতঃপর যারা পাপী ছিল, তাদের আমি শাস্তি দিয়েছি। মুমিনদের সাহায্য করা আমার দায়িত্ব।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmmcdlvii{তিনি আল্লাহ, যিনি বায়ু প্রেরণ করেন, অতঃপর তা মেঘমালাকে সঞ্চারিত করে। অতঃপর তিনি মেঘমালাকে যেভাবে ইচ্ছা আকাশে ছড়িয়ে দেন এবং তাকে স্তরে স্তরে রাখেন। এরপর তুমি দেখতে পাও তার মধ্য থেকে নির্গত হয় বৃষ্টিধারা। তিনি তাঁর বান্দাদের মধ্যে যাদেরকে ইচ্ছা পৌঁছান; তখন তারা আনন্দিত হয়।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmmcdlviii{তারা প্রথম থেকেই তাদের প্রতি এই বৃষ্টি বর্ষিত হওয়ার পূর্বে নিরাশ ছিল।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmmcdlix{অতএব, আল্লাহর রহমতের ফল দেখে নাও, কিভাবে তিনি মৃত্তিকার মৃত্যুর পর তাকে জীবিত করেন। নিশ্চয় তিনি মৃতদেরকে জীবিত করবেন এবং তিনি সব কিছুর উপর সর্বশক্তিমান।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmmcdlx{আমি যদি এমন বায়ু প্রেরণ করি যার ফলে তারা শস্যকে হলদে হয়ে যেতে দেখে, তখন তো তারা অবশ্যই অকৃতজ্ঞ হয়ে যায়।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmmcdlxi{অতএব, আপনি মৃতদেরকে শোনাতে পারবেন না এবং বধিরকেও আহবান শোনাতে পারবেন না, যখন তারা পৃষ্ঠ প্রদর্শন করে।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmmcdlxii{আপনি অন্ধদেরও তাদের পথভ্রষ্টতা থেকে পথ দেখাতে পারবেন না। আপনি কেবল তাদেরই শোনাতে পারবেন, যারা আমার আয়াতসমূহে বিশ্বাস করে। কারন তারা মুসলমান।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmmcdlxiii{আল্লাহ তিনি দূর্বল অবস্থায় তোমাদের সৃষ্টি করেন অতঃপর দূর্বলতার পর শক্তিদান করেন, অতঃপর শক্তির পর দেন দুর্বলতা ও বার্ধক্য। তিনি যা ইচ্ছা সৃষ্টি করেন এবং তিনি সর্বজ্ঞ, সর্বশক্তিমান।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmmcdlxiv{যেদিন কেয়ামত সংঘটিত হবে, সেদিন অপরাধীরা কসম খেয়ে বলবে যে, এক মুহুর্তেরও বেশী অবস্থান করিনি। এমনিভাবে তারা সত্যবিমুখ হত।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mmmcdlxv{যাদের জ্ঞান ও ঈমান দেয়া হয়েছে, তারা বলবে আমরা আল্লাহর কিতাব মতে পুনরুত্থান দিবস পর্যন্ত অবস্থান করেছি। এটাই পুনরুত্থান দিবস, কিন্তু তোমরা তা জানতে না।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mmmcdlxvi{সেদিন জালেমদের ওযর-আপত্তি তাদের কোন উপকারে আসবে না এবং তওবা করে আল্লাহর সন্তুষ্টি লাভের সুযোগও তাদের দেয়া হবে না।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mmmcdlxvii{আমি এই কোরআনে মানুষের জন্য সর্বপ্রকার দৃষ্টান্ত বর্ণনা করেছি। আপনি যদি তাদের কাছে কোন নিদর্শন উপস্থিত করেন, তবে কাফেররা অবশ্যই বলবে, তোমরা সবাই মিথ্যাপন্থী।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mmmcdlxviii{এমনিভাবে আল্লাহ জ্ঞানহীনদের হৃদয় মোহরাঙ্কিত করে দেন।\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mmmcdlxix{অতএব, আপনি সবর করুন। আল্লাহর ওয়াদা সত্য। যারা বিশ্বাসী নয়, তারা যেন আপনাকে বিচলিত করতে না পারে।\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mmmcdlxx{\basmalahbn আলিফ-লাম-মীম।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmcdlxxi{এগুলো প্রজ্ঞাময় কিতাবের আয়াত।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmcdlxxii{হেদায়েত ও রহমত সৎকর্মপরায়ণদের জন্য।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmcdlxxiii{যারা সালাত কায়েম করে, যাকাত দেয় এবং আখেরাত সম্পর্কে দৃঢ় বিশ্বাস রাখে।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmcdlxxiv{এসব লোকই তাদের পরওয়ারদেগারের তরফ থেকে আগত হেদায়েতের উপর প্রতিষ্ঠিত এবং এরাই সফলকাম।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmcdlxxv{একশ্রেণীর লোক আছে যারা মানুষকে আল্লাহর পথ থেকে গোমরাহ করার উদ্দেশে অবান্তর কথাবার্তা সংগ্রহ করে অন্ধভাবে এবং উহাকে নিয়ে ঠাট্টা-বিদ্রূপ করে। এদের জন্য রয়েছে অবমাননাকর শাস্তি।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmcdlxxvi{যখন ওদের সামনে আমার আয়তসমূহ পাঠ করা হয়, তখন ওরা দম্ভের সাথে এমনভাবে মুখ ফিরিয়ে নেয়, যেন ওরা তা শুনতেই পায়নি অথবা যেন ওদের দু’কান বধির। সুতরাং ওদেরকে কষ্টদায়ক আযাবের সংবাদ দাও।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmcdlxxvii{যারা ঈমান আনে আর সৎকাজ করে তাদের জন্য রয়েছে নেয়ামতে ভরা জান্নাত।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmcdlxxviii{সেখানে তারা চিরকাল থাকবে। আল্লাহর ওয়াদা যথার্থ। তিনি পরাক্রমশালী ও প্রজ্ঞাময়।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmcdlxxix{তিনি খুঁটি ব্যতীত আকাশমন্ডলী সৃষ্টি করেছেন; তোমরা তা দেখছ। তিনি পৃথিবীতে স্থাপন করেছেন পর্বতমালা, যাতে পৃথিবী তোমাদেরকে নিয়ে ঢলে না পড়ে এবং এতে ছড়িয়ে দিয়েছেন সর্বপ্রকার জন্তু। আমি আকাশ থেকে পানি বর্ষণ করেছি, অতঃপর তাতে উদগত করেছি সর্বপ্রকার কল্যাণকর উদ্ভিদরাজি।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmcdlxxx{এটা আল্লাহর সৃষ্টি; অতঃপর তিনি ব্যতীত অন্যেরা যা সৃষ্টি করেছে, তা আমাকে দেখাও। বরং জালেমরা সুস্পষ্ট পথভ্রষ্টতায় পতিত আছে।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmcdlxxxi{আমি লোকমানকে প্রজ্ঞা দান করেছি এই মর্মে যে, আল্লাহর প্রতি কৃতজ্ঞ হও। যে কৃতজ্ঞ হয়, সে তো কেবল নিজ কল্যানের জন্যই কৃতজ্ঞ হয়। আর যে অকৃতজ্ঞ হয়, আল্লাহ অভাবমুক্ত, প্রশংসিত।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmcdlxxxii{যখন লোকমান উপদেশচ্ছলে তার পুত্রকে বললঃ হে বৎস, আল্লাহর সাথে শরীক করো না। নিশ্চয় আল্লাহর সাথে শরীক করা মহা অন্যায়।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmcdlxxxiii{আর আমি মানুষকে তার পিতা-মাতার সাথে সদ্ব্যবহারের জোর নির্দেশ দিয়েছি। তার মাতা তাকে কষ্টের পর কষ্ট করে গর্ভে ধারণ করেছে। তার দুধ ছাড়ানো দু বছরে হয়। নির্দেশ দিয়েছি যে, আমার প্রতি ও তোমার পিতা-মতার প্রতি কৃতজ্ঞ হও। অবশেষে আমারই নিকট ফিরে আসতে হবে।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmcdlxxxiv{পিতা-মাতা যদি তোমাকে আমার সাথে এমন বিষয়কে শরীক স্থির করতে পীড়াপীড়ি করে, যার জ্ঞান তোমার নেই; তবে তুমি তাদের কথা মানবে না এবং দুনিয়াতে তাদের সাথে সদ্ভাবে সহঅবস্থান করবে। যে আমার অভিমুখী হয়, তার পথ অনুসরণ করবে। অতঃপর তোমাদের প্রত্যাবর্তন আমারই দিকে এবং তোমরা যা করতে, আমি সে বিষয়ে তোমাদেরকে জ্ঞাত করবো।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmcdlxxxv{হে বৎস, কোন বস্তু যদি সরিষার দানা পরিমাণও হয় অতঃপর তা যদি থাকে প্রস্তর গর্ভে অথবা আকাশে অথবা ভূ-গর্ভে, তবে আল্লাহ তাও উপস্থিত করবেন। নিশ্চয় আল্লাহ গোপন ভেদ জানেন, সবকিছুর খবর রাখেন।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmcdlxxxvi{হে বৎস, নামায কায়েম কর, সৎকাজে আদেশ দাও, মন্দকাজে নিষেধ কর এবং বিপদাপদে সবর কর। নিশ্চয় এটা সাহসিকতার কাজ।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmcdlxxxvii{অহংকারবশে তুমি মানুষকে অবজ্ঞা করো না এবং পৃথিবীতে গর্বভরে পদচারণ করো না। নিশ্চয় আল্লাহ কোন দাম্ভিক অহংকারীকে পছন্দ করেন না।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmcdlxxxviii{পদচারণায় মধ্যবর্তিতা অবলম্বন কর এবং কন্ঠস্বর নীচু কর। নিঃসন্দেহে গাধার স্বরই সর্বাপেক্ষা অপ্রীতিকর।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmcdlxxxix{তোমরা কি দেখ না আল্লাহ নভোমন্ডল ও ভূ-মন্ডলে যাকিছু আছে, সবই তোমাদের কাজে নিয়োজিত করে দিয়েছেন এবং তোমাদের প্রতি তাঁর প্রকাশ্য ও অপ্রকাশ্য নেয়ামতসমূহ পরিপূর্ন করে দিয়েছেন? এমন লোক ও আছে; যারা জ্ঞান, পথনির্দেশ ও উজ্জল কিতাব ছাড়াই আল্লাহ সম্পর্কে বাকবিতন্ডা করে।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmcdxc{তাদেরকে যখন বলা হয়, আল্লাহ যা নাযিল করেছেন, তোমরা তার অনুসরণ কর, তখন তারা বলে, বরং আমরা আমাদের পূর্বপুরুষদেরকে যে বিষয়ের উপর পেয়েছি, তারই অনুসরণ করব। শয়তান যদি তাদেরকে জাহান্নামের শাস্তির দিকে দাওয়াত দেয়, তবুও কি?\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmcdxci{যে ব্যক্তি সৎকর্মপরায়ণ হয়ে স্বীয় মুখমন্ডলকে আল্লাহ অভিমূখী করে, সে এক মজবুত হাতল ধারণ করে, সকল কর্মের পরিণাম আল্লাহর দিকে।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmcdxcii{যে ব্যক্তি কুফরী করে তার কুফরী যেন আপনাকে চিন্তিত না করে। আমারই দিকে তাদের প্রত্যাবর্তন, অতঃপর আমি তাদের কর্ম সম্পর্কে তাদেরকে অবহিত করব। অন্তরে যা কিছু রয়েছে, সে সম্পর্কে আল্লাহ সবিশেষ পরিজ্ঞাত।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmcdxciii{আমি তাদেরকে স্বল্পকালের জন্যে ভোগবিলাস করতে দেব, অতঃপর তাদেরকে বাধ্য করব গুরুতর শাস্তি ভোগ করতে।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmcdxciv{আপনি যদি তাদেরকে জিজ্ঞেস করেন, নভোমন্ডল ও ভূ-মন্ডল কে সৃষ্টি করেছে? তারা অবশ্যই বলবে, আল্লাহ। বলুন, সকল প্রশংসাই আল্লাহর। বরং তাদের অধিকাংশই জ্ঞান রাখে না।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmcdxcv{নভোমন্ডল ও ভূ-মন্ডলে যা কিছু রয়েছে সবই আল্লাহর। আল্লাহ অভাবমুক্ত, প্রশংসিত।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmcdxcvi{পৃথিবীতে যত বৃক্ষ আছে, সবই যদি কলম হয় এবং সমুদ্রের সাথেও সাত সমুদ্র যুক্ত হয়ে কালি হয়, তবুও তাঁর বাক্যাবলী লিখে শেষ করা যাবে না। নিশ্চয় আল্লাহ পরাক্রমশালী, প্রজ্ঞাময়।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmcdxcvii{তোমাদের সৃষ্টি ও পুনরুত্থান একটি মাত্র প্রাণীর সৃষ্টি ও পুনরুত্থানের সমান বৈ নয়। নিশ্চয় আল্লাহ সব কিছু শোনেন, সবকিছু দেখেন।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmcdxcviii{তুমি কি দেখ না যে, আল্লাহ রাত্রিকে দিবসে প্রবিষ্ট করেন এবং দিবসকে রাত্রিতে প্রবিষ্ট করেন? তিনি চন্দ্র ও সূর্যকে কাজে নিয়োজিত করেছেন। প্রত্যেকেই নির্দিষ্টকাল পর্যন্ত পরিভ্রমণ করে। তুমি কি আরও দেখ না যে, তোমরা যা কর, আল্লাহ তার খবর রাখেন?\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmcdxcix{এটাই প্রমাণ যে, আল্লাহ-ই সত্য এবং আল্লাহ ব্যতীত তারা যাদের পূজা করে সব মিথ্যা। আল্লাহ সর্বোচ্চ, মহান।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmd{তুমি কি দেখ না যে, আল্লাহর অনুগ্রহে জাহাজ সমুদ্রে চলাচল করে, যাতে তিনি তোমাদেরকে তাঁর নিদর্শনাবলী প্রদর্শন করেন? নিশ্চয় এতে প্রত্যেক সহনশীল, কৃতজ্ঞ ব্যক্তির জন্যে নিদর্শন রয়েছে।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmdi{যখন তাদেরকে মেঘমালা সদৃশ তরংগ আচ্ছাদিত করে নেয়, তখন তারা খাঁটি মনে আল্লাহকে ডাকতে থাকে। অতঃপর তিনি যখন তাদেরকে স্থলভাগের দিকে উদ্ধার করে আনেন, তখন তাদের কেউ কেউ সরল পথে চলে। কেবল মিথ্যাচারী, অকৃতজ্ঞ ব্যক্তিই আমার নিদর্শনাবলী অস্বীকার করে।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmdii{হে মানব জাতি! তোমরা তোমাদের পালনকর্তাকে ভয় কর এবং ভয় কর এমন এক দিবসকে, যখন পিতা পুত্রের কোন কাজে আসবে না এবং পুত্রও তার পিতার কোন উপকার করতে পারবে না। নিঃসন্দেহে আল্লাহর ওয়াদা সত্য। অতএব, পার্থিব জীবন যেন তোমাদেরকে ধোঁকা না দেয় এবং আল্লাহ সম্পর্কে প্রতারক শয়তানও যেন তোমাদেরকে প্রতারিত না করে।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmdiii{নিশ্চয় আল্লাহর কাছেই কেয়ামতের জ্ঞান রয়েছে। তিনিই বৃষ্টি বর্ষণ করেন এবং গর্ভাশয়ে যা থাকে, তিনি তা জানেন। কেউ জানে না আগামীকল্য সে কি উপার্জন করবে এবং কেউ জানে না কোন দেশে সে মৃত্যুবরণ করবে। আল্লাহ সর্বজ্ঞ, সর্ববিষয়ে সম্যক জ্ঞাত।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmdiv{\basmalahbn আলিফ-লাম-মীম।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmdv{এ কিতাবের অবতরণ বিশ্বপালনকর্তার নিকট থেকে এতে কোন সন্দেহ নেই।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmdvi{তারা কি বলে, এটা সে মিথ্যা রচনা করেছে? বরং এটা আপনার পালনকর্তার তরফ থেকে সত্য, যাতে আপনি এমন এক সম্প্রদায়কে সতর্ক করেন, যাদের কাছে আপনার পূর্বে কোন সতর্ককারী আসেনি। সম্ভবতঃ এরা সুপথ প্রাপ্ত হবে।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmdvii{আল্লাহ যিনি নভোমন্ডল, ভুমন্ডল ও এতদুভয়ের মধ্যবর্তী সবকিছু ছয় দিনে সৃষ্টি করেছেন, অতঃপর তিনি আরশে বিরাজমান হয়েছেন। তিনি ব্যতীত তোমাদের কোন অভিভাবক ও সুপারিশকারী নেই। এরপরও কি তোমরা বুঝবে না?\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmdviii{তিনি আকাশ থেকে পৃথিবী পর্যন্ত সমস্ত কর্ম পরিচালনা করেন, অতঃপর তা তাঁর কাছে পৌছবে এমন এক দিনে, যার পরিমাণ তোমাদের গণনায় হাজার বছরের সমান।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmdix{তিনিই দৃশ্য ও অদৃশ্যের জ্ঞানী, পরাক্রমশালী, পরম দয়ালু,\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmdx{যিনি তাঁর প্রত্যেকটি সৃষ্টিকে সুন্দর করেছেন এবং কাদামাটি থেকে মানব সৃষ্টির সূচনা করেছেন।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmdxi{অতঃপর তিনি তার বংশধর সৃষ্টি করেন তুচ্ছ পানির নির্যাস থেকে।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmdxii{অতঃপর তিনি তাকে সুষম করেন, তাতে রূহ সঞ্চার করেন এবং তোমাদেরকে দেন কর্ণ, চক্ষু ও অন্তঃকরণ। তোমরা সামান্যই কৃতজ্ঞতা প্রকাশ কর।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmdxiii{তারা বলে, আমরা মৃত্তিকায় মিশ্রিত হয়ে গেলেও পুনরায় নতুন করে সৃজিত হব কি? বরং তারা তাদের পালনকর্তার সাক্ষাতকে অস্বীকার করে।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmdxiv{বলুন, তোমাদের প্রাণ হরণের দায়িত্বে নিয়োজিত ফেরেশতা তোমাদের প্রাণ হরণ করবে। অতঃপর তোমরা তোমাদের পালনকর্তার কাছে প্রত্যাবর্তিত হবে।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmdxv{যদি আপনি দেখতেন যখন অপরাধীরা তাদের পালনকর্তার সামনে নতশির হয়ে বলবে, হে আমাদের পালনকর্তা, আমরা দেখলাম ও শ্রবণ করলাম। এখন আমাদেরকে পাঠিয়ে দিন, আমরা সৎকর্ম করব। আমরা দৃঢ়বিশ্বাসী হয়ে গেছি।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmdxvi{আমি ইচ্ছা করলে প্রত্যেককে সঠিক দিক নির্দেশ দিতাম; কিন্তু আমার এ উক্তি অবধারিত সত্য যে, আমি জিন ও মানব সকলকে দিয়ে অবশ্যই জাহান্নাম পূর্ণ করব।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmdxvii{অতএব এ দিবসকে ভূলে যাওয়ার কারণে তোমরা মজা আস্বাদন কর। আমিও তোমাদেরকে ভুলে গেলাম। তোমরা তোমাদের কৃতকর্মের কারণে স্থায়ী আযাব ভোগ কর।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmdxviii{কেবল তারাই আমার আয়াতসমূহের প্রতি ঈমান আনে, যারা আয়াতসমূহ দ্বারা উপদেশপ্রাপ্ত হয়ে সেজদায় লুটিয়ে পড়ে এবং অহংকারমুক্ত হয়ে তাদের পালনকর্তার সপ্রশংস পবিত্রতা বর্ণনা করে।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmdxix{তাদের পার্শ্ব শয্যা থেকে আলাদা থাকে। তারা তাদের পালনকর্তাকে ডাকে ভয়ে ও আশায় এবং আমি তাদেরকে যে রিযিক দিয়েছি, তা থেকে ব্যয় করে।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmdxx{কেউ জানে না তার জন্যে কৃতকর্মের কি কি নয়ন-প্রীতিকর প্রতিদান লুক্কায়িত আছে।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmdxxi{ঈমানদার ব্যক্তি কি অবাধ্যের অনুরূপ? তারা সমান নয়।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmdxxii{যারা ঈমান আনে ও সৎকর্ম করে, তাদের জন্যে রয়েছে তাদের কৃতকর্মের আপ্যায়নস্বরূপ বসবাসের জান্নাত।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmdxxiii{পক্ষান্তরে যারা অবাধ্য হয়, তাদের ঠিকানা জাহান্নাম। যখনই তারা জাহান্নাম থেকে বের হতে চাইবে, তখনই তাদেরকে তথায় ফিরিয়ে দেয়া হবে এবং তাদেরকে বলা হবে, তোমরা জাহান্নামের যে আযাবকে মিথ্যা বলতে, তার স্বাদ আস্বাদন কর।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmdxxiv{গুরু শাস্তির পূর্বে আমি অবশ্যই তাদেরকে লঘু শাস্তি আস্বাদন করাব, যাতে তারা প্রত্যাবর্তন করে।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmdxxv{যে ব্যক্তিকে তার পালনকর্তার আয়াতসমূহ দ্বারা উপদেশ দান করা হয়, অতঃপর সে তা থেকে মুখ ফিরিয়ে নেয়, তার চেয়ে যালেম আর কে? আমি অপরাধীদেরকে শাস্তি দেব।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmdxxvi{আমি মূসাকে কিতাব দিয়েছি, অতএব আপনি কোরআন প্রাপ্তির বিষয়ে কোন সন্দেহ করবেন না। আমি একে বনী ইসরাঈলের জন্যে পথ প্রদর্শক করেছিলাম।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmdxxvii{তারা সবর করত বিধায় আমি তাদের মধ্য থেকে নেতা মনোনীত করেছিলাম, যারা আমার আদেশে পথ প্রদর্শন করত। তারা আমার আয়াতসমূহে দৃঢ় বিশ্বাসী ছিল।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmdxxviii{তারা যে বিষয়ে মত বিরোধ করছে, আপনার পালনকর্তাই কেয়ামতের দিন সে বিষয়ে তাদের মধ্যে ফয়সালা দেবেন।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmdxxix{এতে কি তাদের চোখ খোলেনি যে, আমি তাদের পূর্বে অনেক সম্প্রদায়কে ধ্বংস করেছি, যাদের বাড়ী-ঘরে এরা বিচরণ করে। অবশ্যই এতে নিদর্শনাবলী রয়েছে। তারা কি শোনে না?\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmdxxx{তারা কি লক্ষ্য করে না যে, আমি উষর ভূমিতে পানি প্রবাহিত করে শস্য উদগত করি, যা থেকে ভক্ষণ করে তাদের জন্তুরা এবং তারা কি দেখে না?\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmdxxxi{তারা বলে তোমরা সত্যবাদী হলে বল; কবে হবে এই ফয়সালা?\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmdxxxii{বলুন, ফয়সালার দিনে কাফেরদের ঈমান তাদের কোন কাজে আসবে না এবং তাদেরকে অবকাশ ও দেয়া হবে না।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmdxxxiii{অতএব আপনি তাদের থেকে মুখ ফিরিয়ে নিন এবং অপেক্ষা করুন, তারাও অপেক্ষা করছে।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmdxxxiv{\basmalahbn হে নবী! আল্লাহকে ভয় করুন এবং কাফের ও কপট বিশ্বাসীদের কথা মানবেন না। নিশ্চয় আল্লাহ সর্বজ্ঞ, প্রজ্ঞাময়।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmdxxxv{আপনার পালনকর্তার পক্ষ থেকে যা অবতীর্ণ হয়, আপনি তার অনুসরণ করুন। নিশ্চয় তোমরা যা কর, আল্লাহ সে বিষয়ে খবর রাখেন।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmdxxxvi{আপনি আল্লাহর উপর ভরসা করুন। কার্যনির্বাহীরূপে আল্লাহই যথেষ্ট।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmdxxxvii{আল্লাহ কোন মানুষের মধ্যে দুটি হৃদয় স্থাপন করেননি। তোমাদের স্ত্রীগণ যাদের সাথে তোমরা যিহার কর, তাদেরকে তোমাদের জননী করেননি এবং তোমাদের পোষ্যপুত্রদেরকে তোমাদের পুত্র করেননি। এগুলো তোমাদের মুখের কথা মাত্র। আল্লাহ ন্যায় কথা বলেন এবং পথ প্রদর্শন করেন।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmdxxxviii{তোমরা তাদেরকে তাদের পিতৃপরিচয়ে ডাক। এটাই আল্লাহর কাছে ন্যায়সঙ্গত। যদি তোমরা তাদের পিতৃ-পরিচয় না জান, তবে তারা তোমাদের ধর্মীয় ভাই ও বন্ধুরূপে গণ্য হবে। এ ব্যাপারে তোমাদের কোন বিচ্যুতি হলে তাতে তোমাদের কোন গোনাহ নেই, তবে ইচ্ছাকৃত হলে ভিন্ন কথা। আল্লাহ ক্ষমাশীল, পরম দয়ালু।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmdxxxix{নবী মুমিনদের নিকট তাদের নিজেদের অপেক্ষা অধিক ঘনিষ্ঠ এবং তাঁর স্ত্রীগণ তাদের মাতা। আল্লাহর বিধান অনুযায়ী মুমিন ও মুহাজিরগণের মধ্যে যারা আত্নীয়, তারা পরস্পরে অধিক ঘনিষ্ঠ। তবে তোমরা যদি তোমাদের বন্ধুদের প্রতি দয়া-দাক্ষিণ্য করতে চাও, করতে পার। এটা লওহে-মাহফুযে লিখিত আছে।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmdxl{যখন আমি পয়গম্বরগণের কাছ থেকে, আপনার কাছ থেকে এবং নূহ, ইব্রাহীম, মূসা ও মরিয়ম তনয় ঈসার কাছ থেকে অঙ্গীকার নিলাম এবং অঙ্গীকার নিলাম তাদের কাছ থেকে দৃঢ় অঙ্গীকার।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmdxli{সত্যবাদীদেরকে তাদের সত্যবাদিতা সম্পর্কে জিজ্ঞাসা করার জন্য। তিনি কাফেরদের জন্য যন্ত্রণাদায়ক শাস্তি প্রস্তুত রেখেছেন।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmdxlii{হে মুমিনগণ! তোমরা তোমাদের প্রতি আল্লাহর নেয়ামতের কথা স্মরণ কর, যখন শত্রুবাহিনী তোমাদের নিকটবর্তী হয়েছিল, অতঃপর আমি তাদের বিরুদ্ধে ঝঞ্চাবায়ু এবং এমন সৈন্যবাহিনী প্রেরণ করেছিলাম, যাদেরকে তোমরা দেখতে না। তোমরা যা কর, আল্লাহ তা দেখেন।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmdxliii{যখন তারা তোমাদের নিকটবর্তী হয়েছিল উচ্চ ভূমি ও নিম্নভূমি থেকে এবং যখন তোমাদের দৃষ্টিভ্রম হচ্ছিল, প্রাণ কন্ঠাগত হয়েছিল এবং তোমরা আল্লাহ সম্পর্কে নানা বিরূপ ধারণা পোষণ করতে শুরু করছিলে।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmdxliv{সে সময়ে মুমিনগণ পরীক্ষিত হয়েছিল এবং ভীষণভাবে প্রকম্পিত হচ্ছিল।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmdxlv{এবং যখন মুনাফিক ও যাদের অন্তরে রোগ ছিল তারা বলছিল, আমাদেরকে প্রদত্ত আল্লাহ ও রসূলের প্রতিশ্রুতি প্রতারণা বৈ নয়।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmdxlvi{এবং যখন তাদের একদল বলেছিল, হে ইয়াসরেববাসী, এটা টিকবার মত জায়গা নয়, তোমরা ফিরে চল। তাদেরই একদল নবীর কাছে অনুমতি প্রার্থনা করে বলেছিল, আমাদের বাড়ী-ঘর খালি, অথচ সেগুলো খালি ছিল না, পলায়ন করাই ছিল তাদের ইচ্ছা।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmdxlvii{যদি শত্রুপক্ষ চতুর্দিক থেকে নগরে প্রবেশ করে তাদের সাথে মিলিত হত, অতঃপর বিদ্রোহ করতে প্ররোচিত করত, তবে তারা অবশ্যই বিদ্রোহ করত এবং তারা মোটেই বিলম্ব করত না।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmdxlviii{অথচ তারা পূর্বে আল্লাহর সাথে অঙ্গীকার করেছিল যে, তারা পৃষ্ঠ প্রদর্শন করবে না। আল্লাহর অঙ্গীকার সম্পর্কে জিজ্ঞাসা করা হবে।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmdxlix{বলুন! তোমরা যদি মৃত্যু অথবা হত্যা থেকে পলায়ন কর, তবে এ পলায়ন তোমাদের কাজে আসবে না। তখন তোমাদেরকে সামান্যই ভোগ করতে দেয়া হবে।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmdl{বলুন! কে তোমাদেরকে আল্লাহ থেকে রক্ষা করবে যদি তিনি তোমাদের অমঙ্গল ইচ্ছা করেন অথবা তোমাদের প্রতি অনুকম্পার ইচ্ছা? তারা আল্লাহ ব্যতীত নিজেদের কোন অভিভাবক ও সাহায্যদাতা পাবে না।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmdli{আল্লাহ খুব জানেন তোমাদের মধ্যে কারা তোমাদেরকে বাধা দেয় এবং কারা তাদের ভাইদেরকে বলে, আমাদের কাছে এস। তারা কমই যুদ্ধ করে।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmdlii{তারা তোমাদের প্রতি কুন্ঠাবোধ করে। যখন বিপদ আসে, তখন আপনি দেখবেন মৃত্যুভয়ে অচেতন ব্যক্তির মত চোখ উল্টিয়ে তারা আপনার প্রতি তাকায়। অতঃপর যখন বিপদ টলে যায় তখন তারা ধন-সম্পদ লাভের আশায় তোমাদের সাথে বাকচাতুরীতে অবতীর্ণ হয়। তারা মুমিন নয়। তাই আল্লাহ তাদের কর্মসমূহ নিস্ফল করে দিয়েছেন। এটা আল্লাহর জন্যে সহজ।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmdliii{তারা মনে করে শক্রবাহিনী চলে যায়নি। যদি শক্রবাহিনী আবার এসে পড়ে, তবে তারা কামনা করবে যে, যদি তারা গ্রামবাসীদের মধ্য থেকে তোমাদের সংবাদাদি জেনে নিত, তবেই ভাল হত। তারা তোমাদের মধ্যে অবস্থান করলেও যুদ্ধ সামান্যই করত।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmdliv{যারা আল্লাহ ও শেষ দিবসের আশা রাখে এবং আল্লাহকে অধিক স্মরণ করে, তাদের জন্যে রসূলুল্লাহর মধ্যে উত্তম নমুনা রয়েছে।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmdlv{যখন মুমিনরা শক্রবাহিনীকে দেখল, তখন বলল, আল্লাহ ও তাঁর রসূল এরই ওয়াদা আমাদেরকে দিয়েছিলেন এবং আল্লাহ ও তাঁর রসূল সত্য বলেছেন। এতে তাদের ঈমান ও আত্নসমর্পণই বৃদ্ধি পেল।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmdlvi{মুমিনদের মধ্যে কতক আল্লাহর সাথে কৃত ওয়াদা পূর্ণ করেছে। তাদের কেউ কেউ মৃত্যুবরণ করেছে এবং কেউ কেউ প্রতীক্ষা করছে। তারা তাদের সংকল্প মোটেই পরিবর্তন করেনি।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmdlvii{এটা এজন্য যাতে আল্লাহ, সত্যবাদীদেরকে তাদের সত্যবাদিতার কারণে প্রতিদান দেন এবং ইচ্ছা করলে মুনাফেকদেরকে শাস্তি দেন অথবা ক্ষমা করেন। নিশ্চয় আল্লাহ ক্ষমাশীল, পরম দয়ালু।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmdlviii{আল্লাহ কাফেরদেরকে ক্রুদ্ধাবস্থায় ফিরিয়ে দিলেন। তারা কোন কল্যাণ পায়নি। যুদ্ধ করার জন্য আল্লাহ মুমিনদের জন্যে যথেষ্ট হয়ে গেছেন। আল্লাহ শক্তিধর, পরাক্রমশালী।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmdlix{কিতাবীদের মধ্যে যারা কাফেরদের পৃষ্টপোষকতা করেছিল, তাদেরকে তিনি তাদের দূর্গ থেকে নামিয়ে দিলেন এবং তাদের অন্তরে ভীতি নিক্ষেপ করলেন। ফলে তোমরা একদলকে হত্যা করছ এবং একদলকে বন্দী করছ।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmdlx{তিনি তোমাদেরকে তাদের ভূমির, ঘর-বাড়ীর, ধন-সম্পদের এবং এমন এক ভূ-খন্ডের মালিক করে দিয়েছেন, যেখানে তোমরা অভিযান করনি। আল্লাহ সর্ববিষয়োপরি সর্বশক্তিমান।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmdlxi{হে নবী, আপনার পত্নীগণকে বলুন, তোমরা যদি পার্থিব জীবন ও তার বিলাসিতা কামনা কর, তবে আস, আমি তোমাদের ভোগের ব্যবস্থা করে দেই এবং উত্তম পন্থায় তোমাদের বিদায় নেই।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmdlxii{পক্ষান্তরে যদি তোমরা আল্লাহ, তাঁর রসূল ও পরকাল কামনা কর, তবে তোমাদের সৎকর্মপরায়ণদের জন্য আল্লাহ মহা পুরস্কার প্রস্তুত করে রেখেছেন।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmdlxiii{হে নবী পত্নীগণ! তোমাদের মধ্যে কেউ প্রকাশ্য অশ্লীল কাজ করলে তাকে দ্বিগুণ শাস্তি দেয়া হবে। এটা আল্লাহর জন্য সহজ।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmdlxiv{তোমাদের মধ্যে যে কেউ আল্লাহ ও তাঁর রসূলের অনুগত হবে এবং সৎকর্ম করবে, আমি তাকে দুবার পুরস্কার দেব এবং তার জন্য আমি সম্মান জনক রিযিক প্রস্তুত রেখেছি।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmdlxv{হে নবী পত্নীগণ! তোমরা অন্য নারীদের মত নও; যদি তোমরা আল্লাহকে ভয় কর, তবে পরপুরুষের সাথে কোমল ও আকর্ষনীয় ভঙ্গিতে কথা বলো না, ফলে সেই ব্যক্তি কুবাসনা করে, যার অন্তরে ব্যাধি রয়েছে তোমরা সঙ্গত কথাবার্তা বলবে।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmdlxvi{তোমরা গৃহাভ্যন্তরে অবস্থান করবে-মূর্খতা যুগের অনুরূপ নিজেদেরকে প্রদর্শন করবে না। নামায কায়েম করবে, যাকাত প্রদান করবে এবং আল্লাহ ও তাঁর রসূলের আনুগত্য করবে। হে নবী পরিবারের সদস্যবর্গ। আল্লাহ কেবল চান তোমাদের থেকে অপবিত্রতা দূর করতে এবং তোমাদেরকে পূর্ণরূপে পূত-পবিত্র রাখতে।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmdlxvii{আল্লাহর আয়াত ও জ্ঞানগর্ভ কথা, যা তোমাদের গৃহে পঠিত হয় তোমরা সেগুলো স্মরণ করবে। নিশ্চয় আল্লাহ সূক্ষ্নদর্শী, সর্ববিষয়ে খবর রাখেন।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmdlxviii{নিশ্চয় মুসলমান পুরুষ, মুসলমান নারী, ঈমানদার পুরুষ, ঈমানদার নারী, অনুগত পুরুষ, অনুগত নারী, সত্যবাদী পুরুষ, সত্যবাদী নারী, ধৈর্য্যশীল পুরুষ, ধৈর্য্যশীল নারী, বিনীত পুরুষ, বিনীত নারী, দানশীল পুরুষ, দানশীল নারী, রোযা পালণকারী পুরুষ, রোযা পালনকারী নারী, যৌনাঙ্গ হেফাযতকারী পুরুষ, , যৌনাঙ্গ হেফাযতকারী নারী, আল্লাহর অধিক যিকরকারী পুরুষ ও যিকরকারী নারী-তাদের জন্য আল্লাহ প্রস্তুত রেখেছেন ক্ষমা ও মহাপুরষ্কার।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmdlxix{আল্লাহ ও তাঁর রসূল কোন কাজের আদেশ করলে কোন ঈমানদার পুরুষ ও ঈমানদার নারীর সে বিষয়ে ভিন্ন ক্ষমতা নেই যে, আল্লাহ ও তাঁর রসূলের আদেশ অমান্য করে সে প্রকাশ্য পথভ্রষ্ট তায় পতিত হয়।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmdlxx{আল্লাহ যাকে অনুগ্রহ করেছেন; আপনিও যাকে অনুগ্রহ করেছেন; তাকে যখন আপনি বলেছিলেন, তোমার স্ত্রীকে তোমার কাছেই থাকতে দাও এবং আল্লাহকে ভয় কর। আপনি অন্তরে এমন বিষয় গোপন করছিলেন, যা আল্লাহ পাক প্রকাশ করে দেবেন আপনি লোকনিন্দার ভয় করেছিলেন অথচ আল্লাহকেই অধিক ভয় করা উচিত। অতঃপর যায়েদ যখন যয়নবের সাথে সম্পর্ক ছিন্ন করল, তখন আমি তাকে আপনার সাথে বিবাহবন্ধনে আবদ্ধ করলাম যাতে মুমিনদের পোষ্যপুত্ররা তাদের স্ত্রীর সাথে সম্পর্ক ছিন্ন করলে সেসব স্ত্রীকে বিবাহ করার ব্যাপারে মুমিনদের কোন অসুবিধা না থাকে। আল্লাহর নির্দেশ কার্যে পরিণত হয়েই থাকে।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmdlxxi{আল্লাহ নবীর জন্যে যা নির্ধারণ করেন, তাতে তাঁর কোন বাধা নেই পূর্ববর্তী নবীগণের ক্ষেত্রে এটাই ছিল আল্লাহর চিরাচরিত বিধান। আল্লাহর আদেশ নির্ধারিত, অবধারিত।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmdlxxii{সেই নবীগণ আল্লাহর পয়গাম প্রচার করতেন ও তাঁকে ভয় করতেন। তারা আল্লাহ ব্যতীত অন্যকাউকে ভয় করতেন না। হিসাব গ্রহণের জন্যে আল্লাহ যথেষ্ঠ।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmdlxxiii{মুহাম্মদ তোমাদের কোন ব্যক্তির পিতা নন; বরং তিনি আল্লাহর রাসূল এবং শেষ নবী। আল্লাহ সব বিষয়ে জ্ঞাত।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmdlxxiv{মুমিনগণ তোমরা আল্লাহকে অধিক পরিমাণে স্মরণ কর।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmdlxxv{এবং সকাল বিকাল আল্লাহর পবিত্রতা বর্ণনা কর।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmdlxxvi{তিনিই তোমাদের প্রতি রহমত করেন এবং তাঁর ফেরেশতাগণও রহমতের দোয়া করেন-অন্ধকার থেকে তোমাদেরকে আলোকে বের করার জন্য। তিনি মুমিনদের প্রতি পরম দয়ালু।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmdlxxvii{যেদিন আল্লাহর সাথে মিলিত হবে; সেদিন তাদের অভিবাদন হবে সালাম। তিনি তাদের জন্যে সম্মানজনক পুরস্কার প্রস্তুত রেখেছেন।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmdlxxviii{হে নবী! আমি আপনাকে সাক্ষী, সুসংবাদ দাতা ও সতর্ককারীরূপে প্রেরণ করেছি।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmmdlxxix{এবং আল্লাহর আদেশক্রমে তাঁর দিকে আহবায়করূপে এবং উজ্জ্বল প্রদীপরূপে।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmmdlxxx{আপনি মুমিনদেরকে সুসংবাদ দিন যে, তাদের জন্য আল্লাহর পক্ষ থেকে বিরাট অনুগ্রহ রয়েছে।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmmdlxxxi{আপনি কাফের ও মুনাফিকদের আনুগত্য করবেন না এবং তাদের উৎপীড়ন উপেক্ষা করুন ও আল্লাহর উপর ভরসা করুন। আল্লাহ কার্যনিবার্হীরূপে যথেষ্ট।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmmdlxxxii{মুমিনগণ! তোমরা যখন মুমিন নারীদেরকে বিবাহ কর, অতঃপর তাদেরকে স্পর্শ করার পূর্বে তালাক দিয়ে দাও, তখন তাদেরকে ইদ্দত পালনে বাধ্য করার অধিকার তোমাদের নাই। অতঃপর তোমরা তাদেরকে কিছু দেবে এবং উত্তম পন্থায় বিদায় দেবে।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmmdlxxxiii{হে নবী! আপনার জন্য আপনার স্ত্রীগণকে হালাল করেছি, যাদেরকে আপনি মোহরানা প্রদান করেন। আর দাসীদেরকে হালাল করেছি, যাদেরকে আল্লাহ আপনার করায়ত্ব করে দেন এবং বিবাহের জন্য বৈধ করেছি আপনার চাচাতো ভগ্নি, ফুফাতো ভগ্নি, মামাতো ভগ্নি, খালাতো ভগ্নিকে যারা আপনার সাথে হিজরত করেছে। কোন মুমিন নারী যদি নিজেকে নবীর কাছে সমর্পন করে, নবী তাকে বিবাহ করতে চাইলে সেও হালাল। এটা বিশেষ করে আপনারই জন্য-অন্য মুমিনদের জন্য নয়। আপনার অসুবিধা দূরীকরণের উদ্দেশে। মুমিনগণের স্ত্রী ও দাসীদের ব্যাপারে যা নির্ধারিত করেছি আমার জানা আছে। আল্লাহ ক্ষমাশীল, দয়ালু।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmmdlxxxiv{আপনি তাদের মধ্যে যাকে ইচ্ছা দূরে রাখতে পারেন এবং যাকে ইচ্ছা কাছে রাখতে পারেন। আপনি যাকে দূরে রেখেছেন, তাকে কামনা করলে তাতে আপনার কোন দোষ নেই। এতে অধিক সম্ভাবনা আছে যে, তাদের চক্ষু শীতল থাকবে; তারা দুঃখ পাবে না এবং আপনি যা দেন, তাতে তারা সকলেই সন্তুষ্ট থাকবে। তোমাদের অন্তরে যা আছে, আল্লাহ জানেন। আল্লাহ সর্বজ্ঞ, সহনশীল।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmmdlxxxv{এরপর আপনার জন্যে কোন নারী হালাল নয় এবং তাদের পরিবর্তে অন্য স্ত্রী গ্রহণ করাও হালাল নয় যদিও তাদের রূপলাবণ্য আপনাকে মুগ্ধ করে, তবে দাসীর ব্যাপার ভিন্ন। আল্লাহ সর্ব বিষয়ের উপর সজাগ নজর রাখেন।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmmdlxxxvi{হে মুমিনগণ! তোমাদেরকে অনুমতি দেয়া না হলে তোমরা খাওয়ার জন্য আহার্য রন্ধনের অপেক্ষা না করে নবীর গৃহে প্রবেশ করো না। তবে তোমরা আহুত হলে প্রবেশ করো, তবে অতঃপর খাওয়া শেষে আপনা আপনি চলে যেয়ো, কথাবার্তায় মশগুল হয়ে যেয়ো না। নিশ্চয় এটা নবীর জন্য কষ্টদায়ক। তিনি তোমাদের কাছে সংকোচ বোধ করেন; কিন্তু আল্লাহ সত্যকথা বলতে সংকোচ করেন না। তোমরা তাঁর পত্নীগণের কাছে কিছু চাইলে পর্দার আড়াল থেকে চাইবে। এটা তোমাদের অন্তরের জন্যে এবং তাঁদের অন্তরের জন্যে অধিকতর পবিত্রতার কারণ। আল্লাহর রাসূলকে কষ্ট দেয়া এবং তাঁর ওফাতের পর তাঁর পত্নীগণকে বিবাহ করা তোমাদের জন্য বৈধ নয়। আল্লাহর কাছে এটা গুরুতর অপরাধ।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmmdlxxxvii{তোমরা খোলাখুলি কিছু বল অথবা গোপন রাখ, আল্লাহ সর্ব বিষয়ে সর্বজ্ঞ।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmmdlxxxviii{নবী-পত্নীগণের জন্যে তাঁদের পিতা পুত্র, ভ্রাতা, ভ্রাতুস্পুত্র, ভগ্নি পুত্র, সহধর্মিনী নারী এবং অধিকার ভুক্ত দাসদাসীগণের সামনে যাওয়ার ব্যাপারে গোনাহ নেই। নবী-পত্নীগণ, তোমরা আল্লাহকে ভয় কর। নিশ্চয় আল্লাহ সর্ব বিষয় প্রত্যক্ষ করেন।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mmmdlxxxix{আল্লাহ ও তাঁর ফেরেশতাগণ নবীর প্রতি রহমত প্রেরণ করেন। হে মুমিনগণ! তোমরা নবীর জন্যে রহমতের তরে দোয়া কর এবং তাঁর প্রতি সালাম প্রেরণ কর।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mmmdxc{যারা আল্লাহ ও তাঁর রসূলকে কষ্ট দেয়, আল্লাহ তাদের প্রতি ইহকালে ও পরকালে অভিসম্পাত করেন এবং তাদের জন্যে প্রস্তুত রেখেছেন অবমাননাকর শাস্তি।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mmmdxci{যারা বিনা অপরাধে মুমিন পুরুষ ও মুমিন নারীদেরকে কষ্ট দেয়, তারা মিথ্যা অপবাদ ও প্রকাশ্য পাপের বোঝা বহন করে।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mmmdxcii{হে নবী! আপনি আপনার পত্নীগণকে ও কন্যাগণকে এবং মুমিনদের স্ত্রীগণকে বলুন, তারা যেন তাদের চাদরের কিয়দংশ নিজেদের উপর টেনে নেয়। এতে তাদেরকে চেনা সহজ হবে। ফলে তাদেরকে উত্যক্ত করা হবে না। আল্লাহ ক্ষমাশীল পরম দয়ালু।\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mmmdxciii{মুনাফিকরা এবং যাদের অন্তরে রোগ আছে এবং মদীনায় গুজব রটনাকারীরা যদি বিরত না হয়, তবে আমি অবশ্যই তাদের বিরুদ্ধে আপনাকে উত্তেজিত করব। অতঃপর এই শহরে আপনার প্রতিবেশী অল্পই থাকবে।\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mmmdxciv{অভিশপ্ত অবস্থায় তাদেরকে যেখানেই পাওয়া যাবে, ধরা হবে এবং প্রাণে বধ করা হবে।\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mmmdxcv{যারা পূর্বে অতীত হয়ে গেছে, তাদের ব্যাপারে এটাই ছিল আল্লাহর রীতি। আপনি আল্লাহর রীতিতে কখনও পরিবর্তন পাবেন না।\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mmmdxcvi{লোকেরা আপনাকে কেয়ামত সম্পর্কে জিজ্ঞাসা করে। বলুন, এর জ্ঞান আল্লাহর কাছেই। আপনি কি করে জানবেন যে সম্ভবতঃ কেয়ামত নিকটেই।\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mmmdxcvii{নিশ্চয় আল্লাহ কাফেরদেরকে অভিসম্পাত করেছেন এবং তাদের জন্যে জ্বলন্ত অগ্নি প্রস্তুত রেখেছেন।\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mmmdxcviii{তথায় তারা অনন্তকাল থাকবে এবং কোন অভিভাবক ও সাহায্যকারী পাবে না।\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mmmdxcix{যেদিন অগ্নিতে তাদের মুখমন্ডল ওলট পালট করা হবে; সেদিন তারা বলবে, হায়। আমরা যদি আল্লাহর আনুগত্য করতাম ও রসূলের আনুগত্য করতাম।\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mmmdc{তারা আরও বলবে, হে আমাদের পালনকর্তা, আমরা আমাদের নেতা ও বড়দের কথা মেনেছিলাম, অতঃপর তারা আমাদের পথভ্রষ্ট করেছিল।\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mmmdci{হে আমাদের পালনকর্তা! তাদেরকে দ্বিগুণ শাস্তি দিন এবং তাদেরকে মহা অভিসম্পাত করুন।\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mmmdcii{হে মুমিনগণ! মূসাকে যারা কষ্ট দিয়েছে, তোমরা তাদের মত হয়ো না। তারা যা বলেছিল, আল্লাহ তা থেকে তাঁকে নির্দোষ প্রমাণ করেছিলেন। তিনি আল্লাহর কাছে ছিলেন মর্যাদাবান।\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mmmdciii{হে মুমিনগণ! আল্লাহকে ভয় কর এবং সঠিক কথা বল।\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@mmmdciv{তিনি তোমাদের আমল-আচরণ সংশোধন করবেন এবং তোমাদের পাপসমূহ ক্ষমা করবেন। যে কেউ আল্লাহ ও তাঁর রসূলের আনুগত্য করে, সে অবশ্যই মহা সাফল্য অর্জন করবে।\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@mmmdcv{আমি আকাশ পৃথিবী ও পর্বতমালার সামনে এই আমানত পেশ করেছিলাম, অতঃপর তারা একে বহন করতে অস্বীকার করল এবং এতে ভীত হল; কিন্তু মানুষ তা বহণ করল। নিশ্চয় সে জালেম-অজ্ঞ।\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@mmmdcvi{যাতে আল্লাহ মুনাফিক পুরুষ, মুনাফিক নারী, মুশরিক পুরুষ, মুশরিক নারীদেরকে শাস্তি দেন এবং মুমিন পুরুষ ও মুমিন নারীদেরকে ক্ষমা করেন। আল্লাহ ক্ষমাশীল, পরম দয়ালু।\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@mmmdcvii{\basmalahbn সমস্ত প্রশংসা আল্লাহর, যিনি নভোমন্ডলে যা আছে এবং ভূমন্ডলে যা আছে সব কিছুর মালিক এবং তাঁরই প্রশংসা পরকালে। তিনি প্রজ্ঞাময়, সর্বজ্ঞ।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmdcviii{তিনি জানেন যা ভূগর্ভে প্রবেশ করে, যা সেখান থেকে নির্গত হয়, যা আকাশ থেকে বর্ষিত হয় এবং যা আকাশে উত্থিত হয়। তিনি পরম দয়ালু ক্ষমাশীল।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmdcix{কাফেররা বলে আমাদের উপর কেয়ামত আসবে না। বলুন কেন আসবে না? আমার পালনকর্তার শপথ-অবশ্যই আসবে। তিনি অদৃশ্য সম্পর্কে জ্ঞাত। নভোমন্ডলে ও ভূ-মন্ডলে তাঁর আগোচরে নয় অণু পরিমাণ কিছু, না তদপেক্ষা ক্ষুদ্র এবং না বৃহৎ-সমস্তই আছে সুস্পষ্ট কিতাবে।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmdcx{তিনি পরিণামে যারা মুমিন ও সৎকর্ম পরায়ণ, তাদেরকে প্রতিদান দেবেন। তাদের জন্য রয়েছে ক্ষমা ও সম্মান জনক রিযিক।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmdcxi{আর যারা আমার আয়াত সমূহকে ব্যর্থ করার জন্য উঠে পড়ে লেগে যায়, তাদের জন্যে রয়েছে যন্ত্রনাদায়ক শাস্তি।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmdcxii{যারা জ্ঞানপ্রাপ্ত, তারা আপনার পালনকর্তার নিকট থেকে অবর্তীর্ণ কোরআনকে সত্য জ্ঞান করে এবং এটা মানুষকে পরাক্রমশালী, প্রশংসার্হ আল্লাহর পথ প্রদর্শন করে।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmdcxiii{কাফেররা বলে, আমরা কি তোমাদেরকে এমন ব্যক্তির সন্ধান দেব, যে তোমাদেরকে খবর দেয় যে; তোমরা সম্পুর্ণ ছিন্ন-বিচ্ছিন্ন হয়ে গেলেও তোমরা নতুন সৃজিত হবে।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmdcxiv{সে আল্লাহ সম্পর্কে মিথ্যা বলে, না হয় সে উম্মাদ এবং যারা পরকালে অবিশ্বাসী, তারা আযাবে ও ঘোর পথভ্রষ্টতায় পতিত আছে।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmdcxv{তারা কি তাদের সামনের ও পশ্চাতের আকাশ ও পৃথিবীর প্রতিলক্ষ্য করে না? আমি ইচ্ছা করলে তাদের সহ ভূমি ধসিয়ে দেব অথবা আকাশের কোন খন্ড তাদের উপর পতিত করব। আল্লাহ অভিমুখী প্রত্যেক বান্দার জন্য এতে অবশ্যই নিদর্শন রয়েছে।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmdcxvi{আমি দাউদের প্রতি অনুগ্রহ করেছিলাম এই আদেশ মর্মে যে, হে পর্বতমালা, তোমরা দাউদের সাথে আমার পবিত্রতা ঘোষণা কর এবং হে পক্ষী সকল, তোমরাও। আমি তাঁর জন্য লৌহকে নরম করে ছিলাম।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmdcxvii{এবং তাকে আমি বলে ছিলাম, প্রশস্ত বর্ম তৈরী কর, কড়াসমূহ যথাযথভাবে সংযুক্ত কর এবং সৎকর্ম সম্পাদন কর। তোমরা যা কিছু কর, আমি তা দেখি।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmdcxviii{আর আমি সোলায়মানের অধীন করেছিলাম বায়ুকে, যা সকালে এক মাসের পথ এবং বিকালে এক মাসের পথ অতিক্রম করত। আমি তার জন্যে গলিত তামার এক ঝরণা প্রবাহিত করেছিলাম। কতক জিন তার সামনে কাজ করত তার পালনকর্তার আদেশে। তাদের যে কেউ আমার আদেশ অমান্য করবে, আমি জ্বলন্ত অগ্নির-শাস্তি আস্বাদন করাব।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmdcxix{তারা সোলায়মানের ইচ্ছানুযায়ী দুর্গ, ভাস্কর্য, হাউযসদৃশ বৃহদাকার পাত্র এবং চুল্লির উপর স্থাপিত বিশাল ডেগ নির্মাণ করত। হে দাউদ পরিবার! কৃতজ্ঞতা সহকারে তোমরা কাজ করে যাও। আমার বান্দাদের মধ্যে অল্পসংখ্যকই কৃতজ্ঞ।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmdcxx{যখন আমি সোলায়মানের মৃত্যু ঘটালাম, তখন ঘুণ পোকাই জিনদেরকে তাঁর মৃত্যু সম্পর্কে অবহিত করল। সোলায়মানের লাঠি খেয়ে যাচ্ছিল। যখন তিনি মাটিতে পড়ে গেলেন, তখন জিনেরা বুঝতে পারল যে, অদৃশ্য বিষয়ের জ্ঞান থাকলে তারা এই লাঞ্ছনাপূর্ণ শাস্তিতে আবদ্ধ থাকতো না।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmdcxxi{সাবার অধিবাসীদের জন্যে তাদের বাসভূমিতে ছিল এক নিদর্শন-দুটি উদ্যান, একটি ডানদিকে, একটি বামদিকে। তোমরা তোমাদের পালনকর্তার রিযিক খাও এবং তাঁর প্রতি কৃতজ্ঞতা প্রকাশ কর। স্বাস্থ্যকর শহর এবং ক্ষমাশীল পালনকর্তা।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmdcxxii{অতঃপর তারা অবাধ্যতা করল ফলে আমি তাদের উপর প্রেরণ করলাম প্রবল বন্যা! আর তাদের উদ্যানদ্বয়কে পরিবর্তন করে দিলাম এমন দুই উদ্যানে, যাতে উদগত হয় বিস্বাদ ফলমূল, ঝাউ গাছ এবং সামান্য কুলবৃক্ষ।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmdcxxiii{এটা ছিল কুফরের কারণে তাদের প্রতি আমার শাস্তি। আমি অকৃতজ্ঞ ব্যতীত কাউকে শাস্তি দেই না।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmdcxxiv{তাদের এবং যেসব জনপদের লোকদের প্রতি আমি অনুগ্রহ করেছিলম সেগুলোর মধ্যবর্তী স্থানে অনেক দৃশ্যমান জনপদ স্থাপন করেছিলাম এবং সেগুলোতে ভ্রমণ নির্ধারিত করেছিলাম। তোমরা এসব জনপদে রাত্রে ও দিনে নিরাপদে ভ্রমণ কর।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmdcxxv{অতঃপর তারা বলল, হে আমাদের পালনকর্তা, আমাদের ভ্রমণের পরিসর বাড়িয়ে দাও। তারা নিজেদের প্রতি জুলুম করেছিল। ফলে আমি তাদেরকে উপাখ্যানে পরিণত করলাম এবং সম্পূর্ণরূপে ছিন্ন-বিচ্ছিন্ন করে দিলাম। নিশ্চয় এতে প্রত্যেক ধৈর্যশীল কৃতজ্ঞের জন্যে নিদর্শনাবলী রয়েছে।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmdcxxvi{আর তাদের উপর ইবলীস তার অনুমান সত্য হিসেবে প্রতিষ্ঠিত করল। ফলে তাদের মধ্যে মুমিনদের একটি দল ব্যতীত সকলেই তার পথ অনুসরণ করল।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmdcxxvii{তাদের উপর শয়তানের কোন ক্ষমতা ছিল না, তবে কে পরকালে বিশ্বাস করে এবং কে তাতে সন্দেহ করে, তা প্রকাশ করাই ছিল আমার উদ্দেশ্য। আপনার পালনকর্তা সব বিষয়ে তত্ত্বাবধায়ক।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmdcxxviii{বলুন, তোমরা তাদেরকে আহবান কর, যাদেরকে উপাস্য মনে করতে আল্লাহ ব্যতীত। তারা নভোমন্ডল ও ভূ-মন্ডলের অনু পরিমাণ কোন কিছুর মালিক নয়, এতে তাদের কোন অংশও নেই এবং তাদের কেউ আল্লাহর সহায়কও নয়।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmdcxxix{যার জন্যে অনুমতি দেয়া হয়, তার জন্যে ব্যতীত আল্লাহর কাছে কারও সুপারিশ ফলপ্রসূ হবে না। যখন তাদের মন থেকে ভয়-ভীতি দূর হয়ে যাবে, তখন তারা পরস্পরে বলবে, তোমাদের পালনকর্তা কি বললেন? তারা বলবে, তিনি সত্য বলেছেন এবং তিনিই সবার উপরে মহান।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmdcxxx{বলুন, নভোমন্ডল ও ভূ-মন্ডল থেকে কে তোমাদের কে রিযিক দেয়। বলুন, আল্লাহ। আমরা অথবা তোমরা সৎপথে অথবা স্পষ্ট বিভ্রান্তিতে আছি ও আছ?\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmdcxxxi{বলুন, আমাদের অপরাধের জন্যে তোমরা জিজ্ঞাসিত হবে না এবং তোমরা যা কিছু কর, সে সম্পর্কে আমরা জিজ্ঞাসিত হব না।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmdcxxxii{বলুন, আমাদের পালনকর্তা আমাদেরকে সমবেত করবেন, অতঃপর তিনি আমাদের মধ্যে সঠিকভাবে ফয়সালা করবেন। তিনি ফয়সালাকারী, সর্বজ্ঞ।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmdcxxxiii{বলুন, তোমরা যাদেরকে আল্লাহর সাথে অংশীদাররূপে সংযুক্ত করেছ, তাদেরকে এনে আমাকে দেখাও। বরং তিনিই আল্লাহ, পরাক্রমশীল, প্রজ্ঞাময়।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmdcxxxiv{আমি আপনাকে সমগ্র মানবজাতির জন্যে সুসংবাদাতা ও সতর্ককারী রূপে পাঠিয়েছি; কিন্তু অধিকাংশ মানুষ তা জানে না।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmdcxxxv{তারা বলে, তোমরা যদি সত্যবাদী হও, তবে বল, এ ওয়াদা কখন বাস্তবায়িত হবে?\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmdcxxxvi{বলুন, তোমাদের জন্যে একটি দিনের ওয়াদা রয়েছে যাকে তোমরা এক মহূর্তও বিলম্বিত করতে পারবে না এবং ত্বরান্বিত ও করতে পারবে না।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmdcxxxvii{কাফেররা বলে, আমরা কখনও এ কোরআনে বিশ্বাস করব না এবং এর পূর্ববর্তী কিতাবেও নয়। আপনি যদি পাপিষ্ঠদেরকে দেখতেন, যখন তাদেরকে তাদের পালনকর্তার সামনে দাঁড় করানো হবে, , তখন তারা পরস্পর কথা কাটাকাটি করবে। যাদেরকে দুর্বল মনে করা হত, তারা অহংকারীদেরকে বলবে, তোমরা না থাকলে আমরা অবশ্যই মুমিন হতাম।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmdcxxxviii{অহংকারীরা দুর্বলকে বলবে, তোমাদের কাছে হেদায়েত আসার পর আমরা কি তোমাদেরকে বাধা দিয়েছিলাম? বরং তোমরাই তো ছিলে অপরাধী।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmdcxxxix{দুর্বলরা অহংকারীদেরকে বলবে, বরং তোমরাই তো দিবারাত্রি চক্রান্ত করে আমাদেরকে নির্দেশ দিতে যেন আমরা আল্লাহকে না মানি এবং তাঁর অংশীদার সাব্যস্ত করি তারা যখন শাস্তি দেখবে, তখন মনের অনুতাপ মনেই রাখবে। বস্তুতঃ আমি কাফেরদের গলায় বেড়ী পরাব। তারা সে প্রতিফলই পেয়ে থাকে যা তারা করত।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmdcxl{কোন জনপদে সতর্ককারী প্রেরণ করা হলেই তার বিত্তশালী অধিবাসীরা বলতে শুরু করেছে, তোমরা যে বিষয়সহ প্রেরিত হয়েছ, আমরা তা মানি না।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmdcxli{তারা আরও বলেছে, আমরা ধনে-জনে সমৃদ্ধ, সুতরাং আমরা শাস্তিপ্রাপ্ত হব না।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmdcxlii{বলুন, আমার পালনকর্তা যাকে ইচ্ছা রিযিক বাড়িয়ে দেন এবং পরিমিত দেন। কিন্তু অধিকাংশ মানুষ তা বোঝে না।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmdcxliii{তোমাদের ধন-সম্পদ ও সন্তান-সন্ততি তোমাদেরকে আমার নিকটবর্তী করবে না। তবে যারা বিশ্বাস স্থাপন করে ও সৎকর্ম করে, তারা তাদের কর্মের বহুগুণ প্রতিদান পাবে এবং তারা সুউচ্চ প্রাসাদে নিরাপদে থাকবে।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmdcxliv{আর যারা আমার আয়াতসমূহকে ব্যর্থ করার অপপ্রয়াসে লিপ্ত হয়, তাদেরকে আযাবে উপস্থিত করা হবে।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmdcxlv{বলুন, আমার পালনকর্তা তাঁর বান্দাদের মধ্যে যাকে ইচ্ছা রিযিক বাড়িয়ে দেন এবং সীমিত পরিমাণে দেন। তোমরা যা কিছু ব্যয় কর, তিনি তার বিনিময় দেন। তিনি উত্তম রিযিক দাতা।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmdcxlvi{যেদিন তিনি তাদের সবাইকে একত্রিত করবেন এবং ফেরেশতাদেরকে বলবেন, এরা কি তোমাদেরই পূজা করত?\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmdcxlvii{ফেরেশতারা বলবে, আপনি পবিত্র, আমরা আপনার পক্ষে, তাদের পক্ষে নই, বরং তারা জিনদের পূজা করত। তাদের অধিকাংশই শয়তানে বিশ্বাসী।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmdcxlviii{অতএব আজকের দিনে তোমরা একে অপরের কোন উপকার ও অপকার করার অধিকারী হবে না আর আমি জালেমদেরকে বলব, তোমরা আগুনের যে শাস্তিকে মিথ্যা বলতে তা আস্বাদন কর।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmdcxlix{যখন তাদের কাছে আমার সুস্পষ্ট আয়াত সমূহ তেলাওয়াত করা হয়, তখন তারা বলে, তোমাদের বাপ-দাদারা যার এবাদত করত এ লোকটি যে তা থেকে তোমাদেরকে বাধা দিতে চায়। তারা আরও বলে, এটা মনগড়া মিথ্যা বৈ নয়। আর কাফেরদের কাছে যখন সত্য আগমন করে, তখন তারা বলে, এতো এক সুস্পষ্ট যাদু।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmdcl{আমি তাদেরকে কোন কিতাব দেইনি, যা তারা অধ্যয়ন করবে এবং আপনার পূর্বে তাদের কাছে কোন সতর্ককারী প্রেরণ করিনি।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmdcli{তাদের পূর্ববর্তীরাও মিথ্যা আরোপ করেছে। আমি তাদেরকে যা দিয়েছিলাম, এরা তার এক দশমাংশও পায়নি। এরপরও তারা আমার রাসূলগনকে মিথ্যা বলেছে। অতএব কেমন হয়েছে আমার শাস্তি।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmmdclii{বলুন, আমি তোমাদেরকে একটি বিষয়ে উপদেশ দিচ্ছিঃ তোমরা আল্লাহর নামে এক একজন করে ও দু, দু জন করে দাঁড়াও, অতঃপর চিন্তা-ভাবনা কর-তোমাদের সঙ্গীর মধ্যে কোন উম্মাদনা নেই। তিনি তো আসন্ন কাঠোর শাস্তি সম্পর্কে তোমাদেরকে সতর্ক করেন মাত্র।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmmdcliii{বলুন, আমি তোমাদের কাছে কোন পারিশ্রমিক চাই না বরং তা তোমরাই রাখ। আমার পুরস্কার তো আল্লাহর কাছে রয়েছে। প্রত্যেক বস্তুই তাঁর সামনে।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmmdcliv{বলুন, আমার পালনকর্তা সত্য দ্বীন অবতরণ করেছেন। তিনি আলেমুল গায়ব।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmmdclv{বলুন, সত্য আগমন করেছে এবং অসত্য না পারে নতুন কিছু সৃজন করতে এবং না পারে পূনঃ প্রত্যাবর্তিত হতে।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmmdclvi{বলুন, আমি পথভ্রষ্ট হলে নিজের ক্ষতির জন্যেই পথভ্রষ্ট হব; আর যদি আমি সৎপথ প্রাপ্ত হই, তবে তা এ জন্যে যে, আমার পালনকর্তা আমার প্রতি ওহী প্রেরণ করেন। নিশ্চয় তিনি সর্বশ্রোতা, নিকটবর্তী।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmmdclvii{যদি আপনি দেখতেন, যখন তারা ভীতসস্ত্রস্ত হয়ে পড়বে, অতঃপর পালিয়েও বাঁচতে পারবে না এবং নিকটবর্তী স্থান থেকে ধরা পড়বে।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmmdclviii{তারা বলবে, আমরা সত্যে বিশ্বাস স্থাপন করলাম। কিন্তু তারা এতদূর থেকে তার নাগাল পাবে কেমন করে?\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmmdclix{অথচ তারা পূর্ব থেকে সত্যকে অস্বীকার করছিল। আর তারা সত্য হতে দূরে থেকে অজ্ঞাত বিষয়ের উপর মন্তব্য করত।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmmdclx{তাদের ও তাদের বাসনার মধ্যে অন্তরাল হয়ে গেছে, যেমন-তাদের সতীর্থদের সাথেও এরূপ করা হয়েছে, যারা তাদের পূর্বে ছিল। তারা ছিল বিভ্রান্তিকর সন্দেহে পতিত।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmmdclxi{\basmalahbn সমস্ত প্রশংসা আল্লাহর, যিনি আসমান ও যমীনের স্রষ্টা এবং ফেরেশতাগণকে করেছেন বার্তাবাহক-তারা দুই দুই, তিন তিন ও চার চার পাখাবিশিষ্ট। তিনি সৃষ্টি মধ্যে যা ইচ্ছা যোগ করেন। নিশ্চয় আল্লাহ সর্ববিষয়ে সক্ষম।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmdclxii{আল্লাহ মানুষের জন্য অনুগ্রহের মধ্য থেকে যা খুলে দেন, তা ফেরাবার কেউ নেই এবং তিনি যা বারণ করেন, তা কেউ প্রেরণ করতে পারে না তিনি ব্যতিত। তিনি পরাক্রমশালী প্রজ্ঞাময়।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmdclxiii{হে মানুষ, তোমাদের প্রতি আল্লাহর অনুগ্রহ স্মরণ কর। আল্লাহ ব্যতীত এমন কোন স্রষ্টা আছে কি, যে তোমাদেরকে আসমান ও যমীন থেকে রিযিক দান করে? তিনি ব্যতীত কোন উপাস্য নেই। অতএব তোমরা কোথায় ফিরে যাচ্ছ?\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmdclxiv{তারা যদি আপনাকে মিথ্যাবাদী বলে, তবে আপনার পূর্ববর্তী পয়গম্বরগণকেও তো মিথ্যাবাদী বলা হয়েছিল। আল্লাহর প্রতিই যাবতীয় বিষয় প্রত্যাবর্তিত হয়।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmdclxv{হে মানুষ, নিশ্চয় আল্লাহর ওয়াদা সত্য। সুতরাং, পার্থিব জীবন যেন তোমাদেরকে প্রতারণা না করে। এবং সেই প্রবঞ্চক যেন কিছুতেই তোমাদেরকে আল্লাহ সম্পর্কে প্রবঞ্চিত না করে।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmdclxvi{শয়তান তোমাদের শত্রু; অতএব তাকে শত্রু রূপেই গ্রহণ কর। সে তার দলবলকে আহবান করে যেন তারা জাহান্নামী হয়।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmdclxvii{যারা কুফর করে তাদের জন্যে রয়েছে কঠোর আযাব। আর যারা ঈমান আনে ও সৎকর্ম করে, তাদের জন্যে রয়েছে ক্ষমা ও মহা পুরস্কার।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmdclxviii{যাকে মন্দকর্ম শোভনীয় করে দেখানো হয়, সে তাকে উত্তম মনে করে, সে কি সমান যে মন্দকে মন্দ মনে করে। নিশ্চয় আল্লাহ যাকে ইচ্ছা পথভ্রষ্ট করেন এবং যাকে ইচছা সৎপথ প্রদর্শন করেন। সুতরাং আপনি তাদের জন্যে অনুতাপ করে নিজেকে ধ্বংস করবেন না। নিশ্চয়ই আল্লাহ জানেন তারা যা করে।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmdclxix{আল্লাহই বায়ু প্রেরণ করেন, অতঃপর সে বায়ু মেঘমালা সঞ্চারিত করে। অতঃপর আমি তা মৃত ভূ-খন্ডের দিকে পরিচালিত করি, অতঃপর তদ্বারা সে ভূ-খন্ডকে তার মৃত্যুর পর সঞ্জীবিত করে দেই। এমনিভাবে হবে পুনরুত্থান।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmdclxx{কেউ সম্মান চাইলে জেনে রাখুন, সমস্ত সম্মান আল্লাহরই জন্যে। তাঁরই দিকে আরোহণ করে সৎবাক্য এবং সৎকর্ম তাকে তুলে নেয়। যারা মন্দ কার্যের চক্রান্তে লেগে থাকে, তাদের জন্যে রয়েছে কঠোর শাস্তি। তাদের চক্রান্ত ব্যর্থ হবে।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmdclxxi{আল্লাহ তোমাদেরকে সৃষ্টি করেছেন মাটি থেকে, অতঃপর বীর্য থেকে, তারপর করেছেন তোমাদেরকে যুগল। কোন নারী গর্ভধারণ করে না এবং সন্তান প্রসব করে না; কিন্তু তাঁর জ্ঞাতসারে। কোন বয়স্ক ব্যক্তি বয়স পায় না। এবং তার বয়স হ্রাস পায় না; কিন্তু তা লিখিত আছে কিতাবে। নিশ্চয় এটা আল্লাহর পক্ষে সহজ।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmdclxxii{দু’টি সমুদ্র সমান হয় না-একটি মিঠা ও তৃষ্ণানিবারক এবং অপরটি লোনা। ঊভয়টি থেকেই তোমরা তাজা গোশত (মৎস) আহার কর এবং পরিধানে ব্যবহার্য গয়নাগাটি আহরণ কর। তুমি তাতে তার বুক চিরে জাহাজ চলতে দেখ, যাতে তোমরা তার অনুগ্রহ অন্বেষণ কর এবং যাতে তোমরা কৃতজ্ঞতা প্রকাশ কর।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmdclxxiii{তিনি রাত্রিকে দিবসে প্রবিষ্ট করেন এবং দিবসকে রাত্রিতে প্রবিষ্ট করেন। তিনি সূর্য ও চন্দ্রকে কাজে নিয়োজিত করেছেন। প্রত্যেকটি আবর্তন করে এক নির্দিষ্ট মেয়াদ পর্যন্ত। ইনি আল্লাহ; তোমাদের পালনকর্তা, সাম্রাজ্য তাঁরই। তাঁর পরিবর্তে তোমরা যাদেরকে ডাক, তারা তুচ্ছ খেজুর আঁটিরও অধিকারী নয়।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmdclxxiv{তোমরা তাদেরকে ডাকলে তারা তোমাদের সে ডাক শুনে না। শুনলেও তোমাদের ডাকে সাড়া দেয় না। কেয়ামতের দিন তারা তোমাদের শেরক অস্বীকার করবে। বস্তুতঃ আল্লাহর ন্যায় তোমাকে কেউ অবহিত করতে পারবে না।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmdclxxv{হে মানুষ, তোমরা আল্লাহর গলগ্রহ। আর আল্লাহ; তিনি অভাবমুক্ত, প্রশংসিত।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmdclxxvi{তিনি ইচ্ছা করলে তোমাদেরকে বিলুপ্ত করে এক নতুন সৃষ্টির উদ্ভব করবেন।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmdclxxvii{এটা আল্লাহর পক্ষে কঠিন নয়।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmdclxxviii{কেউ অপরের বোঝা বহন করবে না। কেউ যদি তার গুরুতর ভার বহন করতে অন্যকে আহবান করে কেউ তা বহন করবে না-যদি সে নিকটবর্তী আত্নীয়ও হয়। আপনি কেবল তাদেরকে সতর্ক করেন, যারা তাদের পালনকর্তাকে না দেখেও ভয় করে এবং নামায কায়েম করে। যে কেউ নিজের সংশোধন করে, সে সংশোধন করে, স্বীয় কল্যাণের জন্যেই আল্লাহর নিকটই সকলের প্রত্যাবর্তন।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmdclxxix{দৃষ্টিমান ও দৃষ্টিহীন সমান নয়।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmdclxxx{সমান নয় অন্ধকার ও আলো।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmdclxxxi{সমান নয় ছায়া ও তপ্তরোদ।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmdclxxxii{আরও সমান নয় জীবিত ও মৃত। আল্লাহ শ্রবণ করান যাকে ইচ্ছা। আপনি কবরে শায়িতদেরকে শুনাতে সক্ষম নন।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmdclxxxiii{আপনি তো কেবল একজন সতর্ককারী।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmdclxxxiv{আমি আপনাকে সত্যধর্মসহ পাঠিয়েছি সংবাদদাতা ও সতর্ককারীরূপে। এমন কোন সম্প্রদায় নেই যাতে সতর্ককারী আসেনি।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmdclxxxv{তারা যদি আপনার প্রতি মিথ্যারোপ করে, তাদের পূর্ববর্তীরাও মিথ্যারোপ করেছিল। তাদের কাছে তাদের রসূলগণ স্পষ্ট নিদর্শন, সহীফা এবং উজ্জল কিতাবসহ এসেছিলেন।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmdclxxxvi{অতঃপর আমি কাফেরদেরকে ধৃত করেছিলাম। কেমন ছিল আমার আযাব!\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmdclxxxvii{তুমি কি দেখনি আল্লাহ আকাশ থেকে বৃষ্টিবর্ষণ করেন, অতঃপর তদ্দ্বারা আমি বিভিন্ন বর্ণের ফল-মূল উদগত করি। পর্বতসমূহের মধ্যে রয়েছে বিভিন্ন বর্ণের গিরিপথ-সাদা, লাল ও নিকষ কালো কৃষ্ণ।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmdclxxxviii{অনুরূপ ভাবে বিভিন্ন বর্ণের মানুষ, জন্তু, চতুস্পদ প্রাণী রয়েছে। আল্লাহর বান্দাদের মধ্যে জ্ঞানীরাই কেবল তাঁকে ভয় করে। নিশ্চয় আল্লাহ পরাক্রমশালী ক্ষমাময়।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmdclxxxix{যারা আল্লাহর কিতাব পাঠ করে, নামায কায়েম করে, এবং আমি যা দিয়েছি, তা থেকে গোপনে ও প্রকাশ্যে ব্যয় করে, তারা এমন ব্যবসা আশা কর, যাতে কখনও লোকসান হবে না।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmdcxc{পরিণামে তাদেরকে আল্লাহ তাদের সওয়াব পুরোপুরি দেবেন এবং নিজ অনুগ্রহে আরও বেশী দেবেন। নিশ্চয় তিনি ক্ষমাশীল, গুণগ্রাহী।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmdcxci{আমি আপনার প্রতি যে কিতাব প্রত্যাদেশ করেছি, তা সত্য-পূর্ববর্তী কিতাবের সত্যায়ন কারী নিশ্চয় আল্লাহ তাঁর বান্দাদের ব্যাপারে সব জানেন, দেখেন।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmdcxcii{অতঃপর আমি কিতাবের অধিকারী করেছি তাদেরকে যাদেরকে আমি আমার বান্দাদের মধ্য থেকে মনোনীত করেছি। তাদের কেউ কেউ নিজের প্রতি অত্যাচারী, কেউ মধ্যপন্থা অবলম্বনকারী এবং তাদের মধ্যে কেউ কেউ আল্লাহর নির্দেশক্রমে কল্যাণের পথে এগিয়ে গেছে। এটাই মহা অনুগ্রহ।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmdcxciii{তারা প্রবেশ করবে বসবাসের জান্নাতে। তথায় তারা স্বর্ণনির্মিত, মোতি খচিত কংকন দ্বারা অলংকৃত হবে। সেখানে তাদের পোশাক হবে রেশমের।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmdcxciv{আর তারা বলবে-সমস্ত প্রশংসা আল্লাহর, যিনি আমাদের দূঃখ দূর করেছেন। নিশ্চয় আমাদের পালনকর্তা ক্ষমাশীল, গুণগ্রাহী।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmdcxcv{যিনি স্বীয় অনুগ্রহে আমাদেরকে বসবাসের গৃহে স্থান দিয়েছেন, তথায় কষ্ট আমাদেরকে স্পর্শ করে না এবং স্পর্শ করে না ক্লান্তি।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmdcxcvi{আর যারা কাফের হয়েছে, তাদের জন্যে রয়েছে জাহান্নামের আগুন। তাদেরকে মৃত্যুর আদেশও দেয়া হবে না যে, তারা মরে যাবে এবং তাদের থেকে তার শাস্তিও লাঘব করা হবে না। আমি প্রত্যেক অকৃতজ্ঞকে এভাবেই শাস্তি দিয়ে থাকি।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmdcxcvii{সেখানে তারা আর্ত চিৎকার করে বলবে, হে আমাদের পালনকর্তা, বের করুন আমাদেরকে, আমরা সৎকাজ করব, পূর্বে যা করতাম, তা করব না। (আল্লাহ বলবেন) আমি কি তোমাদেরকে এতটা বয়স দেইনি, যাতে যা চিন্তা করার বিষয় চিন্তা করতে পারতে? উপরন্তু তোমাদের কাছে সতর্ককারীও আগমন করেছিল। অতএব আস্বাদন কর। জালেমদের জন্যে কোন সাহায্যকারী নেই।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmdcxcviii{আল্লাহ আসমান ও যমীনের অদৃশ্য বিষয় সম্পর্কে জ্ঞাত। তিনি অন্তরের বিষয় সম্পর্কেও সবিশেষ অবহিত।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmdcxcix{তিনিই তোমাদেরকে পৃথিবীতে স্বীয় প্রতিনিধি করেছেন। অতএব যে কুফরী করবে তার কুফরী তার উপরই বর্তাবে। কাফেরদের কুফর কেবল তাদের পালনকর্তার ক্রোধই বৃদ্ধি করে এবং কাফেরদের কুফর কেবল তাদের ক্ষতিই বৃদ্ধি করে।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmdcc{বলুন, তোমরা কি তোমাদের সে শরীকদের কথা ভেবে দেখেছ, যাদেরকে আল্লাহর পরিবর্তে তোমরা ডাক? তারা পৃথিবীতে কিছু সৃষ্টি করে থাকলে আমাকে দেখাও। না আসমান সৃষ্টিতে তাদের কোন অংশ আছে, না আমি তাদেরকে কোন কিতাব দিয়েছি যে, তারা তার দলীলের উপর কায়েম রয়েছে, বরং জালেমরা একে অপরকে কেবল প্রতারণামূলক ওয়াদা দিয়ে থাকে।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmdcci{নিশ্চয় আল্লাহ আসমান ও যমীনকে স্থির রাখেন, যাতে টলে না যায়। যদি এগুলো টলে যায় তবে তিনি ব্যতীত কে এগুলোকে স্থির রাখবে? তিনি সহনশীল, ক্ষমাশীল।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmdccii{তারা জোর শপথ করে বলত, তাদের কাছে কোন সতর্ককারী আগমন করলে তারা অন্য যে কোন সম্প্রদায় অপেক্ষা অধিকতর সৎপথে চলবে। অতঃপর যখন তাদের কাছে সতর্ককারী আগমন করল, তখন তাদের ঘৃণাই কেবল বেড়ে গেল।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmdcciii{পৃথিবীতে ঔদ্ধত্যের কারণে এবং কুচক্রের কারণে। কুচক্র কুচক্রীদেরকেই ঘিরে ধরে। তারা কেবল পূর্ববর্তীদের দশারই অপেক্ষা করছে। অতএব আপনি আল্লাহর বিধানে পরিবর্তন পাবেন না এবং আল্লাহর রীতি-নীতিতে কোন রকম বিচ্যুতিও পাবেন না।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmdcciv{তারা কি পৃথিবীতে ভ্রমণ করে না? করলে দেখত তাদের পূর্ববর্তীদের কি পরিণাম হয়েছে। অথচ তারা তাদের অপেক্ষা অধিকতর শক্তিশালী ছিল। আকাশ ও পৃথিবীতে কোন কিছুই আল্লাহকে অপারগ করতে পারে না। নিশ্চয় তিনি সর্বজ্ঞ সর্বশক্তিমান।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmdccv{যদি আল্লাহ মানুষকে তাদের কৃতকর্মের কারণে পাকড়াও করতেন, তবে ভুপৃষ্ঠে চলমানকাউকে ছেড়ে দিতেন না। কিন্তু তিনি এক নির্দিষ্ট মেয়াদ পর্যন্ত তাদেরকে অবকাশ দেন। অতঃপর যখন সে নির্দিষ্ট মেয়াদ এসে যাবে তখন আল্লাহর সব বান্দা তাঁর দৃষ্টিতে থাকবে।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmmdccvi{\basmalahbn ইয়া-সীন\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmdccvii{প্রজ্ঞাময় কোরআনের কসম।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmdccviii{নিশ্চয় আপনি প্রেরিত রসূলগণের একজন।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmdccix{সরল পথে প্রতিষ্ঠিত।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmdccx{কোরআন পরাক্রমশালী পরম দয়ালু আল্লাহর তরফ থেকে অবতীর্ণ,\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmdccxi{যাতে আপনি এমন এক জাতিকে সতর্ক করেন, যাদের পূর্ব পুরুষগণকেও সতর্ক করা হয়নি। ফলে তারা গাফেল।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmdccxii{তাদের অধিকাংশের জন্যে শাস্তির বিষয় অবধারিত হয়েছে। সুতরাং তারা বিশ্বাস স্থাপন করবে না।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmdccxiii{আমি তাদের গর্দানে চিবুক পর্যন্ত বেড়ী পরিয়েছি। ফলে তাদের মস্তক উর্দ্ধমুখী হয়ে গেছে।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmdccxiv{আমি তাদের সামনে ও পিছনে প্রাচীর স্থাপন করেছি, অতঃপর তাদেরকে আবৃত করে দিয়েছি, ফলে তারা দেখে না।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmdccxv{আপনি তাদেরকে সতর্ক করুন বা না করুন, তাদের পক্ষে দুয়েই সমান; তারা বিশ্বাস স্থাপন করবে না।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmdccxvi{আপনি কেবল তাদেরকেই সতর্ক করতে পারেন, যারা উপদেশ অনুসরণ করে এবং দয়াময় আল্লাহকে না দেখে ভয় করে। অতএব আপনি তাদেরকে সুসংবাদ দিয়ে দিন ক্ষমা ও সম্মানজনক পুরস্কারের।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmdccxvii{আমিই মৃতদেরকে জীবিত করি এবং তাদের কর্ম ও কীর্তিসমূহ লিপিবদ্ধ করি। আমি প্রত্যেক বস্তু স্পষ্ট কিতাবে সংরক্ষিত রেখেছি।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmdccxviii{আপনি তাদের কাছে সে জনপদের অধিবাসীদের দৃষ্টান্ত বর্ণনা করুন, যখন সেখানে রসূল আগমন করেছিলেন।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmdccxix{আমি তাদের নিকট দুজন রসূল প্রেরণ করেছিলাম, অতঃপর ওরা তাদেরকে মিথ্যা প্রতিপন্ন করল। তখন আমি তাদেরকে শক্তিশালী করলাম তৃতীয় একজনের মাধ্যমে। তারা সবাই বলল, আমরা তোমাদের প্রতি প্রেরিত হয়েছি।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmdccxx{তারা বলল, তোমরা তো আমাদের মতই মানুষ, রহমান আল্লাহ কিছুই নাযিল করেননি। তোমরা কেবল মিথ্যাই বলে যাচ্ছ।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmdccxxi{রাসূলগণ বলল, আমাদের পরওয়ারদেগার জানেন, আমরা অবশ্যই তোমাদের প্রতি প্রেরিত হয়েছি।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmdccxxii{পরিস্কারভাবে আল্লাহর বাণী পৌছে দেয়াই আমাদের দায়িত্ব।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmdccxxiii{তারা বলল, আমরা তোমাদেরকে অশুভ-অকল্যাণকর দেখছি। যদি তোমরা বিরত না হও, তবে অবশ্যই তোমাদেরকে প্রস্তর বর্ষণে হত্যা করব এবং আমাদের পক্ষ থেকে তোমাদেরকে যন্ত্রনাদায়ক শাস্তি স্পর্শ করবে।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmdccxxiv{রসূলগণ বলল, তোমাদের অকল্যাণ তোমাদের সাথেই! এটা কি এজন্যে যে, আমরা তোমাদেরকে সদুপদেশ দিয়েছি? বস্তুতঃ তোমরা সীমা লংঘনকারী সম্প্রদায় বৈ নও।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmdccxxv{অতঃপর শহরের প্রান্তভাগ থেকে এক ব্যক্তি দৌড়ে এল। সে বলল, হে আমার সম্প্রদায় তোমরা রসূলগণের অনুসরণ কর।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmdccxxvi{অনুসরণ কর তাদের, যারা তোমাদের কাছে কোন বিনিময় কামনা করে না, অথচ তারা সুপথ প্রাপ্ত।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmdccxxvii{আমার কি হল যে, যিনি আমাকে সৃষ্টি করেছেন এবং যার কাছে তোমরা প্রত্যাবর্তিত হবে, আমি তাঁর এবাদত করব না?\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmdccxxviii{আমি কি তাঁর পরিবর্তে অন্যান্যদেরকে উপাস্যরূপে গ্রহণ করব? করুণাময় যদি আমাকে কষ্টে নিপতিত করতে চান, তবে তাদের সুপারিশ আমার কোনই কাজে আসবে না এবং তারা আমাকে রক্ষাও করতে পারবে না।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmdccxxix{এরূপ করলে আমি প্রকাশ্য পথভ্রষ্টতায় পতিত হব।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmdccxxx{আমি নিশ্চিতভাবে তোমাদের পালনকর্তার প্রতি বিশ্বাস স্থাপন করলাম। অতএব আমার কাছ থেকে শুনে নাও।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmdccxxxi{তাকে বলা হল, জান্নাতে প্রবেশ কর। সে বলল হায়, আমার সম্প্রদায় যদি কোন ক্রমে জানতে পারত-\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmdccxxxii{যে আমার পরওয়ারদেগার আমাকে ক্ষমা করেছেন এবং আমাকে সম্মানিতদের অন্তর্ভুক্ত করেছেন।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmdccxxxiii{তারপর আমি তার সম্প্রদায়ের উপর আকাশ থেকে কোন বাহিনী অবতীর্ণ করিনি এবং আমি (বাহিনী) অবতরণকারীও না।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmdccxxxiv{বস্তুতঃ এ ছিল এক মহানাদ। অতঃপর সঙ্গে সঙ্গে সবাই স্তদ্ধ হয়ে গেল।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmdccxxxv{বান্দাদের জন্যে আক্ষেপ যে, তাদের কাছে এমন কোন রসূলই আগমন করেনি যাদের প্রতি তারা বিদ্রুপ করে না।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmdccxxxvi{তারা কি প্রত্যক্ষ করে না, তাদের পূর্বে আমি কত সম্প্রদায়কে ধ্বংস করেছি যে, তারা তাদের মধ্যে আর ফিরে আসবে না।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmdccxxxvii{ওদের সবাইকে সমবেত অবস্থায় আমার দরবারে উপস্থিত হতেই হবে।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmdccxxxviii{তাদের জন্যে একটি নিদর্শন মৃত পৃথিবী। আমি একে সঞ্জীবিত করি এবং তা থেকে উৎপন্ন করি শস্য, তারা তা থেকে ভক্ষণ করে।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmdccxxxix{আমি তাতে সৃষ্টি করি খেজুর ও আঙ্গুরের বাগান এবং প্রবাহিত করি তাতে নির্ঝরিণী।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmdccxl{যাতে তারা তার ফল খায়। তাদের হাত একে সৃষ্টি করে না। অতঃপর তারা কৃতজ্ঞতা প্রকাশ করে না কেন?\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmdccxli{পবিত্র তিনি যিনি যমীন থেকে উৎপন্ন উদ্ভিদকে, তাদেরই মানুষকে এবং যা তারা জানে না, তার প্রত্যেককে জোড়া জোড়া করে সৃষ্টি করেছেন।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmdccxlii{তাদের জন্যে এক নিদর্শন রাত্রি, আমি তা থেকে দিনকে অপসারিত করি, তখনই তারা অন্ধকারে থেকে যায়।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmdccxliii{সূর্য তার নির্দিষ্ট অবস্থানে আবর্তন করে। এটা পরাক্রমশালী, সর্বজ্ঞ, আল্লাহর নিয়ন্ত্রণ।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmdccxliv{চন্দ্রের জন্যে আমি বিভিন্ন মনযিল নির্ধারিত করেছি। অবশেষে সে পুরাতন খর্জুর শাখার অনুরূপ হয়ে যায়।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmdccxlv{সূর্য নাগাল পেতে পারে না চন্দ্রের এবং রাত্রি অগ্রে চলে না দিনের প্রত্যেকেই আপন আপন কক্ষপথে সন্তরণ করে।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmdccxlvi{তাদের জন্যে একটি নিদর্শন এই যে, আমি তাদের সন্তান-সন্ততিকে বোঝাই নৌকায় আরোহণ করিয়েছি।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmdccxlvii{এবং তাদের জন্যে নৌকার অনুরূপ যানবাহন সৃষ্টি করেছি, যাতে তারা আরোহণ করে।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmdccxlviii{আমি ইচ্ছা করলে তাদেরকে নিমজ্জত করতে পারি, তখন তাদের জন্যে কোন সাহায্যকারী নেই এবং তারা পরিত্রাণও পাবে না।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmdccxlix{কিন্তু আমারই পক্ষ থেকে কৃপা এবং তাদেরকে কিছু কাল জীবনোপভোগ করার সুযোগ দেয়ার কারণে তা করি না।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmdccl{আর যখন তাদেরকে বলা হয়, তোমরা সামনের আযাব ও পেছনের আযাবকে ভয় কর, যাতে তোমাদের প্রতি অনুগ্রহ করা হয়, তখন তারা তা অগ্রাহ্য করে।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmmdccli{যখনই তাদের পালনকর্তার নির্দেশাবলীর মধ্যে থেকে কোন নির্দেশ তাদের কাছে আসে, তখনই তারা তা থেকে মুখে ফিরিয়ে নেয়।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmmdcclii{যখন তাদেরকে বলা হয়, আল্লাহ তোমাদেরকে যা দিয়েছেন, তা থেকে ব্যয় কর। তখন কাফেররা মুমিনগণকে বলে, ইচ্ছা করলেই আল্লাহ যাকে খাওয়াতে পারতেন, আমরা তাকে কেন খাওয়াব? তোমরা তো স্পষ্ট বিভ্রান্তিতে পতিত রয়েছ।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmmdccliii{তারা বলে, তোমরা সত্যবাদী হলে বল এই ওয়াদা কবে পূর্ণ হবে?\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmmdccliv{তারা কেবল একটা ভয়াবহ শব্দের অপেক্ষা করছে, যা তাদেরকে আঘাত করবে তাদের পারস্পরিক বাকবিতন্ডাকালে।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmmdcclv{তখন তারা ওছিয়ত করতেও সক্ষম হবে না। এবং তাদের পরিবার-পরিজনের কাছেও ফিরে যেতে পারবে না।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmmdcclvi{শিংগায় ফুঁক দেয়া হবে, তখনই তারা কবর থেকে তাদের পালনকর্তার দিকে ছুটে চলবে।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmmdcclvii{তারা বলবে, হায় আমাদের দুর্ভোগ! কে আমাদেরকে নিদ্রাস্থল থেকে উখিত করল? রহমান আল্লাহ তো এরই ওয়াদা দিয়েছিলেন এবং রসূলগণ সত্য বলেছিলেন।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmmdcclviii{এটা তো হবে কেবল এক মহানাদ। সে মুহুর্তেই তাদের সবাইকে আমার সামনে উপস্থিত করা হবে।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmmdcclix{আজকের দিনে কারও প্রতি জুলুম করা হবে না এবং তোমরা যা করবে কেবল তারই প্রতিদান পাবে।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmmdcclx{এদিন জান্নাতীরা আনন্দে মশগুল থাকবে।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mmmdcclxi{তারা এবং তাদের স্ত্রীরা উপবিষ্ট থাকবে ছায়াময় পরিবেশে আসনে হেলান দিয়ে।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mmmdcclxii{সেখানে তাদের জন্যে থাকবে ফল-মূল এবং যা চাইবে।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mmmdcclxiii{করুণাময় পালনকর্তার পক্ষ থেকে তাদেরকে বলা হবে সালাম।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mmmdcclxiv{হে অপরাধীরা! আজ তোমরা আলাদা হয়ে যাও।\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mmmdcclxv{হে বনী-আদম! আমি কি তোমাদেরকে বলে রাখিনি যে, শয়তানের এবাদত করো না, সে তোমাদের প্রকাশ্য শত্রু?\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mmmdcclxvi{এবং আমার এবাদত কর। এটাই সরল পথ।\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mmmdcclxvii{শয়তান তোমাদের অনেক দলকে পথভ্রষ্ট করেছে। তবুও কি তোমরা বুঝনি?\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mmmdcclxviii{এই সে জাহান্নাম, যার ওয়াদা তোমাদেরকে দেয়া হতো।\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mmmdcclxix{তোমাদের কুফরের কারণে আজ এতে প্রবেশ কর।\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mmmdcclxx{আজ আমি তাদের মুখে মোহর এঁটে দেব তাদের হাত আমার সাথে কথা বলবে এবং তাদের পা তাদের কৃতকর্মের সাক্ষ্য দেবে।\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mmmdcclxxi{আমি ইচ্ছা করলে তাদের দৃষ্টি শক্তি বিলুপ্ত করে দিতে পারতাম, তখন তারা পথের দিকে দৌড়াতে চাইলে কেমন করে দেখতে পেত!\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mmmdcclxxii{আমি ইচ্ছা করলে তাদেরকে স্ব স্ব স্থানে আকার বিকৃত করতে পারতাম, ফলে তারা আগেও চলতে পারত না এবং পেছনেও ফিরে যেতে পারত না।\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mmmdcclxxiii{আমি যাকে দীর্ঘ জীবন দান করি, তাকে সৃষ্টিগত পূর্বাবস্থায় ফিরিয়ে নেই। তবুও কি তারা বুঝে না?\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mmmdcclxxiv{আমি রসূলকে কবিতা শিক্ষা দেইনি এবং তা তার জন্যে শোভনীয়ও নয়। এটা তো এক উপদেশ ও প্রকাশ্য কোরআন।\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mmmdcclxxv{যাতে তিনি সতর্ক করেন জীবিতকে এবং যাতে কাফেরদের বিরুদ্ধে অভিযোগ প্রতিষ্ঠিত হয়।\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@mmmdcclxxvi{তারা কি দেখে না, তাদের জন্যে আমি আমার নিজ হাতের তৈরী বস্তুর দ্বারা চতুস্পদ জন্তু সৃষ্টি করেছি, অতঃপর তারাই এগুলোর মালিক।\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@mmmdcclxxvii{আমি এগুলোকে তাদের হাতে অসহায় করে দিয়েছি। ফলে এদের কতক তাদের বাহন এবং কতক তারা ভক্ষণ করে।\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@mmmdcclxxviii{তাদের জন্যে চতুস্পদ জন্তুর মধ্যে অনেক উপকারিতা ও পানীয় রয়েছে। তবুও কেন তারা শুকরিয়া আদায় করে না?\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@mmmdcclxxix{তারা আল্লাহর পরিবর্তে অনেক উপাস্য গ্রহণ করেছে যাতে তারা সাহায্যপ্রাপ্ত হতে পারে।\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@mmmdcclxxx{অথচ এসব উপাস্য তাদেরকে সাহায্য করতে সক্ষম হবে না এবং এগুলো তাদের বাহিনী রূপে ধৃত হয়ে আসবে।\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@mmmdcclxxxi{অতএব তাদের কথা যেন আপনাকে দুঃখিত না করে। আমি জানি যা তারা গোপনে করে এবং যা তারা প্রকাশ্যে করে।\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@mmmdcclxxxii{মানুষ কি দেখে না যে, আমি তাকে সৃষ্টি করেছি বীর্য থেকে? অতঃপর তখনই সে হয়ে গেল প্রকাশ্য বাকবিতন্ডাকারী।\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@mmmdcclxxxiii{সে আমার সম্পর্কে এক অদ্ভূত কথা বর্ণনা করে, অথচ সে নিজের সৃষ্টি ভুলে যায়। সে বলে কে জীবিত করবে অস্থিসমূহকে যখন সেগুলো পচে গলে যাবে?\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@mmmdcclxxxiv{বলুন, যিনি প্রথমবার সেগুলোকে সৃষ্টি করেছেন, তিনিই জীবিত করবেন। তিনি সর্বপ্রকার সৃষ্টি সম্পর্কে সম্যক অবগত।\qt@no{(79)}}
\qt@newcmd\qurantrans@bn@mmmdcclxxxv{যিনি তোমাদের জন্যে সবুজ বৃক্ষ থেকে আগুন উৎপন্ন করেন। তখন তোমরা তা থেকে আগুন জ্বালাও।\qt@no{(80)}}
\qt@newcmd\qurantrans@bn@mmmdcclxxxvi{যিনি নভোমন্ডল ও ভূমন্ডল সৃষ্টি করেছেন, তিনিই কি তাদের অনুরূপ সৃষ্টি করতে সক্ষম নন? হ্যাঁ তিনি মহাস্রষ্টা, সর্বজ্ঞ।\qt@no{(81)}}
\qt@newcmd\qurantrans@bn@mmmdcclxxxvii{তিনি যখন কোন কিছু করতে ইচ্ছা করেন, তখন তাকে কেবল বলে দেন, ‘হও’ তখনই তা হয়ে যায়।\qt@no{(82)}}
\qt@newcmd\qurantrans@bn@mmmdcclxxxviii{অতএব পবিত্র তিনি, যাঁর হাতে সবকিছুর রাজত্ব এবং তাঁরই দিকে তোমরা প্রত্যাবর্তিত হবে।\qt@no{(83)}}
\qt@newcmd\qurantrans@bn@mmmdcclxxxix{\basmalahbn শপথ তাদের যারা সারিবদ্ধ হয়ে দাঁড়ানো,\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmdccxc{অতঃপর ধমকিয়ে ভীতি প্রদর্শনকারীদের,\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmdccxci{অতঃপর মুখস্থ আবৃত্তিকারীদের-\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmdccxcii{নিশ্চয় তোমাদের মাবুদ এক।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmdccxciii{তিনি আসমান সমূহ, যমীনও এতদুভয়ের মধ্যবর্তী সবকিছুর পালনকর্তা এবং পালনকর্তা উদয়াচলসমূহের।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmdccxciv{নিশ্চয় আমি নিকটবর্তী আকাশকে তারকারাজির দ্বারা সুশোভিত করেছি।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmdccxcv{এবং তাকে সংরক্ষিত করেছি প্রত্যেক অবাধ্য শয়তান থেকে।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmdccxcvi{ওরা উর্ধ্ব জগতের কোন কিছু শ্রবণ করতে পারে না এবং চার দিক থেকে তাদের প্রতি উল্কা নিক্ষেপ করা হয়।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmdccxcvii{ওদেরকে বিতাড়নের উদ্দেশে। ওদের জন্যে রয়েছে বিরামহীন শাস্তি।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmdccxcviii{তবে কেউ ছোঁ মেরে কিছু শুনে ফেললে জ্বলন্ত উল্কাপিন্ড তার পশ্চাদ্ধাবন করে।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmdccxcix{আপনি তাদেরকে জিজ্ঞেস করুন, তাদেরকে সৃষ্টি করা কঠিনতর, না আমি অন্য যা সৃষ্টি করেছি? আমিই তাদেরকে সৃষ্টি করেছি এঁটেল মাটি থেকে।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmdccc{বরং আপনি বিস্ময় বোধ করেন আর তারা বিদ্রুপ করে।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmdccci{যখন তাদেরকে বোঝানো হয়, তখন তারা বোঝে না।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmdcccii{তারা যখন কোন নিদর্শন দেখে তখন বিদ্রূপ করে।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmdccciii{এবং বলে, কিছুই নয়, এযে স্পষ্ট যাদু।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmdccciv{আমরা যখন মরে যাব, এবং মাটি ও হাড়ে পরিণত হয়ে যাব, তখনও কি আমরা পুনরুত্থিত হব?\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmdcccv{আমাদের পিতৃপুরুষগণও কি?\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmdcccvi{বলুন, হ্যাঁ এবং তোমরা হবে লাঞ্ছিত।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmdcccvii{বস্তুতঃ সে উত্থান হবে একটি বিকট শব্দ মাত্র-যখন তারা প্রত্যক্ষ করতে থাকবে।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmdcccviii{এবং বলবে, দুর্ভাগ্য আমাদের! এটাই তো প্রতিফল দিবস।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmdcccix{বলা হবে, এটাই ফয়সালার দিন, যাকে তোমরা মিথ্যা বলতে।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmdcccx{একত্রিত কর গোনাহগারদেরকে, তাদের দোসরদেরকে এবং যাদের এবাদত তারা করত।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmdcccxi{আল্লাহ ব্যতীত। অতঃপর তাদেরকে পরিচালিত কর জাহান্নামের পথে,\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmdcccxii{এবং তাদেরকে থামাও, তারা জিজ্ঞাসিত হবে;\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmdcccxiii{তোমাদের কি হল যে, তোমরা একে অপরের সাহায্য করছ না?\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmdcccxiv{বরং তারা আজকের দিনে আত্নসমর্পণকারী।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmdcccxv{তারা একে অপরের দিকে মুখ করে পরস্পরকে জিজ্ঞাসাবাদ করবে।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmdcccxvi{বলবে, তোমরা তো আমাদের কাছে ডান দিক থেকে আসতে।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmdcccxvii{তারা বলবে, বরং তোমরা তো বিশ্বাসীই ছিলে না।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmdcccxviii{এবং তোমাদের উপর আমাদের কোন কতৃত্ব ছিল না, বরং তোমরাই ছিলে সীমালংঘনকারী সম্প্রদায়।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmdcccxix{আমাদের বিপক্ষে আমাদের পালনকর্তার উক্তিই সত্য হয়েছে। আমাদেরকে অবশই স্বাদ আস্বাদন করতে হবে।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmdcccxx{আমরা তোমাদেরকে পথভ্রষ্ট করেছিলাম। কারণ আমরা নিজেরাই পথভ্রষ্ট ছিলাম।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmdcccxxi{তারা সবাই সেদিন শান্তিতে শরীক হবে।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmdcccxxii{অপরাধীদের সাথে আমি এমনি ব্যবহার করে থাকি।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmdcccxxiii{তাদের যখন বলা হত, আল্লাহ ব্যতীত কোন উপাস্য েনই, তখন তারা ঔদ্ধত্য প্রদর্শন করত।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmdcccxxiv{এবং বলত, আমরা কি এক উম্মাদ কবির কথায় আমাদের উপাস্যদেরকে পরিত্যাগ করব।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmdcccxxv{না, তিনি সত্যসহ আগমন করেছেন এবং রসূলগণের সত্যতা স্বীকার করেছেন।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmdcccxxvi{তোমরা অবশ্যই বেদনাদায়ক শাস্তি আস্বাদন করবে।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmdcccxxvii{তোমরা যা করতে, তারই প্রতিফল পাবে।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmdcccxxviii{তবে তারা নয়, যারা আল্লাহর বাছাই করা বান্দা।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmdcccxxix{তাদের জন্যে রয়েছে নির্ধারিত রুযি।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmdcccxxx{ফল-মূল এবং তারা সম্মানিত।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmdcccxxxi{নেয়ামতের উদ্যানসমূহ।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmdcccxxxii{মুখোমুখি হয়ে আসনে আসীন।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmdcccxxxiii{তাদেরকে ঘুরে ফিরে পরিবেশন করা হবে স্বচ্ছ পানপাত্র।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmmdcccxxxiv{সুশুভ্র, যা পানকারীদের জন্যে সুস্বাদু।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmmdcccxxxv{তাতে মাথা ব্যথার উপাদান নেই এবং তারা তা পান করে মাতালও হবে না।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmmdcccxxxvi{তাদের কাছে থাকবে নত, আয়তলোচনা তরুণীগণ।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmmdcccxxxvii{যেন তারা সুরক্ষিত ডিম।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmmdcccxxxviii{অতঃপর তারা একে অপরের দিকে মুখ করে জিজ্ঞাসাবাদ করবে।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmmdcccxxxix{তাদের একজন বলবে, আমার এক সঙ্গী ছিল।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmmdcccxl{সে বলত, তুমি কি বিশ্বাস কর যে,\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmmdcccxli{আমরা যখন মরে যাব এবং মাটি ও হাড়ে পরিণত হব, তখনও কি আমরা প্রতিফল প্রাপ্ত হব?\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmmdcccxlii{আল্লাহ বলবেন, তোমরা কি তাকে উকি দিয়ে দেখতে চাও?\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmmdcccxliii{অপর সে উকি দিয়ে দেখবে এবং তাকে জাহান্নামের মাঝখানে দেখতে পাবে।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mmmdcccxliv{সে বলবে, আল্লাহর কসম, তুমি তো আমাকে প্রায় ধ্বংসই করে দিয়েছিলে।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mmmdcccxlv{আমার পালনকর্তার অনুগ্রহ না হলে আমিও যে গ্রেফতারকৃতদের সাথেই উপস্থিত হতাম।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mmmdcccxlvi{এখন আমাদের আর মৃত্যু হবে না।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mmmdcccxlvii{আমাদের প্রথম মৃত্যু ছাড়া এবং আমরা শাস্তি প্রাপ্তও হব না।\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mmmdcccxlviii{নিশ্চয় এই মহা সাফল্য।\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mmmdcccxlix{এমন সাফল্যের জন্যে পরিশ্রমীদের পরিশ্রম করা উচিত।\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mmmdcccl{এই কি উত্তম আপ্যায়ন, না যাক্কুম বৃক্ষ?\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mmmdcccli{আমি যালেমদের জন্যে একে বিপদ করেছি।\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mmmdccclii{এটি একটি বৃক্ষ, যা উদগত হয় জাহান্নামের মূলে।\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mmmdcccliii{এর গুচ্ছ শয়তানের মস্তকের মত।\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mmmdcccliv{কাফেররা একে ভক্ষণ করবে এবং এর দ্বারা উদর পূর্ণ করবে।\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mmmdccclv{তদুপরি তাদেরকে দেয়া হবে। ফুটন্ত পানির মিশ্রণ,\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mmmdccclvi{অতঃপর তাদের প্রত্যাবর্তন হবে জাহান্নামের দিকে।\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mmmdccclvii{তারা তাদের পূর্বপুরুষদেরকে পেয়েছিল বিপথগামী।\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mmmdccclviii{অতঃপর তারা তদের পদাংক অনুসরণে তৎপর ছিল।\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@mmmdccclix{তাদের পূর্বেও অগ্রবর্তীদের অধিকাংশ বিপথগামী হয়েছিল।\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@mmmdccclx{আমি তাদের মধ্যে ভীতি প্রদর্শনকারী প্রেরণ করেছিলাম।\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@mmmdccclxi{অতএব লক্ষ্য করুন, যাদেরকে ভীতিপ্রদর্শণ করা হয়েছিল, তাদের পরিণতি কি হয়েছে।\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@mmmdccclxii{তবে আল্লাহর বাছাই করা বান্দাদের কথা ভিন্ন।\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@mmmdccclxiii{আর নূহ আমাকে ডেকেছিল। আর কি চমৎকারভাবে আমি তার ডাকে সাড়া দিয়েছিলাম।\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@mmmdccclxiv{আমি তাকে ও তার পরিবারবর্গকে এক মহাসংকট থেকে রক্ষা করেছিলাম।\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@mmmdccclxv{এবং তার বংশধরদেরকেই আমি অবশিষ্ট রেখেছিলাম।\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@mmmdccclxvi{আমি তার জন্যে পরবর্তীদের মধ্যে এ বিষয় রেখে দিয়েছি যে,\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@mmmdccclxvii{বিশ্ববাসীর মধ্যে নূহের প্রতি শান্তি বর্ষিত হোক।\qt@no{(79)}}
\qt@newcmd\qurantrans@bn@mmmdccclxviii{আমি এভাবেই সৎকর্ম পরায়নদেরকে পুরস্কৃত করে থাকি।\qt@no{(80)}}
\qt@newcmd\qurantrans@bn@mmmdccclxix{সে ছিল আমার ঈমানদার বান্দাদের অন্যতম।\qt@no{(81)}}
\qt@newcmd\qurantrans@bn@mmmdccclxx{অতঃপর আমি অপরাপর সবাইকে নিমজ্জত করেছিলাম।\qt@no{(82)}}
\qt@newcmd\qurantrans@bn@mmmdccclxxi{আর নূহ পন্থীদেরই একজন ছিল ইব্রাহীম।\qt@no{(83)}}
\qt@newcmd\qurantrans@bn@mmmdccclxxii{যখন সে তার পালনকর্তার নিকট সুষ্ঠু চিত্তে উপস্থিত হয়েছিল,\qt@no{(84)}}
\qt@newcmd\qurantrans@bn@mmmdccclxxiii{যখন সে তার পিতা ও সম্প্রদায়কে বলেছিলঃ তোমরা কিসের উপাসনা করছ?\qt@no{(85)}}
\qt@newcmd\qurantrans@bn@mmmdccclxxiv{তোমরা কি আল্লাহ ব্যতীত মিথ্যা উপাস্য কামনা করছ?\qt@no{(86)}}
\qt@newcmd\qurantrans@bn@mmmdccclxxv{বিশ্বজগতের পালনকর্তা সম্পর্কে তোমাদের ধারণা কি?\qt@no{(87)}}
\qt@newcmd\qurantrans@bn@mmmdccclxxvi{অতঃপর সে একবার তারকাদের প্রতি লক্ষ্য করল।\qt@no{(88)}}
\qt@newcmd\qurantrans@bn@mmmdccclxxvii{এবং বললঃ আমি পীড়িত।\qt@no{(89)}}
\qt@newcmd\qurantrans@bn@mmmdccclxxviii{অতঃপর তারা তার প্রতি পিঠ ফিরিয়ে চলে গেল।\qt@no{(90)}}
\qt@newcmd\qurantrans@bn@mmmdccclxxix{অতঃপর সে তাদের দেবালয়ে, গিয়ে ঢুকল এবং বললঃ তোমরা খাচ্ছ না কেন?\qt@no{(91)}}
\qt@newcmd\qurantrans@bn@mmmdccclxxx{তোমাদের কি হল যে, কথা বলছ না?\qt@no{(92)}}
\qt@newcmd\qurantrans@bn@mmmdccclxxxi{অতঃপর সে প্রবল আঘাতে তাদের উপর ঝাঁপিয়ে পড়ল।\qt@no{(93)}}
\qt@newcmd\qurantrans@bn@mmmdccclxxxii{তখন লোকজন তার দিকে ছুটে এলো ভীত-সন্ত্রস্ত পদে।\qt@no{(94)}}
\qt@newcmd\qurantrans@bn@mmmdccclxxxiii{সে বললঃ তোমরা স্বহস্ত নির্মিত পাথরের পূজা কর কেন?\qt@no{(95)}}
\qt@newcmd\qurantrans@bn@mmmdccclxxxiv{অথচ আল্লাহ তোমাদেরকে এবং তোমরা যা নির্মাণ করছ সবাইকে সৃষ্টি করেছেন।\qt@no{(96)}}
\qt@newcmd\qurantrans@bn@mmmdccclxxxv{তারা বললঃ এর জন্যে একটি ভিত নির্মাণ কর এবং অতঃপর তাকে আগুনের স্তুপে নিক্ষেপ কর।\qt@no{(97)}}
\qt@newcmd\qurantrans@bn@mmmdccclxxxvi{তারপর তারা তার বিরুদ্ধে মহা ষড়যন্ত্র আঁটতে চাইল, কিন্তু আমি তাদেরকেই পরাভূত করে দিলাম।\qt@no{(98)}}
\qt@newcmd\qurantrans@bn@mmmdccclxxxvii{সে বললঃ আমি আমার পালনকর্তার দিকে চললাম, তিনি আমাকে পথপ্রদর্শন করবেন।\qt@no{(99)}}
\qt@newcmd\qurantrans@bn@mmmdccclxxxviii{হে আমার পরওয়ারদেগার! আমাকে এক সৎপুত্র দান কর।\qt@no{(100)}}
\qt@newcmd\qurantrans@bn@mmmdccclxxxix{সুতরাং আমি তাকে এক সহনশীল পুত্রের সুসংবাদ দান করলাম।\qt@no{(101)}}
\qt@newcmd\qurantrans@bn@mmmdcccxc{অতঃপর সে যখন পিতার সাথে চলাফেরা করার বয়সে উপনীত হল, তখন ইব্রাহীম তাকে বললঃ বৎস! আমি স্বপ্নে দেখিযে, তোমাকে যবেহ করছি; এখন তোমার অভিমত কি দেখ। সে বললঃ পিতাঃ! আপনাকে যা আদেশ করা হয়েছে, তাই করুন। আল্লাহ চাহে তো আপনি আমাকে সবরকারী পাবেন।\qt@no{(102)}}
\qt@newcmd\qurantrans@bn@mmmdcccxci{যখন পিতা-পুত্র উভয়েই আনুগত্য প্রকাশ করল এবং ইব্রাহীম তাকে যবেহ করার জন্যে শায়িত করল।\qt@no{(103)}}
\qt@newcmd\qurantrans@bn@mmmdcccxcii{তখন আমি তাকে ডেকে বললামঃ হে ইব্রাহীম,\qt@no{(104)}}
\qt@newcmd\qurantrans@bn@mmmdcccxciii{তুমি তো স্বপ্নকে সত্যে পরিণত করে দেখালে! আমি এভাবেই সৎকর্মীদেরকে প্রতিদান দিয়ে থাকি।\qt@no{(105)}}
\qt@newcmd\qurantrans@bn@mmmdcccxciv{নিশ্চয় এটা এক সুস্পষ্ট পরীক্ষা।\qt@no{(106)}}
\qt@newcmd\qurantrans@bn@mmmdcccxcv{আমি তার পরিবর্তে দিলাম যবেহ করার জন্যে এক মহান জন্তু।\qt@no{(107)}}
\qt@newcmd\qurantrans@bn@mmmdcccxcvi{আমি তার জন্যে এ বিষয়টি পরবর্তীদের মধ্যে রেখে দিয়েছি যে,\qt@no{(108)}}
\qt@newcmd\qurantrans@bn@mmmdcccxcvii{ইব্রাহীমের প্রতি সালাম বর্ষিত হোক।\qt@no{(109)}}
\qt@newcmd\qurantrans@bn@mmmdcccxcviii{এমনিভাবে আমি সৎকর্মীদেরকে প্রতিদান দিয়ে থাকি।\qt@no{(110)}}
\qt@newcmd\qurantrans@bn@mmmdcccxcix{সে ছিল আমার বিশ্বাসী বান্দাদের একজন।\qt@no{(111)}}
\qt@newcmd\qurantrans@bn@mmmcm{আমি তাকে সুসংবাদ দিয়েছি ইসহাকের, সে সৎকর্মীদের মধ্য থেকে একজন নবী।\qt@no{(112)}}
\qt@newcmd\qurantrans@bn@mmmcmi{তাকে এবং ইসহাককে আমি বরকত দান করেছি। তাদের বংশধরদের মধ্যে কতক সৎকর্মী এবং কতক নিজেদের উপর স্পষ্ট জুলুমকারী।\qt@no{(113)}}
\qt@newcmd\qurantrans@bn@mmmcmii{আমি অনুগ্রহ করেছিলাম মূসা ও হারুনের প্রতি।\qt@no{(114)}}
\qt@newcmd\qurantrans@bn@mmmcmiii{তাদেরকে ও তাদের সম্প্রদায়কে উদ্ধার করেছি মহা সংকট থেকে।\qt@no{(115)}}
\qt@newcmd\qurantrans@bn@mmmcmiv{আমি তাদেরকে সাহায্য করেছিলাম, ফলে তারাই ছিল বিজয়ী।\qt@no{(116)}}
\qt@newcmd\qurantrans@bn@mmmcmv{আমি উভয়কে দিয়েছিলাম সুস্পষ্ট কিতাব।\qt@no{(117)}}
\qt@newcmd\qurantrans@bn@mmmcmvi{এবং তাদেরকে সরল পথ প্রদর্শন করেছিলাম।\qt@no{(118)}}
\qt@newcmd\qurantrans@bn@mmmcmvii{আমি তাদের জন্যে পরবর্তীদের মধ্যে এ বিষয় রেখে দিয়েছি যে,\qt@no{(119)}}
\qt@newcmd\qurantrans@bn@mmmcmviii{মূসা ও হারুনের প্রতি সালাম বর্ষিত হোক।\qt@no{(120)}}
\qt@newcmd\qurantrans@bn@mmmcmix{এভাবে আমি সৎকর্মীদেরকে প্রতিদান দিয়ে থাকি।\qt@no{(121)}}
\qt@newcmd\qurantrans@bn@mmmcmx{তারা উভয়েই ছিল আমার বিশ্বাসী বান্দাদের অন্যতম।\qt@no{(122)}}
\qt@newcmd\qurantrans@bn@mmmcmxi{নিশ্চয়ই ইলিয়াস ছিল রসূল।\qt@no{(123)}}
\qt@newcmd\qurantrans@bn@mmmcmxii{যখন সে তার সম্প্রদায়কে বললঃ তোমরা কি ভয় কর না ?\qt@no{(124)}}
\qt@newcmd\qurantrans@bn@mmmcmxiii{তোমরা কি বা’আল দেবতার এবাদত করবে এবং সর্বোত্তম স্রষ্টাকে পরিত্যাগ করবে।\qt@no{(125)}}
\qt@newcmd\qurantrans@bn@mmmcmxiv{যিনি আল্লাহ তোমাদের পালনকর্তা এবং তোমাদের পূর্বপুরুষদের পালনকর্তা?\qt@no{(126)}}
\qt@newcmd\qurantrans@bn@mmmcmxv{অতঃপর তারা তাকে মিথ্যা প্রতিপন্ন করল। অতএব তারা অবশ্যই গ্রেফতার হয়ে আসবে।\qt@no{(127)}}
\qt@newcmd\qurantrans@bn@mmmcmxvi{কিন্তু আল্লাহ তা’আলার খাঁটি বান্দাগণ নয়।\qt@no{(128)}}
\qt@newcmd\qurantrans@bn@mmmcmxvii{আমি তার জন্যে পরবর্তীদের মধ্যে এ বিষয়ে রেখে দিয়েছি যে,\qt@no{(129)}}
\qt@newcmd\qurantrans@bn@mmmcmxviii{ইলিয়াসের প্রতি সালাম বর্ষিত হোক!\qt@no{(130)}}
\qt@newcmd\qurantrans@bn@mmmcmxix{এভাবেই আমি সৎকর্মীদেরকে প্রতিদান দিয়ে থাকি।\qt@no{(131)}}
\qt@newcmd\qurantrans@bn@mmmcmxx{সে ছিল আমার বিশ্বাসী বান্দাদের অন্তর্ভূক্ত।\qt@no{(132)}}
\qt@newcmd\qurantrans@bn@mmmcmxxi{নিশ্চয় লূত ছিলেন রসূলগণের একজন।\qt@no{(133)}}
\qt@newcmd\qurantrans@bn@mmmcmxxii{যখন আমি তাকেও তার পরিবারের সবাইকে উদ্ধার করেছিলাম;\qt@no{(134)}}
\qt@newcmd\qurantrans@bn@mmmcmxxiii{কিন্তু এক বৃদ্ধাকে ছাড়া; সে অন্যান্যদের সঙ্গে থেকে গিয়েছিল।\qt@no{(135)}}
\qt@newcmd\qurantrans@bn@mmmcmxxiv{অতঃপর অবশিষ্টদেরকে আমি সমূলে উৎপাটিত করেছিলাম।\qt@no{(136)}}
\qt@newcmd\qurantrans@bn@mmmcmxxv{তোমরা তোমাদের ধ্বংস স্তুপের উপর দিয়ে গমন কর ভোর বেলায়\qt@no{(137)}}
\qt@newcmd\qurantrans@bn@mmmcmxxvi{এবং সন্ধ্যায়, তার পরেও কি তোমরা বোঝ না?\qt@no{(138)}}
\qt@newcmd\qurantrans@bn@mmmcmxxvii{আর ইউনুসও ছিলেন পয়গম্বরগণের একজন।\qt@no{(139)}}
\qt@newcmd\qurantrans@bn@mmmcmxxviii{যখন পালিয়ে তিনি বোঝাই নৌকায় গিয়ে পৌঁছেছিলেন।\qt@no{(140)}}
\qt@newcmd\qurantrans@bn@mmmcmxxix{অতঃপর লটারী (সুরতি) করালে তিনি দোষী সাব্যস্ত হলেন।\qt@no{(141)}}
\qt@newcmd\qurantrans@bn@mmmcmxxx{অতঃপর একটি মাছ তাঁকে গিলে ফেলল, তখন তিনি অপরাধী গণ্য হয়েছিলেন।\qt@no{(142)}}
\qt@newcmd\qurantrans@bn@mmmcmxxxi{যদি তিনি আল্লাহর তসবীহ পাঠ না করতেন,\qt@no{(143)}}
\qt@newcmd\qurantrans@bn@mmmcmxxxii{তবে তাঁকে কেয়ামত দিবস পর্যন্ত মাছের পেটেই থাকতে হত।\qt@no{(144)}}
\qt@newcmd\qurantrans@bn@mmmcmxxxiii{অতঃপর আমি তাঁকে এক বিস্তীর্ণ-বিজন প্রান্তরে নিক্ষেপ করলাম, তখন তিনি ছিলেন রুগ্ন।\qt@no{(145)}}
\qt@newcmd\qurantrans@bn@mmmcmxxxiv{আমি তাঁর উপর এক লতাবিশিষ্ট বৃক্ষ উদগত করলাম।\qt@no{(146)}}
\qt@newcmd\qurantrans@bn@mmmcmxxxv{এবং তাঁকে, লক্ষ বা ততোধিক লোকের প্রতি প্রেরণ করলাম।\qt@no{(147)}}
\qt@newcmd\qurantrans@bn@mmmcmxxxvi{তারা বিশ্বাস স্থাপন করল অতঃপর আমি তাদেরকে নির্ধারিত সময় পর্যন্ত জীবনোপভোগ করতে দিলাম।\qt@no{(148)}}
\qt@newcmd\qurantrans@bn@mmmcmxxxvii{এবার তাদেরকে জিজ্ঞেস করুন, তোমার পালনকর্তার জন্যে কি কন্যা সন্তান রয়েছে এবং তাদের জন্যে কি পুত্র-সন্তান।\qt@no{(149)}}
\qt@newcmd\qurantrans@bn@mmmcmxxxviii{না কি আমি তাদের উপস্থিতিতে ফেরেশতাগণকে নারীরূপে সৃষ্টি করেছি?\qt@no{(150)}}
\qt@newcmd\qurantrans@bn@mmmcmxxxix{জেনো, তারা মনগড়া উক্তি করে যে,\qt@no{(151)}}
\qt@newcmd\qurantrans@bn@mmmcmxl{আল্লাহ সন্তান জন্ম দিয়েছেন। নিশ্চয় তারা মিথ্যাবাদী।\qt@no{(152)}}
\qt@newcmd\qurantrans@bn@mmmcmxli{তিনি কি পুত্র-সন্তানের স্থলে কন্যা-সন্তান পছন্দ করেছেন?\qt@no{(153)}}
\qt@newcmd\qurantrans@bn@mmmcmxlii{তোমাদের কি হল? তোমাদের এ কেমন সিন্ধান্ত?\qt@no{(154)}}
\qt@newcmd\qurantrans@bn@mmmcmxliii{তোমরা কি অনুধাবন কর না?\qt@no{(155)}}
\qt@newcmd\qurantrans@bn@mmmcmxliv{না কি তোমাদের কাছে সুস্পষ্ট কোন দলীল রয়েছে?\qt@no{(156)}}
\qt@newcmd\qurantrans@bn@mmmcmxlv{তোমরা সত্যবাদী হলে তোমাদের কিতাব আন।\qt@no{(157)}}
\qt@newcmd\qurantrans@bn@mmmcmxlvi{তারা আল্লাহ ও জ্বিনদের মধ্যে সম্পর্ক সাব্যস্ত করেছে, অথচ জ্বিনেরা জানে যে, তারা গ্রেফতার হয়ে আসবে।\qt@no{(158)}}
\qt@newcmd\qurantrans@bn@mmmcmxlvii{তারা যা বলে তা থেকে আল্লাহ পবিত্র।\qt@no{(159)}}
\qt@newcmd\qurantrans@bn@mmmcmxlviii{তবে যারা আল্লাহর নিষ্ঠাবান বান্দা, তারা গ্রেফতার হয়ে আসবে না।\qt@no{(160)}}
\qt@newcmd\qurantrans@bn@mmmcmxlix{অতএব তোমরা এবং তোমরা যাদের উপাসনা কর,\qt@no{(161)}}
\qt@newcmd\qurantrans@bn@mmmcml{তাদের কাউকেই তোমরা আল্লাহ সম্পর্কে বিভ্রান্ত করতে পারবে না।\qt@no{(162)}}
\qt@newcmd\qurantrans@bn@mmmcmli{শুধুমাত্র তাদের ছাড়া যারা জাহান্নামে পৌছাবে।\qt@no{(163)}}
\qt@newcmd\qurantrans@bn@mmmcmlii{আমাদের প্রত্যেকের জন্য রয়েছে নির্দিষ্ট স্থান।\qt@no{(164)}}
\qt@newcmd\qurantrans@bn@mmmcmliii{এবং আমরাই সারিবদ্ধভাবে দন্ডায়মান থাকি।\qt@no{(165)}}
\qt@newcmd\qurantrans@bn@mmmcmliv{এবং আমরাই আল্লাহর পবিত্রতা ঘোষণা করি।\qt@no{(166)}}
\qt@newcmd\qurantrans@bn@mmmcmlv{তারা তো বলতঃ\qt@no{(167)}}
\qt@newcmd\qurantrans@bn@mmmcmlvi{যদি আমাদের কাছে পূর্ববর্তীদের কোন উপদেশ থাকত,\qt@no{(168)}}
\qt@newcmd\qurantrans@bn@mmmcmlvii{তবে আমরা অবশ্যই আল্লাহর মনোনীত বান্দা হতাম।\qt@no{(169)}}
\qt@newcmd\qurantrans@bn@mmmcmlviii{বস্তুতঃ তারা এই কোরআনকে অস্বীকার করেছে। এখন শীঘ্রই তারা জেনে নিতে পারবে,\qt@no{(170)}}
\qt@newcmd\qurantrans@bn@mmmcmlix{আমার রাসূল ও বান্দাগণের ব্যাপারে আমার এই বাক্য সত্য হয়েছে যে,\qt@no{(171)}}
\qt@newcmd\qurantrans@bn@mmmcmlx{অবশ্যই তারা সাহায্য প্রাপ্ত হয়।\qt@no{(172)}}
\qt@newcmd\qurantrans@bn@mmmcmlxi{আর আমার বাহিনীই হয় বিজয়ী।\qt@no{(173)}}
\qt@newcmd\qurantrans@bn@mmmcmlxii{অতএব আপনি কিছুকালের জন্যে তাদেরকে উপেক্ষা করুন।\qt@no{(174)}}
\qt@newcmd\qurantrans@bn@mmmcmlxiii{এবং তাদেরকে দেখতে থাকুন। শীঘ্রই তারাও এর পরিণাম দেখে নেবে।\qt@no{(175)}}
\qt@newcmd\qurantrans@bn@mmmcmlxiv{আমার আযাব কি তারা দ্রুত কামনা করে?\qt@no{(176)}}
\qt@newcmd\qurantrans@bn@mmmcmlxv{অতঃপর যখন তাদের আঙ্গিনায় আযাব নাযিল হবে, তখন যাদেরকে সতর্ক করা হয়েছিল, তাদের সকাল বেলাটি হবে খুবই মন্দ।\qt@no{(177)}}
\qt@newcmd\qurantrans@bn@mmmcmlxvi{আপনি কিছুকালের জন্যে তাদেরকে উপেক্ষা করুন।\qt@no{(178)}}
\qt@newcmd\qurantrans@bn@mmmcmlxvii{এবং দেখতে থাকুন, শীঘ্রই তারাও এর পরিণাম দেখে নেবে।\qt@no{(179)}}
\qt@newcmd\qurantrans@bn@mmmcmlxviii{পবিত্র আপনার পরওয়ারদেগারের সত্তা, তিনি সম্মানিত ও পবিত্র যা তারা বর্ণনা করে তা থেকে।\qt@no{(180)}}
\qt@newcmd\qurantrans@bn@mmmcmlxix{পয়গম্বরগণের প্রতি সালাম বর্ষিত হোক।\qt@no{(181)}}
\qt@newcmd\qurantrans@bn@mmmcmlxx{সমস্ত প্রশংসা বিশ্বপালক আল্লাহর নিমিত্ত।\qt@no{(182)}}
\qt@newcmd\qurantrans@bn@mmmcmlxxi{\basmalahbn ছোয়াদ। শপথ উপদেশপূর্ণ কোরআনের,\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmcmlxxii{বরং যারা কাফের, তারা অহংকার ও বিরোধিতায় লিপ্ত।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmcmlxxiii{তাদের আগে আমি কত জনগোষ্ঠীকে ধ্বংস করেছি, অতঃপর তারা আর্তনাদ করতে শুরু করেছে কিন্তু তাদের নিষ্কৃতি লাভের সময় ছিল না।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmcmlxxiv{তারা বিস্ময়বোধ করে যে, তাদেরই কাছে তাদের মধ্যে থেকে একজন সতর্ককারী আগমন করেছেন। আর কাফেররা বলে এ-তো এক মিথ্যাচারী যাদুকর।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmcmlxxv{সে কি বহু উপাস্যের পরিবর্তে এক উপাস্যের উপাসনা সাব্যস্ত করে দিয়েছে। নিশ্চয় এটা এক বিস্ময়কর ব্যাপার।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmcmlxxvi{তাদের কতিপয় বিশিষ্ট ব্যক্তি একথা বলে প্রস্থান করে যে, তোমরা চলে যাও এবং তোমাদের উপাস্যদের পূজায় দৃঢ় থাক। নিশ্চয়ই এ বক্তব্য কোন বিশেষ উদ্দেশ্যে প্রণোদিত।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmcmlxxvii{আমরা সাবেক ধর্মে এ ধরনের কথা শুনিনি। এটা মনগড়া ব্যাপার বৈ নয়।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmcmlxxviii{আমাদের মধ্য থেকে শুধু কি তারই প্রতি উপদেশ বানী অবতীর্ণ হল? বস্তুতঃ ওরা আমার উপদেশ সম্পর্কে সন্দিহান; বরং ওরা এখনও আমার মার আস্বাদন করেনি।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmcmlxxix{না কি তাদের কাছে আপনার পরাক্রান্ত দয়াবান পালনকর্তার রহমতের কোন ভান্ডার রয়েছে?\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmcmlxxx{নাকি নভোমন্ডল, ভূমন্ডল ও এতদুভয়ের মধ্যবর্তী সবকিছুর উপর তাদের সাম্রাজ্য রয়েছে? থাকলে তাদের আকাশে আরোহণ করা উচিত রশি ঝুলিয়ে।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmcmlxxxi{এক্ষেত্রে বহু বাহিনীর মধ্যে ওদেরও এক বাহিনী আছে, যা পরাজিত হবে।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmcmlxxxii{তাদের পূর্বেও মিথ্যারোপ করেছিল নূহের সম্প্রদায়, আদ, কীলক বিশিষ্ট ফেরাউন,\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmcmlxxxiii{সামুদ, লূতের সম্প্রদায় ও আইকার লোকেরা। এরাই ছিল বহু বাহিনী।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmcmlxxxiv{এদের প্রত্যেকেই পয়গম্বরগণের প্রতি মিথ্যারোপ করেছে। ফলে আমার আযাব প্রতিষ্ঠিত হয়েছে।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmcmlxxxv{কেবল একটি মহানাদের অপেক্ষা করছে, যাতে দম ফেলার অবকাশ থাকবে না।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmcmlxxxvi{তারা বলে, হে আমাদের পরওয়ারদেগার, আমাদের প্রাপ্য অংশ হিসাব দিবসের আগেই দিয়ে দাও।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmcmlxxxvii{তারা যা বলে তাতে আপনি সবর করুন এবং আমার শক্তিশালী বান্দা দাউদকে স্মরণ করুন। সে ছিল আমার প্রতি প্রত্যাবর্তনশীল।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmcmlxxxviii{আমি পর্বতমালাকে তার অনুগামী করে দিয়েছিলাম, তারা সকাল-সন্ধ্যায় তার সাথে পবিত্রতা ঘোষণা করত;\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmcmlxxxix{আর পক্ষীকুলকেও, যারা তার কাছে সমবেত হত। সবাই ছিল তাঁর প্রতি প্রত্যাবর্তনশীল।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmcmxc{আমি তাঁর সাম্রাজ্যকে সুদৃঢ় করেছিলাম এবং তাঁকে দিয়েছিলাম প্রজ্ঞা ও ফয়সালাকারী বাগ্নীতা।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmcmxci{আপনার কাছে দাবীদারদের বৃত্তান্ত পৌছেছে, যখন তারা প্রাচীর ডিঙ্গীয়ে এবাদত খানায় প্রবেশ করেছিল।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmcmxcii{যখন তারা দাউদের কাছে অনুপ্রবেশ করল, তখন সে সন্ত্রস্ত হয়ে পড়ল। তারা বললঃ ভয় করবেন না; আমরা বিবদমান দুটি পক্ষ, একে অপরের প্রতি বাড়াবাড়ি করেছি। অতএব, আমাদের মধ্যে ন্যায়বিচার করুন, অবিচার করবেন না। আমাদেরকে সরল পথ প্রদর্শন করুন।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmcmxciii{সে আমার ভাই, সে নিরানব্বই দুম্বার মালিক আর আমি মালিক একটি মাদী দুম্বার। এরপরও সে বলেঃ এটিও আমাকে দিয়ে দাও। সে কথাবার্তায় আমার উপর বল প্রয়োগ করে।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmcmxciv{দাউদ বললঃ সে তোমার দুম্বাটিকে নিজের দুম্বাগুলোর সাথে সংযুক্ত করার দাবী করে তোমার প্রতি অবিচার করেছে। শরীকদের অনেকেই একে অপরের প্রতি জুলুম করে থাকে। তবে তারা করে না, যারা আল্লাহর প্রতি বিশ্বাসী ও সৎকর্ম সম্পাদনকারী। অবশ্য এমন লোকের সংখ্যা অল্প। দাউদের খেয়াল হল যে, আমি তাকে পরীক্ষা করছি। অতঃপর সে তার পালনকর্তার কাছে ক্ষমা প্রার্থনা করল, সেজদায় লুটিয়ে পড়ল এবং তাঁর দিকে প্রত্যাবর্তন করল।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmcmxcv{আমি তার সে অপরাধ ক্ষমা করলাম। নিশ্চয় আমার কাছে তার জন্যে রয়েছে উচ্চ মর্তবা ও সুন্দর আবাসস্থল।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmcmxcvi{হে দাউদ! আমি তোমাকে পৃথিবীতে প্রতিনিধি করেছি, অতএব, তুমি মানুষের মাঝে ন্যায়সঙ্গতভাবে রাজত্ব কর এবং খেয়াল-খুশীর অনুসরণ করো না। তা তোমাকে আল্লাহর পথ থেকে বিচ্যুত করে দেবে। নিশ্চয় যারা আল্লাহর পথ থেকে বিচ্যুত হয়, তাদের জন্যে রয়েছে কঠোর শাস্তি, এ কারণে যে, তারা হিসাবদিবসকে ভূলে যায়।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmcmxcvii{আমি আসমান-যমীন ও এতদুভয়ের মধ্যবর্তী কোন কিছু অযথা সৃষ্টি করিনি। এটা কাফেরদের ধারণা। অতএব, কাফেরদের জন্যে রয়েছে দূর্ভোগ অর্থাৎ জাহান্নাম।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmcmxcviii{আমি কি বিশ্বাসী ও সৎকর্মীদেরকে পৃথিবীতে বিপর্যয় সৃষ্টিকারী কাফেরদের সমতুল্য করে দেব? না খোদাভীরুদেরকে পাপাচারীদের সম্মান করে দেব।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmcmxcix{এটি একটি বরকতময় কিতাব, যা আমি আপনার প্রতি বরকত হিসেবে অবতীর্ণ করেছি, যাতে মানুষ এর আয়াতসূহ লক্ষ্য করে এবং বুদ্ধিমানগণ যেন তা অনুধাবন করে।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmm{আমি দাউদকে সোলায়মান দান করেছি। সে একজন উত্তম বান্দা। সে ছিল প্রত্যাবর্তনশীল।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmi{যখন তার সামনে অপরাহ্নে উৎকৃষ্ট অশ্বরাজি পেশ করা হল,\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmmii{তখন সে বললঃ আমি তো আমার পরওয়ারদেগারের স্মরণে বিস্মৃত হয়ে সম্পদের মহব্বতে মুগ্ধ হয়ে পড়েছি-এমনকি সূর্য ডুবে গেছে।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmmiii{এগুলোকে আমার কাছে ফিরিয়ে আন। অতঃপর সে তাদের পা ও গলদেশ ছেদন করতে শুরু করল।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmmiv{আমি সোলায়মানকে পরীক্ষা করলাম এবং রেখে দিলাম তার সিংহাসনের উপর একটি নিস্প্রাণ দেহ। অতঃপর সে রুজু হল।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmmv{সোলায়মান বললঃ হে আমার পালনকর্তা, আমাকে মাফ করুন এবং আমাকে এমন সাম্রাজ্য দান করুন যা আমার পরে আর কেউ পেতে পারবে না। নিশ্চয় আপনি মহাদাতা।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmmvi{তখন আমি বাতাসকে তার অনুগত করে দিলাম, যা তার হুকুমে অবাধে প্রবাহিত হত যেখানে সে পৌছাতে চাইত।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmmvii{আর সকল শয়তানকে তার অধীন করে দিলাম অর্থৎ, যারা ছিল প্রাসাদ নির্মাণকারী ও ডুবুরী।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmmviii{এবং অন্য আরও অনেককে অধীন করে দিলাম, যারা আবদ্ধ থাকত শৃঙ্খলে।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmmix{এগুলো আমার অনুগ্রহ, অতএব, এগুলো কাউকে দাও অথবা নিজে রেখে দাও-এর কোন হিসেব দিতে হবে না।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmmx{নিশ্চয় তার জন্যে আমার কাছে রয়েছে মর্যাদা ও শুভ পরিণতি।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmmxi{স্মরণ করুণ, আমার বান্দা আইয়্যুবের কথা, যখন সে তার পালনকর্তাকে আহবান করে বললঃ শয়তান আমাকে যন্ত্রণা ও কষ্ট পৌছিয়েছে।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmmxii{তুমি তোমার পা দিয়ে ভূমিতে আঘাত কর। ঝরণা নির্গত হল গোসল করার জন্যে শীতল ও পান করার জন্যে।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmmxiii{আমি তাকে দিলাম তার পরিজনবর্গ ও তাদের মত আরও অনেক আমার পক্ষ থেকে রহমতস্বরূপ এবং বুদ্ধিমানদের জন্যে উপদেশস্বরূপ।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmmxiv{তুমি তোমার হাতে এক মুঠো তৃণশলা নাও, তদ্বারা আঘাত কর এবং শপথ ভঙ্গ করো না। আমি তাকে পেলাম সবরকারী। চমৎকার বান্দা সে। নিশ্চয় সে ছিল প্রত্যাবর্তনশীল।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmmxv{স্মরণ করুন, হাত ও চোখের অধিকারী আমার বান্দা ইব্রাহীম, ইসহাক ও ইয়াকুবের কথা।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmmmxvi{আমি তাদের এক বিশেষ গুণ তথা পরকালের স্মরণ দ্বারা স্বাতন্ত্র্য দান করেছিলাম।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmmmxvii{আর তারা আমার কাছে মনোনীত ও সৎলোকদের অন্তর্ভুক্ত।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmmmxviii{স্মরণ করুণ, ইসমাঈল, আল ইয়াসা ও যুলকিফলের কথা। তারা প্রত্যেকেই গুনীজন।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmmmxix{এ এক মহৎ আলোচনা। খোদাভীরুদের জন্যে রয়েছে উত্তম ঠিকানা-\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmmmxx{তথা স্থায়ী বসবাসের জান্নাত; তাদের জন্যে তার দ্বার উম্মুক্ত রয়েছে।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmmmxxi{সেখানে তারা হেলান দিয়ে বসবে। তারা সেখানে চাইবে অনেক ফল-মূল ও পানীয়।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmmmxxii{তাদের কাছে থাকবে আনতনয়না সমবয়স্কা রমণীগণ।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmmmxxiii{তোমাদেরকে এরই প্রতিশ্রুতি দেয়া হচ্ছে বিচার দিবসের জন্যে।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmmmxxiv{এটা আমার দেয়া রিযিক যা শেষ হবে না।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmmmxxv{এটাতো শুনলে, এখন দুষ্টদের জন্যে রয়েছে নিকৃষ্ট ঠিকানা\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mmmmxxvi{তথা জাহান্নাম। তারা সেখানে প্রবেশ করবে। অতএব, কত নিকৃষ্ট সেই আবাস স্থল।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mmmmxxvii{এটা উত্তপ্ত পানি ও পঁূজ; অতএব তারা একে আস্বাদন করুক।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mmmmxxviii{এ ধরনের আরও কিছু শাস্তি আছে।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mmmmxxix{এই তো একদল তোমাদের সাথে প্রবেশ করছে। তাদের জন্যে অভিনন্দন নেই তারা তো জাহান্নামে প্রবেশ করবে।\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mmmmxxx{তারা বলবে, তোমাদের জন্যে ও তো অভিনন্দন নেই। তোমরাই আমাদেরকে এ বিপদের সম্মুখীন করেছ। অতএব, এটি কতই না ঘৃণ্য আবাসস্থল।\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mmmmxxxi{তারা বলবে, হে আমাদের পালনকর্তা, যে আমাদেরকে এর সম্মুখীন করেছে, আপনি জাহান্নামে তার শাস্তি দ্বিগুণ করে দিন।\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mmmmxxxii{তারা আরও বলবে, আমাদের কি হল যে, আমরা যাদেরকে মন্দ লোক বলে গণ্য করতাম, তাদেরকে এখানে দেখছি না।\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mmmmxxxiii{আমরা কি অহেতুক তাদেরকে ঠাট্টার পাত্র করে নিয়েছিলাম, না আমাদের দৃষ্টি ভুল করছে?\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mmmmxxxiv{এটা অর্থাৎ জাহান্নামীদের পারস্পরিক বাক-বিতন্ডা অবশ্যম্ভাবী।\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mmmmxxxv{বলুন, আমি তো একজন সতর্ককারী মাত্র এবং এক পরাক্রমশালী আল্লাহ ব্যতীত কোন উপাস্য নেই।\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mmmmxxxvi{তিনি আসমান-যমীন ও এতদুভয়ের মধ্যবর্তী সব কিছুর পালনকর্তা, পরাক্রমশালী, মার্জনাকারী।\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mmmmxxxvii{বলুন, এটি এক মহাসংবাদ,\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mmmmxxxviii{যা থেকে তোমরা মুখ ফিরিয়ে নিয়েছ।\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mmmmxxxix{ঊর্ধ্ব জগৎ সম্পর্কে আমার কোন জ্ঞান ছিল না যখন ফেরেশতারা কথাবার্তা বলছিল।\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mmmmxl{আমার কাছে এ ওহীই আসে যে, আমি একজন স্পষ্ট সতর্ককারী।\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@mmmmxli{যখন আপনার পালনকর্তা ফেরেশতাগণকে বললেন, আমি মাটির মানুষ সৃষ্টি করব।\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@mmmmxlii{যখন আমি তাকে সুষম করব এবং তাতে আমার রূহ ফুঁকে দেব, তখন তোমরা তার সম্মুখে সেজদায় নত হয়ে যেয়ো।\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@mmmmxliii{অতঃপর সমস্ত ফেরেশতাই একযোগে সেজদায় নত হল,\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@mmmmxliv{কিন্তু ইবলীস; সে অহংকার করল এবং অস্বীকারকারীদের অন্তর্ভুক্ত হয়ে গেল।\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@mmmmxlv{আল্লাহ বললেন, হে ইবলীস, আমি স্বহস্তে যাকে সৃষ্টি করেছি, তার সম্মুখে সেজদা করতে তোমাকে কিসে বাধা দিল? তুমি অহংকার করলে, না তুমি তার চেয়ে উচ্চ মর্যাদা সম্পন্ন?\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@mmmmxlvi{সে বললঃ আমি তার চেয়ে উত্তম আপনি আমাকে আগুনের দ্বারা সৃষ্টি করেছেন, আর তাকে সৃষ্টি করেছেন মাটির দ্বারা।\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@mmmmxlvii{আল্লাহ বললেনঃ বের হয়ে যা, এখান থেকে। কারণ, তুই অভিশপ্ত।\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@mmmmxlviii{তোর প্রতি আমার এ অভিশাপ বিচার দিবস পর্যন্ত স্থায়ী হবে।\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@mmmmxlix{সে বললঃ হে আমার পালনকর্তা, আপনি আমাকে পুনরুত্থান দিবস পর্যন্ত অবকাশ দিন।\qt@no{(79)}}
\qt@newcmd\qurantrans@bn@mmmml{আল্লঅহ বললেনঃ তোকে অবকাশ দেয়া হল।\qt@no{(80)}}
\qt@newcmd\qurantrans@bn@mmmmli{সে সময়ের দিন পর্যন্ত যা জানা।\qt@no{(81)}}
\qt@newcmd\qurantrans@bn@mmmmlii{সে বলল, আপনার ইযযতের কসম, আমি অবশ্যই তাদের সবাইকে বিপথগামী করে দেব।\qt@no{(82)}}
\qt@newcmd\qurantrans@bn@mmmmliii{তবে তাদের মধ্যে যারা আপনার খাঁটি বান্দা, তাদেরকে ছাড়া।\qt@no{(83)}}
\qt@newcmd\qurantrans@bn@mmmmliv{আল্লাহ বললেনঃ তাই ঠিক, আর আমি সত্য বলছি-\qt@no{(84)}}
\qt@newcmd\qurantrans@bn@mmmmlv{তোর দ্বারা আর তাদের মধ্যে যারা তোর অনুসরণ করবে তাদের দ্বারা আমি জাহান্নাম পূর্ণ করব।\qt@no{(85)}}
\qt@newcmd\qurantrans@bn@mmmmlvi{বলুন, আমি তোমাদের কাছে কোন প্রতিদান চাই না আর আমি লৌকিকতাকারীও নই।\qt@no{(86)}}
\qt@newcmd\qurantrans@bn@mmmmlvii{এটা তো বিশ্ববাসীর জন্যে এক উপদেশ মাত্র।\qt@no{(87)}}
\qt@newcmd\qurantrans@bn@mmmmlviii{তোমরা কিছু কাল পরে এর সংবাদ অবশ্যই জানতে পারবে।\qt@no{(88)}}
\qt@newcmd\qurantrans@bn@mmmmlix{\basmalahbn কিতাব অবতীর্ণ হয়েছে পরাক্রমশালী, প্রজ্ঞাময় আল্লাহর পক্ষ থেকে।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmlx{আমি আপনার প্রতি এ কিতাব যথার্থরূপে নাযিল করেছি। অতএব, আপনি নিষ্ঠার সাথে আল্লাহর এবাদত করুন।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmlxi{জেনে রাখুন, নিষ্ঠাপূর্ণ এবাদত আল্লাহরই নিমিত্ত। যারা আল্লাহ ব্যতীত অপরকে উপাস্যরূপে গ্রহণ করে রেখেছে এবং বলে যে, আমরা তাদের এবাদত এ জন্যেই করি, যেন তারা আমাদেরকে আল্লাহর নিকটবর্তী করে দেয়। নিশ্চয় আল্লাহ তাদের মধ্যে তাদের পারস্পরিক বিরোধপূর্ণ বিষয়ের ফয়সালা করে দেবেন। আল্লাহ মিথ্যাবাদী কাফেরকে সৎপথে পরিচালিত করেন না।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmlxii{আল্লাহ যদি সন্তান গ্রহণ করার ইচ্ছা করতেন, তবে তাঁর সৃষ্টির মধ্য থেকে যা কিছু ইচ্ছা মনোনীত করতেন, তিনি পবিত্র। তিনি আল্লাহ, এক পরাক্রমশালী।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmlxiii{তিনি আসমান ও যমীন সৃষ্টি করেছেন যথাযথভাবে। তিনি রাত্রিকে দিবস দ্বারা আচ্ছাদিত করেন এবং দিবসকে রাত্রি দ্বারা আচ্ছাদিত করেন এবং তিনি সুর্য ও চন্দ্রকে কাজে নিযুক্ত করেছেন প্রত্যেকেই বিচরণ করে নির্দিষ্ট সময়কাল পর্যন্ত। জেনে রাখুন, তিনি পরাক্রমশালী, ক্ষমাশীল।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmlxiv{তিনি সৃষ্টি করেছেন তোমাদেরকে একই ব্যক্তি থেকে। অতঃপর তা থেকে তার যুগল সৃষ্টি করেছেন এবং তিনি তোমাদের জন্যে আট প্রকার চতুষ্পদ জন্তু অবতীর্ণ করেছেন। তিনি তোমাদেরকে সৃষ্টি করেছেন তোমাদের মাতৃগর্ভে পর্যায়ক্রমে একের পর এক ত্রিবিধ অন্ধকারে। তিনি আল্লাহ তোমাদের পালনকর্তা, সাম্রাজ্য তাঁরই। তিনি ব্যতীত কোন উপাস্য নেই। অতএব, তোমরা কোথায় বিভ্রান্ত হচ্ছ?\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmlxv{যদি তোমরা অস্বীকার কর, তবে আল্লাহ তোমাদের থেকে বেপরওয়া। তিনি তাঁর বান্দাদের কাফের হয়ে পড়া পছন্দ করেন না। পক্ষান্তরে যদি তোমরা কৃতজ্ঞ হও, তবে তিনি তোমাদের জন্যে তা পছন্দ করেন। একের পাপ ভার অন্যে বহন করবে না। অতঃপর তোমরা তোমাদের পালনকর্তার কাছে ফিরে যাবে। তিনি তোমাদেরকে তোমাদের কর্ম সম্বন্ধে অবহিত করবেন। নিশ্চয় তিনি অন্তরের বিষয় সম্পর্কেও অবগত।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmlxvi{যখন মানুষকে দুঃখ-কষ্ট স্পর্শ করে, তখন সে একাগ্রচিত্তে তার পালনকর্তাকে ডাকে, অতঃপর তিনি যখন তাকে নেয়ামত দান করেন, তখন সে কষ্টের কথা বিস্মৃত হয়ে যায়, যার জন্যে পূর্বে ডেকেছিল এবং আল্লাহর সমকক্ষ স্থির করে; যাতে করে অপরকে আল্লাহর পথ থেকে বিভ্রান্ত করে। বলুন, তুমি তোমার কুফর সহকারে কিছুকাল জীবনোপভোগ করে নাও। নিশ্চয় তুমি জাহান্নামীদের অন্তর্ভূক্ত।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmlxvii{যে ব্যক্তি রাত্রিকালে সেজদার মাধ্যমে অথবা দাঁড়িয়ে এবাদত করে, পরকালের আশংকা রাখে এবং তার পালনকর্তার রহমত প্রত্যাশা করে, সে কি তার সমান, যে এরূপ করে না; বলুন, যারা জানে এবং যারা জানে না; তারা কি সমান হতে পারে? চিন্তা-ভাবনা কেবল তারাই করে, যারা বুদ্ধিমান।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmlxviii{বলুন, হে আমার বিশ্বাসী বান্দাগণ! তোমরা তোমাদের পালনকর্তাকে ভয় কর। যারা এ দুনিয়াতে সৎকাজ করে, তাদের জন্যে রয়েছে পুণ্য। আল্লাহর পৃথিবী প্রশস্ত। যারা সবরকারী, তারাই তাদের পুরস্কার পায় অগণিত।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmlxix{বলুন, আমি নিষ্ঠার সাথে আল্লাহর এবাদত করতে আদিষ্ট হয়েছি।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmlxx{আরও আদিষ্ট হয়েছি, সর্ব প্রথম নির্দেশ পালনকারী হওয়ার জন্যে।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmlxxi{বলুন, আমি আমার পালনকর্তার অবাধ্য হলে এক মহাদিবসের শাস্তির ভয় করি।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmlxxii{বলুন, আমি নিষ্ঠার সাথে আল্লাহ তা’আলারই এবাদত করি।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmlxxiii{অতএব, তোমরা আল্লাহর পরিবর্তে যার ইচ্ছা তার এবাদত কর। বলুন, কেয়ামতের দিন তারাই বেশী ক্ষতিগ্রস্ত হবে, যারা নিজেদের ও পরিবারবর্গের তরফ থেকে ক্ষতিগ্রস্ত হবে। জেনে রাখ, এটাই সুস্পষ্ট ক্ষতি।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmlxxiv{তাদের জন্যে উপর দিক থেকে এবং নীচের দিক থেকে আগুনের মেঘমালা থাকবে। এ শাস্তি দ্বারা আল্লাহ তাঁর বান্দাদেরকে সতর্ক করেন যে, হে আমার বান্দাগণ, আমাকে ভয় কর।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmlxxv{যারা শয়তানী শক্তির পূজা-অর্চনা থেকে দূরে থাকে এবং আল্লাহ অভিমুখী হয়, তাদের জন্যে রয়েছে সুসংবাদ। অতএব, সুসংবাদ দিন আমার বান্দাদেরকে।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmlxxvi{যারা মনোনিবেশ সহকারে কথা শুনে, অতঃপর যা উত্তম, তার অনুসরণ করে। তাদেরকেই আল্লাহ সৎপথ প্রদর্শন করেন এবং তারাই বুদ্ধিমান।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmlxxvii{যার জন্যে শাস্তির হুকুম অবধারিত হয়ে গেছে আপনি কি সে জাহান্নামীকে মুক্ত করতে পারবেন?\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmlxxviii{কিন্তু যারা তাদের পালনকর্তাকে ভয় করে, তাদের জন্যে নির্মিত রয়েছে প্রাসাদের উপর প্রাসাদ। এগুলোর তলদেশে নদী প্রবাহিত। আল্লাহ প্রতিশ্রুতি দিয়েছেন। আল্লাহ প্রতিশ্রুতির খেলাফ করেন না।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmlxxix{তুমি কি দেখনি যে, আল্লাহ আকাশ থেকে পানি বর্ষণ করেছেন, অতঃপর সে পানি যমীনের ঝর্ণাসমূহে প্রবাহিত করেছেন, এরপর তদ্দ্বারা বিভিন্ন রঙের ফসল উৎপন্ন করেন, অতঃপর তা শুকিয়ে যায়, ফলে তোমরা তা পীতবর্ণ দেখতে পাও। এরপর আল্লাহ তাকে খড়-কুটায় পরিণত করে দেন। নিশ্চয় এতে বুদ্ধিমানদের জন্যে উপদেশ রয়েছে।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmlxxx{আল্লাহ যার বক্ষ ইসলামের জন্যে উম্মুক্ত করে দিয়েছেন, অতঃপর সে তার পালনকর্তার পক্ষ থেকে আগত আলোর মাঝে রয়েছে। (সে কি তার সমান, যে এরূপ নয়) যাদের অন্তর আল্লাহ স্মরণের ব্যাপারে কঠোর, তাদের জন্যে দূর্ভোগ। তারা সুস্পষ্ঠ গোমরাহীতে রয়েছে।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmlxxxi{আল্লাহ উত্তম বাণী তথা কিতাব নাযিল করেছেন, যা সামঞ্জস্যপূর্ণ, পূনঃ পূনঃ পঠিত। এতে তাদের লোম কাঁটা দিয়ে উঠে চামড়ার উপর, যারা তাদের পালনকর্তাকে ভয় করে, এরপর তাদের চামড়া ও অন্তর আল্লাহর স্মরণে বিনম্র হয়। এটাই আল্লাহর পথ নির্দেশ, এর মাধ্যমে আল্লাহ যাকে ইচ্ছা পথ প্রদর্শন করেন। আর আল্লাহ যাকে গোমরাহ করেন, তার কোন পথপ্রদর্শক নেই।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmlxxxii{যে ব্যক্তি কেয়ামতের দিন তার মুখ দ্বারা অশুভ আযাব ঠেকাবে এবং এরূপ জালেমদেরকে বলা হবে, তোমরা যা করতে তার স্বাদ আস্বাদন কর,-সে কি তার সমান, যে এরূপ নয়?\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmlxxxiii{তাদের পূর্ববর্তীরাও মিথ্যারোপ করেছিল, ফলে তাদের কাছে আযাব এমনভাবে আসল, যা তারা কল্পনাও করত না।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmlxxxiv{অতঃপর আল্লাহ তাদেরকে পার্থিব জীবনে লাঞ্ছনার স্বাদ আস্বাদন করালেন, আর পরকালের আযাব হবে আরও গুরুতর, যদি তারা জানত!\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmlxxxv{আমি এ কোরআনে মানুষের জন্যে সব দৃষ্টান্তই বর্ণনা করেছি, যাতে তারা অনুধাবন করে;\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmlxxxvi{আরবী ভাষায় এ কোরআন বক্রতামুক্ত, যাতে তারা সাবধান হয়ে চলে।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmlxxxvii{আল্লাহ এক দৃষ্টান্ত বর্ণনা করেছেনঃ একটি লোকের উপর পরস্পর বিরোধী কয়জন মালিক রয়েছে, আরেক ব্যক্তির প্রভু মাত্র একজন-তাদের উভয়ের অবস্থা কি সমান? সমস্ত প্রশংসা আল্লাহর। কিন্তু তাদের অধিকাংশই জানে না।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmlxxxviii{নিশ্চয় তোমারও মৃত্যু হবে এবং তাদেরও মৃত্যু হবে।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmlxxxix{অতঃপর কেয়ামতের দিন তোমরা সবাই তোমাদের পালনকর্তার সামনে কথা কাটাকাটি করবে।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmmxc{যে ব্যক্তি আল্লাহর বিরুদ্ধে মিথ্যা বলে এবং তার কাছে সত্য আগমন করার পর তাকে মিথ্যা সাব্যস্ত করে, তার চেয়ে অধিক যালেম আর কে হবে? কাফেরদের বাসস্থান জাহান্নামে নয় কি?\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmmxci{যারা সত্য নিয়ে আগমন করছে এবং সত্যকে সত্য মেনে নিয়েছে; তারাই তো খোদাভীরু।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmmxcii{তাদের জন্যে পালনকর্তার কাছে তাই রয়েছে, যা তারা চাইবে। এটা সৎকর্মীদের পুরস্কার।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmmxciii{যাতে আল্লাহ তাদের মন্দ কর্মসমূহ মার্জনা করেন এবং তাদের উত্তম কর্মের পুরস্কার তাদেরকে দান করেন।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmmxciv{আল্লাহ কি তাঁর বান্দার পক্ষে যথেষ্ট নন? অথচ তারা আপনাকে আল্লাহর পরিবর্তে অন্যান্য উপাস্যদের ভয় দেখায়। আল্লাহ যাকে গোমরাহ করেন, তার কোন পথপ্রদর্শক নেই।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmmxcv{আর আল্লাহ যাকে পথপ্রদর্শন করেন, তাকে পথভ্রষ্টকারী কেউ নেই। আল্লাহ কি পরাক্রমশালী, প্রতিশোধ গ্রহণকারী নন?\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmmxcvi{যদি আপনি তাদেরকে জিজ্ঞেস করেন, আসমান ও যমীন কে সৃষ্টি করেছে? তারা অবশ্যই বলবে-আল্লাহ। বলুন, তোমরা ভেবে দেখেছ কি, যদি আল্লাহ আমার অনিষ্ট করার ইচ্ছা করেন, তবে তোমরা আল্লাহ ব্যতীত যাদেরকে ডাক, তারা কি সে অনিষ্ট দূর করতে পারবে? অথবা তিনি আমার প্রতি রহমত করার ইচ্ছা করলে তারা কি সে রহমত রোধ করতে পারবে? বলুন, আমার পক্ষে আল্লাহই যথেষ্ট। নির্ভরকারীরা তাঁরই উপর নির্ভর করে।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmmxcvii{বলুন, হে আমার কওম, তোমরা তোমাদের জায়গায় কাজ কর, আমিও কাজ করছি। সত্ত্বরই জানতে পারবে।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmmxcviii{কার কাছে অবমাননাকর আযাব এবং চিরস্থায়ী শাস্তি নেমে আসে।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmmxcix{আমি আপনার প্রতি সত্য ধর্মসহ কিতাব নাযিল করেছি মানুষের কল্যাণকল্পে। অতঃপর যে সৎপথে আসে, সে নিজের কল্যাণের জন্যেই আসে, আর যে পথভ্রষ্ট হয়, সে নিজেরই অনিষ্টের জন্যে পথভ্রষ্ট হয়। আপনি তাদের জন্যে দায়ী নন।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmmc{আল্লাহ মানুষের প্রাণ হরণ করেন তার মৃত্যুর সময়, আর যে মরে না, তার নিদ্রাকালে। অতঃপর যার মৃত্যু অবধারিত করেন, তার প্রাণ ছাড়েন না এবং অন্যান্যদের ছেড়ে দেন এক নির্দিষ্ট সময়ের জন্যে। নিশ্চয় এতে চিন্তাশীল লোকদের জন্যে নিদর্শনাবলী রয়েছে।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmmci{তারা কি আল্লাহ ব্যতীত সুপারিশকারী গ্রহণ করেছে? বলুন, তাদের কোন এখতিয়ার না থাকলেও এবং তারা না বুঝলেও?\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmmcii{বলুন, সমস্ত সুপারিশ আল্লাহরই ক্ষমতাধীন, আসমান ও যমীনে তাঁরই সাম্রাজ্য। অতঃপর তাঁরই কাছে তোমরা প্রত্যাবর্তিত হবে।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmmciii{যখন খাঁটিভাবে আল্লাহর নাম উচ্চারণ করা হয়, তখন যারা পরকালে বিশ্বাস করে না, তাদের অন্তর সংকুচিত হয়ে যায়, আর যখন আল্লাহ ব্যতীত অন্য উপাস্যদের নাম উচ্চারণ করা হয়, তখন তারা আনন্দে উল্লসিত হয়ে উঠে।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmmmciv{বলুন, হে আল্লাহ আসমান ও যমীনের স্রষ্টা, দৃশ্য ও অদৃশ্যের জ্ঞানী, আপনিই আপনার বান্দাদের মধ্যে ফয়সালা করবেন, যে বিষয়ে তারা মত বিরোধ করত।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmmmcv{যদি গোনাহগারদের কাছে পৃথিবীর সবকিছু থাকে এবং তার সাথে সমপরিমাণ আরও থাকে, তবে অবশ্যই তারা কেয়ামতের দিন সে সবকিছুই নিস্কৃতি পাওয়ার জন্যে মুক্তিপন হিসেবে দিয়ে দেবে। অথচ তারা দেখতে পাবে, আল্লাহর পক্ষ থেকে এমন শাস্তি, যা তারা কল্পনাও করত না।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmmmcvi{আর দেখবে, তাদের দুস্কর্মসমূহ এবং যে বিষয়ে তারা ঠাট্টা-বিদ্রুপ করত, তা তাদেরকে ঘিরে নেবে।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmmmcvii{মানুষকে যখন দুঃখ-কষ্ট স্পর্শ করে, তখন সে আমাকে ডাকতে শুরু করে, এরপর আমি যখন তাকে আমার পক্ষ থেকে নেয়ামত দান করি, তখন সে বলে, এটা তো আমি পূর্বের জানা মতেই প্রাপ্ত হয়েছি। অথচ এটা এক পরীক্ষা, কিন্তু তাদের অধিকাংশই বোঝে না।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmmmcviii{তাদের পূর্ববর্তীরাও তাই বলত, অতঃপর তাদের কৃতকর্ম তাদের কোন উপকারে আসেনি।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmmmcix{তাদের দুস্কর্ম তাদেরকে বিপদে ফেলেছে, এদের মধ্যেও যারা পাপী, তাদেরকেও অতি সত্ত্বর তাদের দুস্কর্ম বিপদে ফেলবে। তারা তা প্রতিহত করতে সক্ষম হবে না।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmmmcx{তারা কি জানেনি যে, আল্লাহ যার জন্যে ইচ্ছা রিযিক বৃদ্ধি করেন এবং পরিমিত দেন। নিশ্চয় এতে বিশ্বাসী সম্প্রদায়ের জন্যে নিদর্শনাবলী রয়েছে।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmmmcxi{বলুন, হে আমার বান্দাগণ যারা নিজেদের উপর যুলুম করেছ তোমরা আল্লাহর রহমত থেকে নিরাশ হয়ো না। নিশ্চয় আল্লাহ সমস্ত গোনাহ মাফ করেন। তিনি ক্ষমাশীল, পরম দয়ালু।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmmmcxii{তোমরা তোমাদের পালনকর্তার অভিমূখী হও এবং তাঁর আজ্ঞাবহ হও তোমাদের কাছে আযাব আসার পূর্বে। এরপর তোমরা সাহায্যপ্রাপ্ত হবে না;\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmmmcxiii{তোমাদের প্রতি অবতীর্ণ উত্তম বিষয়ের অনুসরণ কর তোমাদের কাছে অতর্কিতে ও অজ্ঞাতসারে আযাব আসার পূর্বে,\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mmmmcxiv{যাতে কেউ না বলে, হায়, হায়, আল্লাহ সকাশে আমি কর্তব্যে অবহেলা করেছি এবং আমি ঠাট্টা-বিদ্রুপকারীদের অন্তর্ভূক্ত ছিলাম।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mmmmcxv{অথবা না বলে, আল্লাহ যদি আমাকে পথপ্রদর্শন করতেন, তবে অবশ্যই আমি পরহেযগারদের একজন হতাম।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mmmmcxvi{অথবা আযাব প্রত্যক্ষ করার সময় না বলে, যদি কোনরূপে একবার ফিরে যেতে পারি, তবে আমি সৎকর্মপরায়ণ হয়ে যাব।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mmmmcxvii{হাঁ, তোমার কাছে আমার নির্দেশ এসেছিল; অতঃপর তুমি তাকে মিথ্যা বলেছিলে, অহংকার করেছিলে এবং কাফেরদের অন্তর্ভূক্ত হয়ে গিয়েছিলে।\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mmmmcxviii{যারা আল্লাহর প্রতি মিথ্যা আরোপ করে, কেয়ামতের দিন আপনি তাদের মুখ কাল দেখবেন। অহংকারীদের আবাসস্থল জাহান্নামে নয় কি?\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mmmmcxix{আর যারা শিরক থেকে বেঁচে থাকত, আল্লাহ তাদেরকে সাফল্যের সাথে মুক্তি দেবেন, তাদেরকে অনিষ্ট স্পর্শ করবে না এবং তারা চিন্তিতও হবে না।\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mmmmcxx{আল্লাহ সর্বকিছুর স্রষ্টা এবং তিনি সবকিছুর দায়িত্ব গ্রহণ করেন।\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mmmmcxxi{আসমান ও যমীনের চাবি তাঁরই নিকট। যারা আল্লাহর আয়াতসমূহকে অস্বীকার করে, তারাই ক্ষতিগ্রস্ত।\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mmmmcxxii{বলুন, হে মুর্খরা, তোমরা কি আমাকে আল্লাহ ব্যতীত অন্যের এবাদত করতে আদেশ করছ?\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mmmmcxxiii{আপনার প্রতি এবং আপনার পূর্ববর্তীদের পতি প্রত্যাদেশ হয়েছে, যদি আল্লাহর শরীক স্থির করেন, তবে আপনার কর্ম নিষ্ফল হবে এবং আপনি ক্ষতিগ্রস্তদের একজন হবেন।\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mmmmcxxiv{বরং আল্লাহরই এবাদত করুন এবং কৃতজ্ঞদের অন্তর্ভুক্ত থাকুন।\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mmmmcxxv{তারা আল্লাহকে যথার্থরূপে বোঝেনি। কেয়ামতের দিন গোটা পৃথিবী থাকবে তাঁর হাতের মুঠোতে এবং আসমান সমূহ ভাঁজ করা অবস্থায় থাকবে তাঁর ডান হাতে। তিনি পবিত্র। আর এরা যাকে শরীক করে, তা থেকে তিনি অনেক উর্ধ্বে।\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mmmmcxxvi{শিংগায় ফুঁক দেয়া হবে, ফলে আসমান ও যমীনে যারা আছে সবাই বেহুঁশ হয়ে যাবে, তবে আল্লাহ যাকে ইচ্ছা করেন। অতঃপর আবার শিংগায় ফুঁক দেয়া হবে, তৎক্ষণাৎ তারা দন্ডায়মান হয়ে দেখতে থাকবে।\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mmmmcxxvii{পৃথিবী তার পালনকর্তার নূরে উদ্ভাসিত হবে, আমলনামা স্থাপন করা হবে, পয়গম্বরগণ ও সাক্ষীগণকে আনা হবে এবং সকলের মধ্যে ন্যায় বিচার করা হবে-তাদের প্রতি জুলুম করা হবে না।\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mmmmcxxviii{প্রত্যেকে যা করেছে, তার পূর্ণ প্রতিফল দেয়া হবে। তারা যা কিছু করে, সে সম্পর্কে আল্লাহ সম্যক অবগত।\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@mmmmcxxix{কাফেরদেরকে জাহান্নামের দিকে দলে দলে হাঁকিয়ে নেয়া হবে। তারা যখন সেখানে পৌছাবে, তখন তার দরজাসমূহ খুলে দেয়া হবে এবং জাহান্নামের রক্ষীরা তাদেরকে বলবে, তোমাদের কাছে কি তোমাদের মধ্য থেকে পয়গম্বর আসেনি, যারা তোমাদের কাছে তোমাদের পালনকর্তার আয়াতসমূহ আবৃত্তি করত এবং সতর্ক করত এ দিনের সাক্ষাতের ব্যাপারে? তারা বলবে, হঁ্যা, কিন্তু কাফেরদের প্রতি শাস্তির হুকুমই বাস্তবায়িত হয়েছে।\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@mmmmcxxx{বলা হবে, তোমরা জাহান্নামের দরজা দিয়ে প্রবেশ কর, সেখানে চিরকাল অবস্থানের জন্যে। কত নিকৃষ্ট অহংকারীদের আবাসস্থল।\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@mmmmcxxxi{যারা তাদের পালনকর্তাকে ভয় করত তাদেরকে দলে দলে জান্নাতের দিকে নিয়ে যাওয়া হবে। যখন তারা উম্মুক্ত দরজা দিয়ে জান্নাতে পৌছাবে এবং জান্নাতের রক্ষীরা তাদেরকে বলবে, তোমাদের প্রতি সালাম, তোমরা সুখে থাক, অতঃপর সদাসর্বদা বসবাসের জন্যে তোমরা জান্নাতে প্রবেশ কর।\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@mmmmcxxxii{তারা বলবে, সমস্ত প্রশংসা আল্লাহর, যিনি আমাদের প্রতি তাঁর ওয়াদা পূর্ণ করেছেন এবং আমাদেরকে এ ভূমির উত্তরাধিকারী করেছেন। আমরা জান্নাতের যেখানে ইচ্ছা বসবাস করব। মেহনতকারীদের পুরস্কার কতই চমৎকার।\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@mmmmcxxxiii{আপনি ফেরেশতাগণকে দেখবেন, তারা আরশের চার পাশ ঘিরে তাদের পালনকর্তার পবিত্রতা ঘোষনা করছে। তাদের সবার মাঝে ন্যায় বিচার করা হবে। বলা হবে, সমস্ত প্রশংসা বিশ্বপালক আল্লাহর।\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@mmmmcxxxiv{\basmalahbn হা-মীম।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmcxxxv{কিতাব অবতীর্ণ হয়েছে আল্লাহর পক্ষ থেকে, যিনি পরাক্রমশালী, সর্বজ্ঞ।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmcxxxvi{পাপ ক্ষমাকারী, তওবা কবুলকারী, কঠোর শাস্তিদাতা ও সামর্থ?476;ান। তিনি ব্যতীত কোন উপাস্য নেই। তাঁরই দিকে হবে প্রত্যাবর্তন।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmcxxxvii{কাফেররাই কেবল আল্লাহর আয়াত সম্পর্কে বিতর্ক করে। কাজেই নগরীসমূহে তাদের বিচরণ যেন আপনাকে বিভ্রান্তিতে না ফেলে।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmcxxxviii{তাদের পূর্বে নূহের সম্প্রদায় মিথ্যারোপ করেছিল, আর তাদের পরে অন্য অনেক দল ও প্রত্যেক সম্প্রদায় নিজ নিজ পয়গম্বরকে আক্রমণ করার ইচ্ছা করেছিল এবং তারা মিথ্যা বিতর্কে প্রবৃত্ত হয়েছিল, যেন সত্যধর্মকে ব্যর্থ করে দিতে পারে। অতঃপর আমি তাদেরকে পাকড়াও করলাম। কেমন ছিল আমার শাস্তি।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmcxxxix{এভাবে কাফেরদের বেলায় আপনার পালনকর্তার এ বাক্য সত্য হল যে, তারা জাহান্নামী।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmcxl{যারা আরশ বহন করে এবং যারা তার চারপাশে আছে, তারা তাদের পালনকর্তার সপ্রশংস পবিত্রতা বর্ণনা করে, তার প্রতি বিশ্বাস স্থাপন করে এবং মুমিনদের জন্যে ক্ষমা প্রার্থনা করে বলে, হে আমাদের পালনকর্তা, আপনার রহমত ও জ্ঞান সবকিছুতে পরিব্যাপ্ত। অতএব, যারা তওবা করে এবং আপনার পথে চলে, তাদেরকে ক্ষমা করুন এবং জাহান্নামের আযাব থেকে রক্ষা করুন।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmcxli{হে আমাদের পালনকর্তা, আর তাদেরকে দাখিল করুন চিরকাল বসবাসের জান্নাতে, যার ওয়াদা আপনি তাদেরকে দিয়েছেন এবং তাদের বাপ-দাদা, পতি-পত্নী ও সন্তানদের মধ্যে যারা সৎকর্ম করে তাদেরকে। নিশ্চয় আপনি পরাক্রমশালী, প্রজ্ঞাময়।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmcxlii{এবং আপনি তাদেরকে অমঙ্গল থেকে রক্ষা করুন। আপনি যাকে সেদিন অমঙ্গল থেকে রক্ষা করবেন, তার প্রতি অনুগ্রহই করবেন। এটাই মহাসাফল্য।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmcxliii{যারা কাফের তাদেরকে উচ্চঃস্বরে বলা হবে, তোমাদের নিজেদের প্রতি তোমাদের আজকের এ ক্ষোভ অপেক্ষা আল্লার ক্ষোভ অধিক ছিল, যখন তোমাদেরকে ঈমান আনতে বলা হয়েছিল, অতঃপর তোমরা কুফরী করছিল।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmcxliv{তারা বলবে হে আমাদের পালনকর্তা! আপনি আমাদেরকে দু’বার মৃত্যু দিয়েছেন এবং দু’ বার জীবন দিয়েছেন। এখন আমাদের অপরাধ স্বীকার করছি। অতঃপর এখন ও নিস্কৃতির কোন উপায় আছে কি?\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmcxlv{তোমাদের এ বিপদ এ কারণে যে, যখন এক আল্লাহকে ডাকা হত, তখন তোমরা কাফের হয়ে যেতে যখন তার সাথে শরীককে ডাকা হত তখন তোমরা বিশ্বাস স্থাপন করতে। এখন আদেশ তাই, যা আল্লাহ করবেন, যিনি সর্বোচ্চ, মহান।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmcxlvi{তিনিই তোমাদেরকে তাঁর নিদর্শনাবলী দেখান এবং তোমাদের জন্যে আকাশ থেকে নাযিল করেন রুযী। চিন্তা-ভাবনা তারাই করে, যারা আল্লাহর দিকে রুজু থাকে।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmcxlvii{অতএব, তোমরা আল্লাহকে খাঁটি বিশ্বাস সহকারে ডাক, যদিও কাফেররা তা অপছন্দ করে।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmcxlviii{তিনিই সুউচ্চ মর্যাদার অধিকারী, আরশের মালিক, তাঁর বান্দাদের মধ্যে যার প্রতি ইচ্ছা তত্ত্বপূর্ণ বিষয়াদি নাযিল করেন, যাতে সে সাক্ষাতের দিন সম্পর্কে সকলকে সতর্ক করে।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmcxlix{যেদিন তারা বের হয়ে পড়বে, আল্লাহর কাছে তাদের কিছুই গোপন থাকবে না। আজ রাজত্ব কার? এক প্রবল পরাক্রান্ত আল্লাহর।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmcl{আজ প্রত্যেকেই তার কৃতকর্মের প্রতিদান পাবে। আজ যুলুম নেই। নিশ্চয় আল্লাহ দ্রুত হিসাব গ্রহণকারী।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmcli{আপনি তাদেরকে আসন্ন দিন সম্পর্কে সতর্ক করুন, যখন প্রাণ কন্ঠাগত হবে, দম বন্ধ হওয়ার উপক্রম হবে। পাপিষ্ঠদের জন্যে কোন বন্ধু নেই এবং সুপারিশকারীও নেই; যার সুপারিশ গ্রাহ্য হবে।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmclii{চোখের চুরি এবং অন্তরের গোপন বিষয় তিনি জানেন।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmcliii{আল্লাহ ফয়সালা করেন সঠিকভাবে, আল্লাহর পরিবর্তে তারা যাদেরকে ডাকে, তারা কিছুই ফয়সালা করে না। নিশ্চয় আল্লাহ সবকিছু শুনেন, সবকিছু দেখেন।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmcliv{তারা কি দেশ-বিদেশ ভ্রমণ করে না, যাতে দেখত তাদের পূর্বসুরিদের কি পরিণাম হয়েছে? তাদের শক্তি ও কীর্তি পৃথিবীতে এদের অপেক্ষা অধিকতর ছিল। অতঃপর আল্লাহ তাদেরকে তাদের গোনাহের কারণে ধৃত করেছিলেন এবং আল্লাহ থেকে তাদেরকে রক্ষাকারী কেউ হয়নি।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmclv{এর কারণ এই যে, তাদের কাছে তাদের রসূলগণ সুস্পষ্ট নিদর্শনাবলী নিয়ে আগমন করত, অতঃপর তারা কাফের হয়ে যায়, তখন আল্লাহ তাদের ধৃত করেন। নিশ্চয় তিনি শক্তিধর, কঠোর শাস্তিদাতা।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmclvi{আমি আমার নিদর্শনাবলী ও স্পষ্ট প্রমাণসহ মূসাকে প্রেরণ করেছি।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmclvii{ফেরাউন, হামান ও কারুণের কাছে, অতঃপর তারা বলল, সে তো জাদুকর, মিথ্যাবাদী।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmclviii{অতঃপর মূসা যখন আমার কাছ থেকে সত্যসহ তাদের কাছে পৌঁছাল; তখন তারা বলল, যারা তার সঙ্গী হয়ে বিশ্বাস স্থাপন করেছে, তাদের পুত্র সন্তানদেরকে হত্যা কর, আর তাদের নারীদেরকে জীবিত রাখ। কাফেরদের চক্রান্ত ব্যর্থই হয়েছে।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmclix{ফেরাউন বলল; তোমরা আমাকে ছাড়, মূসাকে হত্যা করতে দাও, ডাকুক সে তার পালনকর্তাকে! আমি আশংকা করি যে, সে তোমাদের ধর্ম পরিবর্তন করে দেবে অথবা সে দেশময় বিপর্যয় সৃষ্টি করবে।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmclx{মূসা বলল, যারা হিসাব দিবসে বিশ্বাস করে না এমন প্রত্যেক অহংকারী থেকে আমি আমার ও তোমাদের পালনকর্তার আশ্রয় নিয়ে নিয়েছি।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmclxi{ফেরাউন গোত্রের এক মুমিন ব্যক্তি, যে তার ঈমান গোপন রাখত, সে বলল, তোমরা কি একজনকে এজন্যে হত্যা করবে যে, সে বলে, আমার পালনকর্তা আল্লাহ, অথচ সে তোমাদের পালনকর্তার নিকট থেকে স্পষ্ট প্রমাণসহ তোমাদের নিকট আগমন করেছে? যদি সে মিথ্যাবাদী হয়, তবে তার মিথ্যাবাদিতা তার উপরই চাপবে, আর যদি সে সত্যবাদী হয়, তবে সে যে শাস্তির কথা বলছে, তার কিছু না কিছু তোমাদের উপর পড়বেই। নিশ্চয় আল্লাহ সীমালংঘনকারী, মিথ্যাবাদীকে পথ প্রদর্শন করেন না।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmclxii{হে আমার কওম, আজ এদেশে তোমাদেরই রাজত্ব, দেশময় তোমরাই বিচরণ করছ; কিন্তু আমাদের আল্লাহর শাস্তি এসে গেলে কে আমাদেরকে সাহায্য করবে? ফেরাউন বলল, আমি যা বুঝি, তোমাদেরকে তাই বোঝাই, আর আমি তোমাদেরকে মঙ্গলের পথই দেখাই।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmclxiii{সে মুমিন ব্যক্তি বললঃ হে আমার কওম, আমি তোমাদের জন্যে পূর্ববর্তী সম্প্রদায়সমূহের মতই বিপদসঙ্কুল দিনের আশংকা করি।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmclxiv{যেমন, কওমে নূহ, আদ, সামুদ ও তাদের পরবর্তীদের অবস্থা হয়েছিল। আল্লাহ বান্দাদের প্রতি কোন যুলুম করার ইচ্ছা করেন না।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmmclxv{হে আমার কওম, আমি তোমাদের জন্যে প্রচন্ড হাঁক-ডাকের দিনের আশংকা করি।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmmclxvi{যেদিন তোমরা পেছনে ফিরে পলায়ন করবে; কিন্তু আল্লাহ থেকে তোমাদেরকে রক্ষাকারী কেউ থাকবে না। আল্লাহ যাকে পথভ্রষ্ট করেন, তার কোন পথপ্রদর্শক নেই।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmmclxvii{ইতিপূর্বে তোমাদের কাছে ইউসুফ সুস্পষ্ট প্রামাণাদিসহ আগমন করেছিল, অতঃপর তোমরা তার আনীত বিষয়ে সন্দেহই পোষণ করতে। অবশেষে যখন সে মারা গেল, তখন তোমরা বলতে শুরু করলে, আল্লাহ ইউসুফের পরে আর কাউকে রসূলরূপে পাঠাবেন না। এমনিভাবে আল্লাহ সীমালংঘনকারী, সংশয়ী ব্যক্তিকে পথভ্রষ্ট করেন।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmmclxviii{যারা নিজেদের কাছে আগত কোন দলীল ছাড়াই আল্লাহর আয়াত সম্পর্কে বিতর্ক করে, তাদের একজন আল্লাহ ও মুমিনদের কাছে খুবই অসন্তোষজনক। এমনিভাবে আল্লাহ প্রত্যেক অহংকারী-স্বৈরাচারী ব্যক্তির অন্তরে মোহর এঁটে দেন।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmmclxix{ফেরাউন বলল, হে হামান, তুমি আমার জন্যে একটি সুউচ্চ প্রাসাদ নির্মাণ কর, হয়তো আমি পৌঁছে যেতে পারব।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmmclxx{আকাশের পথে, অতঃপর উঁকি মেরে দেখব মূসার আল্লাহকে। বস্তুতঃ আমি তো তাকে মিথ্যাবাদীই মনে করি। এভাবেই ফেরাউনের কাছে সুশোভিত করা হয়েছিল তার মন্দ কর্মকে এবং সোজা পথ থেকে তাকে বিরত রাখা হয়েছিল। ফেরাউনের চক্রান্ত ব্যর্থ হওয়ারই ছিল।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmmclxxi{মুমিন লোকটি বললঃ হে আমার কওম, তোমরা আমার অনুসরণ কর। আমি তোমাদেরকে সৎপথ প্রদর্শন করব।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmmclxxii{হে আমার কওম, পার্থিব এ জীবন তো কেবল উপভোগের বস্তু, আর পরকাল হচ্ছে স্থায়ী বসবাসের গৃহ।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmmclxxiii{যে মন্দ কর্ম করে, সে কেবল তার অনুরূপ প্রতিফল পাবে, আর যে, পুরুষ অথবা নারী মুমিন অবস্থায় সৎকর্ম করে তারাই জান্নাতে প্রবেশ করবে। তথায় তাদেরকে বে-হিসাব রিযিক দেয়া হবে।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmmclxxiv{হে আমার কওম, ব্যাপার কি, আমি তোমাদেরকে দাওয়াত দেই মুক্তির দিকে, আর তোমরা আমাকে দাওয়াত দাও জাহান্নামের দিকে।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmmclxxv{তোমরা আমাকে দাওয়াত দাও, যাতে আমি আল্লাহকে অস্বীকার করি এবং তাঁর সাথে শরীক করি এমন বস্তুকে, যার কোন প্রমাণ আমার কাছে নেই। আমি তোমাদেরকে দাওয়াত দেই পরাক্রমশালী, ক্ষমাশীল আল্লাহর দিকে।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmmclxxvi{এতে সন্দেহ নেই যে, তোমরা আমাকে যার দিকে দাওয়াত দাও, হইকালে ও পরকালে তার কোন দাওয়াত নেই! আমাদের প্রত্যাবর্তন আল্লাহর দিকে এবং সীমা লংঘকারীরাই জাহান্নামী।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmmclxxvii{আমি তোমাদেরকে যা বলছি, তোমরা একদিন তা স্মরণ করবে। আমি আমার ব্যাপার আল্লাহর কাছে সমর্পণ করছি। নিশ্চয় বান্দারা আল্লাহর দৃষ্টিতে রয়েছে।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmmclxxviii{অতঃপর আল্লাহ তাকে তাদের চক্রান্তের অনিষ্ট থেকে রক্ষা করলেন এবং ফেরাউন গোত্রকে শোচনীয় আযাব গ্রাস করল।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmmmclxxix{সকালে ও সন্ধ্যায় তাদেরকে আগুনের সামনে পেশ করা হয় এবং যেদিন কেয়ামত সংঘটিত হবে, সেদিন আদেশ করা হবে, ফেরাউন গোত্রকে কঠিনতর আযাবে দাখিল কর।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmmmclxxx{যখন তারা জাহান্নামে পরস্পর বিতর্ক করবে, অতঃপর দূর্বলরা অহংকারীদেরকে বলবে, আমরা তোমাদের অনুসারী ছিলাম। তোমরা এখন জাহান্নামের আগুনের কিছু অংশ আমাদের থেকে নিবৃত করবে কি?\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmmmclxxxi{অহংকারীরা বলবে, আমরা সবাই তো জাহান্নামে আছি। আল্লাহ তাঁর বান্দাদের ফয়সালা করে দিয়েছেন।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmmmclxxxii{যারা জাহান্নামে আছে, তারা জাহান্নামের রক্ষীদেরকে বলবে, তোমরা তোমাদের পালনকর্তাকে বল, তিনি যেন আমাদের থেকে একদিনের আযাব লাঘব করে দেন।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmmmclxxxiii{রক্ষীরা বলবে, তোমাদের কাছে কি সুস্পষ্ট প্রমাণাদিসহ তোমাদের রসূল আসেননি? তারা বলবে হঁ্যা। রক্ষীরা বলবে, তবে তোমরাই দোয়া কর। বস্তুতঃ কাফেরদের দোয়া নিস্ফলই হয়।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmmmclxxxiv{আমি সাহায্য করব রসূলগণকে ও মুমিনগণকে পার্থিব জীবনে ও সাক্ষীদের দন্ডায়মান হওয়ার দিবসে।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmmmclxxxv{সে দিন যালেমদের ওযর-আপত্তি কোন উপকারে আসবে না, তাদের জন্যে থাকবে অভিশাপ এবং তাদের জন্যে থাকবে মন্দ গৃহ।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmmmclxxxvi{নিশ্চয় আমি মূসাকে হেদায়েত দান করেছিলাম এবং বনী ইসরাঈলকে কিতাবের উত্তরাধিকারী করেছিলাম।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmmmclxxxvii{বুদ্ধিমানদের জন্যে উপদেশ ও হেদায়েত স্বরূপ।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmmmclxxxviii{অতএব, আপনি সবর করুন নিশ্চয় আল্লাহর ওয়াদা সত্য। আপনি আপনার গোনাহের জন্যে ক্ষমা প্রর্থনা করুন এবং সকাল-সন্ধ্যায় আপনার পালনকর্তার প্রশংসাসহ পবিত্রতা বর্ণনা করুন।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mmmmclxxxix{নিশ্চয় যারা আল্লাহর আয়াত সম্পর্কে বিতর্ক করে তাদের কাছে আগত কোন দলীল ব্যতিরেকে, তাদের অন্তরে আছে কেবল আত্নম্ভরিতা, যা অর্জনে তারা সফল হবে না। অতএব, আপনি আল্লাহর আশ্রয় প্রার্থনা করুন। নিশ্চয় তিনি সবকিছু শুনেন, সবকিছু দেখেন।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mmmmcxc{মানুষের সৃষ্টি অপেক্ষা নভোমন্ডল ও ভূ-মন্ডলের সৃষ্টি কঠিনতর। কিন্তু অধিকাংশ মানুষ বোঝে না।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mmmmcxci{অন্ধ ও চক্ষুষ্মান সমান নয়, আর যারা বিশ্বাস স্থাপন করে ও সৎকর্ম করে এবং কুকর্মী। তোমরা অল্পই অনুধাবন করে থাক।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mmmmcxcii{কেয়ামত অবশ্যই আসবে, এতে সন্দেহ নেই; কিন্ত অধিকাংশ লোক বিশ্বাস স্থাপন করে না।\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mmmmcxciii{তোমাদের পালনকর্তা বলেন, তোমরা আমাকে ডাক, আমি সাড়া দেব। যারা আমার এবাদতে অহংকার করে তারা সত্বরই জাহান্নামে দাখিল হবে লাঞ্ছিত হয়ে।\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mmmmcxciv{তিনিই আল্লাহ যিনি রাত্র সৃষ্টি করেছেন তোমাদের বিশ্রামের জন্যে এবং দিবসকে করেছেন দেখার জন্যে। নিশ্চয় আল্লাহ মানুষের প্রতি অনুগ্রহশীল, কিন্তু অধিকাংশ মানুষ কৃতজ্ঞতা স্বীকার করে না।\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mmmmcxcv{তিনি আল্লাহ, তোমাদের পালনকর্তা, সব কিছুর স্রষ্টা। তিনি ব্যতীত কোন উপাস্য নেই। অতএব তোমরা কোথায় বিভ্রান্ত হচ্ছ?\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mmmmcxcvi{এমনিভাবে তাদেরকে বিভ্রান্ত করা হয়, যারা আল্লাহর আয়াতসমূহকে অস্বীকার করে।\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mmmmcxcvii{আল্লাহ, পৃথিবীকে করেছেন তোমাদের জন্যে বাসস্থান, আকাশকে করেছেন ছাদ এবং তিনি তোমাদেরকে আকৃতি দান করেছেন, অতঃপর তোমাদের আকৃতি সুন্দর করেছেন এবং তিনি তোমাদেরকে দান করেছেন পরিচ্ছন্ন রিযিক। তিনি আল্লাহ, তোমাদের পালনকর্তা। বিশ্বজগতের পালনকর্তা, আল্লাহ বরকতময়।\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mmmmcxcviii{তিনি চিরঞ্জীব, তিনি ব্যতীত কোন উপাস্য নেই। অতএব, তাঁকে ডাক তাঁর খাঁটি এবাদতের মাধ্যমে। সমস্ত প্রশংসা বিশ্বজগতের পালনকর্তা আল্লাহর।\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mmmmcxcix{বলুন, যখন আমার কাছে আমার পালনকর্তার পক্ষ থেকে স্পষ্ট প্রমাণাদি এসে গেছে, তখন আল্লাহ ব্যতীত তোমরা যার পূজা কর, তার এবাদত করতে আমাকে নিষেধ করা হয়েছে। আমাকে আদেশ করা হয়েছে বিশ্ব পালনকর্তার অনুগত থাকতে।\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mmmmcc{তিনি তো তোমাদের সৃষ্টি করেছেন মাটির দ্বারা, অতঃপর শুক্রবিন্দু দ্বারা, অতঃপর জমাট রক্ত দ্বারা, অতঃপর তোমাদেরকে বের করেন শিশুরূপে, অতঃপর তোমরা যৌবনে পদর্পণ কর, অতঃপর বার্ধক্যে উপনীত হও। তোমাদের কারও কারও এর পূর্বেই মৃত্যু ঘটে এবং তোমরা নির্ধারিত কালে পৌঁছ এবং তোমরা যাতে অনুধাবন কর।\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mmmmcci{তিনিই জীবিত করেন এবং মৃত্যু দেন। যখন তিনি কোন কাজের আদেশ করেন, তখন একথাই বলেন, হয়ে যা’-তা হয়ে যায়।\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mmmmccii{আপনি কি তাদেরকে দেখেননি, যারা আল্লাহর আয়াত সম্পর্কে বিতর্ক করে, তারা কোথায় ফিরছে?\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mmmmcciii{যারা কিতাবের প্রতি এবং যে বিষয় দিয়ে আমি পয়গম্বরগণকে প্রেরণ করেছি, সে বিষয়ের প্রতি মিথ্যারোপ করে। অতএব, সত্বরই তারা জানতে পারবে।\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@mmmmcciv{যখন বেড়িও শৃঙ্খল তাদের গলদেশে পড়বে। তাদেরকে টেনে নিয়ে যাওয়া হবে।\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@mmmmccv{ফুটন্ত পানিতে, অতঃপর তাদেরকে আগুনে জ্বালানো হবে।\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@mmmmccvi{অতঃপর তাদেরকে বলা হবে, কোথায় গেল যাদেরকে তোমরা শরীক করতে।\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@mmmmccvii{আল্লাহ ব্যতীত? তারা বলবে, তারা আমাদের কাছ থেকে উধাও হয়ে গেছে; বরং আমরা তো ইতিপূর্বে কোন কিছুর পূজাই করতাম না। এমনি ভাবে আল্লাহ কাফেরদেরকে বিভ্রান্ত করেন।\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@mmmmccviii{এটা একারণে যে, তোমরা দুনিয়াতে অন্যায়ভাবে আনন্দ-উল্লাস করতে এবং এ কারণে যে, তোমরা ঔদ্ধত্য করতে।\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@mmmmccix{প্রবেশ কর তোমরা জাহান্নামের দরজা দিয়ে সেখানে চিরকাল বসবাসের জন্যে। কত নিকৃষ্ট দাম্ভিকদের আবাসস্থল।\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@mmmmccx{অতএব আপনি সবর করুন। নিশ্চয় আল্লাহর ওয়াদা সত্য। অতঃপর আমি কাফেরদেরকে যে শাস্তির ওয়াদা দেই, তার কিয়দংশ যদি আপনাকে দেখিয়ে দেই অথবা আপনার প্রাণ হরণ করে নেই, সর্বাবস্থায় তারা তো আমারই কাছে ফিরে আসবে।\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@mmmmccxi{আমি আপনার পূর্বে অনেক রসূল প্রেরণ করেছি, তাদের কারও কারও ঘটনা আপনার কাছে বিবৃত করেছি এবং কারও কারও ঘটনা আপনার কাছে বিবৃত করিনি। আল্লাহর অনুমতি ব্যতীত কোন নিদর্শন নিয়ে আসা কোন রসূলের কাজ নয়। যখন আল্লাহর আদেশ আসবে, তখন ন্যায় সঙ্গত ফয়সালা হয়ে যাবে। সেক্ষেত্রে মিথ্যাপন্থীরা ক্ষতিগ্রস্ত হবে।\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@mmmmccxii{আল্লাহ তোমাদের জন্যে চতুস্পদ জন্তু সৃষ্টি করেছেন, যাতে কোন কোনটিই বাহন হিসাবে ব্যবহার কর এবং কোন কোনটিকে ভক্ষণ কর।\qt@no{(79)}}
\qt@newcmd\qurantrans@bn@mmmmccxiii{তাতে তোমাদের জন্যে অনেক উপকারিতা রয়েছে আর এজন্যে সৃষ্টি করেছেন; যাতে সেগুলোতে আরোহণ করে তোমরা তোমাদের অভীষ্ট প্রয়োজন পূর্ণ করতে পার। এগুলোর উপর এবং নৌকার উপর তোমরা বাহিত হও।\qt@no{(80)}}
\qt@newcmd\qurantrans@bn@mmmmccxiv{তিনি তোমাদেরকে তাঁর নিদর্শনাবলী দেখান। অতএব, তোমরা আল্লাহর কোন কোন নিদর্শনকে অস্বীকার করবে?\qt@no{(81)}}
\qt@newcmd\qurantrans@bn@mmmmccxv{তারা কি পৃথিবীতে ভ্রমণ করেনি? করলে দেখত, তাদের পূর্ববর্তীদের কি পরিণাম হয়েছে। তারা তাদের চেয়ে সংখ্যায় বেশী এবং শক্তি ও কীর্তিতে অধিক প্রবল ছিল, অতঃপর তাদের কর্ম তাদেরকে কোন উপকার দেয়নি।\qt@no{(82)}}
\qt@newcmd\qurantrans@bn@mmmmccxvi{তাদের কাছে যখন তাদের রসূলগণ স্পষ্ট প্রমাণাদিসহ আগমন করেছিল, তখন তারা নিজেদের জ্ঞান-গরিমার দম্ভ প্রকাশ করেছিল। তারা যে বিষয় নিয়ে ঠাট্টাবিদ্রুপ করেছিল, তাই তাদেরকে গ্রাস করে নিয়েছিল।\qt@no{(83)}}
\qt@newcmd\qurantrans@bn@mmmmccxvii{তারা যখন আমার শাস্তি প্রত্যক্ষ করল, তখন বলল, আমরা এক আল্লাহর প্রতি বিশ্বাস করলাম এবং যাদেরকে শরীক করতাম, তাদেরকে পরিহার করলাম।\qt@no{(84)}}
\qt@newcmd\qurantrans@bn@mmmmccxviii{অতঃপর তাদের এ ঈমান তাদের কোন উপকারে আসল না যখন তারা শাস্তি প্রত্যক্ষ করল। আল্লাহর এ নিয়মই পূর্ব থেকে তাঁর বান্দাদের মধ্যে প্রচলিত হয়েছে। সেক্ষেত্রে কাফেররা ক্ষতিগ্রস্ত হয়।\qt@no{(85)}}
\qt@newcmd\qurantrans@bn@mmmmccxix{\basmalahbn হা-মীম।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmccxx{এটা অবতীর্ণ পরম করুণাময়, দয়ালুর পক্ষ থেকে।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmccxxi{এটা কিতাব, এর আয়াতসমূহ বিশদভাবে বিবৃত আরবী কোরআনরূপে জ্ঞানী লোকদের জন্য।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmccxxii{সুসংবাদদাতা ও সতর্ককারীরূপে, অতঃপর তাদের অধিকাংশই মুখ ফিরিয়ে নিয়েছে, তারা শুনে না।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmccxxiii{তারা বলে আপনি যে বিষয়ের দিকে আমাদের কে দাওয়াত দেন, সে বিষয়ে আমাদের অন্তর আবরণে আবৃত, আমাদের কর্ণে আছে বোঝা এবং আমাদের ও আপনার মাঝখানে আছে অন্তরাল। অতএব, আপনি আপনার কাজ করুন এবং আমরা আমাদের কাজ করি।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmccxxiv{বলুন, আমিও তোমাদের মতই মানুষ, আমার প্রতি ওহী আসে যে, তোমাদের মাবুদ একমাত্র মাবুদ, অতএব তাঁর দিকেই সোজা হয়ে থাক এবং তাঁর কাছে ক্ষমা প্রার্থনা কর। আর মুশরিকদের জন্যে রয়েছে দুর্ভোগ,\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmccxxv{যারা যাকাত দেয় না এবং পরকালকে অস্বীকার করে।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmccxxvi{নিশ্চয় যারা বিশ্বাস স্থাপন করে ও সৎকর্ম করে, তাদের জন্যে রয়েছে অফুরন্ত পুরস্কার।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmccxxvii{বলুন, তোমরা কি সে সত্তাকে অস্বীকার কর যিনি পৃথিবী সৃষ্টি করেছেন দু’দিনে এবং তোমরা কি তাঁর সমকক্ষ স্থীর কর? তিনি তো সমগ্র বিশ্বের পালনকর্তা।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmccxxviii{তিনি পৃথিবীতে উপরিভাগে অটল পর্বতমালা স্থাপন করেছেন, তাতে কল্যাণ নিহিত রেখেছেন এবং চার দিনের মধ্যে তাতে তার খাদ্যের ব্যবস্থা করেছেন-পূর্ণ হল জিজ্ঞাসুদের জন্যে।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmccxxix{অতঃপর তিনি আকাশের দিকে মনোযোগ দিলেন যা ছিল ধুম্রকুঞ্জ, অতঃপর তিনি তাকে ও পৃথিবীকে বললেন, তোমরা উভয়ে আস ইচ্ছায় অথবা অনিচ্ছায়। তারা বলল, আমরা স্বেচ্ছায় আসলাম।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmccxxx{অতঃপর তিনি আকাশমন্ডলীকে দু’দিনে সপ্ত আকাশ করে দিলেন এবং প্রত্যেক আকাশে তার আদেশ প্রেরণ করলেন। আমি নিকটবর্তী আকাশকে প্রদীপমালা দ্বারা সুশোভিত ও সংরক্ষিত করেছি। এটা পরাক্রমশালী সর্বজ্ঞ আল্লাহর ব্যবস্থাপনা।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmccxxxi{অতঃপর যদি তারা মুখ ফিরিয়ে নেয়, তবে বলুন, আমি তোমাদেরকে সতর্ক করলাম এক কঠোর আযাব সম্পর্কে আদ ও সামুদের আযাবের মত।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmccxxxii{যখন তাদের কাছে রসূলগণ এসেছিলেন সম্মুখ দিক থেকে এবং পিছন দিক থেকে এ কথা বলতে যে, তোমরা আল্লাহ ব্যতীত কারও পূজা করো না। তারা বলেছিল, আমাদের পালনকর্তা ইচ্ছা করলে অবশ্যই ফেরেশতা প্রেরণ করতেন, অতএব, আমরা তোমাদের আনীত বিষয় অমান্য করলাম।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmccxxxiii{যারা ছিল আদ, তারা পৃথিবীতে অযথা অহংকার করল এবং বলল, আমাদের অপেক্ষা অধিক শক্তিধর কে? তারা কি লক্ষ্য করেনি যে, যে আল্লাহ তাদেরকে সৃষ্টি করেছেন, তিনি তাদের অপেক্ষা অধিক শক্তিধর ? বস্তুতঃ তারা আমার নিদর্শনাবলী অস্বীকার করত।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmccxxxiv{অতঃপর আমি তাদেরকে পার্থিব জীবনে লাঞ্ছনার আযাব আস্বাদন করানোর জন্যে তাদের উপর প্রেরণ করলাম ঝঞ্ঝাবায়ু বেশ কতিপয় অশুভ দিনে। আর পরকালের আযাব তো আরও লাঞ্ছনাকর এমতাবস্থায় যে, তারা সাহায্যপ্রাপ্ত হবে না।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmccxxxv{আর যারা সামূদ, আমি তাদেরকে প্রদর্শন করেছিলাম, অতঃপর তারা সৎপথের পরিবর্তে অন্ধ থাকাই পছন্দ করল। অতঃপর তাদের কৃতকর্মের কারণে তাদেরকে অবমাননাকর আযাবের বিপদ এসে ধৃত করল।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmccxxxvi{যারা বিশ্বাস স্থাপন করেছিল ও সাবধানে চলত, আমি তাদেরকে উদ্ধার করলাম।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmccxxxvii{যেদিন আল্লাহর শত্রুদেরকে অগ্নিকুন্ডের দিকে ঠেলে নেওয়া হবে। এবং ওদের বিন্যস্ত করা হবে বিভিন্ন দলে।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmccxxxviii{তারা যখন জাহান্নামের কাছে পৌঁছাবে, তখন তাদের কান, চক্ষু ও ত্বক তাদের কর্ম সম্পর্কে সাক্ষ্য দেবে।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmccxxxix{তারা তাদের ত্বককে বলবে, তোমরা আমাদের বিপক্ষে সাক্ষ্য দিলে কেন? তারা বলবে, যে আল্লাহ সব কিছুকে বাকশক্তি দিয়েছেন, তিনি আমাদেরকেও বাকশক্তি দিয়েছেন। তিনিই তোমাদেরকে প্রথমবার সৃষ্টি করেছেন এবং তোমরা তাঁরই দিকে প্রত্যাবর্তিত হবে।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmccxl{তোমাদের কান, তোমাদের চক্ষু এবং তোমাদের ত্বক তোমাদের বিপক্ষে সাক্ষ্য দেবে না ধারণার বশবর্তী হয়ে তোমরা তাদের কাছে কিছু গোপন করতে না। তবে তোমাদের ধারণা ছিল যে, তোমরা যা কর তার অনেক কিছুই আল্লাহ জানেন না।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmccxli{তোমাদের পালনকর্তা সম্বন্ধে তোমাদের এ ধারণাই তোমাদেরকে ধ্বংস করেছে। ফলে তোমরা ক্ষতিগ্রস্তদের অন্তর্ভুক্ত হয়ে গেছ।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmccxlii{অতঃপর যদি তারা সবর করে, তবুও জাহান্নামই তাদের আবাসস্থল। আর যদি তারা ওযরখাহী করে, তবে তাদের ওযর কবুল করা হবে না।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmccxliii{আমি তাদের পেছনে সঙ্গী লাগিয়ে দিয়েছিলাম, অতঃপর সঙ্গীরা তাদের অগ্র-পশ্চাতের আমল তাদের দৃষ্টিতে শোভনীয় করে দিয়েছিল। তাদের ব্যাপারেও শাস্তির আদেশ বাস্তবায়িত হল, যা বাস্তবায়িত হয়েছিল তাদের পূর্ববতী জিন ও মানুষের ব্যাপারে। নিশ্চয় তারা ক্ষতিগ্রস্ত।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmccxliv{আর কাফেররা বলে, তোমরা এ কোরআন শ্রবণ করো না এবং এর আবৃত্তিতে হঞ্জগোল সৃষ্টি কর, যাতে তোমরা জয়ী হও।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmccxlv{আমি অবশ্যই কাফেরদেরকে কঠিন আযাব আস্বাদন করাব এবং আমি অবশ্যই তাদেরকে তাদের মন্দ ও হীন কাজের প্রতিফল দেব।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmccxlvi{এটা আল্লাহর শত্রুদের শাস্তি-জাহান্নাম। তাতে তাদের জন্যে রয়েছে স্থায়ী আবাস, আমার আয়াতসমূহ অস্বীকার করার প্রতিফলস্বরূপ।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmccxlvii{কাফেররা বলবে, হে আমাদের পালনকর্তা! যেসব জিন ও মানুষ আমাদেরকে পথভ্রষ্ট করেছিল, তাদেরকে দেখিয়ে দাও, আমরা তাদেরকে পদদলিত করব, যাতে তারা যথেষ্ট অপমানিত হয়।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmccxlviii{নিশ্চয় যারা বলে, আমাদের পালনকর্তা আল্লাহ, অতঃপর তাতেই অবিচল থাকে, তাদের কাছে ফেরেশতা অবতীর্ণ হয় এবং বলে, তোমরা ভয় করো না, চিন্তা করো না এবং তোমাদের প্রতিশ্রুত জান্নাতের সুসংবাদ শোন।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmccxlix{ইহকালে ও পরকালে আমরা তোমাদের বন্ধু। সেখানে তোমাদের জন্য আছে যা তোমাদের মন চায় এবং সেখানে তোমাদের জন্যে আছে তোমরা দাবী কর।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmmccl{এটা ক্ষমাশীল করুনাময়ের পক্ষ থেকে সাদর আপ্যায়ন।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmmccli{যে আল্লাহর দিকে দাওয়াত দেয়, সৎকর্ম করে এবং বলে, আমি একজন আজ্ঞাবহ, তার কথা অপেক্ষা উত্তম কথা আর কার?\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmmcclii{সমান নয় ভাল ও মন্দ। জওয়াবে তাই বলুন যা উৎকৃষ্ট। তখন দেখবেন আপনার সাথে যে ব্যক্তির শুত্রুতা রয়েছে, সে যেন অন্তরঙ্গ বন্ধু।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmmccliii{এ চরিত্র তারাই লাভ করে, যারা সবর করে এবং এ চরিত্রের অধিকারী তারাই হয়, যারা অত্যন্ত ভাগ্যবান।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmmccliv{যদি শয়তানের পক্ষ থেকে আপনি কিছু কুমন্ত্রণা অনুভব করেন, তবে আল্লাহর শরণাপন্ন হোন। নিশ্চয় তিনি সর্বশ্রোতা, সর্বজ্ঞ।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmmcclv{তাঁর নিদর্শনসমূহের মধ্যে রয়েছে দিবস, রজনী, সূর্য ও চন্দ্র। তোমরা সূর্যকে সেজদা করো না, চন্দ্রকেও না; আল্লাহকে সেজদা কর, যিনি এগুলো সৃষ্টি করেছেন, যদি তোমরা নিষ্ঠার সাথে শুধুমাত্র তাঁরই এবাদত কর।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmmcclvi{অতঃপর তারা যদি অহংকার করে, তবে যারা আপনার পালনকর্তার কাছে আছে, তারা দিবারাত্রি তাঁর পবিত্রতা ঘোষণা করে এবং তারা ক্লান্ত হয় না।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmmcclvii{তাঁর এক নিদর্শন এই যে, তুমি ভূমিকে দেখবে অনুর্বর পড়ে আছে। অতঃপর আমি যখন তার উপর বৃষ্টি বর্ষণ করি, তখন সে শস্যশ্যামল ও স্ফীত হয়। নিশ্চয় যিনি একে জীবিত করেন, তিনি জীবিত করবেন মৃতদেরকেও। নিশ্চয় তিনি সবকিছু করতে সক্ষম।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmmcclviii{নিশ্চয় যারা আমার আয়াতসমূহের ব্যাপারে বক্রতা অবলম্বন করে, তারা আমার কাছে গোপন নয়। যে ব্যক্তি জাহান্নামে নিক্ষিপ্ত হবে সে শ্রেষ্ঠ, না যে কেয়ামতের দিন নিরাপদে আসবে? তোমরা যা ইচ্ছা কর, নিশ্চয় তিনি দেখেন যা তোমরা কর।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmmcclix{নিশ্চয় যারা কোরআন আসার পর তা অস্বীকার করে, তাদের মধ্যে চিন্তা-ভাবনার অভাব রয়েছে। এটা অবশ্যই এক সম্মানিত গ্রন্থ।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmmcclx{এতে মিথ্যার প্রভাব নেই, সামনের দিক থেকেও নেই এবং পেছন দিক থেকেও নেই। এটা প্রজ্ঞাময়, প্রশংসিত আল্লাহর পক্ষ থেকে অবতীর্ণ।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmmcclxi{আপনাকে তো তাই বলা হয়, যা বলা হত পূর্ববর্তী রসূলগনকে। নিশ্চয় আপনার পালনকর্তার কাছে রয়েছে ক্ষমা এবং রয়েছে যন্ত্রণাদায়ক শাস্তি।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmmcclxii{আমি যদি একে অনারব ভাষায় কোরআন করতাম, তবে অবশ্যই তারা বলত, এর আয়াতসমূহ পরিস্কার ভাষায় বিবৃত হয়নি কেন? কি আশ্চর্য যে, কিতাব অনারব ভাষায় আর রসূল আরবী ভাষী! বলুন, এটা বিশ্বাসীদের জন্য হেদায়েত ও রোগের প্রতিকার। যারা মুমিন নয়, তাদের কানে আছে ছিপি, আর কোরআন তাদের জন্যে অন্ধত্ব। তাদেরকে যেন দূরবর্তী স্থান থেকে আহবান করা হয়।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmmcclxiii{আমি মূসাকে কিতাব দিয়েছিলাম, অতঃপর তাতে মতভেদ সৃষ্টি হয়। আপনার পালনকর্তার পক্ষ থেকে পূর্ব সিদ্ধান্ত না থাকলে তাদের মধ্যে ফয়সালা হয়ে যেত। তারা কোরআন সমন্ধে এক অস্বস্তিকর সন্দেহে লিপ্ত।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmmmcclxiv{যে সৎকর্ম করে, সে নিজের উপকারের জন্যেই করে, আর যে অসৎকর্ম করে, তা তার উপরই বর্তাবে। আপনার পালনকর্তা বান্দাদের প্রতি মোটেই যুলুম করেন না।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmmmcclxv{কেয়ামতের জ্ঞান একমাত্র তাঁরই জানা। তাঁর জ্ঞানের বাইরে কোন ফল আবরণমুক্ত হয় না। এবং কোন নারী গর্ভধারণ ও সন্তান প্রসব করে না। যেদিন আল্লাহ তাদেরকে ডেকে বলবেন, আমার শরীকরা কোথায়? সেদিন তারা বলবে, আমরা আপনাকে বলে দিয়েছি যে, আমাদের কেউ এটা স্বীকার করে না।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmmmcclxvi{পূর্বে তারা যাদের পূজা করত, তারা উধাও হয়ে যাবে এবং তারা বুঝে নেবে যে, তাদের কোন নিস্কৃতি নেই।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmmmcclxvii{মানুষ উন্নতি কামনায় ক্লান্ত হয় না; যদি তাকে অমঙ্গল স্পর্শ করে, তবে সে সম্পূর্ণ রূপে নিরাশ হয়ে পড়ে।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmmmcclxviii{বিপদাপদ স্পর্শ করার পর আমি যদি তাকে আমার অনুগ্রহ আস্বাদন করাই, তখন সে বলতে থাকে, এটা যে আমার যোগ্য প্রাপ্য; আমি মনে করি না যে, কেয়ামত সংঘটিত হবে। আমি যদি আমার পালনকর্তার কাছে ফিরে যাই, তবে অবশ্যই তার কাছে আমার জন্য কল্যাণ রয়েছে। অতএব, আমি কাফেরদেরকে তাদের কর্ম সম্পর্কে অবশ্যই অবহিত করব এবং তাদেরকে অবশ্যই আস্বাদন করাব কঠিন শাস্তি।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmmmcclxix{আমি যখন মানুষের প্রতি অনুগ্রহ করি তখন সে মুখ ফিরিয়ে নেয় এবং পার্শ্ব পরিবর্তন করে। আর যখন তাকে অনিষ্ট স্পর্শ করে, তখন সুদীর্ঘ দোয়া করতে থাকে।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmmmcclxx{বলুন, তোমরা ভেবে দেখেছ কি, যদি এটা আল্লাহর পক্ষ থেকে হয়, অতঃপর তোমরা একে অমান্য কর, তবে যে ব্যক্তি ঘোর বিরোধিতায় লিপ্ত, তার চাইতে অধিক পথভ্রষ্ট আর কে?\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmmmcclxxi{এখন আমি তাদেরকে আমার নিদর্শনাবলী প্রদর্শন করাব পৃথিবীর দিগন্তে এবং তাদের নিজেদের মধ্যে; ফলে তাদের কাছে ফুটে উঠবে যে, এ কোরআন সত্য। আপনার পালনকর্তা সর্ববিষয়ে সাক্ষ্যদাতা, এটা কি যথেষ্ট নয়?\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmmmcclxxii{শুনে রাখ, তারা তাদের পালনকর্তার সাথে সাক্ষাতের ব্যাপারে সন্দেহে পতিত রয়েছে। শুনে রাখ, তিনি সবকিছুকে পরিবেষ্টন করে রয়েছেন।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmmmcclxxiii{\basmalahbn হা-মীম।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmcclxxiv{আইন, সীন ক্বা-ফ।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmcclxxv{এমনিভাবে পরাক্রমশালী, প্রজ্ঞাময় আল্লাহ আপনার প্রতি ও আপনার পূর্ববর্তীদের প্রতি ওহী প্রেরণ করেন।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmcclxxvi{নভোমন্ডলে যা কিছু আছে এবং ভূমন্ডলে যা কিছু আছে, সমস্তই তাঁর। তিনি সমুন্নত, মহান।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmcclxxvii{আকাশ উপর থেকে ফেটে পড়ার উপক্রম হয় আর তখন ফেরেশতাগণ তাদের পালনকর্তার প্রশংসাসহ পবিত্রতা বর্ণনা করে এবং পৃথিবীবাসীদের জন্যে ক্ষমা প্রার্থনা করে। শুনে রাখ, আল্লাহই ক্ষমাশীল, পরম করুনাময়।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmcclxxviii{যারা আল্লাহ ব্যতীত অপরকে অভিভাবক হিসাবে গ্রহণ করে, আল্লাহ তাদের প্রতি লক্ষ্য রাখেন। আপনার উপর নয় তাদের দায়-দায়িত্ব।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmcclxxix{এমনি ভাবে আমি আপনার প্রতি আরবী ভাষায় কোরআন নাযিল করেছি, যাতে আপনি মক্কা ও তার আশ-পাশের লোকদের সতর্ক করেন এবং সতর্ক করেন সমাবেশের দিন সম্পর্কে, যাতে কোন সন্দেহ নেই। একদল জান্নাতে এবং একদল জাহান্নামে প্রবেশ করবে।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmcclxxx{আল্লাহ ইচ্ছা করলে সমস্ত লোককে এক দলে পরিণত করতে পারেন। কিন্তু তিনি যাকে ইচ্ছা স্বীয় রহমতে দাখিল করেন। আর যালেমদের কোন অভিভাবক ও সাহায্যকারী নেই।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmcclxxxi{তারা কি আল্লাহ ব্যতীত অপরকে অভিভাবক স্থির করেছে? পরন্তু আল্লাহই তো একমাত্র অভিভাবক। তিনি মৃতদেরকে জীবিত করেন। তিনি সর্ববিষয়ে ক্ষমতাবান।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmcclxxxii{তোমরা যে বিষয়েই মতভেদ কর, তার ফয়সালা আল্লাহর কাছে সোপর্দ। ইনিই আল্লাহ আমার পালনকর্তা আমি তাঁরই উপর নির্ভর করি এবং তাঁরই অভিমুখী হই।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmcclxxxiii{তিনি নভোমন্ডল ও ভূমন্ডলের স্রষ্টা। তিনি তোমাদের মধ্য থেকে তোমাদের জন্যে যুগল সৃষ্টি করেছেন এবং চতুস্পদ জন্তুদের মধ্য থেকে জোড়া সৃষ্টি করেছেন। এভাবে তিনি তোমাদের বংশ বিস্তার করেন। কোন কিছুই তাঁর অনুরূপ নয়। তিনি সব শুনেন, সব দেখেন।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmcclxxxiv{আকাশ ও পৃথিবীর চাবি তাঁর কাছে। তিনি যার জন্যে ইচ্ছা রিযিক বৃদ্ধি করেন এবং পরিমিত করেন। তিনি সর্ব বিষয়ে জ্ঞানী।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmcclxxxv{তিনি তোমাদের জন্যে দ্বীনের ক্ষেত্রে সে পথই নিধারিত করেছেন, যার আদেশ দিয়েছিলেন নূহকে, যা আমি প্রত্যাদেশ করেছি আপনার প্রতি এবং যার আদেশ দিয়েছিলাম ইব্রাহীম, মূসা ও ঈসাকে এই মর্মে যে, তোমরা দ্বীনকে প্রতিষ্ঠিত কর এবং তাতে অনৈক্য সৃষ্টি করো না। আপনি মূশরেকদেরকে যে বিষয়ের প্রতি আমন্ত্রণ জানান, তা তাদের কাছে দুঃসাধ্য বলে মনে হয়। আল্লাহ যাকে ইচ্ছা মনোনীত করেন এবং যে তাঁর অভিমুখী হয়, তাকে পথ প্রদর্শন করেন।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmcclxxxvi{তাদের কাছে জ্ঞান আসার পরই তারা পারস্পরিক বিভেদের কারণে মতভেদ করেছে। যদি আপনার পালনকর্তার পক্ষ থেকে নির্দিষ্ট সময় পর্যন্ত অবকাশের পূর্ব সিদ্ধান্ত না থাকত, তবে তাদের ফয়সালা হয়ে যেত। তাদের পর যারা কিতাব প্রাপ্ত হয়েছে, তারা অস্বস্তিকর সন্দেহে পতিত রয়েছে।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmcclxxxvii{সুতরাং আপনি এর প্রতিই দাওয়াত দিন এবং হুকুম অনুযায়ী অবিচল থাকুন; আপনি তাদের খেয়ালখুশীর অনুসরণ করবেন না। বলুন, আল্লাহ যে কিতাব নাযিল করেছেন, আমি তাতে বিশ্বাস স্থাপন করেছি। আমি তোমাদের মধ্যে ন্যায় বিচার করতে আদিষ্ট হয়েছি। আল্লাহ আমাদের পালনকর্তা ও তোমাদের পালনকর্তা। আমাদের জন্যে আমাদের কর্ম এবং তোমাদের জন্যে তোমাদের কর্ম। আমাদের মধ্যে ও তোমাদের মধ্যে বিবাদ নেই। আল্লাহ আমাদেরকে সমবেত করবেন এবং তাঁরই দিকে প্রত্যাবর্তণ হবে।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmcclxxxviii{আল্লাহর দ্বীন মেনে নেয়ার পর যারা সে সম্পর্কে বিতর্কে প্রবৃত্ত হয়, তাদের বিতর্ক তাদের পালনকর্তার কাছে বাতিল, তাদের প্রতি আল্লাহর গযব এবং তাদের জন্যে রয়েছে কঠোর আযাব।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmcclxxxix{আল্লাহই সত্যসহ কিতাব ও ইনসাফের মানদন্ড নাযিল করেছেন। আপনি কি জানেন, সম্ভবতঃ কেয়ামত নিকটবর্তী।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmccxc{যারা তাতে বিশ্বাস করে না তারা তাকে তড়িৎ কামনা করে। আর যারা বিশ্বাস করে, তারা তাকে ভয় করে এবং জানে যে, তা সত্য। জেনে রাখ, যারা কেয়ামত সম্পর্কে বিতর্ক করে, তারা দূরবর্তী পথ ভ্রষ্টতায় লিপ্ত রয়েছে।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmccxci{আল্লাহ তাঁর বান্দাদের প্রতি দয়ালু। তিনি যাকে ইচ্ছা, রিযিক দান করেন। তিনি প্রবল, পরাক্রমশালী।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmccxcii{যে কেউ পরকালের ফসল কামনা করে, আমি তার জন্যে সেই ফসল বাড়িয়ে দেই। আর যে ইহকালের ফসল কামনা করে, আমি তাকে তার কিছু দিয়ে দেই এবং পরকালে তার কোন অংশ থাকবে না।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmccxciii{তাদের কি এমন শরীক দেবতা আছে, যারা তাদের জন্যে সে ধর্ম সিদ্ধ করেছে, যার অনুমতি আল্লাহ দেননি ? যদি চুড়ান্ত সিন্ধান্ত না থাকত, তবে তাদের ব্যাপারে ফয়সালা হয়ে যেত। নিশ্চয় যালেমদের জন্যে রয়েছে যন্ত্রণাদায়ক শাস্তি।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmccxciv{আপনি কাফেরদেরকে তাদের কৃতকর্মের জন্যে ভীতসন্ত্রস্ত দেখবেন। তাদের কর্মের শাস্তি অবশ্যই তাদের উপর পতিত হবে। আর যারা মুমিন ও সৎকর্মী, তারা জান্নাতের উদ্যানে থাকবে। তারা যা চাইবে, তাই তাদের জন্যে তাদের পালনকর্তার কাছে রয়েছে। এটাই বড় পুরস্কার।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmccxcv{এরই সুসংবাদ দেন আল্লাহ তার সেসব বান্দাকে, যারা বিশ্বাস স্থাপন করে ও সৎকর্ম করে। বলুন, আমি আমার দাওয়াতের জন্যে তোমাদের কাছে কেবল আত্নীয়তাজনিত সৌহার্দ চাই। যে কেউ উত্তম কাজ করে, আমি তার জন্যে তাতে পুণ্য বাড়িয়ে দেই। নিশ্চয় আল্লাহ ক্ষমাকারী, গুণগ্রাহী।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmccxcvi{নাকি তারা একথা বলে যে, তিনি আল্লাহর বিরুদ্ধে মিথ্যা রটনা করেছেন? আল্লাহ ইচ্ছা করলে আপনার অন্তরে মোহর এঁটে দিতেন। বস্তুতঃ তিনি মিথ্যাকে মিটিয়ে দেন এবং নিজ বাক্য দ্বারা সত্যকে প্রতিষ্ঠিত করেন। নিশ্চয় তিনি অন্তর্নিহিত বিষয় সম্পর্কে সর্বিশেষ জ্ঞাত।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmccxcvii{তিনি তাঁর বান্দাদের তওবা কবুল করেন পাপসমূহ মার্জনা করেন এবং তোমাদের কৃত বিষয় সম্পর্কে অবগত রয়েছেন।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmccxcviii{তিনি মুমিন ও সৎকর্মীদের দোয়া শোনেন এবং তাদের প্রতি স্বীয় অনুগ্রহ বাড়িয়ে দেন। আর কাফেরদের জন্যে রয়েছে কঠোর শাস্তি।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmccxcix{যদি আল্লাহ তাঁর সকল বান্দাকে প্রচুর রিযিক দিতেন, তবে তারা পৃথিবীতে বিপর্যয় সৃষ্টি করত। কিন্তু তিনি যে পরিমাণ ইচ্ছা সে পরিমাণ নাযিল করেন। নিশ্চয় তিনি তাঁর বান্দাদের খবর রাখেন ও সবকিছু দেখেন।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmccc{মানুষ নিরাশ হয়ে যাওয়ার পরে তিনি বৃষ্টি বর্ষণ করেন এবং স্বীয় রহমত ছড়িয়ে দেন। তিনিই কার্যনির্বাহী, প্রশংসিত।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmccci{তাঁর এক নিদর্শন নভোমন্ডল ও ভূমন্ডলের সৃষ্টি এবং এতদুভয়ের মধ্যে তিনি যেসব জীব-জন্তু ছড়িয়ে দিয়েছেন। তিনি যখন ইচ্ছা এগুলোকে একত্রিত করতে সক্ষম।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmcccii{তোমাদের উপর যেসব বিপদ-আপদ পতিত হয়, তা তোমাদের কর্মেরই ফল এবং তিনি তোমাদের অনেক গোনাহ ক্ষমা করে দেন।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmccciii{তোমরা পৃথিবীতে পলায়ন করে আল্লাহকে অক্ষম করতে পার না এবং আল্লাহ ব্যতীত তোমাদের কোন কার্যনির্বাহী নেই, সাহায্যকারীও নেই।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmmccciv{সমুদ্রে ভাসমান পর্বতসম জাহাজসমূহ তাঁর অন্যতম নিদর্শন।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmmcccv{তিনি ইচ্ছা করলে বাতাসকে থামিয়ে দেন। তখন জাহাজসমূহ সমুদ্রপৃষ্ঠে নিশ্চল হয়ে পড়ে যেন পাহাড়। নিশ্চয় এতে প্রত্যেক সবরকারী, কৃতজ্ঞের জন্যে নিদর্শনাবলী রয়েছে।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmmcccvi{অথবা তাদের কৃতকর্মের জন্যে সেগুলোকে ধ্বংস করে দেন এবং অনেককে ক্ষমাও করে দেন।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmmcccvii{এবং যারা আমার ক্ষমতা সম্পর্কে বিতর্ক করে, তারা যেন জানে যে, তাদের কোন পলায়নের জায়গা নেই।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmmcccviii{অতএব, তোমাদেরকে যা দেয়া হয়েছে তা পার্থিব জীবনের ভোগ মাত্র। আর আল্লাহর কাছে যা রয়েছে, তা উৎকৃষ্ট ও স্থায়ী তাদের জন্যে যারা বিশ্বাস স্থাপন করে ও তাদের পালনকর্তার উপর ভরসা করে।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmmcccix{যারা বড় গোনাহ ও অশ্লীল কার্য থেকে বেঁচে থাকে এবং ক্রোধাম্বিত হয়েও ক্ষমা করে,\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmmcccx{যারা তাদের পালনকর্তার আদেশ মান্য করে, নামায কায়েম করে; পারস্পরিক পরামর্শক্রমে কাজ করে এবং আমি তাদেরকে যে রিযিক দিয়েছি, তা থেকে ব্যয় করে,\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmmcccxi{যারা আক্রান্ত হলে প্রতিশোধ গ্রহণ করে।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmmcccxii{আর মন্দের প্রতিফল তো অনুরূপ মন্দই। যে ক্ষমা করে ও আপোষ করে তার পুরস্কার আল্লাহর কাছে রয়েছে; নিশ্চয় তিনি অত্যাচারীদেরকে পছন্দ করেন নাই।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmmcccxiii{নিশ্চয় যে অত্যাচারিত হওয়ার পর প্রতিশোধ গ্রহণ করে, তাদের বিরুদ্ধেও কোন অভিযোগ নেই।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmmcccxiv{অভিযোগ কেবল তাদের বিরুদ্ধে, যারা মানুষের উপর অত্যাচার চালায় এবং পৃথিবীতে অন্যায়ভাবে বিদ্রোহ করে বেড়ায়। তাদের জন্যে রয়েছে যন্ত্রণাদায়ক শাস্তি।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmmcccxv{অবশ্যই যে সবর করে ও ক্ষমা করে নিশ্চয় এটা সাহসিকতার কাজ।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmmcccxvi{আল্লাহ যাকে পথ ভ্রষ্ট করেন, তার জন্যে তিনি ব্যতীত কোন কার্যনির্বাহী নেই। পাপাচারীরা যখন আযাব প্রত্যক্ষ করবে, তখন আপনি তাদেরকে দেখবেন যে, তারা বলছে আমাদের ফিরে যাওয়ার কোন উপায় আছে কি?\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmmcccxvii{জাহান্নামের সামনে উপস্থিত করার সময় আপনি তাদেরকে দেখবেন, অপমানে অবনত এবং অর্ধ নিমীলিত দৃষ্টিতে তাকায়। মুমিনরা বলবে, কেয়ামতের দিন ক্ষতিগ্রস্ত তারাই, যারা নিজেদের ও তাদের পরিবার-পরিজনের ক্ষতি সাধন করেছে। শুনে রাখ, পাপাচারীরা স্থায়ী আযাবে থাকবে।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmmmcccxviii{আল্লাহ তা’আলা ব্যতীত তাদের কোন সাহায্যকারী থাকবে না, যে তাদেরকে সাহায্য করবে। আল্লাহ তা’আলা যাকে পথভ্রষ্ট করেন, তার কোন গতি নেই।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmmmcccxix{আল্লাহ তা’আলার পক্ষ থেকে অবশ্যম্ভাবী দিবস আসার পূর্বে তোমরা তোমাদের পালনকর্তার আদেশ মান্য কর। সেদিন তোমাদের কোন আশ্রয়স্থল থাকবে না এবং তা নিরোধকারী কেউ থাকবে না।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmmmcccxx{যদি তারা মুখ ফিরিয়ে নেয়, তবে আপনাকে আমি তাদের রক্ষক করে পাঠাইনি। আপনার কর্তব্য কেবল প্রচার করা। আমি তাদের রক্ষক করে পাঠাইনি। আপনার কর্তব্য কেবল প্রচার করা। আমি যখন মানুষকে আমার রহমত আস্বাদন করাই, তখন সে উল্লসিত, আর যখন তাদের কৃতকর্মের কারণে তাদের কোন অনিষ্ট ঘটে, তখন মানুষ খুব অকৃতজ্ঞ হয়ে যায়।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmmmcccxxi{নভোমন্ডল ও ভূমন্ডলের রাজত্ব আল্লাহ তা’আলারই। তিনি যা ইচ্ছা, সৃষ্টি করেন, যাকে ইচ্ছা কন্যা-সন্তান এবং যাকে ইচ্ছা পুত্র সন্তান দান করেন।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmmmcccxxii{অথবা তাদেরকে দান করেন পুত্র ও কন্যা উভয়ই এবং যাকে ইচ্ছা বন্ধ্যা করে দেন। নিশ্চয় তিনি সর্বজ্ঞ, ক্ষমতাশীল।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmmmcccxxiii{কোন মানুষের জন্য এমন হওয়ার নয় যে, আল্লাহ তার সাথে কথা বলবেন। কিন্তু ওহীর মাধ্যমে অথবা পর্দার অন্তরাল থেকে অথবা তিনি কোন দূত প্রেরণ করবেন, অতঃপর আল্লাহ যা চান, সে তা তাঁর অনুমতিক্রমে পৌঁছে দেবে। নিশ্চয় তিনি সর্বোচ্চ প্রজ্ঞাময়।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmmmcccxxiv{এমনিভাবে আমি আপনার কাছে এক ফেরেশতা প্রেরণ করেছি আমার আদেশক্রমে। আপনি জানতেন না, কিতাব কি এবং ঈমান কি? কিন্তু আমি একে করেছি নূর, যাদ্দ্বারা আমি আমার বান্দাদের মধ্য থেকে যাকে ইচ্ছা পথ প্রদর্শন করি। নিশ্চয় আপনি সরল পথ প্রদর্শন করেন-\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmmmcccxxv{আল্লাহর পথ। নভোমন্ডল ও ভূমন্ডল যা কিছু আছে, সব তাঁরই। শুনে রাখ, আল্লাহ তা’আলার কাছেই সব বিষয়ে পৌঁছে।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmmmcccxxvi{\basmalahbn হা-মীম।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmcccxxvii{শপথ সুস্পষ্ট কিতাবের,\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmcccxxviii{আমি একে করেছি কোরআন, আরবী ভাষায়, যাতে তোমরা বুঝ।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmcccxxix{নিশ্চয় এ কোরআন আমার কাছে সমুন্নত অটল রয়েছে লওহে মাহফুযে।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmcccxxx{তোমরা সীমাতিক্রমকারী সম্প্রদায়-এ কারণে কি আমি তোমাদের কাছ থেকে কোরআন প্রত্যাহার করে নেব?\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmcccxxxi{পূর্ববর্তী লোকদের কাছে আমি অনেক রসূলই প্রেরণ করেছি।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmcccxxxii{যখনই তাদের কাছে কোন রসূল আগমন করেছেন, তখনই তারা তাঁর সাথে ঠাট্টা-বিদ্রুপ করেছে।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmcccxxxiii{সুতরাং আমি তাদের চেয়ে অধিক শক্তি সম্পন্নদেরকে ধ্বংস করে দিয়েছি। পূর্ববর্তীদের এ ঘটনা অতীত হয়ে গেছে।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmcccxxxiv{আপনি যদি তাদেরকে জিজ্ঞাসা করেন কে নভোমন্ডল ও ভূ-মন্ডল সৃষ্টি করেছে? তারা অবশ্যই বলবে, এগুলো সৃষ্টি করেছেন পরাক্রমশালী সর্বজ্ঞ আল্লাহ।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmcccxxxv{যিনি তোমাদের জন্যে পৃথিবীকে করেছেন বিছানা এবং তাতে তোমাদের জন্যে করেছেন পথ, যাতে তোমরা গন্তব্যস্থলে পৌঁছতে পার।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmcccxxxvi{এবং যিনি আকাশ থেকে পানি বর্ষণ করেছেন পরিমিত। আতঃপর তদ্দ্বারা আমি মৃত ভূ-ভাগকে পুনরুজ্জীবিত করেছি। তোমরা এমনিভাবে উত্থিত হবে।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmcccxxxvii{এবং যিনি সবকিছুর যুগল সৃষ্টি করেছেন এবং নৌকা ও চতুস্পদ জন্তুকে তোমাদের জন্যে যানবাহনে পরিণত করেছেন,\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmcccxxxviii{যাতে তোমরা তাদের পিঠের উপর আরোহণ কর। অতঃপর তোমাদের পালনকর্তার নেয়ামত স্মরণ কর এবং বল পবিত্র তিনি, যিনি এদেরকে আমাদের বশীভূত করে দিয়েছেন এবং আমরা এদেরকে বশীভূত করতে সক্ষম ছিলাম না।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmcccxxxix{আমরা অবশ্যই আমাদের পালনকর্তার দিকে ফিরে যাব।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmcccxl{তারা আল্লাহর বান্দাদের মধ্য থেকে আল্লাহর অংশ স্থির করেছে। বাস্তবিক মানুষ স্পষ্ট অকৃতজ্ঞ।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmcccxli{তিনি কি তাঁর সৃষ্টি থেকে কন্যা সন্তান গ্রহণ করেছেন এবং তোমাদের জন্য মনোনীত করেছেন পুত্র সন্তান?\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmcccxlii{তারা রহমান আল্লাহর জন্যে যে, কন্যা-সন্তান বর্ণনা করে, যখন তাদের কাউকে তার সংবাদ দেয়া হয়, তখন তার মুখমন্ডল কালো হয়ে যায় এবং ভীষণ মনস্তাপ ভোগ করে।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmcccxliii{তারা কি এমন ব্যক্তিকে আল্লাহর জন্যে বর্ণনা করে, যে অলংকারে লালিত-পালিত হয় এবং বিতর্কে কথা বলতে অক্ষম।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmcccxliv{তারা নারী স্থির করে ফেরেশতাগণকে, যারা আল্লাহর বান্দা। তারা কি তাদের সৃষ্টি প্রত্যক্ষ করেছে? এখন তাদের দাবী লিপিবদ্ধ করা হবে এবং তাদের জিজ্ঞাসা করা হবে।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmcccxlv{তারা বলে, রহমান আল্লাহ ইচছা না করলে আমরা ওদের পূজা করতাম না। এ বিষয়ে তারা কিছুই জানে না। তারা কেবল অনুমানে কথা বলে।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmcccxlvi{আমি কি তাদেরকে কোরআনের পূর্বে কোন কিতাব দিয়েছি, অতঃপর তারা তাকে আঁকড়ে রেখেছে?\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmcccxlvii{বরং তারা বলে, আমরা আমাদের পূর্বপুরুষদেরকে পেয়েছি এক পথের পথিক এবং আমরা তাদেরই পদাংক অনুসরণ করে পথপ্রাপ্ত।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmcccxlviii{এমনিভাবে আপনার পূর্বে আমি যখন কোন জনপদে কোন সতর্ককারী প্রেরণ করেছি, তখনই তাদের বিত্তশালীরা বলেছে, আমরা আমাদের পূর্বপুরুষদেরকে পেয়েছি এক পথের পথিক এবং আমরা তাদেরই পদাংক অনুসরণ করে চলছি।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmcccxlix{সে বলত, তোমরা তোমাদের পূর্বপুরুষদেরকে যে বিষয়ের উপর পেয়েছ, আমি যদি তদপেক্ষা উত্তম বিষয় নিয়ে তোমাদের কাছে এসে থাকি, তবুও কি তোমরা তাই বলবে? তারা বলত তোমরা যে বিষয়সহ প্রেরিত হয়েছ, তা আমরা মানব না।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmcccl{অতঃপর আমি তাদের কাছ থেকে প্রতিশোধ নিয়েছি। অতএব দেখুন, মিথ্যারোপকারীদের পরিণাম কিরূপ হয়েছে।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmcccli{যখন ইব্রাহীম তার পিতা ও সম্প্রদায়কে বলল, তোমরা যাদের পূজা কর, তাদের সাথে আমার কোন সম্পর্ক নেই।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmccclii{তবে আমার সম্পর্ক তাঁর সাথে যিনি আমাকে সৃষ্টি করেছেন। অতএব, তিনিই আমাকে সৎপথ প্রদর্শন করবেন।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmcccliii{এ কথাটিকে সে অক্ষয় বাণীরূপে তার সন্তানদের মধ্যে রেখে গেছে, যাতে তারা আল্লাহর দিকেই আকৃষ্ট থাকে।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmcccliv{পরন্ত আমিই এদেরকে ও এদের পূর্বপুরুষদেরকে জীবনোপভোগ করতে দিয়েছি, অবশেষে তাদের কাছে সত্য ও স্পষ্ট বর্ণনাকারী রসূল আগমন করেছে।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmccclv{যখন সত্য তাদের কাছে আগমন করল, তখন তারা বলল, এটা যাদু, আমরা একে মানি না।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmccclvi{তারা বলে, কোরআন কেন দুই জনপদের কোন প্রধান ব্যক্তির উপর অবতীর্ণ হল না?\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmmccclvii{তারা কি আপনার পালনকর্তার রহমত বন্টন করে? আমি তাদের মধ্যে তাদের জীবিকা বন্টন করেছি পার্থিব জীবনে এবং একের মর্যাদাকে অপরের উপর উন্নীত করেছি, যাতে একে অপরকে সেবক রূপে গ্রহণ করে। তারা যা সঞ্চয় করে, আপনার পালনকর্তার রহমত তদপেক্ষা উত্তম।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmmccclviii{যদি সব মানুষের এক মতাবলম্বী হয়ে যাওয়ার আশংকা না থাকত, তবে যারা দয়াময় আল্লাহকে অস্বীকার করে আমি তাদেরকে দিতাম তাদের গৃহের জন্যে রৌপ্য নির্মিত ছাদ ও সিঁড়ি, যার উপর তারা চড়ত।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmmccclix{এবং তাদের গৃহের জন্যে দরজা দিতাম এবং পালংক দিতাম যাতে তারা হেলান দিয়ে বসত।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmmccclx{এবং স্বর্ণনির্মিতও দিতাম। এগুলো সবই তো পার্থিব জীবনের ভোগ সামগ্রী মাত্র। আর পরকাল আপনার পালনকর্তার কাছে তাঁদের জন্যেই যারা ভয় করে।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmmccclxi{যে ব্যক্তি দয়াময় আল্লাহর স্মরণ থেকে চোখ ফিরিয়ে নেয়, আমি তার জন্যে এক শয়তান নিয়োজিত করে দেই, অতঃপর সে-ই হয় তার সঙ্গী।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmmccclxii{শয়তানরাই মানুষকে সৎপথে বাধা দান করে, আর মানুষ মনে করে যে, তারা সৎপথে রয়েছে।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmmccclxiii{অবশেষে যখন সে আমার কাছে আসবে, তখন সে শয়তানকে বলবে, হায়, আমার ও তোমার মধ্যে যদি পূর্ব-পশ্চিমের দূরত্ব থাকত। কত হীন সঙ্গী সে।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmmccclxiv{তোমরা যখন কুফর করছিলে, তখন তোমাদের আজকের আযাবে শরীক হওয়া কোন কাজে আসবে না।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmmccclxv{আপনি কি বধিরকে শোনাতে পারবেন? অথবা যে অন্ধ ও যে স্পষ্ট পথ ভ্রষ্টতায় লিপ্ত, তাকে পথ প্রদর্শণ করতে পারবেন?\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmmccclxvi{অতঃপর আমি যদি আপনাকে নিয়ে যাই, তবু আমি তাদের কাছে থেকে প্রতিশোধ নেব।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmmccclxvii{অথবা যদি আমি তাদেরকে যে আযাবের ওয়াদা দিয়েছি, তা আপনাকে দেখিয়ে দেই, তবু তাদের উপর আমার পূর্ণ ক্ষমতা রয়েছে।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmmccclxviii{অতএব, আপনার প্রতি যে ওহী নাযিল করা হয়, তা দৃঢ়ভাবে অবলম্বন করুন। নিঃসন্দেহে আপনি সরল পথে রয়েছেন।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmmccclxix{এটা আপনার ও আপনার সম্প্রদায়ের জন্যে উল্লেখিত থাকবে এবং শীঘ্রই আপনারা জিজ্ঞাসিত হবেন।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmmccclxx{আপনার পূর্বে আমি যেসব রসূল প্রেরণ করেছি, তাদেরকে জিজ্ঞেস করুন, দয়াময় আল্লাহ ব্যতীত আমি কি কোন উপাস্য স্থির করেছিলাম এবাদতের জন্যে?\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmmmccclxxi{আমি মূসাকে আমার নিদর্শনাবলী দিয়ে ফেরাউন ও তার পরিষদবর্গের কাছে প্রেরণ করেছিলাম, অতঃপর সে বলেছিল, আমি বিশ্ব পালনকর্তার রসূল।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmmmccclxxii{অতঃপর সে যখন তাদের কাছে আমার নিদর্শনাবলী উপস্থাপন করল, তখন তারা হাস্যবিদ্রুপ করতে লাগল।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmmmccclxxiii{আমি তাদেরকে যে নিদর্শনই দেখাতাম, তাই হত পূর্ববর্তী নিদর্শন অপেক্ষা বৃহৎ এবং আমি তাদেরকে শাস্তি দ্বারা পাকড়াও করলাম, যাতে তারা ফিরে আসে।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmmmccclxxiv{তারা বলল, হে যাদুকর, তুমি আমাদের জন্যে তোমার পালনকর্তার কাছে সে বিষয় প্রার্থনা কর, যার ওয়াদা তিনি তোমাকে দিয়েছেন; আমরা অবশ্যই সৎপথ অবলম্বন করব।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmmmccclxxv{অতঃপর যখন আমি তাদের থেকে আযাব প্রত্যাহার করে নিলাম, তখনই তারা অঙ্গীকার ভঙ্গ করতে লাগলো।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmmmccclxxvi{ফেরাউন তার সম্প্রদায়কে ডেকে বলল, হে আমার কওম, আমি কি মিসরের অধিপতি নই? এই নদী গুলো আমার নিম্নদেশে প্রবাহিত হয়, তোমরা কি দেখ না?\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmmmccclxxvii{আমি যে শ্রেষ্ট এ ব্যক্তি থেকে, যে নীচ এবং কথা বলতেও সক্ষম নয়।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmmmccclxxviii{তাকে কেন স্বর্ণবলয় পরিধান করানো হল না, অথবা কেন আসল না তার সঙ্গে ফেরেশতাগণ দল বেঁধে?\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmmmccclxxix{অতঃপর সে তার সম্প্রদায়কে বোকা বানিয়ে দিল, ফলে তারা তার কথা মেনে নিল। নিশ্চয় তারা ছিল পাপাচারী সম্প্রদায়।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmmmccclxxx{অতঃপর যখন আমাকে রাগাম্বিত করল তখন আমি তাদের কাছ থেকে প্রতিশোধ নিলাম এবং নিমজ্জত করলাম। তাদের সবাইকে।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mmmmccclxxxi{অতঃপর আমি তাদেরকে করে দিলাম অতীত লোক ও দৃষ্টান্ত পরবর্তীদের জন্যে।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mmmmccclxxxii{যখনই মরিয়ম তনয়ের দৃষ্টান্ত বর্ণনা করা হল, তখনই আপনার সম্প্রদায় হঞ্জগোল শুরু করে দিল\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mmmmccclxxxiii{এবং বলল, আমাদের উপাস্যরা শ্রেষ্ঠ, না সে? তারা আপনার সামনে যে উদাহরণ উপস্থাপন করে তা কেবল বিতর্কের জন্যেই করে। বস্তুতঃ তারা হল এক বিতর্ককারী সম্প্রদায়।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mmmmccclxxxiv{সে তো এক বান্দাই বটে আমি তার প্রতি অনুগ্রহ করেছি এবং তাকে করেছি বণী-ইসরাঈলের জন্যে আদর্শ।\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mmmmccclxxxv{আমি ইচ্ছা করলে তোমাদের থেকে ফেরেশতা সৃষ্টি করতাম, যারা পৃথিবীতে একের পর এক বসবাস করত।\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mmmmccclxxxvi{সুতরাং তা হল কেয়ামতের নিদর্শন। কাজেই তোমরা কেয়ামতে সন্দেহ করো না এবং আমার কথা মান। এটা এক সরল পথ।\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mmmmccclxxxvii{শয়তান যেন তোমাদেরকে নিবৃত্ত না করে। সে তোমাদের প্রকাশ্য শুত্রু।\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mmmmccclxxxviii{ঈসা যখন স্পষ্ট নিদর্শনসহ আগমন করল, তখন বলল, আমি তোমাদের কাছে প্রজ্ঞা নিয়ে এসেছি এবং তোমরা যে, কোন কোন বিষয়ে মতভেদ করছ তা ব্যক্ত করার জন্যে এসেছি, অতএব, তোমরা আল্লাহকে ভয় কর এবং আমার কথা মান।\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mmmmccclxxxix{নিশ্চয় আল্লাহই আমার পালনকর্তা ও তোমাদের পালনকর্তা। অতএব, তাঁর এবাদত কর। এটা হল সরল পথ।\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mmmmcccxc{অতঃপর তাদের মধ্যে থেকে বিভিন্ন দল মতভেদ সৃষ্টি করল। সুতরাং যালেমদের জন্যে রয়েছে যন্ত্রণাদায়ক দিবসের আযাবের দুর্ভোগ।\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mmmmcccxci{তারা কেবল কেয়ামতেরই অপেক্ষা করছে যে, আকস্মিকভাবে তাদের কাছে এসে যাবে এবং তারা খবর ও রাখবে না।\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mmmmcccxcii{বন্ধুবর্গ সেদিন একে অপরের শত্রু হবে, তবে খোদাভীরুরা নয়।\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mmmmcccxciii{হে আমার বান্দাগণ, তোমাদের আজ কোন ভয় নেই এবং তোমরা দুঃখিতও হবে না।\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mmmmcccxciv{তোমরা আমার আয়াতসমূহে বিশ্বাস স্থাপন করেছিলে এবং তোমরা আজ্ঞাবহ ছিলে।\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mmmmcccxcv{জান্নাতের প্রবেশ কর তোমরা এবং তোমাদের বিবিগণ সানন্দে।\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@mmmmcccxcvi{তাদের কাছে পরিবেশন করা হবে স্বর্ণের থালা ও পানপাত্র এবং তথায় রয়েছে মনে যা চায় এবং নয়ন যাতে তৃপ্ত হয়। তোমরা তথায় চিরকাল অবস্থান করবে।\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@mmmmcccxcvii{এই যে, জান্নাতের উত্তরাধিকারী তোমরা হয়েছ, এটা তোমাদের কর্মের ফল।\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@mmmmcccxcviii{তথায় তোমাদের জন্যে আছে প্রচুর ফল-মূল, তা থেকে তোমরা আহার করবে।\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@mmmmcccxcix{নিশ্চয় অপরাধীরা জাহান্নামের আযাবে চিরকাল থাকবে।\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@mmmmcd{তাদের থেকে আযাব লাঘব করা হবে না এবং তারা তাতেই থাকবে হতাশ হয়ে।\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@mmmmcdi{আমি তাদের প্রতি জুলুম করিনি; কিন্তু তারাই ছিল জালেম।\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@mmmmcdii{তারা ডেকে বলবে, হে মালেক, পালনকর্তা আমাদের কিসসাই শেষ করে দিন। সে বলবে, নিশ্চয় তোমরা চিরকাল থাকবে।\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@mmmmcdiii{আমি তোমাদের কাছে সত্যধর্ম পৌঁছিয়েছি; কিন্তু তোমাদের অধিকাংশই সত্যধর্মে নিস্পৃহ!\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@mmmmcdiv{তারা কি কোন ব্যবস্থা চুড়ান্ত করেছে? তাহলে আমিও এক ব্যবস্থা চুড়ান্ত করেছি।\qt@no{(79)}}
\qt@newcmd\qurantrans@bn@mmmmcdv{তারা কি মনে করে যে, আমি তাদের গোপন বিষয় ও গোপন পরামর্শ শুনি না? হঁ্যা, শুনি। আমার ফেরেশতাগণ তাদের নিকটে থেকে লিপিবদ্ধ করে।\qt@no{(80)}}
\qt@newcmd\qurantrans@bn@mmmmcdvi{বলুন, দয়াময় আল্লাহর কোন সন্তান থাকলে আমি সর্ব প্রথম তার এবাদত করব।\qt@no{(81)}}
\qt@newcmd\qurantrans@bn@mmmmcdvii{তারা যা বর্ণনা করে, তা থেকে নভোমন্ডল ও ভূমন্ডলের পালনকর্তা, আরশের পালনকর্তা পবিত্র।\qt@no{(82)}}
\qt@newcmd\qurantrans@bn@mmmmcdviii{অতএব, তাদেরকে বাকচাতুরী ও ক্রীড়া-কৌতুক করতে দিন সেই দিবসের সাক্ষাত পর্যন্ত, যার ওয়াদা তাদেরকে দেয়া হয়।\qt@no{(83)}}
\qt@newcmd\qurantrans@bn@mmmmcdix{তিনিই উপাস্য নভোমন্ডলে এবং তিনিই উপাস্য ভুমন্ডলে। তিনি প্রজ্ঞাময়, সর্বজ্ঞ,\qt@no{(84)}}
\qt@newcmd\qurantrans@bn@mmmmcdx{বরকতময় তিনিই, নভোমন্ডল, ভূমন্ডল ও এতদুভয়ের মধ্যবর্তী সবকিছু যার। তাঁরই কাছে আছে কেয়ামতের জ্ঞান এবং তাঁরই দিকে তোমরা প্রত্যাবর্তিত হবে।\qt@no{(85)}}
\qt@newcmd\qurantrans@bn@mmmmcdxi{তিনি ব্যতীত তারা যাদের পুজা করে, তারা সুপারিশের অধিকারী হবে না, তবে যারা সত্য স্বীকার করত ও বিশ্বাস করত।\qt@no{(86)}}
\qt@newcmd\qurantrans@bn@mmmmcdxii{যদি আপনি তাদেরকে জিজ্ঞাসা করেন, কে তাদেরকে সৃষ্টি করেছেন, তবে অবশ্যই তারা বলবে, আল্লাহ, অতঃপর তারা কোথায় ফিরে যাচ্ছে ?\qt@no{(87)}}
\qt@newcmd\qurantrans@bn@mmmmcdxiii{রসূলের এই উক্তির কসম, হে আমার পালনকর্তা, এ সম্প্রদায় তো বিশ্বাস স্থাপন করে না।\qt@no{(88)}}
\qt@newcmd\qurantrans@bn@mmmmcdxiv{অতএব, আপনি তাদের থেকে মুখ ফিরিয়ে নিন এবং বলুন, ‘সালাম’। তারা শীঘ্রই জানতে পারবে।\qt@no{(89)}}
\qt@newcmd\qurantrans@bn@mmmmcdxv{\basmalahbn হা-মীম।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmcdxvi{শপথ সুস্পষ্ট কিতাবের।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmcdxvii{আমি একে নাযিল করেছি। এক বরকতময় রাতে, নিশ্চয় আমি সতর্ককারী।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmcdxviii{এ রাতে প্রত্যেক প্রজ্ঞাপূর্ণ বিষয় স্থিরীকৃত হয়।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmcdxix{আমার পক্ষ থেকে আদেশক্রমে, আমিই প্রেরণকারী।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmcdxx{আপনার পালনকর্তার পক্ষ থেকে রহমতস্বরূপ। তিনি সর্বশ্রোতা, সর্বজ্ঞ।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmcdxxi{যদি তোমাদের বিশ্বাস থাকে দেখতে পাবে। তিনি নভোমন্ডল, ভূমন্ডল ও এতদুভয়ের মধ্যেবর্তী সবকিছুর পালনকর্তা।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmcdxxii{তিনি ব্যতীত কোন উপাস্য নেই। তিনি জীবন দান করেন ও মৃত্যু দেন। তিনি তোমাদের পালনকর্তা এবং তোমাদের পূর্ববর্তী পিতৃ-পুরুষদেরও পালনকর্তা।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmcdxxiii{এতদসত্ত্বেও এরা সন্দেহে পতিত হয়ে ক্রীড়া-কৌতুক করছে।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmcdxxiv{অতএব আপনি সেই দিনের অপেক্ষা করুন, যখন আকাশ ধূয়ায় ছেয়ে যাবে।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmcdxxv{যা মানুষকে ঘিরে ফেলবে। এটা যন্ত্রণাদায়ক শাস্তি।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmcdxxvi{হে আমাদের পালনকর্তা আমাদের উপর থেকে শাস্তি প্রত্যাহার করুন, আমরা বিশ্বাস স্থাপন করছি।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmcdxxvii{তারা কি করে বুঝবে, অথচ তাদের কাছে এসেছিলেন স্পষ্ট বর্ণনাকারী রসূল।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmcdxxviii{অতঃপর তারা তাকে পৃষ্ঠপ্রদর্শন করে এবং বলে, সে তো উম্মাদ-শিখানো কথা বলে।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmcdxxix{আমি তোমাদের উপর থেকে আযাব কিছুটা প্রত্যাহার করব, কিন্তু তোমরা পুনরায় পুনর্বস্থায় ফিরে যাবে।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmcdxxx{যেদিন আমি প্রবলভাবে ধৃত করব, সেদিন পুরোপুরি প্রতিশোধ গ্রহণ করবই।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmcdxxxi{তাদের পূর্বে আমি ফেরাউনের সম্প্রদায়কে পরীক্ষা করেছি এবং তাদের কাছে আগমন করেছেন একজন সম্মানিত রসূল,\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmcdxxxii{এই মর্মে যে, আল্লাহর বান্দাদেরকে আমার কাছে অর্পণ কর। আমি তোমাদের জন্য প্রেরীত বিশ্বস্ত রসূল।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmcdxxxiii{আর তোমরা আল্লাহর বিরুদ্ধে ঔদ্ধত্য প্রকাশ করো না। আমি তোমাদের কাছে প্রকাশ্য প্রমাণ উপস্থিত করছি।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmcdxxxiv{তোমরা যাতে আমাকে প্রস্তরবর্ষণে হত্যা না কর, তজ্জন্যে আমি আমার পালনকর্তা ও তোমাদের পালনকর্তার শরনাপন্ন হয়েছি।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmcdxxxv{তোমরা যদি আমার প্রতি বিশ্বাস স্থাপন না কর, তবে আমার কাছ থেকে দূরে থাক।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmcdxxxvi{অতঃপর সে তার পালনকর্তার কাছে দোয়া করল যে, এরা অপরাধী সম্প্রদায়।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmcdxxxvii{তাহলে তুমি আমার বান্দাদেরকে নিয়ে রাত্রিবেলায় বের হয়ে পড়। নিশ্চয় তোমাদের পশ্চাদ্ধবন করা হবে।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmcdxxxviii{এবং সমুদ্রকে অচল থাকতে দাও। নিশ্চয় ওরা নিমজ্জত বাহিনী।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmcdxxxix{তারা ছেড়ে গিয়েছিল কত উদ্যান ও প্রস্রবন,\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmcdxl{কত শস্যক্ষেত্র ও সূরম্য স্থান।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmcdxli{কত সুখের উপকরণ, যাতে তারা খোশগল্প করত।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmcdxlii{এমনিই হয়েছিল এবং আমি ওগুলোর মালিক করেছিলাম ভিন্ন সম্প্রদায়কে।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmcdxliii{তাদের জন্যে ক্রন্দন করেনি আকাশ ও পৃথিবী এবং তারা অবকাশও পায়নি।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmcdxliv{আমি বনী-ইসরাঈলকে অপমানজনক শাস্তি থেকে উদ্ধার করছি।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmcdxlv{ফেরাউন সে ছিল সীমালংঘনকারীদের মধ্যে শীর্ষস্থানীয়।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmmcdxlvi{আমি জেনেশুনে তাদেরকে বিশ্ববাসীদের উপর শ্রেষ্ঠত্ব দিয়েছিলাম।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmmcdxlvii{এবং আমি তাদেরকে এমন নিদর্শনাবলী দিয়েছিলাম যাতে ছিল স্পষ্ট সাহায্য।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmmcdxlviii{কাফেররা বলেই থাকে,\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmmcdxlix{প্রথম মৃত্যুর মাধ্যমেই আমাদের সবকিছুর অবসান হবে এবং আমরা পুনরুত্থিত হব না।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmmcdl{তোমরা যদি সত্যবাদী হও, তবে আমাদের পূর্বপুরুষদেরকে নিয়ে এস।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmmcdli{ওরা শ্রেষ্ঠ, না তুব্বার সম্প্রদায় ও তাদের পূর্ববর্তীরা? আমি ওদেরকে ধ্বংস করে দিয়েছি। ওরা ছিল অপরাধী।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmmcdlii{আমি নভোমন্ডল, ভূমন্ডল ও এতদুভয়ের মধ্যবর্তী সবকিছু ক্রীড়াচ্ছলে সৃষ্টি করিনি।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmmcdliii{আমি এগুলো যথাযথ উদ্দেশ্যে সৃষ্টি করেছি; কিন্তু তাদের অধিকাংশই বোঝে না।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmmcdliv{নিশ্চয় ফয়সালার দিন তাদের সবারই নির্ধারিত সময়।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmmcdlv{যেদিন কোন বন্ধুই কোন বন্ধুর উপকারে আসবে না এবং তারা সাহায্যপ্রাপ্তও হবে না।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmmcdlvi{তবে আল্লাহ যার প্রতি দয়া করেন, তার কথা ভিন্ন। নিশ্চয় তিনি পরাক্রমশালী দয়াময়।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmmcdlvii{নিশ্চয় যাক্কুম বৃক্ষ\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmmcdlviii{পাপীর খাদ্য হবে;\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmmcdlix{গলিত তাম্রের মত পেটে ফুটতে থাকবে।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmmmcdlx{যেমন ফুটে পানি।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxi{একে ধর এবং টেনে নিয়ে যাও জাহান্নামের মধ্যস্থলে,\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxii{অতঃপর তার মাথার উপর ফুটন্ত পানির আযাব ঢেলে দাও,\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxiii{স্বাদ গ্রহণ কর, তুমি তো সম্মানিত, সম্ভ্রান্ত।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxiv{এ সম্পর্কে তোমরা সন্দেহে পতিত ছিলে।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxv{নিশ্চয় খোদাভীরুরা নিরাপদ স্থানে থাকবে-\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxvi{উদ্যানরাজি ও নির্ঝরিণীসমূহে।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxvii{তারা পরিধান করবে চিকন ও পুরু রেশমীবস্ত্র, মুখোমুখি হয়ে বসবে।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxviii{এরূপই হবে এবং আমি তাদেরকে আনতলোচনা স্ত্রী দেব।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxix{তারা সেখানে শান্ত মনে বিভিন্ন ফল-মূল আনতে বলবে।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxx{তারা সেখানে মৃত্যু আস্বাদন করবে না, প্রথম মৃত্যু ব্যতীত এবং আপনার পালনকর্তা তাদেরকে জাহান্নামের আযাব থেকে রক্ষা করবেন।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxxi{আপনার পালনকর্তার কৃপায় এটাই মহা সাফল্য।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxxii{আমি আপনার ভাষায় কোরআনকে সহজ করে দিয়েছি, যাতে তারা স্মরণ রাখে।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxxiii{অতএব, আপনি অপেক্ষা করুন, তারাও অপেক্ষা করছে।\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxxiv{\basmalahbn হা-মীম।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxxv{পরাক্রান্ত, প্রজ্ঞাময় আল্লাহর পক্ষ থেকে অবতীর্ণ এ কিতাব।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxxvi{নিশ্চয় নভোমন্ডল ও ভূ-মন্ডলে মুমিনদের জন্যে নিদর্শনাবলী রয়েছে।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxxvii{আর তোমাদের সৃষ্টিতে এবং চারদিকে ছড়িয়ে রাখা জীব জন্তুর সৃজনের মধ্যেও নিদর্শনাবলী রয়েছে বিশ্বাসীদের জন্য।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxxviii{দিবারাত্রির পরিবর্তনে, আল্লাহ আকাশ থেকে যে রিযিক (বৃষ্টি) বর্ষণ করেন অতঃপর পৃথিবীকে তার মৃত্যুর পর পুনরুজ্জীবিত করেন, তাতে এবং বায়ুর পরিবর্তনে বুদ্ধিমানদের জন্যে নিদর্শনাবলী রয়েছে।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxxix{এগুলো আল্লাহর আয়াত, যা আমি আপনার কাছে আবৃত্তি করি যথাযথরূপে। অতএব, আল্লাহ ও তাঁর আয়াতের পর তারা কোন কথায় বিশ্বাস স্থাপন করবে।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxxx{প্রত্যেক মিথ্যাবাদী পাপাচারীর দুর্ভোগ।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxxxi{সে আল্লাহর আয়াতসমূহ শুনে, অতঃপর অহংকারী হয়ে জেদ ধরে, যেন সে আয়াত শুনেনি। অতএব, তাকে যন্ত্রণাদায়ক শাস্তির সুসংবাদ দিন।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxxxii{যখন সে আমার কোন আয়াত অবগত হয়, তখন তাকে ঠাট্টারূপে গ্রহণ করে। এদের জন্যই রয়েছে লাঞ্ছনাদায়ক শাস্তি।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxxxiii{তাদের সামনে রয়েছে জাহান্নাম। তারা যা উপার্জন করেছে, তা তাদের কোন কাজে আসবে না, তারা আল্লাহর পরিবর্তে যাদেরকে বন্ধুরূপে গ্রহণ করেছে তারাও নয়। তাদের জন্যে রয়েছে মহাশাস্তি।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxxxiv{এটা সৎপথ প্রদর্শন, আর যারা তাদের পালনকর্তার আয়াতসমূহ অস্বীকার করে, তাদের জন্যে রয়েছে কঠোর যন্ত্রণাদায়ক শাস্তি।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxxxv{তিনি আল্লাহ যিনি সমুদ্রকে তোমাদের উপকারার্থে আয়ত্বাধীন করে দিয়েছেন, যাতে তাঁর আদেশক্রমে তাতে জাহাজ চলাচল করে এবং যাতে তোমরা তাঁর অনুগ্রহ তালাশ কর ও তাঁর প্রতি কৃতজ্ঞ হও।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxxxvi{এবং আয়ত্ত্বাধীন করে দিয়েছেন তোমাদের, যা আছে নভোমন্ডলে ও যা আছে ভূমন্ডলে; তাঁর পক্ষ থেকে। নিশ্চয় এতে চিন্তাশীল সম্প্রদায়ের জন্যে নিদর্শনাবলী রয়েছে।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxxxvii{মুমিনদেরকে বলুন, তারা যেন তাদেরকে ক্ষমা করে, যারা আল্লাহর সে দিনগুলো সম্পর্কে বিশ্বাস রাখে না যাতে তিনি কোন সম্প্রদায়কে কৃতকর্মের প্রতিফল দেন।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxxxviii{যে সৎকাজ করছে, সে নিজের কল্যাণার্থেই তা করছে, আর যে অসৎকাজ করছে, তা তার উপরই বর্তাবে। অতঃপর তোমরা তোমাদের পালনকর্তার দিকে প্রত্যাবর্তিত হবে।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmcdlxxxix{আমি বনী ইসরাঈলকে কিতাব, রাজত্ব ও নবুওয়ত দান করেছিলাম এবং তাদেরকে পরিচ্ছন্ন রিযিক দিয়েছিলাম এবং বিশ্ববাসীর উপর শ্রেষ্ঠত্ব দিয়েছিলাম।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmcdxc{আরও দিয়েছিলাম তাদেরকে ধর্মের সুস্পষ্ট প্রমাণাদি। অতঃপর তারা জ্ঞান লাভ করার পর শুধু পারস্পরিক জেদের বশবর্তী হয়ে মতভেদ সৃষ্টি করেছে। তারা যে বিষয়ে মতভেদ করত, আপনার পালনকর্তা কেয়ামতের দিন তার ফয়সালা করে দেবেন।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmcdxci{এরপর আমি আপনাকে রেখেছি ধর্মের এক বিশেষ শরীয়তের উপর। অতএব, আপনি এর অনুসরণ করুন এবং অজ্ঞানদের খেয়াল-খুশীর অনুসরণ করবেন না।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmcdxcii{আল্লাহর সামনে তারা আপনার কোন উপকারে আসবে না। যালেমরা একে অপরের বন্ধু। আর আল্লাহ পরহেযগারদের বন্ধু।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmcdxciii{এটা মানুষের জন্যে জ্ঞানের কথা এবং বিশ্বাসী সম্প্রদায়ের জন্য হেদায়েত ও রহমত।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmcdxciv{যারা দুস্কর্ম উপার্জন করেছে তারা কি মনে করে যে, আমি তাদেরকে সে লোকদের মত করে দেব, যারা ঈমান আনে ও সৎকর্ম করে এবং তাদের জীবন ও মুত্যু কি সমান হবে? তাদের দাবী কত মন্দ।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmcdxcv{আল্লাহ নভোমন্ডল ও ভূ-মন্ডল যথাযথভাবে সৃষ্টি করেছেন, যাতে প্রত্যেক ব্যক্তি তার উপার্জনের ফল পায়। তাদের প্রতি যুলুম করা হবে না।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmcdxcvi{আপনি কি তার প্রতি লক্ষ্য করেছেন, যে তার খেয়াল-খুশীকে স্বীয় উপাস্য স্থির করেছে? আল্লাহ জেনে শুনে তাকে পথভ্রষ্ট করেছেন, তার কান ও অন্তরে মহর এঁটে দিয়েছেন এবং তার চোখের উপর রেখেছেন পর্দা। অতএব, আল্লাহর পর কে তাকে পথ প্রদর্শন করবে? তোমরা কি চিন্তাভাবনা কর না?\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmcdxcvii{তারা বলে, আমাদের পার্থিব জীবনই তো শেষ; আমরা মরি ও বাঁচি মহাকালই আমাদেরকে ধ্বংস করে। তাদের কাছে এ ব্যাপারে কোন জ্ঞান নেই। তারা কেবল অনুমান করে কথা বলে।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmcdxcviii{তাদের কাছে যখন আমার সুস্পষ্ট আয়াতসমূহ পাঠ করা হয়, তখন একথা বলা ছাড়া তাদের কোন মুক্তিই থাকে না যে, তোমরা সত্যবাদী হলে আমাদের পূর্বপুরুষদেরকে নিয়ে আস।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmcdxcix{আপনি বলুন, আল্লাহই তোমাদেরকে জীবন দান করেন, অতঃপর মৃত্যু দেন, অতঃপর তোমাদেরকে কেয়ামতের দিন একত্রিত করবেন, যাতে কোন সন্দেহ নেই। কিন্তু অধিকাংশ মানুষ বোঝে না।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmd{নভোমন্ডল ও ভূ-মন্ডলের রাজত্ব আল্লাহরই। যেদিন কেয়ামত সংঘটিত হবে, সেদিন মিথ্যাপন্থীরা ক্ষতিগ্রস্ত হবে।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmdi{আপনি প্রত্যেক উম্মতকে দেখবেন নতজানু অবস্থায়। প্রত্যেক উম্মতকে তাদের আমলনামা দেখতে বলা হবে। তোমরা যা করতে, অদ্য তোমারদেরকে তার প্রতিফল দেয়া হবে।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmdii{আমার কাছে রক্ষিত এই আমলনামা তোমাদের সম্পর্কে সত্য কথা বলবে। তোমরা যা করতে আমি তা লিপিবদ্ধ করতাম।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmdiii{যারা বিশ্বাস স্থাপন করেছে ও সৎকর্ম করেছে, তাদেরকে তাদের পালনকর্তা স্বীয় রহমতে দাখিল করবেন। এটাই প্রকাশ্য সাফল্য।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmdiv{আর যারা কুফর করেছে, তাদেরকে জিজ্ঞাসা করা হবে, তোমাদের কাছে কি আয়াতসমূহ পঠিত হত না? কিন্তু তোমরা অহংকার করছিলে এবং তোমরা ছিলে এক অপরাধী সম্প্রদায়।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmmdv{যখন বলা হত, আল্লাহর ওয়াদা সত্য এবং কেয়ামতে কোন সন্দেহ নেই, তখন তোমরা বলতে আমরা জানি না কেয়ামত কি ? আমরা কেবল ধারণাই করি এবং এ বিষয়ে আমরা নিশ্চিত নই।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmmdvi{তাদের মন্দ কর্ম গুলো তাদের সামনে প্রকাশ হয়ে পড়বে এবং যে আযাব নিয়ে তারা ঠাট্টা-বিদ্রুপ করত, তা তাদেরকে গ্রাস করবে।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmmdvii{বলা হবে, আজ আমি তোমাদেরকে ভুলে যাব, যেমন তোমরা এ দিনের সাক্ষাৎকে ভুলে গিয়েছিলে। তোমাদের আবাসস্থল জাহান্নাম এবং তোমাদের সাহায্যকারী নেই।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmmdviii{এটা এজন্যে যে, তোমরা আল্লাহর আয়াতসমূহকে ঠাট্টারূপে গ্রহণ করেছিলে এবং পার্থিব জীবন তোমাদেরকে প্রতারিত করেছিল। সুতরাং আজ তাদেরকে জাহান্নাম থেকে বের করা হবে না এবং তাদের কাছে তওবা চাওয়া হবে না।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmmdix{অতএব, বিশ্বজগতের পালনকর্তা, ভূ-মন্ডলের পালনকর্তা ও নভোমন্ডলের পালনকর্তা আল্লাহর-ই প্রশংসা।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmmdx{নভোমন্ডলে ও ভূ-মন্ডলে তাঁরই গৌরব। তিনি পরাক্রমশালী, প্রজ্ঞাময়।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmmdxi{\basmalahbn হা-মীম।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmdxii{এই কিতাব পরাক্রমশালী, প্রজ্ঞাময় আল্লাহর পক্ষ থেকে অবতীর্ণ।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmdxiii{নভোমন্ডল, ভূ-মন্ডল ও এতদুভয়ের মধ্যবর্তী সবকিছু আমি যথাযথভাবেই এবং নির্দিষ্ট সময়ের জন্যেই সৃষ্টি করেছি। আর কাফেররা যে বিষয়ে তাদেরকে সতর্ক করা হয়েছে, তা থেকে মুখ ফিরিয়ে নেয়।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmdxiv{বলুন, তোমরা আল্লাহ ব্যতীত যাদের পূজা কর, তাদের বিষয়ে ভেবে দেখেছ কি? দেখাও আমাকে তারা পৃথিবীতে কি সৃষ্টি করেছে? অথবা নভোমন্ডল সৃজনে তাদের কি কোন অংশ আছে? এর পূর্ববর্তী কোন কিতাব অথবা পরস্পরাগত কোন জ্ঞান আমার কাছে উপস্থিত কর, যদি তোমরা সত্যবাদী হও।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmdxv{যে ব্যক্তি আল্লাহর পরিবর্তে এমন বস্তুর পূজা করে, যে কেয়ামত পর্যন্তও তার ডাকে সাড়া দেবে না, তার চেয়ে অধিক পথভ্রষ্ট আর কে? তারা তো তাদের পুজা সম্পর্কেও বেখবর।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmdxvi{যখন মানুষকে হাশরে একত্রিত করা হবে, তখন তারা তাদের শত্রু হবে এবং তাদের এবাদত অস্বীকার করবে।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmdxvii{যখন তাদেরকে আমার সুস্পষ্ট আয়াতসমূহ পাঠ করে শুনানো হয়, তখন সত্য আগমন করার পর কাফেররা বলে, এ তো প্রকাশ্য জাদু।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmdxviii{তারা কি বলে যে, রসূল একে রচনা করেছে? বলুন, যদি আমি রচনা করে থাকি, তবে তোমরা আল্লাহর শাস্তি থেকে আমাকে রক্ষা করার অধিকারী নও। তোমরা এ সম্পর্কে যা আলোচনা কর, সে বিষয়ে আল্লাহ সম্যক অবগত। আমার ও তোমাদের মধ্যে তিনি সাক্ষী হিসাবে যথেষ্ট। তিনি ক্ষমাশীল, দয়াময়।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmdxix{বলুন, আমি তো কোন নতুন রসূল নই। আমি জানি না, আমার ও তোমাদের সাথে কি ব্যবহার করা হবে। আমি কেবল তারই অনুসরণ করি, যা আমার প্রতি ওহী করা হয়। আমি স্পষ্ট সতর্ক কারী বৈ নই।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmdxx{বলুন, তোমরা ভেবে দেখেছ কি, যদি এটা আল্লাহর পক্ষ থেকে হয় এবং তোমরা একে অমান্য কর এবং বনী ইসরাঈলের একজন সাক্ষী এর পক্ষে সাক্ষ্য দিয়ে এতে বিশ্বাস স্থাপন করে; আর তোমরা অহংকার কর, তবে তোমাদের চেয়ে অবিবেচক আর কে হবে? নিশ্চয় আল্লাহ অবিবেচকদেরকে পথ দেখান না।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmdxxi{আর কাফেররা মুমিনদের বলতে লাগল যে, যদি এ দ্বীন ভাল হত তবে এরা আমাদেরকে পেছনে ফেলে এগিয়ে যেতে পারত না। তারা যখন এর মাধ্যমে সুপথ পায়নি, তখন শীঘ্রই বলবে, এ তো এক পুরাতন মিথ্যা।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmdxxii{এর আগে মূসার কিতাব ছিল পথপ্রদর্শক ও রহমতস্বরূপ। আর এই কিতাব তার সমর্থক আরবী ভাষায়, যাতে যালেমদেরকে সতর্ক করে এবং সৎকর্মপরায়ণদেরকে সুসংবাদ দেয়।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmdxxiii{নিশ্চয় যারা বলে, আমাদের পালনকর্তা আল্লাহ অতঃপর অবিচল থাকে, তাদের কোন ভয় নেই এবং তারা চিন্তিত হবে না।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmdxxiv{তারাই জান্নাতের অধিকারী! তারা তথায় চিরকাল থাকবে। তারা যে কর্ম করত, এটা তারই প্রতিফল।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmdxxv{আমি মানুষকে তার পিতা-মাতার সাথে সদ্ব্যবহারের আদেশ দিয়েছি। তার জননী তাকে কষ্টসহকারে গর্ভে ধারণ করেছে এবং কষ্টসহকারে প্রসব করেছে। তাকে গর্ভে ধারণ করতে ও তার স্তন্য ছাড়তে লেগেছে ত্রিশ মাস। অবশেষে সে যখন শক্তি-সামর্থে?480; বয়সে ও চল্লিশ বছরে পৌছেছে, তখন বলতে লাগল, হে আমার পালনকর্তা, আমাকে এরূপ ভাগ্য দান কর, যাতে আমি তোমার নেয়ামতের শোকর করি, যা তুমি দান করেছ আমাকে ও আমার পিতা-মাতাকে এবং যাতে আমি তোমার পছন্দনীয় সৎকাজ করি। আমার সন্তানদেরকে সৎকর্মপরায়ণ কর, আমি তোমার প্রতি তওবা করলাম এবং আমি আজ্ঞাবহদের অন্যতম।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmdxxvi{আমি এমন লোকদের সুকর্মগুলো কবুল করি এবং মন্দকর্মগুলো মার্জনা করি। তারা জান্নাতীদের তালিকাভুক্ত সেই সত্য ওয়াদার কারণে যা তাদেরকে দেওয়া হত।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmdxxvii{আর যে ব্যক্তি তার পিতা-মাতাকে বলে, ধিক তোমাদেরকে, তোমরা কি আমাকে খবর দাও যে, আমি পুনরুত্থিত হব, অথচ আমার পূর্বে বহু লোক গত হয়ে গেছে? আর পিতা-মাতা আল্লাহর কাছে ফরিযাদ করে বলে, দুর্ভোগ তোমার তুমি বিশ্বাস স্থাপন কর। নিশ্চয় আল্লাহর ওয়াদা সত্য। তখন সে বলে, এটা তো পূর্ববর্তীদের উপকথা বৈ নয়।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmdxxviii{তাদের পূর্বে যে সব জ্বিন ও মানুষ গত হয়েছে, তাদের মধ্যে এ ধরনের লোকদের প্রতিও শাস্তিবানী অবধারিত হয়ে গেছে। নিশ্চয় তারা ছিল ক্ষতিগ্রস্থ।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmdxxix{প্রত্যেকের জন্যে তাদের কৃতকর্ম অনুযায়ী বিভিন্ন স্তর রয়েছে, যাতে আল্লাহ তাদের কর্মের পূর্ণ প্রতিফল দেন। বস্তুতঃ তাদের প্রতি যুলুম করা হবে না।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmdxxx{যেদিন কাফেরদেরকে জাহান্নামের কাছে উপস্থিত করা হবে সেদিন বলা হবে, তোমরা তোমাদের সুখ পার্থিব জীবনেই নিঃশেষ করেছ এবং সেগুলো ভোগ করেছ সুতরাং আজ তোমাদেরকে অপমানকর আযাবের শাস্তি দেয়া হবে; কারণ, তোমরা পৃথিবীতে অন্যায় ভাবে অহংকার করতে এবং তোমরা পাপাচার করতে।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmdxxxi{আ’দ সম্প্রদায়ের ভাইয়ের কথা স্মরণ করুন, তার পূর্বে ও পরে অনেক সতর্ককারী গত হয়েছিল সে তার সম্প্রদায়কে বালুকাময় উচ্চ উপত্যকায় এ মর্মে সতর্ক করেছিল যে, তোমরা আল্লাহ ব্যতীত কারও এবাদত করো না। আমি তোমাদের জন্যে এক মহাদিবসের শাস্তির আশংকা করি।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmdxxxii{তারা বলল, তুমি কি আমাদেরকে আমাদের উপাস্য দেব-দেবী থেকে নিবৃত্ত করতে আগমন করেছ? তুমি সত্যবাদী হলে আমাদেরকে যে বিষয়ের ওয়াদা দাও, তা নিয়ে আস।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmdxxxiii{সে বলল, এ জ্ঞান তো আল্লাহর কাছেই রয়েছে। আমি যে বিষয়সহ প্রেরিত হয়েছি, তা তোমাদের কাছে পৌঁছাই। কিন্তু আমি দেখছি তোমরা এক মুর্খ সম্প্রদায়।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmdxxxiv{(অতঃপর) তারা যখন শাস্তিকে মেঘরূপে তাদের উপত্যকা অভিমুখী দেখল, তখন বলল, এ তো মেঘ, আমাদেরকে বৃষ্টি দেবে। বরং এটা সেই বস্তু, যা তোমরা তাড়াতাড়ি চেয়েছিলে। এটা বায়ু এতে রয়েছে মর্মন্তুদ শাস্তি।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmdxxxv{তার পালনকর্তার আদেশে সে সব কিছুকে ধ্বংস করে দেবে। অতঃপর তারা ভোর বেলায় এমন হয়ে গেল যে, তাদের বসতিগুলো ছাড়া কিছুই দৃষ্টিগোচর হল না। আমি অপরাধী সম্প্রদায়কে এমনিভাবে শাস্তি দিয়ে থাকি।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmdxxxvi{আমি তাদেরকে এমন বিষয়ে ক্ষমতা দিয়েছিলাম, যে বিষয়ে তোমাদেরকে ক্ষমতা দেইনি। আমি তাদের দিয়েছিলাম, কর্ণ, চক্ষু ও হৃদয়, কিন্তু তাদের কর্ণ, চক্ষু ও হৃদয় তাদের কোন কাজে আসল না, যখন তারা আল্লাহর আয়াতসমূহকে অস্বীকার করল এবং তাদেরকে সেই শাস্তি গ্রাস করে নিল, যা নিয়ে তারা ঠাট্টা বিদ্রুপ করত।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmdxxxvii{আমি তোমাদের আশপাশের জনপদ সমূহ ধ্বংস করে দিয়েছি এবং বার বার আয়াতসমূহ শুনিয়েছি, যাতে তারা ফিরে আসে।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmdxxxviii{অতঃপর আল্লাহর পরিবর্তে তারা যাদেরকে সান্নিধ্য লাভের জন্যে উপাস্যরূপে গ্রহণ করেছিল, তারা তাদেরকে সাহায্য করল না কেন? বরং তারা তাদের কাছ থেকে উধাও হয়ে গেল। এটা ছিল তাদের মিথ্যা ও মনগড়া বিষয়।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmdxxxix{যখন আমি একদল জিনকে আপনার প্রতি আকৃষ্ট করেছিলাম, তারা কোরআন পাঠ শুনছিল,। তারা যখন কোরআন পাঠের জায়গায় উপস্থিত হল, তখন পরস্পর বলল, চুপ থাক। অতঃপর যখন পাঠ সমাপ্ত হল, তখন তারা তাদের সম্প্রদায়ের কাছে সতর্ককারীরূপে ফিরে গেল।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmdxl{তারা বলল, হে আমাদের সম্প্রদায়, আমরা এমন এক কিতাব শুনেছি, যা মূসার পর অবর্তীণ হয়েছে। এ কিতাব পূর্ববর্তী সব কিতাবের প্রত্যায়ন করে, সত্যধর্ম ও সরলপথের দিকে পরিচালিত করে।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmdxli{হে আমাদের সম্প্রদায়, তোমরা আল্লাহর দিকে আহবানকারীর কথা মান্য কর এবং তাঁর প্রতি বিশ্বাস স্থাপন কর। তিনি তোমাদের গোনাহ মার্জনা করবেন।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmmdxlii{আর যে ব্যক্তি আল্লাহর দিকে আহবানকারীর কথা মানবে না, সে পৃথিবীতে আল্লাহকে অপারক করতে পারবে না এবং আল্লাহ ব্যতীত তার কোন সাহায্যকারী থাকবে না। এ ধরনের লোকই প্রকাশ্য পথভ্রষ্টতায় লিপ্ত।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmmdxliii{তারা কি জানে না যে, আল্লাহ যিনি নভোমন্ডল ও ভূমন্ডল সৃষ্টি করেছেন এবং এগুলোর সৃষ্টিতে কোন ক্লান্তিবোধ করেননি, তিনি মৃতকে জীবিত করতে সক্ষম? কেন নয়, নিশ্চয় তিনি সর্ব বিষয়ে সর্বশক্তিমান।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmmdxliv{যেদিন কাফেরদেরকে জাহান্নামের সামনে পেশ করা হবে, সেদিন বলা হবে, এটা কি সত্য নয়? তারা বলবে, হঁ্যা আমাদের পালনকর্তার শপথ। আল্লাহ বলবেন, আযাব আস্বাদন কর। কারণ, তোমরা কুফরী করতে।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmmdxlv{অতএব, আপনি সবর করুন, যেমন উচ্চ সাহসী পয়গম্বরগণ সবর করেছেন এবং ওদের বিষয়ে তড়িঘড়ি করবেন না। ওদেরকে যে বিষয়ে ওয়াদা দেয়া হত, তা যেদিন তারা প্রত্যক্ষ করবে, সেদিন তাদের মনে হবে যেন তারা দিনের এক মুহুর্তের বেশী পৃথিবীতে অবস্থান করেনি। এটা সুস্পষ্ট অবগতি। এখন তারাই ধ্বংসপ্রাপ্ত হবে, যারা পাপাচারী সম্প্রদায়।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmmdxlvi{\basmalahbn যারা কুফরী করে এবং আল্লাহর পথে বাধা সৃষ্টি করে, আল্লাহ তাদের সকল কর্ম ব্যর্থ করে দেন।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmdxlvii{আর যারা বিশ্বাস স্থাপন করে, সৎকর্ম সম্পাদন করে এবং তাদের পালনকর্তার পক্ষ থেকে মুহাম্মদের প্রতি অবতীর্ণ সত্যে বিশ্বাস করে, আল্লাহ তাদের মন্দ কর্মসমূহ মার্জনা করেন এবং তাদের অবস্থা ভাল করে দেন।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmdxlviii{এটা এ কারণে যে, যারা কাফের, তারা বাতিলের অনুসরণ করে এবং যারা বিশ্বাসী, তারা তাদের পালনকর্তার নিকট থেকে আগত সত্যের অনুসরণ করে। এমনিভাবে আল্লাহ মানুষের জন্যে তাদের দৃষ্টান্তসমূহ বর্ণনা করেন।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmdxlix{অতঃপর যখন তোমরা কাফেরদের সাথে যুদ্ধে অবতীর্ণ হও, তখন তাদের গর্দার মার, অবশেষে যখন তাহাদেরকে পূর্ণরূপে পরাভূত কর তখন তাদেরকে শক্ত করে বেধে ফেল। অতঃপর হয় তাদের প্রতি অনুগ্রহ কর, না হয় তাদের নিকট হতে মুক্তিপণ লও। তোমরা যুদ্ধ চালিয়ে যাবে যে পর্যন্ত না শত্রুপক্ষ অস্ত্র সমর্পণ করবে! একথা শুনলে। আল্লাহ ইচ্ছা করলে তাদের কাছ থেকে প্রতিশোধ নিতে পারতেন। কিন্তু তিনি তোমাদের কতককে কতকের দ্বারা পরীক্ষা করতে চান। যারা আল্লাহর পথে শহীদ হয়, আল্লাহ কখনই তাদের কর্ম বিনষ্ট করবেন না।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmdl{তিনি তাদেরকে পথ প্রদর্শন করবেন এবং তাদের অবস্থা ভাল করবেন।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmdli{অতঃপর তিনি তাদেরকে জান্নাতে দাখিল করবেন, যা তাদেরকে জানিয়ে দিয়েছেন।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmdlii{হে বিশ্বাসীগণ! যদি তোমরা আল্লাহকে সাহায্য কর, আল্লাহ তোমাদেরকে সাহায্য করবেন এবং তোমাদের পা দৃঢ়প্রতিষ্ঠ করবেন।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmdliii{আর যারা কাফের, তাদের জন্যে আছে দুর্গতি এবং তিনি তাদের কর্ম বিনষ্ট করে দিবেন।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmdliv{এটা এজন্যে যে, আল্লাহ যা নাযিল করেছেন, তারা তা পছন্দ করে না। অতএব, আল্লাহ তাদের কর্ম ব্যর্থ করে দিবেন।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmdlv{তারা কি পৃথিবীতে ভ্রমণ করেনি অতঃপর দেখেনি যে, তাদের পূর্ববর্তীদের পরিণাম কি হয়েছে? আল্লাহ তাদেরকে ধ্বংস করে দিয়েছেন এবং কাফেরদের অবস্থা এরূপই হবে।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmdlvi{এটা এজন্যে যে, আল্লাহ মুমিনদের হিতৈষী বন্ধু এবং কাফেরদের কোন হিতৈষী বন্ধু নাই।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmdlvii{যারা বিশ্বাস করে ও সৎকর্ম করে, আল্লাহ তাদেরকে জান্নাতে দাখিল করবেন, যার নিম্নদেশে নির্ঝরিণীসমূহ প্রবাহিত হয়। আর যারা কাফের, তারা ভোগ-বিলাসে মত্ত থাকে এবং চতুস্পদ জন্তুর মত আহার করে। তাদের বাসস্থান জাহান্নাম।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmdlviii{যে জনপদ আপনাকে বহিস্কার করেছে, তদপেক্ষা কত শক্তিশালী জনপদকে আমি ধ্বংস করেছি, অতঃপর তাদেরকে সাহায্য করার কেউ ছিল না।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmdlix{যে ব্যক্তি তার পালনকর্তার পক্ষ থেকে আগত নিদর্শন অনুসরণ করে, সে কি তার সমান, যার কাছে তার মন্দ কর্ম শোভনীয় করা হয়েছে এবং যে তার খেয়াল-খুশীর অনুসরণ করে।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmdlx{পরহেযগারদেরকে যে জান্নাতের ওয়াদা দেয়া হয়েছে, তার অবস্থা নিম্নরূপঃ তাতে আছে পানির নহর, নির্মল দুধের নহর যারা স্বাদ অপরিবর্তনীয়, পানকারীদের জন্যে সুস্বাদু শরাবের নহর এবং পরিশোধিত মধুর নহর। তথায় তাদের জন্যে আছে রকমারি ফল-মূল ও তাদের পালনকর্তার ক্ষমা। পরহেযগাররা কি তাদের সমান, যারা জাহান্নামে অনন্তকাল থাকবে এবং যাদেরকে পান করতে দেয়া হবে ফুটন্ত পানি অতঃপর তা তাদের নাড়িভূঁড়ি ছিন্ন বিচ্ছিন্ন করে দেবে?\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmdlxi{তাদের মধ্যে কতক আপনার দিকে কান পাতে, অতঃপর যখন আপনার কাছ থেকে বাইরে যায়, তখন যারা শিক্ষিত, তাদেরকে বলেঃ এইমাত্র তিনি কি বললেন ? এদের অন্তরে আল্লাহ মোহর মেরে দিয়েছেন এবং তারা নিজেদের খেয়াল-খুশীর অনুসরণ করে।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmdlxii{যারা সৎপথপ্রাপ্ত হয়েছে, তাদের সৎপথপ্রাপ্তি আরও বেড়ে যায় এবং আল্লাহ তাদেরকে তাকওয়া দান করেন।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmdlxiii{তারা শুধু এই অপেক্ষাই করছে যে, কেয়ামত অকস্মাৎ তাদের কাছে এসে পড়ুক। বস্তুতঃ কেয়ামতের লক্ষণসমূহ তো এসেই পড়েছে। সুতরাং কেয়ামত এসে পড়লে তারা উপদেশ গ্রহণ করবে কেমন করে ?\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmdlxiv{জেনে রাখুন, আল্লাহ ব্যতীত কোন উপাস্য নেই। ক্ষমাপ্রার্থনা করুন, আপনার ক্রটির জন্যে এবং মুমিন পুরুষ ও নারীদের জন্যে। আল্লাহ, তোমাদের গতিবিধি ও অবস্থান সম্পর্কে জ্ঞাত।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmdlxv{যারা মুমিন, তারা বলেঃ একটি সূরা নাযিল হয় না কেন? অতঃপর যখন কোন দ্ব্যর্থহীন সূরা নাযিল হয় এবং তাতে জেহাদের উল্লেখ করা হয়, তখন যাদের অন্তরে রোগ আছে, আপনি তাদেরকে মৃত্যুভয়ে মূর্ছাপ্রাপ্ত মানুষের মত আপনার দিকে তাকিয়ে থাকতে দেখবেন। সুতরাং ধ্বংস তাদের জন্যে।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmdlxvi{তাদের আনুগত্য ও মিষ্ট বাক্য জানা আছে। অতএব, জেহাদের সিন্ধান্ত হলে যদি তারা আল্লাহর প্রতি পদত্ত অংগীকার পূর্ণ করে, তবে তাদের জন্যে তা মঙ্গলজনক হবে।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmdlxvii{ক্ষমতা লাভ করলে, সম্ভবতঃ তোমরা পৃথিবীতে অনর্থ সৃষ্টি করবে এবং আত্নীয়তা বন্ধন ছিন্ন করবে।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmdlxviii{এদের প্রতিই আল্লাহ অভিসম্পাত করেন, অতঃপর তাদেরকে বধির ও দৃষ্টিশক্তিহীন করেন।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmdlxix{তারা কি কোরআন সম্পর্কে গভীর চিন্তা করে না? না তাদের অন্তর তালাবদ্ধ?\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmdlxx{নিশ্চয় যারা সোজা পথ ব্যক্ত হওয়ার পর তৎপ্রতি পৃষ্ঠপ্রদর্শন করে, শয়তান তাদের জন্যে তাদের কাজকে সুন্দর করে দেখায় এবং তাদেরকে মিথ্যা আশা দেয়।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmdlxxi{এটা এজন্য যে, তারা তাদেরকে বলে, যারা আল্লাহর অবতীর্ণ কিতাব অপছন্দ করেঃ আমরা কোন কোন ব্যাপারে তোমাদের কথা মান্য করব। আল্লাহ তাদের গোপন পরামর্শ অবগত আছেন।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmdlxxii{ফেরেশতা যখন তাদের মুখমন্ডল ও পৃষ্ঠদেশে আঘাত করতে করতে প্রাণ হরণ করবে, তখন তাদের অবস্থা কেমন হবে?\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmdlxxiii{এটা এজন্যে যে, তারা সেই বিষয়ের অনুসরণ করে, যা আল্লাহর অসন্তোষ সৃষ্টি করে এবং আল্লাহর সন্তুষ্টিকে অপছন্দ করে। ফলে তিনি তাদের কর্মসমূহ ব্যর্থ করে দেন।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmdlxxiv{যাদের অন্তরে রোগ আছে, তারা কি মনে করে যে, আল্লাহ তাদের অন্তরের বিদ্বেষ প্রকাশ করে দেবেন না?\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmdlxxv{আমি ইচ্ছা করলে আপনাকে তাদের সাথে পরিচিত করে দিতাম। তখন আপনি তাদের চেহারা দেখে তাদেরকে চিনতে পারতেন এবং আপনি অবশ্যই কথার ভঙ্গিতে তাদেরকে চিনতে পারবেন। আল্লাহ তোমাদের কর্মসমূহের খবর রাখেন।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmdlxxvi{আমি অবশ্যই তোমাদেরকে পরীক্ষা করব যে পর্যন্ত না ফুটিয়ে তুলি তোমাদের জেহাদকারীদেরকে এবং সবরকারীদেরকে এবং যতক্ষণ না আমি তোমাদের অবস্থান সমূহ যাচাই করি।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmmdlxxvii{নিশ্চয় যারা কাফের এবং আল্লাহর পথ থেকে মানুষকে ফিরিয়ে রাখে এবং নিজেদের জন্যে সৎপথ ব্যক্ত হওয়ার পর রসূলের (সঃ) বিরোধিতা করে, তারা আল্লাহর কোনই ক্ষতি করতে পারবে না এবং তিনি ব্যর্থ করে দিবেন তাদের কর্মসমূহকে।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmmdlxxviii{হে মুমিনগণ! তোমরা আল্লাহর আনুগত্য কর, রসূলের (সাঃ) আনুগত্য কর এবং নিজেদের কর্ম বিনষ্ট করো না।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmmdlxxix{নিশ্চয় যারা কাফের এবং আল্লাহর পথ থেকে মানুষকে ফিরিয়ে রাখে, অতঃপর কাফের অবস্থায় মারা যায়, আল্লাহ কখনই তাদেরকে ক্ষমা করবেন না।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmmdlxxx{অতএব, তোমরা হীনবল হয়ো না এবং সন্ধির আহবান জানিও না, তোমরাই হবে প্রবল। আল্লাহই তোমাদের সাথে আছেন। তিনি কখনও তোমাদের কর্ম হ্রাস করবেন না।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmmdlxxxi{পার্থিব জীবন তো কেবল খেলাধুলা, যদি তোমরা বিশ্বাসী হও এবং সংযম অবলম্বন কর, আল্লাহ তোমাদেরকে তোমাদের প্রতিদান দেবেন এবং তিনি তোমাদের ধন-সম্পদ চাইবেন না।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmmdlxxxii{তিনি তোমাদের কাছে ধন-সম্পদ চাইলে অতঃপর তোমাদেরকে অতিষ্ঠ করলে তোমরা কার্পণ্য করবে এবং তিনি তোমাদের মনের সংকীর্ণতা প্রকাশ করে দেবেন।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmmdlxxxiii{শুন, তোমরাই তো তারা, যাদেরকে আল্লাহর পথে ব্যয় করার আহবান জানানো হচ্ছে, অতঃপর তোমাদের কেউ কেউ কৃপণতা করছে। যারা কৃপণতা করছে, তারা নিজেদের প্রতিই কৃপণতা করছে। আল্লাহ অভাবমুক্ত এবং তোমরা অভাবগ্রস্থ। যদি তোমরা মুখ ফিরিয়ে নাও, তবে তিনি তোমাদের পরিবর্তে অন্য জাতিকে প্রতিষ্ঠিত করবেন, এরপর তারা তোমাদের মত হবে না।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmmdlxxxiv{\basmalahbn নিশ্চয় আমি আপনার জন্যে এমন একটা ফয়সালা করে দিয়েছি, যা সুস্পষ্ট।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmdlxxxv{যাতে আল্লাহ আপনার অতীত ও ভবিষ্যত ত্রুটিসমূহ মার্জনা করে দেন এবং আপনার প্রতি তাঁর নেয়ামত পূর্ণ করেন ও আপনাকে সরল পথে পরিচালিত করেন।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmdlxxxvi{এবং আপনাকে দান করেন বলিষ্ঠ সাহায্য।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmdlxxxvii{তিনি মুমিনদের অন্তরে প্রশান্তি নাযিল করেন, যাতে তাদের ঈমানের সাথে আরও ঈমান বেড়ে যায়। নভোমন্ডল ও ভূমন্ডলের বাহিনীসমূহ আল্লাহরই এবং আল্লাহ সর্বজ্ঞ, প্রজ্ঞাময়।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmdlxxxviii{ঈমান এজন্যে বেড়ে যায়, যাতে তিনি ঈমানদার পুরুষ ও ঈমানদার নারীদেরকে জান্নাতে প্রবেশ করান, যার তলদেশে নদী প্রবাহিত। সেথায় তারা চিরকাল বসবাস করবে এবং যাতে তিনি তাদের পাপ মোচন করেন। এটাই আল্লাহর কাছে মহাসাফল্য।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmdlxxxix{এবং যাতে তিনি কপট বিশ্বাসী পুরুষ ও কপট বিশ্বাসিনী নারী এবং অংশীবাদী পুরুষ ও অংশীবাদিনী নারীদেরকে শাস্তি দেন, যারা আল্লাহ সম্পর্কে মন্দ ধারণা পোষন করে। তাদের জন্য মন্দ পরিনাম। আল্লাহ তাদের প্রতি ক্রুদ্ধ হয়েছেন, তাদেরকে অভিশপ্ত করেছেন। এবং তাহাদের জন্যে জাহান্নাম প্রস্তুত রেখেছেন। তাদের প্রত্যাবর্তন স্থল অত্যন্ত মন্দ।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmdxc{নভোমন্ডল ও ভূমন্ডলের বাহিনীসমূহ আল্লাহরই। আল্লাহ পরাক্রমশালী, প্রজ্ঞাময়।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmdxci{আমি আপনাকে প্রেরণ করেছি অবস্থা ব্যক্তকারীরূপে, সুসংবাদদাতা ও ভয় প্রদর্শনকারীরূপে।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmdxcii{যাতে তোমরা আল্লাহ ও রসূলের প্রতি বিশ্বাস স্থাপন কর এবং তাঁকে সাহায্য ও সম্মান কর এবং সকাল-সন্ধ্যায় আল্লাহর পবিত্রতা ঘোষণা কর।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmdxciii{যারা আপনার কাছে আনুগত্যের শপথ করে, তারা তো আল্লাহর কাছে আনুগত্যের শপথ করে। আল্লাহর হাত তাদের হাতের উপর রয়েছে। অতএব, যে শপথ ভঙ্গ করে; অতি অবশ্যই সে তা নিজের ক্ষতির জন্যেই করে এবং যে আল্লাহর সাথে কৃত অঙ্গীকার পূর্ণ করে; আল্লাহ সত্ত্বরই তাকে মহাপুরস্কার দান করবেন।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmdxciv{মরুবাসীদের মধ্যে যারা গৃহে বসে রয়েছে, তারা আপনাকে বলবেঃ আমরা আমাদের ধন-সম্পদ ও পরিবার-পরিজনের কাজে ব্যস্ত ছিলাম। অতএব, আমাদের পাপ মার্জনা করান। তারা মুখে এমন কথা বলবে, যা তাদের অন্তরে নেই। বলুনঃ আল্লাহ তোমাদের ক্ষতি অথবা উপকার সাধনের ইচ্ছা করলে কে তাকে বিরত রাখতে পারে? বরং তোমরা যা কর, আল্লাহ সে বিষয় পরিপূর্ণ জ্ঞাত।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmdxcv{বরং তোমরা ধারণ করেছিলে যে, রসূল ও মুমিনগণ তাদের বাড়ী-ঘরে কিছুতেই ফিরে আসতে পারবে না এবং এই ধারণা তোমাদের জন্যে খুবই সুখকর ছিল। তোমরা মন্দ ধারণার বশবর্তী হয়েছিলে। তোমরা ছিলে ধ্বংসমুখী এক সম্প্রদায়।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmdxcvi{যারা আল্লাহ ও তাঁর রসূলে বিশ্বাস করে না, আমি সেসব কাফেরের জন্যে জ্বলন্ত অগ্নি প্রস্তুত রেখেছি।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmdxcvii{নভোমন্ডল ও ভূমন্ডলের রাজত্ব আল্লাহরই। তিনি যাকে ইচ্ছা ক্ষমা করেন এবং যাকে ইচ্ছা শাস্তি দেন। তিনি ক্ষমাশীল, পরম মেহেরবান।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmdxcviii{তোমরা যখন যুদ্ধলব্ধ ধন-সম্পদ সংগ্রহের জন্য যাবে, তখন যারা পশ্চাতে থেকে গিয়েছিল, তারা বলবেঃ আমাদেরকেও তোমাদের সঙ্গে যেতে দাও। তারা আল্লাহর কালাম পরিবর্তন করতে চায়। বলুনঃ তোমরা কখনও আমাদের সঙ্গে যেতে পারবে না। আল্লাহ পূর্ব থেকেই এরূপ বলে দিয়েছেন। তারা বলবেঃ বরং তোমরা আমাদের প্রতি বিদ্বেষ পোষণ করছ। পরন্তু তারা সামান্যই বোঝে।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmdxcix{গৃহে অবস্থানকারী মরুবাসীদেরকে বলে দিনঃ আগামীতে তোমরা এক প্রবল পরাক্রান্ত জাতির সাথে যুদ্ধ করতে আহুত হবে। তোমরা তাদের সাথে যুদ্ধ করবে, যতক্ষণ না তারা মুসলমান হয়ে যায়। তখন যদি তোমরা নির্দেশ পালন কর, তবে আল্লাহ তোমাদেরকে উত্তম পুরস্কার দিবেন। আর যদি পৃষ্ঠপ্রদর্শন কর যেমন ইতিপূর্বে পৃষ্ঠপ্রদর্শন করেছ, তবে তিনি তোমাদেরকে যন্ত্রনাদায়ক শাস্তি দিবেন।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmdc{অন্ধের জন্যে, খঞ্জের জন্যে ও রুগ্নের জন্যে কোন অপরাধ নাই এবং যে কেউ আল্লাহ ও তাঁর রসূলের অনুগত্য করবে তাকে তিনি জান্নাতে দাখিল করবেন, যার তলদেশে নদী প্রবাহিত হয়। পক্ষান্তরে যে, ব্যক্তি পৃষ্ঠপ্রদর্শন করবে, তাকে যন্ত্রণাদায়ক শাস্তি দিবেন।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmdci{আল্লাহ মুমিনদের প্রতি সন্তুষ্ট হলেন, যখন তারা বৃক্ষের নীচে আপনার কাছে শপথ করল। আল্লাহ অবগত ছিলেন যা তাদের অন্তরে ছিল। অতঃপর তিনি তাদের প্রতি প্রশান্তি নাযিল করলেন এবং তাদেরকে আসন্ন বিজয় পুরস্কার দিলেন।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmdcii{এবং বিপুল পরিমাণে যুদ্ধলব্ধ সম্পদ, যা তারা লাভ করবে। আল্লাহ পরাক্রমশালী, প্রজ্ঞাময়।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmdciii{আল্লাহ তোমাদেরকে বিপুল পরিমাণ যুদ্ধলব্ধ সম্পদের ওয়াদা দিয়েছেন, যা তোমরা লাভ করবে। তিনি তা তোমাদের জন্যে ত্বরান্বিত করবেন। তিনি তোমাদের থেকে শত্রুদের স্তব্দ করে দিয়েছেন-যাতে এটা মুমিনদের জন্যে এক নিদর্শন হয় এবং তোমাদেরকে সরল পথে পরিচালিত করেন।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmdciv{আর ও একটি বিজয় রয়েছে যা এখনও তোমাদের অধিকারে আসেনি, আল্লাহ তা বেষ্টন করে আছেন। আল্লাহ সর্ববিষয়ে ক্ষমতাবান।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmdcv{যদি কাফেররা তোমাদের মোকাবেলা করত, তবে অবশ্যই তারা পৃষ্ঠপ্রদর্শন করত। তখন তারা কোন অভিভাবক ও সাহায্যকারী পেত না।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmdcvi{এটাই আল্লাহর রীতি, যা পূর্ব থেকে চালু আছে। তুমি আল্লাহর রীতিতে কোন পরিবর্তন পাবে না।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmdcvii{তিনি মক্কা শহরে তাদের হাত তোমাদের থেকে এবং তোমাদের হাত তাদের থেকে নিবারিত করেছেন তাদের উপর তোমাদেরকে বিজয়ী করার পর। তোমরা যা কিছু কর, আল্লাহ তা দেখেন।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmdcviii{তারাই তো কুফরী করেছে এবং বাধা দিয়েছে তোমাদেরকে মসজিদে হারাম থেকে এবং অবস্থানরত কোরবানীর জন্তুদেরকে যথাস্থানে পৌছতে। যদি মক্কায় কিছুসংখ্যক ঈমানদার পুরুষ ও ঈমানদার নারী না থাকত, যাদেরকে তোমরা জানতে না। অর্থাৎ তাদের পিষ্ট হয়ে যাওয়ার আশংকা না থাকত, অতঃপর তাদের কারণে তোমরা অজ্ঞাতসারে ক্ষতিগ্রস্ত হতে, তবে সব কিছু চুকিয়ে দেয়া হত; কিন্তু এ কারণে চুকানো হয়নি, যাতে আল্লাহ তা’আলা যাকে ইচ্ছা স্বীয় রহমতে দাখিল করে নেন। যদি তারা সরে যেত, তবে আমি অবশ্যই তাদের মধ্যে যারা কাফের তাদেরকে যন্ত্রনাদায়ক শস্তি দিতাম।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmdcix{কেননা, কাফেররা তাদের অন্তরে মূর্খতাযুগের জেদ পোষণ করত। অতঃপর আল্লাহ তাঁর রসূল ও মুমিনদের উপর স্বীয় প্রশান্তি নাযিল করলেন এবং তাদের জন্যে সংযমের দায়িত্ব অপরিহার্য করে দিলেন। বস্তুতঃ তারাই ছিল এর অধিকতর যোগ্য ও উপযুক্ত। আল্লাহ সর্ববিষয়ে সম্যক জ্ঞাত।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmdcx{আল্লাহ তাঁর রসূলকে সত্য স্বপ্ন দেখিয়েছেন। আল্লাহ চাহেন তো তোমরা অবশ্যই মসজিদে হারামে প্রবেশ করবে নিরাপদে মস্তকমুন্ডিত অবস্থায় এবং কেশ কর্তিত অবস্থায়। তোমরা কাউকে ভয় করবে না। অতঃপর তিনি জানেন যা তোমরা জান না। এছাড়াও তিনি দিয়েছেন তোমাদেরকে একটি আসন্ন বিজয়।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmdcxi{তিনিই তাঁর রসূলকে হেদায়েত ও সত্য ধর্মসহ প্রেরণ করেছেন, যাতে একে অন্য সমস্ত ধর্মের উপর জয়যুক্ত করেন। সত্য প্রতিষ্ঠাতারূপে আল্লাহ যথেষ্ট।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmdcxii{মুহাম্মদ আল্লাহর রসূল এবং তাঁর সহচরগণ কাফেরদের প্রতি কঠোর, নিজেদের মধ্যে পরস্পর সহানুভূতিশীল। আল্লাহর অনুগ্রহ ও সন্তুষ্টি কামনায় আপনি তাদেরকে রুকু ও সেজদারত দেখবেন। তাদের মুখমন্ডলে রয়েছে সেজদার চিহ্ন । তওরাতে তাদের অবস্থা এরূপ এবং ইঞ্জিলে তাদের অবস্থা যেমন একটি চারা গাছ যা থেকে নির্গত হয় কিশলয়, অতঃপর তা শক্ত ও মজবুত হয় এবং কান্ডের উপর দাঁড়ায় দৃঢ়ভাবে-চাষীকে আনন্দে অভিভুত করে-যাতে আল্লাহ তাদের দ্বারা কাফেরদের অন্তর্জালা সৃষ্টি করেন। তাদের মধ্যে যারা বিশ্বাস স্থাপন করে এবং সৎকর্ম করে, আল্লাহ তাদেরকে ক্ষমা ও মহাপুরস্কারের ওয়াদা দিয়েছেন।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmdcxiii{\basmalahbn মুমিনগণ! তোমরা আল্লাহ ও রসূলের সামনে অগ্রণী হয়ো না এবং আল্লাহকে ভয় কর। নিশ্চয় আল্লাহ সবকিছু শুনেন ও জানেন।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmdcxiv{মুমিনগণ! তোমরা নবীর কন্ঠস্বরের উপর তোমাদের কন্ঠস্বর উঁচু করো না এবং তোমরা একে অপরের সাথে যেরূপ উঁচুস্বরে কথা বল, তাঁর সাথে সেরূপ উঁচুস্বরে কথা বলো না। এতে তোমাদের কর্ম নিস্ফল হয়ে যাবে এবং তোমরা টেরও পাবে না।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmdcxv{যারা আল্লাহর রসূলের সামনে নিজেদের কন্ঠস্বর নীচু করে, আল্লাহ তাদের অন্তরকে শিষ্টাচারের জন্যে শোধিত করেছেন। তাদের জন্যে রয়েছে ক্ষমা ও মহাপুরস্কার।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmdcxvi{যারা প্রাচীরের আড়াল থেকে আপনাকে উচুস্বরে ডাকে, তাদের অধিকাংশই অবুঝ।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmdcxvii{যদি তারা আপনার বের হয়ে তাদের কাছে আসা পর্যন্ত সবর করত, তবে তা-ই তাদের জন্যে মঙ্গলজনক হত। আল্লাহ ক্ষমাশীল, পরম দয়ালু।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmdcxviii{মুমিনগণ! যদি কোন পাপাচারী ব্যক্তি তোমাদের কাছে কোন সংবাদ আনয়ন করে, তবে তোমরা পরীক্ষা করে দেখবে, যাতে অজ্ঞতাবশতঃ তোমরা কোন সম্প্রদায়ের ক্ষতিসাধনে প্রবৃত্ত না হও এবং পরে নিজেদের কৃতকর্মের জন্যে অনুতপ্ত না হও।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmdcxix{তোমরা জেনে রাখ তোমাদের মধ্যে আল্লাহর রসূল রয়েছেন। তিনি যদি অনেক বিষয়ে তোমাদের আবদার মেনে নেন, তবে তোমরাই কষ্ট পাবে। কিন্তু আল্লাহ তোমাদের অন্তরে ঈমানের মহব্বত সৃষ্টি করে দিয়েছেন এবং তা হৃদয়গ্রাহী করে দিয়েছেন। পক্ষান্তরে কুফর, পাপাচার ও নাফরমানীর প্রতি ঘৃণা সৃষ্টি করে দিয়েছেন। তারাই সৎপথ অবলম্বনকারী।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmdcxx{এটা আল্লাহর কৃপা ও নিয়ামতঃ আল্লাহ সর্বজ্ঞ প্রজ্ঞাময়।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmdcxxi{যদি মুমিনদের দুই দল যুদ্ধে লিপ্ত হয়ে পড়ে, তবে তোমরা তাদের মধ্যে মীমাংসা করে দিবে। অতঃপর যদি তাদের একদল অপর দলের উপর চড়াও হয়, তবে তোমরা আক্রমণকারী দলের বিরুদ্ধে যুদ্ধ করবে; যে পর্যন্ত না তারা আল্লাহর নির্দেশের দিকে ফিরে আসে। যদি ফিরে আসে, তবে তোমরা তাদের মধ্যে ন্যায়ানুগ পন্থায় মীমাংসা করে দিবে এবং ইনছাফ করবে। নিশ্চয় আল্লাহ ইনছাফকারীদেরকে পছন্দ করেন।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmdcxxii{মুমিনরা তো পরস্পর ভাই-ভাই। অতএব, তোমরা তোমাদের দুই ভাইয়ের মধ্যে মীমাংসা করবে এবং আল্লাহকে ভয় করবে-যাতে তোমরা অনুগ্রহপ্রাপ্ত হও।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmdcxxiii{মুমিনগণ, কেউ যেন অপর কাউকে উপহাস না করে। কেননা, সে উপহাসকারী অপেক্ষা উত্তম হতে পারে এবং কোন নারী অপর নারীকেও যেন উপহাস না করে। কেননা, সে উপহাসকারিণী অপেক্ষা শ্রেষ্ঠ হতে পারে। তোমরা একে অপরের প্রতি দোষারোপ করো না এবং একে অপরকে মন্দ নামে ডেকো না। কেউ বিশ্বাস স্থাপন করলে তাদের মন্দ নামে ডাকা গোনাহ। যারা এহেন কাজ থেকে তওবা না করে তারাই যালেম।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmdcxxiv{মুমিনগণ, তোমরা অনেক ধারণা থেকে বেঁচে থাক। নিশ্চয় কতক ধারণা গোনাহ। এবং গোপনীয় বিষয় সন্ধান করো না। তোমাদের কেউ যেন কারও পশ্চাতে নিন্দা না করে। তোমাদের কেউ কি তারা মৃত ভ্রাতার মাংস ভক্ষণ করা পছন্দ করবে? বস্তুতঃ তোমরা তো একে ঘৃণাই কর। আল্লাহকে ভয় কর। নিশ্চয় আল্লাহ তওবা কবুলকারী, পরম দয়ালু।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmdcxxv{হে মানব, আমি তোমাদেরকে এক পুরুষ ও এক নারী থেকে সৃষ্টি করেছি এবং তোমাদেরকে বিভিন্ন জাতি ও গোত্রে বিভক্ত করেছি, যাতে তোমরা পরস্পরে পরিচিতি হও। নিশ্চয় আল্লাহর কাছে সে-ই সর্বাধিক সম্ভ্রান্ত যে সর্বাধিক পরহেযগার। নিশ্চয় আল্লাহ সর্বজ্ঞ, সবকিছুর খবর রাখেন।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmdcxxvi{মরুবাসীরা বলেঃ আমরা বিশ্বাস স্থাপন করেছি। বলুনঃ তোমরা বিশ্বাস স্থাপন করনি; বরং বল, আমরা বশ্যতা স্বীকার করেছি। এখনও তোমাদের অন্তরে বিশ্বাস জন্মেনি। যদি তোমরা আল্লাহ ও তাঁর রসূলের আনুগত্য কর, তবে তোমাদের কর্ম বিন্দুমাত্রও নিস্ফল করা হবে না। নিশ্চয়, আল্লাহ ক্ষমাশীল, পরম মেহেরবান।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmdcxxvii{তারাই মুমিন, যারা আল্লাহ ও তাঁর রসূলের প্রতি ঈমান আনার পর সন্দেহ পোষণ করে না এবং আল্লাহর পথে প্রাণ ও ধন-সম্পদ দ্বারা জেহাদ করে। তারাই সত্যনিষ্ঠ।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmdcxxviii{বলুনঃ তোমরা কি তোমাদের ধর্ম পরায়ণতা সম্পর্কে আল্লাহকে অবহিত করছ? অথচ আল্লাহ জানেন যা কিছু আছে ভূমন্ডলে এবং যা কিছু আছে নভোমন্ডলে। আল্লাহ সর্ববিষয়ে সম্যক জ্ঞাত।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmdcxxix{তারা মুসলমান হয়ে আপনাকে ধন্য করেছে মনে করে। বলুন, তোমরা মুসলমান হয়ে আমাকে ধন্য করেছ মনে করো না। বরং আল্লাহ ঈমানের পথে পরিচালিত করে তোমাদেরকে ধন্য করেছেন, যদি তোমরা সত্যনিষ্ঠ হয়ে থাক।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmdcxxx{আল্লাহ নভোমন্ডল ও ভূমন্ডলের অদৃশ্য বিষয় জানেন, তোমরা যা কর আল্লাহ তা দেখেন।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmdcxxxi{\basmalahbn ক্বাফ! সম্মানিত কোরআনের শপথ;\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmdcxxxii{বরং তারা তাদের মধ্য থেকেই একজন ভয় প্রদর্শনকারী আগমন করেছে দেখে বিস্ময় বোধ করে। অতঃপর কাফেররা বলেঃ এটা আশ্চর্যের ব্যাপার।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmdcxxxiii{আমরা মরে গেলে এবং মৃত্তিকায় পরিণত হয়ে গেলেও কি পুনরুত্থিত হব? এ প্রত্যাবর্তন সুদূরপরাহত।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmdcxxxiv{মৃত্তিকা তাদের কতটুকু গ্রাস করবে, তা আমার জানা আছে এবং আমার কাছে আছে সংরক্ষিত কিতাব।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmdcxxxv{বরং তাদের কাছে সত্য আগমন করার পর তারা তাকে মিথ্যা বলছে। ফলে তারা সংশয়ে পতিত রয়েছে।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmdcxxxvi{তারা কি তাদের উপরস্থিত আকাশের পানে দৃষ্টিপাত করে না আমি কিভাবে তা নির্মাণ করেছি এবং সুশোভিত করেছি? তাতে কোন ছিদ্রও নেই।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmdcxxxvii{আমি ভূমিকে বিস্তৃত করেছি, তাতে পর্বতমালার ভার স্থাপন করেছি এবং তাতে সর্বপ্রকার নয়নাভিরাম উদ্ভিদ উদগত করেছি।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmdcxxxviii{এটা জ্ঞান আহরণ ও স্মরণ করার মত ব্যাপার প্রত্যেক অনুরাগী বান্দার জন্যে।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmdcxxxix{আমি আকাশ থেকে কল্যাণময় বৃষ্টি বর্ষণ করি এবং তদ্বারা বাগান ও শস্য উদগত করি, যেগুলোর ফসল আহরণ করা হয়।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmdcxl{এবং লম্বমান খর্জুর বৃক্ষ, যাতে আছে গুচ্ছ গুচ্ছ খর্জুর,\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmdcxli{বান্দাদের জীবিকাস্বরূপ এবং বৃষ্টি দ্বারা আমি মৃত জনপদকে সঞ্জীবিত করি। এমনিভাবে পুনরুত্থান ঘটবে।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmdcxlii{তাদের পূর্বে মিথ্যাবাদী বলেছে নূহের সম্প্রদায়, কুপবাসীরা এবং সামুদ সম্প্রদায়।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmdcxliii{আদ, ফেরাউন, ও লূতের সম্প্রদায়,\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmdcxliv{বনবাসীরা এবং তোব্বা সম্প্রদায়। প্রত্যেকেই রসূলগণকে মিথ্যা বলেছে, অতঃপর আমার শাস্তির যোগ্য হয়েছে।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmdcxlv{আমি কি প্রথমবার সৃষ্টি করেই ক্লান্ত হয়ে পড়েছি? বরং তারা নতুন সৃষ্টির ব্যাপারে সন্দেহ পোষন করেছে।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmdcxlvi{আমি মানুষ সৃষ্টি করেছি এবং তার মন নিভৃতে যে কুচিন্তা করে, সে সম্বন্ধেও আমি অবগত আছি। আমি তার গ্রীবাস্থিত ধমনী থেকেও অধিক নিকটবর্তী।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmdcxlvii{যখন দুই ফেরেশতা ডানে ও বামে বসে তার আমল গ্রহণ করে।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmdcxlviii{সে যে কথাই উচ্চারণ করে, তাই গ্রহণ করার জন্যে তার কাছে সদা প্রস্তুত প্রহরী রয়েছে।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmdcxlix{মৃত্যুযন্ত্রণা নিশ্চিতই আসবে। এ থেকেই তুমি টালবাহানা করতে।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmdcl{এবং শিঙ্গায় ফুঁৎকার দেয়া হবে এটা হবে ভয় প্রদর্শনের দিন।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmdcli{প্রত্যেক ব্যক্তি আগমন করবে। তার সাথে থাকবে চালক ও কর্মের সাক্ষী।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmdclii{তুমি তো এই দিন সম্পর্কে উদাসীন ছিলে। এখন তোমার কাছ থেকে যবনিকা সরিয়ে দিয়েছি। ফলে আজ তোমার দৃষ্টি সুতীক্ষ্ন।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmdcliii{তার সঙ্গী ফেরেশতা বলবেঃ আমার কাছে যে, আমলনামা ছিল, তা এই।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmdcliv{তোমরা উভয়েই নিক্ষেপ কর জাহান্নামে প্রত্যেক অকৃতজ্ঞ বিরুদ্ধবাদীকে,\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmdclv{যে বাধা দিত মঙ্গলজনক কাজে, সীমালঙ্ঘনকারী, সন্দেহ পোষণকারীকে।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmdclvi{যে ব্যক্তি আল্লাহর সাথে অন্য উপাস্য গ্রহণ করত, তাকে তোমরা কঠিন শাস্তিতে নিক্ষেপ কর।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmdclvii{তার সঙ্গী শয়তান বলবেঃ হে আমাদের পালনকর্তা, আমি তাকে অবাধ্যতায় লিপ্ত করিনি। বস্তুতঃ সে নিজেই ছিল সুদূর পথভ্রান্তিতে লিপ্ত।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmdclviii{আল্লাহ বলবেনঃ আমার সামনে বাকবিতন্ডা করো না আমি তো পূর্বেই তোমাদেরকে আযাব দ্বারা ভয় প্রদর্শন করেছিলাম।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmdclix{আমার কাছে কথা রদবদল হয় না এবং আমি বান্দাদের প্রতি জুলুমকারী নই।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmdclx{যেদিন আমি জাহান্নামকে জিজ্ঞাসা করব; তুমি কি পূর্ণ হয়ে গেছ? সে বলবেঃ আরও আছে কি?\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmdclxi{জান্নাতকে উপস্থিত করা হবে খোদাভীরুদের অদূরে।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmmdclxii{তোমাদের প্রত্যেক অনুরাগী ও স্মরণকারীকে এরই প্রতিশ্রুতি দেয়া হয়েছিল।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmmdclxiii{যে না দেখে দয়াময় আল্লাহ তা’আলাকে ভয় করত এবং বিনীত অন্তরে উপস্থিত হত।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmmdclxiv{তোমরা এতে শান্তিতে প্রবেশ কর। এটাই অনন্তকাল বসবাসের জন্য প্রবেশ করার দিন।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmmdclxv{তারা তথায় যা চাইবে, তাই পাবে এবং আমার কাছে রয়েছে আরও অধিক।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmmdclxvi{আমি তাদের পূর্বে বহু সম্প্রদায়কে ধ্বংস করেছি, তারা এদের অপেক্ষা অধিক শক্তিশালী ছিল এবং দেশে-বিদেশে বিচরণ করে ফিরত। তাদের কোন পলায়ন স্থান ছিল না।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmmdclxvii{এতে উপদেশ রয়েছে তার জন্যে, যার অনুধাবন করার মত অন্তর রয়েছে। অথবা সে নিবিষ্ট মনে শ্রবণ করে।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmmdclxviii{আমি নভোমন্ডল, ভূমন্ডল ও এতদুভয়ের মধ্যবর্তী সবকিছু ছয়দিনে সৃষ্টি করেছি এবং আমাকে কোনরূপ ক্লান্তি স্পর্শ করেনি।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmmdclxix{অতএব, তারা যা কিছু বলে, তজ্জন্যে আপনি ছবর করুন এবং, সূর্যোদয় ও সূর্যাস্তের পূর্বে আপনার পালনকর্তার সপ্রশংস পবিত্রতা ঘোষণা করুন।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmmdclxx{রাত্রির কিছু অংশে তাঁর পবিত্রতা ঘোষণা করুন এবং নামাযের পশ্চাতেও।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmmdclxxi{শুন, যে দিন এক আহবানকারী নিকটবর্তী স্থান থেকে আহবান করবে।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmmdclxxii{যেদিন মানুষ নিশ্চিত সেই ভয়াবহ আওয়াজ শুনতে পাবে, সেদিনই পুনরত্থান দিবস।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmmdclxxiii{আমি জীবন দান করি, মৃত্যু ঘটাই এবং আমারই দিকে সকলের প্রত্যাবর্তন।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmmdclxxiv{যেদিন ভূমন্ডল বিদীর্ণ হয়ে মানুষ ছুটাছুটি করে বের হয়ে আসবে। এটা এমন সমবেত করা, যা আমার জন্যে অতি সহজ।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmmdclxxv{তারা যা বলে, তা আমি সম্যক অবগত আছি। আপনি তাদের উপর জোরজবরকারী নন। অতএব, যে আমার শাস্তিকে ভয় করে, তাকে কোরআনের মাধ্যমে উপদেশ দান করুন।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmmmdclxxvi{\basmalahbn কসম ঝঞ্ঝাবায়ুর।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmdclxxvii{অতঃপর বোঝা বহনকারী মেঘের।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmdclxxviii{অতঃপর মৃদু চলমান জলযানের,\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmdclxxix{অতঃপর কর্ম বন্টনকারী ফেরেশতাগণের,\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmdclxxx{তোমাদের প্রদত্ত ওয়াদা অবশ্যই সত্য।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmdclxxxi{ইনসাফ অবশ্যম্ভাবী।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmdclxxxii{পথবিশিষ্ট আকাশের কসম,\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmdclxxxiii{তোমরা তো বিরোধপূর্ণ কথা বলছ।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmdclxxxiv{যে ভ্রষ্ট, সেই এ থেকে মুখ ফিরায়,\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmdclxxxv{অনুমানকারীরা ধ্বংস হোক,\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmdclxxxvi{যারা উদাসীন, ভ্রান্ত।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmdclxxxvii{তারা জিজ্ঞাসা করে, কেয়ামত কবে হবে?\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmdclxxxviii{যেদিন তারা অগ্নিতে পতিত হবে,\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmdclxxxix{তোমরা তোমাদের শাস্তি আস্বাদন কর। তোমরা একেই ত্বরান্বিত করতে চেয়েছিল।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmdcxc{খোদাভীরুরা জান্নাতে ও প্রস্রবণে থাকবে।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmdcxci{এমতাবস্থায় যে, তারা গ্রহণ করবে যা তাদের পালনকর্তা তাদেরকে দেবেন। নিশ্চয় ইতিপূর্বে তারা ছিল সৎকর্মপরায়ণ,\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmdcxcii{তারা রাত্রির সামান্য অংশেই নিদ্রা যেত,\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmdcxciii{রাতের শেষ প্রহরে তারা ক্ষমাপ্রার্থনা করত,\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmdcxciv{এবং তাদের ধন-সম্পদে প্রার্থী ও বঞ্চিতের হক ছিল।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmdcxcv{বিশ্বাসকারীদের জন্যে পৃথিবীতে নিদর্শনাবলী রয়েছে,\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmdcxcvi{এবং তোমাদের নিজেদের মধ্যেও, তোমরা কি অনুধাবন করবে না?\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmdcxcvii{আকাশে রয়েছে তোমাদের রিযিক ও প্রতিশ্রুত সবকিছু।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmdcxcviii{নভোমন্ডল ও ভূমন্ডলের পালনকর্তার কসম, তোমাদের কথাবার্তার মতই এটা সত্য।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmdcxcix{আপনার কাছে ইব্রাহীমের সম্মানিত মেহমানদের বৃত্তান্ত এসেছে কি?\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmdcc{যখন তারা তাঁর কাছে উপস্থিত হয়ে বললঃ সালাম, তখন সে বললঃ সালাম। এরা তো অপরিচিত লোক।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmdcci{অতঃপর সে গ্রহে গেল এবং একটি ঘৃতেপক্ক মোটা গোবৎস নিয়ে হাযির হল।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmdccii{সে গোবৎসটি তাদের সামনে রেখে বললঃ তোমরা আহার করছ না কেন?\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmdcciii{অতঃপর তাদের সম্পর্কে সে মনে মনে ভীত হলঃ তারা বললঃ ভীত হবেন না। তারা তাঁকে একট জ্ঞানীগুণী পুত্র সন্তানের সুসংবাদ দিল।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmdcciv{অতঃপর তাঁর স্ত্রী চীৎকার করতে করতে সামনে এল এবং মুখ চাপড়িয়ে বললঃ আমি তো বৃদ্ধা, বন্ধ্যা।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmdccv{তারা বললঃ তোমার পালনকর্তা এরূপই বলেছেন। নিশ্চয় তিনি প্রজ্ঞাময়, সর্বজ্ঞ।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmdccvi{ইব্রাহীম বললঃ হে প্রেরিত ফেরেশতাগণ, তোমাদের উদ্দেশ্য কি?\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmmdccvii{তারা বললঃ আমরা এক অপরাধী সম্প্রদায়ের প্রতি প্রেরিত হয়েছি,\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmmdccviii{যাতে তাদের উপর মাটির ঢিলা নিক্ষেপ করি।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmmdccix{যা সীমাতিক্রমকারীদের জন্যে আপনার পালনকর্তার কাছে চিহ্নিত আছে।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmmdccx{অতঃপর সেখানে যারা ঈমানদার ছিল, আমি তাদেরকে উদ্ধার করলাম।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmmdccxi{এবং সেখানে একটি গৃহ ব্যতীত কোন মুসলমান আমি পাইনি।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmmdccxii{যারা যন্ত্রণাদায়ক শাস্তিকে ভয় করে, আমি তাদের জন্যে সেখানে একটি নিদর্শন রেখেছি।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmmdccxiii{এবং নিদর্শন রয়েছে মূসার বৃত্তান্তে; যখন আমি তাকে সুস্পষ্ট প্রমাণসহ ফেরাউনের কাছে প্রেরণ করেছিলাম।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmmdccxiv{অতঃপর সে শক্তিবলে মুখ ফিরিয়ে নিল এবং বললঃ সে হয় যাদুকর, না হয় পাগল।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmmdccxv{অতঃপর আমি তাকে ও তার সেনাবাহিনীকে পাকড়াও করলাম এবং তাদেরকে সমুদ্রে নিক্ষেপ করলাম। সে ছিল অভিযুক্ত।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmmdccxvi{এবং নিদর্শন রয়েছে তাদের কাহিনীতে; যখন আমি তাদের উপর প্রেরণ করেছিলাম অশুভ বায়ু।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmmdccxvii{এই বায়ু যার উপর দিয়ে প্রবাহিত হয়েছিলঃ তাকেই চুর্ণ-বিচুর্ণ করে দিয়েছিল।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmmdccxviii{আরও নিদর্শন রয়েছে সামূদের ঘটনায়; যখন তাদেরকে বলা হয়েছিল, কিছুকাল মজা লুটে নাও।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmmdccxix{অতঃপর তারা তাদের পালনকর্তার আদেশ অমান্য করল এবং তাদের প্রতি বজ্রঘাত হল এমতাবস্থায় যে, তারা তা দেখেছিল।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmmdccxx{অতঃপর তারা দাঁড়াতে সক্ষম হল না এবং কোন প্রতিকারও করতে পারল না।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmmmdccxxi{আমি ইতিপূর্বে নূহের সম্প্রদায়কে ধ্বংস করেছি। নিশ্চিতই তারা ছিল পাপাচারী সম্প্রদায়।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmmmdccxxii{আমি স্বীয় ক্ষমতাবলে আকাশ নির্মাণ করেছি এবং আমি অবশ্যই ব্যাপক ক্ষমতাশালী।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmmmdccxxiii{আমি ভূমিকে বিছিয়েছি। আমি কত সুন্দরভাবেই না বিছাতে সক্ষম।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmmmdccxxiv{আমি প্রত্যেক বস্তু জোড়ায় জোড়ায় সৃষ্টি করেছি, যাতে তোমরা হৃদয়ঙ্গম কর।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmmmdccxxv{অতএব, আল্লাহর দিকে ধাবিত হও। আমি তাঁর তরফ থেকে তোমাদের জন্যে সুস্পষ্ট সতর্ককারী।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmmmdccxxvi{তোমরা আল্লাহর সাথে কোন উপাস্য সাব্যস্ত করো না। আমি তাঁর পক্ষ থেকে তোমাদের জন্য সুস্পষ্ট সতর্ককারী।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmmmdccxxvii{এমনিভাবে, তাদের পূর্ববর্তীদের কাছে যখনই কোন রসূল আগমন করেছে, তারা বলছেঃ যাদুকর, না হয় উম্মাদ।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmmmdccxxviii{তারা কি একে অপরকে এই উপদেশই দিয়ে গেছে? বস্তুতঃ ওরা দুষ্ট সম্প্রদায়।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmmmdccxxix{অতএব, আপনি ওদের থেকে মুখ ফিরিয়ে নিন। এতে আপনি অপরাধী হবেন না।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmmmdccxxx{এবং বোঝাতে থাকুন; কেননা, বোঝানো মুমিনদের উপকারে আসবে।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mmmmdccxxxi{আমার এবাদত করার জন্যই আমি মানব ও জিন জাতি সৃষ্টি করেছি।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mmmmdccxxxii{আমি তাদের কাছে জীবিকা চাই না এবং এটাও চাই না যে, তারা আমাকে আহার্য যোগাবে।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mmmmdccxxxiii{আল্লাহ তা’আলাই তো জীবিকাদাতা শক্তির আধার, পরাক্রান্ত।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mmmmdccxxxiv{অতএব, এই যালেমদের প্রাপ্য তাই, যা ওদের অতীত সহচরদের প্রাপ্য ছিল। কাজেই ওরা যেন আমার কাছে তা তাড়াতাড়ি না চায়।\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mmmmdccxxxv{অতএব, কাফেরদের জন্যে দুর্ভোগ সেই দিনের, যেদিনের প্রতিশ্রুতি ওদেরকে দেয়া হয়েছে।\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mmmmdccxxxvi{\basmalahbn কসম তূরপর্বতের,\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmdccxxxvii{এবং লিখিত কিতাবের,\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmdccxxxviii{প্রশস্ত পত্রে,\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmdccxxxix{কসম বায়তুল-মামুর তথা আবাদ গৃহের,\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmdccxl{এবং সমুন্নত ছাদের,\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmdccxli{এবং উত্তাল সমুদ্রের,\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmdccxlii{আপনার পালনকর্তার শাস্তি অবশ্যম্ভাবী,\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmdccxliii{তা কেউ প্রতিরোধ করতে পারবে না।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmdccxliv{সেদিন আকাশ প্রকম্পিত হবে প্রবলভাবে।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmdccxlv{এবং পর্বতমালা হবে চলমান,\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmdccxlvi{সেদিন মিথ্যারোপকারীদের দুর্ভোগ হবে,\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmdccxlvii{যারা ক্রীড়াচ্ছলে মিছেমিছি কথা বানায়।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmdccxlviii{সেদিন তোমাদেরকে জাহান্নামের অগ্নির দিকে ধাক্কা মেরে মেরে নিয়ে যাওয়া হবে।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmdccxlix{এবং বলা হবেঃ এই সেই অগ্নি, যাকে তোমরা মিথ্যা বলতে,\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmdccl{এটা কি জাদু, না তোমরা চোখে দেখছ না?\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmdccli{এতে প্রবেশ কর অতঃপর তোমরা সবর কর অথবা না কর, উভয়ই তোমাদের জন্য সমান। তোমরা যা করতে তোমাদেরকে কেবল তারই প্রতিফল দেয়া হবে।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmdcclii{নিশ্চয় খোদাভীরুরা থাকবে জান্নাতে ও নেয়ামতে।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmdccliii{তারা উপভোগ করবে যা তাদের পালনকর্তা তাদের দেবেন এবং তিনি জাহান্নামের আযাব থেকে তাদেরকে রক্ষা করবেন।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmdccliv{তাদেরকে বলা হবেঃ তোমরা যা করতে তার প্রতিফলস্বরূপ তোমরা তৃপ্ত হয়ে পানাহার কর।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmdcclv{তারা শ্রেণীবদ্ধ সিংহাসনে হেলান দিয়ে বসবে। আমি তাদেরকে আয়তলোচনা হুরদের সাথে বিবাহবন্ধনে আবদ্ধ করে দেব।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmdcclvi{যারা ঈমানদার এবং যাদের সন্তানরা ঈমানে তাদের অনুগামী, আমি তাদেরকে তাদের পিতৃপুরুষদের সাথে মিলিত করে দেব এবং তাদের আমল বিন্দুমাত্রও হ্রাস করব না। প্রত্যেক ব্যক্তি নিজ কৃত কর্মের জন্য দায়ী।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmdcclvii{আমি তাদেরকে দেব ফল-মূল এবং মাংস যা তারা চাইবে।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmdcclviii{সেখানে তারা একে অপরকে পানপাত্র দেবে; যাতে অসার বকাবকি নেই এবং পাপকর্মও নেই।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmdcclix{সুরক্ষিত মোতিসদৃশ কিশোররা তাদের সেবায় ঘুরাফেরা করবে।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmdcclx{তারা একে অপরের দিকে মুখ করে জিজ্ঞাসাবাদ করবে।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxi{তারা বলবেঃ আমরা ইতিপূর্বে নিজেদের বাসগৃহে ভীত-কম্পিত ছিলাম।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxii{অতঃপর আল্লাহ আমাদের প্রতি অনুগ্রহ করেছেন এবং আমাদেরকে আগুনের শাস্তি থেকে রক্ষা করেছেন।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxiii{আমরা পূর্বেও আল্লাহকে ডাকতাম। তিনি সৌজন্যশীল, পরম দয়ালু।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxiv{অতএব, আপনি উপদেশ দান করুন। আপনার পালনকর্তার কৃপায় আপনি অতীন্দ্রিয়বাদী নন এবং উম্মাদও নন।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxv{তারা কি বলতে চায়ঃ সে একজন কবি আমরা তার মৃত্যু-দুর্ঘটনার প্রতীক্ষা করছি।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxvi{বলুনঃ তোমরা প্রতীক্ষা কর, আমিও তোমাদের সাথে প্রতীক্ষারত আছি।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxvii{তাদের বুদ্ধি কি এ বিষয়ে তাদেরকে আদেশ করে, না তারা সীমালংঘনকারী সম্প্রদায়?\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxviii{না তারা বলেঃ এই কোরআন সে নিজে রচনা করেছে? বরং তারা অবিশ্বাসী।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxix{যদি তারা সত্যবাদী হয়ে থাকে, তবেএর অনুরূপ কোন রচনা উপস্থিত করুক।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxx{তারা কি আপনা-আপনিই সৃজিত হয়ে গেছে, না তারা নিজেরাই স্রষ্টা?\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxxi{না তারা নভোমন্ডল ও ভূমন্ডল সৃষ্টি করেছে? বরং তারা বিশ্বাস করে না।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxxii{তাদের কাছে কি আপনার পালনকর্তার ভান্ডার রয়েছে, না তারাই সবকিছুর তত্ত্বাবধায়ক?\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxxiii{না তাদের কোন সিঁড়ি আছে, যাতে আরোহণ করে তারা শ্রবণ করে? থাকলে তাদের শ্রোতা সুস্পষ্ট প্রমাণ উপস্থিত করুক।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxxiv{না তার কন্যা-সন্তান আছে আর তোমাদের আছে পুত্রসন্তান?\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxxv{না আপনি তাদের কাছে পারিশ্রমিক চান যে, তাদের উপর জরিমানার বোঝা চেপে বসে?\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxxvi{না তাদের কাছে অদৃশ্য বিষয়ের জ্ঞান আছে যে, তারাই তা লিপিবদ্ধ করে?\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxxvii{না তারা চক্রান্ত করতে চায়? অতএব যারা কাফের, তারই চক্রান্তের শিকার হবে।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxxviii{না তাদের আল্লাহ তা’আলা ব্যতীত কোন উপাস্য আছে? তারা যাকে শরীক করে, আল্লাহ তা’আলা তা থেকে পবিত্র।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxxix{তারা যদি আকাশের কোন খন্ডকে পতিত হতে দেখে, তবে বলে এটা তো পুঞ্জীভুত মেঘ।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxxx{তাদেরকে ছেড়ে দিন সেদিন পর্যন্ত, যেদিন তাদের উপর বজ্রাঘাত পতিত হবে।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxxxi{সেদিন তাদের চক্রান্ত তাদের কোন উপকারে আসবে না এবং তারা সাহায্যপ্রাপ্তও হবে না।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxxxii{গোনাহগারদের জন্যে এছাড়া আরও শাস্তি রয়েছে, কিন্তু তাদের অধিকাংশই তা জানে না।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxxxiii{আপনি আপনার পালনকর্তার নির্দেশের অপেক্ষায় সবর করুন। আপনি আমার দৃষ্টির সামনে আছেন এবং আপনি আপনার পালনকর্তꦣ2494;র সপ্রশংস পবিত্রতা ঘোষণা করুন যখন আপনি গাত্রোত্থান করেন।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxxxiv{এবং রাত্রির কিছু অংশে এবং তারকা অস্তমিত হওয়ার সময় তাঁর পবিত্রতা ঘোষণা করুন।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxxxv{\basmalahbn নক্ষত্রের কসম, যখন অস্তমিত হয়।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxxxvi{তোমাদের সংগী পথভ্রষ্ট হননি এবং বিপথগামীও হননি।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxxxvii{এবং প্রবৃত্তির তাড়নায় কথা বলেন না।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxxxviii{কোরআন ওহী, যা প্রত্যাদেশ হয়।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmdcclxxxix{তাঁকে শিক্ষা দান করে এক শক্তিশালী ফেরেশতা,\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmdccxc{সহজাত শক্তিসম্পন্ন, সে নিজ আকৃতিতে প্রকাশ পেল।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmdccxci{উর্ধ্ব দিগন্তে,\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmdccxcii{অতঃপর নিকটবর্তী হল ও ঝুলে গেল।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmdccxciii{তখন দুই ধনুকের ব্যবধান ছিল অথবা আরও কম।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmdccxciv{তখন আল্লাহ তাঁর দাসের প্রতি যা প্রত্যাদেশ করবার, তা প্রত্যাদেশ করলেন।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmdccxcv{রসূলের অন্তর মিথ্যা বলেনি যা সে দেখেছে।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmdccxcvi{তোমরা কি বিষয়ে বিতর্ক করবে যা সে দেখেছে?\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmdccxcvii{নিশ্চয় সে তাকে আরেকবার দেখেছিল,\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmdccxcviii{সিদরাতুলমুন্তাহার নিকটে,\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmdccxcix{যার কাছে অবস্থিত বসবাসের জান্নাত।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmdccc{যখন বৃক্ষটি দ্বারা আচ্ছন্ন হওয়ার, তদ্দ্বারা আচ্ছন্ন ছিল।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmdccci{তাঁর দৃষ্টিবিভ্রম হয় নি এবং সীমালংঘনও করেনি।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmdcccii{নিশ্চয় সে তার পালনকর্তার মহান নিদর্শনাবলী অবলোকন করেছে।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmdccciii{তোমরা কি ভেবে দেখেছ লাত ও ওযযা সম্পর্কে।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmdccciv{এবং তৃতীয় আরেকটি মানাত সম্পর্কে?\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmdcccv{পুত্র-সন্তান কি তোমাদের জন্যে এবং কন্যা-সন্তান আল্লাহর জন্য?\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmdcccvi{এমতাবস্থায় এটা তো হবে খুবই অসংগত বন্টন।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmdcccvii{এগুলো কতগুলো নাম বৈ নয়, যা তোমরা এবং তোমাদের পূর্ব-পুরুষদের রেখেছ। এর সমর্থনে আল্লাহ কোন দলীল নাযিল করেননি। তারা অনুমান এবং প্রবৃত্তিরই অনুসরণ করে। অথচ তাদের কাছে তাদের পালনকর্তার পক্ষ থেকে পথ নির্দেশ এসেছে।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmdcccviii{মানুষ যা চায়, তাই কি পায়?\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmdcccix{অতএব, পরবর্তী ও পূর্ববর্তী সব মঙ্গলই আল্লাহর হাতে।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmdcccx{আকাশে অনেক ফেরেশতা রয়েছে। তাদের কোন সুপারিশ ফলপ্রসূ হয় না যতক্ষণ আল্লাহ যার জন্যে ইচ্ছা ও যাকে পছন্দ করেন, অনুমতি না দেন।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxi{যারা পরকালে বিশ্বাস করে না, তারাই ফেরেশতাকে নারীবাচক নাম দিয়ে থাকে।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxii{অথচ এ বিষয়ে তাদের কোন জ্ঞান নেই। তারা কেবল অনুমানের উপর চলে। অথচ সত্যের ব্যাপারে অনুমান মোটেই ফলপ্রসূ নয়।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxiii{অতএব যে আমার স্মরণে বিমুখ এবং কেবল পার্থিব জীবনই কামনা করে তার তরফ থেকে আপনি মুখ ফিরিয়ে নিন।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxiv{তাদের জ্ঞানের পরিধি এ পর্যন্তই। নিশ্চয় আপনার পালনকর্তা ভাল জানেন, কে তাঁর পথ থেকে বিচ্যুত হয়েছে এবং তিনিই ভাল জানেন কে সুপথপ্রাপ্ত হয়েছে।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxv{নভোমন্ডল ও ভূমন্ডলে যা কিছু আছে, সবই আল্লাহর, যাতে তিনি মন্দকর্মীদেরকে তাদের কর্মের প্রতিফল দেন এবং সৎকর্মীদেরকে দেন ভাল ফল।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxvi{যারা বড় বড় গোনাহ ও অশ্লীলকার্য থেকে বেঁচে থাকে ছোটখাট অপরাধ করলেও নিশ্চয় আপনার পালনকর্তার ক্ষমা সুদূর বিস্তৃত। তিনি তোমাদের সম্পর্কে ভাল জানেন, যখন তিনি তোমাদেরকে সৃষ্টি করেছেন মৃত্তিকা থেকে এবং যখন তোমরা মাতৃগর্ভে কচি শিশু ছিলে। অতএব তোমরা আত্নপ্রশংসা করো না। তিনি ভাল জানেন কে সংযমী।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxvii{আপনি কি তাকে দেখেছেন, যে মুখ ফিরিয়ে নেয়।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxviii{এবং দেয় সামান্যই ও পাষাণ হয়ে যায়।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxix{তার কাছে কি অদৃশ্যের জ্ঞান আছে যে, সে দেখে?\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxx{তাকে কি জানানো হয়নি যা আছে মূসার কিতাবে,\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxxi{এবং ইব্রাহীমের কিতাবে, যে তার দায়িত্ব পালন করেছিল?\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxxii{কিতাবে এই আছে যে, কোন ব্যক্তি কারও গোনাহ নিজে বহন করবে না।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxxiii{এবং মানুষ তাই পায়, যা সে করে,\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxxiv{তার কর্ম শীঘ্রই দেখা হবে।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxxv{অতঃপর তাকে পূর্ণ প্রতিদান দেয়া হবে।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxxvi{তোমার পালনকর্তার কাছে সবকিছুর সমাপ্তি,\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxxvii{এবং তিনিই হাসান ও কাঁদান\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxxviii{এবং তিনিই মারেন ও বাঁচান,\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxxix{এবং তিনিই সৃষ্টি করেন যুগল-পুরুষ ও নারী।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxxx{একবিন্দু বীর্য থেকে যখন স্খলিত করা হয়।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxxxi{পুনরুত্থানের দায়িত্ব তাঁরই,\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxxxii{এবং তিনিই ধনবান করেন ও সম্পদ দান করেন।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxxxiii{তিনি শিরা নক্ষত্রের মালিক।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxxxiv{তিনিই প্রথম আদ সম্প্রদায়কে ধ্বংস করেছেন,\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxxxv{এবং সামুদকেও; অতঃপর কাউকে অব্যহতি দেননি।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxxxvi{এবং তাদের পূর্বে নূহের সম্প্রদায়কে, তারা ছিল আরও জালেম ও অবাধ্য।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxxxvii{তিনিই জনপদকে শুন্যে উত্তোলন করে নিক্ষেপ করেছেন।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxxxviii{অতঃপর তাকে আচ্ছন্ন করে নেয় যা আচ্ছন্ন করার।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxxxix{অতঃপর তুমি তোমার পালনকর্তার কোন অনুগ্রহকে মিথ্যা বলবে?\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxl{অতীতের সতর্ককারীদের মধ্যে সে-ও একজন সতর্ককারী।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxli{কেয়ামত নিকটে এসে গেছে।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxlii{আল্লাহ ব্যতীত কেউ একে প্রকাশ করতে সক্ষম নয়।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxliii{তোমরা কি এই বিষয়ে আশ্চর্যবোধ করছ?\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxliv{এবং হাসছ-ক্রন্দন করছ না?\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxlv{তোমরা ক্রীড়া-কৌতুক করছ,\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxlvi{অতএব আল্লাহকে সেজদা কর এবং তাঁর এবাদত কর।\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxlvii{\basmalahbn কেয়ামত আসন্ন, চন্দ্র বিদীর্ণ হয়েছে।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxlviii{তারা যদি কোন নিদর্শন দেখে তবে মুখ ফিরিয়ে নেয় এবং বলে, এটা তো চিরাগত জাদু।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxlix{তারা মিথ্যারোপ করছে এবং নিজেদের খেয়াল-খুশীর অনুসরণ করছে। প্রত্যেক কাজ যথাসময়ে স্থিরীকৃত হয়।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmdcccl{তাদের কাছে এমন সংবাদ এসে গেছে, যাতে সাবধানবাণী রয়েছে।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmdcccli{এটা পরিপূর্ণ জ্ঞান, তবে সতর্ককারীগণ তাদের কোন উপকারে আসে না।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmdccclii{অতএব, আপনি তাদের থেকে মুখ ফিরিয়ে নিন। যেদিন আহবানকারী আহবান করবে এক অপ্রিয় পরিণামের দিকে,\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmdcccliii{তারা তখন অবনমিত নেত্রে কবর থেকে বের হবে বিক্ষিপ্ত পংগপাল সদৃশ।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmdcccliv{তারা আহবানকারীর দিকে দৌড়াতে থাকবে। কাফেরা বলবেঃ এটা কঠিন দিন।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmdccclv{তাদের পূর্বে নূহের সম্প্রদায়ও মিথ্যারোপ করেছিল। তারা মিথ্যারোপ করেছিল আমার বান্দা নূহের প্রতি এবং বলেছিলঃ এ তো উম্মাদ। তাঁরা তাকে হুমকি প্রদর্শন করেছিল।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmdccclvi{অতঃপর সে তার পালনকর্তাকে ডেকে বললঃ আমি অক্ষম, অতএব, তুমি প্রতিবিধান কর।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmdccclvii{তখন আমি খুলে দিলাম আকাশের দ্বার প্রবল বারিবর্ষণের মাধ্যমে।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmdccclviii{এবং ভুমি থেকে প্রবাহিত করলাম প্রস্রবণ। অতঃপর সব পানি মিলিত হল এক পরিকম্পিত কাজে।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmdccclix{আমি নূহকে আরোহণ করালাম এক কাষ্ঠ ও পেরেক নির্মিত জলযানে।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmdccclx{যা চলত আমার দৃষ্টি সামনে। এটা তার পক্ষ থেকে প্রতিশোধ ছিল, যাকে প্রত্যখ্যান করা হয়েছিল।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxi{আমি একে এক নিদর্শনরূপে রেখে দিয়েছি। অতএব, কোন চিন্তাশীল আছে কি?\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxii{কেমন কঠোর ছিল আমার শাস্তি ও সতর্কবাণী।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxiii{আমি কোরআনকে সহজ করে দিয়েছি বোঝার জন্যে। অতএব, কোন চিন্তাশীল আছে কি?\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxiv{আদ সম্প্রদায় মিথ্যারোপ করেছিল, অতঃপর কেমন কঠোর হয়েছিল আমার শাস্তি ও সতর্কবাণী।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxv{আমি তাদের উপর প্রেরণ করেছিলাম ঝঞ্জাবায়ু এক চিরাচরিত অশুভ দিনে।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxvi{তা মানুষকে উৎখাত করছিল, যেন তারা উৎপাটিত খর্জুর বৃক্ষের কান্ড।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxvii{অতঃপর কেমন কঠোর ছিল আমার শাস্তি ও সতর্কবাণী।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxviii{আমি কোরআনকে বোঝার জন্যে সহজ করে দিয়েছি। অতএব, কোন চিন্তাশীল আছে কি?\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxix{সামুদ সম্প্রদায় সতর্ককারীদের প্রতি মিথ্যারোপ করেছিল।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxx{তারা বলেছিলঃ আমরা কি আমাদেরই একজনের অনুসরণ করব? তবে তো আমরা বিপথগামী ও বিকার গ্রস্থরূপে গণ্য হব।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxxi{আমাদের মধ্যে কি তারই প্রতি উপদেশ নাযিল করা হয়েছে? বরং সে একজন মিথ্যাবাদী, দাম্ভিক।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxxii{এখন আগামীকল্যই তারা জানতে পারবে কে মিথ্যাবাদী, দাম্ভিক।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxxiii{আমি তাদের পরীক্ষার জন্য এক উষ্ট্রী প্রেরণ করব, অতএব, তাদের প্রতি লক্ষ্য রাখ এবং সবর কর।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxxiv{এবং তাদেরকে জানিয়ে দাও যে, তাদের মধ্যে পানির পালা নির্ধারিত হয়েছে এবং পালাক্রমে উপস্থিত হতে হবে।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxxv{অতঃপর তারা তাদের সঙ্গীকে ডাকল। সে তাকে ধরল এবং বধ করল।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxxvi{অতঃপর কেমন কঠোর ছিল আমার শাস্তি ও সতর্কবাণী।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxxvii{আমি তাদের প্রতি একটিমাত্র নিনাদ প্রেরণ করেছিলাম। এতেই তারা হয়ে গেল শুষ্ক শাখাপল্লব নির্মিত দলিত খোয়াড়ের ন্যায়।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxxviii{আমি কোরআনকে বোঝার জন্যে সহজ করে দিয়েছি। অতএব, কোন চিন্তাশীল আছে কি?\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxxix{লূত-সম্প্রদায় সতর্ককারীদের প্রতি মিথ্যারোপ করেছিল।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxxx{আমি তাদের প্রতি প্রেরণ করেছিলাম প্রস্তর বর্ষণকারী প্রচন্ড ঘূর্ণিবায়ু; কিন্তু লূত পরিবারের উপর নয়। আমি তাদেরকে রাতের শেষপ্রহরে উদ্ধার করেছিলাম।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxxxi{আমার পক্ষ থেকে অনুগ্রহ স্বরূপ। যারা কৃতজ্ঞতা স্বীকার করে, আমি তাদেরকে এভাবে পুরস্কৃত করে থকি।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxxxii{লূত (আঃ) তাদেরকে আমার প্রচন্ড পাকড়াও সম্পর্কে সতর্ক করেছিল। অতঃপর তারা সতর্কবাণী সম্পর্কে বাকবিতন্ডা করেছিল।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxxxiii{তারা লূতের (আঃ) কাছে তার মেহমানদেরকে দাবী করেছিল। তখন আমি তাদের চক্ষু লোপ করে দিলাম। অতএব, আস্বাদন কর আমার শাস্তি ও সতর্কবাণী।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxxxiv{তাদেরকে প্রত্যুষে নির্ধারিত শাস্তি আঘাত হেনেছিল।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxxxv{অতএব, আমার শাস্তি ও সতর্কবাণী আস্বাদন কর।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxxxvi{আমি কোরআনকে বোঝবার জন্যে সহজ করে দিয়েছি। অতএব, কোন চিন্তাশীল আছে কি?\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxxxvii{ফেরাউন সম্প্রদায়ের কাছেও সতর্ককারীগণ আগমন করেছিল।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxxxviii{তারা আমার সকল নিদর্শনের প্রতি মিথ্যারোপ করেছিল। অতঃপর আমি পরাভূতকারী, পরাক্রমশালীর ন্যায় তাদেরকে পাকড়াও করলাম।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmmdccclxxxix{তোমাদের মধ্যকার কাফেররা কি তাদের চাইতে শ্রেষ্ঠ ? না তোমাদের মুক্তির সনদপত্র রয়েছে কিতাবসমূহে?\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxc{না তারা বলে যে, আমারা এক অপরাজেয় দল?\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxci{এ দল তো সত্ত্বরই পরাজিত হবে এবং পৃষ্ঠপ্রদর্শন করবে।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxcii{বরং কেয়ামত তাদের প্রতিশ্রুত সময় এবং কেয়ামত ঘোরতর বিপদ ও তিক্ততর।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxciii{নিশ্চয় অপরাধীরা পথভ্রষ্ট ও বিকারগ্রস্ত।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxciv{যেদিন তাদেরকে মুখ হিঁচড়ে টেনে নেয়া হবে জাহান্নামে, বলা হবেঃ অগ্নির খাদ্য আস্বাদন কর।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxcv{আমি প্রত্যেক বস্তুকে পরিমিতরূপে সৃষ্টি করেছি।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxcvi{আমার কাজ তো এক মুহূর্তে চোখের পলকের মত।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxcvii{আমি তোমাদের সমমনা লোকদেরকে ধ্বংস করেছি, অতএব, কোন চিন্তাশীল আছে কি?\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxcviii{তারা যা কিছু করেছে, সবই আমলনামায় লিপিবদ্ধ আছে।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmmmdcccxcix{ছোট ও বড় সবই লিপিবদ্ধ।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmmmcm{খোদাভীরুরা থাকবে জান্নাতে ও নির্ঝরিণীতে।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmmmcmi{যোগ্য আসনে, সর্বাধিপতি সম্রাটের সান্নিধ্যে।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mmmmcmii{\basmalahbn করুনাময় আল্লাহ।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmcmiii{শিক্ষা দিয়েছেন কোরআন,\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmcmiv{সৃষ্টি করেছেন মানুষ,\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmcmv{তাকে শিখিয়েছেন বর্ণনা।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmcmvi{সূর্য ও চন্দ্র হিসাবমত চলে।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmcmvii{এবং তৃণলতা ও বৃক্ষাদি সেজদারত আছে।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmcmviii{তিনি আকাশকে করেছেন সমুন্নত এবং স্থাপন করেছেন তুলাদন্ড।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmcmix{যাতে তোমরা সীমালংঘন না কর তুলাদন্ডে।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmcmx{তোমরা ন্যায্য ওজন কায়েম কর এবং ওজনে কম দিয়ো না।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmcmxi{তিনি পৃথিবীকে স্থাপন করেছেন সৃষ্টজীবের জন্যে।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmcmxii{এতে আছে ফলমূল এবং বহিরাবরণবিশিষ্ট খর্জুর বৃক্ষ।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmcmxiii{আর আছে খোসাবিশিষ্ট শস্য ও সুগন্ধি ফুল।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmcmxiv{অতএব, তোমরা উভয়ে তোমাদের পালনকর্তার কোন কোন অনুগ্রহকে অস্বীকার করবে?\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmcmxv{তিনি মানুষকে সৃষ্টি করেছেন পোড়া মাটির ন্যায় শুষ্ক মৃত্তিকা থেকে।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmcmxvi{এবং জিনকে সৃষ্টি করেছেন অগ্নিশিখা থেকে।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmcmxvii{অতএব, তোমরা উভয়ে তোমাদের পালনকর্তার কোন কোন অনুগ্রহ অস্বীকার করবে?\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmcmxviii{তিনি দুই উদয়াচল ও দুই অস্তাচলের মালিক।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmcmxix{অতএব, তোমরা উভয়ে তোমাদের পালনকর্তার কোন কোন অবদানকে অস্বীকার করবে?\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmcmxx{তিনি পাশাপাশি দুই দরিয়া প্রবাহিত করেছেন।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmcmxxi{উভয়ের মাঝখানে রয়েছে এক অন্তরাল, যা তারা অতিক্রম করে না।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmcmxxii{অতএব, তোমরা উভয়ে তোমাদের পালনকর্তার কোন কোন অবদানকে অস্বীকার করবে?\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmcmxxiii{উভয় দরিয়া থেকে উৎপন্ন হয় মোতি ও প্রবাল।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmcmxxiv{অতএব, তোমরা উভয়ে তোমাদের পালনকর্তার কোন কোন অবদানকে অস্বীকার করবে?\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmcmxxv{দরিয়ায় বিচরণশীল পর্বতদৃশ্য জাহাজসমূহ তাঁরই (নিয়ন্ত্রনাধীন)\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmcmxxvi{অতএব, তোমরা উভয়ে তোমাদের পালনকর্তার কোন কোন অবদানকে অস্বীকার করবে?\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmcmxxvii{ভূপৃষ্টের সবকিছুই ধ্বংসশীল।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmcmxxviii{একমাত্র আপনার মহিমায় ও মহানুভব পালনকর্তার সত্তা ছাড়া।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmcmxxix{অতএব, তোমরা উভয়ে তোমাদের পালনকর্তার কোন কোন অবদানকে অস্বীকার করবে?\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmcmxxx{নভোমন্ডল ও ভূমন্ডলের সবাই তাঁর কাছে প্রার্থী। তিনি সর্বদাই কোন না কোন কাজে রত আছেন।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmcmxxxi{অতএব, তোমরা উভয়ে তোমাদের পালনকর্তার কোন কোন অবদানকে অস্বীকার করবে?\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmcmxxxii{হে জিন ও মানব! আমি শীঘ্রই তোমাদের জন্যে কর্মমুক্ত হয়ে যাব।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmmcmxxxiii{অতএব, তোমরা উভয়ে তোমাদের পালনকর্তার কোন কোন অবদানকে অস্বীকার করবে?\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmmcmxxxiv{হে জিন ও মানবকূল, নভোমন্ডল ও ভূমন্ডলের প্রান্ত অতিক্রম করা যদি তোমাদের সাধ্যে কুলায়, তবে অতিক্রম কর। কিন্তু ছাড়পত্র ব্যতীত তোমরা তা অতিক্রম করতে পারবে না।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmmcmxxxv{অতএব, তোমরা উভয়ে তোমাদের পালনকর্তার কোন কোন অবদানকে অস্বীকার করবে?\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmmcmxxxvi{ছাড়া হবে তোমাদের প্রতি অগ্নিস্ফুলিঙ্গ ও ধুম্রকুঞ্জ তখন তোমরা সেসব প্রতিহত করতে পারবে না।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmmcmxxxvii{অতএব, তোমরা উভয়ে তোমাদের পালনকর্তার কোন কোন অবদানকে অস্বীকার করবে?\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmmcmxxxviii{যেদিন আকাশ বিদীর্ণ হবে তখন সেটি রক্তবর্ণে রঞ্জিত চামড়ার মত হয়ে যাবে।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmmcmxxxix{অতএব, তোমরা উভয়ে তোমাদের পালনকর্তার কোন কোন অবদানকে অস্বীকার করবে?\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmmcmxl{সেদিন মানুষ না তার অপরাধ সম্পর্কে জিজ্ঞাসিত হবে, না জিন।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmmcmxli{অতএব, তোমরা উভয়ে তোমাদের পালনকর্তার কোন কোন অবদানকে অস্বীকার করবে?\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmmcmxlii{অপরাধীদের পরিচয় পাওয়া যাবে তাদের চেহারা থেকে; অতঃপর তাদের কপালের চুল ও পা ধরে টেনে নেয়া হবে।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmmcmxliii{অতএব, তোমরা উভয়ে তোমাদের পালনকর্তার কোন কোন অবদানকে অস্বীকার করবে?\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmmcmxliv{এটাই জাহান্নাম, যাকে অপরাধীরা মিথ্যা বলত।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmmcmxlv{তারা জাহান্নামের অগ্নি ও ফুটন্ত পানির মাঝখানে প্রদক্ষিণ করবে।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmmcmxlvi{অতএব, তোমরা উভয়ে তোমাদের পালনকর্তার কোন কোন অবদানকে অস্বীকার করবে?\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmmmcmxlvii{যে ব্যক্তি তার পালনকর্তার সামনে পেশ হওয়ার ভয় রাখে, তার জন্যে রয়েছে দু’টি উদ্যান।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmmmcmxlviii{অতএব, তোমরা উভয়ে তোমাদের পালনকর্তার কোন কোন অবদানকে অস্বীকার করবে?\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmmmcmxlix{উভয় উদ্যানই ঘন শাখা-পল্লববিশিষ্ট।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmmmcml{অতএব, তোমরা উভয়ে তোমাদের পালনকর্তার কোন কোন অবদানকে অস্বীকার করবে?\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmmmcmli{উভয় উদ্যানে আছে বহমান দুই প্রস্রবন।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmmmcmlii{অতএব, তোমরা উভয়ে তোমাদের পালনকর্তার কোন কোন অবদানকে অস্বীকার করবে?\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmmmcmliii{উভয়ের মধ্যে প্রত্যেক ফল বিভিন্ন রকমের হবে।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmmmcmliv{অতএব, তোমরা উভয়ে তোমাদের পালনকর্তার কোন কোন অবদানকে অস্বীকার করবে?\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmmmcmlv{তারা তথায় রেশমের আস্তরবিশিষ্ট বিছানায় হেলান দিয়ে বসবে। উভয় উদ্যানের ফল তাদের নিকট ঝুলবে।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmmmcmlvi{অতএব, তোমরা উভয়ে তোমাদের পালনকর্তার কোন কোন অবদানকে অস্বীকার করবে?\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mmmmcmlvii{তথায় থাকবে আনতনয়ন রমনীগন, কোন জিন ও মানব পূর্বে যাদের ব্যবহার করেনি।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mmmmcmlviii{অতএব, তোমরা উভয়ে তোমাদের পালনকর্তার কোন কোন অবদানকে অস্বীকার করবে?\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mmmmcmlix{প্রবাল ও পদ্মরাগ সদৃশ রমণীগণ।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mmmmcmlx{অতএব, তোমরা উভয়ে তোমাদের পালনকর্তার কোন কোন অবদানকে অস্বীকার করবে?\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxi{সৎকাজের প্রতিদান উত্তম পুরস্কার ব্যতীত কি হতে পারে?\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxii{অতএব, তোমরা উভয়ে তোমাদের পালনকর্তার কোন কোন অবদানকে অস্বীকার করবে?\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxiii{এই দু’টি ছাড়া আরও দু’টি উদ্যান রয়েছে।\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxiv{অতএব, তোমরা উভয়ে তোমাদের পালনকর্তার কোন কোন অবদানকে অস্বীকার করবে?\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxv{কালোমত ঘন সবুজ।\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxvi{অতএব, তোমরা উভয়ে তোমাদের পালনকর্তার কোন কোন অবদানকে অস্বীকার করবে?\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxvii{তথায় আছে উদ্বেলিত দুই প্রস্রবণ।\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxviii{অতএব, তোমরা উভয়ে তোমাদের পালনকর্তার কোন কোন অবদানকে অস্বীকার করবে?\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxix{তথায় আছে ফল-মূল, খর্জুর ও আনার।\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxx{অতএব, তোমরা উভয়ে তোমাদের পালনকর্তার কোন কোন অবদানকে অস্বীকার করবে?\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxxi{সেখানে থাকবে সচ্চরিত্রা সুন্দরী রমণীগণ।\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxxii{অতএব, তোমরা উভয়ে তোমাদের পালনকর্তার কোন কোন অবদানকে অস্বীকার করবে?\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxxiii{তাঁবুতে অবস্থানকারিণী হুরগণ।\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxxiv{অতএব, তোমরা উভয়ে তোমাদের পালনকর্তার কোন কোন অবদানকে অস্বীকার করবে?\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxxv{কোন জিন ও মানব পূর্বে তাদেরকে স্পর্শ করেনি।\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxxvi{অতএব, তোমরা উভয়ে তোমাদের পালনকর্তার কোন কোন অবদানকে অস্বীকার করবে?\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxxvii{তারা সবুজ মসনদে এবং উৎকৃষ্ট মূল্যবান বিছানায় হেলান দিয়ে বসবে।\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxxviii{অতএব, তোমরা উভয়ে তোমাদের পালনকর্তার কোন কোন অবদানকে অস্বীকার করবে?\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxxix{কত পূণ্যময় আপনার পালনকর্তার নাম, যিনি মহিমাময় ও মহানুভব।\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxxx{\basmalahbn যখন কিয়ামতের ঘটনা ঘটবে,\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxxxi{যার বাস্তবতায় কোন সংশয় নেই।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxxxii{এটা নীচু করে দেবে, সমুন্নত করে দেবে।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxxxiii{যখন প্রবলভাবে প্রকম্পিত হবে পৃথিবী।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxxxiv{এবং পর্বতমালা ভেঙ্গে চুরমার হয়ে যাবে।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxxxv{অতঃপর তা হয়ে যাবে উৎক্ষিপ্ত ধূলিকণা।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxxxvi{এবং তোমরা তিনভাবে বিভক্ত হয়ে পড়বে।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxxxvii{যারা ডান দিকে, কত ভাগ্যবান তারা।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxxxviii{এবং যারা বামদিকে, কত হতভাগা তারা।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmcmlxxxix{অগ্রবর্তীগণ তো অগ্রবর্তীই।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmcmxc{তারাই নৈকট্যশীল,\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmcmxci{অবদানের উদ্যানসমূহে,\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmcmxcii{তারা একদল পূর্ববর্তীদের মধ্য থেকে।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmcmxciii{এবং অল্পসংখ্যক পরবর্তীদের মধ্যে থেকে।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmcmxciv{স্বর্ণ খচিত সিংহাসন।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmcmxcv{তারা তাতে হেলান দিয়ে বসবে পরস্পর মুখোমুখি হয়ে।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmcmxcvi{তাদের কাছে ঘোরাফেরা করবে চির কিশোরেরা।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmcmxcvii{পানপাত্র কুঁজা ও খাঁটি সূরাপূর্ণ পেয়ালা হাতে নিয়ে,\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmcmxcviii{যা পান করলে তাদের শিরঃপীড়া হবে না এবং বিকারগ্রস্ত ও হবে না।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmcmxcix{আর তাদের পছন্দমত ফল-মুল নিয়ে,\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmm{এবং রুচিমত পাখীর মাংস নিয়ে।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmmi{তথায় থাকবে আনতনয়না হুরগণ,\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmmii{আবরণে রক্ষিত মোতির ন্যায়,\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmmiii{তারা যা কিছু করত, তার পুরস্কারস্বরূপ।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmmiv{তারা তথায় অবান্তর ও কোন খারাপ কথা শুনবে না।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmmv{কিন্তু শুনবে সালাম আর সালাম।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmmvi{যারা ডান দিকে থাকবে, তারা কত ভাগ্যবান।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmmvii{তারা থাকবে কাঁটাবিহীন বদরিকা বৃক্ষে।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmmviii{এবং কাঁদি কাঁদি কলায়,\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmmix{এবং দীর্ঘ ছায়ায়।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmmx{এবং প্রবাহিত পানিতে,\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmmmxi{ও প্রচুর ফল-মূলে,\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmmmxii{যা শেষ হবার নয় এবং নিষিদ্ধ ও নয়,\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmmmxiii{আর থাকবে সমুন্নত শয্যায়।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmmmxiv{আমি জান্নাতী রমণীগণকে বিশেষরূপে সৃষ্টি করেছি।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmmmxv{অতঃপর তাদেরকে করেছি চিরকুমারী।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmmmxvi{কামিনী, সমবয়স্কা।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmmmxvii{ডান দিকের লোকদের জন্যে।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmmmxviii{তাদের একদল হবে পূর্ববর্তীদের মধ্য থেকে।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmmmxix{এবং একদল পরবর্তীদের মধ্য থেকে।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmmmxx{বামপার্শ্বস্থ লোক, কত না হতভাগা তারা।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmmmxxi{তারা থাকবে প্রখর বাষ্পে এবং উত্তপ্ত পানিতে,\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmmmxxii{এবং ধুম্রকুঞ্জের ছায়ায়।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmmmxxiii{যা শীতল নয় এবং আরামদায়কও নয়।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmmmxxiv{তারা ইতিপূর্বে স্বাচ্ছন্দ্যশীল ছিল।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmmmmxxv{তারা সদাসর্বদা ঘোরতর পাপকর্মে ডুবে থাকত।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmmmmxxvi{তারা বলতঃ আমরা যখন মরে অস্থি ও মৃত্তিকায় পরিণত হয়ে যাব, তখনও কি পুনরুত্থিত হব?\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmmmmxxvii{এবং আমাদের পূর্বপুরুষগণও!\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmmmmxxviii{বলুনঃ পূর্ববর্তী ও পরবর্তীগণ,\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmmmmxxix{সবাই একত্রিত হবে এক নির্দিষ্ট দিনের নির্দিষ্ট সময়ে।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmmmmxxx{অতঃপর হে পথভ্রষ্ট, মিথ্যারোপকারীগণ।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmmmmxxxi{তোমরা অবশ্যই ভক্ষণ করবে যাক্কুম বৃক্ষ থেকে,\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmmmmxxxii{অতঃপর তা দ্বারা উদর পূর্ণ করবে,\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmmmmxxxiii{অতঃপর তার উপর পান করবে উত্তপ্ত পানি।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmmmmxxxiv{পান করবে পিপাসিত উটের ন্যায়।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mmmmmxxxv{কেয়ামতের দিন এটাই হবে তাদের আপ্যায়ন।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mmmmmxxxvi{আমি সৃষ্টি করেছি তোমাদেরকে। অতঃপর কেন তোমরা তা সত্য বলে বিশ্বাস কর না।\qt@no{(57)}}
\qt@newcmd\qurantrans@bn@mmmmmxxxvii{তোমরা কি ভেবে দেখেছ, তোমাদের বীর্যপাত সম্পর্কে।\qt@no{(58)}}
\qt@newcmd\qurantrans@bn@mmmmmxxxviii{তোমরা তাকে সৃষ্টি কর, না আমি সৃষ্টি করি?\qt@no{(59)}}
\qt@newcmd\qurantrans@bn@mmmmmxxxix{আমি তোমাদের মৃত্যুকাল নির্ধারিত করেছি এবং আমি অক্ষম নই।\qt@no{(60)}}
\qt@newcmd\qurantrans@bn@mmmmmxl{এ ব্যাপারে যে, তোমাদের পরিবর্তে তোমাদের মত লোককে নিয়ে আসি এবং তোমাদেরকে এমন করে দেই, যা তোমরা জান না।\qt@no{(61)}}
\qt@newcmd\qurantrans@bn@mmmmmxli{তোমরা অবগত হয়েছ প্রথম সৃষ্টি সম্পর্কে, তবে তোমরা অনুধাবন কর না কেন?\qt@no{(62)}}
\qt@newcmd\qurantrans@bn@mmmmmxlii{তোমরা যে বীজ বপন কর, সে সম্পর্কে ভেবে দেখেছ কি?\qt@no{(63)}}
\qt@newcmd\qurantrans@bn@mmmmmxliii{তোমরা তাকে উৎপন্ন কর, না আমি উৎপন্নকারী ?\qt@no{(64)}}
\qt@newcmd\qurantrans@bn@mmmmmxliv{আমি ইচ্ছা করলে তাকে খড়কুটা করে দিতে পারি, অতঃপর হয়ে যাবে তোমরা বিস্ময়াবিষ্ট।\qt@no{(65)}}
\qt@newcmd\qurantrans@bn@mmmmmxlv{বলবেঃ আমরা তো ঋণের চাপে পড়ে গেলাম;\qt@no{(66)}}
\qt@newcmd\qurantrans@bn@mmmmmxlvi{বরং আমরা হূত সর্বস্ব হয়ে পড়লাম।\qt@no{(67)}}
\qt@newcmd\qurantrans@bn@mmmmmxlvii{তোমরা যে পানি পান কর, সে সম্পর্কে ভেবে দেখেছ কি?\qt@no{(68)}}
\qt@newcmd\qurantrans@bn@mmmmmxlviii{তোমরা তা মেঘ থেকে নামিয়ে আন, না আমি বর্ষন করি?\qt@no{(69)}}
\qt@newcmd\qurantrans@bn@mmmmmxlix{আমি ইচ্ছা করলে তাকে লোনা করে দিতে পারি, অতঃপর তোমরা কেন কৃতজ্ঞতা প্রকাশ কর না?\qt@no{(70)}}
\qt@newcmd\qurantrans@bn@mmmmml{তোমরা যে অগ্নি প্রজ্জ্বলিত কর, সে সম্পর্কে ভেবে দেখেছ কি?\qt@no{(71)}}
\qt@newcmd\qurantrans@bn@mmmmmli{তোমরা কি এর বৃক্ষ সৃষ্টি করেছ, না আমি সৃষ্টি করেছি ?\qt@no{(72)}}
\qt@newcmd\qurantrans@bn@mmmmmlii{আমি সেই বৃক্ষকে করেছি স্মরণিকা এবং মরুবাসীদের জন্য সামগ্রী।\qt@no{(73)}}
\qt@newcmd\qurantrans@bn@mmmmmliii{অতএব, আপনি আপনার মহান পালনকর্তার নামে পবিত্রতা ঘোষণা করুন।\qt@no{(74)}}
\qt@newcmd\qurantrans@bn@mmmmmliv{অতএব, আমি তারকারাজির অস্তাচলের শপথ করছি,\qt@no{(75)}}
\qt@newcmd\qurantrans@bn@mmmmmlv{নিশ্চয় এটা এক মহা শপথ-যদি তোমরা জানতে।\qt@no{(76)}}
\qt@newcmd\qurantrans@bn@mmmmmlvi{নিশ্চয় এটা সম্মানিত কোরআন,\qt@no{(77)}}
\qt@newcmd\qurantrans@bn@mmmmmlvii{যা আছে এক গোপন কিতাবে,\qt@no{(78)}}
\qt@newcmd\qurantrans@bn@mmmmmlviii{যারা পাক-পবিত্র, তারা ব্যতীত অন্য কেউ একে স্পর্শ করবে না।\qt@no{(79)}}
\qt@newcmd\qurantrans@bn@mmmmmlix{এটা বিশ্ব-পালনকর্তার পক্ষ থেকে অবতীর্ণ।\qt@no{(80)}}
\qt@newcmd\qurantrans@bn@mmmmmlx{তবুও কি তোমরা এই বাণীর প্রতি শৈথিল্য পদর্শন করবে?\qt@no{(81)}}
\qt@newcmd\qurantrans@bn@mmmmmlxi{এবং একে মিথ্যা বলাকেই তোমরা তোমাদের ভূমিকায় পরিণত করবে?\qt@no{(82)}}
\qt@newcmd\qurantrans@bn@mmmmmlxii{অতঃপর যখন কারও প্রাণ কন্ঠাগত হয়।\qt@no{(83)}}
\qt@newcmd\qurantrans@bn@mmmmmlxiii{এবং তোমরা তাকিয়ে থাক,\qt@no{(84)}}
\qt@newcmd\qurantrans@bn@mmmmmlxiv{তখন আমি তোমাদের অপেক্ষা তার অধিক নিকটে থাকি; কিন্তু তোমরা দেখ না।\qt@no{(85)}}
\qt@newcmd\qurantrans@bn@mmmmmlxv{যদি তোমাদের হিসাব-কিতাব না হওয়াই ঠিক হয়,\qt@no{(86)}}
\qt@newcmd\qurantrans@bn@mmmmmlxvi{তবে তোমরা এই আত্মাকে ফিরাও না কেন, যদি তোমরা সত্যবাদী হও ?\qt@no{(87)}}
\qt@newcmd\qurantrans@bn@mmmmmlxvii{যদি সে নৈকট্যশীলদের একজন হয়;\qt@no{(88)}}
\qt@newcmd\qurantrans@bn@mmmmmlxviii{তবে তার জন্যে আছে সুখ, উত্তম রিযিক এবং নেয়ামতে ভরা উদ্যান।\qt@no{(89)}}
\qt@newcmd\qurantrans@bn@mmmmmlxix{আর যদি সে ডান পার্শ্বস্থদের একজন হয়,\qt@no{(90)}}
\qt@newcmd\qurantrans@bn@mmmmmlxx{তবে তাকে বলা হবেঃ তোমার জন্যে ডানপার্শ্বসস্থদের পক্ষ থেকে সালাম।\qt@no{(91)}}
\qt@newcmd\qurantrans@bn@mmmmmlxxi{আর যদি সে পথভ্রষ্ট মিথ্যারোপকারীদের একজন হয়,\qt@no{(92)}}
\qt@newcmd\qurantrans@bn@mmmmmlxxii{তবে তার আপ্যায়ন হবে উত্তপ্ত পানি দ্বারা।\qt@no{(93)}}
\qt@newcmd\qurantrans@bn@mmmmmlxxiii{এবং সে নিক্ষিপ্ত হবে অগ্নিতে।\qt@no{(94)}}
\qt@newcmd\qurantrans@bn@mmmmmlxxiv{এটা ধ্রুব সত্য।\qt@no{(95)}}
\qt@newcmd\qurantrans@bn@mmmmmlxxv{অতএব, আপনি আপনার মহান পালনকর্তার নামে পবিত্রতা ঘোষণা করুন।\qt@no{(96)}}
\qt@newcmd\qurantrans@bn@mmmmmlxxvi{\basmalahbn নভোমন্ডল ও ভূমন্ডলে যা কিছু আছে, সবাই আল্লাহর পবিত্রতা ঘোষণা করে। তিনি শক্তিধর; প্রজ্ঞাময়।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmlxxvii{নভোমন্ডল ও ভূমন্ডলের রাজত্ব তাঁরই। তিনি জীবন দান করেন ও মৃত্যু ঘটান। তিনি সবকিছু করতে সক্ষম।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmlxxviii{তিনিই প্রথম, তিনিই সর্বশেষ, তিনিই প্রকাশমান ও অপ্রকাশমান এবং তিনি সব বিষয়ে সম্যক পরিজ্ঞাত।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmlxxix{তিনি নভোমন্ডল ও ভূ-মন্ডল সৃষ্টি করেছেন ছয়দিনে, অতঃপর আরশের উপর সমাসীন হয়েছেন। তিনি জানেন যা ভূমিতে প্রবেশ করে ও যা ভূমি থেকে নির্গত হয় এবং যা আকাশ থেকে বর্ষিত হয় ও যা আকাশে উত্থিত হয়। তিনি তোমাদের সাথে আছেন তোমরা যেখানেই থাক। তোমরা যা কর, আল্লাহ তা দেখেন।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmlxxx{নভোমন্ডল ও ভূমন্ডলের রাজত্ব তাঁরই। সবকিছু তাঁরই দিকে প্রত্যাবর্তন করবে।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmlxxxi{তিনি রাত্রিকে দিবসে প্রবিষ্ট করেন এবং দিবসকে প্রবিষ্ট করেন রাত্রিতে। তিনি অন্তরের বিষয়াদি সম্পর্কেও সম্যক জ্ঞাত।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmlxxxii{তোমরা আল্লাহ ও তাঁর রসূলের প্রতি বিশ্বাস স্থাপন কর এবং তিনি তোমাদেরকে যার উত্তরাধিকারী করেছেন, তা থেকে ব্যয় কর। অতএব, তোমাদের মধ্যে যারা বিশ্বাস স্থাপন করে ও ব্যয় করে, তাদের জন্যে রয়েছে মহাপুরস্কার।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmlxxxiii{তোমাদের কি হল যে, তোমরা আল্লাহর প্রতি বিশ্বাস স্থাপন করছ না, অথচ রসূল তোমাদেরকে তোমাদের পালনকর্তার প্রতি বিশ্বাস স্থাপন করার দাওয়াত দিচ্ছেন? আল্লাহ তো পূর্বেই তোমাদের অঙ্গীকার নিয়েছেন-যদি তোমরা বিশ্বাসী হও।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmlxxxiv{তিনিই তাঁর দাসের প্রতি প্রকাশ্য আয়াত অবতীর্ণ করেন, যাতে তোমাদেরকে অন্ধকার থেকে আলোকে আনয়ন করেন। নিশ্চয় আল্লাহ তোমাদের প্রতি করুণাময়, পরম দয়ালু।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmlxxxv{তোমাদেরকে আল্লাহর পথে ব্যয় করতে কিসে বাধা দেয়, যখন আল্লাহই নভোমন্ডল ও ভূমন্ডলের উত্তরাধিকারী? তোমাদের মধ্যে যে মক্কা বিজয়ের পূর্বে ব্যয় করেছে ও জেহাদ করেছে, সে সমান নয়। এরূপ লোকদের মর্যদা বড় তাদের অপেক্ষা, যার পরে ব্যয় করেছে ও জেহাদ করেছে। তবে আল্লাহ উভয়কে কল্যাণের ওয়াদা দিয়েছেন। তোমরা যা কর, আল্লাহ সে সম্পর্কে সম্যক জ্ঞাত।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmlxxxvi{কে সেই ব্যক্তি, যে আল্লাহকে উত্তম ধার দিবে, এরপর তিনি তার জন্যে তা বহুগুণে বৃদ্ধি করবেন এবং তার জন্যে রয়েছে সম্মানিত পুরস্কার।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmlxxxvii{যেদিন আপনি দেখবেন ঈমানদার পুরুষ ও ঈমানদার নারীদেরকে, তাদের সম্মুখ ভাগে ও ডানপার্শ্বে তাদের জ্যোতি ছুটোছুটি করবে বলা হবেঃ আজ তোমাদের জন্যে সুসংবাদ জান্নাতের, যার তলদেশে নদী প্রবাহিত, তাতে তারা চিরকাল থাকবে। এটাই মহাসাফল্য।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmlxxxviii{যেদিন কপট বিশ্বাসী পুরুষ ও কপট বিশ্বাসিনী নারীরা মুমিনদেরকে বলবেঃ তোমরা আমাদের জন্যে অপেক্ষা কর, আমরাও কিছু আলো নিব তোমাদের জ্যোতি থেকে। বলা হবেঃ তোমরা পিছনে ফিরে যাও ও আলোর খোঁজ কর। অতঃপর উভয় দলের মাঝখানে খাড়া করা হবে একটি প্রাচীর, যার একটি দরজা হবে। তার অভ্যন্তরে থাকবে রহমত এবং বাইরে থাকবে আযাব।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmlxxxix{তারা মুমিনদেরকে ডেকে বলবেঃ আমরা কি তোমাদের সাথে ছিলাম না? তারা বলবেঃ হঁ্যা কিন্তু তোমরা নিজেরাই নিজেদেরকে বিপদগ্রস্ত করেছ। প্রতীক্ষা করেছ, সন্দেহ পোষণ করেছ এবং অলীক আশার পেছনে বিভ্রান্ত হয়েছ, অবশেষে আল্লাহর আদেশ পৌঁছেছে। এই সবই তোমাদেরকে আল্লাহ সম্পর্কে প্রতারিত করেছে।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmxc{অতএব, আজ তোমাদের কাছ থেকে কোন মুক্তিপন গ্রহণ করা হবে না। এবং কাফেরদের কাছ থেকেও নয়। তোমাদের সবার আবাস্থল জাহান্নাম। সেটাই তোমাদের সঙ্গী। কতই না নিকৃষ্ট এই প্রত্যাবর্তন স্থল।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmxci{যারা মুমিন, তাদের জন্যে কি আল্লাহর স্মরণে এবং যে সত্য অবর্তীর্ণ হয়েছে, তার কারণে হৃদয় বিগলিত হওয়ার সময় আসেনি? তারা তাদের মত যেন না হয়, যাদেরকে পূর্বে কিতাব দেয়া হয়েছিল। তাদের উপর সুদীর্ঘকাল অতিক্রান্ত হয়েছে, অতঃপর তাদের অন্তঃকরণ কঠিন হয়ে গেছে। তাদের অধিকাংশই পাপাচারী।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmxcii{তোমরা জেনে রাখ, আল্লাহই ভূ-ভাগকে তার মৃত্যুর পর পুনরুজ্জীবিত করেন। আমি পরিস্কারভাবে তোমাদের জন্যে আয়াতগুলো ব্যক্ত করেছি, যাতে তোমরা বোঝ।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmxciii{নিশ্চয় দানশীল ব্যক্তি ও দানশীলা নারী, যারা আল্লাহকে উত্তমরূপে ধার দেয়, তাদেরকে দেয়া হবে বহুগুণ এবং তাদের জন্যে রয়েছে সম্মানজনক পুরস্কার।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmxciv{আর যারা আল্লাহ ও তাঁর রসূলের প্রতি বিশ্বাস স্থাপন করে তারাই তাদের পালনকর্তার কাছে সিদ্দীক ও শহীদ বলে বিবেচিত। তাদের জন্যে রয়েছে পুরস্কার ও জ্যোতি এবং যারা কাফের ও আমার নিদর্শন অস্বীকারকারী তারাই জাহান্নামের অধিবাসী হবে।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmmxcv{তোমরা জেনে রাখ, পার্থিব জীবন ক্রীড়া-কৌতুক, সাজ-সজ্জা, পারস্পরিক অহমিকা এবং ধন ও জনের প্রাচুর্য ব্যতীত আর কিছু নয়, যেমন এক বৃষ্টির অবস্থা, যার সবুজ ফসল কৃষকদেরকে চমৎকৃত করে, এরপর তা শুকিয়ে যায়, ফলে তুমি তাকে পীতবর্ণ দেখতে পাও, এরপর তা খড়কুটা হয়ে যায়। আর পরকালে আছে কঠিন শাস্তি এবং আল্লাহর ক্ষমা ও সন্তুষ্টি। পার্থিব জীবন প্রতারণার উপকরণ বৈ কিছু নয়।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmmxcvi{তোমরা অগ্রে ধাবিত হও তোমাদের পালনকর্তার ক্ষমা ও সেই জান্নাতের দিকে, যা আকাশ ও পৃথিবীর মত প্রশস্ত। এটা প্রস্তুত করা হয়েছে আল্লাহ ও তাঁর রসূলগণের প্রতি বিশ্বাসস্থাপনকারীদের জন্যে। এটা আল্লাহর কৃপা, তিনি যাকে ইচ্ছা, এটা দান করেন। আল্লাহ মহান কৃপার অধিকারী।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmmxcvii{পৃথিবীতে এবং ব্যক্তিগতভাবে তোমাদের উপর কোন বিপদ আসে না; কিন্তু তা জগত সৃষ্টির পূর্বেই কিতাবে লিপিবদ্ধ আছে। নিশ্চয় এটা আল্লাহর পক্ষে সহজ।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmmxcviii{এটা এজন্যে বলা হয়, যাতে তোমরা যা হারাও তজ্জন্যে দুঃখিত না হও এবং তিনি তোমাদেরকে যা দিয়েছেন, তজ্জন্যে উল্লসিত না হও। আল্লাহ কোন উদ্ধত অহংকারীকে পছন্দ করেন না,\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmmxcix{যারা কৃপণতা করে এবং মানুষকে কৃপণতার প্রতি উৎসাহ দেয়, যে মুখ ফিরিয়ে নেয়, তার জানা উচিত যে, আল্লাহ অভাবমুক্ত, প্রশংসিত।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmmc{আমি আমার রসূলগণকে সুস্পষ্ট নিদর্শনসহ প্রেরণ করেছি এবং তাঁদের সাথে অবতীর্ণ করেছি কিতাব ও ন্যায়নীতি, যাতে মানুষ ইনসাফ প্রতিষ্ঠা করে। আর আমি নাযিল করেছি লৌহ, যাতে আছে প্রচন্ড রণশক্তি এবং মানুষের বহুবিধ উপকার। এটা এজন্যে যে, আল্লাহ জেনে নিবেন কে না দেখে তাঁকে ও তাঁর রসূলগণকে সাহায্য করে। আল্লাহ শক্তিধর, পরাক্রমশালী।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmmci{আমি নূহ ও ইব্রাহীমকে রসূলরূপে প্রেরণ করেছি এবং তাদের বংশধরের মধ্যে নবুওয়ত ও কিতাব অব্যাহত রেখেছি। অতঃপর তাদের কতক সৎপথপ্রাপ্ত হয়েছে এবং অধিকাংশই হয়েছে পাপাচারী।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmmcii{অতঃপর আমি তাদের পশ্চাতে প্রেরণ করেছি আমার রসূলগণকে এবং তাদের অনুগামী করেছি মরিয়ম তনয় ঈসাকে ও তাকে দিয়েছি ইঞ্জিল। আমি তার অনুসারীদের অন্তরে স্থাপন করেছি নম্রতা ও দয়া। আর বৈরাগ্য, সে তো তারা নিজেরাই উদ্ভাবন করেছে; আমি এটা তাদের উপর ফরজ করিনি; কিন্তু তারা আল্লাহর সন্তুষ্টি লাভের জন্যে এটা অবলম্বন করেছে। অতঃপর তারা যথাযথভাবে তা পালন করেনি। তাদের মধ্যে যারা বিশ্বাসী ছিল, আমি তাদেরকে তাদের প্রাপ্য পুরস্কার দিয়েছি। আর তাদের অধিকাংশই পাপাচারী।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmmciii{মুমিনগণ, তোমরা আল্লাহকে ভয় কর এবং তাঁর রসূলের প্রতি বিশ্বাস স্থাপন কর। তিনি নিজে অনুগ্রহের দ্বিগুণ অংশ তোমাদেরকে দিবেন, তোমাদেরকে দিবেন জ্যোতি, যার সাহায্যে তোমরা চলবে এবং তোমাদেরকে ক্ষমা করবেন। আল্লাহ ক্ষমাশীল, দয়াময়।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmmciv{যাতে কিতাবধারীরা জানে যে, আল্লাহর সামান্য অনুগ্রহের উপর ও তাদের কোন ক্ষমতা নেই, দয়া আল্লাহরই হাতে; তিনি যাকে ইচ্ছা, তা দান করেন। আল্লাহ মহা অনুগ্রহশীল।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmmcv{\basmalahbn যে নারী তার স্বামীর বিষয়ে আপনার সাথে বাদানুবাদ করছে এবং অভিযোগ পেশ করছে আল্লাহর দরবারে, আল্লাহ তার কথা শুনেছেন। আল্লাহ আপনাদের উভয়ের কথাবার্তা শুনেন। নিশ্চয় আল্লাহ সবকিছু শুনেন, সবকিছু দেখেন।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmcvi{তোমাদের মধ্যে যারা তাদের স্ত্রীগণকে মাতা বলে ফেলে, তাদের স্ত্রীগণ তাদের মাতা নয়। তাদের মাতা কেবল তারাই, যারা তাদেরকে জন্মদান করেছে। তারা তো অসমীচীন ও ভিত্তিহীন কথাই বলে। নিশ্চয় আল্লাহ মার্জনাকারী, ক্ষমাশীল।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmcvii{যারা তাদের স্ত্রীগণকে মাতা বলে ফেলে, অতঃপর নিজেদের উক্তি প্রত্যাহার করে, তাদের কাফফারা এই একে অপরকে স্পর্শ করার পূর্বে একটি দাসকে মুক্তি দিবে। এটা তোমাদের জন্যে উপদেশ হবে। আল্লাহ খবর রাখেন তোমরা যা কর।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmcviii{যার এ সামর্থ্য নেই, সে একে অপরকে স্পর্শ করার পূর্বে একাদিক্রমে দুই মাস রোযা রাখবে। যে এতেও অক্ষম হয় সে ষাট জন মিসকীনকে আহার করাবে। এটা এজন্যে, যাতে তোমরা আল্লাহ ও তাঁর রসূলের প্রতি বিশ্বাস স্থাপন কর। এগুলো আল্লাহর নির্ধারিত শাস্তি। আর কাফেরদের জন্যে রয়েছে যন্ত্রণা দায়ক আযাব।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmcix{যারা আল্লাহর তাঁর রসূলের বিরুদ্ধাচরণ করে, তারা অপদস্থ হয়েছে, যেমন অপদস্থ হয়েছে তাদের পূর্ববর্তীরা। আমি সুস্পষ্ট আয়াতসমূহ নাযিল করেছি। আর কাফেরদের জন্যে রয়েছে অপমানজনক শাস্তি।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmcx{সেদিন স্মরণীয়; যেদিন আল্লাহ তাদের সকলকে পুনরুত্থিত করবেন, অতঃপর তাদেরকে জানিয়ে দিবেন যা তারা করত। আল্লাহ তার হিসাব রেখেছেন, আর তারা তা ভুলে গেছে। আল্লাহর সামনে উপস্থিত আছে সব বস্তুই।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmcxi{আপনি কি ভেবে দেখেননি যে, নভোমন্ডল ও ভূমন্ডলে যা কিছু আছে, আল্লাহ তা জানেন। তিন ব্যক্তির এমন কোন পরামর্শ হয় না যাতে তিনি চতুর্থ না থাকেন এবং পাঁচ জনেরও হয় না, যাতে তিনি ষষ্ঠ না থাকেন তারা এতদপেক্ষা কম হোক বা বেশী হোক তারা যেখানেই থাকুক না কেন তিনি তাদের সাথে আছেন, তারা যা করে, তিনি কেয়ামতের দিন তা তাদেরকে জানিয়ে দিবেন। নিশ্চয় আল্লাহ সর্ববিষয়ে সম্যক জ্ঞাত।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmcxii{আপনি কি ভেবে দেখেননি, যাদেরকে কানাঘুষা করতে নিষেধ করা হয়েছিল অতঃপর তারা নিষিদ্ধ কাজেরই পুনরাবৃত্তি করে এবং পাপাচার, সীমালংঘন এবং রসূলের অবাধ্যতার বিষয়েই কানাঘুষা করে। তারা যখন আপনার কাছে আসে, তখন আপনাকে এমন ভাষায় সালাম করে, যদ্দ্বারা আল্লাহ আপনাকে সালাম করেননি। তারা মনে মনে বলেঃ আমরা যা বলি, তজ্জন্যে আল্লাহ আমাদেরকে শাস্তি দেন না কেন? জাহান্নামই তাদের জন্যে যথেষ্ট। তারা তাতে প্রবেশ করবে। কতই না নিকৃষ্ট সেই জায়গা।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmcxiii{মুমিনগণ, তোমরা যখন কানাকানি কর, তখন পাপাচার, সীমালংঘন ও রসূলের অবাধ্যতার বিষয়ে কানাকানি করো না বরং অনুগ্রহ ও খোদাভীতির ব্যাপারে কানাকানি করো। আল্লাহকে ভয় কর, যাঁর কাছে তোমরা একত্রিত হবে।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmcxiv{এই কানাঘুষা তো শয়তানের কাজ; মুমিনদেরকে দুঃখ দেয়ার দেয়ার জন্যে। তবে আল্লাহর অনুমতি ব্যতীত সে তাদের কোন ক্ষতি করতে পারবে না। মুমিনদের উচিত আল্লাহর উপর ভরসা করা।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmcxv{মুমিনগণ, যখন তোমাদেরকে বলা হয়ঃ মজলিসে স্থান প্রশস্ত করে দাও, তখন তোমরা স্থান প্রশস্ত করে দিও। আল্লাহর জন্যে তোমাদের জন্য প্রশস্ত করে দিবেন। যখন বলা হয়ঃ উঠে যাও, তখন উঠে যেয়ো। তোমাদের মধ্যে যারা ঈমানদার এবং যারা জ্ঞানপ্রাপ্ত, আল্লাহ তাদের মর্যাদা উচ্চ করে দিবেন। আল্লাহ খবর রাখেন যা কিছু তোমরা কর।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmcxvi{মুমিনগণ, তোমরা রসূলের কাছে কানকথা বলতে চাইলে তৎপূর্বে সদকা প্রদান করবে। এটা তোমাদের জন্যে শ্রেয়ঃ ও পবিত্র হওয়ার ভাল উপায়। যদি তাতে সক্ষম না হও, তবে আল্লাহ ক্ষমাশীল, পরম দয়ালু।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmcxvii{তোমরা কি কানকথা বলার পূর্বে সদকা প্রদান করতে ভীত হয়ে গেলে? অতঃপর তোমরা যখন সদকা দিতে পারলে না এবং আল্লাহ তোমাদেরকে মাফ করে দিলেন তখন তোমরা নামায কায়েম কর, যাকাত প্রদান কর এবং আল্লাহ ও রসূলের আনুগত্য কর। আল্লাহ খবর রাখেন তোমরা যা কর।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmcxviii{আপনি কি তাদের প্রতি লক্ষ্য করেননি, যারা আল্লাহর গযবে নিপতিত সম্প্রদায়ের সাথে বন্ধুত্ব করে? তারা মুসলমানদের দলভুক্ত নয় এবং তাদেরও দলভূক্ত নয়। তারা জেনেশুনে মিথ্যা বিষয়ে শপথ করে।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmcxix{আল্লাহ তাদের জন্যে কঠোর শাস্তি প্রস্তুত রেখেছেন। নিশ্চয় তারা যা করে, খুবই মন্দ।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmcxx{তারা তাদের শপথকে ঢাল করে রেখেছেন, অতঃপর তারা আল্লাহর পথ থেকে মানুষকে বাধা প্রদান করে। অতএব, তাদের জন্য রয়েছে অপমানজনক শাস্তি।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmcxxi{আল্লাহর কবল থেকে তাদের ধন-সম্পদ ও সন্তান-সন্ততি তাদেরকে মোটেই বাঁচাতে পারবেনা। তারাই জাহান্নামের অধিবাসী তথায় তারা চিরকাল থাকবে।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmcxxii{যেদিন আল্লাহ তাদের সকলকে পুনরুত্থিত করবেন। অতঃপর তারা আল্লাহর সামনে শপথ করবে, যেমন তোমাদের সামনে শপথ করে। তারা মনে করবে যে, তারা কিছু সৎপথে আছে। সাবধান, তারাই তো আসল মিথ্যাবাদী।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmcxxiii{শয়তান তাদেরকে বশীভূত করে নিয়েছে, অতঃপর আল্লাহর স্মরণ ভূলিয়ে দিয়েছে। তারা শয়তানের দল। সাবধান, শয়তানের দলই ক্ষতিগ্রস্ত।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmmcxxiv{নিশ্চয় যারা আল্লাহ ও তাঁর রসূলের বিরুদ্ধাচারণ করে, তারাই লাঞ্ছিতদের দলভূক্ত।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmmcxxv{আল্লাহ লিখে দিয়েছেনঃ আমি এবং আমার রসূলগণ অবশ্যই বিজয়ী হব। নিশ্চয় আল্লাহ শক্তিধর, পরাক্রমশালী।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmmcxxvi{যারা আল্লাহ ও পরকালে বিশ্বাস করে, তাদেরকে আপনি আল্লাহ ও তাঁর রসূলের বিরুদ্ধাচরণকারীদের সাথে বন্ধুত্ব করতে দেখবেন না, যদিও তারা তাদের পিতা, পুত্র, ভ্রাতা অথবা জ্ঞাতি-গোষ্ঠী হয়। তাদের অন্তরে আল্লাহ ঈমান লিখে দিয়েছেন এবং তাদেরকে শক্তিশালী করেছেন তাঁর অদৃশ্য শক্তি দ্বারা। তিনি তাদেরকে জান্নাতে দাখিল করবেন, যার তলদেশে নদী প্রবাহিত। তারা তথায় চিরকাল থাকবে। আল্লাহ তাদের প্রতি সন্তুষ্ট এবং তারা আল্লাহর প্রতি সন্তুষ্ট। তারাই আল্লাহর দল। জেনে রাখ, আল্লাহর দলই সফলকাম হবে।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmmcxxvii{\basmalahbn নভোমন্ডল ও ভূমন্ডলে যা কিছু আছে, সবই আল্লাহর পবিত্রতা বর্ণনা করে। তিনি পরাক্রমশালী মহাজ্ঞানী।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmcxxviii{তিনিই কিতাবধারীদের মধ্যে যারা কাফের, তাদেরকে প্রথমবার একত্রিত করে তাদের বাড়ী-ঘর থেকে বহিস্কার করেছেন। তোমরা ধারণাও করতে পারনি যে, তারা বের হবে এবং তারা মনে করেছিল যে, তাদের দূর্গগুলো তাদেরকে আল্লাহর কবল থেকে রক্ষা করবে। অতঃপর আল্লাহর শাস্তি তাদের উপর এমনদিক থেকে আসল, যার কল্পনাও তারা করেনি। আল্লাহ তাদের অন্তরে ত্রাস সঞ্চার করে দিলেন। তারা তাদের বাড়ী-ঘর নিজেদের হাতে এবং মুসলমানদের হাতে ধ্বংস করছিল। অতএব, হে চক্ষুষ্মান ব্যক্তিগণ, তোমরা শিক্ষা গ্রহণ কর।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmcxxix{আল্লাহ যদি তাদের জন্যে নির্বাসন অবধারিত না করতেন, তবে তাদেরকে দুনিয়াতে শাস্তি দিতেন। আর পরকালে তাদের জন্যে রয়েছে জাহান্নামের আযাব।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmcxxx{এটা এ কারণে যে, তারা আল্লাহ ও তাঁর রসূলের বিরুদ্ধাচরণ করেছে। যে আল্লাহর বিরুদ্ধাচরণ করে, তার জানা উচিত যে, আল্লাহ কঠোর শাস্তিদাতা।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmcxxxi{তোমরা যে কিছু কিছু খর্জুর বৃক্ষ কেটে দিয়েছ এবং কতক না কেটে ছেড়ে দিয়েছ, তা তো আল্লাহরই আদেশ এবং যাতে তিনি অবাধ্যদেরকে লাঞ্ছিত করেন।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmcxxxii{আল্লাহ বনু-বনুযায়রের কাছ থেকে তাঁর রসূলকে যে ধন-সম্পদ দিয়েছেন, তজ্জন্যে তোমরা ঘোড়ায় কিংবা উটে চড়ে যুদ্ধ করনি, কিন্তু আল্লাহ যার উপর ইচ্ছা, তাঁর রসূলগণকে প্রাধান্য দান করেন। আল্লাহ সবকিছুর উপর সর্বশক্তিমান।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmcxxxiii{আল্লাহ জনপদবাসীদের কাছ থেকে তাঁর রসূলকে যা দিয়েছেন, তা আল্লাহর, রসূলের, তাঁর আত্নীয়-স্বজনের, ইয়াতীমদের, অভাবগ্রস্তদের এবং মুসাফিরদের জন্যে, যাতে ধনৈশ্বর্য্য কেবল তোমাদের বিত্তশালীদের মধ্যেই পুঞ্জীভূত না হয়। রসূল তোমাদেরকে যা দেন, তা গ্রহণ কর এবং যা নিষেধ করেন, তা থেকে বিরত থাক এবং আল্লাহকে ভয় কর। নিশ্চয় আল্লাহ কঠোর শাস্তিদাতা।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmcxxxiv{এই ধন-সম্পদ দেশত্যাগী নিঃস্বদের জন্যে, যারা আল্লাহর অনুগ্রহ ও সন্তুষ্টিলাভের অন্বেষণে এবং আল্লাহ তাঁর রসূলের সাহায্যার্থে নিজেদের বাস্তুভিটা ও ধন-সম্পদ থেকে বহিস্কৃত হয়েছে। তারাই সত্যবাদী।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmcxxxv{যারা মুহাজিরদের আগমনের পূর্বে মদীনায় বসবাস করেছিল এবং বিশ্বাস স্থাপন করেছিল, তারা মুহাজিরদের ভালবাসে, মুহাজিরদেরকে যা দেয়া হয়েছে, তজ্জন্যে তারা অন্তরে ঈর্ষাপোষণ করে না এবং নিজেরা অভাবগ্রস্ত হলেও তাদেরকে অগ্রাধিকার দান করে। যারা মনের কার্পণ্য থেকে মুক্ত, তারাই সফলকাম।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmcxxxvi{আর এই সম্পদ তাদের জন্যে, যারা তাদের পরে আগমন করেছে। তারা বলেঃ হে আমাদের পালনকর্তা, আমাদেরকে এবং ঈমানে আগ্রহী আমাদের ভ্রাতাগণকে ক্ষমা কর এবং ঈমানদারদের বিরুদ্ধে আমাদের অন্তরে কোন বিদ্বেষ রেখো না। হে আমাদের পালনকর্তা, আপনি দয়ালু, পরম করুণাময়।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmcxxxvii{আপনি কি মুনাফিকদেরকে দেখেন নি? তারা তাদের কিতাবধারী কাফের ভাইদেরকে বলেঃ তোমরা যদি বহিস্কৃত হও, তবে আমরা অবশ্যই তোমাদের সাথে দেশ থেকে বের হয়ে যাব এবং তোমাদের ব্যাপারে আমরা কখনও কারও কথা মানব না। আর যদি তোমরা আক্রান্ত হও, তবে আমরা অবশ্যই তোমাদেরকে সাহায্য করব। আল্লাহ তা’আলা সাক্ষ্য দেন যে, ওরা নিশ্চয়ই মিথ্যাবাদী।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmcxxxviii{যদি তারা বহিস্কৃত হয়, তবে মুনাফিকরা তাদের সাথে দেশত্যাগ করবে না আর যদি তারা আক্রান্ত হয়, তবে তারা তাদেরকে সাহায্য করবে না। যদি তাদেরকে সাহায্য করে, তবে অবশ্যই পৃষ্ঠপ্রদর্শন করে পলায়ন করবে। এরপর কাফেররা কোন সাহায্য পাবে না।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmcxxxix{নিশ্চয় তোমরা তাদের অন্তরে আল্লাহ তা’আলা অপেক্ষা অধিকতর ভয়াবহ। এটা এ কারণে যে, তারা এক নির্বোধ সম্প্রদায়।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmcxl{তারা সংঘবদ্ধভাবেও তোমাদের বিরুদ্ধে যুদ্ধ করতে পারবে না। তারা যুদ্ধ করবে কেবল সুরক্ষিত জনপদে অথবা দুর্গ প্রাচীরের আড়াল থেকে। তাদের পারস্পরিক যুদ্ধই প্রচন্ড হয়ে থাকে। আপনি তাদেরকে ঐক্যবদ্ধ মনে করবেন; কিন্তু তাদের অন্তর শতধাবিচ্ছিন্ন। এটা এ কারণে যে, তারা এক কান্ডজ্ঞানহীণ সম্প্রদায়।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmcxli{তারা সেই লোকদের মত, যারা তাদের নিকট অতীতে নিজেদের কর্মের শাস্তিভোগ করেছে। তাদের জন্যে রয়েছে যন্ত্রণাদায়ক শাস্তি।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmcxlii{তারা শয়তানের মত, যে মানুষকে কাফের হতে বলে। অতঃপর যখন সে কাফের হয়, তখন শয়তান বলেঃ তোমার সাথে আমার কোন সম্পর্ক নেই। আমি বিশ্বপালনকর্তা আল্লাহ তা’আলাকে ভয় করি।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmcxliii{অতঃপর উভয়ের পরিণতি হবে এই যে, তারা জাহান্নামে যাবে এবং চিরকাল তথায় বসবাস করবে। এটাই জালেমদের শাস্তি।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmcxliv{মুমিনগণ, তোমরা আল্লাহ তা’আলাকে ভয় কর। প্রত্যেক ব্যক্তির উচিত, আগামী কালের জন্যে সে কি প্রেরণ করে, তা চিন্তা করা। আল্লাহ তা’আলাকে ভয় করতে থাক। তোমরা যা কর, আল্লাহ তা’আলা সে সম্পর্কে খবর রাখেন।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmcxlv{তোমরা তাদের মত হয়ো না, যারা আল্লাহ তা’আলাকে ভুলে গেছে। ফলে আল্লাহ তা’আলা তাদেরকে আত্ন বিস্মৃত করে দিয়েছেন। তারাই অবাধ্য।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmmcxlvi{জাহান্নামের অধিবাসী এবং জান্নাতের অধিবাসী সমান হতে পারে না। যারা জান্নাতের অধিবাসী, তারাই সফলকাম।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmmcxlvii{যদি আমি এই কোরআন পাহাড়ের উপর অবতীর্ণ করতাম, তবে তুমি দেখতে যে, পাহাড় বিনীত হয়ে আল্লাহ তা’আলার ভয়ে বিদীর্ণ হয়ে গেছে। আমি এসব দৃষ্টান্ত মানুষের জন্যে বর্ণনা করি, যাতে তারা চিন্তা-ভাবনা করে।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmmcxlviii{তিনিই আল্লাহ তা’আলা, তিনি ব্যতীত কোন উপাস্য নেই; তিনি দৃশ্য ও অদৃশ্যকে জানেন তিনি পরম দয়ালু, অসীম দাতা।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmmcxlix{তিনিই আল্লাহ তিনি ব্যতিত কোন উপাস্য নেই। তিনিই একমাত্র মালিক, পবিত্র, শান্তি ও নিরাপত্তাদাতা, আশ্রয়দাতা, পরাক্রান্ত, প্রতাপান্বিত, মাহাত্ন?486;ীল। তারা যাকে অংশীদার করে আল্লাহ তা’ আলা তা থেকে পবিত্র।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmmcl{তিনিই আল্লাহ তা’আলা, স্রষ্টা, উদ্ভাবক, রূপদাতা, উত্তম নাম সমূহ তাঁরই। নভোমন্ডলে ও ভূমন্ডলে যা কিছু আছে, সবই তাঁর পবিত্রতা ঘোষণা করে। তিনি পরাক্রান্ত প্রজ্ঞাময়।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmmcli{\basmalahbn মুমিনগণ, তোমরা আমার ও তোমাদের শত্রুদেরকে বন্ধরূপে গ্রহণ করো না। তোমরা তো তাদের প্রতি বন্ধুত্বের বার্তা পাঠাও, অথচ তারা যে সত্য তোমাদের কাছে আগমন করেছে, তা অস্বীকার করছে। তারা রসূলকে ও তোমাদেরকে বহিস্কার করে এই অপরাধে যে, তোমরা তোমাদের পালনকর্তার প্রতি বিশ্বাস রাখ। যদি তোমরা আমার সন্তুষ্টিলাভের জন্যে এবং আমার পথে জেহাদ করার জন্যে বের হয়ে থাক, তবে কেন তাদের প্রতি গোপনে বন্ধুত্বের পয়গাম প্রেরণ করছ? তোমরা যা গোপন কর এবং যা প্রকাশ কর, ত আমি খুব জানি। তোমাদের মধ্যে যে এটা করে, সে সরলপথ থেকে বিচ্যুত হয়ে যায়।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmclii{তোমাদেরকে করতলগত করতে পারলে তারা তোমাদের শত্রু হয়ে যাবে এবং মন্দ উদ্দেশ্যে তোমাদের প্রতি বাহু ও রসনা প্রসারিত করবে এবং চাইবে যে, কোনরূপে তোমরা ও কাফের হয়ে যাও।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmcliii{তোমাদের স্বজন-পরিজন ও সন্তান-সন্ততি কিয়ামতের দিন কোন উপকারে আসবে না। তিনি তোমাদের মধ্যে ফয়সালা করবেন। তোমরা যা কর, আল্লাহ তা দেখেন।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmcliv{তোমাদের জন্যে ইব্রাহীম ও তাঁর সঙ্গীগণের মধ্যে চমৎকার আদর্শ রয়েছে। তারা তাদের সম্প্রদায়কে বলেছিলঃ তোমাদের সাথে এবং তোমরা আল্লাহর পরিবর্তে যার এবাদত কর, তার সাথে আমাদের কোন সম্পর্ক নেই। আমরা তোমাদের মানি না। তোমরা এক আল্লাহর প্রতি বিশ্বাস স্থাপন না করলে তোমাদের মধ্যে ও আমাদের মধ্যে চিরশত্রুতা থাকবে। কিন্তু ইব্রাহীমের উক্তি তাঁর পিতার উদ্দেশে এই আদর্শের ব্যতিক্রম। তিনি বলেছিলেনঃ আমি অবশ্যই তোমার জন্য ক্ষমাপ্রার্থনা করব। তোমার উপকারের জন্যে আল্লাহর কাছে আমার আর কিছু করার নেই। হে আমাদের পালনকর্তা! আমরা তোমারই উপর ভরসা করেছি, তোমারই দিকে মুখ করেছি এবং তোমারই নিকট আমাদের প্রত্যাবর্তন।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmclv{হে আমাদের পালনকর্তা! তুমি আমাদেরকে কাফেরদের জন্য পরীক্ষার পাত্র করো না। হে আমাদের পালনকর্তা! আমাদের ক্ষমা কর। নিশ্চয় তুমি পরাক্রমশালী, প্রজ্ঞাময়।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmclvi{তোমরা যারা আল্লাহ ও পরকাল প্রত্যাশা কর, তোমাদের জন্য তাদের মধ্যে উত্তম আদর্শ রয়েছে। আর যে মুখ ফিরিয়ে নেয়, তার জানা উচিত যে, আল্লাহ বেপরওয়া, প্রশংসার মালিক।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmclvii{যারা তোমাদের শত্রু আল্লাহ তাদের মধ্যে ও তোমাদের মধ্যে সম্ভবতঃ বন্ধুত্ব সৃষ্টি করে দেবেন। আল্লাহ সবই করতে পারেন এবং আল্লাহ ক্ষমাশীল, করুণাময়।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmclviii{ধর্মের ব্যাপারে যারা তোমাদের বিরুদ্ধে লড়াই করেনি এবং তোমাদেরকে দেশ থেকে বহিস্কৃত করেনি, তাদের প্রতি সদাচরণ ও ইনসাফ করতে আল্লাহ তোমাদেরকে নিষেধ করেন না। নিশ্চয় আল্লাহ ইনসাফকারীদেরকে ভালবাসেন।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmclix{আল্লাহ কেবল তাদের সাথে বন্ধুত্ব করতে নিষেধ করেন, যারা ধর্মের ব্যাপারে তোমাদের বিরুদ্ধে যুদ্ধ করেছে, তোমাদেরকে দেশ থেকে বহিস্কৃত করেছে এবং বহিস্কারকার্যে সহায়তা করেছে। যারা তাদের সাথে বন্ধুত্ব করে তারাই জালেম।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmclx{মুমিনগণ, যখন তোমাদের কাছে ঈমানদার নারীরা হিজরত করে আগমন করে, তখন তাদেরকে পরীক্ষা কর। আল্লাহ তাদের ঈমান সম্পর্কে সম্যক অবগত আছেন। যদি তোমরা জান যে, তারা ঈমানদার, তবে আর তাদেরকে কাফেরদের কাছে ফেরত পাঠিও না। এরা কাফেরদের জন্যে হালাল নয় এবং কাফেররা এদের জন্যে হালাল নয়। কাফেররা যা ব্যয় করেছে, তা তাদের দিয়ে দাও। তোমরা, এই নারীদেরকে প্রাপ্য মোহরানা দিয়ে বিবাহ করলে তোমাদের অপরাধ হবে না। তোমরা কাফের নারীদের সাথে দাম্পত্য সম্পর্ক বজায় রেখো না। তোমরা যা ব্যয় করেছ, তা চেয়ে নাও এবং তারাও চেয়ে নিবে যা তারা ব্যয় করেছে। এটা আল্লাহর বিধান; তিনি তোমাদের মধ্যে ফয়সালা করেন। আল্লাহ সর্বজ্ঞ প্রজ্ঞাময়।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmclxi{তোমাদের স্ত্রীদের মধ্যে যদি কেউ হাতছাড়া হয়ে কাফেরদের কাছে থেকে যায়, অতঃপর তোমরা সুযোগ পাও, তখন যাদের স্ত্রী হাতছাড়া হয়ে গেছে, তাদেরকে তাদের ব্যয়কৃত অর্থের সমপরিমাণ অর্থ প্রদান কর এবং আল্লাহকে ভয় কর, যার প্রতি তোমরা বিশ্বাস রাখ।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmclxii{হে নবী, ঈমানদার নারীরা যখন আপনার কাছে এসে আনুগত্যের শপথ করে যে, তারা আল্লাহর সাথে কাউকে শরীক করবে না, চুরি করবে না, ব্যভিচার করবে না, তাদের সন্তানদেরকে হত্যা করবে না, জারজ সন্তানকে স্বামীর ঔরস থেকে আপন গর্ভজাত সন্তান বলে মিথ্যা দাবী করবে না এবং ভাল কাজে আপনার অবাধ্যতা করবে না, তখন তাদের আনুগত্য গ্রহণ করুন এবং তাদের জন্যে আল্লাহর কাছে ক্ষমা প্রার্থনা করুন। নিশ্চয় আল্লাহ ক্ষমাশীল অত্যন্ত দয়ালু।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmclxiii{মুমিনগণ, আল্লাহ যে জাতির প্রতি রুষ্ট, তোমরা তাদের সাথে বন্ধুত্ব করো না। তারা পরকাল সম্পর্কে নিরাশ হয়ে গেছে যেমন কবরস্থ কাফেররা নিরাশ হয়ে গেছে।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmclxiv{\basmalahbn নভোমন্ডলে ও ভূমন্ডলে যা কিছু আছে, সবই আল্লাহর পবিত্রতা ঘোষণা করে। তিনি পরাক্রান্ত প্রজ্ঞাবান।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmclxv{মুমিনগণ! তোমরা যা কর না, তা কেন বল?\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmclxvi{তোমরা যা কর না, তা বলা আল্লাহর কাছে খুবই অসন্তোষজনক।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmclxvii{আল্লাহ তাদেরকে ভালবাসেন, যারা তাঁর পথে সারিবদ্ধভাবে লড়াই করে, যেন তারা সীসাগালানো প্রাচীর।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmclxviii{স্মরণ কর, যখন মূসা (আঃ) তাঁর সম্প্রদায়কে বললঃ হে আমার সম্প্রদায়, তোমরা কেন আমাকে কষ্ট দাও, অথচ তোমরা জান যে, আমি তোমাদের কাছে আল্লাহর রসূল। অতঃপর তারা যখন বক্রতা অবলম্বন করল, তখন আল্লাহ তাদের অন্তরকে বক্র করে দিলেন। আল্লাহ পাপাচারী সম্প্রদায়কে পথপ্রদর্শন করেন না।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmclxix{স্মরণ কর, যখন মরিয়ম-তনয় ঈসা (আঃ) বললঃ হে বনী ইসরাইল! আমি তোমাদের কাছে আল্লাহর প্রেরিত রসূল, আমার পূর্ববর্তী তওরাতের আমি সত্যায়নকারী এবং আমি এমন একজন রসূলের সুসংবাদদাতা, যিনি আমার পরে আগমন করবেন। তাঁর নাম আহমদ। অতঃপর যখন সে স্পষ্ট প্রমাণাদি নিয়ে আগমন করল, তখন তারা বললঃ এ তো এক প্রকাশ্য যাদু।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmclxx{যে ব্যক্তি ইসলামের দিকে আহুত হয়েও আল্লাহ সম্পর্কে মিথ্যা বলে; তার চাইতে অধিক যালেম আর কে? আল্লাহ যালেম সম্প্রদায়কে পথ প্রদর্শন করেন না।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmclxxi{তারা মুখের ফুঁৎকারে আল্লাহর আলো নিভিয়ে দিতে চায়। আল্লাহ তাঁর আলোকে পূর্ণরূপে বিকশিত করবেন যদিও কাফেররা তা অপছন্দ করে।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmclxxii{তিনি তাঁর রসূলকে পথ নির্দেশ ও সত্যধর্ম নিয়ে প্রেরণ করেছেন, যাতে একে সবধর্মের উপর প্রবল করে দেন যদিও মুশরিকরা তা অপছন্দ করে।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmclxxiii{মুমিনগণ, আমি কি তোমাদেরকে এমন এক বানিজ্যের সন্ধান দিব, যা তোমাদেরকে যন্ত্রণাদায়ক শাস্তি থেকে মুক্তি দেবে?\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmclxxiv{তা এই যে, তোমরা আল্লাহ ও তাঁর রসূলের প্রতি বিশ্বাস স্থাপন করবে এবং আল্লাহর পথে নিজেদের ধন-সম্পদ ও জীবনপণ করে জেহাদ করবে। এটাই তোমাদের জন্যে উত্তম; যদি তোমরা বোঝ।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmclxxv{তিনি তোমাদের পাপরাশি ক্ষমা করবেন এবং এমন জান্নাতে দাখিল করবেন, যার পাদদেশে নদী প্রবাহিত এবং বসবাসের জান্নাতে উত্তম বাসগৃহে। এটা মহাসাফল্য।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmclxxvi{এবং আরও একটি অনুগ্রহ দিবেন, যা তোমরা পছন্দ কর। আল্লাহর পক্ষ থেকে সাহায্য এবং আসন্ন বিজয়। মুমিনদেরকে এর সুসংবাদ দান করুন।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmclxxvii{মুমিনগণ, তোমরা আল্লাহর সাহায্যকারী হয়ে যাও, যেমন ঈসা ইবনে-মরিয়ম তার শিষ্যবর্গকে বলেছিল, আল্লাহর পথে কে আমার সাহায্যকারী হবে? শিষ্যবর্গ বলেছিলঃ আমরা আল্লাহর পথে সাহায্যকারী। অতঃপর বনী-ইসরাঈলের একদল বিশ্বাস স্থাপন করল এবং একদল কাফের হয়ে গেল। যারা বিশ্বাস স্থাপন করেছিল, আমি তাদেরকে তাদের শত্রুদের মোকাবেলায় শক্তি যোগালাম, ফলে তারা বিজয়ী হল।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmclxxviii{\basmalahbn রাজ্যাধিপতি, পবিত্র, পরাক্রমশালী ও প্রজ্ঞাময় আল্লাহর পবিত্রতা ঘোষণা করে, যা কিছু আছে নভোমন্ডলে ও যা কিছু আছে ভূমন্ডলে।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmclxxix{তিনিই নিরক্ষরদের মধ্য থেকে একজন রসূল প্রেরণ করেছেন, যিনি তাদের কাছে পাঠ করেন তার আয়াতসমূহ, তাদেরকে পবিত্র করেন এবং শিক্ষা দেন কিতাব ও হিকমত। ইতিপূর্বে তারা ছিল ঘোর পথভ্রষ্টতায় লিপ্ত।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmclxxx{এই রসূল প্রেরিত হয়েছেন অন্য আরও লোকদের জন্যে, যারা এখনও তাদের সাথে মিলিত হয়নি। তিনি পরাক্রমশালী, প্রজ্ঞাময়।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmclxxxi{এটা আল্লাহর কৃপা, যাকে ইচ্ছা তিনি তা দান করেন। আল্লাহ মহাকৃপাশীল।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmclxxxii{যাদেরকে তওরাত দেয়া হয়েছিল, অতঃপর তারা তার অনুসরণ করেনি, তাদের দৃষ্টান্ত সেই গাধা, যে পুস্তক বহন করে, যারা আল্লাহর আয়াতসমূহকে মিথ্যা বলে, তাদের দৃষ্টান্ত কত নিকৃষ্ট। আল্লাহ জালেম সম্প্রদায়কে পথ প্রদর্শন করেন না।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmclxxxiii{বলুন হে ইহুদীগণ, যদি তোমরা দাবী কর যে, তোমরাই আল্লাহর বন্ধু-অন্য কোন মানব নয়, তবে তোমরা মৃত্যু কামনা কর যদি তোমরা সত্যবাদী হও।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmclxxxiv{তারা নিজেদের কৃতকর্মের কারণে কখনও মৃত্যু কামনা করবে না। আল্লাহ জালেমদের সম্পর্কে সম্যক অবগত আছেন।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmclxxxv{বলুন, তোমরা যে মৃত্যু থেকে পলায়নপর, সেই মৃত্যু অবশ্যই তোমাদের মুখামুখি হবে, অতঃপর তোমরা অদৃশ্য, দৃশ্যের জ্ঞানী আল্লাহর কাছে উপস্থিত হবে। তিনি তোমাদেরকে জানিয়ে দিবেন সেসব কর্ম, যা তোমরা করতে।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmclxxxvi{মুমিনগণ, জুমআর দিনে যখন নামাযের আযান দেয়া হয়, তখন তোমরা আল্লাহর স্মরণের পানে ত্বরা কর এবং বেচাকেনা বন্ধ কর। এটা তোমাদের জন্যে উত্তম যদি তোমরা বুঝ।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmclxxxvii{অতঃপর নামায সমাপ্ত হলে তোমরা পৃথিবীতে ছড়িয়ে পড় এবং আল্লাহর অনুগ্রহ তালাশ কর ও আল্লাহকে অধিক স্মরণ কর, যাতে তোমরা সফলকাম হও।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmclxxxviii{তারা যখন কোন ব্যবসায়ের সুযোগ অথবা ক্রীড়াকৌতুক দেখে তখন আপনাকে দাঁড়ানো অবস্থায় রেখে তারা সেদিকে ছুটে যায়। বলুনঃ আল্লাহর কাছে যা আছে, তা ক্রীড়াকৌতুক ও ব্যবসায় অপেক্ষা উৎকৃষ্ট। আল্লাহ সর্বোত্তম রিযিকদাতা।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmclxxxix{\basmalahbn মুনাফিকরা আপনার কাছে এসে বলেঃ আমরা সাক্ষ্য দিচ্ছি যে আপনি নিশ্চয়ই আল্লাহর রসূল। আল্লাহ জানেন যে, আপনি অবশ্যই আল্লাহর রসূল এবং আল্লাহ সাক্ষ্য দিচ্ছেন যে, মুনাফিকরা অবশ্যই মিথ্যাবাদী।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmcxc{তারা তাদের শপথসমূহকে ঢালরূপে ব্যবহার করে। অতঃপর তারা আল্লাহর পথে বাধা সৃষ্টি করে। তারা যা করছে, তা খুবই মন্দ।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmcxci{এটা এজন্য যে, তারা বিশ্বাস করার পর পুনরায় কাফের হয়েছে। ফলে তাদের অন্তরে মোহর মেরে দেয়া হয়েছে। অতএব তারা বুঝে না।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmcxcii{আপনি যখন তাদেরকে দেখেন, তখন তাদের দেহাবয়ব আপনার কাছে প্রীতিকর মনে হয়। আর যদি তারা কথা বলে, তবে আপনি তাদের কথা শুনেন। তারা প্রাচীরে ঠেকানো কাঠসদৃশ্য। প্রত্যেক শোরগোলকে তারা নিজেদের বিরুদ্ধে মনে করে। তারাই শত্রু, অতএব তাদের সম্পর্কে সতর্ক হোন। ধ্বংস করুন আল্লাহ তাদেরকে। তারা কোথায় বিভ্রান্ত হচ্ছে ?\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmcxciii{যখন তাদেরকে বলা হয়ঃ তোমরা এস, আল্লাহর রসূল তোমাদের জন্য ক্ষমাপ্রার্থনা করবেন, তখন তারা মাথা ঘুরিয়ে নেয় এবং আপনি তাদেরকে দেখেন যে, তারা অহংকার করে মুখ ফিরিয়ে নেয়।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmcxciv{আপনি তাদের জন্যে ক্ষমাপ্রার্থনা করুন অথবা না করুন, উভয়ই সমান। আল্লাহ কখনও তাদেরকে ক্ষমা করবেন না। আল্লাহ পাপাচারী সম্প্রদায়কে পথপ্রদর্শন করেন না।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmcxcv{তারাই বলেঃ আল্লাহর রাসূলের সাহচর্যে যারা আছে তাদের জন্যে ব্যয় করো না। পরিণামে তারা আপনা-আপনি সরে যাবে। ভূ ও নভোমন্ডলের ধন-ভান্ডার আল্লাহরই কিন্তু মুনাফিকরা তা বোঝে না।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmcxcvi{তারাই বলেঃ আমরা যদি মদীনায় প্রত্যাবর্তন করি তবে সেখান থেকে সবল অবশ্যই দুর্বলকে বহিস্কৃত করবে। শক্তি তো আল্লাহ তাঁর রসূল ও মুমিনদেরই কিন্তু মুনাফিকরা তা জানে না।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmcxcvii{মুমিনগণ! তোমাদের ধন-সম্পদ ও সন্তান-সন্ততি যেন তোমাদেরকে আল্লাহর স্মরণ থেকে গাফেল না করে। যারা এ কারণে গাফেল হয়, তারাই তো ক্ষতিগ্রস্ত।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmcxcviii{আমি তোমাদেরকে যা দিয়েছি, তা থেকে মৃত্যু আসার আগেই ব্যয় কর। অন্যথায় সে বলবেঃ হে আমার পালনকর্তা, আমাকে আরও কিছুকাল অবকাশ দিলে না কেন? তাহলে আমি সদকা করতাম এবং সৎকর্মীদের অন্তর্ভুক্ত হতাম।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmcxcix{প্রত্যেক ব্যক্তির নির্ধারিত সময় যখন উপস্থিত হবে, তখন আল্লাহ কাউকে অবকাশ দেবেন না। তোমরা যা কর, আল্লাহ সে বিষয়ে খবর রাখেন।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmcc{\basmalahbn নভোমন্ডল ও ভূমন্ডলে যা কিছু আছে, সবই আল্লাহর পবিত্রতা ঘোষণা করে। রাজত্ব তাঁরই এবং প্রশংসা তাঁরই। তিনি সর্ববিষয়ে সর্বশক্তিমান।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmcci{তিনিই তোমাদেরকে সৃষ্টি করেছেন, অতঃপর তোমাদের মধ্যে কেউ কাফের এবং কেউ মুমিন। তোমরা যা কর, আল্লাহ তা দেখেন।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmccii{তিনি নভোমন্ডল ও ভূমন্ডলকে যথাযথভাবে সৃষ্টি করেছেন এবং তোমাদেরকে আকৃতি দান করেছেন, অতঃপর সুন্দর করেছেন তোমাদের আকৃতি। তাঁরই কাছে প্রত্যাবর্তন।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmcciii{নভোমন্ডল ও ভূমন্ডলে যা আছে, তিনি তা জানেন। তিনি আরও জানেন তোমরা যা গোপনে কর এবং যা প্রকাশ্যে কর। আল্লাহ অন্তরের বিষয়াদি সম্পর্কে সম্যক জ্ঞাত।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmcciv{তোমাদের পুর্বে যারা কাফের ছিল, তাদের বৃত্তান্ত কি তোমাদের কাছে পৌছেনি? তারা তাদের কর্মের শাস্তি আস্বাদন করেছে, এবং তাদের জন্যে রয়েছে যন্ত্রণাদায়ক শাস্তি।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmccv{এটা এ কারণে যে, তাদের কাছে তাদের রসূলগণ প্রকাশ্য নিদর্শনাবলীসহ আগমন করলে তারা বলতঃ মানুষই কি আমাদেরকে পথপ্রদর্শন করবে? অতঃপর তারা কাফের হয়ে গেল এবং মুখ ফিরিয়ে নিল। এতে আল্লাহর কিছু আসে যায় না। আল্লাহ অমুখাপেক্ষী প্রশংসিত।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmccvi{কাফেররা দাবী করে যে, তারা কখনও পুনরুত্থিত হবে না। বলুন, অবশ্যই হবে, আমার পালনকর্তার কসম, তোমরা নিশ্চয় পুরুত্থিত হবে। অতঃপর তোমাদেরকে অবহিত করা হবে যা তোমরা করতে। এটা আল্লাহর পক্ষে সহজ।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmccvii{অতএব তোমরা আল্লাহ তাঁর রসূল এবং অবতীর্ন নূরের প্রতি বিশ্বাস স্থাপন কর। তোমরা যা কর, সে বিষয়ে আল্লাহ সম্যক অবগত।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmccviii{সেদিন অর্থাৎ, সমাবেশের দিন আল্লাহ তোমাদেরকে সমবেত করবেন। এ দিন হার-জিতের দিন। যে ব্যক্তি আল্লাহর প্রতি বিশ্বাস স্থাপন করে এবং সৎকর্ম সম্পাদন করে, আল্লাহ তার পাপসমূহ মোচন করবেন এবং তাকে জান্নাতে দাখিল করবেন। যার তলদেশে নির্ঝরিনীসমূহ প্রবাহিত হবে, তারা তথায় চিরকাল বসবাস করবে। এটাই মহাসাফল্য।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmccix{আর যারা কাফের এবং আমার আয়াতসমূহকে মিথ্যা বলে, তারাই জাহান্নামের অধিবাসী, তারা তথায় অনন্তকাল থাকবে। কতই না মন্দ প্রত্যাবর্তনস্থল এটা।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmccx{আল্লাহর নির্দেশ ব্যতিরেকে কোন বিপদ আসে না এবং যে আল্লাহর প্রতি বিশ্বাস করে, তিনি তার অন্তরকে সৎপথ প্রদর্শন করেন। আল্লাহ সর্ববিষয়ে সম্যক পরিজ্ঞাত।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmccxi{তোমরা আল্লাহর আনুগত্য কর এবং রসূলুল্লাহর আনুগত্য কর। যদি তোমরা মুখ ফিরিয়ে নাও, তবে আমার রসূলের দায়িত্ব কেবল খোলাখুলি পৌছে দেয়া।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmccxii{আল্লাহ তিনি ব্যতীত কোন মাবুদ নেই। অতএব মুমিনগণ আল্লাহর উপর ভরসা করুক।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmccxiii{হে মুমিনগণ, তোমাদের কোন কোন স্ত্রী ও সন্তান-সন্ততি তোমাদের দুশমন। অতএব তাদের ব্যাপারে সতর্ক থাক। যদি মার্জনা কর, উপেক্ষা কর, এবং ক্ষমা কর, তবে আল্লাহ ক্ষমাশীল, করুনাময়।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmccxiv{তোমাদের ধন-সম্পদ ও সন্তান-সন্ততি তো কেবল পরীক্ষাস্বরূপ। আর আল্লাহর কাছে রয়েছে মহাপুরস্কার।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmccxv{অতএব তোমরা যথাসাধ্য আল্লাহকে ভয় কর, শুন, আনুগত্য কর এবং ব্যয় কর। এটা তোমাদের জন্যে কল্যাণকর। যারা মনের কার্পন্য থেকে মুক্ত, তারাই সফলকাম।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmccxvi{যদি তোমরা আল্লাহকে উত্তম ঋণ দান কর, তিনি তোমাদের জন্যে তা দ্বিগুণ করে দেবেন এবং তোমাদেরকে ক্ষমা করবেন। আল্লাহ গুণগ্রাহী, সহনশীল।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmccxvii{তিনি দৃশ্য ও অদৃশ্যের জ্ঞানী, পরাক্রান্ত, প্রজ্ঞাময়।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmccxviii{\basmalahbn হে নবী, তোমরা যখন স্ত্রীদেরকে তালাক দিতে চাও, তখন তাদেরকে তালাক দিয়ো ইদ্দতের প্রতি লক্ষ্য রেখে এবং ইদ্দত গণনা করো। তোমরা তোমাদের পালনকর্তা আল্লাহকে ভয় করো। তাদেরকে তাদের গৃহ থেকে বহিস্কার করো না এবং তারাও যেন বের না হয় যদি না তারা কোন সুস্পষ্ট নির্লজ্জ কাজে লিপ্ত হয়। এগুলো আল্লাহর নির্ধারিত সীমা। যে ব্যক্তি আল্লাহর সীমালংঘন করে, সে নিজেরই অনিষ্ট করে। সে জানে না, হয়তো আল্লাহ এই তালাকের পর কোন নতুন উপায় করে দেবেন।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmccxix{অতঃপর তারা যখন তাদের ইদ্দতকালে পৌঁছে, তখন তাদেরকে যথোপযুক্ত পন্থায় রেখে দেবে অথবা যথোপযুক্ত পন্থায় ছেড়ে দেবে এবং তোমাদের মধ্য থেকে দু’জন নির্ভরযোগ্য লোককে সাক্ষী রাখবে। তোমরা আল্লাহর উদ্দেশ্যে সাক্ষ্য দিবে। এতদ্দ্বারা যে ব্যক্তি আল্লাহ ও পরকালে বিশ্বাস করে, তাকে উপদেশ দেয়া হচ্ছে। আর যে আল্লাহকে ভয় করে, আল্লাহ তার জন্যে নিস্কৃতির পথ করে দেবেন।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmccxx{এবং তাকে তার ধারণাতীত জায়গা থেকে রিযিক দেবেন। যে ব্যক্তি আল্লাহর উপর ভরসা করে তার জন্যে তিনিই যথেষ্ট। আল্লাহ তার কাজ পূর্ণ করবেন। আল্লাহ সবকিছুর জন্যে একটি পরিমাণ স্থির করে রেখেছেন।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmccxxi{তোমাদের স্ত্রীদের মধ্যে যাদের ঋতুবর্তী হওয়ার আশা নেই, তাদের ব্যাপারে সন্দেহ হলে তাদের ইদ্দত হবে তিন মাস। আর যারা এখনও ঋতুর বয়সে পৌঁছেনি, তাদেরও অনুরূপ ইদ্দতকাল হবে। গর্ভবর্তী নারীদের ইদ্দতকাল সন্তানপ্রসব পর্যন্ত। যে আল্লাহকে ভয় করে, আল্লাহ তার কাজ সহজ করে দেন।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmccxxii{এটা আল্লাহর নির্দেশ, যা তিনি তোমাদের প্রতি নাযিল করেছেন। যে আল্লাহকে ভয় করে, আল্লাহ তার পাপ মোচন করেন এবং তাকে মহাপুরস্কার দেন।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmccxxiii{তোমরা তোমাদের সামর্থ?2437;নুযায়ী যেরূপ গৃহে বাস কর, তাদেরকেও বসবাসের জন্যে সেরূপ গৃহ দাও। তাদেরকে কষ্ট দিয়ে সংকটাপন্ন করো না। যদি তারা গর্ভবতী হয়, তবে সন্তানপ্রসব পর্যন্ত তাদের ব্যয়ভার বহন করবে। যদি তারা তোমাদের সন্তানদেরকে স্তন্যদান করে, তবে তাদেরকে প্রাপ্য পারিশ্রমিক দেবে এবং এ সম্পর্কে পরস্পর সংযতভাবে পরামর্শ করবে। তোমরা যদি পরস্পর জেদ কর, তবে অন্য নারী স্তন্যদান করবে।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmccxxiv{বিত্তশালী ব্যক্তি তার বিত্ত অনুযায়ী ব্যয় করবে। যে ব্যক্তি সীমিত পরিমাণে রিযিকপ্রাপ্ত, সে আল্লাহ যা দিয়েছেন, তা থেকে ব্যয় করবে। আল্লাহ যাকে যা দিয়েছেন, তদপেক্ষা বেশী ব্যয় করার আদেশ কাউকে করেন না। আল্লাহ কষ্টের পর সুখ দেবেন।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmccxxv{অনেক জনপদ তাদের পালনকর্তা ও তাঁর রসূলগণের আদেশ অমান্য করেছিল, অতঃপর আমি তাদেরকে কঠোর হিসাবে ধৃত করেছিলাম এবং তাদেরকে ভীষণ শাস্তি দিয়েছিলাম।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmccxxvi{অতঃপর তাদের কর্মের শাস্তি আস্বাদন করল এবং তাদের কর্মের পরিণাম ক্ষতিই ছিল।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmccxxvii{আল্লাহ তাদের জন্যে যন্ত্রণাদায়ক শাস্তি প্রস্তত রেখেছেন অতএব, হে বুদ্ধিমানগণ, যারা ঈমান এনেছ, তোমরা আল্লাহকে ভয় কর। আল্লাহ তোমাদের প্রতি উপদেশ নাযিল করেছেন।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmccxxviii{একজন রসূল, যিনি তোমাদের কাছে আল্লাহর সুস্পষ্ট আয়াতসমূহ পাঠ করেন, যাতে বিশ্বাসী ও সৎকর্মপরায়ণদের অন্ধকার থেকে আলোতে আনয়ন করেন। যে আল্লাহর প্রতি বিশ্বাস স্থাপন করে ও সৎকর্ম সম্পাদন করে, তিনি তাকে দাখিল করবেন জান্নাতে, যার তলদেশে নদী প্রবাহিত, তথায় তারা চিরকাল থাকবে। আল্লাহ তাকে উত্তম রিযিক দেবেন।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmccxxix{আল্লাহ সপ্তাকাশ সৃষ্টি করেছেন এবং পৃথিবীও সেই পরিমাণে, এসবের মধ্যে তাঁর আদেশ অবতীর্ণ হয়, যাতে তোমরা জানতে পার যে, আল্লাহ সর্বশক্তিমান এবং সবকিছু তাঁর গোচরীভূত।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmccxxx{\basmalahbn হে নবী, আল্লাহ আপনার জন্যে যা হালাল করছেন, আপনি আপনার স্ত্রীদেরকে খুশী করার জন্যে তা নিজের জন্যে হারাম করেছেন কেন? আল্লাহ ক্ষমাশীল, দয়াময়।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmccxxxi{আল্লাহ তোমাদের জন্যে কসম থেকে অব্যহতি লাভের উপায় নির্ধারণ করে দিয়েছেন। আল্লাহ তোমাদের মালিক। তিনি সর্বজ্ঞ, প্রজ্ঞাময়।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmccxxxii{যখন নবী তাঁর একজন স্ত্রীর কাছে একটি কথা গোপনে বললেন, অতঃপর স্ত্রী যখন তা বলে দিল এবং আল্লাহ নবীকে তা জানিয়ে দিলেন, তখন নবী সে বিষয়ে স্ত্রীকে কিছু বললেন এবং কিছু বললেন না। নবী যখন তা স্ত্রীকে বললেন, তখন স্ত্রী বললেনঃ কে আপনাকে এ সম্পর্কে অবহিত করল? নবী বললেন,ঃ যিনি সর্বজ্ঞ, ওয়াকিফহাল, তিনি আমাকে অবহিত করেছেন।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmccxxxiii{তোমাদের অন্তর অন্যায়ের দিকে ঝুঁকে পড়েছে বলে যদি তোমরা উভয়ে তওবা কর, তবে ভাল কথা। আর যদি নবীর বিরুদ্ধে একে অপরকে সাহায্য কর, তবে জেনে রেখ আল্লাহ জিবরাঈল এবং সৎকর্মপরায়ণ মুমিনগণ তাঁর সহায়। উপরন্তুত ফেরেশতাগণও তাঁর সাহায্যকারী।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmccxxxiv{যদি নবী তোমাদের সকলকে পরিত্যাগ করেন, তবে সম্ভবতঃ তাঁর পালনকর্তা তাঁকে পরিবর্তে দিবেন তোমাদের চাইতে উত্তম স্ত্রী, যারা হবে আজ্ঞাবহ, ঈমানদার, নামাযী তওবাকারিণী, এবাদতকারিণী, রোযাদার, অকুমারী ও কুমারী।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmccxxxv{মুমিনগণ, তোমরা নিজেদেরকে এবং তোমাদের পরিবার-পরিজনকে সেই অগ্নি থেকে রক্ষা কর, যার ইন্ধন হবে মানুষ ও প্রস্তর, যাতে নিয়োজিত আছে পাষাণ হৃদয়, কঠোরস্বভাব ফেরেশতাগণ। তারা আল্লাহ তা’আলা যা আদেশ করেন, তা অমান্য করে না এবং যা করতে আদেশ করা হয়, তাই করে।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmccxxxvi{হে কাফের সম্প্রদায়, তোমরা আজ ওযর পেশ করো না। তোমাদেরকে তারই প্রতিফল দেয়া হবে, যা তোমরা করতে।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmccxxxvii{মুমিনগণ! তোমরা আল্লাহ তা’আলার কাছে তওবা কর-আন্তরিক তওবা। আশা করা যায়, তোমাদের পালনকর্তা তোমাদের মন্দ কর্মসমূহ মোচন করে দেবেন এবং তোমাদেরকে দাখিল করবেন জান্নাতে, যার তলদেশে নদী প্রবাহিত। সেদিন আল্লাহ নবী এবং তাঁর বিশ্বাসী সহচরদেরকে অপদস্থ করবেন না। তাদের নূর তাদের সামনে ও ডানদিকে ছুটোছুটি করবে। তারা বলবেঃ হে আমাদের পালনকর্তা, আমাদের নূরকে পূর্ণ করে দিন এবং আমাদেরকে ক্ষমা করুন। নিশ্চয় আপনি সবকিছুর উপর সর্ব শক্তিমান।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmccxxxviii{হে নবী! কাফের ও মুনাফিকদের বিরুদ্ধে জেহাদ করুন এবং তাদের প্রতি কঠোর হোন। তাদের ঠিকানা জাহান্নাম। সেটা কতই না নিকৃষ্ট স্থান।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmccxxxix{আল্লাহ তা’আলা কাফেরদের জন্যে নূহ-পত্নী ও লূত-পত্নীর দৃষ্টান্ত বর্ণনা করেছেন। তারা ছিল আমার দুই ধর্মপরায়ণ বান্দার গৃহে। অতঃপর তারা তাদের সাথে বিশ্বাসঘাতকতা করল। ফলে নূহ ও লূত তাদেরকে আল্লাহ তা’আলার কবল থেকে রক্ষা করতে পারল না এবং তাদেরকে বলা হলঃ জাহান্নামীদের সাথে জাহান্নামে চলে যাও।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmccxl{আল্লাহ তা’আলা মুমিনদের জন্যে ফেরাউন-পত্নীর দৃষ্টান্ত বর্ণনা করেছেন। সে বললঃ হে আমার পালনকর্তা! আপনার সন্নিকটে জান্নাতে আমার জন্যে একটি গৃহ নির্মাণ করুন, আমাকে ফেরাউন ও তার দুস্কর্ম থেকে উদ্ধার করুন এবং আমাকে যালেম সম্প্রদায় থেকে মুক্তি দিন।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmccxli{আর দৃষ্টান্ত বর্ণনা করেছেন এমরান-তনয়া মরিয়মের, যে তার সতীত্ব বজায় রেখেছিল। অতঃপর আমি তার মধ্যে আমার পক্ষ থেকে জীবন ফুঁকে দিয়েছিলাম এবং সে তার পালনকর্তার বানী ও কিতাবকে সত্যে পরিণত করেছিল। সে ছিল বিনয় প্রকাশকারীনীদের একজন।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmccxlii{\basmalahbn পূণ্যময় তিনি, যাঁর হাতে রাজত্ব। তিনি সবকিছুর উপর সর্বশক্তিমান।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmccxliii{যিনি সৃষ্টি করেছেন মরণ ও জীবন, যাতে তোমাদেরকে পরীক্ষা করেন-কে তোমাদের মধ্যে কর্মে শ্রেষ্ঠ? তিনি পরাক্রমশালী, ক্ষমাময়।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmccxliv{তিনি সপ্ত আকাশ স্তরে স্তরে সৃষ্টি করেছেন। তুমি করুণাময় আল্লাহ তা’আলার সৃষ্টিতে কোন তফাত দেখতে পাবে না। আবার দৃষ্টিফেরাও; কোন ফাটল দেখতে পাও কি?\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmccxlv{অতঃপর তুমি বার বার তাকিয়ে দেখ-তোমার দৃষ্টি ব্যর্থ ও পরিশ্রান্ত হয়ে তোমার দিকে ফিরে আসবে।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmccxlvi{আমি সর্বনিম্ন আকাশকে প্রদীপমালা দ্বারা সুসজ্জত করেছি; সেগুলোকে শয়তানদের জন্যে ক্ষেপণাস্ত্রবৎ করেছি এবং প্রস্তুত করে রেখেছি তাদের জন্যে জলন্ত অগ্নির শাস্তি।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmccxlvii{যারা তাদের পালনকর্তাকে অস্বীকার করেছে তাদের জন্যে রয়েছে জাহান্নামের শাস্তি। সেটা কতই না নিকৃষ্ট স্থান।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmccxlviii{যখন তারা তথায় নিক্ষিপ্ত হবে, তখন তার উৎক্ষিপ্ত গর্জন শুনতে পাবে।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmccxlix{ক্রোধে জাহান্নাম যেন ফেটে পড়বে। যখনই তাতে কোন সম্প্রদায় নিক্ষিপ্ত হবে তখন তাদেরকে তার সিপাহীরা জিজ্ঞাসা করবে। তোমাদের কাছে কি কোন সতর্ককারী আগমন করেনি?\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmccl{তারা বলবেঃ হ্যাঁ আমাদের কাছে সতর্ককারী আগমন করেছিল, অতঃপর আমরা মিথ্যারোপ করেছিলাম এবং বলেছিলামঃ আল্লাহ তা’আলা কোন কিছু নাজিল করেননি। তোমরা মহাবিভ্রান্তিতে পড়ে রয়েছ।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmccli{তারা আরও বলবেঃ যদি আমরা শুনতাম অথবা বুদ্ধি খাটাতাম, তবে আমরা জাহান্নামবাসীদের মধ্যে থাকতাম না।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmcclii{অতঃপর তারা তাদের অপরাধ স্বীকার করবে। জাহান্নামীরা দূর হোক।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmccliii{নিশ্চয় যারা তাদের পালনকর্তাকে না দেখে ভয় করে, তাদের জন্যে রয়েছে ক্ষমা ও মহাপুরস্কার।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmccliv{তোমরা তোমাদের কথা গোপনে বল অথবা প্রকাশ্যে বল, তিনি তো অন্তরের বিষয়াদি সম্পর্কে সম্যক অবগত।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmcclv{যিনি সৃষ্টি করেছেন, তিনি কি করে জানবেন না? তিনি সূক্ষ্নজ্ঞানী, সম্যক জ্ঞাত।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmcclvi{তিনি তোমাদের জন্যে পৃথিবীকে সুগম করেছেন, অতএব, তোমরা তার কাঁধে বিচরণ কর এবং তাঁর দেয়া রিযিক আহার কর। তাঁরই কাছে পুনরুজ্জীবন হবে।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmcclvii{তোমরা কি ভাবনামুক্ত হয়ে গেছ যে, আকাশে যিনি আছেন তিনি তোমাদেরকে ভূগর্ভে বিলীন করে দেবেন, অতঃপর তা কাঁপতে থাকবে।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmcclviii{না তোমরা নিশ্চিন্ত হয়ে গেছ যে, আকাশে যিনি আছেন, তিনি তোমাদের উপর প্রস্তর বৃষ্টি বর্ষণ করবেন, অতঃপর তোমরা জানতে পারবে কেমন ছিল আমার সতর্কবাণী।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmcclix{তাদের পূর্ববর্তীরা মিথ্যারোপ করেছিল, অতঃপর কত কঠোর হয়েছিল আমার অস্বীকৃতি।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmcclx{তারা কি লক্ষ্য করে না, তাদের মাথার উপর উড়ন্ত পক্ষীকুলের প্রতি পাখা বিস্তারকারী ও পাখা সংকোচনকারী? রহমান আল্লাহ-ই তাদেরকে স্থির রাখেন। তিনি সর্ব-বিষয় দেখেন।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxi{রহমান আল্লাহ তা’আলা ব্যতীত তোমাদের কোন সৈন্য আছে কি, যে তোমাদেরকে সাহায্য করবে? কাফেররা বিভ্রান্তিতেই পতিত আছে।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxii{তিনি যদি রিযিক বন্ধ করে দেন, তবে কে আছে, যে তোমাদেরকে রিযিক দিবে বরং তারা অবাধ্যতা ও বিমুখতায় ডুবে রয়েছে।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxiii{যে ব্যক্তি উপুড় হয়ে মুখে ভর দিয়ে চলে, সে-ই কি সৎ পথে চলে, না সে ব্যক্তি যে সোজা হয়ে সরলপথে চলে?\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxiv{বলুন, তিনিই তোমাদেরকে সৃষ্টি করেছেন এবং দিয়েছেন কর্ণ, চক্ষু ও অন্তর। তোমরা অল্পই কৃতজ্ঞতা প্রকাশ কর।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxv{বলুন, তিনিই তোমাদেরকে পৃথিবীতে বিস্তৃত করেছেন এবং তাঁরই কাছে তোমরা সমবেত হবে।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxvi{কাফেররা বলেঃ এই প্রতিশ্রুতি কবে হবে, যদি তোমরা সত্যবাদী হও?\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxvii{বলুন, এর জ্ঞান আল্লাহ তা’আলার কাছেই আছে। আমি তো কেবল প্রকাশ্য সতর্ককারী।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxviii{যখন তারা সেই প্রতিশ্রুতিকে আসন্ন দেখবে তখন কাফেরদের মুখমন্ডল মলিন হয়ে পড়বে এবং বলা হবেঃ এটাই তো তোমরা চাইতে।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxix{বলুন, তোমরা কি ভেবে দেখেছ-যদি আল্লাহ তা’আলা আমাকে ও আমার সংগীদেরকে ধ্বংস করেন অথবা আমাদের প্রতি দয়া করেন, তবে কাফেরদেরকে কে যন্ত্রণাদায়ক শাস্তি থেকে রক্ষা করবে?\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxx{বলুন, তিনি পরম করুণাময়, আমরা তাতে বিশ্বাস রাখি এবং তাঁরই উপর ভরসা করি। সত্ত্বরই তোমরা জানতে পারবে, কে প্রকাশ্য পথ-ভ্রষ্টতায় আছে।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxxi{বলুন, তোমরা ভেবে দেখেছ কি, যদি তোমাদের পানি ভূগর্ভের গভীরে চলে যায়, তবে কে তোমাদেরকে সরবরাহ করবে পানির স্রোতধারা?\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxxii{\basmalahbn নূন। শপথ কলমের এবং সেই বিষয়ের যা তারা লিপিবদ্ধ করে,\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxxiii{আপনার পালনকর্তার অনুগ্রহে আপনি উম্মাদ নন।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxxiv{আপনার জন্যে অবশ্যই রয়েছে অশেষ পুরস্কার।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxxv{আপনি অবশ্যই মহান চরিত্রের অধিকারী।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxxvi{সত্ত্বরই আপনি দেখে নিবেন এবং তারাও দেখে নিবে।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxxvii{কে তোমাদের মধ্যে বিকারগ্রস্ত।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxxviii{আপনার পালনকর্তা সম্যক জানেন কে তাঁর পথ থেকে বিচ্যুত হয়েছে এবং তিনি জানেন যারা সৎপথ প্রাপ্ত।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxxix{অতএব, আপনি মিথ্যারোপকারীদের আনুগত্য করবেন না।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxxx{তারা চায় যদি আপনি নমনীয় হন, তবে তারাও নমনীয় হবে।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxxxi{যে অধিক শপথ করে, যে লাঞ্ছিত, আপনি তার আনুগত্য করবেন না।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxxxii{যে পশ্চাতে নিন্দা করে একের কথা অপরের নিকট লাগিয়ে ফিরে।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxxxiii{যে ভাল কাজে বাধা দেয়, সে সীমালংঘন করে, সে পাপিষ্ঠ,\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxxxiv{কঠোর স্বভাব, তদুপরি কুখ্যাত;\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxxxv{এ কারণে যে, সে ধন-সম্পদ ও সন্তান সন্ততির অধিকারী।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxxxvi{তার কাছে আমার আয়াত পাঠ করা হলে সে বলে; সেকালের উপকথা।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxxxvii{আমি তার নাসিকা দাগিয়ে দিব।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxxxviii{আমি তাদেরকে পরীক্ষা করেছি, যেমন পরীক্ষা করেছি উদ্যানওয়ালাদের, যখন তারা শপথ করেছিল যে, সকালে বাগানের ফল আহরণ করবে,\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmcclxxxix{ইনশাআল্লাহ না বলে।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmccxc{অতঃপর আপনার পালনকর্তার পক্ষ থেকে বাগানে এক বিপদ এসে পতিত হলো। যখন তারা নিদ্রিত ছিল।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmmccxci{ফলে সকাল পর্যন্ত হয়ে গেল ছিন্নবিচ্ছিন্ন তৃণসম।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmmccxcii{সকালে তারা একে অপরকে ডেকে বলল,\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmmccxciii{তোমরা যদি ফল আহরণ করতে চাও, তবে সকাল সকাল ক্ষেতে চল।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmmccxciv{অতঃপর তারা চলল ফিসফিস করে কথা বলতে বলতে,\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmmccxcv{অদ্য যেন কোন মিসকীন ব্যক্তি তোমাদের কাছে বাগানে প্রবেশ করতে না পারে।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmmccxcvi{তারা সকালে লাফিয়ে লাফিয়ে সজোরে রওয়ানা হল।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmmccxcvii{অতঃপর যখন তারা বাগান দেখল, তখন বললঃ আমরা তো পথ ভূলে গেছি।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmmccxcviii{বরং আমরা তো কপালপোড়া,\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmmccxcix{তাদের উত্তম ব্যক্তি বললঃ আমি কি তোমাদেরকে বলিনি? এখনও তোমরা আল্লাহ তা’আলার পবিত্রতা বর্ণনা করছো না কেন?\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmmccc{তারা বললঃ আমরা আমাদের পালনকর্তার পবিত্রতা ঘোষণা করছি, নিশ্চিতই আমরা সীমালংঘনকারী ছিলাম।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmmccci{অতঃপর তারা একে অপরকে ভৎর্সনা করতে লাগল।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmmcccii{তারা বললঃ হায়! দুর্ভোগ আমাদের আমরা ছিলাম সীমাতিক্রমকারী।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmmmccciii{সম্ভবতঃ আমাদের পালনকর্তা পরিবর্তে এর চাইতে উত্তম বাগান আমাদেরকে দিবেন। আমরা আমাদের পালনকর্তার কাছে আশাবাদী।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmmmccciv{শাস্তি এভাবেই আসে এবং পরকালের শাস্তি আরও গুরুতর; যদি তারা জানত!\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmmmcccv{মোত্তাকীদের জন্যে তাদের পালনকর্তার কাছে রয়েছে নেয়ামতের জান্নাত।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmmmcccvi{আমি কি আজ্ঞাবহদেরকে অপরাধীদের ন্যায় গণ্য করব?\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmmmcccvii{তোমাদের কি হল ? তোমরা কেমন সিদ্ধান্ত দিচ্ছ?\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmmmcccviii{তোমাদের কি কোন কিতাব আছে, যা তোমরা পাঠ কর।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmmmcccix{তাতে তোমরা যা পছন্দ কর, তাই পাও?\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmmmcccx{না তোমরা আমার কাছ থেকেকেয়ামত পর্যন্ত বলবৎ কোন শপথ নিয়েছ যে, তোমরা তাই পাবে যা তোমরা সিদ্ধান্ত করবে?\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxi{আপনি তাদেরকে জিজ্ঞাসা করুন তাদের কে এ বিষয়ে দায়িত্বশীল?\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxii{না তাদের কোন শরীক উপাস্য আছে? থাকলে তাদের শরীক উপাস্যদেরকে উপস্থিত করুক যদি তারা সত্যবাদী হয়।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxiii{গোছা পর্যন্ত পা খোলার দিনের কথা স্মরণ কর, সেদিন তাদেরকে সেজদা করতে আহবান জানানো হবে, অতঃপর তারা সক্ষম হবে না।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxiv{তাদের দৃষ্টি অবনত থাকবে; তারা লাঞ্ছনাগ্রস্ত হবে, অথচ যখন তারা সুস্থ ও স্বাভাবিক অবস্থায় ছিল, তখন তাদেরকে সেজদা করতে আহবান জানানো হত।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxv{অতএব, যারা এই কালামকে মিথ্যা বলে, তাদেরকে আমার হাতে ছেড়ে দিন, আমি এমন ধীরে ধীরে তাদেরকে জাহান্নামের দিকে নিয়ে যাব যে, তারা জানতে পারবে না।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxvi{আমি তাদেরকে সময় দেই। নিশ্চয় আমার কৌশল মজবুত।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxvii{আপনি কি তাদের কাছে পারিশ্রমিক চান? ফলে তাদের উপর জরিমানার বোঝা পড়ছে?\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxviii{না তাদের কাছে গায়বের খবর আছে? অতঃপর তারা তা লিপিবদ্ধ করে।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxix{আপনি আপনার পালনকর্তার আদেশের অপেক্ষায় সবর করুন এবং মাছওয়ালা ইউনুসের মত হবেন না, যখন সে দুঃখাকুল মনে প্রার্থনা করেছিল।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxx{যদি তার পালনকর্তার অনুগ্রহ তাকে সামাল না দিত, তবে সে নিন্দিত অবস্থায় জনশুন্য প্রান্তরে নিক্ষিপ্ত হত।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxxi{অতঃপর তার পালনকর্তা তাকে মনোনীত করলেন এবং তাকে সৎকর্মীদের অন্তর্ভুক্ত করে নিলেন।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxxii{কাফেররা যখন কোরআন শুনে, তখন তারা তাদের দৃষ্টি দ্বারা যেন আপনাকে আছাড় দিয়ে ফেলে দিবে এবং তারা বলেঃ সে তো একজন পাগল।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxxiii{অথচ এই কোরআন তো বিশ্বজগতের জন্যে উপদেশ বৈ নয়।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxxiv{\basmalahbn সুনিশ্চিত বিষয়।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxxv{সুনিশ্চিত বিষয় কি?\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxxvi{আপনি কি কিছু জানেন, সেই সুনিশ্চিত বিষয় কি?\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxxvii{আদ ও সামুদ গোত্র মহাপ্রলয়কে মিথ্যা বলেছিল।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxxviii{অতঃপর সমুদ গোত্রকে ধ্বংস করা হয়েছিল এক প্রলয়ংকর বিপর্যয় দ্বারা।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxxix{এবং আদ গোত্রকে ধ্বংস করা হয়েছিল এক প্রচন্ড ঝঞ্জাবায়ূ,\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxxx{যা তিনি প্রবাহিত করেছিলেন তাদের উপর সাত রাত্রি ও আট দিবস পর্যন্ত অবিরাম। আপনি তাদেরকে দেখতেন যে, তারা অসার খর্জুর কান্ডের ন্যায় ভূপাতিত হয়ে রয়েছে।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxxxi{আপনি তাদের কোন অস্তিত্ব দেখতে পান কি?\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxxxii{ফেরাউন, তাঁর পূর্ববর্তীরা এবং উল্টে যাওয়া বস্তিবাসীরা গুরুতর পাপ করেছিল।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxxxiii{তারা তাদের পালনকর্তার রসূলকে অমান্য করেছিল। ফলে তিনি তাদেরকে কঠোরহস্তে পাকড়াও করলেন।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxxxiv{যখন জলোচ্ছ্বাস হয়েছিল, তখন আমি তোমাদেরকে চলন্ত নৌযানে আরোহণ করিয়েছিলাম।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxxxv{যাতে এ ঘটনা তোমাদের জন্যে স্মৃতির বিষয় এবং কান এটাকে উপদেশ গ্রহণের উপযোগী রূপে গ্রহণ করে।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxxxvi{যখন শিংগায় ফুৎকার দেয়া হবে-একটি মাত্র ফুৎকার\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxxxvii{এবং পৃথিবী ও পর্বতমালা উত্তোলিত হবে ও চুর্ণ-বিচুর্ণ করে দেয়া হবে,\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxxxviii{সেদিন কেয়ামত সংঘটিত হবে।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxxxix{সেদিন আকাশ বিদীর্ণ হবে ও বিক্ষিপ্ত হবে।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxl{এবং ফেরেশতাগণ আকাশের প্রান্তদেশে থাকবে ও আট জন ফেরেশতা আপনার পালনকর্তার আরশকে তাদের উর্ধ্বে বহন করবে।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxli{সেদিন তোমাদেরকে উপস্থিত করা হবে। তোমাদের কোন কিছু গোপন থাকবে না।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxlii{অতঃপর যার আমলনামা ডান হাতে দেয়া হবে, সে বলবেঃ নাও, তোমরাও আমলনামা পড়ে দেখ।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxliii{আমি জানতাম যে, আমাকে হিসাবের সম্মুখীন হতে হবে।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxliv{অতঃপর সে সুখী জীবন-যাপন করবে,\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxlv{সুউচ্চ জান্নাতে।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxlvi{তার ফলসমূহ অবনমিত থাকবে।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxlvii{বিগত দিনে তোমরা যা প্রেরণ করেছিলে, তার প্রতিদানে তোমরা খাও এবং পান কর তৃপ্তি সহকারে।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxlviii{যার আমলনামা তার বাম হাতে দেয়া হবে, সে বলবেঃ হায় আমায় যদি আমার আমল নামা না দেয়া হতো।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxlix{আমি যদি না জানতাম আমার হিসাব!\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmmcccl{হায়, আমার মৃত্যুই যদি শেষ হত।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmmcccli{আমার ধন-সম্পদ আমার কোন উপকারে আসল না।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmmccclii{আমার ক্ষমতাও বরবাদ হয়ে গেল।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmmcccliii{ফেরেশতাদেরকে বলা হবেঃ ধর একে গলায় বেড়ি পড়িয়ে দাও,\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmmcccliv{অতঃপর নিক্ষেপ কর জাহান্নামে।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmmmccclv{অতঃপর তাকে শৃঙ্খলিত কর সত্তর গজ দীর্ঘ এক শিকলে।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmmmccclvi{নিশ্চয় সে মহান আল্লাহতে বিশ্বাসী ছিল না।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmmmccclvii{এবং মিসকীনকে আহার্য দিতে উৎসাহিত করত না।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmmmccclviii{অতএব, আজকের দিন এখানে তার কোন সুহূদ নাই।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmmmccclix{এবং কোন খাদ্য নাই, ক্ষত-নিঃসৃত পুঁজ ব্যতীত।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmmmccclx{গোনাহগার ব্যতীত কেউ এটা খাবে না।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxi{তোমরা যা দেখ, আমি তার শপথ করছি।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxii{এবং যা তোমরা দেখ না, তার-\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxiii{নিশ্চয়ই এই কোরআন একজন সম্মানিত রসূলের আনীত।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxiv{এবং এটা কোন কবির কালাম নয়; তোমরা কমই বিশ্বাস কর।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxv{এবং এটা কোন অতীন্দ্রিয়বাদীর কথা নয়; তোমরা কমই অনুধাবন কর।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxvi{এটা বিশ্বপালনকর্তার কাছ থেকে অবতীর্ণ।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxvii{সে যদি আমার নামে কোন কথা রচনা করত,\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxviii{তবে আমি তার দক্ষিণ হস্ত ধরে ফেলতাম,\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxix{অতঃপর কেটে দিতাম তার গ্রীবা।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxx{তোমাদের কেউ তাকে রক্ষা করতে পারতে না।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxxi{এটা খোদাভীরুদের জন্যে অবশ্যই একটি উপদেশ।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxxii{আমি জানি যে, তোমাদের মধ্যে কেউ কেউ মিথ্যারোপ করবে।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxxiii{নিশ্চয় এটা কাফেরদের জন্যে অনুতাপের কারণ।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxxiv{নিশ্চয় এটা নিশ্চিত সত্য।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxxv{অতএব, আপনি আপনার মহান পালনকর্তার নামের পবিত্রতা বর্ননা করুন।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxxvi{\basmalahbn একব্যক্তি চাইল, সেই আযাব সংঘটিত হোক যা অবধারিত-\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxxvii{কাফেরদের জন্যে, যার প্রতিরোধকারী কেউ নেই।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxxviii{তা আসবে আল্লাহ তা’আলার পক্ষ থেকে, যিনি সমুন্নত মর্তবার অধিকারী।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxxix{ফেরেশতাগণ এবং রূহ আল্লাহ তা’আলার দিকে উর্ধ্বগামী হয় এমন একদিনে, যার পরিমাণ পঞ্চাশ হাজার বছর।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxxx{অতএব, আপনি উত্তম সবর করুন।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxxxi{তারা এই আযাবকে সুদূরপরাহত মনে করে,\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxxxii{আর আমি একে আসন্ন দেখছি।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxxxiii{সেদিন আকাশ হবে গলিত তামার মত।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxxxiv{এবং পর্বতসমূহ হবে রঙ্গীন পশমের মত,\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxxxv{বন্ধু বন্ধুর খবর নিবে না।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxxxvi{যদিও একে অপরকে দেখতে পাবে। সেদিন গোনাহগার ব্যক্তি পনস্বরূপ দিতে চাইবে তার সন্তান-সন্ততিকে,\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxxxvii{তার স্ত্রীকে, তার ভ্রাতাকে,\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxxxviii{তার গোষ্ঠীকে, যারা তাকে আশ্রয় দিত।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmccclxxxix{এবং পৃথিবীর সবকিছুকে, অতঃপর নিজেকে রক্ষা করতে চাইবে।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxc{কখনই নয়। নিশ্চয় এটা লেলিহান অগ্নি।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxci{যা চামড়া তুলে দিবে।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxcii{সে সেই ব্যক্তিকে ডাকবে যে সত্যের প্রতি পৃষ্ঠপ্রদর্শন করেছিল ও বিমুখ হয়েছিল।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxciii{সম্পদ পুঞ্জীভূত করেছিল, অতঃপর আগলিয়ে রেখেছিল।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxciv{মানুষ তো সৃজিত হয়েছে ভীরুরূপে।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxcv{যখন তাকে অনিষ্ট স্পর্শ করে, তখন সে হা-হুতাশ করে।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxcvi{আর যখন কল্যাণপ্রাপ্ত হয়, তখন কৃপণ হয়ে যায়।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxcvii{তবে তারা স্বতন্ত্র, যারা নামায আদায় কারী।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxcviii{যারা তাদের নামাযে সার্বক্ষণিক কায়েম থাকে।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmmcccxcix{এবং যাদের ধন-সম্পদে নির্ধারিত হক আছে\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmmcd{যাঞ্ছাকারী ও বঞ্চিতের\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmmcdi{এবং যারা প্রতিফল দিবসকে সত্য বলে বিশ্বাস করে।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmmcdii{এবং যারা তাদের পালনকর্তার শাস্তির সম্পর্কে ভীত-কম্পিত।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmmcdiii{নিশ্চয় তাদের পালনকর্তার শাস্তি থেকে নিঃশঙ্কা থাকা যায় না।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmmcdiv{এবং যারা তাদের যৌন-অঙ্গকে সংযত রাখে\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmmcdv{কিন্তু তাদের স্ত্রী অথবা মালিকানাভূক্ত দাসীদের বেলায় তিরস্কৃত হবে না।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmmcdvi{অতএব, যারা এদের ছাড়া অন্যকে কামনা করে, তারাই সীমালংঘনকারী।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmmmcdvii{এবং যারা তাদের আমানত ও অঙ্গীকার রক্ষা করে\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmmmcdviii{এবং যারা তাদের সাক্ষ্যদানে সরল-নিষ্ঠাবান\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmmmcdix{এবং যারা তাদের নামাযে যত্নবান,\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmmmcdx{তারাই জান্নাতে সম্মানিত হবে।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxi{অতএব, কাফেরদের কি হল যে, তারা আপনার দিকে উর্ধ্বশ্বাসে ছুটে আসছে।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxii{ডান ও বামদিক থেকে দলে দলে।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxiii{তাদের প্রত্যেকেই কি আশা করে যে, তাকে নেয়ামতের জান্নাতে দাখিল করা হবে?\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxiv{কখনই নয়, আমি তাদেরকে এমন বস্তু দ্বারা সৃষ্টি করেছি, যা তারা জানে।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxv{আমি শপথ করছি উদয়াচল ও অস্তাচলসমূহের পালনকর্তার, নিশ্চয়ই আমি সক্ষম!\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxvi{তাদের পরিবর্তে উৎকৃষ্টতর মানুষ সৃষ্টি করতে এবং এটা আমার সাধ্যের অতীত নয়।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxvii{অতএব, আপনি তাদেরকে ছেড়ে দিন, তারা বাকবিতন্ডা ও ক্রীড়া-কৌতুক করুক সেই দিবসের সম্মুখীন হওয়া পর্যন্ত, যে দিবসের ওয়াদা তাদের সাথে করা হচ্ছে।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxviii{সে দিন তারা কবর থেকে দ্রুতবেগে বের হবে, যেন তারা কোন এক লক্ষ্যস্থলের দিকে ছুটে যাচ্ছে।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxix{তাদের দৃষ্টি থাকবে অবনমিত; তারা হবে হীনতাগ্রস্ত। এটাই সেইদিন, যার ওয়াদা তাদেরকে দেয়া হত।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxx{\basmalahbn আমি নূহকে প্রেরণ করেছিলাম তাঁর সম্প্রদায়ের প্রতি একথা বলেঃ তুমি তোমার সম্প্রদায়কে সতর্ক কর, তাদের প্রতি মর্মন্তদ শাস্তি আসার আগে।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxxi{সে বলল, হে আমার সম্প্রদায়! আমি তোমাদের জন্যে স্পষ্ট সতর্ককারী।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxxii{এ বিষয়ে যে, তোমরা আল্লাহ তা’আলার এবাদত কর, তাঁকে ভয় কর এবং আমার আনুগত্য কর।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxxiii{আল্লাহ তা’আলা তোমাদের পাপসমূহ ক্ষমা করবেন এবং নির্দিষ্ট সময় পর্যন্ত অবকাশ দিবেন। নিশ্চয় আল্লাহ তা’আলার নির্দিষ্টকাল যখন হবে, তখন অবকাশ দেয়া হবে না, যদি তোমরা তা জানতে!\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxxiv{সে বললঃ হে আমার পালনকর্তা! আমি আমার সম্প্রদায়কে দিবারাত্রি দাওয়াত দিয়েছি;\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxxv{কিন্তু আমার দাওয়াত তাদের পলায়নকেই বৃদ্ধি করেছে।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxxvi{আমি যতবারই তাদেরকে দাওয়াত দিয়েছি, যাতে আপনি তাদেরকে ক্ষমা করেন, ততবারই তারা কানে অঙ্গুলি দিয়েছে, মুখমন্ডল বস্ত্রাবৃত করেছে, জেদ করেছে এবং খুব ঔদ্ধত্য প্রদর্শন করেছে।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxxvii{অতঃপর আমি তাদেরকে প্রকাশ্যে দাওয়াত দিয়েছি,\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxxviii{অতঃপর আমি ঘোষণা সহকারে প্রচার করেছি এবং গোপনে চুপিসারে বলেছি।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxxix{অতঃপর বলেছিঃ তোমরা তোমাদের পালনকর্তার ক্ষমা প্রার্থনা কর। তিনি অত্যন্ত ক্ষমাশীল।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxxx{তিনি তোমাদের উপর অজস্র বৃষ্টিধারা ছেড়ে দিবেন,\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxxxi{তোমাদের ধন-সম্পদ ও সন্তান-সন্ততি বাড়িয়ে দিবেন, তোমাদের জন্যে উদ্যান স্থাপন করবেন এবং তোমাদের জন্যে নদীনালা প্রবাহিত করবেন।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxxxii{তোমাদের কি হল যে, তোমরা আল্লাহ তা’আলার শ্রেষ্টত্ব আশা করছ না।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxxxiii{অথচ তিনি তোমাদেরকে বিভিন্ন রকমে সৃষ্টি করেছেন।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxxxiv{তোমরা কি লক্ষ্য কর না যে, আল্লাহ কিভাবে সপ্ত আকাশ স্তরে স্তরে সৃষ্টি করেছেন।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxxxv{এবং সেখানে চন্দ্রকে রেখেছেন আলোরূপে এবং সূর্যকে রেখেছেন প্রদীপরূপে।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxxxvi{আল্লাহ তা’আলা তোমাদেরকে মৃত্তিকা থেকে উদগত করেছেন।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxxxvii{অতঃপর তাতে ফিরিয়ে নিবেন এবং আবার পুনরুত্থিত করবেন।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxxxviii{আল্লাহ তা’আলা তোমাদের জন্যে ভূমিকে করেছেন বিছানা।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxxxix{যাতে তোমরা চলাফেরা কর প্রশস্ত পথে।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxl{নূহ বললঃ হে আমার পালনকর্তা, আমার সম্প্রদায় আমাকে অমান্য করেছে আর অনুসরণ করছে এমন লোককে, যার ধন-সম্পদ ও সন্তান-সন্ততি কেবল তার ক্ষতিই বৃদ্ধি করছে।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxli{আর তারা ভয়ানক চক্রান্ত করছে।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxlii{তারা বলছেঃ তোমরা তোমাদের উপাস্যদেরকে ত্যাগ করো না এবং ত্যাগ করো না ওয়াদ, সূয়া, ইয়াগুছ, ইয়াউক ও নসরকে।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxliii{অথচ তারা অনেককে পথভ্রষ্ট করেছে। অতএব আপনি জালেমদের পথভ্রষ্টতাই বাড়িয়ে দিন।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxliv{তাদের গোনাহসমূহের দরুন তাদেরকে নিমজ্জিত করা হয়েছে, অতঃপর দাখিল করা হয়েছে জাহান্নামে। অতঃপর তারা আল্লাহ তা’আলা ব্যতীত কাউকে সাহায্যকারী পায়নি।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxlv{নূহ আরও বললঃ হে আমার পালনকর্তা, আপনি পৃথিবীতে কোন কাফের গৃহবাসীকে রেহাই দিবেন না।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxlvi{যদি আপনি তাদেরকে রেহাই দেন, তবে তারা আপনার বান্দাদেরকে পথভ্রষ্ট করবে এবং জন্ম দিতে থাকবে কেবল পাপাচারী, কাফের।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxlvii{হে আমার পালনকর্তা! আপনি আমাকে, আমার পিতা-মাতাকে, যারা মুমিন হয়ে আমার গৃহে প্রবেশ করে-তাদেরকে এবং মুমিন পুরুষ ও মুমিন নারীদেরকে ক্ষমা করুন এবং যালেমদের কেবল ধ্বংসই বৃদ্ধি করুন।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxlviii{\basmalahbn বলুনঃ আমার প্রতি ওহী নাযিল করা হয়েছে যে, জিনদের একটি দল কোরআন শ্রবণ করেছে, অতঃপর তারা বলেছেঃ আমরা বিস্ময়কর কোরআন শ্রবণ করেছি;\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxlix{যা সৎপথ প্রদর্শন করে। ফলে আমরা তাতে বিশ্বাস স্থাপন করেছি। আমরা কখনও আমাদের পালনকর্তার সাথে কাউকে শরীক করব না।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmcdl{এবং আরও বিশ্বাস করি যে, আমাদের পালনকর্তার মহান মর্যাদা সবার উর্ধ্বে। তিনি কোন পত্নী গ্রহণ করেননি এবং তাঁর কোন সন্তান নেই।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmcdli{আমাদের মধ্যে নির্বোধেরা আল্লাহ তা’আলা সম্পর্কে বাড়াবাড়ির কথাবার্তা বলত।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlii{অথচ আমরা মনে করতাম, মানুষ ও জিন কখনও আল্লাহ তা’আলা সম্পর্কে মিথ্যা বলতে পারে না।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmcdliii{অনেক মানুষ অনেক জিনের আশ্রয় নিত, ফলে তারা জিনদের আত্নম্ভরিতা বাড়িয়ে দিত।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmcdliv{তারা ধারণা করত, যেমন তোমরা মানবেরা ধারণা কর যে, মৃত্যুর পর আল্লাহ তা’আলা কখনও কাউকে পুনরুত্থিত করবেন না।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlv{আমরা আকাশ পর্যবেক্ষণ করছি, অতঃপর দেখতে পেয়েছি যে, কঠোর প্রহরী ও উল্কাপিন্ড দ্বারা আকাশ পরিপূর্ণ।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlvi{আমরা আকাশের বিভিন্ন ঘাঁটিতে সংবাদ শ্রবণার্থে বসতাম। এখন কেউ সংবাদ শুনতে চাইলে সে জলন্ত উল্কাপিন্ড ওঁৎ পেতে থাকতে দেখে।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlvii{আমরা জানি না পৃথিবীবাসীদের অমঙ্গল সাধন করা অভীষ্ট, না তাদের পালনকর্তা তাদের মঙ্গল সাধন করার ইচ্ছা রাখেন।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlviii{আমাদের কেউ কেউ সৎকর্মপরায়ণ এবং কেউ কেউ এরূপ নয়। আমরা ছিলাম বিভিন্ন পথে বিভক্ত।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlix{আমরা বুঝতে পেরেছি যে, আমরা পৃথিবীতে আল্লাহ তা’আলাকে পরাস্ত করতে পারব না এবং পলায়ন করেও তাকে অপারক করত পরব না।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlx{আমরা যখন সুপথের নির্দেশ শুনলাম, তখন তাতে বিশ্বাস স্থাপন করলাম। অতএব, যে তার পালনকর্তার প্রতি বিশ্বাস করে, সে লোকসান ও জোর-জবরের আশংকা করে না।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxi{আমাদের কিছুসংখ্যক আজ্ঞাবহ এবং কিছুসংখ্যক অন্যায়কারী। যারা আজ্ঞাবহ হয়, তারা সৎপথ বেছে নিয়েছে।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxii{আর যারা অন্যায়কারী, তারা তো জাহান্নামের ইন্ধন।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxiii{আর এই প্রত্যাদেশ করা হয়েছে যে, তারা যদি সত্যপথে কায়েম থাকত, তবে আমি তাদেরকে প্রচুর পানি বর্ষণে সিক্ত করতাম।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxiv{যাতে এ ব্যাপারে তাদেরকে পরীক্ষা করি। পক্ষান্তরে যে ব্যক্তি তার পালনকর্তার স্মরণ থেকে মুখ ফিরিয়ে নেয়, তিনি তাকে উদীয়মান আযাবে পরিচালিত করবেন।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxv{এবং এই ওহীও করা হয়েছে যে, মসজিদসমূহ আল্লাহ তা’আলাকে স্মরণ করার জন্য। অতএব, তোমরা আল্লাহ তা’আলার সাথে কাউকে ডেকো না।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxvi{আর যখন আল্লাহ তা’আলার বান্দা তাঁকে ডাকার জন্যে দন্ডায়মান হল, তখন অনেক জিন তার কাছে ভিড় জমাল।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxvii{বলুনঃ আমি তো আমার পালনকর্তাকেই ডাকি এবং তাঁর সাথে কাউকে শরীক করি না।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxviii{বলুনঃ আমি তোমাদের ক্ষতি সাধন করার ও সুপথে আনয়ন করার মালিক নই।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxix{বলুনঃ আল্লাহ তা’আলার কবল থেকে আমাকে কেউ রক্ষা করতে পারবে না এবং তিনি ব্যতীত আমি কোন আশ্রয়স্থল পাব না।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxx{কিন্তু আল্লাহ তা’আলার বাণী পৌছানো ও তাঁর পয়গাম প্রচার করাই আমার কাজ। যে আল্লাহ ও তাঁর রসূলকে অমান্য করে, তার জন্যে রয়েছে জাহান্নামের অগ্নি। তথায় তারা চিরকাল থাকবে।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxxi{এমনকি যখন তারা প্রতিশ্রুত শাস্তি দেখতে পাবে, তখন তারা জানতে পারবে, কার সাহায্যকারী দূর্বল এবং কার সংখ্যা কম।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxxii{বলুনঃ আমি জানি না তোমাদের প্রতিশ্রুত বিষয় আসন্ন না আমার পালনকর্তা এর জন্যে কোন মেয়াদ স্থির করে রেখেছেন।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxxiii{তিনি অদৃশ্যের জ্ঞানী। পরন্ত তিনি অদৃশ্য বিষয় কারও কাছে প্রকাশ করেন না।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxxiv{তাঁর মনোনীত রসূল ব্যতীত। তখন তিনি তার অগ্রে ও পশ্চাতে প্রহরী নিযুক্ত করেন\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxxv{যাতে আল্লাহ তা’আলা জেনে নেন যে, রসূলগণ তাঁদের পালনকর্তার পয়গাম পৌছিয়েছেন কি না। রসূলগণের কাছে যা আছে, তা তাঁর জ্ঞান-গোচর। তিনি সবকিছুর সংখ্যার হিসাব রাখেন।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxxvi{\basmalahbn হে বস্ত্রাবৃত!\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxxvii{রাত্রিতে দন্ডায়মান হোন কিছু অংশ বাদ দিয়ে;\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxxviii{অর্ধরাত্রি অথবা তদপেক্ষা কিছু কম\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxxix{অথবা তদপেক্ষা বেশী এবং কোরআন আবৃত্তি করুন সুবিন্যস্ত ভাবে ও স্পষ্টভাবে।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxxx{আমি আপনার প্রতি অবতীর্ণ করেছি গুরুত্বপূর্ণ বাণী।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxxxi{নিশ্চয় এবাদতের জন্যে রাত্রিতে উঠা প্রবৃত্তি দলনে সহায়ক এবং স্পষ্ট উচ্চারণের অনুকূল।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxxxii{নিশ্চয় দিবাভাগে রয়েছে আপনার দীর্ঘ কর্মব্যস্ততা।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxxxiii{আপনি আপনার পালনকর্তার নাম স্মরণ করুন এবং একাগ্রচিত্তে তাতে মগ্ন হোন।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxxxiv{তিনি পূর্ব ও পশ্চিমের অধিকর্তা। তিনি ব্যতীত কোন উপাস্য নেই। অতএব, তাঁকেই গ্রহণ করুন কর্মবিধায়করূপে।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxxxv{কাফেররা যা বলে, তজ্জন্যে আপনি সবর করুন এবং সুন্দরভাবে তাদেরকে পরিহার করে চলুন।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxxxvi{বিত্ত-বৈভবের অধিকারী মিথ্যারোপকারীদেরকে আমার হাতে ছেড়ে দিন এবং তাদেরকে কিছু অবকাশ দিন।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxxxvii{নিশ্চয় আমার কাছে আছে শিকল ও অগ্নিকুন্ড।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxxxviii{গলগ্রহ হয়ে যায় এমন খাদ্য এবং যন্ত্রণাদায়ক শাস্তি।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmcdlxxxix{যেদিন পৃথিবী পর্বতমালা প্রকম্পিত হবে এবং পর্বতসমূহ হয়ে যাবে বহমান বালুকাস্তুপ।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxc{আমি তোমাদের কাছে একজন রসূলকে তোমাদের জন্যে সাক্ষী করে প্রেরণ করেছি, যেমন প্রেরণ করেছিলাম ফেরাউনের কাছে একজন রসূল।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxci{অতঃপর ফেরাউন সেই রসূলকে অমান্য করল, ফলে আমি তাকে কঠিন শাস্তি দিয়েছি।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxcii{অতএব, তোমরা কিরূপে আত্নরক্ষা করবে যদি তোমরা সেদিনকে অস্বীকার কর, যেদিন বালককে করে দিব বৃদ্ধ?\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxciii{সেদিন আকাশ বিদীর্ণ হবে। তার প্রতিশ্রুতি অবশ্যই বাস্তবায়িত হবে।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxciv{এটা উপদেশ। অতএব, যার ইচ্ছা, সে তার পালনকর্তার দিকে পথ অবলম্বন করুক।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxcv{আপনার পালনকর্তা জানেন, আপনি এবাদতের জন্যে দন্ডায়মান হন রাত্রির প্রায় দু’তৃতীয়াংশ, অর্ধাংশ ও তৃতীয়াংশ এবং আপনার সঙ্গীদের একটি দলও দন্ডায়মান হয়। আল্লাহ দিবা ও রাত্রি পরিমাপ করেন। তিনি জানেন, তোমরা এর পূর্ণ হিসাব রাখতে পার না। অতএব তিনি তোমাদের প্রতি ক্ষমা পরায়ন হয়েছেন। কাজেই কোরআনের যতটুকু তোমাদের জন্যে সহজ, ততটুকু আবৃত্তি কর। তিনি জানেন তোমাদের মধ্যে কেউ কেউ অসুস্থ হবে, কেউ কেউ আল্লাহর অনুগ্রহ সন্ধানে দেশে-বিদেশে যাবে এবং কেউ কেউ আল্লাহর পথে জেহাদে লিপ্ত হবে। কাজেই কোরআনের যতটুকু তোমাদের জন্যে সহজ ততটুকু আবৃত্তি কর। তোমরা নামায কায়েম কর, যাকাত দাও এবং আল্লাহকে উত্তম ঋণ দাও। তোমরা নিজেদের জন্যে যা কিছু অগ্রে পাঠাবে, তা আল্লাহর কাছে উত্তম আকারে এবং পুরস্কার হিসেবে বর্ধিতরূপে পাবে। তোমরা আল্লাহর কাছে ক্ষমাপ্রার্থনা কর। নিশ্চয় আল্লাহ ক্ষমাশীল, দয়ালু।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxcvi{\basmalahbn হে চাদরাবৃত!\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxcvii{উঠুন, সতর্ক করুন,\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxcviii{আপন পালনকর্তার মাহাত্ম্য ঘোষনা করুন,\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmcdxcix{আপন পোশাক পবিত্র করুন\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmd{এবং অপবিত্রতা থেকে দূরে থাকুন।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmdi{অধিক প্রতিদানের আশায় অন্যকে কিছু দিবেন না।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmdii{এবং আপনার পালনকর্তার উদ্দেশে সবর করুন।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmdiii{যেদিন শিংগায় ফুঁক দেয়া হবে;\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmdiv{সেদিন হবে কঠিন দিন,\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmdv{কাফেরদের জন্যে এটা সহজ নয়।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmdvi{যাকে আমি অনন্য করে সৃষ্টি করেছি, তাকে আমার হাতে ছেড়ে দিন।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmdvii{আমি তাকে বিপুল ধন-সম্পদ দিয়েছি।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmdviii{এবং সদা সংগী পুত্রবর্গ দিয়েছি,\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmdix{এবং তাকে খুব সচ্ছলতা দিয়েছি।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmdx{এরপরও সে আশা করে যে, আমি তাকে আরও বেশী দেই।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmdxi{কখনই নয়! সে আমার নিদর্শনসমূহের বিরুদ্ধাচরণকারী।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmdxii{আমি সত্ত্বরই তাকে শাস্তির পাহাড়ে আরোহণ করাব।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmdxiii{সে চিন্তা করেছে এবং মনঃস্থির করেছে,\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmdxiv{ধ্বংস হোক সে, কিরূপে সে মনঃস্থির করেছে!\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmmdxv{আবার ধ্বংস হোক সে, কিরূপে সে মনঃস্থির করেছে!\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmmdxvi{সে আবার দৃষ্টিপাত করেছে,\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmmdxvii{অতঃপর সে ভ্রূকুঞ্চিত করেছে ও মুখ বিকৃত করেছে,\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmmdxviii{অতঃপর পৃষ্ঠপ্রদশন করেছে ও অহংকার করেছে।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmmdxix{এরপর বলেছেঃ এতো লোক পরস্পরায় প্রাপ্ত জাদু বৈ নয়,\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmmdxx{এতো মানুষের উক্তি বৈ নয়।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmmdxxi{আমি তাকে দাখিল করব অগ্নিতে।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmmdxxii{আপনি কি বুঝলেন অগ্নি কি?\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmmdxxiii{এটা অক্ষত রাখবে না এবং ছাড়বেও না।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmmdxxiv{মানুষকে দগ্ধ করবে।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmmdxxv{এর উপর নিয়োজিত আছে উনিশ (ফেরেশতা)।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmmdxxvi{আমি জাহান্নামের তত্ত্বাবধায়ক ফেরেশতাই রেখেছি। আমি কাফেরদেরকে পরীক্ষা করার জন্যেই তার এই সংখ্যা করেছি-যাতে কিতাবীরা দৃঢ়বিশ্বাসী হয়, মুমিনদের ঈমান বৃদ্ধি পায় এবং কিতাবীরা ও মুমিনগণ সন্দেহ পোষণ না করে এবং যাতে যাদের অন্তরে রোগ আছে, তারা এবং কাফেররা বলে যে, আল্লাহ এর দ্বারা কি বোঝাতে চেয়েছেন। এমনিভাবে আল্লাহ যাকে ইচ্ছা পথভ্রষ্ট করেন এবং যাকে ইচ্ছা সৎপথে চালান। আপনার পালনকর্তার বাহিনী সম্পর্কে একমাত্র তিনিই জানেন এটা তো মানুষের জন্যে উপদেশ বৈ নয়।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmmmdxxvii{কখনই নয়। চন্দ্রের শপথ,\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmmmdxxviii{শপথ রাত্রির যখন তার অবসান হয়,\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmmmdxxix{শপথ প্রভাতকালের যখন তা আলোকোদ্ভাসিত হয়,\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmmmdxxx{নিশ্চয় জাহান্নাম গুরুতর বিপদসমূহের অন্যতম,\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmmmdxxxi{মানুষের জন্যে সতর্ককারী।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmmmdxxxii{তোমাদের মধ্যে যে সামনে অগ্রসর হয় অথবা পশ্চাতে থাকে।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmmmdxxxiii{প্রত্যেক ব্যক্তি তার কৃতকর্মের জন্য দায়ী;\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmmmdxxxiv{কিন্তু ডানদিকস্থরা,\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmmmdxxxv{তারা থাকবে জান্নাতে এবং পরস্পরে জিজ্ঞাসাবাদ করবে।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmmmdxxxvi{অপরাধীদের সম্পর্কে\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmmmdxxxvii{বলবেঃ তোমাদেরকে কিসে জাহান্নামে নীত করেছে?\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmmmdxxxviii{তারা বলবেঃ আমরা নামায পড়তাম না,\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmmmdxxxix{অভাবগ্রস্তকে আহার্য্য দিতাম না,\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmmmdxl{আমরা সমালোচকদের সাথে সমালোচনা করতাম।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmmmmdxli{এবং আমরা প্রতিফল দিবসকে অস্বীকার করতাম।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmmmmdxlii{আমাদের মৃত্যু পর্যন্ত।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmmmmdxliii{অতএব, সুপারিশকারীদের সুপারিশ তাদের কোন উপকারে আসবে না।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmmmmdxliv{তাদের কি হল যে, তারা উপদেশ থেকে মুখ ফিরিয়ে নেয়?\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmmmmdxlv{যেন তারা ইতস্ততঃ বিক্ষিপ্ত গর্দভ।\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmmmmdxlvi{হট্টগোলের কারণে পলায়নপর।\qt@no{(51)}}
\qt@newcmd\qurantrans@bn@mmmmmdxlvii{বরং তাদের প্রত্যেকেই চায় তাদের প্রত্যেককে একটি উম্মুক্ত গ্রন্থ দেয়া হোক।\qt@no{(52)}}
\qt@newcmd\qurantrans@bn@mmmmmdxlviii{কখনও না, বরং তারা পরকালকে ভয় করে না।\qt@no{(53)}}
\qt@newcmd\qurantrans@bn@mmmmmdxlix{কখনও না, এটা তো উপদেশ মাত্র।\qt@no{(54)}}
\qt@newcmd\qurantrans@bn@mmmmmdl{অতএব, যার ইচ্ছা, সে একে স্মরণ করুক।\qt@no{(55)}}
\qt@newcmd\qurantrans@bn@mmmmmdli{তারা স্মরণ করবে না, কিন্তু যদি আল্লাহ চান। তিনিই ভয়ের যোগ্য এবং ক্ষমার অধিকারী।\qt@no{(56)}}
\qt@newcmd\qurantrans@bn@mmmmmdlii{\basmalahbn আমি শপথ করি কেয়ামত দিবসের,\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmdliii{আরও শপথ করি সেই মনের, যে নিজেকে ধিক্কার দেয়-\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmdliv{মানুষ কি মনে করে যে আমি তার অস্থিসমূহ একত্রিত করব না?\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmdlv{পরন্ত আমি তার অংগুলিগুলো পর্যন্ত সঠিকভাবে সন্নিবেশিত করতে সক্ষম।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmdlvi{বরং মানুষ তার ভবিষ্যত জীবনেও ধৃষ্টতা করতে চায়\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmdlvii{সে প্রশ্ন করে-কেয়ামত দিবস কবে?\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmdlviii{যখন দৃষ্টি চমকে যাবে,\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmdlix{চন্দ্র জ্যোতিহীন হয়ে যাবে।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmdlx{এবং সূর্য ও চন্দ্রকে একত্রিত করা হবে-\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxi{সে দিন মানুষ বলবেঃ পলায়নের জায়গা কোথায় ?\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxii{না কোথাও আশ্রয়স্থল নেই।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxiii{আপনার পালনকর্তার কাছেই সেদিন ঠাঁই হবে।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxiv{সেদিন মানুষকে অবহিত করা হবে সে যা সামনে প্রেরণ করেছে ও পশ্চাতে ছেড়ে দিয়েছে।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxv{বরং মানুষ নিজেই তার নিজের সম্পর্কে চক্ষুমান।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxvi{যদিও সে তার অজুহাত পেশ করতে চাইবে।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxvii{তাড়াতাড়ি শিখে নেয়ার জন্যে আপনি দ্রুত ওহী আবৃত্তি করবেন না।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxviii{এর সংরক্ষণ ও পাঠ আমারই দায়িত্ব।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxix{অতঃপর আমি যখন তা পাঠ করি, তখন আপনি সেই পাঠের অনুসরণ করুন।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxx{এরপর বিশদ বর্ণনা আমারই দায়িত্ব।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxxi{কখনও না, বরং তোমরা পার্থিব জীবনকে ভালবাস\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxxii{এবং পরকালকে উপেক্ষা কর।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxxiii{সেদিন অনেক মুখমন্ডল উজ্জ্বল হবে।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxxiv{তারা তার পালনকর্তার দিকে তাকিয়ে থাকবে।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxxv{আর অনেক মুখমন্ডল সেদিন উদাস হয়ে পড়বে।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxxvi{তারা ধারণা করবে যে, তাদের সাথে কোমর-ভাঙ্গা আচরণ করা হবে।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxxvii{কখনও না, যখন প্রাণ কন্ঠাগত হবে।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxxviii{এবং বলা হবে, কে ঝাড়বে\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxxix{এবং সে মনে করবে যে, বিদায়ের ক্ষণ এসে গেছে।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxxx{এবং গোছা গোছার সাথে জড়িত হয়ে যাবে।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxxxi{সেদিন, আপনার পালনকর্তার নিকট সবকিছু নীত হবে।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxxxii{সে বিশ্বাস করেনি এবং নামায পড়েনি;\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxxxiii{পরন্ত মিথ্যারোপ করেছে ও পৃষ্ঠ প্রদর্শন করেছে।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxxxiv{অতঃপর সে দম্ভভরে পরিবার-পরিজনের নিকট ফিরে গিয়েছে।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxxxv{তোমার দুর্ভোগের উপর দুর্ভোগ।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxxxvi{অতঃপর, তোমার দুর্ভোগের উপর দূর্ভোগ।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxxxvii{মানুষ কি মনে করে যে, তাকে এমনি ছেড়ে দেয়া হবে?\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxxxviii{সে কি স্খলিত বীর্য ছিল না?\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmmmdlxxxix{অতঃপর সে ছিল রক্তপিন্ড, অতঃপর আল্লাহ তাকে সৃষ্টি করেছেন এবং সুবিন্যস্ত করেছেন।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmmmdxc{অতঃপর তা থেকে সৃষ্টি করেছেন যুগল নর ও নারী।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmmmdxci{তবুও কি সেই আল্লাহ মৃতদেরকে জীবিত করতে সক্ষম নন?\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmmmdxcii{\basmalahbn মানুষের উপর এমন কিছু সময় অতিবাহিত হয়েছে যখন সে উল্লেখযোগ্য কিছু ছিল না।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmdxciii{আমি মানুষকে সৃষ্টি করেছি মিশ্র শুক্রবিন্দু থেকে, এভাবে যে, তাকে পরীক্ষা করব অতঃপর তাকে করে দিয়েছি শ্রবণ ও দৃষ্টিশক্তিসম্পন্ন।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmdxciv{আমি তাকে পথ দেখিয়ে দিয়েছি। এখন সে হয় কৃতজ্ঞ হয়, না হয় অকৃতজ্ঞ হয়।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmdxcv{আমি অবিশ্বাসীদের জন্যে প্রস্তুত রেখেছি শিকল, বেড়ি ও প্রজ্বলিত অগ্নি।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmdxcvi{নিশ্চয়ই সৎকর্মশীলরা পান করবে কাফুর মিশ্রিত পানপাত্র।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmdxcvii{এটা একটা ঝরণা, যা থেকে আল্লাহর বান্দাগণ পান করবে-তারা একে প্রবাহিত করবে।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmdxcviii{তারা মান্নত পূর্ণ করে এবং সেদিনকে ভয় করে, যেদিনের অনিষ্ট হবে সুদূরপ্রসারী।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmdxcix{তারা আল্লাহর প্রেমে অভাবগ্রস্ত, এতীম ও বন্দীকে আহার্য দান করে।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmdc{তারা বলেঃ কেবল আল্লাহর সন্তুষ্টির জন্যে আমরা তোমাদেরকে আহার্য দান করি এবং তোমাদের কাছে কোন প্রতিদান ও কৃতজ্ঞতা কামনা করি না।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmdci{আমরা আমাদের পালনকর্তার তরফ থেকে এক ভীতিপ্রদ ভয়ংকর দিনের ভয় রাখি।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmdcii{অতঃপর আল্লাহ তাদেরকে সেদিনের অনিষ্ট থেকে রক্ষা করবেন এবং তাদেরকে দিবেন সজীবতা ও আনন্দ।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmdciii{এবং তাদের সবরের প্রতিদানে তাদেরকে দিবেন জান্নাত ও রেশমী পোশাক।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmdciv{তারা সেখানে সিংহাসনে হেলান দিয়ে বসবে। সেখানে রৌদ্র ও শৈত্য অনুভব করবে না।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmdcv{তার বৃক্ষছায়া তাদের উপর ঝুঁকে থাকবে এবং তার ফলসমূহ তাদের আয়ত্তাধীন রাখা হবে।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmdcvi{তাদেরকে পরিবেশন করা হবে রূপার পাত্রে এবং স্ফটিকের মত পানপাত্রে।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmdcvii{রূপালী স্ফটিক পাত্রে, পরিবেশনকারীরা তা পরিমাপ করে পূর্ণ করবে।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmdcviii{তাদেরকে সেখানে পান করানো হবে ‘যানজাবীল’ মিশ্রিত পানপাত্র।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmdcix{এটা জান্নাতস্থিত ‘সালসাবীল’ নামক একটি ঝরণা।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmdcx{তাদের কাছে ঘোরাফেরা করবে চির কিশোরগণ। আপনি তাদেরকে দেখে মনে করবেন যেন বিক্ষিপ্ত মনি-মুক্তা।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxi{আপনি যখন সেখানে দেখবেন, তখন নেয়ামতরাজি ও বিশাল রাজ্য দেখতে পাবেন।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxii{তাদের আবরণ হবে চিকন সবুজ রেশম ও মোটা সবুজ রেশম এবং তাদেরকে পরিধান করোনো হবে রৌপ্য নির্মিত কংকণ এবং তাদের পালনকর্তা তাদেরকে পান করাবেন ‘শরাবান-তহুরা’।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxiii{এটা তোমাদের প্রতিদান। তোমাদের প্রচেষ্টা স্বীকৃতি লাভ করেছে।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxiv{আমি আপনার প্রতি পর্যায়ক্রমে কোরআন নাযিল করেছি।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxv{অতএব, আপনি আপনার পালনকর্তার আদেশের জন্যে ধৈর্য্য সহকারে অপেক্ষা করুন এবং ওদের মধ্যকার কোন পাপিষ্ঠ কাফেরের আনুগত্য করবেন না।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxvi{এবং সকাল-সন্ধ্যায় আপন পালনকর্তার নাম স্মরণ করুন।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxvii{রাত্রির কিছু অংশে তাঁর উদ্দেশে সিজদা করুন এবং রাত্রির দীর্ঘ সময় তাঁর পবিত্রতা বর্ণনা করুন।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxviii{নিশ্চয় এরা পার্থিব জীবনকে ভালবাসে এবং এক কঠিন দিবসকে পশ্চাতে ফেলে রাখে।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxix{আমি তাদেরকে সৃষ্টি করেছি এবং মজবুত করেছি তাদের গঠন। আমি যখন ইচ্ছা করব, তখন তাদের পরিবর্তে তাদের অনুরূপ লোক আনব।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxx{এটা উপদেশ, অতএব যার ইচ্ছা হয় সে তার পালনকর্তার পথ অবলম্বন করুক।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxxi{আল্লাহর অভিপ্রায় ব্যতিরেকে তোমরা অন্য কোন অভিপ্রায় পোষণ করবে না। আল্লাহ সর্বজ্ঞ প্রজ্ঞাময়।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxxii{তিনি যাকে ইচ্ছা তাঁর রহমতে দাখিল করেন। আর যালেমদের জন্যে তো প্রস্তুত রেখেছেন মর্মন্তুদ শাস্তি।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxxiii{\basmalahbn কল্যাণের জন্যে প্রেরিত বায়ুর শপথ,\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxxiv{সজোরে প্রবাহিত ঝটিকার শপথ,\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxxv{মেঘবিস্তৃতকারী বায়ুর শপথ\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxxvi{মেঘপুঞ্জ বিতরণকারী বায়ুর শপথ এবং\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxxvii{ওহী নিয়ে অবতরণকারী ফেরেশতাগণের শপথ-\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxxviii{ওযর-আপত্তির অবকাশ না রাখার জন্যে অথবা সতর্ক করার জন্যে।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxxix{নিশ্চয়ই তোমাদেরকে প্রদত্ত ওয়াদা বাস্তবায়িত হবে।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxxx{অতঃপর যখন নক্ষত্রসমুহ নির্বাপিত হবে,\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxxxi{যখন আকাশ ছিদ্রযুক্ত হবে,\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxxxii{যখন পর্বতমালাকে উড়িয়ে দেয়া হবে এবং\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxxxiii{যখন রসূলগণের একত্রিত হওয়ার সময় নিরূপিত হবে,\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxxxiv{এসব বিষয় কোন দিবসের জন্যে স্থগিত রাখা হয়েছে?\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxxxv{বিচার দিবসের জন্য।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxxxvi{আপনি জানেন বিচার দিবস কি?\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxxxvii{সেদিন মিথ্যারোপকারীদের দুর্ভোগ হবে।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxxxviii{আমি কি পূর্ববর্তীদেরকে ধ্বংস করিনি?\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxxxix{অতঃপর তাদের পশ্চাতে প্রেরণ করব পরবর্তীদেরকে।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxl{অপরাধীদের সাথে আমি এরূপই করে থাকি।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxli{সেদিন মিথ্যারোপকারীদের দুর্ভোগ হবে।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxlii{আমি কি তোমাদেরকে তুচ্ছ পানি থেকে সৃষ্টি করিনি?\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxliii{অতঃপর আমি তা রেখেছি এক সংরক্ষিত আধারে,\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxliv{এক নির্দিষ্টকাল পর্যন্ত,\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxlv{অতঃপর আমি পরিমিত আকারে সৃষ্টি করেছি, আমি কত সক্ষম স্রষ্টা?\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxlvi{সেদিন মিথ্যারোপকারীদের দুর্ভোগ হবে।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxlvii{আমি কি পৃথিবীকে সৃষ্টি করিনি ধারণকারিণীরূপে,\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxlviii{জীবিত ও মৃতদেরকে?\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxlix{আমি তাতে স্থাপন করেছি মজবুত সুউচ্চ পর্বতমালা এবং পান করিয়েছি তোমাদেরকে তৃষ্ণা নিবারণকারী সুপেয় পানি।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmmdcl{সেদিন মিথ্যারোপকারীদের দুর্ভোগ হবে।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmmdcli{চল তোমরা তারই দিকে, যাকে তোমরা মিথ্যা বলতে।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmmdclii{চল তোমরা তিন কুন্ডলীবিশিষ্ট ছায়ার দিকে,\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmmdcliii{যে ছায়া সুনিবিড় নয় এবং অগ্নির উত্তাপ থেকে রক্ষা করে না।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmmmdcliv{এটা অট্টালিকা সদৃশ বৃহৎ স্ফুলিংগ নিক্ষেপ করবে।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmmmdclv{যেন সে পীতবর্ণ উষ্ট্রশ্রেণী।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmmmdclvi{সেদিন মিথ্যারোপকারীদের দুর্ভোগ হবে।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmmmdclvii{এটা এমন দিন, যেদিন কেউ কথা বলবে না।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmmmdclviii{এবং কাউকে তওবা করার অনুমতি দেয়া হবে না।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmmmdclix{সেদিন মিথ্যারোপকারীদের দুর্ভোগ হবে।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmmmdclx{এটা বিচার দিবস, আমি তোমাদেরকে এবং তোমাদের পূর্ববর্তীদেরকে একত্রিত করেছি।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxi{অতএব, তোমাদের কোন অপকৌশল থাকলে তা প্রয়োগ কর আমার কাছে।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxii{সেদিন মিথ্যারোপকারীদের দুর্ভোগ হবে।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxiii{নিশ্চয় খোদাভীরুরা থাকবে ছায়ায় এবং প্রস্রবণসমূহে-\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxiv{এবং তাদের বাঞ্ছিত ফল-মূলের মধ্যে।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxv{বলা হবেঃ তোমরা যা করতে তার বিনিময়ে তৃপ্তির সাথে পানাহার কর।\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxvi{এভাবেই আমি সৎকর্মশীলদেরকে পুরস্কৃত করে থাকি।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxvii{সেদিন মিথ্যারোপকারীদের দুর্ভোগ হবে।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxviii{কাফেরগণ, তোমরা কিছুদিন খেয়ে নাও এবং ভোগ করে নাও। তোমরা তো অপরাধী।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxix{সেদিন মিথ্যারোপকারীদের দুর্ভোগ হবে।\qt@no{(47)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxx{যখন তাদেরকে বলা হয়, নত হও, তখন তারা নত হয় না।\qt@no{(48)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxxi{সেদিন মিথ্যারোপকারীদের দুর্ভোগ হবে।\qt@no{(49)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxxii{এখন কোন কথায় তারা এরপর বিশ্বাস স্থাপন করবে?\qt@no{(50)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxxiii{\basmalahbn তারা পরস্পরে কি বিষয়ে জিজ্ঞাসাবাদ করছে?\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxxiv{মহা সংবাদ সম্পর্কে,\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxxv{যে সম্পর্কে তারা মতানৈক্য করে।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxxvi{না, সত্ত্বরই তারা জানতে পারবে,\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxxvii{অতঃপর না, সত্বর তারা জানতে পারবে।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxxviii{আমি কি করিনি ভূমিকে বিছানা\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxxix{এবং পর্বতমালাকে পেরেক?\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxxx{আমি তোমাদেরকে জোড়া জোড়া সৃষ্টি করেছি,\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxxxi{তোমাদের নিদ্রাকে করেছি ক্লান্তি দূরকারী,\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxxxii{রাত্রিকে করেছি আবরণ।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxxxiii{দিনকে করেছি জীবিকা অর্জনের সময়,\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxxxiv{নির্মান করেছি তোমাদের মাথার উপর মজবুত সপ্ত-আকাশ।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxxxv{এবং একটি উজ্জ্বল প্রদীপ সৃষ্টি করেছি।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxxxvi{আমি জলধর মেঘমালা থেকে প্রচুর বৃষ্টিপাত করি,\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxxxvii{যাতে তদ্দ্বারা উৎপন্ন করি শস্য, উদ্ভিদ।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxxxviii{ও পাতাঘন উদ্যান।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmdclxxxix{নিশ্চয় বিচার দিবস নির্ধারিত রয়েছে।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxc{যেদিন শিংগায় ফুঁক দেয়া হবে, তখন তোমরা দলে দলে সমাগত হবে।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxci{আকাশ বিদীর্ণ হয়ে; তাতে বহু দরজা সৃষ্টি হবে।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxcii{এবং পর্বতমালা চালিত হয়ে মরীচিকা হয়ে যাবে।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxciii{নিশ্চয় জাহান্নাম প্রতীক্ষায় থাকবে,\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxciv{সীমালংঘনকারীদের আশ্রয়স্থলরূপে।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxcv{তারা তথায় শতাব্দীর পর শতাব্দী অবস্থান করবে।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxcvi{তথায় তারা কোন শীতল এবং পানীয় আস্বাদন করবে না;\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxcvii{কিন্তু ফুটন্ত পানি ও পূঁজ পাবে।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxcviii{পরিপূর্ণ প্রতিফল হিসেবে।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmmdcxcix{নিশ্চয় তারা হিসাব-নিকাশ আশা করত না।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmmdcc{এবং আমার আয়াতসমূহে পুরোপুরি মিথ্যারোপ করত।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmmdcci{আমি সবকিছুই লিপিবদ্ধ করে সংরক্ষিত করেছি।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmmdccii{অতএব, তোমরা আস্বাদন কর, আমি কেবল তোমাদের শাস্তিই বৃদ্ধি করব।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmmdcciii{পরহেযগারদের জন্যে রয়েছে সাফল্য।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmmmdcciv{উদ্যান, আঙ্গুর,\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmmmdccv{সমবয়স্কা, পূর্ণযৌবনা তরুণী।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmmmdccvi{এবং পূর্ণ পানপাত্র।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmmmdccvii{তারা তথায় অসার ও মিথ্যা বাক্য শুনবে না।\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmmmdccviii{এটা আপনার পালনকর্তার তরফ থেকে যথোচিত দান,\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmmmdccix{যিনি নভোমন্ডল, ভূমন্ডল ও এতদুভয়ের মধ্যবর্তী সবকিছুর পালনকর্তা, দয়াময়, কেউ তাঁর সাথে কথার অধিকারী হবে না।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmmmdccx{যেদিন রূহ ও ফেরেশতাগণ সারিবদ্ধভাবে দাঁড়াবে। দয়াময় আল্লাহ যাকে অনুমতি দিবেন, সে ব্যতিত কেউ কথা বলতে পারবে না এবং সে সত্যকথা বলবে।\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxi{এই দিবস সত্য। অতঃপর যার ইচ্ছা, সে তার পালনকর্তার কাছে ঠিকানা তৈরী করুক।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxii{আমি তোমাদেরকে আসন্ন শাস্তি সম্পর্কে সতর্ক করলাম, যেদিন মানুষ প্রত্যেক্ষ করবে যা সে সামনে প্রেরণ করেছে এবং কাফের বলবেঃ হায়, আফসোস-আমি যদি মাটি হয়ে যেতাম।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxiii{\basmalahbn শপথ সেই ফেরেশতাগণের, যারা ডুব দিয়ে আত্মা উৎপাটন করে,\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxiv{শপথ তাদের, যারা আত্মার বাঁধন খুলে দেয় মৃদুভাবে;\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxv{শপথ তাদের, যারা সন্তরণ করে দ্রুতগতিতে,\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxvi{শপথ তাদের, যারা দ্রুতগতিতে অগ্রসর হয় এবং\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxvii{শপথ তাদের, যারা সকল কর্মনির্বাহ করে, কেয়ামত অবশ্যই হবে।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxviii{যেদিন প্রকম্পিত করবে প্রকম্পিতকারী,\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxix{অতঃপর পশ্চাতে আসবে পশ্চাদগামী;\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxx{সেদিন অনেক হৃদয় ভীত-বিহবল হবে।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxxi{তাদের দৃষ্টি নত হবে।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxxii{তারা বলেঃ আমরা কি উলটো পায়ে প্রত্যাবর্তিত হবই-\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxxiii{গলিত অস্থি হয়ে যাওয়ার পরও?\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxxiv{তবে তো এ প্রত্যাবর্তন সর্বনাশা হবে!\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxxv{অতএব, এটা তো কেবল এক মহা-নাদ,\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxxvi{তখনই তারা ময়দানে আবির্ভূত হবে।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxxvii{মূসার বৃত্তান্ত আপনার কাছে পৌছেছে কি?\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxxviii{যখন তার পালনকর্তা তাকে পবিত্র তুয়া উপ্যকায় আহবান করেছিলেন,\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxxix{ফেরাউনের কাছে যাও, নিশ্চয় সে সীমালংঘন করেছে।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxxx{অতঃপর বলঃ তোমার পবিত্র হওয়ার আগ্রহ আছে কি?\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxxxi{আমি তোমাকে তোমার পালনকর্তার দিকে পথ দেখাব, যাতে তুমি তাকে ভয় কর।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxxxii{অতঃপর সে তাকে মহা-নিদর্শন দেখাল।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxxxiii{কিন্তু সে মিথ্যারোপ করল এবং অমান্য করল।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxxxiv{অতঃপর সে প্রতিকার চেষ্টায় প্রস্থান করল।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxxxv{সে সকলকে সমবেত করল এবং সজোরে আহবান করল,\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxxxvi{এবং বললঃ আমিই তোমাদের সেরা পালনকর্তা।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxxxvii{অতঃপর আল্লাহ তাকে পরকালের ও ইহকালের শাস্তি দিলেন।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxxxviii{যে ভয় করে তার জন্যে অবশ্যই এতে শিক্ষা রয়েছে।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxxxix{তোমাদের সৃষ্টি অধিক কঠিন না আকাশের, যা তিনি নির্মাণ করেছেন?\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxl{তিনি একে উচ্চ করেছেন ও সুবিন্যস্ত করেছেন।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxli{তিনি এর রাত্রিকে করেছেন অন্ধকারাচ্ছন্ন এবং এর সূর্যোলোক প্রকাশ করেছেন।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxlii{পৃথিবীকে এর পরে বিস্তৃত করেছেন।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxliii{তিনি এর মধ্য থেকে এর পানি ও ঘাম নির্গত করেছেন,\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxliv{পর্বতকে তিনি দৃঢ়ভাবে প্রতিষ্ঠিত করেছেন,\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxlv{তোমাদের ও তোমাদের চতুস্পদ জন্তুদের উপকারার্থে।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxlvi{অতঃপর যখন মহাসংকট এসে যাবে।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxlvii{অর্থাৎ যেদিন মানুষ তার কৃতকর্ম স্মরণ করবে\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxlviii{এবং দর্শকদের জন্যে জাহান্নাম প্রকাশ করা হবে,\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxlix{তখন যে ব্যক্তি সীমালংঘন করেছে;\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmmmdccl{এবং পার্থিব জীবনকে অগ্রাধিকার দিয়েছে,\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmmmdccli{তার ঠিকানা হবে জাহান্নাম।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclii{পক্ষান্তরে যে ব্যক্তি তার পালনকর্তার সামনে দন্ডায়মান হওয়াকে ভয় করেছে এবং খেয়াল-খুশী থেকে নিজেকে নিবৃত্ত রেখেছে,\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmmmdccliii{তার ঠিকানা হবে জান্নাত।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmmmdccliv{তারা আপনাকে জিজ্ঞাসা করে, কেয়ামত কখন হবে?\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclv{এর বর্ণনার সাথে আপনার কি সম্পর্ক ?\qt@no{(43)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclvi{এর চরম জ্ঞান আপনার পালনকর্তার কাছে।\qt@no{(44)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclvii{যে একে ভয় করে, আপনি তো কেবল তাকেই সতর্ক করবেন।\qt@no{(45)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclviii{যেদিন তারা একে দেখবে, সেদিন মনে হবে যেন তারা দুনিয়াতে মাত্র এক সন্ধ্যা অথবা এক সকাল অবস্থান করেছে।\qt@no{(46)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclix{\basmalahbn তিনি ভ্রূকুঞ্চিত করলেন এবং মুখ ফিরিয়ে নিলেন।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclx{কারণ, তাঁর কাছে এক অন্ধ আগমন করল।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxi{আপনি কি জানেন, সে হয়তো পরিশুদ্ধ হত,\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxii{অথবা উপদেশ গ্রহণ করতো এবং উপদেশ তার উপকার হত।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxiii{পরন্তু যে বেপরোয়া,\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxiv{আপনি তার চিন্তায় মশগুল।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxv{সে শুদ্ধ না হলে আপনার কোন দোষ নেই।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxvi{যে আপনার কাছে দৌড়ে আসলো\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxvii{এমতাবস্থায় যে, সে ভয় করে,\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxviii{আপনি তাকে অবজ্ঞা করলেন।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxix{কখনও এরূপ করবেন না, এটা উপদেশবানী।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxx{অতএব, যে ইচ্ছা করবে, সে একে গ্রহণ করবে।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxxi{এটা লিখিত আছে সম্মানিত,\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxxii{উচ্চ পবিত্র পত্রসমূহে,\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxxiii{লিপিকারের হস্তে,\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxxiv{যারা মহৎ, পূত চরিত্র।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxxv{মানুষ ধ্বংস হোক, সে কত অকৃতজ্ঞ!\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxxvi{তিনি তাকে কি বস্তু থেকে সৃষ্টি করেছেন?\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxxvii{শুক্র থেকে তাকে সৃষ্টি করেছেন, অতঃপর তাকে সুপরিমিত করেছেন।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxxviii{অতঃপর তার পথ সহজ করেছেন,\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxxix{অতঃপর তার মৃত্যু ঘটান ও কবরস্থ করেন তাকে।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxxx{এরপর যখন ইচ্ছা করবেন তখন তাকে পুনরুজ্জীবিত করবেন।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxxxi{সে কখনও কৃতজ্ঞ হয়নি, তিনি তাকে যা আদেশ করেছেন, সে তা পূর্ণ করেনি।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxxxii{মানুষ তার খাদ্যের প্রতি লক্ষ্য করুক,\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxxxiii{আমি আশ্চর্য উপায়ে পানি বর্ষণ করেছি,\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxxxiv{এরপর আমি ভূমিকে বিদীর্ণ করেছি,\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxxxv{অতঃপর তাতে উৎপন্ন করেছি শস্য,\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxxxvi{আঙ্গুর, শাক-সব্জি,\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxxxvii{যয়তুন, খর্জূর,\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxxxviii{ঘন উদ্যান,\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmmdcclxxxix{ফল এবং ঘাস\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxc{তোমাদেরও তোমাদের চতুস্পদ জন্তুদের উপাকারার্থে।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxci{অতঃপর যেদিন কর্ণবিদারক নাদ আসবে,\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxcii{সেদিন পলায়ন করবে মানুষ তার ভ্রাতার কাছ থেকে,\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxciii{তার মাতা, তার পিতা,\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxciv{তার পত্নী ও তার সন্তানদের কাছ থেকে।\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxcv{সেদিন প্রত্যেকেরই নিজের এক চিন্তা থাকবে, যা তাকে ব্যতিব্যস্ত করে রাখবে।\qt@no{(37)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxcvi{অনেক মুখমন্ডল সেদিন হবে উজ্জ্বল,\qt@no{(38)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxcvii{সহাস্য ও প্রফুল্ল।\qt@no{(39)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxcviii{এবং অনেক মুখমন্ডল সেদিন হবে ধুলি ধূসরিত।\qt@no{(40)}}
\qt@newcmd\qurantrans@bn@mmmmmdccxcix{তাদেরকে কালিমা আচ্ছন্ন করে রাখবে।\qt@no{(41)}}
\qt@newcmd\qurantrans@bn@mmmmmdccc{তারাই কাফের পাপিষ্ঠের দল।\qt@no{(42)}}
\qt@newcmd\qurantrans@bn@mmmmmdccci{\basmalahbn যখন সূর্য আলোহীন হয়ে যাবে,\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccii{যখন নক্ষত্র মলিন হয়ে যাবে,\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmdccciii{যখন পর্বতমালা অপসারিত হবে,\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmdccciv{যখন দশ মাসের গর্ভবতী উষ্ট্রীসমূহ উপেক্ষিত হবে;\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccv{যখন বন্য পশুরা একত্রিত হয়ে যাবে,\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccvi{যখন সমুদ্রকে উত্তাল করে তোলা হবে,\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccvii{যখন আত্মাসমূহকে যুগল করা হবে,\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccviii{যখন জীবন্ত প্রোথিত কন্যাকে জিজ্ঞেস করা হবে,\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccix{কি অপরাধে তাকে হত্য করা হল?\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccx{যখন আমলনামা খোলা হবে,\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxi{যখন আকাশের আবরণ অপসারিত হবে,\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxii{যখন জাহান্নামের অগ্নি প্রজ্বলিত করা হবে\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxiii{এবং যখন জান্নাত সন্নিকটবর্তী হবে,\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxiv{তখন প্রত্যেকেই জেনে নিবে সে কি উপস্থিত করেছে।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxv{আমি শপথ করি যেসব নক্ষত্রগুলো পশ্চাতে সরে যায়।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxvi{চলমান হয় ও অদৃশ্য হয়,\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxvii{শপথ নিশাবসান ও\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxviii{প্রভাত আগমন কালের,\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxix{নিশ্চয় কোরআন সম্মানিত রসূলের আনীত বাণী,\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxx{যিনি শক্তিশালী, আরশের মালিকের নিকট মর্যাদাশালী,\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxxi{সবার মান্যবর, সেখানকার বিশ্বাসভাজন।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxxii{এবং তোমাদের সাথী পাগল নন।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxxiii{তিনি সেই ফেরেশতাকে প্রকাশ্য দিগন্তে দেখেছেন।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxxiv{তিনি অদৃশ্য বিষয় বলতে কৃপনতা করেন না।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxxv{এটা বিতাড়িত শয়তানের উক্তি নয়।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxxvi{অতএব, তোমরা কোথায় যাচ্ছ?\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxxvii{এটা তো কেবল বিশ্বাবাসীদের জন্যে উপদেশ,\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxxviii{তার জন্যে, যে তোমাদের মধ্যে সোজা চলতে চায়।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxxix{তোমরা আল্লাহ রাব্বুল আলামীনের অভিপ্রায়ের বাইরে অন্য কিছুই ইচ্ছা করতে পার না।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxxx{\basmalahbn যখন আকাশ বিদীর্ণ হবে,\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxxxi{যখন নক্ষত্রসমূহ ঝরে পড়বে,\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxxxii{যখন সমুদ্রকে উত্তাল করে তোলা হবে,\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxxxiii{এবং যখন কবরসমূহ উম্মোচিত হবে,\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxxxiv{তখন প্রত্যেকে জেনে নিবে সে কি অগ্রে প্রেরণ করেছে এবং কি পশ্চাতে ছেড়ে এসেছে।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxxxv{হে মানুষ, কিসে তোমাকে তোমার মহামহিম পালনকর্তা সম্পর্কে বিভ্রান্ত করল?\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxxxvi{যিনি তোমাকে সৃষ্টি করেছেন, অতঃপর তোমাকে সুবিন্যস্ত করেছেন এবং সুষম করেছেন।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxxxvii{যিনি তোমাকে তাঁর ইচ্ছামত আকৃতিতে গঠন করেছেন।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxxxviii{কখনও বিভ্রান্ত হয়ো না; বরং তোমরা দান-প্রতিদানকে মিথ্যা মনে কর।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxxxix{অবশ্যই তোমাদের উপর তত্ত্বাবধায়ক নিযুক্ত আছে।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxl{সম্মানিত আমল লেখকবৃন্দ।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxli{তারা জানে যা তোমরা কর।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxlii{সৎকর্মশীলগণ থাকবে জান্নাতে।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxliii{এবং দুষ্কর্মীরা থাকবে জাহান্নামে;\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxliv{তারা বিচার দিবসে তথায় প্রবেশ করবে।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxlv{তারা সেখান থেকে পৃথক হবে না।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxlvi{আপনি জানেন, বিচার দিবস কি?\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxlvii{অতঃপর আপনি জানেন, বিচার দিবস কি?\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxlviii{যেদিন কেউ কারও কোন উপকার করতে পারবে না এবং সেদিন সব কতৃꦣ2468;্ব হবে আল্লাহর।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxlix{\basmalahbn যারা মাপে কম করে, তাদের জন্যে দুর্ভোগ,\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccl{যারা লোকের কাছ থেকে যখন মেপে নেয়, তখন পূর্ণ মাত্রায় নেয়\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccli{এবং যখন লোকদেরকে মেপে দেয় কিংবা ওজন করে দেয়, তখন কম করে দেয়।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclii{তারা কি চিন্তা করে না যে, তারা পুনরুত্থিত হবে।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccliii{সেই মহাদিবসে,\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccliv{যেদিন মানুষ দাঁড়াবে বিশ্ব পালনকর্তার সামনে।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclv{এটা কিছুতেই উচিত নয়, নিশ্চয় পাপাচারীদের আমলনামা সিজ্জীনে আছে।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclvi{আপনি জানেন, সিজ্জীন কি?\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclvii{এটা লিপিবদ্ধ খাতা।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclviii{সেদিন দুর্ভোগ মিথ্যারোপকারীদের,\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclix{যারা প্রতিফল দিবসকে মিথ্যারোপ করে।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclx{প্রত্যেক সীমালংঘনকারী পাপিষ্ঠই কেবল একে মিথ্যারোপ করে।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxi{তার কাছে আমার আয়াতসমূহ পাঠ করা হলে সে বলে, পুরাকালের উপকথা।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxii{কখনও না, বরং তারা যা করে, তাই তাদের হৃদয় মরিচা ধরিয়ে দিয়েছে।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxiii{কখনও না, তারা সেদিন তাদের পালনকর্তার থেকে পর্দার অন্তরালে থাকবে।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxiv{অতঃপর তারা জাহান্নামে প্রবেশ করবে।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxv{এরপর বলা হবে, একেই তো তোমরা মিথ্যারোপ করতে।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxvi{কখনও না, নিশ্চয় সৎলোকদের আমলনামা আছে ইল্লিয়্যীনে।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxvii{আপনি জানেন ইল্লিয়্যীন কি?\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxviii{এটা লিপিবদ্ধ খাতা।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxix{আল্লাহর নৈকট্যপ্রাপ্ত ফেরেশতাগণ একে প্রত্যক্ষ করে।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxx{নিশ্চয় সৎলোকগণ থাকবে পরম আরামে,\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxxi{সিংহাসনে বসে অবলোকন করবে।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxxii{আপনি তাদের মুখমন্ডলে স্বাচ্ছন্দ্যের সজীবতা দেখতে পাবেন।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxxiii{তাদেরকে মোহর করা বিশুদ্ধ পানীয় পান করানো হবে।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxxiv{তার মোহর হবে কস্তুরী। এ বিষয়ে প্রতিযোগীদের প্রতিযোগিতা করা উচিত।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxxv{তার মিশ্রণ হবে তসনীমের পানি।\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxxvi{এটা একটা ঝরণা, যার পানি পান করবে নৈকট্যশীলগণ।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxxvii{যারা অপরাধী, তারা বিশ্বাসীদেরকে উপহাস করত।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxxviii{এবং তারা যখন তাদের কাছ দিয়ে গমন করত তখন পরস্পরে চোখ টিপে ইশারা করত।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxxix{তারা যখন তাদের পরিবার-পরিজনের কাছে ফিরত, তখনও হাসাহাসি করে ফিরত।\qt@no{(31)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxxx{আর যখন তারা বিশ্বাসীদেরকে দেখত, তখন বলত, নিশ্চয় এরা বিভ্রান্ত।\qt@no{(32)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxxxi{অথচ তারা বিশ্বাসীদের তত্ত্বাবধায়করূপে প্রেরিত হয়নি।\qt@no{(33)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxxxii{আজ যারা বিশ্বাসী, তারা কাফেরদেরকে উপহাস করছে।\qt@no{(34)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxxxiii{সিংহাসনে বসে, তাদেরকে অবলোকন করছে,\qt@no{(35)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxxxiv{কাফেররা যা করত, তার প্রতিফল পেয়েছে তো?\qt@no{(36)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxxxv{\basmalahbn যখন আকাশ বিদীর্ণ হবে,\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxxxvi{ও তার পালনকর্তার আদেশ পালন করবে এবং আকাশ এরই উপযুক্ত\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxxxvii{এবং যখন পৃথিবীকে সম্প্রসারিত করা হবে।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxxxviii{এবং পৃথিবী তার গর্ভস্থিত সবকিছু বাইরে নিক্ষেপ করবে ও শুন্যগর্ভ হয়ে যাবে।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmdccclxxxix{এবং তার পালনকর্তার আদেশ পালন করবে এবং পৃথিবী এরই উপযুক্ত।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxc{হে মানুষ, তোমাকে তোমরা পালনকর্তা পর্যন্ত পৌছতে কষ্ট স্বীকার করতে হবে, অতঃপর তার সাক্ষাৎ ঘটবে।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxci{যাকে তার আমলনামা ডান হাতে দেয়া হবে\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxcii{তার হিসাব-নিকাশ সহজে হয়ে যাবে\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxciii{এবং সে তার পরিবার-পরিজনের কাছে হৃষ্টচিত্তে ফিরে যাবে\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxciv{এবং যাকে তার আমলনামা পিঠের পশ্চাদ্দিক থেকে দেয়া, হবে,\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxcv{সে মৃত্যুকে আহবান করবে,\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxcvi{এবং জাহান্নামে প্রবেশ করবে।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxcvii{সে তার পরিবার-পরিজনের মধ্যে আনন্দিত ছিল।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxcviii{সে মনে করত যে, সে কখনও ফিরে যাবে না।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmdcccxcix{কেন যাবে না, তার পালনকর্তা তো তাকে দেখতেন।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmcm{আমি শপথ করি সন্ধ্যাকালীন লাল আভার\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmcmi{এবং রাত্রির, এবং তাতে যার সমাবেশ ঘটে\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmcmii{এবং চন্দ্রের, যখন তা পূর্ণরূপ লাভ করে,\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmcmiii{নিশ্চয় তোমরা এক সিঁড়ি থেকে আরেক সিঁড়িতে আরোহণ করবে।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmmcmiv{অতএব, তাদের কি হল যে, তারা ঈমান আনে না?\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmmcmv{যখন তাদের কাছে কোরআন পাঠ করা হয়, তখন সেজদা করে না।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmmcmvi{বরং কাফেররা এর প্রতি মিথ্যারোপ করে।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmmcmvii{তারা যা সংরক্ষণ করে, আল্লাহ তা জানেন।\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmmcmviii{অতএব, তাদেরকে যন্ত্রণাদায়ক শাস্তির সুসংবাদ দিন।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmmcmix{কিন্তু যারা বিশ্বাস স্থাপন করে ও সৎকর্ম করে, তাদের জন্য রয়েছে অফুরন্ত পুরস্কার।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmmcmx{\basmalahbn শপথ গ্রহ-নক্ষত্র শোভিত আকাশের,\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxi{এবং প্রতিশ্রুত দিবসের,\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxii{এবং সেই দিবসের, যে উপস্থিত হয় ও যাতে উপস্থিত হয়\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxiii{অভিশপ্ত হয়েছে গর্ত ওয়ালারা অর্থাৎ,\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxiv{অনেক ইন্ধনের অগ্নিসংযোগকারীরা;\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxv{যখন তারা তার কিনারায় বসেছিল।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxvi{এবং তারা বিশ্বাসীদের সাথে যা করেছিল, তা নিরীক্ষণ করছিল।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxvii{তারা তাদেরকে শাস্তি দিয়েছিল শুধু এ কারণে যে, তারা প্রশংসিত, পরাক্রান্ত আল্লাহর প্রতি বিশ্বাস স্থাপন করেছিল,\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxviii{যিনি নভোমন্ডল ও ভূমন্ডলের ক্ষমতার মালিক, আল্লাহর সামনে রয়েছে সবকিছু।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxix{যারা মুমিন পুরুষ ও নারীকে নিপীড়ন করেছে, অতঃপর তওবা করেনি, তাদের জন্যে আছে জাহান্নামের শাস্তি, আর আছে দহন যন্ত্রণা,\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxx{যারা ঈমান আনে ও সৎকর্ম করে তাদের জন্যে আছে জান্নাত, যার তলদেশে প্রবাহিত হয় নির্ঝরিণীসমূহ। এটাই মহাসাফল্য।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxxi{নিশ্চয় তোমার পালনকর্তার পাকড়াও অত্যন্ত কঠিন।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxxii{তিনিই প্রথমবার অস্তিত্ব দান করেন এবং পুনরায় জীবিত করেন।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxxiii{তিনি ক্ষমাশীল, প্রেমময়;\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxxiv{মহান আরশের অধিকারী।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxxv{তিনি যা চান, তাই করেন।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxxvi{আপনার কাছে সৈন্যবাহিনীর ইতিবৃত্ত পৌছেছে কি?\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxxvii{ফেরাউনের এবং সামুদের?\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxxviii{বরং যারা কাফের, তারা মিথ্যারোপে রত আছে।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxxix{আল্লাহ তাদেরকে চতুর্দিক থেকে পরিবেষ্টন করে রেখেছেন।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxxx{বরং এটা মহান কোরআন,\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxxxi{লওহে মাহফুযে লিপিবদ্ধ।\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxxxii{\basmalahbn শপথ আকাশের এবং রাত্রিতে আগমনকারীর।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxxxiii{আপনি জানেন, যে রাত্রিতে আসে সেটা কি?\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxxxiv{সেটা এক উজ্জ্বল নক্ষত্র।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxxxv{প্রত্যেকের উপর একজন তত্ত্বাবধায়ক রয়েছে।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxxxvi{অতএব, মানুষের দেখা উচিত কি বস্তু থেকে সে সৃজিত হয়েছে।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxxxvii{সে সৃজিত হয়েছে সবেগে স্খলিত পানি থেকে।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxxxviii{এটা নির্গত হয় মেরুদন্ড ও বক্ষপাজরের মধ্য থেকে।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxxxix{নিশ্চয় তিনি তাকে ফিরিয়ে নিতে সক্ষম।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxl{যেদিন গোপন বিষয়াদি পরীক্ষিত হবে,\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxli{সেদিন তার কোন শক্তি থাকবে না এবং সাহায্যকারীও থাকবে না।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxlii{শপথ চক্রশীল আকাশের\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxliii{এবং বিদারনশীল পৃথিবীর\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxliv{নিশ্চয় কোরআন সত্য-মিথ্যার ফয়সালা।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxlv{এবং এটা উপহাস নয়।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxlvi{তারা ভীষণ চক্রান্ত করে,\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxlvii{আর আমিও কৌশল করি।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxlviii{অতএব, কাফেরদেরকে অবকাশ দিন, তাদেরকে অবকাশ দিন, কিছু দিনের জন্যে।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxlix{\basmalahbn আপনি আপনার মহান পালনকর্তার নামের পবিত্রতা বর্ণনা করুন\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmcml{যিনি সৃষ্টি করেছেন ও সুবিন্যস্ত করেছেন।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmcmli{এবং যিনি সুপরিমিত করেছেন ও পথ প্রদর্শন করেছেন\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlii{এবং যিনি তৃণাদি উৎপন্ন করেছেন,\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmcmliii{অতঃপর করেছেন তাকে কাল আবর্জনা।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmcmliv{আমি আপনাকে পাঠ করাতে থাকব, ফলে আপনি বিস্মৃত হবেন না\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlv{আল্লাহ যা ইচ্ছা করেন তা ব্যতীত। নিশ্চয় তিনি জানেন প্রকাশ্য ও গোপন বিষয়।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlvi{আমি আপনার জন্যে সহজ শরীয়ত সহজতর করে দেবো।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlvii{উপদেশ ফলপ্রসূ হলে উপদেশ দান করুন,\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlviii{যে ভয় করে, সে উপদেশ গ্রহণ করবে,\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlix{আর যে, হতভাগা, সে তা উপেক্ষা করবে,\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlx{সে মহা-অগ্নিতে প্রবেশ করবে।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxi{অতঃপর সেখানে সে মরবেও না, জীবিতও থাকবে না।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxii{নিশ্চয় সাফল্য লাভ করবে সে, যে শুদ্ধ হয়\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxiii{এবং তার পালনকর্তার নাম স্মরণ করে, অতঃপর নামায আদায় করে।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxiv{বস্তুতঃ তোমরা পার্থিব জীবনকে অগ্রাধিকার দাও,\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxv{অথচ পরকালের জীবন উৎকৃষ্ট ও স্থায়ী।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxvi{এটা লিখিত রয়েছে পূর্ববতী কিতাবসমূহে;\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxvii{ইব্রাহীম ও মূসার কিতাবসমূহে।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxviii{\basmalahbn আপনার কাছে আচ্ছন্নকারী কেয়ামতের বৃত্তান্ত পৌঁছেছে কি?\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxix{অনেক মুখমন্ডল সেদিন হবে লাঞ্ছিত,\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxx{ক্লিষ্ট, ক্লান্ত।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxxi{তারা জ্বলন্ত আগুনে পতিত হবে।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxxii{তাদেরকে ফুটন্ত নহর থেকে পান করানো হবে।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxxiii{কন্টকপূর্ণ ঝাড় ব্যতীত তাদের জন্যে কোন খাদ্য নেই।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxxiv{এটা তাদেরকে পুষ্ট করবে না এবং ক্ষুধায়ও উপকার করবে না।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxxv{অনেক মুখমন্ডল সেদিন হবে, সজীব,\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxxvi{তাদের কর্মের কারণে সন্তুষ্ট।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxxvii{তারা থাকবে, সুউচ্চ জান্নাতে।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxxviii{তথায় শুনবে না কোন অসার কথাবার্তা।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxxix{তথায় থাকবে প্রবাহিত ঝরণা।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxxx{তথায় থাকবে উন্নত সুসজ্জিত আসন।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxxxi{এবং সংরক্ষিত পানপাত্র\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxxxii{এবং সারি সারি গালিচা\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxxxiii{এবং বিস্তৃত বিছানো কার্পেট।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxxxiv{তারা কি উষ্ট্রের প্রতি লক্ষ্য করে না যে, তা কিভাবে সৃষ্টি করা হয়েছে?\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxxxv{এবং আকাশের প্রতি লক্ষ্য করে না যে, তা কিভাবে উচ্চ করা হয়েছে?\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxxxvi{এবং পাহাড়ের দিকে যে, তা কিভাবে স্থাপন করা হয়েছে?\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxxxvii{এবং পৃথিবীর দিকে যে, তা কিভাবে সমতল বিছানো হয়েছে?\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxxxviii{অতএব, আপনি উপদেশ দিন, আপনি তো কেবল একজন উপদেশদাতা,\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmmcmlxxxix{আপনি তাদের শাসক নন,\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxc{কিন্তু যে মুখ ফিরিয়ে নেয় ও কাফের হয়ে যায়,\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxci{আল্লাহ তাকে মহা আযাব দেবেন।\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxcii{নিশ্চয় তাদের প্রত্যাবর্তন আমারই নিকট,\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxciii{অতঃপর তাদের হিসাব-নিকাশ আমারই দায়িত্ব।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxciv{\basmalahbn শপথ ফজরের,\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxcv{শপথ দশ রাত্রির, শপথ তার,\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxcvi{যা জোড় ও যা বিজোড়\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxcvii{এবং শপথ রাত্রির যখন তা গত হতে থাকে\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxcviii{এর মধ্যে আছে শপথ জ্ঞানী ব্যক্তির জন্যে।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmcmxcix{আপনি কি লক্ষ্য করেননি, আপনার পালনকর্তা আদ বংশের ইরাম গোত্রের সাথে কি আচরণ করেছিলেন,\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmm{যাদের দৈহিক গঠন স্তম্ভ ও খুঁটির ন্যায় দীর্ঘ ছিল এবং\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmmi{যাদের সমান শক্তি ও বলবীর্যে সারা বিশ্বের শহরসমূহে কোন লোক সৃজিত হয়নি\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmmii{এবং সামুদ গোত্রের সাথে, যারা উপত্যকায় পাথর কেটে গৃহ নির্মাণ করেছিল।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmmiii{এবং বহু কীলকের অধিপতি ফেরাউনের সাথে\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmmiv{যারা দেশে সীমালঙ্ঘন করেছিল।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmmv{অতঃপর সেখানে বিস্তর অশান্তি সৃষ্টি করেছিল।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmmvi{অতঃপর আপনার পালনকর্তা তাদেরকে শাস্তির কশাঘাত করলেন।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmmvii{নিশ্চয় আপনার পালকর্তা সতর্ক দৃষ্টি রাখেন।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmmviii{মানুষ এরূপ যে, যখন তার পালনকর্তা তাকে পরীক্ষা করেন, অতঃপর সম্মান ও অনুগ্রহ দান করেন, তখন বলে, আমার পালনকর্তা আমাকে সম্মান দান করেছেন।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmmix{এবং যখন তাকে পরীক্ষা করেন, অতঃপর রিযিক সংকুচিত করে দেন, তখন বলেঃ আমার পালনকর্তা আমাকে হেয় করেছেন।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmmx{এটা অমূলক, বরং তোমরা এতীমকে সম্মান কর না।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmmxi{এবং মিসকীনকে অন্নদানে পরস্পরকে উৎসাহিত কর না।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmmxii{এবং তোমরা মৃতের ত্যাজ্য সম্পত্তি সম্পূর্ণরূপে কুক্ষিগত করে ফেল\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmmmxiii{এবং তোমরা ধন-সম্পদকে প্রাণভরে ভালবাস।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmmmxiv{এটা অনুচিত। যখন পৃথিবী চুর্ণ-বিচুর্ণ হবে\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmmmxv{এবং আপনার পালনকর্তা ও ফেরেশতাগণ সারিবদ্ধভাবে উপস্থিত হবেন,\qt@no{(22)}}
\qt@newcmd\qurantrans@bn@mmmmmmxvi{এবং সেদিন জাহান্নামকে আনা হবে, সেদিন মানুষ স্মরণ করবে, কিন্তু এই স্মরণ তার কি কাজে আসবে?\qt@no{(23)}}
\qt@newcmd\qurantrans@bn@mmmmmmxvii{সে বলবেঃ হায়, এ জীবনের জন্যে আমি যদি কিছু অগ্রে প্রেরণ করতাম!\qt@no{(24)}}
\qt@newcmd\qurantrans@bn@mmmmmmxviii{সেদিন তার শাস্তির মত শাস্তি কেউ দিবে না।\qt@no{(25)}}
\qt@newcmd\qurantrans@bn@mmmmmmxix{এবং তার বন্ধনের মত বন্ধন কেউ দিবে না।\qt@no{(26)}}
\qt@newcmd\qurantrans@bn@mmmmmmxx{হে প্রশান্ত মন,\qt@no{(27)}}
\qt@newcmd\qurantrans@bn@mmmmmmxxi{তুমি তোমার পালনকর্তার নিকট ফিরে যাও সন্তুষ্ট ও সন্তোষভাজন হয়ে।\qt@no{(28)}}
\qt@newcmd\qurantrans@bn@mmmmmmxxii{অতঃপর আমার বান্দাদের অন্তর্ভুক্ত হয়ে যাও।\qt@no{(29)}}
\qt@newcmd\qurantrans@bn@mmmmmmxxiii{এবং আমার জান্নাতে প্রবেশ কর।\qt@no{(30)}}
\qt@newcmd\qurantrans@bn@mmmmmmxxiv{\basmalahbn আমি এই নগরীর শপথ করি\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmmxxv{এবং এই নগরীতে আপনার উপর কোন প্রতিবন্ধকতা নেই।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmmxxvi{শপথ জনকের ও যা জন্ম দেয়।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmmxxvii{নিশ্চয় আমি মানুষকে শ্রমনির্ভররূপে সৃষ্টি করেছি।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmmxxviii{সে কি মনে করে যে, তার উপর কেউ ক্ষমতাবান হবে না ?\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmmxxix{সে বলেঃ আমি প্রচুর ধন-সম্পদ ব্যয় করেছি।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmmxxx{সে কি মনে করে যে, তাকে কেউ দেখেনি?\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmmxxxi{আমি কি তাকে দেইনি চক্ষুদ্বয়,\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmmxxxii{জিহবা ও ওষ্ঠদ্বয় ?\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmmxxxiii{বস্তুতঃ আমি তাকে দু’টি পথ প্রদর্শন করেছি।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmmxxxiv{অতঃপর সে ধর্মের ঘাঁটিতে প্রবেশ করেনি।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmmxxxv{আপনি জানেন, সে ঘাঁটি কি?\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmmxxxvi{তা হচ্ছে দাসমুক্তি\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmmxxxvii{অথবা দুর্ভিক্ষের দিনে অন্নদান।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmmxxxviii{এতীম আত্বীয়কে\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmmxxxix{অথবা ধুলি-ধুসরিত মিসকীনকে\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmmxl{অতঃপর তাদের অন্তর্ভুক্ত হওয়া, যারা ঈমান আনে এবং পরস্পরকে উপদেশ দেয় সবরের ও উপদেশ দেয় দয়ার।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmmxli{তারাই সৌভাগ্যশালী।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmmxlii{আর যারা আমার আয়াতসমূহ অস্বীকার করে তারাই হতভাগা।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmmmxliii{তারা অগ্নিপরিবেষ্টিত অবস্থায় বন্দী থাকবে।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmmmxliv{\basmalahbn শপথ সূর্যের ও তার কিরণের,\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmmxlv{শপথ চন্দ্রের যখন তা সূর্যের পশ্চাতে আসে,\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmmxlvi{শপথ দিবসের যখন সে সূর্যকে প্রখরভাবে প্রকাশ করে,\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmmxlvii{শপথ রাত্রির যখন সে সূর্যকে আচ্ছাদিত করে,\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmmxlviii{শপথ আকাশের এবং যিনি তা নির্মাণ করেছেন, তাঁর।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmmxlix{শপথ পৃথিবীর এবং যিনি তা বিস্তৃত করেছেন, তাঁর,\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmml{শপথ প্রাণের এবং যিনি তা সুবিন্যস্ত করেছেন, তাঁর,\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmmli{অতঃপর তাকে তার অসৎকর্ম ও সৎকর্মের জ্ঞান দান করেছেন,\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmmlii{যে নিজেকে শুদ্ধ করে, সেই সফলকাম হয়।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmmliii{এবং যে নিজেকে কলুষিত করে, সে ব্যর্থ মনোরথ হয়।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmmliv{সামুদ সম্প্রদায় অবাধ্যতা বশতঃ মিথ্যারোপ করেছিল।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmmlv{যখন তাদের সর্বাধিক হতভাগ্য ব্যক্তি তৎপর হয়ে উঠেছিল।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmmlvi{অতঃপর আল্লাহর রসূল তাদেরকে বলেছিলেনঃ আল্লাহর উষ্ট্রী ও তাকে পানি পান করানোর ব্যাপারে সতর্ক থাক।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmmlvii{অতঃপর ওরা তার প্রতি মিথ্যারোপ করেছিল এবং উষ্ট্রীর পা কর্তন করেছিল। তাদের পাপের কারণে তাদের পালনকর্তা তাদের উপর ধ্বংস নাযিল করে একাকার করে দিলেন।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmmlviii{আল্লাহ তা’আলা এই ধ্বংসের কোন বিরূপ পরিণতির আশংকা করেন না।\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmmlix{\basmalahbn শপথ রাত্রির, যখন সে আচ্ছন্ন করে,\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmmlx{শপথ দিনের, যখন সে আলোকিত হয়\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxi{এবং তাঁর, যিনি নর ও নারী সৃষ্টি করেছেন,\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxii{নিশ্চয় তোমাদের কর্ম প্রচেষ্টা বিভিন্ন ধরনের।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxiii{অতএব, যে দান করে এবং খোদাভীরু হয়,\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxiv{এবং উত্তম বিষয়কে সত্য মনে করে,\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxv{আমি তাকে সুখের বিষয়ের জন্যে সহজ পথ দান করব।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxvi{আর যে কৃপণতা করে ও বেপরওয়া হয়\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxvii{এবং উত্তম বিষয়কে মিথ্যা মনে করে,\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxviii{আমি তাকে কষ্টের বিষয়ের জন্যে সহজ পথ দান করব।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxix{যখন সে অধঃপতিত হবে, তখন তার সম্পদ তার কোনই কাজে আসবে না।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxx{আমার দায়িত্ব পথ প্রদর্শন করা।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxxi{আর আমি মালিক ইহকালের ও পরকালের।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxxii{অতএব, আমি তোমাদেরকে প্রজ্বলিত অগ্নি সম্পর্কে সতর্ক করে দিয়েছি।\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxxiii{এতে নিতান্ত হতভাগ্য ব্যক্তিই প্রবেশ করবে,\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxxiv{যে মিথ্যারোপ করে ও মুখ ফিরিয়ে নেয়।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxxv{এ থেকে দূরে রাখা হবে খোদাভীরু ব্যক্তিকে,\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxxvi{যে আত্নশুদ্ধির জন্যে তার ধন-সম্পদ দান করে।\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxxvii{এবং তার উপর কারও কোন প্রতিদানযোগ্য অনুগ্রহ থাকে না।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxxviii{তার মহান পালনকর্তার সন্তুষ্টি অন্বেষণ ব্যতীত।\qt@no{(20)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxxix{সে সত্বরই সন্তুষ্টি লাভ করবে।\qt@no{(21)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxxx{\basmalahbn শপথ পূর্বাহ্নের,\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxxxi{শপথ রাত্রির যখন তা গভীর হয়,\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxxxii{আপনার পালনকর্তা আপনাকে ত্যাগ করেনি এবং আপনার প্রতি বিরূপও হননি।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxxxiii{আপনার জন্যে পরকাল ইহকাল অপেক্ষা শ্রেয়।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxxxiv{আপনার পালনকর্তা সত্বরই আপনাকে দান করবেন, অতঃপর আপনি সন্তুষ্ট হবেন।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxxxv{তিনি কি আপনাকে এতীমরূপে পাননি? অতঃপর তিনি আশ্রয় দিয়েছেন।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxxxvi{তিনি আপনাকে পেয়েছেন পথহারা, অতঃপর পথপ্রদর্শন করেছেন।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxxxvii{তিনি আপনাকে পেয়েছেন নিঃস্ব, অতঃপর অভাবমুক্ত করেছেন।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxxxviii{সুতরাং আপনি এতীমের প্রতি কঠোর হবেন না;\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmmlxxxix{সওয়ালকারীকে ধমক দেবেন না।\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmmxc{এবং আপনার পালনকর্তার নেয়ামতের কথা প্রকাশ করুন।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmmxci{\basmalahbn আমি কি আপনার বক্ষ উম্মুক্ত করে দেইনি?\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmmxcii{আমি লাঘব করেছি আপনার বোঝা,\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmmxciii{যা ছিল আপনার জন্যে অতিশয় দুঃসহ।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmmxciv{আমি আপনার আলোচনাকে সমুচ্চ করেছি।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmmxcv{নিশ্চয় কষ্টের সাথে স্বস্তি রয়েছে।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmmxcvi{নিশ্চয় কষ্টের সাথে স্বস্তি রয়েছে।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmmxcvii{অতএব, যখন অবসর পান পরিশ্রম করুন।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmmxcviii{এবং আপনার পালনকর্তার প্রতি মনোনিবেশ করুন।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmmxcix{\basmalahbn শপথ আঞ্জীর (ডুমুর) ও যয়তুনের,\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmmc{এবং সিনাই প্রান্তরস্থ তূর পর্বতের,\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmmci{এবং এই নিরাপদ নগরীর।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmmcii{আমি সৃষ্টি করেছি মানুষকে সুন্দরতর অবয়বে।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmmciii{অতঃপর তাকে ফিরিয়ে দিয়েছি নীচ থেকে নীচে।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmmciv{কিন্তু যারা বিশ্বাস স্থাপন করেছে ও সৎকর্ম করেছে, তাদের জন্যে রয়েছে অশেষ পুরস্কার।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmmcv{অতঃপর কেন তুমি অবিশ্বাস করছ কেয়ামতকে?\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmmcvi{আল্লাহ কি বিচারকদের মধ্যে শ্রেষ্টতম বিচারক নন?\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmmcvii{\basmalahbn পাঠ করুন আপনার পালনকর্তার নামে যিনি সৃষ্টি করেছেন\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmmcviii{সৃষ্টি করেছেন মানুষকে জমাট রক্ত থেকে।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmmcix{পাঠ করুন, আপনার পালনকর্তা মহা দয়ালু,\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmmcx{যিনি কলমের সাহায্যে শিক্ষা দিয়েছেন,\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxi{শিক্ষা দিয়েছেন মানুষকে যা সে জানত না।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxii{সত্যি সত্যি মানুষ সীমালংঘন করে,\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxiii{এ কারণে যে, সে নিজেকে অভাবমুক্ত মনে করে।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxiv{নিশ্চয় আপনার পালনকর্তার দিকেই প্রত্যাবর্তন হবে।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxv{আপনি কি তাকে দেখেছেন, যে নিষেধ করে\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxvi{এক বান্দাকে যখন সে নামায পড়ে?\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxvii{আপনি কি দেখেছেন যদি সে সৎপথে থাকে।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxviii{অথবা খোদাভীতি শিক্ষা দেয়।\qt@no{(12)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxix{আপনি কি দেখেছেন, যদি সে মিথ্যারোপ করে ও মুখ ফিরিয়ে নেয়।\qt@no{(13)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxx{সে কি জানে না যে, আল্লাহ দেখেন?\qt@no{(14)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxxi{কখনই নয়, যদি সে বিরত না হয়, তবে আমি মস্তকের সামনের কেশগুচ্ছ ধরে হেঁচড়াবই-\qt@no{(15)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxxii{মিথ্যাচারী, পাপীর কেশগুচ্ছ।\qt@no{(16)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxxiii{অতএব, সে তার সভাসদদেরকে আহবান করুক।\qt@no{(17)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxxiv{আমিও আহবান করব জাহান্নামের প্রহরীদেরকে\qt@no{(18)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxxv{কখনই নয়, আপনি তার আনুগত্য করবেন না। আপনি সেজদা করুন ও আমার নৈকট্য অর্জন করুন।\qt@no{(19)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxxvi{\basmalahbn আমি একে নাযিল করেছি শবে-কদরে।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxxvii{শবে-কদর সমন্ধে আপনি কি জানেন?\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxxviii{শবে-কদর হল এক হাজার মাস অপেক্ষা শ্রেষ্ঠ।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxxix{এতে প্রত্যেক কাজের জন্যে ফেরেশতাগণ ও রূহ অবতীর্ণ হয় তাদের পালনকর্তার নির্দেশক্রমে।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxxx{এটা নিরাপত্তা, যা ফজরের উদয় পর্যন্ত অব্যাহত থাকে।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxxxi{\basmalahbn আহলে-কিতাব ও মুশরেকদের মধ্যে যারা কাফের ছিল, তারা প্রত্যাবর্তন করত না যতক্ষণ না তাদের কাছে সুস্পষ্ট প্রমাণ আসত।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxxxii{অর্থাৎ আল্লাহর একজন রসূল, যিনি আবৃত্তি করতেন পবিত্র সহীফা,\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxxxiii{যাতে আছে, সঠিক বিষয়বস্তু।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxxxiv{অপর কিতাব প্রাপ্তরা যে বিভ্রান্ত হয়েছে, তা হয়েছে তাদের কাছে সুস্পষ্ট প্রমাণ আসার পরেই।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxxxv{তাদেরকে এছাড়া কোন নির্দেশ করা হয়নি যে, তারা খাঁটি মনে একনিষ্ঠভাবে আল্লাহর এবাদত করবে, নামায কায়েম করবে এবং যাকাত দেবে। এটাই সঠিক ধর্ম।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxxxvi{আহলে-কিতাব ও মুশরেকদের মধ্যে যারা কাফের, তারা জাহান্নামের আগুনে স্থায়ীভাবে থাকবে। তারাই সৃষ্টির অধম।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxxxvii{যারা ঈমান আনে ও সৎকর্ম করে, তারাই সৃষ্টির সেরা।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxxxviii{তাদের পালনকর্তার কাছে রয়েছে তাদের প্রতিদান চিরকাল বসবাসের জান্নাত, যার তলদেশে নির্ঝরিণী প্রবাহিত। তারা সেখানে থাকবে অনন্তকাল। আল্লাহ তাদের প্রতি সন্তুষ্ট এবং তারা আল্লাহর প্রতি সন্তুষ্ট। এটা তার জন্যে, যে তার পালনকর্তাকে ভয় কর।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxxxix{\basmalahbn যখন পৃথিবী তার কম্পনে প্রকম্পিত হবে,\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxl{যখন সে তার বোঝা বের করে দেবে।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxli{এবং মানুষ বলবে, এর কি হল ?\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxlii{সেদিন সে তার বৃত্তান্ত বর্ণনা করবে,\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxliii{কারণ, আপনার পালনকর্তা তাকে আদেশ করবেন।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxliv{সেদিন মানুষ বিভিন্ন দলে প্রকাশ পাবে, যাতে তাদেরকে তাদের কৃতকর্ম দেখানো হয়।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxlv{অতঃপর কেউ অণু পরিমাণ সৎকর্ম করলে তা দেখতে পাবে\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxlvi{এবং কেউ অণু পরিমাণ অসৎকর্ম করলে তাও দেখতে পাবে।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxlvii{\basmalahbn শপথ উর্ধ্বশ্বাসে চলমান অশ্বসমূহের,\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxlviii{অতঃপর ক্ষুরাঘাতে অগ্নিবিচ্ছুরক অশ্বসমূহের\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxlix{অতঃপর প্রভাতকালে আক্রমণকারী অশ্বসমূহের\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmmcl{ও যারা সে সময়ে ধুলি উৎক্ষিপ্ত করে\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmmcli{অতঃপর যারা শক্রদলের অভ্যন্তরে ঢুকে পড়ে-\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmmclii{নিশ্চয় মানুষ তার পালনকর্তার প্রতি অকৃতজ্ঞ।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmmcliii{এবং সে অবশ্য এ বিষয়ে অবহিত\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmmcliv{এবং সে নিশ্চিতই ধন-সম্পদের ভালবাসায় মত্ত।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmmclv{সে কি জানে না, যখন কবরে যা আছে, তা উত্থিত হবে\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmmclvi{এবং অন্তরে যা আছে, তা অর্জন করা হবে?\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmmclvii{সেদিন তাদের কি হবে, সে সম্পর্কে তাদের পালনকর্তা সবিশেষ জ্ঞাত।\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmmclviii{\basmalahbn করাঘাতকারী,\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmmclix{করাঘাতকারী কি?\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmmclx{করাঘাতকারী সম্পর্কে আপনি কি জানেন ?\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxi{যেদিন মানুষ হবে বিক্ষিপ্ত পতংগের মত\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxii{এবং পর্বতমালা হবে ধুনিত রঙ্গীন পশমের মত।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxiii{অতএব যার পাল্লা ভারী হবে,\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxiv{সে সুখীজীবন যাপন করবে।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxv{আর যার পাল্লা হালকা হবে,\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxvi{তার ঠিকানা হবে হাবিয়া।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxvii{আপনি জানেন তা কি?\qt@no{(10)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxviii{প্রজ্জ্বলিত অগ্নি!\qt@no{(11)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxix{\basmalahbn প্রাচুর্যের লালসা তোমাদেরকে গাফেল রাখে,\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxx{এমনকি, তোমরা কবরস্থানে পৌছে যাও।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxxi{এটা কখনও উচিত নয়। তোমরা সত্ত্বরই জেনে নেবে।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxxii{অতঃপর এটা কখনও উচিত নয়। তোমরা সত্ত্বরই জেনে নেবে।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxxiii{কখনই নয়; যদি তোমরা নিশ্চিত জানতে।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxxiv{তোমরা অবশ্যই জাহান্নাম দেখবে,\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxxv{অতঃপর তোমরা তা অবশ্যই দেখবে দিব্য প্রত্যয়ে,\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxxvi{এরপর অবশ্যই সেদিন তোমরা নেয়ামত সম্পর্কে জিজ্ঞাসিত হবে।\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxxvii{\basmalahbn কসম যুগের (সময়ের),\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxxviii{নিশ্চয় মানুষ ক্ষতিগ্রস্ত;\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxxix{কিন্তু তারা নয়, যারা বিশ্বাস স্থাপন করে ও সৎকর্ম করে এবং পরস্পরকে তাকীদ করে সত্যের এবং তাকীদ করে সবরের।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxxx{\basmalahbn প্রত্যেক পশ্চাতে ও সম্মুখে পরনিন্দাকারীর দুর্ভোগ,\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxxxi{যে অর্থ সঞ্চিত করে ও গণনা করে\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxxxii{সে মনে করে যে, তার অর্থ চিরকাল তার সাথে থাকবে!\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxxxiii{কখনও না, সে অবশ্যই নিক্ষিপ্ত হবে পিষ্টকারীর মধ্যে।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxxxiv{আপনি কি জানেন, পিষ্টকারী কি?\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxxxv{এটা আল্লাহর প্রজ্জ্বলিত অগ্নি,\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxxxvi{যা হৃদয় পর্যন্ত পৌছবে।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxxxvii{এতে তাদেরকে বেঁধে দেয়া হবে,\qt@no{(8)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxxxviii{লম্বা লম্বা খুঁটিতে।\qt@no{(9)}}
\qt@newcmd\qurantrans@bn@mmmmmmclxxxix{\basmalahbn আপনি কি দেখেননি আপনার পালনকর্তা হস্তীবাহিনীর সাথে কিরূপ ব্যবহার করেছেন?\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxc{তিনি কি তাদের চক্রান্ত নস্যাৎ করে দেননি?\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxci{তিনি তাদের উপর প্রেরণ করেছেন ঝাঁকে ঝাঁকে পাখী,\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxcii{যারা তাদের উপর পাথরের কংকর নিক্ষেপ করছিল।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxciii{অতঃপর তিনি তাদেরকে ভক্ষিত তৃণসদৃশ করে দেন।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxciv{\basmalahbn কোরাইশের আসক্তির কারণে,\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxcv{আসক্তির কারণে তাদের শীত ও গ্রীষ্মকালীন সফরের।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxcvi{অতএব তারা যেন এবাদত করে এই ঘরের পালনকর্তার\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxcvii{যিনি তাদেরকে ক্ষুধায় আহার দিয়েছেন এবং যুদ্ধভীতি থেকে তাদেরকে নিরাপদ করেছেন।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxcviii{\basmalahbn আপনি কি দেখেছেন তাকে, যে বিচারদিবসকে মিথ্যা বলে?\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmmcxcix{সে সেই ব্যক্তি, যে এতীমকে গলা ধাক্কা দেয়\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmmcc{এবং মিসকীনকে অন্ন দিতে উৎসাহিত করে না।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmmcci{অতএব দুর্ভোগ সেসব নামাযীর,\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmmccii{যারা তাদের নামায সম্বন্ধে বে-খবর;\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmmcciii{যারা তা লোক-দেখানোর জন্য করে\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmmcciv{এবং নিত্য ব্যবহার্য্য বস্তু অন্যকে দেয় না।\qt@no{(7)}}
\qt@newcmd\qurantrans@bn@mmmmmmccv{\basmalahbn নিশ্চয় আমি আপনাকে কাওসার দান করেছি।\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmmccvi{অতএব আপনার পালনকর্তার উদ্দেশ্যে নামায পড়ুন এবং কোরবানী করুন।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmmccvii{যে আপনার শত্রু, সেই তো লেজকাটা, নির্বংশ।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmmccviii{\basmalahbn বলুন, হে কাফেরকূল,\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmmccix{আমি এবাদত করিনা, তোমরা যার এবাদত কর।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmmccx{এবং তোমরাও এবাদতকারী নও, যার এবাদত আমি করি\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmmccxi{এবং আমি এবাদতকারী নই, যার এবাদত তোমরা কর।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmmccxii{তোমরা এবাদতকারী নও, যার এবাদত আমি করি।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmmccxiii{তোমাদের কর্ম ও কর্মফল তোমাদের জন্যে এবং আমার কর্ম ও কর্মফল আমার জন্যে।\qt@no{(6)}}
\qt@newcmd\qurantrans@bn@mmmmmmccxiv{\basmalahbn যখন আসবে আল্লাহর সাহায্য ও বিজয়\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmmccxv{এবং আপনি মানুষকে দলে দলে আল্লাহর দ্বীনে প্রবেশ করতে দেখবেন,\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmmccxvi{তখন আপনি আপনার পালনকর্তার পবিত্রতা বর্ণনা করুন এবং তাঁর কাছে ক্ষমা প্রার্থনা করুন। নিশ্চয় তিনি ক্ষমাকারী।\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmmccxvii{\basmalahbn আবু লাহাবের হস্তদ্বয় ধ্বংস হোক এবং ধ্বংস হোক সে নিজে,\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmmccxviii{কোন কাজে আসেনি তার ধন-সম্পদ ও যা সে উপার্জন করেছে।\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmmccxix{সত্বরই সে প্রবেশ করবে লেলিহান অগ্নিতে\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmmccxx{এবং তার স্ত্রীও-যে ইন্ধন বহন করে,\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmmccxxi{তার গলদেশে খর্জুরের রশি নিয়ে।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmmccxxii{\basmalahbn বলুন, তিনি আল্লাহ, এক,\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmmccxxiii{আল্লাহ অমুখাপেক্ষী,\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmmccxxiv{তিনি কাউকে জন্ম দেননি এবং কেউ তাকে জন্ম দেয়নি\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmmccxxv{এবং তার সমতুল্য কেউ নেই।\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmmccxxvi{\basmalahbn বলুন, আমি আশ্রয় গ্রহণ করছি প্রভাতের পালনকর্তার,\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmmccxxvii{তিনি যা সৃষ্টি করেছেন, তার অনিষ্ট থেকে,\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmmccxxviii{অন্ধকার রাত্রির অনিষ্ট থেকে, যখন তা সমাগত হয়,\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmmccxxix{গ্রন্থিতে ফুঁৎকার দিয়ে জাদুকারিনীদের অনিষ্ট থেকে\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmmccxxx{এবং হিংসুকের অনিষ্ট থেকে যখন সে হিংসা করে।\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmmccxxxi{\basmalahbn বলুন, আমি আশ্রয় গ্রহণ করিতেছি মানুষের পালনকর্তার,\qt@no{(1)}}
\qt@newcmd\qurantrans@bn@mmmmmmccxxxii{মানুষের অধিপতির,\qt@no{(2)}}
\qt@newcmd\qurantrans@bn@mmmmmmccxxxiii{মানুষের মা’বুদের\qt@no{(3)}}
\qt@newcmd\qurantrans@bn@mmmmmmccxxxiv{তার অনিষ্ট থেকে, যে কুমন্ত্রণা দেয় ও আত্নগোপন করে,\qt@no{(4)}}
\qt@newcmd\qurantrans@bn@mmmmmmccxxxv{যে কুমন্ত্রণা দেয় মানুষের অন্তরে\qt@no{(5)}}
\qt@newcmd\qurantrans@bn@mmmmmmccxxxvi{জ্বিনের মধ্য থেকে অথবা মানুষের মধ্য থেকে।\qt@no{(6)}}
%% End of file `qurantext-bnii.translation.def'.
