\qt@newcmd\qurantrans@ur@i{اللہ کے نام سے شروع جو بہت مہربان رحمت والا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@ii{سب خوبیاں اللہ کو جو مالک سارے جہان والوں کا،\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@iii{بہت مہربان رحمت والا،\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@iv{روز جزا کا مالک،\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@v{ہم تجھی کو پوجیں اور تجھی سے مدد چاہیں،\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@vi{ہم کو سیدھا راستہ چلا،\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@vii{راستہ ان کا جن پر تو نے احسان کیا، نہ ان کا جن پر غضب ہوا اور نہ بہکے ہوؤں کا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@viii{\basmalahur الم\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@ix{وہ بلند رتبہ کتاب (قرآن) کوئی شک کی جگہ نہیں، اس میں ہدایت ہے ڈر والوں کو\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@x{وہ جو بے دیکھے ایمان لائیں اور نماز قائم رکھیں اور ہماری دی ہوئی روزی میں سے ہماری میں اٹھائیں-\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@xi{اور وہ کہ ایمان لائیں اس پر جو اے محبوب تمہاری طرف اترا اور جو تم سے پہلے اترا اور آخرت پر یقین رکھیں،\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@xii{وہی لوگ اپنے رب کی طرف سے ہدایت پر ہیں اور وہی مراد کو پہنچنے والے۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@xiii{بیشک وہ جن کی قسمت میں کفر ہے ا نہیں برابر ہے، چاہے تم انہیں ڈراؤ، یا نہ ڈراؤ، وہ ایمان لانے کے نہیں۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@xiv{اللہ نے ان کے دلوں پر اور کانوں پر مہر کردی اور ان کی آنکھوں پر گھٹاٹوپ ہے، اور ان کے لئے بڑا عذاب،\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@xv{اور کچھ لوگ کہتے ہیں کہ ہم اللہ اور پچھلے دن پر ایمان لائے اور وہ ایمان والے نہیں،\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@xvi{فریب دیا چاہتے ہیں اللہ اور ایمان والوں کو اور حقیقت میں فریب نہیں دیتے مگر اپنی جانوں کو اور انہیں شعور نہیں۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@xvii{ان کے دلوں میں بیماری ہے تو اللہ نے ان کی بیماری اور بڑھائی اور ان کے لئے دردناک عذاب ہے، بدلا ان کے جھوٹ کا -\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@xviii{اوران سے کہا جائے زمین میں فساد نہ کرو، تو کہتے ہیں ہم تو سنوارنے والے ہیں،\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@xix{سنتا ہے وہی فسادی ہیں مگر انہیں شعور نہیں،\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@xx{اور جب ان سے کہا جائے ایمان لاؤ جیسے اور لوگ ایمان لائے تو کہیں کیا ہم احمقوں کی طرح ایمان لے آئیں سنتا ہے وہی احمق ہیں مگر جانتے نہیں -\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@xxi{اور جب ایمان والوں سے ملیں تو کہیں ہم ایمان لائے اور جب اپنے شیطانوں کے پاس اکیلے ہوں تو کہیں ہم تمہارے ساتھ ہیں، ہم تو یونہی ہنسی کرتے ہیں-\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@xxii{اللہ ان سے استہزاء فرماتا ہے (جیسا کہ اس کی شان کے لائق ہے) اور انہیں ڈھیل دیتا ہے کہ اپنی سرکشی میں بھٹکتے رہیں۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@xxiii{یہ لوگ جنہوں نے ہدایت کے بدلے گمراہی خریدی تو ان کا سودا کچھ نفع نہ لایا اور وہ سودے کی راہ جانتے ہی نہ تھے -\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@xxiv{ان کی کہاوت اس طرح ہے جس نے آگ روشن کی۔ تو جب اس سے آس پاس سب جگمگا اٹھا اللہ ان کا نور لے گیا اور انہیں اندھیریوں میں چھوڑ دیا کہ کچھ نہیں سوجھتا -\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@xxv{بہرے، گونگے، ندھے تو وہ پھر آ نے والے نہیں،\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@xxvi{یا جیسے آسمان سے اترتا پانی کہ ان میں اندھیریاں ہیں اور گرج اور چمک اپنے کانوں میں انگلیاں ٹھونس رہے ہیں، کڑک کے سبب، موت کے ڈر سے اور اللہ کافروں کو، گھیرے ہوئے ہے -\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@xxvii{بجلی یوں معلوم ہوتی ہے کہ ان کی نگاہیں اچک لے جائے گی جب کچھ چمک ہوئی اس میں چلنے لگے اور جب اندھیرا ہوا کھڑے رہ گئے اور اللہ چاہتا تو ان کے کان اور آنکھیں لے جاتا بیشک اللہ سب کچھ کرسکتا ہے -\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@xxviii{اے لوگو! اپنے رب کو پوجو جس نے تمہیں اور تم سے اگلوں کو پیدا کیا، یہ امید کرتے ہوئے، کہ تمہیں پرہیزگاری ملے -\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@xxix{جس نے تمہارے لئے زمین کو بچھونا اور آسمان کو عمارت بنایا اور آسمان سے پانی اتارا تو اس سے کچھ پھل نکالے تمہارے کھانے کو۔ تو اللہ کے لئے جان بوجھ کر برابر والے نہ ٹھہراؤ\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@xxx{اور اگر تمہیں کچھ شک ہو اس میں جو ہم نے اپنے (اس خاص) بندے پر اتارا تو اس جیسی ایک سورت تو لے آؤ اور اللہ کے سوا، اپنے سب حمایتیوں کو بلالو، اگر تم سچے ہو۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@xxxi{پھر اگر نہ لا سکو اور ہم فرمائے دیتے ہیں کہ ہر گز نہ لا سکو گے تو ڈرو اس آگ سے، جس کا ایندھن آدمی اور پتھر ہیں تیار رکھی ہے کافروں کے لئے -\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@xxxii{اور خوشخبری دے، انہیں جو ایمان لائے اور اچھے کام کئے، کہ ان کے لئے باغ ہیں، جن کے نیچے نہریں رواں جب انہیں ان باغوں سے کوئی پھل کھانے کو دیا جائے گا، (صورت دیکھ کر) کہیں گے، یہ تو وہی رزق ہے جو ہمیں پہلے ملا تھا اور وہ (صورت میں) ملتا جلتا انہیں دیا گیا اور ان کے لئے ان باغوں میں ستھری بیبیاں ہیں اور وہ ان میں ہمیشہ رہیں گے -\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@xxxiii{بیشک اللہ اس سے حیا نہیں فرماتا کہ مثال سمجھانے کو کیسی ہی چیز کا ذکر فرمائے مچھر ہو یا اس سے بڑھ کر تو وہ جو ایمان لائے، وہ تو جانتے ہیں کہ یہ ان کے رب کی طرف سے حق ہے رہے کافر، وہ کہتے ہیں ایسی کہاوت میں اللہ کا کیا مقصُود ہے، اللہ بہتیروں کو اس سے گمراہ کرتا ہے اور بہتیروں کو ہدایت فرماتا ہے اور اس سے انہیں گمراہ کرتا ہے جو بے حکم ہیں-\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@xxxiv{وہ جو اللہ کے عہد کو توڑ دیتے ہیں پکا ہونے کے بعد، اور کاٹتے ہیں اس چیز کو جس کے جوڑنے کا خدا نے حکم دیا ہے اور زمین میں فساد پھیلاتے ہیں وہی نقصان میں ہیں۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@xxxv{بھلا تم کیونکر خدا کے منکر ہو گے، حالانکہ تم مردہ تھے اس نے تمہیں جِلایا پھر تمہیں مارے گا پھر تمہیں جِلائے گا پھر اسی کی طرف پلٹ کر جاؤ گے -\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@xxxvi{وہی ہے جس نے تمہارے لئے بنایا جو کچھ زمین میں ہے۔ پھر آسمان کی طرف استوا (قصد) فرمایا تو ٹھیک سات آسمان بنائے وہ سب کچھ جانتا ہے -\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@xxxvii{اور یاد کرو جب تمہارے رب نے فرشتوں سے فرمایا، میں زمین میں اپنا نائب بنانے والا ہوں بولے کیا ایسے کو نائب کرے گا جو اس میں فساد پھیلائے گا اور خونریزیاں کرے گا اور ہم تجھے سراہتے ہوئے، تیری تسبیح کرتے اور تیری پاکی بولتے ہیں، فرمایا مجھے معلوم ہے جو تم نہیں جانتے-\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@xxxviii{اور اللہ تعالیٰ نے آدم کو تمام (اشیاء کے) نام سکھائے پھر سب (اشیاء) کو ملائکہ پر پیش کرکے فرمایا سچے ہو تو ان کے نام تو بتاؤ\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@xxxix{بولے پاکی ہے تجھے ہمیں کچھ علم نہیں مگر جتنا تو نے ہمیں سکھایا بے شک تو ہی علم و حکمت والا ہے -\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@xl{فرمایا اے آدم بتادے انہیں سب (اشیاء کے) نام جب اس نے (یعنی آدم نے) انہیں سب کے نام بتادیئے فرمایا میں نہ کہتا تھا کہ میں جانتا ہوں آسمانوں اور زمین کی سب چھپی چیزیں اور میں جانتا ہوں جو کچھ تم ظاہر کرتے اور جو کچھ تم چھپاتے ہو -\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@xli{اور (یاد کرو) جب ہم نے فرشتوں کو حکم دیا کہ آدم کو سجدہ کو تو سب نے سجدہ کیا سوائے ابلیس کے کہ منکر ہوا اور غرور کیا اور کافر ہوگیا-\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@xlii{اور ہم نے فرمایا اے آدم تو اور تیری بیوی جنت میں رہو اور کھاؤ اس میں سے بے روک ٹوک جہاں تمہارا جی چاہے مگر اس پیڑ کے پاس نہ جانا کہ حد سے بڑھنے والوں میں ہوجاؤ گے-\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@xliii{تو شیطان نے اس سے (یعنی جنت سے) انہیں لغزش دی اور جہاں رہتے تھے وہاں سے انہیں الگ کردیا اور ہم نے فرمایا نیچے اترو آپس میں ایک تمہارا دوسرے کا دشمن اور تمہیں ایک وقت تک زمین میں ٹھہرنا اور برتنا ہے -\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@xliv{پھر سیکھ لیے آدم نے اپنے رب سے کچھ کلمے تو اللہ نے اس کی توبہ قبول کی بیشک وہی ہے بہت توبہ قبول کرنے والا مہربان۔\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@xlv{ہم نے فرمایا تم سب جنت سے اتر جاؤ پھر اگر تمہارے پاس میری طرف سے کوئی ہدایت آئے تو جو میری ہدایت کا پیرو ہوا اسے نہ کوئی اندیشہ نہ کچھ غم -\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@xlvi{اور وہ جو کفر کریں گے اور میری آیتیں جھٹلائیں گے وہ دوزخ والے ہیں، ان کو ہمیشہ اس میں رہنا -\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@xlvii{اے یعقوب کی اولاد یاد کرو میرا وہ احسان جو میں نے تم پر کیا اور میرا عہد پورا کرو میں تمہارا عہد پورا کروں گا اور خاص میرا ہی ڈر رکھو -\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@xlviii{اور ایمان لاؤ اس پر جو میں نے اتارا اس کی تصدیق کرتا ہوا جو تمہارے ساتھ ہے اور سب سے پہلے اس کے منکر نہ بنو اور میری آیتوں کے بدلے تھوڑے دام نہ لو اور مجھی سے ڈرو -\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@xlix{اور حق سے باطل کو نہ ملاؤ اور دیدہ و دانستہ حق نہ چھپاؤ -\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@l{اور نماز قائم رکھو اور زکوٰة دو اور رکوع کرنے والوں کے ساتھ رکوع کرو-\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@li{کیا لوگوں کو بھلائی کا حکم دیتے ہو اور اپنی جانوں کو بھولتے ہو حالانکہ تم کتاب پڑھتے ہو تو کیا تمہیں عقل نہیں -\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@lii{اور صبر اور نماز سے مدد چاہو اور بیشک نماز ضرور بھاری ہے مگر ان پر (نہیں) جو دل سے میری طرف جھکتے ہیں -\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@liii{جنہیں یقین ہے کہ انہیں اپنے رب سے ملنا ہے اور اسی کی طرف پھرنا-\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@liv{اے اولاد یعقوب یاد کرو میرا وہ احسان جو میں نے تم پر کیا اور یہ کہ اس سارے زمانہ پر تمہیں بڑائی دی-\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@lv{اور ڈرو اس دن سے جس دن کوئی جان دوسرے کا بدلہ نہ ہوسکے گی اور نہ (کافر کے لئے) کوئی سفارش مانی جائے اور نہ کچھ لے کر (اس کی) جان چھوڑی جائے اور نہ ان کی مدد ہو-\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@lvi{اور (یاد کرو) جب ہم نے تم کو فرعون والوں سے نجات بخشی کہ وہ تم پر برا عذاب کرتے تھے تمہارے بیٹوں کو ذبح کرتے اور تمہاری بیٹیوں کو زندہ رکھتے اور اس میں تمہارے رب کی طرف سے بڑی بلا تھی (یا بڑا انعام)\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@lvii{اور جب ہم نے تمہارے لئے دریا پھاڑ دیا تو تمہیں بچالیا اور فرعون والوں کو تمہاری آنکھوں کے سامنے ڈبو دیا -\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@lviii{اور جب ہم نے موسیٰ سے چالیس رات کا وعدہ فرمایا پھر اس کے پیچھے تم نے بچھڑے کی پوجا شروع کردی اور تم ظالم تھے -\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@lix{پھر اس کے بعد ہم نے تمہیں معافی دی کہ کہیں تم احسان مانو -\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@lx{اور جب ہم نے موسیٰ کو کتاب عطا کی اور حق و باطل میں تمیز کردینا کہ کہیں تم راہ آؤ -\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@lxi{اور جب موسیٰ نے اپنی قوم سے کہا اے میری قوم تم نے بچھڑا بناکر اپنی جانوں پر ظلم کیا تو اپنے پیدا کرنے والے کی طرف رجوع لاؤ تو آپس میں ایک دوسرے کو قتل کردو یہ تمہارے پیدا کرنے والے کے نزدیک تمہارے لیے بہتر ہے تو اس نے تمہاری توبہ قبول کی بیشک وہی ہے بہت توبہ قبول کرنے والا مہربان -\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@lxii{اور جب تم نے کہا اے موسیٰ ہم ہرگز تمہارا یقین نہ لائیں گے جب تک اعلانیہ خدا کو نہ دیکھ لیں تو تمہیں کڑک نے آلیا اور تم دیکھ رہے تھے ۔\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@lxiii{پھر مرے پیچھے ہم نے تمہیں زندہ کیا کہ کہیں تم احسان مانو-\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@lxiv{اور ہم نے ابر کو تمہارا سائبان کیا اور تم پر من اور سلویٰ اتارا کھاؤ ہماری دی ہوئی ستھری چیزیں اور انہوں نے کچھ ہمارا نہ بگاڑا ہاں اپنی ہی جانوں کو بگاڑ کرتے تھے- اور جب ہم نے فرمایا اس بستی میں جاؤ -\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@lxv{پھر اس میں جہاں چاہو بے روک ٹوک کھاؤ اور دروازہ میں سجدہ کرتے داخل ہو اور کہو ہمارے گناہ معاف ہوں ہم تمہاری خطائیں بخش دیں گے اور قریب ہے کہ نیکی والوں کو اور زیادہ دیں-\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@lxvi{تو ظالموں نے اور بات بدل دی جو فرمائی گئی تھی اس کے سوا تو ہم نے آسمان سے ان پر عذاب اتارا بدلہ ان کی بے حکمی کا۔\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@lxvii{اور جب موسیٰ نے اپنی قوم کے لئے پانی مانگا تو ہم نے فرمایا اس پتھر پر اپنا عصا مارو فوراً اس میں سے بارہ چشمے بہ نکلے ہر گروہ نے اپنا گھاٹ پہچان لیا کھاؤ اور پیؤ خدا کا دیا اور زمین میں فساد اٹھاتے نہ پھرو\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@lxviii{اور جب تم نے کہا اے موسیٰ ہم سے تو ایک کھانے پر ہرگز صبر نہ ہوگا تو آپ اپنے رب سے دعا کیجئے کہ زمین کی اگائی ہوئی چیزیں ہمارے لئے نکالے کچھ ساگ اور ککڑی اور گیہوں اور مسور اور پیاز فرمایا کیا ادنیٰ چیز کو بہتر کے بدلے مانگتے ہو اچھا مصر یا کسی شہر میں اترو وہاں تمہیں ملے گا جو تم نے مانگا اور ان پر مقرر کردی گئی خواری اور ناداری اور خدا کے غضب میں لوٹے یہ بدلہ تھا اس کا کہ وہ اللہ کی آیتوں کا انکار کرتے اور انبیاء کو ناحق شہید کرتے یہ بدلہ تھا ان کی نافرمانیوں اور حد سے بڑھنے کا-\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@lxix{بیشک ایمان والے نیز یہودیوں اور نصرانیوں اور ستارہ پرستوں میں سے وہ کہ سچے دل سے اللہ اور پچھلے دن پر ایمان لائیں اور نیک کام کریں ان کا ثواب ان کے رب کے پاس ہے اور نہ انہیں کچھ اندیشہ ہو اور نہ کچھ غم\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@lxx{اور جب ہم نے تم سے عہد لیا اور تم پر طور کو اونچا کیا لو جو کچھ ہم تم کو دیتے ہیں زور سے اور اس کے مضمون یاد کرو اس امید پر کہ تمہیں پرہیزگاری ملے-\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@lxxi{پھر اس کے بعد تم پھر گئے تو اگر اللہ کا فضل اور اس کی رحمت تم پر نہ ہوتی تو تم ٹوٹے والوں میں ہو جاتے -\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@lxxii{اور بیشک ضرور تمہیں معلوم ہے تم میں کے وہ جنہوں نے ہفتہ میں سرکشی کی تو ہم نے ان سے فرمایا کہ ہوجاؤ بندر دھتکارے ہوئے -\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@lxxiii{تو ہم نے (اس بستی کا) یہ واقعہ اس کے آگے اور پیچھے والوں کے لیے عبرت کردیا اور پرہیزگاروں کے لیے نصیحت-\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@lxxiv{اور جب موسیٰ نے اپنی قوم سے فرمایا خدا تمہیں حکم دیتا ہے کہ ایک گائے ذبح کرو بولے کہ آپ ہمیں مسخرہ بناتے ہیں فرمایا خدا کی پناہ کہ میں جاہلوں سے ہوں-\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@lxxv{بولے اپنے رب سے دعا کیجئے کہ وہ ہمیں بتادے گائے کیسی کہا وہ فرماتا ہے کہ وہ ایک گائے ہے نہ بوڑھی اور نہ اَدسر بلکہ ان دونوں کے بیچ میں تو کرو جس کا تمہیں حکم ہوتا ہے،\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@lxxvi{بولے اپنے رب سے دعا کیجئے ہمیں بتادے اس کا رنگ کیا ہے کہا وہ فرماتا ہے وہ ایک پیلی گائے ہے جس کی رنگت ڈہڈہاتی دیکھنے والوں کو خوشی دیتی،\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@lxxvii{بولے اپنے رب سے دعا کیجئے کہ ہمارے لیے صاف بیان کردے وہ گائے کیسی ہے بیشک گائیوں میں ہم کو شبہ پڑگیا اور اللہ چاہے تو ہم راہ پا جائیں گے -\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@lxxviii{کہا وہ فرماتا ہے کہ وہ ایک گائے ہے جس سے خدمت نہیں لی جاتی کہ زمین جوتے اور نہ کھیتی کو پانی دے بے عیب ہے جس میں کوئی داغ نہیں بولے اب آپ ٹھیک بات لائے تو اسے ذبح کیا اور (ذبح) کرتے معلوم نہ ہوتے تھے\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@lxxix{اور جب تم نے ایک خون کیا تو ایک دوسرے پر اس کی تہمت ڈالنے لگے اور اللہ کو ظاہر کرنا تھا جو تم چھپاتے تھے،\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@lxxx{تو ہم نے فرمایا اس مقتول کو اس گائے کا ایک ٹکڑا مارو اللہ یونہی مرُدے جلائے گا۔ اور تمہیں اپنی نشانیاں دکھاتا ہے کہ کہیں تمہیں عقل ہو\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@lxxxi{پھر اس کے بعد تمہارے دل سخت ہوگئے تو وہ پتھروں کی مثل ہیں بلکہ ان سے بھی زیادہ کرّے اور پتھروں میں تو کچھ وہ ہیں جن سے ندیاں بہہ نکلتی ہیں اور کچھ وہ ہیں جو پھٹ جاتے ہیں تو ان سے پانی نکلتا ہے اور کچھ وہ ہیں جو اللہ کے ڈر سے گر پڑتے ہیں اور اللہ تمہارے کوتکوں سے بے خبر نہیں،\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@lxxxii{تو اے مسلمانو! کیا تمہیں یہ طمع ہے کہ یہ (یہودی) تمہارا یقین لائیں گے اور ان میں کا تو ایک گروہ وه تھا کہ اللہ کا کلام سنتے پھر سمجھنے کے بعد اسے دانستہ بدل دیتے، ف۱۲۶)\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@lxxxiii{اور جب مسلمانوں سے ملیں تو کہیں ہم ایمان لائے اور جب آپس میں اکیلے ہوں تو کہیں وہ علم جو اللہ نے تم پر کھولا مسلمانوں سے بیان کیے دیتے ہو کہ اس سے تمہارے رب کے یہاں تمہیں پر حجت لائیں کیا تمہیں عقل نہیں -\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@lxxxiv{کیا تم نہیں جانتے کہ اللہ جانتا ہے جو کچھ وہ چھپاتے ہیں اور جو کچھ ظاہر کرتے ہیں-\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@lxxxv{اور ان میں کچھ اَن پڑھ ہیں کہ جو کتاب کو نہیں جانتے مگر زبانی پڑھ لینا یا کچھ اپنی من گھڑت اور وہ نرے گمان میں ہیں -\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@lxxxvi{تو خرابی ہے ان کے لئے جو کتاب اپنے ہاتھ سے لکھیں پھر کہہ دیں یہ خدا کے پاس سے ہے کہ اس کے عوض تھوڑے دام حاصل کریں تو خرابی ہے ان کے لئے ان کے ہاتھوں کے لکھے سے اور خرابی ان کے لئے اس کمائی سے-\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@lxxxvii{اور بولے ہمیں تو آگ نہ چھوئے گی مگر گنتی کے دن تم فرمادو کیا خدا سے تم نے کوئی عہد لے رکھا ہے جب تو اللہ ہرگز اپنا عہد خلاف نہ کرے گا یا خدا پر وہ بات کہتے ہو جس کا تمہیں علم نہیں -\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@lxxxviii{ہاں کیوں نہیں جو گناہ کمائے اور اس کی خطا اسے گھیر لے وہ دوزخ والوں میں ہے انہیں ہمیشہ اس میں رہنا -\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@lxxxix{اور جو ایمان لائے اور اچھے کام کیے وہ جنت والے ہیں انہیں ہمیشہ اس میں رہنا -\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@xc{اور جب ہم نے بنی اسرائیل سے عہد لیا کہ اللہ کے سوا کسی کو نہ پوجو اور ماں باپ کے ساتھ بھلائی کرو، اور رشتہ داروں اور یتیموں اور مسکینوں سے اور لوگوں سے اچھی بات کہو اور نماز قائم رکھو اور زکوٰة دو پھر تم پھِر گئے مگر تم میں کے تھوڑے اور تم رد گردان ہو-\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@xci{اور جب ہم نے تم سے عہد لیا کہ اپنوں کا خون نہ کرنا اور اپنوں کو اپنی بستیوں سے نہ نکالنا پھر تم نے اس کا اقرار کیا اور تم گواہ ہو-\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@xcii{پھر یہ جو تم ہو اپنوں کو قتل کرنے لگے اور اپنے میں سے ایک گروہ کو ان کے وطن سے نکالتے ہو ان پر مدد دیتے ہو (ان کے مخالف کو) گناہ اور زیادتی میں اور اگر وہ قیدی ہو کر تمہارے پاس آئیں تو بدلا دے کر چھڑا لیتے ہو اور ان کا نکالنا تم پر حرام ہے تو کیا خدا کے کچھ حکموں پر ایمان لاتے ہو اور کچھ سے انکار کرتے ہو تو جو تم میں ایسا کرے اس کا بدلہ کیا ہے مگر یہ کہ دنیا میں رسوا ہو اور قیامت میں سخت تر عذاب کی طرف پھیرے جائیں گے اور اللہ تمہارے کوتکوں سے بے خبر نہیں -\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@xciii{یہ ہیں وہ لوگ جنہوں نے آخرت کے بدلے دنیا کی زندگی مول لی تو نہ ان پر سے عذاب ہلکا ہو اور نہ ان کی مدد کی جائے -\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@xciv{اور بے شک ہم نے موسیٰ کو کتاب عطا کی اور اس کے بعد پے در پے رسول بھیجے اور ہم نے عیسیٰ بن مریم کو کھیلی نشانیاں عطا فرمائیں اور پاک روح سے اس کی مدد کی تو کیا جب تمہارے پاس کوئی رسول وہ لے کر آئے جو تمہارے نفس کی خواہش نہیں تکبر کرتے ہو تو ان (انبیاء) میں ایک گروہ کو تم جھٹلاتے ہو اور ایک گروہ کو شہید کرتے ہو -\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@xcv{اور یہودی بولے ہمارے دلوں پر پردے پڑے ہیں بلکہ اللہ نے ان پر لعنت کی ان کے کفر کے سبب تو ان میں تھوڑے ایمان لاتے ہیں-\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@xcvi{اور جب ان کے پاس اللہ کی وہ کتاب (قرآن) آئی جو ان کے ساتھ والی کتاب (توریت) کی تصدیق فرماتی ہے اور اس سے پہلے وہ اسی نبی کے وسیلہ سے کافروں پر فتح مانگتے تھے تو جب تشریف لایا انکے پاس وہ جانا پہچانا اس سے منکر ہو بیٹھے تو اللہ کی لعنت منکروں پر -\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@xcvii{کس برے مولوں انہوں نے اپنی جانوں کو خریدا کہ اللہ کے اتارے سے منکر ہوں اس کی جلن سے کہ اللہ اپنے فضل سے اپنے جس بندے پر چاہے وحی اتارلے تو غضب پر غضب کے سزاوار ہوئے اور کافروں کے لیے ذلت کا عذاب ہے -\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@xcviii{اور جب ان سے کہا جائے کہ اللہ کے اتارے پر ایمان لاؤ تو کہتے ہیں وہ جو ہم پر اترا اس پر ایمان لاتے ہیں اور باقی سے منکر ہوتے ہیں حالانکہ وہ حق ہے ان کے پاس والے کی تصدیق فرماتا ہوا تم فرماؤ کہ پھر اگلے انبیاء کو کیوں شہید کیا اگر تمہیں اپنی کتاب پر ایمان تھا -\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@xcix{اور بیشک تمہارے پاس موسیٰ کھلی نشانیاں لے کر تشریف لایا پھر تم نے اس کے بعد بچھڑے کو معبود بنالیا اور تم ظالم تھے-\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@c{اور (یاد کرو) جب ہم نے تم سے پیمان لیا او ر کوہ ِ طور کو تمہارے سروں پر بلند کیا، لو جو ہم تمہیں دیتے ہیں زور سے اور سنو بولے ہم نے سنا اور نہ مانا اور ان کے دلوں میں بچھڑا رچ رہا تھا ان کے کفر کے سبب تم فرمادو کیا برا حکم دیتا ہے تم کو تمہارا ایمان اگر ایمان رکھتے ہو-\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@ci{تم فرماؤ اگر پچھلا گھر اللہ کے نزدیک خالص تمہارے لئے ہو، نہ اوروں کے لئے تو بھلا موت کی آرزو تو کرو اگر سچے ہو-\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@cii{اور ہرگز کبھی اس کی آرزو نہ کریں گے ان بداعمالیوں کے سبب جو آگے کرچکے اور اللہ خوب جانتا ہے ظالموں کو-\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@ciii{اور بیشک تم ضرور انہیں پاؤ گے کہ سب لوگوں سے زیادہ جینے کی ہوس رکھتے ہیں اور مشرکوں سے ایک کو تمنا ہے کہ کہیں ہزار برس جئے اور وہ اسے عذاب سے دور نہ کرے گا اتنی عمر دیا جانا اور اللہ ان کے کوتک دیکھ رہا ہے،\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@civ{تم فرمادو جو کوئی جبریل کا دشمن ہو تو اس (جبریل) نے تو تمہارے دل پر اللہ کے حکم سے یہ قرآن اتارا اگلی کتابوں کی تصدیق فرماتا اور ہدایت و بشارت مسلمانوں کو-\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@cv{جو کوئی دشمن ہو اللہ اور اس کے فرشتوں اور اس کے رسولوں اور جبریل اور میکائیل کا تو اللہ دشمن ہے کافروں کا\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@cvi{اور بیشک ہم نے تمہاری طرف روشن آیتیں اتاریں اور ان کے منکر نہ ہوں گے مگر فاسق لوگ -\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@cvii{اور کیا جب کبھی کوئی عہد کرتے ہیں ان میں کا ایک فریق اسے پھینک دیتا ہے بلکہ ان میں بہتیروں کو ایمان نہیں -\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@cviii{اور جب ان کے پاس تشریف لایا اللہ کے یہاں سے ایک رسول ان کی کتابوں کی تصدیق فرماتا تو کتاب والوں سے ایک گروہ نے اللہ کی کتاب پیٹھ پیچھے پھینک دی گویا وہ کچھ علم ہی نہیں رکھتے -\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@cix{اور اس کے پیرو ہوئے جو شیطان پڑھا کرتے تھے سلطنت سلیمان کے زمانہ میں اور سلیمان نے کفر نہ کیا ہاں شیطان کافر ہوئے لوگوں کو جادو سکھاتے ہیں اور وہ (جادو) جو بابل میں دو فرشتوں ہاروت و ماروت پر اترا اور وہ دونوں کسی کو کچھ نہ سکھاتے جب تک یہ نہ کہہ لیتے کہ ہم تو نری آزمائش ہیں تو اپنا ایمان نہ کھو تو ان سے سیکھتے وہ جس سے جدائی ڈالیں مرد اور اس کی عورت میں اور اس سے ضرر نہیں پہنچا سکتے کسی کو مگر خدا کے حکم سے اور وہ سیکھتے ہیں جو انہیں نقصان دے گا نفع نہ دے گا اور بیشک ضرور انہیں معلوم ہے کہ جس نے یہ سودا لیا آخرت میں اس کا کچھ حصہ نہیں اور بیشک کیا بری چیز ہے وہ جس کے بدلے انہوں نے اپنی جانیں بیچیں کسی طرح انہیں علم ہوتا-\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@cx{اور اگر وہ ایمان لاتے اور پرہیزگاری کرتے تو اللہ کے یہاں کا ثواب بہت اچھا ہے کسی طرح انہیں علم ہوتا -\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@cxi{اے ایمان والو! راعنا نہ کہو اور یوں عرض کرو کہ حضور ہم پر نظر رکھیں اور پہلے ہی سے بغور سنو اور کافروں کے لئے دردناک عذاب ہے-\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@cxii{وہ جو کافر ہیں کتابی یا مشرک وہ نہیں چاہتے کہ تم پر کوئی بھلائی اترے تمہارے رب کے پاس سے اور اللہ اپنی رحمت سے خاص کرتا ہے جسے چاہے اور اللہ بڑے فضل والا ہے -\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@cxiii{جب کوئی آیت منسوخ فرمائیں یا بھلا دیں تو اس سے بہتر یا اس جیسی لے آئیں گے کیا تجھے خبر نہیں کہ اللہ سب کچھ کرسکتا ہے-\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@cxiv{کیا تجھے خبر نہیں کہ اللہ ہی کے لئے ہے آسمانوں اور زمین کی بادشاہی اور اللہ کے سوا تمہارا نہ کوئی حمایتی نہ مددگار،\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@cxv{کیا یہ چاہتے ہو کہ اپنے رسول سے ویسا سوال کرو جو موسیٰ سے پہلے ہوا تھا اور جو ایمان کے بدلے کفر لے وہ ٹھیک راستہ بہک گیا -\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@cxvi{بہت کتابیوں نے چاہا کاش تمہیں ایمان کے بعد کفر کی طرف پھیردیں اپنے دلوں کی جلن سے بعد اس کے کہ حق ان پر خوب ظاہر ہوچکا ہے تو تم چھوڑو اور درگزر کرو یہاں تک کہ اللہ اپنا حکم لائے بیشک اللہ ہر چیز پر قادر ہے -\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@cxvii{اور نماز قائم رکھو اور زکوٰة دو اور اپنی جانوں کے لئے جو بھلائی آگے بھیجو گے اسے اللہ کے یہاں پاؤ گے بیشک اللہ تمہارے کام دیکھ رہا ہے-\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@cxviii{اور اہل کتاب بولے، ہرگز جنت میں نہ جائے گا مگر وہ جو یہودی یا نصرانی ہو یہ ان کی خیال بندیاں ہیں تم فرماؤ لا ؤ اپنی دلیل اگر سچے ہو-\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@cxix{ہاں کیوں نہیں جس نے اپنا منہ جھکایا اللہ کے لئے اور وہ نیکو کار ہے تو اس کا نیگ اس کے رب کے پاس ہے اور انہیں کچھ اندیشہ ہو اور نہ کچھ غم-\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@cxx{اور یہودی بولے نصرانی کچھ نہیں اور نصرانی بولے یہودی کچھ نہیں حالانکہ وہ کتاب پڑھتے ہیں، اسی طرح جاہلوں نے ان کی سی بات کہی تو اللہ قیامت کے دن ان میں فیصلہ کردے گا جس بات میں جھگڑ رہے ہیں-\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@cxxi{اور اس سے بڑھ کر ظالم کون جو اللہ کی مسجدوں کو روکے ان میں نامِ خدا لئے جانے سے اور ان کی ویرانی میں کوشش کرے ان کو نہ پہنچتا تھا کہ مسجدوں میں جائیں مگر ڈرتے ہوئے ان کے لئے دنیا میں رسوائی ہے اور ان کے لئے آخرت میں بڑا عذاب -\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@cxxii{اور پورب و پچھم سب اللہ ہی کا ہے تو تم جدھر منہ کرو ادھر وجہ اللہ (خدا کی رحمت تمہاری طرف متوجہ) ہے بیشک اللہ وسعت والا علم والا ہے،\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@cxxiii{اور بولے خدا نے اپنے لیے اولاد رکھی پاکی ہے اسے بلکہ اسی کی مِلک ہے جو کچھ آسمانوں اور زمین میں ہے سب اس کے حضور گردن ڈالے ہیں،\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@cxxiv{نیا پیدا کرنے والا آسمانوں اور زمین کا اور جب کسی بات کا حکم فرمائے تو اس سے یہی فرماتا ہے کہ ہو جا وہ فورا ً ہوجاتی ہے-\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@cxxv{اور جاہل بولے اللہ ہم سے کیوں نہیں کلام کرتا یا ہمیں کوئی نشانی ملے ان سے اگلوں نے بھی ایسی ہی کہی ان کی سی بات اِن کے اُن کے دل ایک سے ہیں بیشک ہم نے نشانیاں کھول دیں یقین والوں کے لئے -\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@cxxvi{بیشک ہم نے تمہیں حق کے ساتھ بھیجا خوشخبری دیتا اور ڈر سناتا اور تم سے دوزخ والوں کا سوال نہ ہوگا -\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@cxxvii{اور ہرگز تم سے یہود اور نصاری ٰ راضی نہ ہوں گے جب تک تم ان کے دین کی پیروی نہ کرو تم فرمادو اللہ ہی کی ہدایت ہدایت ہے اور (اے سننے والے کسے باشد) اگر تو ان کی خواہشوں کا پیرو ہوا بعد اس کے کہ تجھے علم آچکا تو اللہ سے تیرا کوئی بچانے والا نہ ہوگا او ر نہ مددگار\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@cxxviii{جنہیں ہم نے کتاب دی ہے وہ جیسی چاہئے اس کی تلاوت کرتے ہیں وہی اس پر ایمان رکھتے ہیں اور جو اس کے منکر ہوں تو وہی زیاں کار ہیں -\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@cxxix{اے اولاد یعقوب یاد کرو میرا احسان جو میں نے تم پر کیا او ر وہ جو میں نے اس زمانہ کے سب لوگوں پر تمہیں بڑائی دی -\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@cxxx{اور ڈرو اس دن سے کہ کوئی جان دوسرے کا بدلہ نہ ہوگی اور نہ اس کو کچھ لے کر چھوڑیں اور نہ کافر کو کوئی سفارش نفع دے اور نہ ان کی مدد ہو -\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@cxxxi{اور جب ابراہیم کو اس کے رب نے کچھ باتوں سے آزمایا تو اس نے وہ پوری کر دکھائیں فرمایا میں تمہیں لوگوں کا پیشوا بنانے والا ہوں عرض کی اور میری اولاد سے فرمایا میرا عہد ظالموں کو نہیں پہنچتا-\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@cxxxii{اور (یاد کرو) جب ہم نے اس گھر کو لوگوں کے لئے مرجع اور امان بنایا اور ابراہیم کے کھڑے ہونے کی جگہ کو نماز کا مقام بناؤ اور ہم نے تاکید فرمائی ابراہیم و اسماعیل ؑ کو کہ میرا گھر خوب ستھرا کرو طواف کرنے والوں اور اعتکاف والوں اور رکوع و سجود والوں کے لئے -\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@cxxxiii{اور جب عرض کی ابراہیم ؑ نے کہ اے میرے رب اس شہر کو امان والا کردے اور اس کے رہنے والوں کو طرح طرح کے پھلوں سے روزی دے جو ان میں سے اللہ اور پچھلے دن پر ایمان لائیں فرمایا اور جو کافر ہوا تھوڑا برتنے کو اسے بھی دوں گا پھر اسے عذاب ِ دوزخ کی طرف مجبور کردوں گا اور بہت بری جگہ ہے پلٹنے کی-\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@cxxxiv{اور جب اٹھاتا تھا ابراہیم ؑ اس گھر کی نیویں اور اسمٰعیل ؑ یہ کہتے ہوئے اے رب ہمارے ہم سے قبول فرما بیشک تو ہی ہے سنتا جانتا،\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@cxxxv{اے رب ہمارے اور کر ہمیں تیرے حضور گردن رکھنے والا اور ہماری اولاد میں سے ایک امت تیری فرمانبردار اور ہمیں ہماری عبادت کے قاعدے بتا اور ہم پر اپنی رحمت کے ساتھ رجوع فرما بیشک تو ہی ہے بہت توبہ قبول کرنے والا مہربان۔\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@cxxxvi{اے رب ہمارے اور بھیج ان میں ایک رسول انہیں میں سے کہ ان پر تیری آیتیں تلاوت فرمائے اور انہیں تیری کتاب اور پختہ علم سکھائے اور انہیں خوب ستھرا فرمادے بیشک تو ہی ہے غالب حکمت والا-\qt@no{(129)}}%
\qt@newcmd\qurantrans@ur@cxxxvii{اور ابراہیم کے دین سے کون منہ پھیرے سوا اس کے جو دل کا احمق ہے اور بیشک ضرور ہم نے دنیا میں اسے چن لیا اور بیشک وہ آخرت میں ہمارے خاص قرب کی قابلیت والوں میں ہے -\qt@no{(130)}}%
\qt@newcmd\qurantrans@ur@cxxxviii{جبکہ اس سے اس کے رب نے فرمایا گردن رکھ عرض کی میں نے گردن رکھی اس کے لئے جو رب ہے سارے جہان کا-\qt@no{(131)}}%
\qt@newcmd\qurantrans@ur@cxxxix{اور اسی دین کی وصیت کی ابراہیم ؑ نے اپنے بیٹوں کو اور یعقوب نے کہ اے میرے بیٹو! بیشک اللہ نے یہ دین تمہارے لئے چن لیا تو نہ مرنا مگر مسلمان -\qt@no{(132)}}%
\qt@newcmd\qurantrans@ur@cxl{بلکہ تم میں کے خود موجود تھے جب یعقوب ؑ کو موت آئی جبکہ اس نے اپنے بیٹوں سے فرمایا میرے بعد کس کی پوجا کروگے بولے ہم پوجیں گے اسے جو خدا ہے آپ کا اور آپ کے آباء ابراہیم ؑ و اسمٰعیل ؑ و اسحاقؑ کا ایک خدا اور ہم اس کے حضور گردن رکھے ہیں،\qt@no{(133)}}%
\qt@newcmd\qurantrans@ur@cxli{یہ ایک امت ہے کہ گزرچکی ان کے لیے ہے جو انہوں نے کمایا اور تمہارے لئے ہے جو تم کماؤ اور ان کے کاموں کی تم سے پرسش نہ ہوگی-\qt@no{(134)}}%
\qt@newcmd\qurantrans@ur@cxlii{اور کتابی بولے یہودی یا نصرانی ہوجاؤ راہ پاؤگے تم فرماؤ بلکہ ہم تو ابراہیم ؑ کا دین لیتے ہیں جو ہر باطل سے جدا تھے اور مشرکوں سے نہ تھے -\qt@no{(135)}}%
\qt@newcmd\qurantrans@ur@cxliii{یوں کہو کہ ہم ایمان لائے اللہ پر اس پر جو ہماری طرف اترا اور جو اتارا گیا ابراہیم ؑ و اسمٰعیل ؑ و اسحاقؑ و یعقوبؑ اور ان کی اولاد پر اور جو عطا کئے گئے موسیٰ ؑ و عیسیٰ ؑ اور جو عطا کئے گئے باقی انبیاء اپنے رب کے پاس سے ہم ان پر ایمان میں فرق نہیں کرتے اور ہم اللہ کے حضور گردن رکھے ہیں-\qt@no{(136)}}%
\qt@newcmd\qurantrans@ur@cxliv{پھر اگر وہ بھی یونہی ایمان لائے جیسا تم لائے جب تو وہ ہدایت پاگئے اور اگر منہ پھیریں تو وہ نری ضد میں ہیں تو اے محبوب! عنقریب اللہ ان کی طرف سے تمہیں کفایت کرے گا اور وہی ہے سنتا جانتا -\qt@no{(137)}}%
\qt@newcmd\qurantrans@ur@cxlv{ہم نے اللہ کی رینی (رنگائی) لی اور اللہ سے بہتر کس کی رینی؟ (رنگائی) اور ہم اسی کو پوجتے ہیں،\qt@no{(138)}}%
\qt@newcmd\qurantrans@ur@cxlvi{تم فرماؤ اللہ کے بارے میں جھگڑتے ہو حالانکہ وہ ہمارا بھی مالک ہے اور تمہارا بھی اور ہماری کرنی (ہمارے اعمال) ہمارے ساتھ اور تمہاری کرنی (تمہارے اعمال) تمہارے ساتھ اور ہم نِرے اسی کے ہیں-\qt@no{(139)}}%
\qt@newcmd\qurantrans@ur@cxlvii{بلکہ تم یوں کہتے ہو کہ ابراہیم ؑ و اسمٰعیل ؑ و اسحاقؑ و یعقوب ؑ اور ان کے بیٹے یہودی یا نصرانی تھے، تم فرماؤ کیا تمہیں علم زیادہ ہے یا اللہ کو اور اس سے بڑھ کر ظالم کون جس کے پاس اللہ کی طرف کی گواہی ہو اور وہ اسے چھپائے اور خدا تمہارے کوتکوں (برے اعمال) سے بے خبر نہیں-\qt@no{(140)}}%
\qt@newcmd\qurantrans@ur@cxlviii{وہ ایک گروہ ہے کہ گزر گیا ان کے لئے ان کی کمائی اور تمہارے لئے تمہاری کمائی اور ان کے کاموں کی تم سے پرسش نہ ہوگی۔\qt@no{(141)}}%
\qt@newcmd\qurantrans@ur@cxlix{اب کہیں گے بیوقوف لوگ، کس نے پھیردیامسلمانوں کو، ان کے اس قبلہ سے، جس پر تھے تم فرمادو کہ پورب پچھم (مشرق مغرب) سب اللہ ہی کا ہے جسے چاہے سیدھی راہ چلاتا ہے۔\qt@no{(142)}}%
\qt@newcmd\qurantrans@ur@cl{اور بات یوں ہی ہے کہ ہم نے تمہیں کیا سب امتوں میں افضل، کہ تم لوگوں پر گواہ ہو اور یہ رسول تمہارے نگہبان و گواہ اور اے محبوب! تم پہلے جس قبلہ پر تھے ہم نے وہ اسی لئے مقرر کیا تھا کہ دیکھیں کون رسول کی پیروی کرتا ہے اور کون الٹے پاؤں پھر جاتا ہے۔ اور بیشک یہ بھاری تھی مگر ان پر، جنہیں اللہ نے ہدایت کی اور اللہ کی شان نہیں کہ تمہارا ایمان اکارت کرے بیشک اللہ آدمیوں پر بہت مہربان، رحم والا ہے۔\qt@no{(143)}}%
\qt@newcmd\qurantrans@ur@cli{ہم دیکھ رہے ہیں بار بار تمہارا آسمان کی طرف منہ کرنا تو ضرور ہم تمہیں پھیردیں گے اس قبلہ کی طرف جس میں تمہاری خوشی ہے ابھی اپنا منہ پھیر دو مسجد حرام کی طرف اور اے مسلمانو! تم جہاں کہیں ہو اپنا منہ اسی کی طرف کرو اور وہ جنہیں کتاب ملی ہے ضرور جانتے کہ یہ انکے رب کی طرف سے حق ہے اور اللہ ان کے کوتکوں (اعمال) سے بے خبر نہیں-\qt@no{(144)}}%
\qt@newcmd\qurantrans@ur@clii{اور اگر تم ان کتابیوں کے پاس ہر نشانی لے کر آ ؤ وہ تمہارے قبلہ کی پیروی نہ کریں گے اور نہ تم ان کے قبلہ کی پیروی کرو اور وہ آپس میں بھی ایک دوسرے کے قبلہ کے تابع نہیں اور (اے سننے والے کسے باشد) اگر تو ان کی خواہشوں پر چلا بعد اس کے کہ تجھے علم مل چکا تو اس وقت تو ضرور ستم گر ہوگا۔\qt@no{(145)}}%
\qt@newcmd\qurantrans@ur@cliii{جنہیں ہم نے کتاب عطا فرمائی وہ اس نبی کو ایسا پہچانتے ہیں جیسے آدمی اپنے بیٹوں کو پہچانتا ہے اور بیشک ان میں ایک گروہ جان بوجھ کر حق چھپاتے ہیں -\qt@no{(146)}}%
\qt@newcmd\qurantrans@ur@cliv{(اے سننے والو) یہ حق ہے تیرے رب کی طرف سے (یا حق وہی ہے جو تیرے رب کی طرف سے ہو) تو خبردار توشک نہ کرنا -\qt@no{(147)}}%
\qt@newcmd\qurantrans@ur@clv{اور ہر ایک کے لئے توجہ ایک سمعت ہے کہ وہ اسی طرف منہ کرتا ہے تو یہ چاہو کہ نیکیوں میں اوروں سے آگے نکل جائیں تو کہیں ہو اللہ تم سب کو اکٹھا لے آئے گا بیشک اللہ جو چاہے کرے-\qt@no{(148)}}%
\qt@newcmd\qurantrans@ur@clvi{اور جہاں سے ا ٓ ؤ اپنا منہ مسجد حرام کی طرف کرو اور وہ ضرور تمہارے رب کی طرف سے حق ہے اور اللہ تمہارے کاموں سے غافل نہیں-\qt@no{(149)}}%
\qt@newcmd\qurantrans@ur@clvii{اور اے محبوب تم جہاں سے آ ؤ اپنا منہ مسجد حرام کی طرف کرو اور اے مسلمانو! تم جہاں کہیں ہو اپنا منہ اسی کی طرف کرو کہ لوگوں کو تم پر کوئی حجت نہ رہے مگر جو ان میں ناانصافی کریں تو ان سے نہ ڈرو اور مجھ سے ڈرو اور یہ اس لئے ہے کہ میں اپنی نعمت تم پر پوری کروں اور کسی طرح تم ہدایت پاؤ،\qt@no{(150)}}%
\qt@newcmd\qurantrans@ur@clviii{جیسا کہ ہم نے تم میں بھیجا ایک رسول تم میں سے کہ تم پر ہماری آیتیں تلاوت فرماتا ہے اور تمہیں پاک کرتا اور کتاب اور پختہ علم سکھاتا ہے اور تمہیں وہ تعلیم فرماتا ہے جس کا تمہیں علم نہ تھا،\qt@no{(151)}}%
\qt@newcmd\qurantrans@ur@clix{تو میری یاد کرو میں تمہارا چرچا کروں گا اور میرا حق مانو اور میری ناشکری نہ کرو-\qt@no{(152)}}%
\qt@newcmd\qurantrans@ur@clx{اے ایمان والو! صبر اور نماز سے مدد چاہو بیشک اللہ صابروں کے ساتھ ہے -\qt@no{(153)}}%
\qt@newcmd\qurantrans@ur@clxi{اور جو خدا کی راہ میں مارے جائیں انہیں مردہ نہ کہو بلکہ وہ زندہ ہیں ہاں تمہیں خبرنہیں-\qt@no{(154)}}%
\qt@newcmd\qurantrans@ur@clxii{اور ضرور ہم تمہیں آزمائیں گے کچھ ڈر اور بھوک سے اور کچھ مالوں اور جانوں اور پھلوں کی کمی سے اور خوشخبری سنا ان صبر والوں کو -\qt@no{(155)}}%
\qt@newcmd\qurantrans@ur@clxiii{کہ جب ان پر کوئی مصیبت پڑے تو کہیں ہم اللہ کے مال ہیں اور ہم کو اسی کی طرف پھرنا-\qt@no{(156)}}%
\qt@newcmd\qurantrans@ur@clxiv{یہ لوگ ہیں جن پر ان کے رب کی دروُ دیں ہیں اوررحمت اور یہی لوگ راہ پر ہیں،\qt@no{(157)}}%
\qt@newcmd\qurantrans@ur@clxv{بیشک صفا اور مروہ اللہ کے نشانوں سے ہیں تو جو اس گھر کا حج یا عمرہ کرے اس پر کچھ گناہ نہیں کہ ان دونوں کے پھیرے کرے اور جو کوئی بھلی بات اپنی طرف سے کرے تو اللہ نیکی کا صلہ دینے خبردار ہے-\qt@no{(158)}}%
\qt@newcmd\qurantrans@ur@clxvi{بیشک وہ جو ہماری اتاری ہوئی روشن باتوں اور ہدایت کو چھپاتے ہیں بعد اس کے کہ لوگوں کے لئے ہم اسے کتاب میں واضح فرماچکے ہیں ان پر اللہ کی لعنت ہے اور لعنت کرنے والوں کی لعنت -\qt@no{(159)}}%
\qt@newcmd\qurantrans@ur@clxvii{مگر وہ جو توبہ کریں اور سنواریں اور ظاہر کریں تو میں ان کی توبہ قبول فرماؤں گا اور میں ہی ہوں بڑا توبہ قبول فرمانے والا مہربان،\qt@no{(160)}}%
\qt@newcmd\qurantrans@ur@clxviii{بیشک وہ جنہوں نے کفر کیا اور کافر ہی مرے ان پر لعنت ہے اللہ اور فرشتوں اور آدمیوں سب کی،\qt@no{(161)}}%
\qt@newcmd\qurantrans@ur@clxix{ہمیشہ رہیں گے اس میں نہ ان پر سے عذاب ہلکا ہو اور نہ انہیں مہلت دی جائے،\qt@no{(162)}}%
\qt@newcmd\qurantrans@ur@clxx{اور تمہارا معبود ایک معبود ہے اس کے سوا کوئی معبود نہیں مگر وہی بڑی رحمت والا مہربان\qt@no{(163)}}%
\qt@newcmd\qurantrans@ur@clxxi{بیشک آسمانوں اور زمین کی پیدائش اور رات و دن کا بدلتے آنا اور کشتی کہ دریا میں لوگوں کے فائدے لے کر چلتی ہے اور وہ جو اللہ نے آسمان سے پانی اتار کر مردہ زمین کو اس سے جِلا دیا اور زمین میں ہر قسم کے جانور پھیلائے اور ہواؤں کی گردش اور وہ بادل کہ آسمان و زمین کے بیچ میں حکم کا باندھا ہے ان سب میں عقلمندوں کے لئے ضرور نشانیاں ہیں،\qt@no{(164)}}%
\qt@newcmd\qurantrans@ur@clxxii{اور کچھ لوگ اللہ کے سوا اور معبود بنالیتے ہیں کہ انہیں اللہ کی طرح محبوب رکھتے ہیں اور ایمان والوں کو اللہ کے برابر کسی کی محبت نہیں اور کیسے ہو اگر دیکھیں ظالم وہ وقت جب کہ عذاب ان کی آنکھوں کے سامنے آئے گا اس لئے کہ سارا زور خدا کو ہے اور اس لئے کہ اللہ کا عذاب بہت سخت ہے،\qt@no{(165)}}%
\qt@newcmd\qurantrans@ur@clxxiii{جب بیزار ہوں گے پیشوا اپنے پیروؤں سے اور دیکھیں گے عذاب اور کٹ جائیں گی ان کی سب ڈوریں\qt@no{(166)}}%
\qt@newcmd\qurantrans@ur@clxxiv{اور کہیں گے پیرو کاش ہمیں لوٹ کر جانا ہوتا (دنیا میں) تو ہم ان سے توڑ دیتے جیسے انہوں نے ہم سے توڑ دی، یونہی اللہ انہیں دکھائے گا ان کے کام ان پر حسرتیں ہوکر اور وہ دوزخ سے نکلنے والے نہیں\qt@no{(167)}}%
\qt@newcmd\qurantrans@ur@clxxv{اے لوگوں کھاؤ جو کچھ زمین میں حلال پاکیزہ ہے اور شیطان کے قدم پر قدم نہ رکھو، بیشک وہ تمہارا کھلا دشمن ہے،\qt@no{(168)}}%
\qt@newcmd\qurantrans@ur@clxxvi{وہ تو تمہیں یہی حکم دے گا بدی اور بے حیائی کا اور یہ کہ اللہ پر وہ بات جوڑو جس کی تمہیں خبر نہیں،\qt@no{(169)}}%
\qt@newcmd\qurantrans@ur@clxxvii{اور جب ان سے کہا جائے اللہ کے اتارے پر چلو تو کہیں بلکہ ہم تو اس پر چلیں گے جس پر اپنے باپ دادا کو پایا کیا اگرچہ ان کے باپ دادا نہ کچھ عقل رکھتے ہوں نہ ہدایت\qt@no{(170)}}%
\qt@newcmd\qurantrans@ur@clxxviii{اور کافروں کی کہاوت اس کی سی ہے جو پکارے ایسے کو کہ خالی چیخ و پکار کے سوا کچھ نہ سنے بہرے، گونگے، اندھے تو انہیں سمجھ نہیں\qt@no{(171)}}%
\qt@newcmd\qurantrans@ur@clxxix{اے ایمان والو! کھاؤ ہماری دی ہوئی ستھری چیزیں اور اللہ کا احسان مانو اگر تم اسی کو پوجتے ہو\qt@no{(172)}}%
\qt@newcmd\qurantrans@ur@clxxx{اس نے یہی تم پر حرام کئے ہیں مردار اور خون اور سُور کا گوشت اور وہ جانور جو غیر خدان کا نام لے کر ذبح کیا گیا تو جو نا چار ہو نہ یوں کہ خواہش سے کھائے اور نہ یوں کہ ضرورت سے آگے بڑھے تو اس پر گناہ نہیں، بیشک اللہ بخشنے والا مہربان ہے،\qt@no{(173)}}%
\qt@newcmd\qurantrans@ur@clxxxi{وہ جو چھپاتے ہیں اللہ کی کتاب اور اسکے بدلے ذلیل قیمت لیتےہیں وہ اپنے پیٹ میں آگ ہی بھرتے ہیں اور اللہ قیامت کے دن ان سے بات نہ کرے گا اور نہ انہیں ستھرا کرے، اور ان کے لئے دردناک عذاب ہے،\qt@no{(174)}}%
\qt@newcmd\qurantrans@ur@clxxxii{وہ لوگ ہیں جنہوں نے ہدایت کے بدلے گمراہی مول لی اور بخشش کے بدلے عذاب، تو کس درجہ انہیں آگ کی سہار (برداشت) ہے\qt@no{(175)}}%
\qt@newcmd\qurantrans@ur@clxxxiii{یہ اس لئے کہ اللہ نے کتاب حق کے ساتھ اتاری، اور بے شک جو لوگ کتاب میں اختلاف ڈالنے لگے وہ ضرور پرلے سرے کے جھگڑالو ہیں،\qt@no{(176)}}%
\qt@newcmd\qurantrans@ur@clxxxiv{کچھ اصل نیکی یہ نہیں کہ منہ مشرق یا مغرب کی طرف کرو ہاں اصلی نیکی یہ کہ ایمان لائے اللہ اور قیامت اور فرشتوں اور کتاب اور پیغمبروں پر اور اللہ کی محبت میں اپنا عزیز مال دے رشتہ داروں اور یتیموں اور مسکینوں اور راہ گیر اور سائلوں کو اور گردنیں چھوڑانے میں اور نماز قائم رکھے اور زکوٰة دے اور اپنا قول پورا کرنے والے جب عہد کریں اور صبر والے مصیبت اور سختی میں اور جہاد کے وقت یہی ہیں جنہوں نے اپنی بات سچی کی اور یہی پرہیزگار ہیں،\qt@no{(177)}}%
\qt@newcmd\qurantrans@ur@clxxxv{اے ایمان والوں تم پر فرض ہے کہ جو ناحق مارے جائیں ان کے خون کا بدلہ لو آزاد کے بدلے آزاد اور غلام کے بدلے غلام اور عورت کے بدلے عورت تو جس کے لئے اس کے بھائی کی طرف سے کچھ معافی ہوئی۔ تو بھلائی سے تقا ضا ہو اور اچھی طرح ادا، یہ تمہارے رب کی طرف سے تمہارا بوجھ پر ہلکا کرنا ہے اور تم پر رحمت تو اس کے بعد جو زیادتی کرے اس کے لئے دردناک عذاب ہے\qt@no{(178)}}%
\qt@newcmd\qurantrans@ur@clxxxvi{اور خون کا بدلہ لینے میں تمہاری زندگی ہے اے عقل مندو کہ تم کہیں بچو،\qt@no{(179)}}%
\qt@newcmd\qurantrans@ur@clxxxvii{تم پر فرض ہوا کہ جب تم میں کسی کو موت آئے اگر کچھ مال چھوڑے تو وصیت کرجائے اپنے ماں باپ اور قریب کے رشتہ داروں کے لئے موافق دستور یہ واجب ہے پرہیزگاروں پر،\qt@no{(180)}}%
\qt@newcmd\qurantrans@ur@clxxxviii{تو جو وصیت کو سن سنا کر بدل دے اس کا گناہ انہیں بدلنے والوں پر ہے بیشک اللہ سنتا جانتا ہے،\qt@no{(181)}}%
\qt@newcmd\qurantrans@ur@clxxxix{پھر جسے اندیشہ ہوا کہ وصیت کرنے والے نے کچھ بے انصافی یا گناہ کیا تو اس نے ان میں صلح کرادی اس پر کچھ گناہ نہیں بیشک اللہ بخشنے والا مہربان ہے\qt@no{(182)}}%
\qt@newcmd\qurantrans@ur@cxc{اے ایمان والو! تم پر روزے فرض کیے گئے جیسے اگلوں پر فرض ہوئے تھے کہ کہیں تمہیں پرہیزگاری ملے، ف۳۲۵)\qt@no{(183)}}%
\qt@newcmd\qurantrans@ur@cxci{گنتی کے دن ہیں تو تم میں جو کوئی بیمار یا سفر میں ہو تو اتنے روزے اور دنوں میں اور جنہیں اس کی طاقت نہ ہو وہ بدلہ دیں ایک مسکین کا کھانا پھر جو اپنی طرف سے نیکی زیادہ کرے تو وہ اس کے لئے بہتر ہے اور روزہ رکھنا تمہارے لئے زیادہ بھلا ہے اگر تم جانو\qt@no{(184)}}%
\qt@newcmd\qurantrans@ur@cxcii{رمضان کا مہینہ جس میں قرآن اترا لوگوں کے لئے ہدایت اور رہنمائی اور فیصلہ کی روشن باتیں تو تم میں جو کوئی یہ مہینہ پائے، ضرور اس کے روزے رکھے اور جو بیمار یا سفر میں ہو تو اتنے روزے اور دنوں میں اللہ تم پر آسانی چاہتا ہے اور تم پر دشواری نہیں چاہتا اور اس لئے کہ تم گنتی پوری کرو اور اللہ کی بڑائی بولو اس پر کہ اس نے تمہیں ہدایت کی اور کہیں تم حق گزار ہو،\qt@no{(185)}}%
\qt@newcmd\qurantrans@ur@cxciii{اور اے محبوب جب تم سے میرے بندے مجھے پوچھیں تو میں نزدیک ہوں دعا قبول کرتا ہوں پکارنے والے کی جب مجھے پکارے تو انہیں چاہئے میرا حکم مانیں اور مجھ پر ایمان لائیں کہ کہیں راہ پائیں،\qt@no{(186)}}%
\qt@newcmd\qurantrans@ur@cxciv{روزہ کی راتوں میں اپنی عورتوں کے پاس جانا تمہارے لئے حلال ہوا وہ تمہاری لباس ہیں اور تم ان کے لباس، اللہ نے جانا کہ تم اپنی جانوں کو خیانت میں ڈالتے تھے تو اس نے تمہاری توبہ قبول کی اور تمہیں معاف فرمایا تو اب ان سے صحبت کرو اور طلب کرو جو اللہ نے تمہارے نصیب میں لکھا ہو اور کھاؤ اور پیئو یہاں تک کہ تمہارے لئے ظاہر ہوجائے سفیدی کا ڈورا سیاہی کے ڈورے سے (پوپھٹ کر) پھر رات آنے تک روزے پورے کرو اور عورتوں کو ہاتھ نہ لگاؤ جب تم مسجدوں میں اعتکاف سے ہو یہ اللہ کی حدیں ہیں ان کے پاس نہ جاؤ اللہ یوں ہی بیان کرتا ہے لوگوں سے اپنی آیتیں کہ کہیں انہیں پرہیزگاری ملے،\qt@no{(187)}}%
\qt@newcmd\qurantrans@ur@cxcv{اور آپس میں ایک دوسرے کا مال ناحق نہ کھاؤ اور نہ حاکموں کے پاس ان کا مقدمہ اس لئے پہنچاؤ کہ لوگوں کا کچھ مال ناجائز طور پر کھاؤ جان بوجھ کر،\qt@no{(188)}}%
\qt@newcmd\qurantrans@ur@cxcvi{تم سے نئے چاند کو پوچھتے ہیں تم فرمادو وہ وقت کی علامتیں ہیں لوگوں اور حج کے لئے اور یہ کچھ بھلائی نہیں کہ گھروں میں پچھیت (پچھلی دیوار) توڑ کر آ ؤ ہاں بھلائی تو پرہیزگاری ہے، اور گھروں میں دروازوں سے آ ؤ اور اللہ سے ڈرتے رہو اس امید پر کہ فلاح پاؤ\qt@no{(189)}}%
\qt@newcmd\qurantrans@ur@cxcvii{اور اللہ کی راہ میں لڑو ان سے جو تم سے لڑتے ہیں اور حد سے نہ بڑھو اللہ پسند نہیں رکھتا حد سے بڑھنے والوں کو،\qt@no{(190)}}%
\qt@newcmd\qurantrans@ur@cxcviii{اور کافروں کو جہاں پاؤ مارو اور انہیں نکال دو جہاں سے انہوں نے تمہیں نکا لا تھا اور ان کا فساد تو قتل سے بھی سخت ہے اور مسجد حرام کے پاس ان سے نہ لڑو جب تک وہ تم سے وہاں نہ لڑیں اور اگر تم سے لڑیں تو انہیں قتل کرو کافروں کی یہی سزا ہے،\qt@no{(191)}}%
\qt@newcmd\qurantrans@ur@cxcix{پھر اگر وہ باز رہیں تو بیشک اللہ بخشنے والا مہربان ہے،\qt@no{(192)}}%
\qt@newcmd\qurantrans@ur@cc{اور ان سے لڑو یہاں تک کہ کوئی فتنہ نہ رہے اور ایک اللہ کی پوجا ہو پھر اگر وہ باز آئیں تو زیادتی نہیں مگر ظالموں پر،\qt@no{(193)}}%
\qt@newcmd\qurantrans@ur@cci{ماہ حرام کے بدلے ماہ حرام اور ادب کے بدلے ادب ہے جو تم پر زیادتی کرے اس پر زیادتی کرو اتنی ہی جتنی اس نے کی اور اللہ سے ڈرتے رہو اور جان رکھو کہ اللہ ڈر والوں کے ساتھ ہے،\qt@no{(194)}}%
\qt@newcmd\qurantrans@ur@ccii{اور اللہ کی راہ میں خرچ کرو اور اپنے ہاتھوں، ہلاکت میں نہ پڑو اور بھلائی والے ہو جاؤ بیشک بھلائی والے اللہ کے محبوب ہیں،\qt@no{(195)}}%
\qt@newcmd\qurantrans@ur@cciii{اور حج اور عمرہ اللہ کے لئے پورا کرو پھر اگر تم روکے جاؤ تو قربانی بھیجو جو میسر آئے اور اپنے سر نہ منڈاؤ جب تک قربانی اپنے ٹھکانے نہ پہنچ جائے پھر جو تم میں بیمار ہو یا اس کے سر میں کچھ تکلیف ہے تو بدلے دے روزے یا خیرات یا قربانی، پھر جب تم اطمینان سے ہو تو جو حج سے عمرہ ملانے کا فائدہ اٹھائے اس پر قربانی ہے جیسی میسر آئے پھر جسے مقدور نہ ہو تو تین روزے حج کے دنوں میں رکھے اور سات جب اپنے گھر پلٹ کر جاؤ یہ پورے دس ہوئے یہ حکم اس کے لئے ہے جو مکہ کا رہنے والا نہ ہو اور اللہ سے ڈرتے رہو اور جان رکھو کہ اللہ کا عذاب سخت ہے،\qt@no{(196)}}%
\qt@newcmd\qurantrans@ur@cciv{حج کے کئی مہینہ ہیں جانے ہوئے تو جو ان میں حج کی نیت کرے تو نہ عورتوں کے سامنے صحبت کا تذکرہ ہو نہ کوئی گناہ، نہ کسی سے جھگڑا حج کے وقت تک اور تم جو بھلائی کرو اللہ اسے جانتا ہے اور توشہ ساتھ لو کہ سب سے بہتر توشہ پرہیزگاری ہے اور مجھ سے ڈرتے رہو اے عقل والو، ف۳۷۸)\qt@no{(197)}}%
\qt@newcmd\qurantrans@ur@ccv{تم پر کچھ گناہ نہیں کہ اپنے رب کا فضل تلاش کرو، تو جب عرفات سے پلٹو تو اللہ کی یاد کرو مشعر حرام کے پاس اور اس کا ذکر کرو جیسے اس نے تمہیں ہدایت فرمائی اور بیشک اس سے پہلے تم بہکے ہوئے تھے، ف۳۸۳)\qt@no{(198)}}%
\qt@newcmd\qurantrans@ur@ccvi{پھر بات یہ ہے کہ اے قریشیو! تم بھی وہیں سے پلٹو جہاں سے لوگ پلٹتے ہیں اور اللہ سے معافی مانگو، بیشک اللہ بخشنے والا مہربان ہے،\qt@no{(199)}}%
\qt@newcmd\qurantrans@ur@ccvii{پھر جب اپنے حج کے کام پورے کرچکو تو اللہ کا ذکر کرو جیسے اپنے باپ دادا کا ذکر کرتے تھے بلکہ اس سے زیادہ اور کوئی آدمی یوں کہتا ہے کہ اے رب ہمارے ہمیں دنیا میں دے اور آخرت میں اس کا کچھ حصہ نہیں،\qt@no{(200)}}%
\qt@newcmd\qurantrans@ur@ccviii{اور کوئی یوں کہتا ہے کہ اے رب ہمارے! ہمیں دنیا میں بھلائی دے اور ہمیں آخرت میں بھلائی دے اور ہمیں عذاب دوزخ سے بچا\qt@no{(201)}}%
\qt@newcmd\qurantrans@ur@ccix{ایسوں کو ان کی کمائی سے بھاگ (خوش نصیبی) ہے اور اللہ جلد حساب کرنے والا ہے\qt@no{(202)}}%
\qt@newcmd\qurantrans@ur@ccx{اور اللہ کی یاد کرو گنے ہوئے دنوں میں تو جلدی کرکے دو دن میں چلا جائے اس پر کچھ گنا نہیں اور جو رہ جائے تو اس پر گناہ نہیں پرہیزگار کے لئے اور اللہ سے ڈرتے رہو اور جان رکھو کہ تمہیں اسی کی طرف اٹھنا ہے،\qt@no{(203)}}%
\qt@newcmd\qurantrans@ur@ccxi{اور بعض آدمی وہ ہیں کہ دنیا کی زندگی میں اس کی بات تجھے بھلی لگے اور اپنے دل کی بات پر اللہ کو گواہ لائے اور وہ سب سے بڑا جھگڑالو ہے،\qt@no{(204)}}%
\qt@newcmd\qurantrans@ur@ccxii{اور جب پیٹھ پھیرے تو زمین میں فساد ڈالتا پھرے اور کھیتی اور جانیں تباہ کرے اور اللہ فسادسے راضی نہیں\qt@no{(205)}}%
\qt@newcmd\qurantrans@ur@ccxiii{اور جب اس سے کہا جائے کہ اللہ سے ڈرو تو اسے اور ضد چڑھے گنا ہ کی ایسے کو دوزخ کافی ہے اور وہ ضرور بہت برا بچھونا ہے،\qt@no{(206)}}%
\qt@newcmd\qurantrans@ur@ccxiv{اور کوئی آدمی اپنی جان بیچتا ہے اللہ کی مرضی چاہنے میں اور اللہ بندوں پر مہربان ہے،\qt@no{(207)}}%
\qt@newcmd\qurantrans@ur@ccxv{اے ایمان والو! اسلام میں پورے داخل ہو اور شیطان کے قدموں پر نہ چلے بیشک وہ تمہارا کھلا دشمن ہے،\qt@no{(208)}}%
\qt@newcmd\qurantrans@ur@ccxvi{اور اگر اس کے بعد بھی بچلو کہ تمہارے پاس روشن حکم آچکے تو جان لو کہ اللہ زبردست حکمت والا ہے،\qt@no{(209)}}%
\qt@newcmd\qurantrans@ur@ccxvii{کاہے کے انتظار میں ہیں مگر یہی کہ اللہ کا عذاب آئے چھائے ہوئے بادلوں میں اور فرشتے اتریں اور کام ہوچکے اور سب کاموں کی رجوع اللہ کی طرف ہے،\qt@no{(210)}}%
\qt@newcmd\qurantrans@ur@ccxviii{بنی اسرائیل سے پوچھو ہم نے کتنی روشن نشانیاں انہیں دیں اور جو اللہ کی آئی ہوئی نعمت کو بدل دے تو بیشک اللہ کا عذاب سخت ہے،\qt@no{(211)}}%
\qt@newcmd\qurantrans@ur@ccxix{کافروں کی نگاہ میں دنیا کی زندگی آراستہ کی گئی اور مسلمانوں سے ہنستے ہیں اور ڈر والے ان سے اوپر ہوں گے قیامت کے دن اور خدا جسے چاہے بے گنتی دے،\qt@no{(212)}}%
\qt@newcmd\qurantrans@ur@ccxx{لوگ ایک دین پر تھے پھر اللہ نے انبیاء بھیجے خوشخبری دیتے اور ڈر سناتے اور ان کے ساتھ سچی کتاب اتاری کہ وہ لوگوں میں ان کے اختلافوں کا فیصلہ کردے اور کتاب میں اختلاف اُنہیں نے ڈالا جن کو دی گئی تھی بعداس کے کہ ان کے پاس روشن حکم آچکے آپس میں سرکشی سے تو اللہ نے ایمان والوں کو وہ حق بات سوجھا دی جس میں جھگڑ رہے تھے اپنے حکم سے، اور اللہ جسے چاہے سیدھی راہ دکھائے،\qt@no{(213)}}%
\qt@newcmd\qurantrans@ur@ccxxi{کیا اس گمان میں ہو کہ جنت میں چلے جاؤ گے اور ابھی تم پر اگلوں کی سی روداد (حالت) نہ آئی پہنچی انہیں سختی اور شدت اور ہلا ہلا ڈالے گئے یہاں تک کہ کہہ اٹھا رسول اور اس کے ساتھ ایمان والے کب آئے گی اللہ کی مدد سن لو بیشک اللہ کی مدد قریب ہے،\qt@no{(214)}}%
\qt@newcmd\qurantrans@ur@ccxxii{تم سے پوچھتے ہیں کیا خرچ کریں، تم فرماؤ جو کچھ مال نیکی میں خرچ کرو تو و ہ ماں باپ اور قریب کے رشتہ داروں اور یتیموں اور محتاجوں اور راہ گیر کے لئے ہے اور جو بھلائی کرو بیشک اللہ اسے جانتا ہے\qt@no{(215)}}%
\qt@newcmd\qurantrans@ur@ccxxiii{تم پر فرض ہوا خدا کی راہ میں لڑنا اور وہ تمہیں ناگوار ہے اور قریب ہے کہ کوئی بات تمہیں بری لگے اور وہ تمہارے حق میں بہتر ہو اور قریب ہے کہ کوئی بات تمہیں پسند آئے اور وہ تمہارے حق میں بری ہو اور اللہ جانتا ہے اور تم نہیں جانتے\qt@no{(216)}}%
\qt@newcmd\qurantrans@ur@ccxxiv{تم سے پوچھتے ہیں ماہ حرام میں لڑنے کا حکم تم فرماؤ اس میں لڑنا بڑا گناہ ہے اور اللہ کی راہ سے روکنا اور اس پر ایمان نہ لانا اور مسجد حرام سے روکنا، اور اس کے بسنے والوں کو نکال دینا اللہ کے نزدیک یہ گناہ اس سے بھی بڑے ہیں اور ان کا فساد قتل سے سخت تر ہے اور ہمیشہ تم سے لڑتے رہیں گے یہاں تک کہ تمہیں تمہارے دین سے پھیردیں اگر بن پڑے اور تم میں جو کوئی اپنے دین سے پھرے پھر کافر ہوکر مرے تو ان لوگوں کا کیا اکارت گیا دنیا میں اور آخرت میں اور وہ دوزخ والے ہیں انہیں اس میں ہمیشہ رہنا،\qt@no{(217)}}%
\qt@newcmd\qurantrans@ur@ccxxv{وه جو ایمان لائے اور وہ جنہوں نے اللہ کے لئے اپنے گھر بار چھوڑے اور اللہ کی راہ میں لڑے وہ رحمت الٰہی کے امیداور ہیں، اور اللہ بخشنے والا مہربان ہے\qt@no{(218)}}%
\qt@newcmd\qurantrans@ur@ccxxvi{تم سے شراب اور جوئے کا حکم پوچھتے ہیں، تم فرمادو کہ ان دونوں میں بڑا گناہ ہے اور لوگوں کے کچھ دنیوی نفع بھی اور ان کا گناہ ان کے نفع سے بڑا ہے تم سے پوچھتے ہیں کیا خرچ کریں تم فرماؤ جو فاضل بچے اسی طرح اللہ تم سے آیتیں بیان فرماتا ہے کہ کہیں تم دنیا،\qt@no{(219)}}%
\qt@newcmd\qurantrans@ur@ccxxvii{اور ا ٓ خرت کے کام سوچ کر کرو اور تم سے یتیموں کا مسئلہ پوچھتے ہیں تم فرماؤ ان کا بھلا کرنا بہتر ہے اور اگر اپنا ان کا خرچ ملالو تو وہ تمہارے بھائی ہیں اور خدا خوب جانتا ہے بگاڑنے والے کو سنوارنے والے سے، اور اللہ چاہتا ہے تو تمہیں مشقت میں ڈالتا، بیشک اللہ زبردست حکمت والا ہے،\qt@no{(220)}}%
\qt@newcmd\qurantrans@ur@ccxxviii{اور شرک والی عورتوں سے نکاح نہ کرو جب تک مسلمان نہ ہوجائیں اور بیشک مسلمان لونڈی مشرکہ سے اچھی ہے اگرچہ وہ تمہیں بھاتی ہو اور مشرکوں کے نکاح میں نہ دو جب تک وہ ایمان نہ لائیں اور بیشک مسلمان غلام مشرک سے اچھا ہے اگرچہ وہ تمہیں بھاتا ہو، وہ دوزخ کی طرف بلاتے ہیں اور اللہ جنت اور بخشش کی طرف بلاتا ہے اپنے حکم سے اور اپنی آیتیں لوگوں کے لئے بیان کرتا ہے کہ کہیں وہ نصیحت مانیں،\qt@no{(221)}}%
\qt@newcmd\qurantrans@ur@ccxxix{اور تم سے پوچھتے ہیں حیض کا حکم تم فرماؤ وہ ناپاکی ہے تو عورتوں سے الگ رہو حیض کے دنوں اور ان سے نزدیکی نہ کرو جب تک پاک نہ ہولیں پھر جب پاک ہوجائیں تو ان کے پاس جاؤ جہاں سے تمہیں اللہ نے حکم دیا، بیشک اللہ پسند کرتا ہے بہت توبہ کرنے والوں کو اور پسند رکھتا ہے سھتروں کو،\qt@no{(222)}}%
\qt@newcmd\qurantrans@ur@ccxxx{تمہاری عورتیں تمہارے لئے کھیتیاں ہیں، تو آؤ اپنی کھیتیوں میں جس طرح چاہو اور اپنے بھلے کا کام پہلے کرو اور اللہ سے ڈرتے رہو اور جان رکھو کہ تمہیں اس سے ملنا ہے اور اے محبوب بشارت دو ایمان والوں کو،\qt@no{(223)}}%
\qt@newcmd\qurantrans@ur@ccxxxi{اور اللہ کو اپنی قسموں کا نشانہ نہ بنالو کہ احسان اور پرہیزگاری او ر لوگوں میں صلح کرنے کی قسم کرلو، اور اللہ سنتا جانتا ہے،\qt@no{(224)}}%
\qt@newcmd\qurantrans@ur@ccxxxii{اور تمہیں نہیں پکڑ تا ان قسموں میں جو بے ارادہ زبان سے نکل جائے ہاں اس پر گرفت فرماتا ہے جو کام تمہارے دلوں نے کئے اور اللہ بخشنے والا حلم والا ہے،\qt@no{(225)}}%
\qt@newcmd\qurantrans@ur@ccxxxiii{اور وہ جو قسم کھا بیٹھتے ہیں اپنی عورتوں کے پاس جانے کی انہیں چار مہینے کی مہلت ہے، پس اگر اس مدت میں پھر آئے تو اللہ بخشنے والا مہربان ہے\qt@no{(226)}}%
\qt@newcmd\qurantrans@ur@ccxxxiv{اور اگر چھوڑ دینے کا ارادہ پکا کرلیا تو اللہ سنتا جانتا ہے\qt@no{(227)}}%
\qt@newcmd\qurantrans@ur@ccxxxv{اور طلاق والیاں اپنی جانوں کو روکے رہیں تین حیض تک اور انہیں حلال نہیں کہ چھپائیں وہ جو اللہ نے ان کے پیٹ میں پیدا کیا اگر اللہ اور قیامت پر ایمان رکھتی ہیں اور ان کے شوہروں کو اس مدت کے اندر ان کے پھیر لینے کا حق پہنچتا ہے اگر ملاپ چاہیں اور عورتوں کا بھی حق ایسا ہی ہے جیسا ان پر ہے شرع کے موافق اور مردوں کو ان پر فضیلت ہے، اور اللہ غالب حکمت والا ہے،\qt@no{(228)}}%
\qt@newcmd\qurantrans@ur@ccxxxvi{یہ طلاق دو بار تک ہے پھر بھلائی کے ساتھ روک لینا ہے یا نکوئی (اچھے سلوک) کے ساتھ چھوڑ دینا ہے اور تمہیں روا نہیں کہ جو کچھ عورتوں کو دیا اس میں سے کچھ واپس لو مگر جب دونوں کو اندیشہ ہو کہ اللہ کی حدیں قائم نہ کریں گے پھر اگر تمہیں خوف ہو کہ وہ دونوں ٹھیک انہیں حدوں پر نہ رہیں گے تو ان پر کچھ گناہ نہیں اس میں جو بدلہ دے کر عورت چھٹی لے، یہ اللہ کی حدیں ہیں ان سے آگے نہ بڑھو اور جو اللہ کی حدوں سے آگے بڑھے تو وہی لوگ ظالم ہیں،\qt@no{(229)}}%
\qt@newcmd\qurantrans@ur@ccxxxvii{پھر اگر تیسری طلاق اسے دی تو اب وہ عورت اسے حلال نہ ہوگی جب تک دوسرے خاوند کے پاس نہ رہے، پھر وہ دوسرا اگر اسے طلاق دے دے تو ان دونوں پر گناہ نہیں کہ پھر آپس میں مل جائیں اگر سمجھتے ہوں کہ اللہ کی حدیں نباہیں گے، اور یہ اللہ کی حدیں ہیں جنہیں بیان کرتا ہے دانش مندوں کے لئے،\qt@no{(230)}}%
\qt@newcmd\qurantrans@ur@ccxxxviii{اور جب تم عورتوں کو طلاق دو اور ان کی میعاد آلگے تو اس وقت تک یا بھلائی کے ساتھ روک لو یا نکوئی (اچھے سلوک) کے ساتھ چھوڑ دو اور انہیں ضرر دینے کے لئے روکنا نہ ہو کہ حد سے بڑھو اور جو ایسا کرے وہ اپنا ہی نقصان کرتا ہے اور اللہ کی آیتوں کو ٹھٹھا نہ بنالو اور یاد کرو اللہ کا احسان جو تم پر ہے اور و ہ جو تم پر کتاب اور حکمت اتاری تمہیں نصیحت دینے کو اور اللہ سے ڈرتے رہو اور جان رکھو کہ اللہ سب کچھ جانتا ہے\qt@no{(231)}}%
\qt@newcmd\qurantrans@ur@ccxxxix{اور جب تم عورتوں کو طلاق دو اور ان کی میعاد پوری ہوجائے تو اے عورتوں کے والِیو انہیں نہ روکو اس سے کہ اپنے شوہروں سے نکاح کرلیں جب کہ آپس میں موافق شرع رضا مند ہوجائیں یہ نصیحت اسے دی جاتی ہے جو تم میں سے اللہ اور قیامت پر ایمان رکھتا ہو یہ تمہارے لئے زیادہ ستھرا اور پاکیزہ ہے اور اللہ جانتا ہے اور تم نہیں جانتے،\qt@no{(232)}}%
\qt@newcmd\qurantrans@ur@ccxl{اور مائیں دودھ پلائیں اپنے بچوں کو پورے دو برس اس کے لئے جو دودھ کی مدت پوری کرنی چاہئے اور جس کا بچہ ہے اس پر عورتوں کا کھانا پہننا ہے حسب دستور کسی جان پر بوجھ نہ رکھا جائے گا مگر اس کے مقدور بھر ماں کو ضرر نہ دیا جائے اس کے بچہ سے اور نہ اولاد والے کو اس کی اولاد سے یا ماں ضرر نہ دے اپنے بچہ کو اور نہ اولاد والا اپنی اولاد کو اور جو باپ کا قائم مقام ہے اس پر بھی ایسا ہی واجب ہے پھر اگر ماں باپ دونوں آپس کی رضا اور مشورے سے دودھ چھڑانا چاہیں تو ان پر گناہ نہیں اور اگر تم چاہو کہ دائیوں سے اپنے بچوں کو دودھ پلواؤ تو بھی تم پر مضائقہ نہیں جب کہ جو دینا ٹھہرا تھا بھلائی کے ساتھ انہیں ادا کردو، اور اللہ سے ڈرتے رہو اور جان رکھو کہ اللہ تمہارے کام دیکھ رہا ہے،\qt@no{(233)}}%
\qt@newcmd\qurantrans@ur@ccxli{اور تم میں جو مریں اور بیبیاں چھوڑیں وہ چار مہینے دس دن اپن ے آپ کو روکے رہیں تو جب ان کی عدت پوری ہوجائے تو اے والیو! تم پر مؤاخذہ نہیں اس کام میں جو عورتیں اپنے معاملہ میں موافق شرع کریں، اور اللہ کو تمہارے کاموں کی خبر ہے،\qt@no{(234)}}%
\qt@newcmd\qurantrans@ur@ccxlii{اور تم پر گناہ نہیں اس بات میں جو پردہ رکھ کر تم عورتوں کے نکاح کا پیام د و یا اپنے دل میں چھپا رکھو اللہ جانتا ہے کہ اب تم ان کی یاد کرو گے ہاں ان سے خفیہ وعدہ نہ کر رکھو مگر یہ کہ اتنی بات کہو جو شرع میں معروف ہے، اور نکاح کی گرہ پکی نہ کرو جب تک لکھا ہوا حکم اپنی میعاد کو نہ پہنچ لے اور جان لو کہ اللہ تمہارے دل کی جانتا ہے تو اس سے ڈرو اور جان لو کہ اللہ بخشنے والا حلم والا ہے،\qt@no{(235)}}%
\qt@newcmd\qurantrans@ur@ccxliii{تم پر کچھ مطالبہ نہیں تم عورتوں کو طلاق دو جب تک تم نے ان کو ہاتھ ن ہ لگایا ہو یا کوئی مہر مقرر کرلیا ہو اور ان کو کچھ برتنے کو دو مقدور والے پر اس کے لائق اور تنگدست پر اس کے لائق حسب دستور کچھ برتنے کی چیز یہ واجب ہے بھلائی والوں پر\qt@no{(236)}}%
\qt@newcmd\qurantrans@ur@ccxliv{اور اگر تم نے عورتوں کو بے چھوئے طلاق دے دی اور ان کے لئے کچھ مہر مقرر کرچکے تھے تو جتنا ٹھہرا تھا اس کا آدھا واجب ہے مگر یہ کہ عورتیں کچھ چھوڑدیں یا وہ زیاد ه دے جس کے ہاتھ میں نکاح کی گرہ ہے اور اے مرَدو تمہارا زیادہ دینا پرہیزگاری سے نزدیک تر ہے اور آپس میں ایک دوسرے پر احسان کو بُھلا نہ دو بیشک اللہ تمہارے کام دیکھ رہا ہے\qt@no{(237)}}%
\qt@newcmd\qurantrans@ur@ccxlv{نگہبانی کرو سب نمازوں کی اور بیچ کی نماز کی اور کھڑے ہو اللہ کے حضور ادب سے\qt@no{(238)}}%
\qt@newcmd\qurantrans@ur@ccxlvi{پھر اگر خوف میں ہو تو پیادہ یا سوار جیسے بن پڑے پھر جب اطمینان سے ہو تو اللہ کی یاد کرو جیسا اس نے سکھایا جو تم نہ جانتے تھے،\qt@no{(239)}}%
\qt@newcmd\qurantrans@ur@ccxlvii{اور جو تم میں مریں اور بیبیاں چھوڑ جائیں، وہ اپنی عورتوں کے لئے وصیت کرجائیں سال بھر تک نان نفقہ دینے کی بے نکالے پھر اگر وہ خود نکل جائیں تو تم پر اس کا مؤاخذہ نہیں جو انہوں نے اپنے معاملہ میں مناسب طور پر کیا، اور اللہ غالب حکمت والا ہے،\qt@no{(240)}}%
\qt@newcmd\qurantrans@ur@ccxlviii{اور طلاق والیوں کے لئے بھی مناسب طور پر نان و نفقہ ہے، یہ واجب ہے پرہیزگاروں پر،\qt@no{(241)}}%
\qt@newcmd\qurantrans@ur@ccxlix{اللہ یونہی بیان کرتا ہے تمہارے لئے اپنی آیتیں کہ کہیں تمہیں سمجھ ہو،\qt@no{(242)}}%
\qt@newcmd\qurantrans@ur@ccl{اے محبوب کیا تم نے نہ دیکھا تھا انہیں جو اپنے گھروں سے نکلے اور وہ ہزاروں تھے موت کے ڈر سے، تو اللہ نے ان سے فرمایا مرجاؤ پھر انہیں زندہ فرمادیا، بیشک اللہ لوگوں پر فضل کرنے والا ہے مگر اکثر لوگ ناشکرے ہیں\qt@no{(243)}}%
\qt@newcmd\qurantrans@ur@ccli{اور لڑو اللہ کی راہ میں اور جان لو کہ اللہ سنتا جانتا ہے،\qt@no{(244)}}%
\qt@newcmd\qurantrans@ur@cclii{ہے کوئی جو اللہ کو قرض حسن دے تو اللہ اس کے لئے بہت گنُا بڑھا دے اور اللہ تنگی اور کشائیش کرتا ہے اور تمہیں اسی کی طرف پھر جانا،\qt@no{(245)}}%
\qt@newcmd\qurantrans@ur@ccliii{اے محبوب! کیا تم نے نہ دیکھا بنی اسرائیل کے ایک گروہ کو جو موسیٰ کے بعد ہوا جب اپنے ایک پیغمبر سے بولے ہمارے لیے کھڑا کردو ایک بادشاہ کہ ہم خدا کی راہ میں لڑیں، نبی نے فرمایا کیا تمہارے انداز ایسے ہیں کہ تم پر جہاد فرض کیا جائے تو پھر نہ کرو، بولے ہمیں کیا ہوا کہ ہم اللہ کی راہ میں نہ لڑیں حالانکہ ہم نکالے گئے ہیں اپنے وطن اور اپنی اولاد سے تو پھر جب ان پر جہاد فرض کیا گیا منہ پھیر گئے مگر ان میں کے تھوڑے اور اللہ خوب جانتا ہے ظالموں کو،\qt@no{(246)}}%
\qt@newcmd\qurantrans@ur@ccliv{اور ان سے ان کے نبی نے فرمایا بیشک اللہ نے طالوت کو تمہارا بادشاہ بنا کر بھیجا ہے بولے اسے ہم پر بادشاہی کیونکر ہوگی اور ہم اس سے زیادہ سلطنت کے مستحق ہیں اور اسے مال میں بھی وسعت نہیں دی گئی فرمایا اسے اللہ نے تم پر چن لیا اور اسے علم اور جسم میں کشادگی زیادہ دی اور اللہ اپنا ملک جسے چاہ ے دے اور اللہ وسعت والا علم والا ہے\qt@no{(247)}}%
\qt@newcmd\qurantrans@ur@cclv{اور ان سے ان کے نبی نے فرمایا اس کی بادشاہی کی نشانی یہ ہے کہ آئے تمہارے پاس تابوت جس میں تمہارے رب کی طرف سے دلوں کا چین ہے اور کچھ بچی ہوئی چیزیں معزز موسی ٰ او ر معزز ہارون کے ترکہ کی اٹھاتے لائیں گے اسے فرشتے، بیشک اس میں بڑی نشانی ہے تمہارے لئے اگر ایمان رکھتے ہو،\qt@no{(248)}}%
\qt@newcmd\qurantrans@ur@cclvi{پھر جب طالوت لشکروں کو لے کر شہر سے جدا ہوا بولا بیشک اللہ تمہیں ایک نہر سے آزمانے والا ہے تو جو اس کا پانی پئے وہ میرا نہیں اور جو نہ پیئے وہ میرا ہے مگر وہ جو ایک چلُو اپنے ہاتھ سے لے لے تو سب نے اس سے پیا مگر تھوڑوں نے پھر جب طالوت اور اس کے ساتھ کے مسلمان نہر کے پار گئے بولے ہم میں آج طاقت نہیں جالوت اور اس کے لشکروں کی بولے وہ جنہیں اللہ سے ملنے کا یقین تھا کہ بارہا کم جماعت غالب آئی ہے زیادہ گروہ پر اللہ کے حکم سے، اور اللہ صابروں کے ساتھ ہے\qt@no{(249)}}%
\qt@newcmd\qurantrans@ur@cclvii{پھر جب سامنے آئے جالوت اور اس کے لشکروں کے عرض کی اے رب ہمارے ہم پر صبر انڈیل اور ہمارے پاؤں جمے رکھ کافر لوگوں پرہماری مدد کر،\qt@no{(250)}}%
\qt@newcmd\qurantrans@ur@cclviii{تو انہوں نے ان کو بھگا دیا اللہ کے حکم سے، اور قتل کیا داؤد نے جالوت کو اور اللہ نے اسے سلطنت اور حکمت عطا فرمائی اور اسے جو چاہا سکھایا اور اگر اللہ لوگوں میں بعض سے بعض کو دفع نہ کرے تو ضرور زمین تباہ ہوجائے مگر اللہ سارے جہان پر فضل کرنے والا ہے،\qt@no{(251)}}%
\qt@newcmd\qurantrans@ur@cclix{یہ اللہ کی آیتیں ہیں کہ ہم اے محبوب تم پر ٹھیک ٹھیک پڑھتے ہیں، اور تم بےشک رسولوں میں ہو۔\qt@no{(252)}}%
\qt@newcmd\qurantrans@ur@cclx{یہ رسول ہیں کہ ہم نے ان میں ایک کو دوسرے پر افضل کیا ان میں کسی سے اللہ نے کلام فرمایا اور کوئی وہ ہے جسے سب پر درجوں بلند کیا اور ہم نے مریم کے بیٹے عیسیٰ کو کھلی نشانیاں دیں اور پاکیزہ روح سے اس کی مدد کی اور اللہ چاہتا تو ان کے بعد والے آپس میں نہ لڑتے نہ اس کے کہ ان کے پاس کھلی نشانیاں آچکیں لیکن وہ مختلف ہوگئے ان میں کوئی ایمان پر رہا اور کوئی کافر ہوگیا اور اللہ چاہتا تو وہ نہ لڑتے مگر اللہ جو چاہے کرے\qt@no{(253)}}%
\qt@newcmd\qurantrans@ur@cclxi{اے ایمان والو! اللہ کی راہ میں ہمارے دیئے میں سے خرچ کرو وہ دن آنے سے پہلے جس میں نہ خرید و فروخت ہے اور نہ کافروں کے لئے دوستی اور نہ شفاعت، اور کافر خود ہی ظالم ہیں\qt@no{(254)}}%
\qt@newcmd\qurantrans@ur@cclxii{اللہ ہے جس کے سوا کوئی معبود نہیں وہ آپ زندہ اور اوروں کا قائم رکھنے والا اسے نہ اونگھ آئے نہ نیند اسی کا ہے جو کچھ آسمانوں میں ہے اور جو کچھ زمین میں وہ کون ہے جو اس کے یہاں سفارش کرے بغیر اس کے حکم کے جانتا ہے جو کچھ ان کے آگے ہے اور جو کچھ ان کے پیچھے اور وہ نہیں پاتے اس کے علم میں سے مگر جتنا وہ چاہے اس کی کرسی میں سمائے ہوئے آسمان اور زمین اور اسے بھاری نہیں ان کی نگہبانی اور وہی ہے بلند بڑائی والا\qt@no{(255)}}%
\qt@newcmd\qurantrans@ur@cclxiii{کچھ زبردستی نہیں دین میں بیشک خوب جدا ہوگئی ہے نیک راہ گمراہی سے تو جو شیطان کو نہ مانے اور اللہ پر ایمان لائے اس نے بڑی محکم گرہ تھامی جسے کبھی کھلنا نہیں، اور اللہ سنتا جانتا ہے،\qt@no{(256)}}%
\qt@newcmd\qurantrans@ur@cclxiv{اللہ والی ہے مسلمانوں کا انہیں اندھیریوں سے نور کی طرف نکلتا ہے، اور کافروں کے حمایتی شیطان ہیں وہ انہیں نور سے اندھیریوں کی طرف نکالتے ہیں یہی لوگ دوزخ والے ہیں انہیں ہمیشہ اس میں رہنا،\qt@no{(257)}}%
\qt@newcmd\qurantrans@ur@cclxv{اے محبوب! کیا تم نے نہ دیکھا تھا اسے جو ابراہیم سے جھگڑا اس کے رب کے بارے میں اس پر کہ اللہ نے اسے بادشاہی دی جبکہ ابراہیم نے کہا کہ میرا رب وہ ہے جو جِلاتا اور مارتا ہے بولا میں جِلاتا اور مارتا ہوں ابراہیم نے فرمایا تو اللہ سورج کو لاتا ہے پورب (مشرق) سے تو اس کو پچھم (مغرب) سے لے آ تو ہوش اڑ گئے کافروں کے، اور اللہ راہ نہیں دکھاتا ظالموں کو،\qt@no{(258)}}%
\qt@newcmd\qurantrans@ur@cclxvi{یا اس کی طرح جو گزرا ایک بستی پر اور وہ ڈھئی (مسمار ہوئی) پڑی تھی اپنی چھتوں پر بولا اسے کیونکر جِلائے گا اللہ اس کی موت کے بعد تو اللہ نے اسے مردہ رکھا سو برس پھر زندہ کردیا، فرمایا تو یہاں کتنا ٹھہرا، عرض کی دن بھر ٹھہرا ہوں گا یا کچھ کم، فرمایا نہیں تجھے سو برس گزر گئے اور اپنے کھانے اور پانی کو دیکھ کہ اب تک بو نہ لایا اور اپنے گدھے کو دیکھ کہ جس کی ہڈیاں تک سلامت نہ رہیں اور یہ اس لئے کہ تجھے ہم لوگوں کے واسطے نشانی کریں اور ان ہڈیوں کو دیکھ کیونکر ہم انہیں اٹھان دیتے پھر انہیں گوشت پہناتے ہیں جب یہ معاملہ اس پر ظاہر ہوگیا بولا میں خوب جانتا ہوں کہ اللہ سب کچھ کرسکتا ہے،\qt@no{(259)}}%
\qt@newcmd\qurantrans@ur@cclxvii{اور جب عرض کی ابراہیم نے اے رب میرے مجھے دکھا دے تو کیونکر مردے جِلائے گا فرمایا کیا تجھے یقین نہیں عرض کی یقین کیوں نہیں مگر یہ چاہتا ہوں کہ میرے دل کو قرار آجائے فرمایا تو اچھا، چار پرندے لے کر اپنے ساتھ ہلالے پھر ان کا ایک ایک ٹکڑا ہر پہاڑ پر رکھ دے پھر انہیں بلا وہ تیرے پاس چلے آئیں گے پاؤں سے دوڑتے اور جان رکھ کہ اللہ غالب حکمت والا ہے\qt@no{(260)}}%
\qt@newcmd\qurantrans@ur@cclxviii{ان کی کہاوت جو اپنے مال اللہ کی راہ میں خرچ کرتے ہیں اس دانہ کی طرح جس نے اگائیں سات بالیں ہر بال میں سو دانے اور اللہ اس سے بھی زیادہ بڑھائے جس کے لئے چاہے اور اللہ وسعت والا علم والا ہے،\qt@no{(261)}}%
\qt@newcmd\qurantrans@ur@cclxix{وہ جو اپنے مال اللہ کی راہ میں خرچ کرتے ہیں پھر دیئے پیچھے نہ احسان رکھیں نہ تکلیف دیں ان کا نیگ (انعام) ان کے رب کے پاس ہے اور انہیں نہ کچھ اندیشہ ہو نہ کچھ غم،\qt@no{(262)}}%
\qt@newcmd\qurantrans@ur@cclxx{اچھی بات کہنا اور درگزر کرنا اس خیرات سے بہتر ہے جس کے بعد ستانا ہو اور اللہ بے پراہ حلم والا ہے،\qt@no{(263)}}%
\qt@newcmd\qurantrans@ur@cclxxi{اے ایمان والوں اپنے صدقے باطل نہ کردو احسان رکھ کر اور ایذا دے کر اس کی طرح جو اپنا مال لوگوں کے دکھاوے کے لئے خرچ کرے اور اللہ اور قیامت پر ایمان نہ لائے، تو اس کی کہاوت ایسی ہے جیسے ایک چٹان کہ اس پر مٹی ہے اب اس پر زور کا پانی پڑا جس نے اسے نرا پتھر کر چھوڑا اپنی کمائی سے کسی چیز پر قابو نہ پائیں گے، اور اللہ کافروں کو راہ نہیں دیتا،\qt@no{(264)}}%
\qt@newcmd\qurantrans@ur@cclxxii{اور ان کی کہاوت جو اپنے مال اللہ کی رضا چاہنے میں خرچ کرتے ہیں اور اپنے دل جمانے کو اس باغ کی سی ہے جو بھوڑ (رتیلی زمین) پر ہو اس پر زور کا پانی پڑا تو دُونے میوے لایا پھر اگر زور کا مینھ اسے نہ پہنچے تو اوس کافی ہے اور اللہ تمہارے کام دیکھ رہا ہے\qt@no{(265)}}%
\qt@newcmd\qurantrans@ur@cclxxiii{کیا تم میں کوئی اسے پسند رکھے گا کہ اس کے پاس ایک باغ ہو کھجوروں اور انگوروں کا جس کے نیچے ندیاں بہتیں اس کے لئے اس میں ہر قسم کے پھلوں سے ہے اور اسے بڑھاپا آیا اور اس کے ناتوان بچے ہیں تو آیا اس پر ایک بگولا جس میں آگ تھی تو جل گیا ایسا ہی بیان کرتا ہے اللہ تم سے اپنی آیتیں کہ کہیں تم دھیان لگاؤ\qt@no{(266)}}%
\qt@newcmd\qurantrans@ur@cclxxiv{اے ایمان والو! اپنی پاک کمائیوں میں سے کچھ دو اور اس میں سے جو ہم نے تمہارے لئے زمین سے نکالا اور خاص ناقص کا ارادہ نہ کرو کہ دو تو اس میں سے اور تمہیں ملے تو نہ لوگے جب تک اس میں چشم پوشی نہ کرو اور جان رکھو کہ اللہ بے پروانہ سراہا گیا ہے۔\qt@no{(267)}}%
\qt@newcmd\qurantrans@ur@cclxxv{شیطان تمہیں اندیشہ دلاتا ہے محتاجی کا اور حکم دیتا ہے بے حیائی کا اور اللہ تم سے وعدہ فرماتا ہے بخشش اور فضل کا اور اللہ وسعت و الا علم والا ہے،\qt@no{(268)}}%
\qt@newcmd\qurantrans@ur@cclxxvi{اللہ حکمت دیتا ہے جسے چاہے اور جسے حکمت ملی اسے بہت بھلائی ملی، اور نصیحت نہیں مانتے مگر عقل والے،\qt@no{(269)}}%
\qt@newcmd\qurantrans@ur@cclxxvii{اور تم جو خرچ کرو یا منت مانو اللہ کو اس کی خبر ہے اور ظالموں کا کوئی مددگار نہیں،\qt@no{(270)}}%
\qt@newcmd\qurantrans@ur@cclxxviii{اگر خیرات اعلانیہ دو تو وہ کیا ہی اچھی بات ہے اور اگر چھپا کر فقیروں کو دو یہ تمہارے لئے سب سے بہتر ہے اور اسمیں تمہارے کچھ گناہ گھٹیں گے، اور اللہ کو تمہارے کاموں کی خبر ہے،\qt@no{(271)}}%
\qt@newcmd\qurantrans@ur@cclxxix{انہیں راہ دینا تمہارے ذمہ لازم نہیں، ہاں اللہ راہ دیتا ہے جسے چاہتا ہے، اور تم جو اچھی چیز دو تو تمہارا ہی بھلا ہے اور تمہیں خرچ کرنا مناسب نہیں مگر اللہ کی مرضی چاہنے کے لئے، اور جو مال دو تمہیں پورا ملے گا اور نقصان نہ دیئے جاؤ گے،\qt@no{(272)}}%
\qt@newcmd\qurantrans@ur@cclxxx{ان فقیروں کے لئے جو راہ خدا میں روکے گئے زمین میں چل نہیں سکتے نادان انہیں تونگر سمجھے بچنے کے سبب تو انہیں ان کی صورت سے پہچان لے گا لوگوں سے سوال نہیں کرتے کہ گڑ گڑانا پڑے اور تم جو خیرات کرو اللہ اسے جانتا ہے،\qt@no{(273)}}%
\qt@newcmd\qurantrans@ur@cclxxxi{وہ جو اپنے مال خیرات کرتے ہیں رات میں اور دن میں چھپے اور ظاہر ان کے لئے ان کا نیگ (انعام، حصہ) ہے ان کے رب کے پاس ان کو نہ کچھ اندیشہ ہو نہ کچھ غم،\qt@no{(274)}}%
\qt@newcmd\qurantrans@ur@cclxxxii{وہ جو سود کھاتے ہیں قیامت کے دن نہ کھڑے ہوں گے مگر، جیسے کھڑا ہوتا ہے وہ جسے آسیب نے چھو کر مخبوط بنادیا ہو اس لئے کہ انہوں نے کہا بیع بھی تو سود ہی کے مانند ہے، اور اللہ نے حلال کیا بیع کو اور حرام کیا سود، تو جسے اس کے رب کے پاس سے نصیحت آئی اور وہ باز رہا تو اسے حلال ہے جو پہلے لے چکا، اور اس کا کام خدا کے سپرد ہے اور جو اب ایسی حرکت کرے گا تو وہ دوزخی ہے وہ اس میں مدتو ں رہیں گے\qt@no{(275)}}%
\qt@newcmd\qurantrans@ur@cclxxxiii{اللہ ہلاک کرتا ہے سود کو اور بڑھاتا ہے خیرات کو اور اللہ کو پسند نہیں آتا کوئی ناشکرا بڑا گنہگار،\qt@no{(276)}}%
\qt@newcmd\qurantrans@ur@cclxxxiv{بیشک وہ جو ایمان لائے اور اچھے کام کئے اور نماز قائم کی اور زکوٰة دی ان کا نیگ (انعام) ان کے رب کے پاس ہے، اور نہ انہیں کچھ اندیشہ ہو، نہ کچھ غم،\qt@no{(277)}}%
\qt@newcmd\qurantrans@ur@cclxxxv{اے ایمان والو! اللہ سے ڈرو اور چھوڑ دو جو باقی رہ گیا ہے سود اگر مسلمان ہو\qt@no{(278)}}%
\qt@newcmd\qurantrans@ur@cclxxxvi{پھر اگر ایسا نہ کرو تو یقین کرلو اللہ اور اللہ کے رسول سے لڑائی کا اور اگر تم توبہ کرو تو اپنا اصل مال لے لو نہ تم کسی کو نقصان پہچاؤ نہ تمہیں نقصان ہو\qt@no{(279)}}%
\qt@newcmd\qurantrans@ur@cclxxxvii{اور اگر قرضدار تنگی والا ہے تو اسے مہلت دو آسانی تک، اور قرض اس پر بالکل چھوڑ دینا تمہارے لئے اور بھلا ہے اگر جانو\qt@no{(280)}}%
\qt@newcmd\qurantrans@ur@cclxxxviii{اور ڈرو اس دن سے جس میں اللہ کی طرف پھرو گے، اور ہر جان کو اس کی کمائی پوری بھردی جائے گی اور ان پر ظلم نہ ہوگا\qt@no{(281)}}%
\qt@newcmd\qurantrans@ur@cclxxxix{اے ایمان والو! جب تم ایک مقرر مدت تک کسی دین کا لین دین کرو تو اسے لکھ لو اور چاہئے کہ تمہارے درمیان کوئی لکھنے والا ٹھیک ٹھیک لکھے اور لکھنے والا لکھنے سے انکار نہ کرے جیسا کہ اسے اللہ نے سکھایا ہے تو اسے لکھ دینا چاہئے اور جس بات پر حق آتا ہے وہ لکھا تا جائے اور اللہ سے ڈرے جو اس کا رب ہے اور حق میں سے کچھ رکھ نہ چھوڑے پھر جس پر حق آتا ہے اگر بے عقل یا ناتواں ہو یا لکھا نہ سکے تو اس کا ولی انصاف سے لکھائے، اور دو گواہ کرلو اپنے مردوں میں سے پھر اگر دو مرد نہ ہوں تو ایک مرد اور دو عورتیں ایسے گواہ جن کو پسند کرو کہ کہیں ان میں ایک عورت بھولے تو اس کو دوسری یاد دلادے، اور گواہ جب بلائے جائیں تو آنے سے انکار نہ کریں اور اسے بھاری نہ جانو کہ دین چھوٹا ہو یا بڑا اس کی میعاد تک لکھت کرلو یہ اللہ کے نزدیک زیادہ انصاف کی بات ہے اس میں گواہی خوب ٹھیک رہے گی اور یہ اس سے قریب ہے کہ تمہیں شبہ نہ پڑے مگر یہ کہ کوئی سردست کا سودا دست بدست ہو تو اس کے نہ لکھنے کا تم پر گناہ نہیں اور جب خرید و فروخت کرو تو گواہ کرلو اور نہ کسی لکھنے والے کو ضَرر دیا جائے، نہ گواہ کو (یا، نہ لکھنے والا ضَرر دے نہ گواہ) اور جو تم ایسا کرو تو یہ تمہارا فسق ہوگا، اور اللہ سے ڈرو اور اللہ تمہیں سکھاتا ہے، اور اللہ سب کچھ جانتا ہے،\qt@no{(282)}}%
\qt@newcmd\qurantrans@ur@ccxc{اور اگر تم سفر میں ہو اور لکھنے والا نہ پاؤ تو گِرو (رہن) ہو قبضہ میں دیا ہوا اور اگر تم ایک کو دوسرے پر اطمینان ہو تو وہ جسے اس نے امین سمجھا تھا اپنی امانت ادا کردے اور اللہ سے ڈرے جو اس کا رب ہے اور گواہی نہ چھپاؤ اور جو گواہی چھپائے گا تو اندر سے اسکا دل گنہگار ہے اور اللہ تمہارے کاموں کو جانتا ہے،\qt@no{(283)}}%
\qt@newcmd\qurantrans@ur@ccxci{اللہ ہی کا ہے جو کچھ آسمانوں میں ہے اور جو کچھ زمین میں ہے، اور اگر تم ظاہر کرو جو کچھ تمہارے جی میں ہے یا چھپاؤ اللہ تم سے اس کا حساب لے گا تو جسے چاہے گا بخشے گا اور جسے چاہے گا سزادے گا اور اللہ ہر چیز پر قادر ہے،\qt@no{(284)}}%
\qt@newcmd\qurantrans@ur@ccxcii{سب نے مانا اللہ اور اس کے فرشتوں اور اس کی کتابوں اور اس کے رسولوں کو یہ کہتے ہوئے کہ ہم اس کے کسی رسول پر ایمان لانے میں فرق نہیں کرتے اور عرض کی کہ ہم نے سنا اور مانا تیری معافی ہو اے رب ہمارے! اور تیری ہی طرف پھرنا ہے،\qt@no{(285)}}%
\qt@newcmd\qurantrans@ur@ccxciii{اللہ کسی جان پر بوجھ نہیں ڈالتا مگر اس کی طاقت بھر، اس کا فائدہ ہے جو اچھا کمایا اور اس کا نقصان ہے جو برائی کمائی اے رب ہمارے! ہمیں نہ پکڑ اگر ہم بھولیں یا چوُکیں اے رب ہمارے! اور ہم پر بھاری بوجھ نہ رکھ جیسا تو نے ہم سے اگلوں پر رکھا تھا، اے رب ہمارے! اور ہم پر وہ بوجھ نہ ڈال جس کی ہمیں سہار (برداشت) نہ ہو اور ہمیں معاف فرمادے اور بخش دے اور ہم پر مہر کر تو ہمارا مولیٰ ہے۔ تو کافروں پر ہمیں مدد دے۔\qt@no{(286)}}%
\qt@newcmd\qurantrans@ur@ccxciv{\basmalahur الم،\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@ccxcv{اللہ ہے جس کے سوا کسی کی پوجا نہیں آپ زندہ اور ونکا قائم رکھنے والا،\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@ccxcvi{اس نے تم پر یہ سچی کتاب اتاری اگلی کتابوں کی تصدیق فرماتی اور اس نے اس سے پہلے توریت اور انجیل اتاری،\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@ccxcvii{لوگوں کو راہ دکھاتی اور فیصلہ اتارا، بیشک وہ جو اللہ کی آیتوں سے منکر ہوئے ان کے لئے سخت عذاب ہے اور اللہ غالب بدلہ لینے والا ہے،\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@ccxcviii{اللہ پر کچھ چھپا ہوا نہیں زمین میں نہ آسمان میں،\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@ccxcix{وہی ہے کہ تمہاری تصویر بناتا ہے ماؤں کے پیٹ میں جیسی چاہے اس کے سوا کسی کی عبادت نہیں عزت والا حکمت والا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@ccc{وہی ہے جس نے تم پر یہ کتاب اتاری اس کی کچھ آیتیں صاف معنی رکھتی ہیں وہ کتاب کی اصل ہیں اور دوسری وہ ہیں جن کے معنی میں اشتباہ ہے وہ جن کے دلوں میں کجی ہے وہ اشتباہ والی کے پیچھے پڑتے ہیں گمراہی چاہنے اور اس کا پہلو ڈھونڈنے کو اور اس کا ٹھیک پہلو اللہ ہی کو معلوم ہے اور پختہ علم والے کہتے ہیں ہم اس پر ایمان لائے سب ہمارے رب کے پاس سے ہے اور نصیحت نہیں مانتے مگر عقل والے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@ccci{اے رب ہمارے دل ٹیڑھے نہ کر بعد اس کے کہ تو نے ہمیں ہدایت دی اور ہمیں اپنے پاس سے رحمت عطا کر بیشک تو ہے بڑا دینے والا،\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@cccii{اے رب ہمارے بیشک تو سب لوگوں کو جمع کرنے والا ہے اس دن کے لئے جس میں کوئی شبہ نہیں بیشک اللہ کا وعدہ نہیں بدلتا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@ccciii{بیشک وہ جو کافر ہوئے ان کے مال اور ان کی اولاد اللہ سے انہیں کچھ نہ بچاسکیں گے اور وہی دوزخ کے ایندھن ہیں،\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@ccciv{جیسے فرعون والوں اور ان سے اگلوں کا طریقہ، انہوں نے ہماری آیتیں جھٹلائیں تو اللہ نے ان کے گناہوں پر ان کو پکڑا اور اللہ کا عذاب سخت،\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@cccv{فرمادو، کافروں سے کوئی دم جاتا ہے کہ تم مغلوب ہوگے اور دوزخ کی طرف ہانکے جاؤ گے اور وہ بہت ہی برا بچھونا،\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@cccvi{بیشک تمہارے لئے نشانی تھی دو گروہوں میں جو آپس میں بھڑ پڑے ایک جتھا اللہ کی راہ میں لڑتا اور دوسرا کافر کہ انہیں آنکھوں دیکھا اپنے سے دونا سمجھیں، اور اللہ اپنی مدد سے زور دیتا ہے جسے چاہتا ہے بیشک اس میں عقلمندوں کے لئے ضرور دیکھ کر سیکھنا ہے،\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@cccvii{لوگوں کے لئے آراستہ کی گئی ان خواہشوں کی محبت عورتوں اور بیٹے اور تلے اوپر سونے چاندے کے ڈھیر اور نشان کئے ہوئے گھوڑے اور چوپائے اور کھیتی یہ جیتی دنیا کی پونجی ہے اور اللہ ہے جس کے پاس اچھا ٹھکانا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@cccviii{تم فرماؤ کیا میں تمہیں اس سے بہتر چیز بتادوں پرہیزگاروں کے لئے ان کے رب کے پاس جنتیں ہیں جن کے نیچے نہریں رواں ہمیشہ ان میں رہیں گے اور ستھری بیبیاں اور اللہ کی خوشنودی اور اللہ بندوں کو دیکھتا ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@cccix{وہ جو کہتے ہیں ے رب ہمارے! ہم ایمان لائے تو ہمارے گناہ معاف کر اور ہمیں دوزخ کے عذاب سے بچالے،\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@cccx{صبر والے اور سچے اور ادب والے اور راہِ خدا میں خرچنے والے اور پچھلے پہر سے معافی مانگنے والے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@cccxi{اور اللہ نے گواہی دی کہ اس کے سوا کوئی معبود نہیں اور فرشتوں نے اور عالموں نے انصاف سے قائم ہوکر اس کے سوا کسی کی عبادت نہیں عزت والا حکمت والا،\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@cccxii{بیشک اللہ کے یہاں اسلام ہی دین ہے اور پھوٹ میں نہ پڑے کتابی مگر اس کے کہ انہیں علم آچکا اپنے دلو ں کی جلن سے اور جو اللہ کی آیتوں کا منکر ہو تو بیشک اللہ جلد حساب لینے والا ہے،\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@cccxiii{پھر اے محبوب! اگر وہ تم سے حجت کریں تو فرمادو میں اپنا منہ اللہ کے حضور جھکائے ہوں اور جومیرے پیرو ہوئے اور کتابیوں اور اَن پڑھوں سے فرماؤ کیا تم نے گردن رکھی پس اگر وہ گردن رکھیں جب تو راہ پاگئے اور اگر منہ پھیریں تو تم پر تو یہی حکم پہنچادینا ہے اور اللہ بندوں کو کو دیکھ رہا ہے،\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@cccxiv{وہ جو اللہ کی آیتوں سے منکر ہوتے اور پیغمبروں کو ناحق شہید کرتے اور انصاف کا حکم کرنے والوں کو قتل کرتے ہیں انہیں خوشخبری دو درناک عذاب کی،\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@cccxv{یہ ہیں وہ جنکے اعمال اکارت گئے دنیا و آخرت میں اور ان کا کوئی مددگار نہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@cccxvi{کیا تم نے انہیں دیکھا جنہیں کتاب کا ایک حصہ ملا کتاب اللہ کی طرف بلائے جاتے ہیں کہ وہ ان کا فیصلہ کرے پھر ان میں کا ایک گروہ اس سے روگرداں ہوکر پھر جاتا ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@cccxvii{یہ جرأت انہیں اس لئے ہوئی کہ وہ کہتے ہیں ہرگز ہمیں آگ نہ چھوئے گی مگر گنتی کے دنوں اور ان کے دین میں انہیں فریب دیا اس جھوٹ نے جو باندھتے تھے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@cccxviii{تو کیسی ہوگی جب ہم انہیں اکٹھا کریں گے اس دن کے لئے جس میں شک نہیں اور ہر جان کو اس کی کمائی پوری بھر (بالکل پوری) دی جائے گی اور ان پر ظلم نہ ہوگا،\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@cccxix{یوں عرض کر، اے اللہ! ملک کے مالک تو جسے چاہے سلطنت دے اور جس سے چاہے چھین لے، اور جسے چاہے عزت دے اور جسے چاہے ذلت دے، ساری بھلائی تیرے ہی ہاتھ ہے، بیشک تو سب کچھ کرسکتا ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@cccxx{تو دن کا حصّہ رات میں ڈالے اور رات کا حصہ دن میں ڈالے اور مردہ سے زندہ نکالے اور زندہ سے مردہ نکالے اور جسے چاہے بے گنتی دے،\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@cccxxi{مسلمان کافروں کو اپنا دوست نہ بنالیں مسلمانوں کے سوا اور جو ایسا کرے گا اسے اللہ سے کچھ علاقہ نہ رہا مگر یہ کہ تم ان سے کچھ ڈرو اور اللہ تمہیں اپنے غضب سے ڈراتا ہے اور اللہ ہی کی طرف پھرنا ہے،\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@cccxxii{تم فرمادو کہ اگر تم اپنے جی کی بات چھپاؤ یا ظاہر کرو اللہ کو سب معلوم ہے، اور جانتا ہے جو کچھ آسمانوں میں ہے اور جو کچھ زمین میں ہے، اور ہر چیز پر اللہ کا قابو ہے،\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@cccxxiii{جس دن ہر جان نے جو بھلا کیا حاضر پائے گی اور جو برا کام کیا، امید کرے گی کاش مجھ میں اور اس میں دور کا فاصلہ ہوتا اور اللہ تمہیں اپنے عذاب سے ڈراتا ہے، اور اللہ بندوں پر مہربان ہے،\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@cccxxiv{اے محبوب! تم فرمادو کہ لوگو اگر تم اللہ کو دوست رکھتے ہو تو میرے فرمانبردار ہوجاؤ اللہ تمہیں دوست رکھے گا اور تمہارے گناہ بخش دے گا اور اللہ بخشنے والا مہربان ہے،\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@cccxxv{تم فرمادو کہ حکم مانو اللہ اور رسول کا پھر اگر وہ منہ پھیریں تو اللہ کو خوش نہیں آتے کافر،\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@cccxxvi{بیشک اللہ نے چن لیا آدم اور نوح اور ابراہیم کی آ ل اولاد اور عمران کی آ ل کو سارے جہاں سے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@cccxxvii{یہ ایک نسل ہے ایک دوسرے سے اور اللہ سنتا جانتا ہے،\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@cccxxviii{جب عمران کی بی بی نے عرض کی اے رب میرے! میں تیرے لئے منت مانتی ہو جو میرے پیٹ میں ہے کہ خالص تیری ہی خدمت میں رہے تو تو مجھ سے قبول کرلے بیشک تو ہی سنتا جانتا،\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@cccxxix{پھر جب اسے جنا بولی، اے رب میرے! یہ تو میں نے لڑکی جنی اور اللہ جو خوب معلوم ہے جو کچھ وہ جنی، اور وہ لڑکا جو اس نے مانگا اس لڑکی سا نہیں اور میں نے اس کا نام مریم رکھا اور میں اسے اور اس کی اولاد کو تیری پناہ میں دیتی ہوں راندے ہوئے شیطان سے،\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@cccxxx{تو اسے اس کے رب نے اچھی طرح قبول کیا اور اسے اچھا پروان چڑھایا اور اسے زکریا کی نگہبانی میں دیا، جب زکریا اس کے پاس اس کی نماز پڑھنے کی جگہ جاتے اس کے پاس نیا رزق پاتے کہا اے مریم! یہ تیرے پاس کہاں سے آیا، بولیں وہ اللہ کے پاس سے ہے، بیشک اللہ جسے چاہے بے گنتی دے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@cccxxxi{یہاں پکارا زکریا اپنے رب کو بولا اے رب! میرے مجھے اپنے پاس سے دے ستھری اولاد، بیشک تو ہی ہے دعا سننے والا،\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@cccxxxii{تو فرشتوں نے اسے آواز دی اور وہ اپنی نماز کی جگہ کھڑا نماز پڑھ رہا تھا بیشک اللہ آپ کو مژدہ دیتا ہے یحییٰ کا جو اللہ کی طرف کے ایک کلمہ کی تصدیق کرے گا اور سردار اور ہمیشہ کے لیے عورتوں سے بچنے والا اور نبی ہمارے خاصوں میں سے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@cccxxxiii{بولا اے میرے رب میرے لڑکا کہاں سے ہوگا مجھے تو پہنچ گیا بڑھا پا اور میری عورت بانجھ فرمایا اللہ یوں ہی کرتا ہے جو چاہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@cccxxxiv{عرض کی اے میرے رب میرے لئے کوئی نشانی کردے فرمایا تیری نشانی یہ ہے کہ تین دن تو لوگوں سے بات نہ کرے مگر اشارہ سے اور اپنے رب کی بہت یاد کر اور کچھ دن رہے اور تڑکے اس کی پاکی بول،\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@cccxxxv{اور جب فرشتوں نے کہا، اے مریم، بیشک اللہ نے تجھے چن لیا اور خوب ستھرا کیا اور آج سارے جہاں کی عورتوں سے تجھے پسند کیا\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@cccxxxvi{اے مریم اپنے رب کے حضور ادب سے کھڑی ہو اور اس کے لئے سجدہ کر اور رکوع والوں کے ساتھ رکوع کر،\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@cccxxxvii{یہ غیب کی خبریں ہیں کہ ہم خفیہ طور پر تمہیں بتاتے ہیں اور تم ان کے پاس نہ تھے جب وہ اپنی قلموں سے قرعہ ڈالتے تھے کہ مریم کس کی پرورش میں رہیں اور تم ان کے پاس نہ تھے جب وہ جھگڑ رہے تھے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@cccxxxviii{اور یاد کرو جب فرشتو ں نے مریم سے کہا، اے مریم! اللہ تجھے بشارت دیتا ہے اپنے پاس سے ایک کلمہ کی جس کا نام ہے مسیح عیسیٰ مریم کا بیٹا رُو دار (باعزت) ہوگا دنیا اور آخرت میں اور قرب والا\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@cccxxxix{اور لوگوں سے بات کرے گا پالنے میں اور پکی عمر میں اور خاصوں میں ہوگا،\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@cccxl{بولی اے میرے رب! میرے بچہ کہاں سے ہوگا مجھے تو کسی شخص نے ہاتھ نہ لگایا فرمایا اللہ یوں ہی پیدا کرتا ہے جو چاہے جب، کسی کام کا حکم فرمائے تو اس سے یہی کہتا ہے کہ ہوجا وہ فوراً ہوجاتا ہے،\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@cccxli{اور اللہ سکھائے گا کتاب اور حکمت اور توریت اور انجیل،\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@cccxlii{اور رسول ہوگا بنی اسرائیل کی طرف، یہ فرماتا ہو کہ میں تمہارے پاس ایک نشانی لایا ہوں تمہارے رب کی طرف سے کہ میں تمہارے لئے مٹی سے پرند کی سی مور ت بناتا ہوں پھر اس میں پھونک مارتا ہوں تو وہ فوراً پرند ہوجاتی ہے اللہ کے حکم سے اور میں شفا دیتا ہوں مادر زاد اندھے اور سفید داغ والے کو اور میں مُردے جلاتا ہوں اللہ کے حکم سے اور تمہیں بتاتا ہوں جو تم کھاتے اور جو اپنے گھروں میں جمع کر رکھتے ہو، بیشک ان باتوں میں تمہارے لئے بڑی نشانی ہے اگر تم ایمان رکھتے ہو،\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@cccxliii{اور تصدیق کرتا آیا ہوں اپنے سے پہلے کتاب توریت کی اور اس لئے کہ حلال کروں تمہارے لئے کچھ وہ چیزیں جو تم پر حرام تھیں اور میں تمہارے پاس پاس تمہارے رب کی طرف سے نشانی لایا ہوں، تو اللہ سے ڈرو اور میرا حکم مانو،\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@cccxliv{بیشک میرا تمہارا سب کا رب اللہ ہے تو اسی کو پوجو یہ ہے سیدھا راستہ،\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@cccxlv{پھر جب عیسیٰ نے ان سے کفر پایا بولا کون میرے مددگار ہوتے ہیں اللہ کی طرف، حواریوں نے کہا ہم دینِ خدا کے مددگار ہیں ہم اللہ پر ایمان لائے، اور آپ گواہ ہوجائیں کہ ہم مسلمان ہیں\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@cccxlvi{اے رب ہمارے! ہم اس پر ایمان لائے جو تو نے اتارا اور رسول کے تابع ہوئے تو ہمیں حق پر گواہی دینے والوں میں لکھ لے،\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@cccxlvii{اور کافروں نے مکر کیا اور اللہ نے ان کے ہلاک کی خفیہ تدبیر فرمائی اور اللہ سب سے بہتر چھپی تدبیر والا ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@cccxlviii{یاد کرو جب اللہ نے فرمایا اے عیسیٰ میں تجھے پوری عمر تک پہنچاؤں گا اور تجھے اپنی طرف اٹھالوں گا اور تجھے کافروں سے پاک کردوں گا اور تیرے پیروؤں کو قیامت تک تیرے منکروں پر غلبہ دوں گا پھر تم سب میری طرف پلٹ کر آؤ گے تو میں تم میں فیصلہ فرمادوں گا جس بات میں جھگڑتے ہو،\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@cccxlix{تو وہ جو کافر ہوئے میں انہیں دنیاو آخرت میں سخت عذاب کروں گا، اور انکا کوئی مددگار نہ ہوگا،\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@cccl{اور وہ جو ایمان لائے اور اچھے کام کئے اللہ ان کا نیگ (انعام) انہیں بھرپور دے گا اور ظالم اللہ کو نہیں بھاتے،\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@cccli{یہ ہم تم پر پڑھتے ہیں کچھ آیتیں اور حکمت والی نصیحت،\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@ccclii{عیسیٰ کی کہاوت اللہ کے نزدیک آدم کی طرح ہے اسے مٹی سے بنایا پھر فرمایا ہوجا وہ فوراً ہوجاتا ہے،\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@cccliii{اے سننے والے! یہ تیرے رب کی طرف سے حق ہے تو شک والوں میں نہ ہونا،\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@cccliv{پھر اے محبوب! جو تم سے عیسیٰ کے بارے میں حجت کریں بعد اس کے کہ تمہیں علم آچکا تو ان سے فرما دو آ ؤ ہم بلائیں اپنے بیٹے اور تمہارے بیٹے اور اپنی عورتیں اور تمہاری عورتیں اور اپنی جانیں اور تمہاری جانیں، پھر مباہلہ کریں تو جھوٹوں پر اللہ کی لعنت ڈالیں\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@ccclv{یہی بیشک سچا بیان ہے اور اللہ کے سوا کوئی معبود نہیں اور بیشک اللہ ہی غالب ہے حکمت والا،\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@ccclvi{پھر اگر وہ منہ پھیریں تو اللہ فسادیوں کو جانتا ہے،\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@ccclvii{تم فرماؤ، اے کتابیو! ایسے کلمہ کی طرف آؤ جو ہم میں تم میں یکساں ہے یہ کہ عبادت نہ کریں مگر خدا کی اور اس کا شریک کسی کو نہ کریں اور ہم میں کوئی ایک دوسرے کو رب نہ بنالے اللہ کے سوا پھر اگر وہ نہ مانیں تو کہہ دو تم گواہ رہو کہ ہم مسلمان ہیں،\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@ccclviii{اے کتاب والو! ابراہیم کے باب میں کیوں جھگڑتے ہو توریت و انجیل تو نہ اتری مگر ان کے بعد تو کیا تمہیں عقل نہیں\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@ccclix{سنتے ہو یہ جو تم ہو اس میں جھگڑے جس کا تمہیں علم تھا تو اس میں کیوں جھگڑتے ہو جس کا تمہیں علم ہی نہیں اور اللہ جانتا ہے اور تم نہیں جانتے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@ccclx{ابراہیم نہ یہودی تھے نہ نصرانی بلکہ ہر باطل سے جدا مسلمان تھے، اور مشرکوں سے نہ تھے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@ccclxi{بیشک سب لوگوں سے ابراہیم کے زیادہ حق دار وہ تھے جو ان کے پیرو ہوئے اور یہ نبی اور ایمان والے اور ایمان والوں کا ولی اللہ ہے،\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@ccclxii{کتابیوں کا ایک گروہ دل سے چاہتا ہے کہ کسی طرح تمہیں گمراہ کردیں، اور وہ اپنے ہی آپ کو گمراہ کرتے ہیں اور انہیں شعور نہیں\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@ccclxiii{اے کتابیو! اللہ کی آیتوں سے کیوں کفر کرتے ہو حالانکہ تم خود گواہی ہو\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@ccclxiv{اے کتابیو! حق میں باطل کیوں ملاتے ہو اور حق کیوں چھپاتے ہو حالانکہ تمہیں خبر ہے،\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@ccclxv{اور کتابیوں کا ایک گروہ بولا وہ جو ایمان والوں پر اترا صبح کو اس پر ایمان لاؤ اور شام کو منکر ہوجاؤ شاید وہ پھر جائیں\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@ccclxvi{اور یقین نہ لاؤ مگر اس کا جو تمہارے دین کا پیرو ہو تم فرمادو کہ اللہ ہی کی ہدایت ہدایت ہے (یقین کا ہے کا نہ لاؤ) اس کا کہ کسی کو ملے جیسا تمہیں ملا یا کوئی تم پر حجت لاسکے تمہارے رب کے پاس تم فرمادو کہ فضل تو اللہ ہی کے ہاتھ ہے جسے چاہے دے، اور اللہ وسعت والا علم والا ہے،\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@ccclxvii{اپنی رحمت سے خاص کرتا ہے جسے چاہے اور اللہ بڑے فضل والا ہے،\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@ccclxviii{اور کتابیوں میں کوئی وہ ہے کہ اگر تو اس کے پاس ایک ڈھیر امانت رکھے تو وہ تجھے ادا کردے گا اور ان میں کوئی وہ ہے کہ اگر ایک اشرفی اس کے پاس امانت رکھے تو وہ تجھے پھیر کر نہ دے گا مگر جب تک تو اس کے سر پر کھڑا رہے یہ اس لئے کہ وہ کہتے ہیں کہ اَن پڑھوں کے معاملہ میں ہم پر کوئی مؤاخذہ نہیں اور اللہ پر جان بوجھ کر جھوٹ باندھتے ہیں\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@ccclxix{ہاں کیوں نہیں جس نے اپنا عہد پورا کیا اور پرہیزگاری کی اور بیشک پرہیزگار اللہ کو خوش آتے ہیں،\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@ccclxx{جو اللہ کے عہد اور اپنی قسموں کے بدلے ذلیل دام لیتے ہیں آخرت میں ان کا کچھ حصہ نہیں اور اللہ نہ ان سے بات کرے نہ ان کی طرف نظر فرمائے قیامت کے دن اور نہ انہیں پاک کرے، اور ان کے لئے دردناک عذاب ہے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@ccclxxi{اور ان میں کچھ وہ ہیں جو زبان پھیر کر کتاب میں میل (ملاوٹ) کرتے ہیں کہ تم سمجھو یہ بھی کتاب میں ہے اور وہ کتاب میں نہیں، اور وہ کہتے ہیں یہ اللہ کے پاس سے ہے اور وہ اللہ کے پاس سے نہیں، اور اللہ پر دیدہ و دانستہ جھوٹ باندھتے ہیں\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@ccclxxii{کسی آدمی کا یہ حق نہیں کہ اللہ اسے کتاب اور حکم و پیغمبری دے پھر وہ لوگوں سے کہے کہ اللہ کو چھوڑ کر میرے بندے ہوجاؤ ہاں یہ کہے گا کہ اللہ والے ہوجاؤ اس سبب سے کہ تم کتاب سکھاتے ہو اور اس سے کہ تم درس کرتے ہو\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@ccclxxiii{اور نہ تمہیں یہ حکم دے گا کہ فرشتوں اور پیغمبروں کو خدا ٹھیرالو، کیا تمہیں کفر کا حکم دے گا بعد اس کے کہ تم مسلمان ہولیے\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@ccclxxiv{اور یاد کرو جب اللہ نے پیغمبروں سے ان کا عہد لیا جو میں تم کو کتاب اور حکمت دوں پھر تشریف لائے تمہارے پاس وہ رسول کہ تمہاری کتابوں کی تصدیق فرمائے تو تم ضرور ضرور اس پر ایمان لانا اور ضرور ضرور اس کی مدد کرنا، فرمایا کیوں تم نے اقرار کیا اور اس پر میرا بھاری ذمہ لیا؟ سب نے عرض کی، ہم نے اقرار کیا، فرمایا تو ایک دوسرے پر گواہ ہوجاؤ اور میں آپ تمہارے ساتھ گواہوں میں ہوں،\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@ccclxxv{تو جو کوئی اس کے بعد پھرے تو وہی لوگ فاسق ہیں\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@ccclxxvi{تو کیا اللہ کے دین کے سوا اور دین چاہتے ہیں اور اسی کے حضور گردن رکھے ہیں جو کوئی آسمانوں اور زمین میں ہیں خوشی سے سے مجبوری سے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@ccclxxvii{اور اُسی کی طرف پھیریں گے، یوں کہو کہ ہم ایمان لائے اللہ پر اور اس پر جو ہماری طرف اترا اور جو اترا ابراہیم اور اسماعیل اور اسحاق اور یعقوب اور ان کے بیٹوں پر اور جو کچھ ملا موسیٰ اور عیسیٰ اور انبیاء کو ان کے رب سے، ہم ان میں کسی پر ایمان میں فرق نہیں کرتے اور ہم اسی کے حضور گردن جھکائے ہیں\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@ccclxxviii{اور جو اسلام کے سوا کوئی دین چاہے گا وہ ہرگز اس سے قبول نہ کیا جائے گا اور وہ آخرت میں زیاں کاروں سے ہے،\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@ccclxxix{کیونکر اللہ ایسی قوم کی ہدایت چاہے جو ایمان لاکر کافر ہوگئے اور گواہی دے چکے تھے کہ رسول سچا ہے اور انہیں کھلی نشانیاں آچکی تھیں اور اللہ ظالموں کو ہدایت نہیں کرتا\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@ccclxxx{ان کا بدلہ یہ ہے کہ ان پر لعنت ہے اللہ اور فرشتوں اور آدمیوں کی سب کی،\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@ccclxxxi{ہمیشہ اس میں رہیں، نہ ان پر سے عذاب ہلکا ہو اور نہ انہیں مہلت دی جائے،\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@ccclxxxii{مگر جنہوں نے اس کے بعد توبہ کی اور آپا سنبھالا تو ضرور اللہ بخشنے والا مہربان ہے،\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@ccclxxxiii{بیشک وہ جو ایمان لاکر کافر ہوئے پھر اور کفر میں بڑھے ان کی توبہ ہرگز قبول نہ ہوگی اور وہی ہیں بہکے ہوئے،\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@ccclxxxiv{وہ جو کافر ہوئے اور کافر ہی مرے ان میں کسی سے زمین بھر سونا ہرگز قبول نہ کیا جائے گا اگرچہ اپنی خلاصی کو دے، ان کے لئے دردناک عذاب ہے اور ان کا کوئی یار نہیں۔\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@ccclxxxv{تم ہرگز بھلائی کو نہ پہنچو گے جب تک راہِ خدا میں اپنی پیاری چیز نہ خرچ کرو اور تم جو کچھ خرچ کرو اللہ کو معلوم ہے،\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@ccclxxxvi{سب کھانے بنی اسرائیل کو حلال تھے مگر وہ جو یعقوبؑ نے اپنے اوپر حرام کرلیا تھا توریت اترنے سے پہلے تم فرماؤ توریت لاکر پڑھو اگر سچے ہو\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@ccclxxxvii{تو اس کے بعد جو اللہ پر جھوٹ باندھے تو وہی ظالم ہیں،\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@ccclxxxviii{تم فرماؤ اللہ سچا ہے، تو ابراہیم کے دین پر چلو جو ہر باطل سے جدا تھے اور شرک والوں میں نہ تھے،\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@ccclxxxix{بیشک سب میں پہلا گھر جو لوگوں کی عبادت کو مقرر ہوا وہ ہے جو مکہ میں ہے برکت والا اور سارے جہان کا راہنما\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@cccxc{اس میں کھلی نشانیاں ہیں ابراہیم کے کھڑے ہونے کی جگہ اور جو اس میں آئے امان میں ہو اور اللہ کے لئے لوگوں پر اس گھر کا حج کرنا ہے جو اس تک چل سکے اور جو منکر ہو تو اللہ سارے جہان سے بے پرواہ ہے\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@cccxci{تم فرماؤ اے کتابیو! اللہ کی آیتیں کیوں نہیں مانتے اور تمہارے کام اللہ سامنے ہیں،\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@cccxcii{تم فرماؤ اے کتابیو! کیوں اللہ کی راہ سے روکتے ہو اسے جو ایمان لائے اسے ٹیڑھا کیا چاہتے ہو اور تم خود اس پر گواہ ہو اور اللہ تمہارے کوتکوں (برے اعمال، کرتوت) سے بے خبر نہیں،\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@cccxciii{اے ایمان والو! اگر تم کچھ کتابیوں کے کہے پر چلے تو وہ تمہارے ایمان کے بعد کافر کر چھوڑیں گے\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@cccxciv{اور تم کیوں کر کفر کروگے تم پر اللہ کی آیتیں پڑھی جاتی ہیں اور تم میں اس کا رسول تشریف لایا اور جس نے اللہ کا سہارا لیا تو ضرور وہ سیدھی راہ دکھایا گیا،\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@cccxcv{اے ایمان والو! اللہ سے ڈرو جیسا اس سے ڈرنے کا حق ہے اور ہرگز نہ مرنا مگر مسلمان،\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@cccxcvi{اور اللہ کی رسی مضبوط تھام لو سب مل کر اور آپس میں پھٹ نہ جانا (فرقوں میں نہ بٹ جانا) اور اللہ کا احسان اپنے اوپر یاد کرو جب تم میں بیر تھا اس نے تمہارے دلوں میں ملاپ کردیا تو اس کے فضل سے تم آپس میں بھائی ہوگئے اور تم ایک غار دوزخ کے کنارے پر تھے تو اس نے تمہیں اس سے بچادیا اللہ تم سے یوں ہی اپنی آیتیں بیان فرماتا ہے کہ کہیں تم ہدایت پاؤ،\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@cccxcvii{اور تم میں ایک گروہ ایسا ہونا چاہئے کہ بھلائی کی طرف بلائیں اور اچھی بات کا حکم دیں اور بری سے منع کریں اور یہی لوگ مراد کو پہنچے\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@cccxcviii{اور ان جیسے نہ ہونا جو آپس میں پھٹ گئے اور ان میں پھوٹ پڑگئی بعد اس کے کہ روشن نشانیاں انہیں آچکی تھیں اور ان کے لیے بڑا عذاب ہے،\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@cccxcix{جس دن کچھ منہ اونجالے ہوں گے اور کچھ منہ کالے تو وہ جن کے منہ کالے ہوئے کیا تم ایمان لاکر کافر ہوئے تو اب عذاب چکھو اپنے کفر کا بدلہ،\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@cd{اور وہ جن کے منہ اونجالے ہوئے وہ اللہ کی رحمت میں ہیں وہ ہمیشہ اس میں رہیں گے،\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@cdi{یہ اللہ کی آیتیں ہیں کہ ہم ٹھیک ٹھیک تم پر پڑھتے ہیں، اور اللہ جہاں والوں پر ظلم نہیں چاہتا\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@cdii{اور اللہ ہی کا ہے جو کچھ آسمانوں میں ہے اور جو کچھ زمین میں ہے، اور اللہ ہی کی طرف سب کاموں کی رجوع ہے،\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@cdiii{تم بہتر ہو ان امتوں میں جو لوگوں میں ظاہر ہوئیں بھلائی کا حکم دیتے ہو اور برائی سے منع کرتے ہو اور اللہ پر ایمان رکھتے ہو، اور اگر کتابی ایمان لاتے تو ان کا بھلا تھا، ان میں کچھ مسلمان ہیں اور زیادہ کافر،\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@cdiv{وہ تمہارے کچھ نہ بگاڑیں گے مگر یہی ستانا اور اگر تم سے لڑیں تو تمہارے سامنے سے پیٹھ پھیر جائیں گے پھر ان کی مدد نہ ہوگی،\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@cdv{ان پر جمادی گئی خواری جہاں ہوں امان نہ پائیں مگر اللہ کی ڈور اور آدمیوں کی ڈور سے اور غضب الٰہی کے سزاوار ہوئے اور ان پر جمادی گئی محتاجی یہ اس لئے کہ وہ اللہ کی آیتوں سے کفر کرتے اور پیغمبروں کو ناحق شہید کرتے، یہ اس لئے کہ نا فرمانبردار اور سرکش تھے،\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@cdvi{سب ایک سے نہیں کتابیوں میں کچھ وہ ہیں کہ حق پر قائم ہیں اللہ کی آیتیں پڑھتے ہیں رات کی گھڑیوں میں اور سجدہ کرتے ہیں\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@cdvii{اللہ اور پچھلے دن پر ایمان لاتے ہیں اور بھلائی کا حکم دیتے اور برائی سے منع کرتے ہیں اور نیک کاموں پر دوڑتے ہیں، اور یہ لوگ لائق ہیں،\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@cdviii{اور وہ جو بھلائی کریں ان کا حق نہ مارا جائے گا اور اللہ کو معلوم ہیں ڈر والے\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@cdix{وہ جو کافر ہوئے ان کے مال اور اولاد ان کو اللہ سے کچھ نہ بچالیں گے اور وہ جہنمی ہیں ان کو ہمیشہ اس میں رہنا\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@cdx{کہاوت اس کی جو اس دنیا میں زندگی میں خرچ کرتے ہیں اس ہوا کی سی ہے جس میں پالا ہو وہ ایک ایسی قوم کی کھیتی پر پڑی جو اپنا ہی برا کرتے تھے تو اسے بالکل مارگئی اور اللہ نے ان پر ظلم نہ کیا ہاں وہ خود اپنی جانوں پر ظلم کرتے ہیں،\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@cdxi{اے ایمان والو! غیروں کو اپنا راز دار نہ بناؤ وہ تمہاری برائی میں کمی نہیں کرتے ان کی آرزو ہے، جتنی ایذا پہنچے بیَر ان کی باتوں سے جھلک اٹھا اور وہ جو سینے میں چھپائے ہیں اور بڑا ہے، ہم نے نشانیاں تمہیں کھول کر سنادیں اگر تمہیں عقل ہو\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@cdxii{سنتے ہو یہ جو تم ہو تم تو انہیں چاہتے ہو اور وہ تمہیں نہیں چاہتے اور حال یہ کہ تم سب کتابوں پر ایمان لاتے ہو اور وہ جب تم سے ملتے ہیں کہتے ہیں ہم ایمان لائے اور اکیلے ہوں تو تم پر انگلیاں چبائیں غصہ سے تم فرمادو کہ مرجاؤ اپنی گھٹن (قلبی جلن) میں اللہ خوب جانتا ہے دلوں کی بات،\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@cdxiii{تمہیں کوئی بھلائی پہنچے تو انہیں برا لگے اور تم کہ برائی پہنچے تو اس پر خوش ہوں، اور اگر تم صبر اور پرہیزگاری کیے رہو تو ان کا داؤ تمہارا کچھ نہ بگاڑے گا، بیشک ان کے سب کام خدا کے گھیرے میں ہیں،\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@cdxiv{اور یاد کرو اے محبوب! جب تم صبح کو اپنے دولت خانہ سے برآمد ہوئے مسلمانوں کو لڑائی کے مور چوں پر قائم کرتے اور اللہ سنتا جانتا ہے،\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@cdxv{جب تم میں کے دو گروہوں کا ارادہ ہوا کہ نامردی کرجائیں اور اللہ ان کا سنبھالنے والا ہے اور مسلمانوں کو اللہ ہی پر بھروسہ چاہئے،\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@cdxvi{اور بیشک اللہ نے بدر میں تمہاری مدد کی جب تم بالکل بے سر و سامان تھے تو اللہ سے ڈرو کہیں تم شکر گزار ہو،\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@cdxvii{جب اے محبوب تم مسلمانوں سے فرماتے تھے کیا تمہیں یہ کافی نہیں کہ تمہارا رب تمہاری مدد کرے تین ہزار فرشتہ اتار کر،\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@cdxviii{ہا ں کیوں نہیں اگر تم صبرو تقویٰ کرو اور کافر اسی دم تم پر آپڑیں تو تمہارا رب تمہاری مدد کو پانچ ہزار فرشتے نشان والے بھیجے گا\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@cdxix{اور یہ فتح اللہ نے نہ کی مگر تمہاری خوشی کے لئے اور اسی لئے کہ اس سے تمہارے دلوں کو چین ملے اور مدد نہیں مگر اللہ غالب حکمت والے کے پاس سے\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@cdxx{اس لئے کہ کافروں کا ایک حصہ کاٹ دے یا انہیں ذلیل کرے کہ نامراد پھر جائیں،\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@cdxxi{یہ بات تمہارے ہاتھ نہیں یا انہیں توبہ کی توفیق دے یا ان پر عذاب کرے کہ وہ ظالم ہیں،\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@cdxxii{اور اللہ ہی کا ہے جو کچھ آسمانوں میں ہے اور جو کچھ زمین میں ہے جسے چاہے بخشے اور جسے چاہے عذاب کرے، اور اللہ بخشنے والا مہربان،\qt@no{(129)}}%
\qt@newcmd\qurantrans@ur@cdxxiii{اے ایمان والوں سود دونا دون نہ کھاؤ اللہ سے ڈرو اس امید پر کہ تمہیں فلاح ملے،\qt@no{(130)}}%
\qt@newcmd\qurantrans@ur@cdxxiv{اور اس آگ سے بچو جو کافروں کے لئے تیار رکھی ہے\qt@no{(131)}}%
\qt@newcmd\qurantrans@ur@cdxxv{اور اللہ و رسول کے فرمانبردار رہو اس امید پر کہ تم رحم کیے جاؤ،\qt@no{(132)}}%
\qt@newcmd\qurantrans@ur@cdxxvi{اور دوڑو اپنے رب کی بخشش اور ایسی جنت کی طرف جس کی چوڑان میں سب آسمان و زمین پرہیزگاروں کے لئے تیار کر رکھی ہے\qt@no{(133)}}%
\qt@newcmd\qurantrans@ur@cdxxvii{وہ جو اللہ کے راہ میں خرچ کرتے ہیں خوشی میں اور رنج میں اور غصہ پینے والے اور لوگوں سے درگزر کرنے والے، اور نیک لوگ اللہ کے محبوب ہیں،\qt@no{(134)}}%
\qt@newcmd\qurantrans@ur@cdxxviii{اور وہ کہ جب کوئی بے حیائی یا اپنی جانوں پر ظلم کریں اللہ کو یاد کرکے اپنے گناہوں کی معافی چاہیں اور گناہ کون بخشے سوا اللہ کے، اور اپنے کیے پر جان بوجھ کر اڑ نہ جائیں،\qt@no{(135)}}%
\qt@newcmd\qurantrans@ur@cdxxix{ایسوں کو بدلہ ان کے رب کی بخشش اور جنتیں ہیں جن کے نیچے نہریں رواں ہمیشہ ان میں رہیں اور کامیوں (نیک لوگوں) کا اچھا نیگ (انعام، حصہ) ہے\qt@no{(136)}}%
\qt@newcmd\qurantrans@ur@cdxxx{تم سے پہلے کچھ طریقے برتاؤ میں آچکے ہیں تو زمین میں چل کر دیکھو کیسا انجام ہوا جھٹلانے والوں کا\qt@no{(137)}}%
\qt@newcmd\qurantrans@ur@cdxxxi{یہ لوگوں کو بتانا اور راہ دکھانا اور پرہیزگاروں کو نصیحت ہے،\qt@no{(138)}}%
\qt@newcmd\qurantrans@ur@cdxxxii{اور نہ سستی کرو اور نہ غم کھاؤ تم ہی غالب آؤ گے اگر ایمان رکھتے ہو،\qt@no{(139)}}%
\qt@newcmd\qurantrans@ur@cdxxxiii{اگر تمہیں کوئی تکلیف پہنچی تو وہ لوگ بھی ویسی ہی تکلیف پاچکے ہیں اور یہ دن ہیں جن میں ہم نے لوگوں کے لیے باریاں رکھی ہیں اور اس لئے کہ اللہ پہچان کرادے ایمان والوں کی اور تم میں سے کچھ لوگوں کو شہادت کا مرتبہ دے اور اللہ دوست نہیں رکھتا ظالموں کو،\qt@no{(140)}}%
\qt@newcmd\qurantrans@ur@cdxxxiv{اور اس لئے کہ اللہ مسلمانوں کا نکھار کردے اور کافروں کو مٹادے\qt@no{(141)}}%
\qt@newcmd\qurantrans@ur@cdxxxv{کیا اس گمان میں ہو کہ جنت میں چلے جاؤ گے اور ابھی اللہ نے تمہارے غازیوں کا امتحان نہ لیا اور نہ صبر والوں آزمائش کی\qt@no{(142)}}%
\qt@newcmd\qurantrans@ur@cdxxxvi{اور تم تو موت کی تمنا کیا کرتے تھے اس کے ملنے سے پہلے تو اب وہ تمہیں نظر آئی آنکھوں کے سامنے،\qt@no{(143)}}%
\qt@newcmd\qurantrans@ur@cdxxxvii{اور محمد تو ایک رسول ان سے پہلے اور رسول ہوچکے تو کیا اگر وہ انتقال فرمائیں یا شہید ہوں تو تم الٹے پاؤں پھر جاؤں گے اور جو الٹے پاؤں پھرے گا اللہ کا کچھ نقصان نہ کرے گا، اور عنقریب اللہ شکر والوں کو صلہ دے گا،\qt@no{(144)}}%
\qt@newcmd\qurantrans@ur@cdxxxviii{اور کوئی جان بے حکم خدا مر نہیں سکتی سب کا وقت لکھا رکھا ہے اور دنیا کا انعام چاہے ۰ف۲۶۱) ہم اس میں سے اسے دیں اور جو آخرت کا انعام چاہے ہم اس میں سے اسے دیں اور قریب ہے کہ ہم شکر والوں کو صلہ عطا کریں،\qt@no{(145)}}%
\qt@newcmd\qurantrans@ur@cdxxxix{اور کتنے ہی انبیاء نے جہاد کیا ان کے ساتھ بہت خدا والے تھے، تو نہ سست پڑے ان مصیبتوں سے جو اللہ کی راہ میں انہیں پہنچیں اور نہ کمزور ہوئے اور نہ دبے اور صبر والے اللہ کو محبوب ہیں،\qt@no{(146)}}%
\qt@newcmd\qurantrans@ur@cdxl{اور وہ کچھ بھی نہ کہتے تھے سوا اس دعا کے کہ اے ہمارے رب بخش دے ہمارے گناہ اور جو زیادتیاں ہم نے اپنے کام کیں اور ہمارے قدم جما دے اور ہمیں ان کافر لوگوں پر مدد دے\qt@no{(147)}}%
\qt@newcmd\qurantrans@ur@cdxli{تو اللہ نے انہیں دنیا کا انعام دیا اور آخرت کے ثواب کی خوبی اور نیکی والے اللہ کو پیارے ہیں،\qt@no{(148)}}%
\qt@newcmd\qurantrans@ur@cdxlii{اے ایمان والو! اگر تم کافروں کے کہے پر چلے تو وہ تمہیں الٹے پاؤں لوٹادیں گے پھر ٹوٹا کھا کے پلٹ جاؤ گے\qt@no{(149)}}%
\qt@newcmd\qurantrans@ur@cdxliii{بلکہ اللہ تمہارا مولا ہے اور وہ سب سے بہتر مددگار،\qt@no{(150)}}%
\qt@newcmd\qurantrans@ur@cdxliv{کوئی دم جاتا ہے کہ ہم کافروں کے دلوں میں رعب ڈالیں گے کہ انہوں نے اللہ کا شریک ٹھہرایا جس پر اس نے کوئی سمجھ نہ اتاری اور ان کا ٹھکانا دوزخ ہے، اور کیا برا ٹھکانا ناانصافوں کا،\qt@no{(151)}}%
\qt@newcmd\qurantrans@ur@cdxlv{اور بیشک اللہ نے تمہیں سچ کر دکھایا اپنا وعدہ جب کہ تم اس کے حکم سے کافروں کو قتل کرتے تھے یہاں تک کہ جب تم نے بزدلی کی اور حکم میں جھگڑا ڈالا اور نافرمانی کی بعد اس کے کہ اللہ تمہیں دکھا چکا تمہاری خوشی کی بات تم میں کوئی دنیا چاہتا تھا اور تم میں کوئی آخرت چاہتا تھا پھر تمہارا منہ ان سے پھیردیا کہ تمہیں آزمائے اور بیشک اس نے تمہیں معاف کردیا، اور اللہ مسلمانوں پر فضل کرتا ہے،\qt@no{(152)}}%
\qt@newcmd\qurantrans@ur@cdxlvi{جب تم منہ اٹھائے چلے جاتے تھے اور پیٹھ پھیر کر کسی کو نہ دیکھتے اور دوسری جماعت میں ہمارے رسول تمہیں پکار رہے تھے تو تمہیں غم کا بدلہ غم دیا اور معافی اس لئے سنائی کہ جو ہاتھ سے گیا اور جو افتاد پڑی اس کا رنج نہ کرو اور اللہ کوتمہارے کاموں کی خبر ہے،\qt@no{(153)}}%
\qt@newcmd\qurantrans@ur@cdxlvii{پھر تم پر غم کے بعد چین کی نیند اتاری کہ تمہاری ایک جماعت کو گھیرے تھی اور ایک گروہ کو اپنی جان کی پڑی تھی اللہ پر بے جا گمان کرتے تھے جاہلیت کے سے گمان، کہتے کیا اس کام میں کچھ ہمارا بھی اختیار ہے تم فرمادو کہ اختیار تو سارا اللہ کا ہے اپنے دلوں میں چھپاتے ہیں جو تم پر ظاہر نہیں کرتے کہتے ہیں، ہمارا کچھ بس ہوتا تو ہم یہاں نہ مارے جاتے، تم فرمادو کہ اگر تم اپنے گھروں میں ہوتے جب بھی جن کا مارا جانا لکھا جاچکا تھا اپنی قتل گاہوں تک نکل آتے اور اس لئے کہ اللہ تمہارے سینوں کی بات آزمائے اور جو کچھ تمہارے دلو ں میں ہے اسے کھول دے اور اللہ دلوں کی بات جانتا ہے\qt@no{(154)}}%
\qt@newcmd\qurantrans@ur@cdxlviii{بیشک وہ جو تم میں سے پھرگئے جس دن دونوں فوجیں ملی تھیں انہیں شیطان ہی نے لغزش دی ان کے بعض اعمال کے باعث اور بیشک اللہ نے انہیں معاف فرمادیا، بیشک اللہ بخشنے والا حلم والا ہے،\qt@no{(155)}}%
\qt@newcmd\qurantrans@ur@cdxlix{اے ایمان والو! ان کافروں کی طرح نہ ہونا جنہوں نے اپنے بھائیوں کی نسبت کہا کہ جب وہ سفر یا جہاد کو گئے کہ ہمارے پاس ہوتے تو نہ مرتے اور نہ مارے جاتے اس لئے اللہ ان کے دلوں میں اس کا افسوس رکھے، اور اللہ جِلاتا اور مارتا ہے اور اللہ تمہارے کام دیکھ رہا ہے،\qt@no{(156)}}%
\qt@newcmd\qurantrans@ur@cdl{اور بیشک اگر تم اللہ کی راہ میں مارے جاؤ یا مرجاؤ تو اللہ کی بخشش اور رحمت ان کے سارے دھن دولت سے بہتر ہے،\qt@no{(157)}}%
\qt@newcmd\qurantrans@ur@cdli{اور اگر تم مرو یا مارے جاؤ تو اللہ کی طرف اٹھنا ہے\qt@no{(158)}}%
\qt@newcmd\qurantrans@ur@cdlii{تو کیسی کچھ اللہ کی مہربانی ہے کہ اے محبوب! تم ان کے لئے نرم دل ہوئے اور اگر تند مزاج سخت دل ہوتے تو وہ ضرور تمہارے گرد سے پریشان ہوجاتے تو تم انہیں معاف فرماؤ او ر ان کی شفاعت کرو اور کاموں میں ان سے مشورہ لو اور جو کسی بات کا ارادہ پکا کرلو تو اللہ پر بھروسہ کرو بیشک توکل والے اللہ کو پیارے ہیں،\qt@no{(159)}}%
\qt@newcmd\qurantrans@ur@cdliii{اگر اللہ تمہاری مدد کرے تو کوئی تم پر غالب نہیں آسکتا اور اگر وہ تمہیں چھوڑ دے تو ایسا کون ہے جو پھر تمہاری مدد کرے اور مسلمانوں کو اللہ ہی پر بھروسہ چاہئے،\qt@no{(160)}}%
\qt@newcmd\qurantrans@ur@cdliv{اور کسی نبی پر یہ گمان نہیں ہوسکتا کہ وہ کچھ چھپا رکھے اور جو چھپا رکھے وہ قیامت کے دن اپنی چھپائی چیز لے کر آئے گا پھر ہر جان کو ان کی کمائی بھرپور دی جائے گی اور ان پر ظلم نہ ہوگا،\qt@no{(161)}}%
\qt@newcmd\qurantrans@ur@cdlv{تو کیا جو اللہ کی مرضی پر چلا وہ اس جیسا ہوگا جس نے اللہ کا غضب اوڑھا اور اس کا ٹھکانا جہنم ہے، اور کیا بری جگہ پلٹنے کی،\qt@no{(162)}}%
\qt@newcmd\qurantrans@ur@cdlvi{وہ اللہ کے یہاں درجہ درجہ ہیں اور اللہ ان کے کام دیکھتا ہے،\qt@no{(163)}}%
\qt@newcmd\qurantrans@ur@cdlvii{بیشک اللہ کا بڑا احسان ہوا مسلمانوں پر کہ ان میں انہیں میں سے ایک رسول بھیجا جو ان پر اس کی آیتیں پڑھتا ہے اور انہیں پاک کرتا ہے اور انہیں کتاب و حکمت سکھاتا ہے اور وہ ضرور اس سے پہلے کھلی گمراہی میں تھے\qt@no{(164)}}%
\qt@newcmd\qurantrans@ur@cdlviii{کیا جب تمہیں کوئی مصیبت پہنچے کہ اس سے دونی تم پہنچا چکے ہو تو کہنے لگو کہ یہ کہاں سے آئی تم فرمادو کہ وہ تمہاری ہی طرف سے آئی بیشک اللہ سب کچھ کرسکتا ہے،\qt@no{(165)}}%
\qt@newcmd\qurantrans@ur@cdlix{اور وہ مصیبت جو تم پر آئی جس دن دونوں فوجیں ملی تھیں وہ اللہ کے حکم سے تھی اور اس لئے کہ پہچان کرادے ایمان والوں کی،\qt@no{(166)}}%
\qt@newcmd\qurantrans@ur@cdlx{اور اس لئے کہ پہچان کرادے، ان کی جو منافق ہوئے اور ان سے کہا گیا کہ ا ٓؤ اللہ کی راہ میں لڑو یا دشمن کو ہٹاؤ بولے اگر ہم لڑائی ہوتی جانتے تو ضرو ر تمہارا ساتھ دیتے، اور اس دن ظاہری ایمان کی بہ نسبت کھلے کفر سے زیادہ قریب ہیں، اپنے منہ سے کہتے ہیں جو ان کے دل میں نہیں اور اللہ کو معلوم ہے جو چھپارہے ہیں\qt@no{(167)}}%
\qt@newcmd\qurantrans@ur@cdlxi{وہ جنہوں نے اپنے بھائیوں کے بارے میں کہا اور آپ بیٹھ رہے کہ وہ ہمارا کہا مانتے تو نہ مارے جاتے تم فرمادو تو اپنی ہی موت ٹال دو اگر سچے ہو\qt@no{(168)}}%
\qt@newcmd\qurantrans@ur@cdlxii{اور جو اللہ کی راہ میں مارے گئے ہر گز انہیں مردہ نہ خیال کرنا، بلکہ وہ اپنے رب کے پاس زندہ ہیں روزی پاتے ہیں\qt@no{(169)}}%
\qt@newcmd\qurantrans@ur@cdlxiii{شاد ہیں اس پر جو اللہ نے انہیں اپنے فضل سے دیا اور خوشیاں منارہے ہیں اپنے پچھلوں کی جو ابھی ان سے نہ ملے کہ ان پر نہ کچھ اندیشہ ہے اور نہ کچھ غم،\qt@no{(170)}}%
\qt@newcmd\qurantrans@ur@cdlxiv{خوشیاں مناتے ہیں اللہ کی نعمت اور فضل کی اور یہ کہ اللہ ضائع نہیں کرتا اجر مسلمانوں کا\qt@no{(171)}}%
\qt@newcmd\qurantrans@ur@cdlxv{وہ جو اللہ و رسول کے بلانے پر حاضر ہوئے بعد اس کے کہ انہیں زخم پہنچ چکا تھا ان کے نکوکاروں اور پرہیزگاروں کے لئے بڑا ثواب ہے،\qt@no{(172)}}%
\qt@newcmd\qurantrans@ur@cdlxvi{وہ جن سے لوگوں نے کہا کہ لوگوں نے تمہارے لئے جتھا جوڑا تو ان س ے ڈرو تو ان کا ایمان اور زائد ہوا اور بولے اللہ ہم کو بس ہے اور کیا اچھا کارساز\qt@no{(173)}}%
\qt@newcmd\qurantrans@ur@cdlxvii{تو پلٹے اللہ کے احسان اور فضل سے کہ انہیں کوئی برائی نہ پہنچی اور اللہ کی خوشی پر چلے اور اللہ بڑے فضل والا ہے\qt@no{(174)}}%
\qt@newcmd\qurantrans@ur@cdlxviii{وہ تو شیطان ہی ہے کہ اپنے دوستوں سے دھمکاتا ہے تو ان سے نہ ڈرو اور مجھ سے ڈرو اگر ایمان رکھتے ہو\qt@no{(175)}}%
\qt@newcmd\qurantrans@ur@cdlxix{اور اے محبوب! تم ان کا کچھ غم نہ کرو جو کفر پر دوڑتے ہیں وہ اللہ کا کچھ بگاڑیں گے اور اللہ چاہتا ہے کہ آخرت میں ان کا کوئی حصہ نہ رکھے اور ان کے لئے بڑا عذاب ہے،\qt@no{(176)}}%
\qt@newcmd\qurantrans@ur@cdlxx{وہ جنہوں نے ایمان کے بدلے کفر مول لیا اللہ کا کچھ نہ بگاڑیں گے اور ان کے لئے دردناک عذاب ہے،\qt@no{(177)}}%
\qt@newcmd\qurantrans@ur@cdlxxi{اور ہرگز کافر اس گمان میں نہ رہیں کہ وہ جو ہم انہیں ڈھیل دیتے ہیں کچھ ان کے لئے بھلا ہے، ہم تو اسی لئے انہیں ڈھیل دیتے ہیں کہ اور گناہ میں بڑھیں اور ان کے لئے ذلت کا عذاب ہے،\qt@no{(178)}}%
\qt@newcmd\qurantrans@ur@cdlxxii{اللہ مسلمانوں کو اس حال پر چھوڑنے کا نہیں جس پر تم ہو جب تک جدا نہ کردے گندے کو ستھرے سے اور اللہ کی شان یہ نہیں کہ اے عام لوگو! تمہیں غیب کا علم دے دے ہاں اللہ چن لیتا ہے اپنے رسولوں سے جسے چاہے تو ایمان لاؤ اللہ اور اس کے رسولوں پر اور اگر ایمان لاؤ اور پرہیزگاری کرو تو تمہارے لئے بڑا ثواب ہے،\qt@no{(179)}}%
\qt@newcmd\qurantrans@ur@cdlxxiii{اور جو بخل کرتے ہیں اس چیز میں جو اللہ نے انہیں اپنے فضل سے دی ہرگز اسے اپنے لئے اچھا نہ سمجھیں بلکہ وہ ان کے لئے برا ہے، عنقریب وہ جس میں بخل کیا تھا قیامت کے دن ان کے گلے کا طوق ہوگا اور اللہ ہی وارث ہے آسمانوں اور زمین کا اور اللہ تمہارے کاموں سے خبردار ہے،\qt@no{(180)}}%
\qt@newcmd\qurantrans@ur@cdlxxiv{بیشک اللہ نے سنا جنہوں نے کہا کہ اللہ محتاج ہے اور ہم غنی اور ہم غنی اب ہم لکھ رکھیں گے ان کا کہا اور انبیاء کو ان کا ناحق شہید کرنا اور فرمائیں گے کہ چکھو آگ کا عذاب،\qt@no{(181)}}%
\qt@newcmd\qurantrans@ur@cdlxxv{یہ بدلا ہے اس کا جو تمہارے ہاتھوں نے آگے بھیجا اور اللہ بندوں پر ظلم نہیں کرتا،\qt@no{(182)}}%
\qt@newcmd\qurantrans@ur@cdlxxvi{وہ جو کہتے ہیں اللہ نے ہم سے اقرار کر لیا ہے کہ ہم کسی رسول پر ایمان نہ لائیں جب تک ایسی قربانی کا حکم نہ لائے جس آ گ کھائے تم فرمادو مجھ سے پہلے بہت رسول تمہارے پاس کھلی نشانیاں اور یہ حکم لے کر آئے جو تم کہتے ہو پھر تم نے انہیں کیوں شہید کیا اگر سچے ہو\qt@no{(183)}}%
\qt@newcmd\qurantrans@ur@cdlxxvii{تو اے محبوب! اگر وہ تمہاری تکذیب کرتے ہیں تو تم سے اگلے رسولوں کی بھی تکذیب کی گئی ہے جو صاف نشانیاں اور صحیفے اور چمکتی کتاب لے کر آئے تھے\qt@no{(184)}}%
\qt@newcmd\qurantrans@ur@cdlxxviii{ہر جان کو موت چکھنی ہے، اور تمہارے بدلے تو قیامت ہی کو پورے ملیں گے، جو آگ سے بچا کر جنت میں داخل کیا گیا وہ مراد کو پہنچا، اور دنیا کی زندگی تو یہی دھوکے کا مال ہے\qt@no{(185)}}%
\qt@newcmd\qurantrans@ur@cdlxxix{بیشک ضرور تمہاری آزمائش ہوگی تمہارے مال اور تمہاری جانوں میں اور بیشک ضرور تم اگلے کتاب والوں اور مشرکوں سے بہت کچھ برا سنو گے اور اگر تم صبر کرو اور بچتے رہو تو یہ بڑی ہمت کا کام ہے،\qt@no{(186)}}%
\qt@newcmd\qurantrans@ur@cdlxxx{اور یاد کرو جب اللہ نے عہد لیا ان سے جنہیں کتاب عطا فرمائی کہ تم ضرور اسے لوگوں سے بیان کردینا اور نہ چھپانا تو انہوں نے اسے اپنی پیٹھ کے پیچھے پھینک دیا اور اس کے بدلے ذلیل دام حاصل کیے تو کتنی بری خریداری ہے\qt@no{(187)}}%
\qt@newcmd\qurantrans@ur@cdlxxxi{ہر گز نہ سمجھنا انہیں جو خوش ہوتے ہیں اپنے کیے پر اور چاہتے ہیں کہ بے کیے ان کی تعریف ہو ایسوں کو ہرگز عذاب سے دور نہ جاننا اور ان کے لیے دردناک عذاب ہے\qt@no{(188)}}%
\qt@newcmd\qurantrans@ur@cdlxxxii{اور اللہ ہی کے لئے ہے آسمانوں اور زمین کی بادشاہی اور اللہ ہر چیز پر قادر ہے،\qt@no{(189)}}%
\qt@newcmd\qurantrans@ur@cdlxxxiii{بیشک آسمانوں اور زمین کی پیدائش اور رات اور دن کی باہم بدلیوں میں نشانیاں ہیں عقلمندوں کے لئے\qt@no{(190)}}%
\qt@newcmd\qurantrans@ur@cdlxxxiv{جو اللہ کی یاد کرت ہیں کھڑے اور بیٹھے اور کروٹ پر لیٹے اور آسمانوں اور زمین کی پیدائش میں غور کرتے ہیں اے رب ہمارے! تو نے یہ بیکار نہ بنایا پاکی ہے تجھے تو ہمیں دوزخ کے عذاب سے بچالے،\qt@no{(191)}}%
\qt@newcmd\qurantrans@ur@cdlxxxv{اے رب ہمارے! بیشک جسے تو دوزخ میں لے جائے اسے ضرور تو نے رسوائی دی اور ظالموں کا کوئی مددگار نہیں،\qt@no{(192)}}%
\qt@newcmd\qurantrans@ur@cdlxxxvi{اے رب ہمارے ہم نے ایک منادی کو سنا کہ ایمان کے لئے ندا فرماتا ہے کہ اپنے رب پر ایمان لاؤ تو ہم ایمان لائے اے رب ہمارے تو ہمارے گنا بخش دے اور ہماری برائیاں محو فرمادے اور ہماری موت اچھوں کے ساتھ کر\qt@no{(193)}}%
\qt@newcmd\qurantrans@ur@cdlxxxvii{اے رب ہمارے! اور ہمیں دے وہ جس کا تو نے ہم سے وعدہ کیا ہے اپنے رسولوں کی معرفت اور ہمیں قیامت کے دن رسوانہ کر، بیشک تو وعدہ خلاف نہیں کرتا،\qt@no{(194)}}%
\qt@newcmd\qurantrans@ur@cdlxxxviii{تو ان کی دعا سن لی ان کے رب نے کہ میں تم میں کام والے کی محنت اکارت نہیں کرتا مرد ہو یا عورت تم آپس میں ایک ہو تو وہ جنہوں نے ہجرت کی اور اپنے گھروں سے نکالے گئے اور میری راہ میں ستائے گئے اور لڑے اور مارے گء ے میں ضرور ان کے سب گناہ اتار دوں گا اور ضرور انہیں باغوں میں لے جاؤں گا جن کے نیچے نہریں رواں اللہ کے پاس کا ثواب، اور اللہ ہی کے پاس اچھا ثواب ہے،\qt@no{(195)}}%
\qt@newcmd\qurantrans@ur@cdlxxxix{اے سننے والے! کافروں کا شہروں میں اہلے گہلے پھرنا ہرگز تجھے دھوکا نہ دے\qt@no{(196)}}%
\qt@newcmd\qurantrans@ur@cdxc{تھوڑا برتنا، ان کا ٹھکانا دوزخ ہے، اور کیا ہی برا بچھونا،\qt@no{(197)}}%
\qt@newcmd\qurantrans@ur@cdxci{لیکن وہ جو اپنے رب سے ڈرتے ہیں ان کے لئے جنتیں ہیں جن کے نیچے نہریں بہیں ہمیشہ ان میں رہیں اللہ کی طرف کی، مہمانی اور جو اللہ پاس ہے وہ نیکوں کے لئے سب سے بھلا\qt@no{(198)}}%
\qt@newcmd\qurantrans@ur@cdxcii{اور بیشک کچھ کتابیں ایسے ہیں کہ اللہ پر ایمان لاتے ہیں اور اس پر جو تمہاری طرف اترا اور جو ان کی طرف اترا ان کے دل اللہ کے حضور جھکے ہوئے اللہ کی آیتوں کے بدلے ذلیل دام نہیں لیتے یہ وہ ہیں، جن کا ثواب ان کے رب کے پاس ہے اور اللہ جلد حساب کرنے والا ہے،\qt@no{(199)}}%
\qt@newcmd\qurantrans@ur@cdxciii{اے ایمان والو! صبر کرو اور صبر میں دشمنوں سے آگے رہو اور سرحد پر اسلامی ملک کی نگہبانی کرو اور اللہ سے ڈرتے رہو اس امید پر کہ کامیاب ہو،\qt@no{(200)}}%
\qt@newcmd\qurantrans@ur@cdxciv{\basmalahur اے لوگو! اپنے رب سے ڈرو جس نے تمہیں ایک جان سے پیدا کیا اور اسی میں سے اس کا جوڑا بنایا اور ان دونوں سے بہت سے مرد و عورت پھیلا دیئے اور اللہ سے ڈرو جس کے نام پر مانگتے ہو اور رشتوں کا لحاظ رکھو بیشک اللہ ہر وقت تمہیں دیکھ رہا ہے،\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@cdxcv{اور یتیموں کو ان کے مال دو اور ستھرے کے بدلے گندا نہ لو اور ان کے مال اپنے مالوں میں ملاکر نہ کھا جاؤ، بیشک یہ بڑا گناہ ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@cdxcvi{ا ور اگر تمہیں اندیشہ ہو کہ یتیم لڑکیوں میں انصاف نہ کرو گے تو نکاح میں لاؤ جو عورتیں تمہیں خوش آئیں دو دو اور تین تین او ر چار چار پھر اگر ڈرو کہ دو بیبیوں کو برابر نہ رکھ سکو گے تو ایک ہی کرو یا کنیزیں جن کے تم مالک ہو یہ اس سے زیادہ قریب ہے کہ تم سے ظلم نہ ہو\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@cdxcvii{اور عورتوں کو ان کے مہر خوشی سے دو پھر اگر وہ اپنے دل کی خوشی سے مہر میں سے تمہیں کچھ دے دیں تو اسے کھاؤ رچتا پچتا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@cdxcviii{اور بے عقلوں کو ان کے مال نہ دو جو تمہارے پاس ہیں جن کو اللہ نے تمہاری بسر اوقات کیا ہے اور انہیں اس میں سے کھلاؤ اور پہناؤ اور ان سے اچھی بات کہو\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@cdxcix{اور یتیموں کو آزماتے رہو یہاں تک کہ جب وہ نکاح کے قابل ہوں تو اگر تم ان کی سمجھ ٹھیک دیکھو تو ان کے مال انہیں سپرد کردو اور انہیں نہ کھاؤ حد سے بڑھ کر اور اس جلدی میں کہ کہیں بڑے نہ ہوجائیں اور جسے حاجت نہ ہو وہ بچتا رہے اور جو حاجت مند ہو وہ بقدر مناسب کھائے، پھر جب تم ان کے مال انہیں سپرد کرو تو ان پر گواہ کرلو، اور اللہ کافی ہے حساب لینے کو،\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@d{مردوں کے لئے حصہ ہے اس میں سے جو چھوڑ گئے ماں باپ اور قرابت والے اور عورتوں کے لئے حصہ ہے اس میں سے جو چھوڑ گئے ماں باپ اور قرابت والے ترکہ تھوڑا ہو یا بہت، حصہ ہے اندازہ باندھا ہوا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@di{پھر بانٹتے وقت اگر رشتہ دار اور یتیم اور مسکین آجائیں تو اس میں سے انہیں بھی کچھ دو اور ان سے اچھی بات کہو\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@dii{اور ڈریں وہ لوگ اگر اپنے بعد ناتواں اولاد چھوڑتے تو ان کا کیسا انہیں خطرہ ہوتا تو چاہئے کہ اللہ سے ڈریں اور سیدھی بات کریں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@diii{وہ جو یتیموں کا مال ناحق کھاتے ہیں وہ تو اپنے پیٹ میں نری آ گ بھرتے ہیں اور کوئی دم جاتا ہے کہ بھڑتے دھڑے (آتش کدے) میں جائیں گے،\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@div{اللہ تمہیں حکم دیتا ہے تمہاری اولاد کے بارے میں بیٹے کا حصہ دو بیٹیوں برابر ہے پھر اگر نری لڑکیاں ہوں اگرچہ دو سے اوپر تو ان کو ترکہ کی دو تہائی اور اگر ایک لڑکی ہو تو اس کا آدھا اور میت کے ماں باپ کو ہر ایک کو اس کے ترکہ سے چھٹا اگر میت کے اولاد ہو پھر اگر اس کی اولاد نہ ہو اور ماں باپ چھوڑے تو ماں کا تہا ئی پھر اگر اس کے کئی بہن بھا ئی ہو ں تو ماں کا چھٹا بعد اس و صیت کے جو کر گیا اور دین کے تمہارے باپ اور تمہارے بیٹے تم کیا جانو کہ ان میں کون تمہارے زیادہ کام آئے گا یہ حصہ باندھا ہوا ہے اللہ کی طرف سے بیشک اللہ علم والا حکمت والا ہے،\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@dv{اور تمہاری بیبیاں جو چھوڑ جائیں اس میں سے تمہیں آدھا ہے اگر ان کی اولاد نہ ہو، پھر اگر ان کی اولاد ہو تو ان کے ترکہ میں سے تمہیں چوتھائی ہے جو وصیت وہ کر گئیں اور دَین نکال کر اور تمہارے ترکہ میں عورتوں کا چوتھائی ہے اگر تمہارے اولاد نہ ہو پھر اگر تمہارے اولاد ہو تو ان کا تمہارے ترکہ میں سے آٹھواں جو وصیت تم کر جاؤ اور دین نکال کر، اور اگر کسی ایسے مرد یا عورت کا ترکہ بٹنا ہو جس نے ماں باپ اولاد کچھ نہ چھوڑے اور ماں کی طرف سے اس کا بھائی یا بہن ہے تو ان میں سے ہر ایک کو چھٹا پھر اگر وہ بہن بھائی ایک سے زیادہ ہوں تو سب تہائی میں شریک ہیں میت کی وصیت اور دین نکال کر جس میں اس نے نقصان نہ پہنچایا ہو یہ اللہ کا ارشاد ہے اور اللہ علم والا حلم والا ہے،\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@dvi{یہ اللہ کی حدیں ہیں اور جو حکم مانے اللہ اور اللہ کے رسول کا اللہ اسے باغوں میں لے جائے گا جن کے نیچے نہریں رواں ہمیشہ ان میں رہیں گے، اور یہی ہے بڑی کامیابی،\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@dvii{اور جو اللہ اور اس کے رسول کی نافرمانی کرے اور اس کی کل حدوں سے بڑھ جائے اللہ اسے آگ میں داخل کرے گا جس میں ہمیشہ رہے گا اور اس کے لئے خواری کا عذاب ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@dviii{اور تمہاری عورتوں میں جو بدکاری کریں ان پر خاص اپنے میں کے چار مردوں کی گواہی لو پھر اگر وہ گواہی دے دیں تو ان عورتوں کو گھر میں بند رکھو یہاں تک کہ انہیں موت اٹھالے یا اللہ ان کی کچھ راہ نکالے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@dix{اور تم میں جو مرد عورت ایسا کریں ان کو ایذا دو پھر اگر وہ توبہ کرلیں اور نیک ہوجائیں تو ان کا پیچھا چھوڑ دو، بیشک اللہ بڑا توبہ قبول کرنے والا مہربان ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@dx{وہ توبہ جس کا قبول کرنا اللہ نے اپنے فضل سے لازم کرلیا ہے وہ انہیں کی ہے جو نادانی سے برائی کر بیٹھیں پھر تھوڑی دیر میں توبہ کرلیں ایسوں پر اللہ اپنی رحمت سے رجوع کرتا ہے، اور اللہ علم و حکمت والا ہے،\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@dxi{اور وہ توبہ ان کی نہیں جو گناہوں میں لگے رہتے ہیں، یہاں تک کہ جب ان میں کسی کو موت آئے تو کہے اب م یں نے توبہ کی اور نہ ان کی جو کافر مریں ان کے لئے ہم نے دردناک عذاب تیار رکھا ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@dxii{اے ایمان والو! تمہیں حلال نہیں کہ عورتوں کے وارث بن جاؤ زبردستی اور عورتوں کو روکو نہیں اس نیت سے کہ جو مہر ان کو دیا تھا اس میں سے کچھ لے لو مگر اس صورت میں کہ صریح بے حیا ئی کا کام کریں اور ان سے اچھا برتاؤ کرو پھر اگر وہ تمہیں پسند نہ آئیں تو قریب ہے کہ کوئی چیز تمہیں ناپسند ہو اور اللہ اس میں بہت بھلائی رکھے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@dxiii{اور اگر تم ایک بی بی کے بدلے دوسری بدلنا چاہو اور اسے ڈھیروں مال دے چکے ہو تو اس میں سے کچھ واپس نہ لو کیا اسے واپس لو گے جھوٹ باندھ کر اور کھلے گناہ سے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@dxiv{اور کیونکر اسے واپس لوگے حالانکہ تم میں ایک دوسرے کے سامنے بے پردہ ہولیا اور وہ تم سے گاڑھا عہد لے چکیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@dxv{اور باپ دادا کی منکوحہ سے نکاح نہ کرو مگر جو ہو گزرا وہ بیشک بے حیائی اور غضب کا کام ہے، اور بہت بری راہ\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@dxvi{حرام ہوئیں تم پر تمہاری مائیں اور بیٹیاں اور بہنیں اور پھوپھیاں اور خالائیں اور بھتیجیاں اور بھانجیاں اور تمہاری مائیں جنہوں نے دودھ پلایا اور دودھ کی بہنیں اور عورتوں کی مائیں اور ان کی بیٹیاں جو تمہاری گود میں ہیں ان بیبیوں سے جن سے تم صحبت کرچکے ہو تو پھر اگر تم نے ان سے صحبت نہ کی ہو تو ان کی بیٹیوں سے حرج نہیں اور تمہاری نسلی بیٹوں کی بیبیں اور دو بہنیں اکٹھی کرنا مگر جو ہو گزرا بیشک اللہ بخشنے والا مہربان ہے،\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@dxvii{اور حرام ہیں شوہر دار عورتیں مگر کافروں کی عورتیں جو تمہاری ملک میں آجائیں یہ اللہ کا نوشتہ ہے تم پر اور ان کے سوا جو رہیں وہ تمہیں حلال ہیں کہ اپنے مالوں کے عوض تلاش کرو قید لاتے نہ پانی گراتے تو جن عورتوں کو نکاح میں لانا چاہو ان کے بندھے ہوئے مہر انہیں دو، اور قرار داد کے بعد اگر تمہارے آپس میں کچھ رضامندی ہوجاوے تو اس میں گناہ نہیں بیشک اللہ علم و حکمت والا ہے،\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@dxviii{اور تم میں بے مقدوری کے باعث جن کے نکاح میں آزاد عورتیں ایمان والیاں نہ ہوں تو ان سے نکاح کرے جو تمہارے ہاتھ کی مِلک ہیں ایمان والی کنیزیں اور اللہ تمہارے ایمان کو خوب جانتا ہے، تم میں ایک دوسرے سے ہے تو ان سے نکاح کرو ان کے مالکوں کی اجازت سے اور حسب دستور ان کے مہر انہیں دو قید میں آتیاں نہ مستی نکالتی اور نہ یار بناتی جب وہ قید میں آجائیں پھر برا کام کریں تو ان پر اس سزا کی آدھی ہے جو آزاد عورتوں پر ہے یہ اس کے لئے جسے تم میں سے زنا کا اندیشہ ہے، اور صبر کرنا تمہارے لئے بہتر ہے اور اللہ بخشنے والا مہربان ہے،\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@dxix{اللہ چاہتا ہے کہ اپنے احکام تمہارے لئے بیان کردے اور تمہیں اگلوں کی روشیں بتادے اور تم پر اپنی رحمت سے رجوع فرمائے اور اللہ علم و حکمت والا ہے،\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@dxx{اور اللہ تم پر اپنی رحمت سے رجوع فرمانا چاہتا ہے، اور جو اپنے مزوں کے پیچھے پڑے ہیں وہ چاہتے ہیں کہ تم سیدھی راہ سے بہت الگ ہوجاؤ\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@dxxi{اللہ چاہتا ہے کہ تم پر تخفیف کرے اور آدمی کمزور بنایا گیا\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@dxxii{اے ایمان والو! آپس میں ایک دوسرے کے مال ناحق نہ کھاؤ مگر یہ کہ کوئی سودا تمہاری باہمی رضامندی کا ہو اور اپنی جانیں قتل نہ کرو بیشک اللہ تم پر مہربان ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@dxxiii{اور جو ظلم و زیادتی سے ایسا کرے گا تو عنقریب ہم اسے آگ میں داخل کریں گے اور یہ اللہ کو آسان ہے،\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@dxxiv{اگر بچتے رہو کبیرہ گناہوں سے جن کی تمہیں ممانعت ہے تو تمہارے اور گناہ ہم بخش دیں گے اور تمہیں عزت کی جگہ داخل کریں گے،\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@dxxv{اور ا س کی آرزو نہ کرو جس سے اللہ نے تم میں ایک کو دوسرے پر بڑائی دی مردوں کے لئے ان کی کمائی سے حصہ ہے، اور عورتوں کے لئے ان کی کمائی سے حصہ اور اللہ سے اس کا فضل مانگو، بیشک اللہ سب کچھ جانتا ہے،\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@dxxvi{اور ہم نے سب کے لئے مال کے مستحق بنادیے ہیں جو کچھ چھوڑ جائیں ماں باپ اور قرابت والے اور وہ جن سے تمہارا حلف بندھ چکا انہیں ان کا حصہ دو، بیشک ہر چیز اللہ کے سامنے ہے،\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@dxxvii{مرد افسر ہیں عورتوں پر اس لیے کہ اللہ نے ان میں ایک کو دوسرے پر فضیلت دی اور اس لئے کہ مردوں نے ان پر اپنے مال خرچ کیے تو نیک بخت عورتیں ادب والیاں ہیں خاوند کے پیچھے حفاظت رکھتی ہیں جس طرح اللہ نے حفاظت کا حکم دیا اور جن عورتوں کی نافرمانی کا تمہیں اندیشہ ہو تو انہیں سمجھاؤ اور ان سے الگ سوؤ اور انہیں مارو پھر اگر وہ تمہارے حکم میں آجائیں تو ان پر زیادتی کی کوئی راہ نہ چاہو بیشک اللہ بلند بڑا ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@dxxviii{اور اگر تم کو میاں بی بی کے جھگڑے کا خوف ہو تو ایک پنچ مرد والوں کی طرف سے بھیجو اور ایک پنچ عورت والوں کی طرف سے یہ دونوں اگر صلح کرانا چاہیں گے تو اللہ ان میں میل کردے گا، بیشک اللہ جاننے والا خبردار ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@dxxix{اور اللہ کی بندگی کرو اور اس کا شریک کسی کو نہ ٹھہراؤ اور ماں باپ سے بھلائی کرو اور رشتہ داروں اور یتیموں اور محتاجوں اور پاس کے ہمسائے اور دور کے ہمسائے اور کروٹ کے ساتھی اور راہ گیر اور اپنی باندی غلام سے بیشک اللہ کو خوش نہیں آتا کوئی اترانے والے بڑائی مارنے والا\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@dxxx{جو آپ بخل کریں اور اوروں سے بخل کے لئے کہیں اور اللہ نے جو انہیں اپنے فضل سے دیا ہے اسے چھپائيں اور کافروں کے لئے ہم نے ذلت کا عذاب تیار کر رکھا ہے،\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@dxxxi{اور وہ جو اپنے مال لوگوں کے دکھاوے کو خرچ کرتے ہیں اور ایمان نہیں لاتے اللہ اور نہ قیامت پر، اور جس کا مصاحب شیطان ہوا، تو کتنا برا مصاحب ہے،\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@dxxxii{اور ان کا کیا نقصان تھا اگر ایمان لاتے اللہ اور قیامت پر اور اللہ کے دیے میں سے اس کی راہ میں خرچ کرتے اور اللہ ان کو جانتا ہے،\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@dxxxiii{اللہ ایک ذرہ بھر ظلم نہیں فرماتا اور اگر کوئی نیکی ہو تو اسے دونی کرتا اور اپنے پاس سے بڑا ثواب دیتا ہے،\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@dxxxiv{تو کیسی ہوگی جب ہم ہر امت سے ایک گواہ لائیں اور اے محبوب! تمہیں ان سب پر گواہ اور نگہبان بناکر لائیں\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@dxxxv{اس دن تمنا کریں گے وہ جنہوں نے کفر کیا اور رسول کی نافرمانی کی کاش انہیں مٹی میں دبا کر زمین برابر کردی جائے، اور کوئی بات اللہ سے نہ چھپاسکیں گے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@dxxxvi{اے ایمان والو! نشہ کی حالت میں نماز کے پاس نہ جاؤ جب تک اتنا ہوش نہ ہو کہ جو کہو اسے سمجھو اور نہ ناپاکی کی حالت میں بے نہائے مگر مسافری میں اور اگر تم بیمار ہو یا سفر میں یا تم میں سے کوئی قضائے حاجت سے آیا ہو یا تم نے عورتو ں کو چھوا اور پانی نہ پایا تو پاک مٹی سے تیمم کرو تو اپنے منہ اور ہاتھوں کا مسح کرو بیشک اللہ معاف کرنے والا بخشنے والا ہے،\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@dxxxvii{کیا تم نے انہیں نہ دیکھا جن کو کتاب سے ایک حصہ ملا گمراہی مول لیتے ہیں اور چاہتے ہیں کہ تم بھی راہ سے بہک جاؤ،\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@dxxxviii{اور اللہ خوب جانتا ہے تمہارے دشمنوں کو اور اللہ کافی ہے والی اور اللہ کافی ہے مددگار،\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@dxxxix{کچھ یہودی کلاموں کو ان کی جگہ سے پھیرتے ہیں اور کہتے ہیں ہم نے سنا اور نہ مانا اور سنیئے آپ سنائے نہ جائیں اور راعنا کہتے ہیں زبانیں پھیر کر اور دین میں طعنہ کے لئے اور اگر وہ کہتے کہ ہم نے سنا اور مانا اور حضور ہماری بات سنیں اور حضور ہم پر نظر فرمائیں تو ان کے لئے بھلائی اور راستی میں زیادہ ہوتا لیکن ان پر تو اللہ نے لعنت کی ان کے کفر کے سبب تو یقین نہیں رکھتے مگر تھوڑا\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@dxl{اے کتاب والو! ایمان لاؤ اس پر جو ہم نے اتارا تمہارے ساتھ والی کتاب کی تصدیق فرماتا قبل اس کے کہ ہم بگاڑ دیں کچھ مونہوں کو تو انہیں پھیر دیں ان کی پیٹھ کی طرف یا انہیں لعنت کریں جیسی لعنت کی ہفتہ والوں پر اور خدا کا حکم ہوکر رہے،\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@dxli{بیشک اللہ اسے نہیں بخشتا کہ اس کے ساتھ کفر کیا جائے اور کفر سے نیچے جو کچھ ہے جسے چاہے معاف فرمادیتا ہے اور جس نے خدا کا شریک ٹھہرایا اس نے بڑا گناہ کا طوفان باندھا،\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@dxlii{کیا تم نے انہیں نہ دیکھا جو خود اپنی ستھرائی بیان کرتے ہیں بلکہ اللہ جسے چاہے ستھرا کرے اور ان پر ظلم نہ ہوگا دانہ خرما کے ڈورے برابر\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@dxliii{دیکھو کیسا اللہ پر جھوٹ باندھا رہے ہیں اور یہ کافی ہے صریح گناہ،\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@dxliv{کیا تم نے، وہ نہ دیکھے جنہیں کتاب کا ایک حصہ ملا ایمان لاتے ہیں بت اور شیطان پر اور کافروں کو کہتے ہیں کہ یہ مسلمانوں سے زیادہ راہ پر ہیں،\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@dxlv{یہ ہیں جن پر اللہ نے لعنت کی اور جسے خدا لعنت کرے تو ہر گز اسکا کوئی یار نہ پائے گا\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@dxlvi{کیا ملک میں ان کا کچھ حصہ ہے ایسا ہو تو لوگوں کو تِل بھر نہ دیں،\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@dxlvii{یا لوگوں سے حسد کرتے ہیں اس پر جو اللہ نے انہیں اپنے فضل سے دیا تو ہم نے تو ابراہیم کی اولاد کو کتاب اور حکمت عطا فرمائی اور انہیں بڑا ملک دیا\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@dxlviii{تو ان میں کوئی اس پر ایمان لایا اور کسی نے اس سے منہ پھیرا اور دوزخ کافی ہے بھڑکتی آگ\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@dxlix{جنہوں نے ہماری آیتوں کا انکار کیا عنقریب ہم ان کو آگ میں داخل کریں گے، جب کبھی ان کی کھالیں پک جائیں گی ہم ان کے سوا اور کھالیں انہیں بدل دیں گے کہ عذاب کا مزہ لیں، بیشک اللہ غالب حکمت والا ہے،\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@dl{اور جو لوگ ایمان لائے اور اچھے کام کیے عنقریب ہم انہیں باغوں میں لے جائیں گے جن کے نیچے نہریں رواں ان میں ہمیشہ رہیں گے، ان کے لیے وہاں ستھری بیبیاں ہیں اور ہم انہیں وہاں داخل کریں گے جہاں سایہ ہی سایہ ہوگا\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@dli{بیشک اللہ تمہیں حکم دیتا ہے کہ امانتیں جن کی ہیں انہیں سپرد کرو اور یہ کہ جب تم لوگوں میں فیصلہ کرو تو انصاف کے ساتھ فیصلہ کرو بیشک اللہ تمہیں کیا ہی خوب نصیحت فرماتا ہے، بیشک اللہ سنتا دیکھتا ہے،\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@dlii{اے ایمان والو! حکم مانو اللہ کا اور حکم مانو رسول کا اور ان کا جو تم میں حکومت والے ہیں پھر اگر تم میں کسی بات کا جھگڑا اٹھے تو اسے اللہ اور رسول کے حضور رجوع کرو اگر اللہ اور قیامت پر ایمان رکھتے ہو یہ بہتر ہے اور اس کا انجام سب سے اچھا،\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@dliii{کیا تم نے انہیں نہ دیکھا جن کا دعویٰ ہے کہ وہ ایمان لائے اس پر جو تمہاری طرف اترا اور اس پر جو تم سے پہلے اترا پھر چاہتے ہیں کہ شیطان کو اپنا پنچ بنائیں اور ان کو تو حکم یہ تھا کہ اسے اصلاً نہ مانیں اور ابلیس یہ چاہتا ہے کہ انہیں دور بہکاوے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@dliv{اور جب ان سے کہا جائے کہ اللہ کی اتاری ہوئی کتاب اور رسول کی طرف آؤ تو تم دیکھو گے کہ منافق تم سے منہ موڑ کر پھر جاتے ہیں،\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@dlv{کیسی ہوگی جب ان پر کوئی افتاد پڑے بدلہ اسکا جو انکے ہاتھوں نے آگے بھیجا پھر اے محبوب! تمہارے حضور حاضر ہوں، اللہ کی قسم کھاتے کہ ہمارا مقصود تو بھلائی اور میل ہی تھا\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@dlvi{ان کے دلوں کی تو بات اللہ جانتا ہے تو تم ان سے چشم پوشی کرو اور انہیں سمجھا دو اور ان کے معاملہ میں ان سے رسا بات کہو\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@dlvii{اور ہم نے کوئی رسول نہ بھیجا مگر اس لئے کہ اللہ کے حکم سے اس کی اطاعت کی جائے اور اگر جب وہ اپنی جانوں پر ظلم کریں تو اے محبوب! تمہارے حضور حاضر ہوں اور پھر اللہ سے معافی چاہیں اور رسول ان کی شفاعت فرمائے تو ضرور اللہ کو بہت توبہ قبول کرنے والا مہربان پائیں\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@dlviii{تو اے محبوب! تمہارے رب کی قسم وہ مسلمان نہ ہوں گے جب تک اپنے آپس کے جھگڑے میں تمہیں حاکم نہ بنائئیں پھر جو کچھ تم حکم فرما دو اپنے دلوں میں اس سے رکاوٹ نہ پائیں اور جی سے مان لیں\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@dlix{اور اگر ہم ان پر فرض کرتے کہ اپنے آپ کو قتل کردو یا اپنے گھر بار چھوڑ کر نکل جاؤ تو ان میں تھوڑے ہی ایسا کرتے، اور اگر وہ کرتے جس بات کی انہیں نصیحت دی جاتی ہے تو اس میں ان کا بھلا تھا اور ایمان پر خوب جمنا\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@dlx{اور ایسا ہوتا تو ضرور ہم انہیں اپنے پاس سے بڑا ثواب دیتے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@dlxi{اور ضرور ان کو سیدھی راہ کی ہدایت کرتے،\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@dlxii{اور جو اللہ اور اس کے رسول کا حکم مانے تو اُسے ان کا ساتھ ملے گا جن پر اللہ نے فضل کیا یعنی انبیاء اور صدیق اور شہید اور نیک لوگ یہ کیا ہی اچھے ساتھی ہیں،\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@dlxiii{یہ اللہ کا فضل ہے، اور اللہ کافی ہے جاننے والا،\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@dlxiv{اے ایمان والو! ہوشیاری سے کام لو پھر دشمن کی طرف تھوڑے تھوڑے ہوکر نکلو یا اکٹھے چلو\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@dlxv{اور تم میں کوئی وہ ہے کہ ضرور دیر لگائے گا پھر اگر تم پر کوئی افتاد پڑے تو کہے خدا کا مجھ پر احسان تھا کہ میں ان کے ساتھ حاضر نہ تھا،\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@dlxvi{اور اگر تمہیں اللہ کا فضل ملے تو ضرو ر کہے گویا تم اس میں کوئی دوستی نہ تھی اے کاش میں ان کے ساتھ ہوتا تو بڑی مراد پاتا،\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@dlxvii{تو انہیں اللہ کی راہ میں لڑنا چاہئے جو دنیا کی زندگی بیچ کر آخرت لیتے ہیں اور جو اللہ کی راہ میں لڑے پھر مارا جائے یا غالب آئے تو عنقریب ہم اسے بڑا ثواب دیں گے،\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@dlxviii{اور تمہیں کیا ہوا کہ نہ لڑو اللہ کی راہ میں اور کمزور مردوں اور عورتوں اور بچوں کے واسطے یہ دعا کررہے ہیں کہ اے ہمارے رب ہمیں اس بستی سے نکال جس کے لوگ ظالم ہیں اور ہمیں اپنے پاس سے کوئی حمایتی دے دے اور ہمیں اپنے پاس سے کوئی مددگار دے دے،\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@dlxix{ایمان والے اللہ کی راہ میں لڑتے ہیں اور کفار شیطان کی راہ میں لڑتے ہیں تو شیطان کے دوستوں سے لڑو بیشک شیطان کا داؤ کمزور ہے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@dlxx{کیا تم نے انہیں نہ دیکھا جن سے کہا گیا اپنے ہاتھ روک لو اور نماز قائم رکھو اور زکوٰة دو پھر جب ان پر جہاد فرض کیا گیا تو ان میں بعضے لوگوں سے ایسا ڈرنے لگے جیسے اللہ سے ڈرے یا اس سے بھی زائد اور بولے اے رب ہمارے! تو نے ہم پر جہاد کیوں فرض کردیا تھوڑی مدت تک ہمیں اور جینے دیا ہوتا، تم فرما دو کہ دنیا کا برتنا تھوڑا ہے اور ڈر والوں کے لئے آخرت اچھی اور تم پر تاگے برابر ظلم نہ ہوگا\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@dlxxi{تم جہاں کہیں ہو موت تمہیں آلے گی اگرچہ مضبوط قلعوں میں ہو اور اُنہیں کوئی بھلائی پہنچے تو کہیں یہ اللہ کی طرف سے ہے اور انہیں کوئی برائی پہنچے تو کہیں یہ حضور کی طرف آئی تم فرمادو سب اللہ کی طرف سے ہے تو ان لوگوں کو کیا ہوا کوئی بات سمجھتے معلوم ہی نہیں ہوتے،\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@dlxxii{اے سننے والے تجھے جو بھلائی پہنچے وہ اللہ کی طرف سے ہے اور جو برائی پہنچے وہ تیری اپنی طرف سے ہے اور اے محبوب ہم نے تمہیں سب لوگوں کے لئے رسول بھیجا اور اللہ کافی ہے گواہ\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@dlxxiii{جس نے رسول کا حکم مانا بیشک اس نے اللہ کا حکم مانا اور جس نے منہ پھیرا تو ہم نے تمہیں ان کے بچانے کو نہ بھیجا\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@dlxxiv{اور کہتے ہیں ہم نے حکم مانا پھر جب تمہارے پاس سے نکل کر جاتے ہیں تو ان میں ایک گروہ جو کہہ گیا تھا اس کے خلاف رات کو منصوبے گانٹھتا ہے اور اللہ لکھ رکھتا ہے ان کے رات کے منصوبے تو اے محبوب تم ان سے چشم پوشی کرو اور اللہ پر بھروسہ رکھو اور اللہ کافی ہے کام بنانے کو،\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@dlxxv{تو کیا غور نہیں کرتے قرآن میں اور اگر وہ غیر خدا کے پاس سے ہوتا تو ضرور اس میں بہت اختلاف پاتے\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@dlxxvi{اور جب ان کے پاس کوئی بات اطمینان یا ڈر کی آتی ہے اس کا چرچا کر بیٹھتے ہیں اور اگر اس میں رسول اور اپنے ذی اختیار لوگوں کی طرف رجوع لاتے تو ضرور اُن سے اُ س کی حقیقت جان لیتے یہ جو بعد میں کاوش کرتے ہیں اور اگر تم پر اللہ کا فضل اور اس کی رحمت نہ ہوتی تو ضرور تم شیطان کے پیچھے لگ جاتے مگر تھوڑے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@dlxxvii{تو اے محبوب اللہ کی راہ میں لڑو تم تکلیف نہ دیئے جاؤ گے مگر اپنے دم کی اور مسلمانوں کو آمادہ کرو قریب ہے کہ اللہ کافروں کی سختی روک دے اور اللہ کی آنچ (جنگی طاقت) سب سے سخت تر ہے اور اس کا عذاب سب سے کڑا (زبردست)\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@dlxxviii{جو اچھی سفارش کرے اس کے لئے اس میں سے حصہ ہے اور جو بری سفارش کرے اس کے لئے اس میں سے حصہ ہے اور اللہ ہر چیز پر قادر ہے،\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@dlxxix{اور جب تمہیں کوئی کسی لفظ سے سلام کرے تو اس سے بہتر لفظ جواب میں کہو یا یا وہی کہہ دو، بیشک اللہ ہر چیز پر حساب لینے والا ہے\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@dlxxx{ا لله کہ اس کے سوا کسی کی بندگی نہیں اور وہ ضرور تمہیں اکٹھا کرے گا قیامت کے دن جس میں کچھ شک نہیں اور اللہ سے زیادہ کس کی بات سچی\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@dlxxxi{تو تمہیں کیا ہوا کہ منافقوں کے بارے میں دو فریق ہوگئے اور اللہ نے انہیں اوندھا کردیا ان کے کوتکوں (کرتوتوں) کے سبب کیا یہ چاہتے ہیں کہ اسے راہ دکھاؤ جسے اللہ نے گمراہ کیا اور جسے اللہ گمراہ کرے تو ہرگز اس کے لئے راہ نہ پائے گا،\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@dlxxxii{وہ تو یہ چاہتے ہیں کہ کہیں تم بھی کافر ہوجاؤ جیسے وہ کافر ہوئے تو تم سب ایک سے ہو جاؤ ان میں کسی کو اپنا دوست نہ بناؤ جب تک اللہ کی راہ میں گھر بار نہ چھوڑیں پھر اگر وہ منہ پھیریں تو انہیں پکڑو اور جہاں پاؤ قتل کرو، اور ان میں کسی کو نہ دوست ٹھہراؤ نہ مددگار\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@dlxxxiii{مگر جو ایسی قوم سے علاقے رکھتے ہیں کہ تم میں ان میں معاہدہ ہے یا تمہارے پاس یوں آئے کہ ان کے دلوں میں سکت نہ رہی کہ تم سے لڑیں یا اپنی قوم سے لڑیں اور اللہ چاہتا تو ضرور انہیں تم پر قابو دیتا تو وہ بے شک تم سے لڑتے پھر اگر وہ تم سے کنارہ کریں اور نہ لڑیں اور صلح کا پیام ڈالیں تو اللہ نے تمہیں ان پر کوئی راہ نہ رکھی\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@dlxxxiv{اب کچھ اور تم ایسے پاؤ گے جو یہ چاہتے ہیں کہ تم سے بھی امان میں رہیں اور اپنی قوم سے بھی امان میں رہیں جب کبھی انکی قوم انہیں فساد کی طرف پھیرے تو اس پر اوندھے گرتے ہیں پھر اگر وہ تم سے کنارہ نہ کریں اور صلح کی گردن نہ ڈالیں اور اپنے ہاتھ سے نہ روکیں تو انہیں پکڑو اور جہاں پاؤ قتل کرو، اور یہ ہیں جن پر ہم نے تمہیں صریح اختیار دیا\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@dlxxxv{اور مسلمانوں کو نہیں پہنچتا کہ مسلمان کا خون کرے مگر ہاتھ بہک کر اور جو کسی مسلمان کو نادانستہ قتل کرے تو اس پر ایک مملوک مسلمان کا آزاد کرنا ہے اور خون بہا کر مقتول کے لوگوں کو سپرد کی جائے مگر یہ کہ وہ معاف کردیں پھر اگر وہ اس قوم سے ہو جو تمہاری دشمن ہے اور خود مسلمان ہے تو صرف ایک مملوک مسلمان کا آزاد کرنا اور اگر وہ اس قوم میں ہو کہ تم میں ان میں معاہدہ ہے تو اس کے لوگوں کو خوں بہا سپرد کیا جائے اور ایک مسلمان مملوک آزاد کرنا تو جس کا ہاتھ نہ پہنچے وہ لگاتار دو مہینے کے روزے یہ اللہ کے یہاں اس کی توبہ ہے اور اللہ جاننے والا حکمت والا ہے،\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@dlxxxvi{اور جو کوئی مسلمان کو جان بوجھ کر قتل کرے تو اس کا بدلہ جہنم ہے کہ مدتوں اس میں رہے اور اللہ نے اس پر غضب کیا اور اس پر لعنت کی اور اس کے لئے تیار رکھا بڑا عذاب،\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@dlxxxvii{اے ایمان والو! جب تم جہاد کو چلو تو تحقیق کرلو اور جو تمہیں سلام کرے اس سے یہ نہ کہو کہ تو مسلمان نہیں تم جیتی دنیا کا اسباب چاہتے ہو تو اللہ کے پاس بہتری غنیمتیں ہیں پہلے تم بھی ایسے ہی تھے پھر اللہ نے تم پر احسان کیا تو تم پر تحقیق کرنا لازم ہے بیشک اللہ کو تمہارے کاموں کی خبر ہے،\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@dlxxxviii{برابر نہیں وہ مسلمان کہ بے عذر جہاد سے بیٹھ رہیں اور وہ کہ راہ خدا میں اپنے مالوں اور جانوں سے جہاد کرتے ہیں اللہ نے اپنے مالوں اور جانوں کے ساتھ جہاد کرنے والوں کا درجہ بیٹھنے والوں سے بڑا کیا اور اللہ نے سب سےبھلائی کا وعدہ فرمایا اور اللہ نے جہاد والوں کو بیٹھنے والوں پر بڑے ثواب سے فضیلت دی ہے،\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@dlxxxix{اُس کی طرف سے درجے اور بخشش اور رحمت اور اللہ بخشنے والا مہربان ہے،\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@dxc{وہ لوگ جنکی جان فرشتے نکالتے ہیں اس حال میں کہ وہ اپنے اوپر ظلم کرتے تھے انسے فرشتے کہتے ہیں تم کاہے میں تھے کہتے ہیں کہ ہم زمین میں کمزور تھے کہتے ہیں کیا اللہ کی زمین کشادہ نہ تھی کہ تم اسمیں ہجرت کرتے، تو ایسوں کا ٹھکانا جہنم ہے، اور بہت بری جگہ پلٹنے کی\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@dxci{مگر وہ جو دبالیے گئے مرد اور عورتیں اور بچے جنہیں نہ کوئی تدبیر بن پڑے نہ راستہ جانیں،\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@dxcii{تو قریب ہے اللہ ایسوں کو معاف فرمائے اور اللہ معاف فرمانے والا بخشنے والا ہے،\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@dxciii{اور جو اللہ کی راہ میں گھر بار چھوڑ کر نکلے گا وہ زمین میں بہت جگہ اور گنجائش پائے گا، اور جو اپنے گھر سے نکلا اللہ و رسول کی طرف ہجرت کرتا پھر اسے موت نے آلیا تو اس کا ثواب اللہ کے ذمہ پر ہوگیا اور اللہ بخشنے والا مہربان ہے\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@dxciv{اور جب تم زمین میں سفر کرو تو تم پر گناہ نہیں کہ بعض نمازیں قصر سے پڑھو اگر تمہیں اندیشہ ہو کہ کافر تمہیں ایذا دیں گے بیشک کفار تمہارے کھلے دشمن ہیں،\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@dxcv{اور اے محبوب! جب تم ان میں تشریف فرما ہو پھر نماز میں ان کی امامت کرو تو چاہئے کہ ان میں ایک جماعت تمہارے ساتھ ہو اور وہ اپنے ہتھیار لیے رہیں پھر جب وہ سجدہ کرلیں تو ہٹ کر تم سے پیچھے ہوجائیں اور اب دوسری جماعت آئے جو اس وقت تک نماز میں شریک نہ تھی اب وہ تمہارے مقتدی ہوں اور چاہئے کہ اپنی پناہ اور اپنے ہتھیار لیے رہیں کافروں کی تمنا ہے کہ کہیں تم اپنے ہتھیاروں اور اپنے اسباب سے غافل ہو جاؤ تو ایک دفعہ تم پر جھک پڑیں اور تم پر مضائقہ نہیں اگر تمہیں مینھ کے سبب تکلیف ہو یا بیمار ہو کہ اپنے ہتھیار کھول رکھو اور اپنی پناہ لیے رہو بیشک اللہ نے کافروں کے لئے خواری کا عذاب تیار کر رکھا ہے،\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@dxcvi{پھر جب تم نماز پڑھ چکو تو اللہ کی یاد کرو کھڑے اور بیٹھے اور کروٹوں پر لیٹے پھر جب مطمئن ہو جاؤ تو حسب دستور نماز قائم کرو بیشک نماز مسلمانوں پر وقت باندھا ہوا فرض ہے\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@dxcvii{اور کافروں کی تلاش میں سستی نہ کرو اگر تمہیں دکھ پہنچتا ہے تو انہیں بھی دکھ پہنچتا ہے جیسا تمہیں پہنچتا ہے، اورتم اللہ سے وہ امید رکھتےہو جو وہ نہیں رکھتے، ور اللہ جاننے والا حکمت والا ہے\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@dxcviii{اے محبوب! بیشک ہم نے تمہاری طرف سچی کتاب اتاری کہ تم لوگوں میں فیصلہ کرو جس طرح تمہیں اللہ دکھائے اور دغا والوں کی طرف سے نہ جھگڑو\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@dxcix{اور اللہ سے معافی چاہو بیشک اللہ بخشنے والا مہربان ہے،\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@dc{اور ان کی طرف سے نہ جھگڑو جو اپنی جانوں کو خیانت میں ڈالتے ہیں بیشک اللہ نہیں چاہتا کسی بڑے دغا باز گنہگار کو\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@dci{آدمیوں سے چھپتے ہیں اور اللہ نہیں چھپتے اور ا لله ان کے پاس ہے جب دل میں وہ بات تجویز کرتے ہیں جو اللہ کو ناپسند ہے اور اللہ ان کے کاموں کو گھیرے ہوئے ہے،\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@dcii{سنتے ہو یہ جو تم ہو دنیا کی زندگی میں تو ان کی طرف سے جھگڑے تو ان کی طرف سے کون جھگڑے گا اللہ سے قیامت کے دن یا کون ان کا وکیل ہوگا،\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@dciii{اور جو کوئی برائی یا اپنی جان پر ظلم کرے پھر اللہ سے بخشش چاہے تو اللہ کو بخشنے والا مہربان پائے گا،\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@dciv{اور جو گناہ کمائے تو ا س کی کمائی اسی کی جان پر پڑے اور اللہ علم و حکمت والا ہے\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@dcv{اور جو کوئی خطا یا گناہ کمائے پھر اسے کسی بے گناہ پر تھوپ دے اس نے ضرور بہتان اور کھلا گناہ اٹھایا،\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@dcvi{اور اے محبوب! اگر اللہ کا فضل و رحمت تم پر نہ ہوتا تو ان میں کے کچھ لوگ یہ چاہتے کہ تمہیں دھوکا دے دیں اور وہ اپنے ہی آپ کو بہکا رہے ہیں اور تمہارا کچھ نہ بگاڑیں گے اور اللہ نے تم پر کتاب اور حکمت اتاری اور تمہیں سکھا دیا جو کچھ تم نہ جانتے تھے اور اللہ کا تم پر بڑا فضل ہے\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@dcvii{ان کے اکثر مشوروں میں کچھ بھلائی نہیں مگر جو حکم دے خیرات یا اچھی بات یا لوگوں میں صلح کرنے کا اور جو اللہ کی رضا چاہنے کو ایسا کرے اسے عنقریب ہم بڑا ثواب دیں گے،\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@dcviii{اور جو رسول کا خلاف کرے بعد اس کے کہ حق راستہ اس پر کھل چکا اور مسلمانوں کی راہ سے جدا راہ چلے ہم اُسے اُس کے حال پر چھوڑ دیں گے اور اسے دوزخ میں داخل کریں گے اور کیا ہی بری جگہ پلٹنے کی\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@dcix{اللہ اسے نہیں بخشتا کہ اس کا کوئی شریک ٹھہرایا جائے اور اس سے نیچے جو کچھ ہے جسے چاہے معاف فرما دیتا ہے اور جو اللہ کا شریک ٹھہرائے وہ دور کی گمراہی میں پڑا،\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@dcx{یہ شرک والے اللہ سوا نہیں پوجتے مگر کچھ عورتوں کو اور نہیں پوجتے مگر سرکش شیطان کو\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@dcxi{جس پر اللہ نے لعنت کی اور بولا قسم ہے میں ضرور تیرے بندوں میں سے کچھ ٹھہرایا ہوا حصہ لوں گا\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@dcxii{قسم ہے میں ضرور بہکادوں گا اور ضرور انہیں آرزوئیں دلاؤں گا اور ضرور انہیں کہوں گا کہ وہ چوپایوں کے کان چیریں گے اور ضرور انہیں کہوں گا کہ وہ اللہ کی پیدا کی ہوئی چیزیں بدل دیں گے، اور جو اللہ کو چھوڑ کر شیطان کو دوست بنائے وہ صریح ٹوٹے میں پڑا\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@dcxiii{شیطان انہیں وعدے دیتا ہے اور آرزوئیں دلاتا ہے اور شیطان انہیں وعدے نہیں دیتا مگر فریب کے\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@dcxiv{اُن کا ٹھکانا دوزخ ہے اس سے بچنے کی جگہ نہ پائیں گے،\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@dcxv{اور جو ایمان لائے اور اچھے کام کیے کچھ دیر جاتی ہے کہ ہم انہیں باغوں میں لے جائیں گے جن کے نیچے نہریں بہیں ہمیشہ ہمیشہ ان میں رہیں اللہ کا سچا وعدہ اور اللہ سے زیادہ کس کی بات سچی،\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@dcxvi{کام نہ کچھ تمہارے خیالوں پر ہے اور نہ کتاب والوں کی ہوس پر جو برائی کرے گا اس کا بدلہ پائے گا اور اللہ کے سوا نہ کوئی اپنا حمایتی پائے گا نہ مددگار\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@dcxvii{اور جو کچھ بھلے کام کرے گا مرد ہو یا عورت اور ہو مسلمان تو وہ جنت میں داخل کیے جائیں گے اور انہیں تِل بھر نقصان نہ دیا جائے گا\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@dcxviii{اور اس سے بہتر کس کا دین جس نے اپنا منہ اللہ کے لئے جھکا دیا اور وہ نیکی والا ہے اور ابراہیم کے دین پر جو ہر باطل سے جدا تھا اور اللہ نے ابراہیم کو اپنا گہرا دوست بنایا\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@dcxix{اور اللہ ہی کا ہے جو کچھ آسمانوں میں ہے اور جو کچھ زمین میں، اور ہر چیز پر اللہ کا قابو ہے\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@dcxx{اور تم سے عورتوں کے بارے میں فتویٰ پوچھتے ہیں تم فرمادو کہ اللہ تمہیں ان کا فتویٰ دیتا ہے اور وہ جو تم پر قرآن میں پڑھا جاتا ہے ان یتیم لڑکیوں کے بارے میں تم انہیں نہیں دیتے جو ان کا مقرر ہے اور انہیں نکاح میں بھی لانے سے منہ پھیرتے ہو اور کمزور بچوں کے بارے میں اور یہ کہ یتیموں کے حق میں انصاف پر قائم رہو اور تم جو بھلائی کرو تو اللہ کو اس کی خبر ہے،\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@dcxxi{اور اگر کوئی عورت اپنے شوہر کی زیادتی یا بے رغبتی کا اندیشہ کرے تو ان پر گناہ نہیں کہ آپس میں صلح کرلیں اور صلح خوب ہے اور دل لالچ کے پھندے میں ہیں اور اگر تم نیکی اور پرہیزگاری کرو تو اللہ کو تمہارے کاموں کی خبر ہے\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@dcxxii{اور تم سے ہرگز نہ ہوسکے گا کہ عورتوں کو برابر رکھو اور چاہے کتنی ہی حرص کرو تو یہ تو نہ ہو کہ ایک طرف پورا جھک جاؤ کہ دوسری کو ادھر میں لٹکتی چھوڑ دو اور اگر تم نیکی اور پرہیزگاری کرو تو بیشک اللہ بخشنے والا مہربان ہے،\qt@no{(129)}}%
\qt@newcmd\qurantrans@ur@dcxxiii{اور اگر وہ دونوں جدا ہوجائیں تو اللہ اپنی کشائش سے تم میں ہر ایک کو دوسرے سے بے نیاز کردے گا اور اللہ کشائش والا حکمت والا ہے،\qt@no{(130)}}%
\qt@newcmd\qurantrans@ur@dcxxiv{اور اللہ ہی کا ہے جو کچھ آسمانوں میں ہے اور جو کچھ زمین میں، اور بیشک تاکید فرمادی ہے ہم نے ان سے جو تم سے پہلے کتاب دیئے گئے اور تم کو کہ اللہ سے ڈرتے رہو اور اگر کفر کرو تو بیشک اللہ ہی کا ہے جو کچھ آسمانوں میں ہے اور جو کچھ زمین میں اور اللہ بے نیاز ہے سب خوبیوں سراہا،\qt@no{(131)}}%
\qt@newcmd\qurantrans@ur@dcxxv{اور اللہ کا ہے جو کچھ آسمانوں میں ہے اور جو کچھ زمین میں، اور اللہ کافی ہے کارساز،\qt@no{(132)}}%
\qt@newcmd\qurantrans@ur@dcxxvi{اے لوگوں وہ چاہے تو تمہیں لے جائے اور اوروں کو لے آئے اور اللہ کو اس کی قدرت ہے،\qt@no{(133)}}%
\qt@newcmd\qurantrans@ur@dcxxvii{جو دنیا کا انعام چاہے تو اللہ ہی کے پاس دنیا و آخرت دونوں کا انعام ہے اور اللہ ہی سنتا دیکھتا ہے،\qt@no{(134)}}%
\qt@newcmd\qurantrans@ur@dcxxviii{اے ایمان والو! انصاف پر خوب قائم ہوجاؤ اللہ کے لئے گواہی دیتے چاہے اس میں تمہارا اپنا نقصان ہو یا ماں باپ کا یا رشتہ داروں کا جس پر گواہی دو وہ غنی ہو یا فقیر ہو بہرحال اللہ کو اس کا سب سے زیادہ اختیار ہے تو خواہش کے پیچھے نہ جاؤ کہ حق سے الگ پڑو اگر تم ہیر پھیر کرو یا منہ پھیرو تو اللہ کو تمہارے کاموں کی خبر ہے\qt@no{(135)}}%
\qt@newcmd\qurantrans@ur@dcxxix{اے ایمان والو ایمان رکھو اللہ اور اللہ کے رسول پر اور اس کتاب پر جو اپنے ان رسول پر اتاری اور اس کتاب پر جو پہلے اتاردی اور جو نہ مانے اللہ اور اس کے فرشتوں اور کتابوں اور رسولوں اور قیامت کو تو وہ ضرور دور کی گمراہی میں پڑا،\qt@no{(136)}}%
\qt@newcmd\qurantrans@ur@dcxxx{بیشک وہ لوگ جو ایمان لائے پھر کافر ہوئے پھر ایمان لائے پھر کافر ہوئے پھر اور کفر میں بڑھے اللہ ہرگز نہ انہیں بخشے نہ انہیں راہ دکھائے،\qt@no{(137)}}%
\qt@newcmd\qurantrans@ur@dcxxxi{خوشخبری دو منافقوں کو کہ ان کے لئے دردناک عذاب ہے\qt@no{(138)}}%
\qt@newcmd\qurantrans@ur@dcxxxii{وہ جو مسلمانوں کو چھوڑ کر کافروں کو دوست بناتے ہیں کیا ان کے پاس عزت ڈھونڈتے ہیں تو عزت تو ساری اللہ کے لیے ہے\qt@no{(139)}}%
\qt@newcmd\qurantrans@ur@dcxxxiii{اور بیشک اللہ تم پر کتاب میں اتار چکا کہ جب تم اللہ کی آیتوں کو سنو کہ ان کا انکار کیا جاتا اور ان کی ہنسی بنائی جاتی ہے تو ان لوگوں کے ساتھ نہ بیٹھو جب تک وہ اور بات میں مشغول نہ ہوں ورنہ تم بھی انہیں جیسے ہو بیشک اللہ منافقوں اور کافروں سب کو جہنم میں اکٹھا کرے گا\qt@no{(140)}}%
\qt@newcmd\qurantrans@ur@dcxxxiv{وہ جو تمہاری حالت تکا کرتے ہیں تو اگر اللہ کی طرف سے تم کو فتح ملے کہیں کیا ہم تمہارے ساتھ نہ تھے اور اگر کافروں کا حصہ ہو تو ان سے کہیں کیا ہمیں تم پر قابو نہ تھا اور ہم نے تمہیں مسلمانوں سے بچایا تو اللہ تم سب میں قیامت کے دن فیصلہ کردے گا اور اللہ کافروں کو مسلمان پر کوئی راہ نہ دے گا\qt@no{(141)}}%
\qt@newcmd\qurantrans@ur@dcxxxv{بیشک منافق لوگ اپنے گمان میں اللہ کو فریب دیا چاہتے ہیں اور وہی انہیں غافل کرکے مارے گا اور جب نماز کو کھڑے ہوں تو ہارے جی سے لوگوں کو دکھاوا کرتے ہیں اور اللہ کو یاد نہیں کرتے مگر تھوڑا\qt@no{(142)}}%
\qt@newcmd\qurantrans@ur@dcxxxvi{بیچ میں ڈگمگا رہے ہیں نہ اِدھر کے نہ اُدھر کے اور جسے اللہ گمراہ کرے تو اس کے لئے کوئی راہ نہ پائے گا،\qt@no{(143)}}%
\qt@newcmd\qurantrans@ur@dcxxxvii{اے ایمان والو! کافروں کو دوست نہ بناؤ مسلمانوں کے سوا کیا یہ چاہتے ہو کہ اپنے اوپر اللہ کے لئے صریح حجت کرلو\qt@no{(144)}}%
\qt@newcmd\qurantrans@ur@dcxxxviii{بیشک منافق دوزخ کے سب سے نیچے طبقہ میں ہیں اور تو ہرگز ان کا کوئی مددگار نہ پائے گا\qt@no{(145)}}%
\qt@newcmd\qurantrans@ur@dcxxxix{مگر وہ جنہوں نے توبہ کی اور سنورے اور اللہ کی رسی مضبوط تھامی اور اپنا دین خالص اللہ کے لئے کرلیا تو یہ مسلمانوں کے ساتھ ہیں اور عنقریب اللہ مسلمانوں کو بڑا ثواب دے گا،\qt@no{(146)}}%
\qt@newcmd\qurantrans@ur@dcxl{اور اللہ تمہیں عذاب دے کر کیا کرے گا اگر تم حق مانو، اور ایمان لاؤ اور اللہ ہے صلہ دینے والا جاننے والا،\qt@no{(147)}}%
\qt@newcmd\qurantrans@ur@dcxli{اللہ پسند نہیں کرتا بری بات کا اعلان کرنا مگر مظلوم سے اور اللہ سنتا جانتا ہے،\qt@no{(148)}}%
\qt@newcmd\qurantrans@ur@dcxlii{اگر تم کوئی بھلائی اعلانیہ کرو یا چھپ کر یا کسی کی برائی سے درگزرو تو بیشک اللہ معاف کرنے والا قدرت والا ہے\qt@no{(149)}}%
\qt@newcmd\qurantrans@ur@dcxliii{وہ جو اللہ اور اس کے رسولوں کو نہیں مانتے اور چاہتے ہیں کہ اللہ سے اس کے رسولوں کو جدا کردیں اور کہتے ہیں ہم کسی پر ایمان لائے اور کسی کے منکر ہوئے اور چاہتے ہیں کہ ایمان و کفر کے بیچ میں کوئی راہ نکال لیں\qt@no{(150)}}%
\qt@newcmd\qurantrans@ur@dcxliv{یہی ہیں ٹھیک ٹھیک کافر اور ہم نے کافروں کے لئے ذلت کا عذاب تیار کر رکھا ہے،\qt@no{(151)}}%
\qt@newcmd\qurantrans@ur@dcxlv{اور وہ جو اللہ اور اس کے سب رسولوں پر ایمان لائے اور ان میں سے کسی پر ایمان میں فرق نہ کیا انہیں عنقریب اللہ ان کے ثواب دے گا اور اللہ بخشنے والا مہربان ہے\qt@no{(152)}}%
\qt@newcmd\qurantrans@ur@dcxlvi{اے محبوب! اہل کتاب تم سے سوال کرتے ہیں کہ ان پر آسمان سے ایک کتاب اتاردو تو وہ تو موسیٰ سے اس سے بھی بڑا سوال کرچکے کہ بولے ہمیں ا لله کو اعلانیہ دکھادو تو انہیں کڑک نے آ لیا ان کے گناہوں پر پھر بچھڑا لے بیٹھے بعداس کے لئے روشن آیتیں ان کے پاس آچکیں تو ہم نے یہ معاف فرمادیا اور ہم نے موسیٰ کو روشن غلبہ دیا\qt@no{(153)}}%
\qt@newcmd\qurantrans@ur@dcxlvii{پھر ہم نے ان پر طور کو اونچا کیا ان سے عہد لینے کو اور ان سے فرمایا کہ دروازے میں سجدہ کرتے داخل ہو اور ان سے فرمایا کہ ہفتہ میں حد سے نہ بڑھو اور ہم نے ان سے گاڑھا عہد لیا\qt@no{(154)}}%
\qt@newcmd\qurantrans@ur@dcxlviii{تو ان کی کیسی بدعہدیوں کے سبب ہم نے ان پر لعنت کی اور اس لئے کہ وہ آیات الٰہی کے منکر ہوئے اور انبیاء کو ناحق شہید کرتے اور ان کے اس کہنے پر کہ ہمارے دلوں پر غلاف ہیں بلکہ اللہ نے ان کے کفر کے سبب ان کے دلوں پر مہر لگادی ہے تو ایمان نہیں لاتے مگر تھوڑے،\qt@no{(155)}}%
\qt@newcmd\qurantrans@ur@dcxlix{اور اس لئے کہ انہوں نے کفر کیا اور مریم پر بڑا بہتان اٹھایا،\qt@no{(156)}}%
\qt@newcmd\qurantrans@ur@dcl{اور ان کے اس کہنے پر کہ ہم نے مسیح عیسیٰ بن مریم اللہ کے رسول کو شہید کیا اور ہے یہ کہ انہوں نے نہ اسے قتل کیا اور نہ اسے سولی دی بلکہ ان کے لئے ان کی شبیہ کا ایک بنادیا گیا اور وہ جو اس کے بارہ میں اختلاف کررہے ہیں ضرور اس کی طرف سے شبہ میں پڑے ہوئے ہیں انہیں اس کی کچھ بھی خبر نہیں مگر یہی گمان کی پیروی اور بیشک انہوں نے اس کو قتل نہیں کیا\qt@no{(157)}}%
\qt@newcmd\qurantrans@ur@dcli{بلکہ اللہ نے اسے اپنی طرف اٹھالیا اور اللہ غالب حکمت والا ہے،\qt@no{(158)}}%
\qt@newcmd\qurantrans@ur@dclii{کوئی کتابی ایسا نہیں جو اس کی موت سے پہلے اس پر ایمان نہ لائے اور قیامت کے دن وہ ان پر گواہ ہوگا\qt@no{(159)}}%
\qt@newcmd\qurantrans@ur@dcliii{تو یہودیوں کے بڑے ظلم کے سبب ہم نے وہ بعض ستھری چیزیں کہ ان کے لئے حلال تھیں ان پر حرام فرمادیں اور اس لئے کہ انہوں نے بہتوں کو اللہ کی راہ سے روکا،\qt@no{(160)}}%
\qt@newcmd\qurantrans@ur@dcliv{اور اس لئے کہ وہ سود لیتے حالانکہ وہ اس سے منع کیے گئے تھے اور لوگوں کا مال ناحق کھا جاتے اور ان میں جو کافر ہوئے ہم نے ان کے لئے دردناک عذاب تیار کر رکھا ہے،\qt@no{(161)}}%
\qt@newcmd\qurantrans@ur@dclv{ہاں جو اُن میں علم کے پکے اور ایمان والے ہیں وہ ایمان لاتے ہیں اس پر جو اے محبوب تمہاری طرف اُترا اور جو تم سے پہلے اُترا اور نماز قائم رکھنے والے اور زکوٰة دینے والے اور اللہ اور قیامت پر ایمان لانے والے ایسوں کو عنقریب ہم بڑا ثواب دیں گے،\qt@no{(162)}}%
\qt@newcmd\qurantrans@ur@dclvi{بیشک اے محبوب! ہم نے تمہاری طرف وحی بھیجی جیسے دحی نوح اور اس کے بعد پیغمبروں کو بھیجی اور ہم نے ابراہیم اور اسمٰعیل اور اسحاق اور یعقوب اور ان کے بیٹوں اور عیسیٰ اور ایوب اور یونس اور ہارون اور سلیمان کو وحی کی اور ہم نے داؤد کو زبور عطا فرمائی\qt@no{(163)}}%
\qt@newcmd\qurantrans@ur@dclvii{اور رسولوں کو جن کا ذکر آگے ہم تم سے فرماچکے اور ان رسولوں کو جن کا ذکر تم سے نہ فرمایا اور اللہ نے موسیٰ سے حقیقتاً کلام فرمایا\qt@no{(164)}}%
\qt@newcmd\qurantrans@ur@dclviii{رسول خوشخبری دیتے اور ڈر سناتے کہ رسولوں کے بعد اللہ کے یہاں لوگوں کو کوئی عذر نہ رہے اور اللہ غالب حکمت والا ہے،\qt@no{(165)}}%
\qt@newcmd\qurantrans@ur@dclix{لیکن اے محبوب! اللہ اس کا گواہ ہے جو اس نے تمہاری طرف اتارا وہ اس نے اپنے علم سے اتارا ہے اور فرشتے گواہ ہیں اور اللہ کی گواہی کافی،\qt@no{(166)}}%
\qt@newcmd\qurantrans@ur@dclx{وہ جنہوں نے کفر کیا اور اللہ کی راہ سے روکا بیشک وہ دور کی گمراہی میں پڑے،\qt@no{(167)}}%
\qt@newcmd\qurantrans@ur@dclxi{بیشک جنہوں نے کفر کیا اور حد سے بڑھے اللہ ہرگز انہیں نہ بخشے گا اور نہ انہیں کوئی راہ دکھائے،\qt@no{(168)}}%
\qt@newcmd\qurantrans@ur@dclxii{مگر جہنم کا راستہ کہ اس میں ہمیشہ ہمیشہ رہیتں گے اور یہ اللہ کو آسان ہے،\qt@no{(169)}}%
\qt@newcmd\qurantrans@ur@dclxiii{اے لوگو! تمہارے پاس یہ رسول حق کے ساتھ تمہارے رب کی طرف سے تشریف لائے تو ایمان لاؤ اپنے بھلے کو اور اگر تم کفر کرو تو بیشک اللہ ہی کا ہے جو کچھ آسمانوں اور زمین میں ہے، اور اللہ علم و حکمت والا ہے،\qt@no{(170)}}%
\qt@newcmd\qurantrans@ur@dclxiv{اے کتاب والو! اپنے دین میں زیادتی نہ کرو اور اللہ پر نہ کہو مگر سچ مسیح عیسیٰ مریم کا بیٹا ا لله کا رسول ہی ہے اور اس کا ایک کلمہ کہ مریم کی طرف بھیجا اور اس کے یہاں کی ایک روح تو اللہ اور اس کے رسولوں پر ایمان لاؤ اور تین نہ کہو باز رہو اپنے بھلے کو اللہ تو ایک ہی خدا ہے پاکی اُسے اس سے کہ اس کے کوئی بچہ ہو اسی کا مال ہے جو کچھ آسمانوں میں ہے اور جو کچھ زمین میں ہے اور اللہ کافی کارساز،\qt@no{(171)}}%
\qt@newcmd\qurantrans@ur@dclxv{مسیح اللہ کا بندہ بننے سے کچھ نفرت نہیں کرتا اور نہ مقرب فرشتے اور جو اللہ کی بندگی سے نفرت اور تکبر کرے تو کوئی دم جاتا ہے کہ وہ ان سب کو اپنی طرف ہانکے گا\qt@no{(172)}}%
\qt@newcmd\qurantrans@ur@dclxvi{تو وہ جو ایمان لائے اور اچھے کام کیے ان کی مزدوری انہیں بھرپور دے کر اپنے فضل سے انہیں اور زیادہ دے گا اور وہ جنہوں نے نفرت اور تکبر کیا تھا انہیں دردناک سزا دے گا اور اللہ کے سوا نہ اپنا کوئی حمایتی پائیں گے نہ مددگار،\qt@no{(173)}}%
\qt@newcmd\qurantrans@ur@dclxvii{اے لوگو! بیشک تمہارے پاس اللہ کی طرف سے واضح دلیل آئی اور ہم نے تمہاری طرف روشن نور اتارا\qt@no{(174)}}%
\qt@newcmd\qurantrans@ur@dclxviii{تو وہ جو اللہ پر ایمان لائے اور اس کی رسی مضبوط تھامی تو عنقریب اللہ انہیں اپنی رحمت اور اپنے فضل میں داخل کرے گا اور انہیں اپنی طرف سیدھی راہ دکھائے گا،\qt@no{(175)}}%
\qt@newcmd\qurantrans@ur@dclxix{اے محبوب! تم سے فتویٰ پوچھتے ہیں تم فرمادو کہ اللہ تمہیں کلالہ میں فتویٰ دیتا ہے، اگر کسی مرد کا انتقال ہو جو بے اولاد ہے اور اس کی ایک بہن ہو تو ترکہ میں اس کی بہن کا آدھا ہے اور مرد اپنی بہن کا وارث ہوگا اگر بہن کی اولاد نہ ہو پھر اگر دو بہنیں ہوں ترکہ میں ان کا دو تہائی اور اگر بھائی بہن ہوں مرد بھی اور عورتیں بھی تو مرد کا حصہ دو عورتوں کے برابر، ا لله تمہارے لئے صاف بیان فرماتا ہے کہ کہیں بہک نہ جاؤ، اور اللہ ہرچیز جانتا ہے،\qt@no{(176)}}%
\qt@newcmd\qurantrans@ur@dclxx{\basmalahur اے ایمان والو! اپنے قول پورے کرو تمہارے لئے حلال ہوئے بے زبان مویشی مگر وہ جو آگے سنایا جائے گا تم کو لیکن شکار حلال نہ سمجھو جب تم احرام میں ہو بیشک اللہ حکم فرماتا ہے جو چاہے،\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@dclxxi{اے ایمان والو! حلال نہ ٹھہرالو اللہ کے نشان اور نہ ادب والے مہینے اور نہ حرم کو بھیجی ہوئی قربانیاں اور نہ جن کے گلے میں علامتیں آویزاں اور نہ ان کا مال و آبرو جو عزت والے گھر کا قصد کرکے آئیں اپنے رب کا فضل اوراس کی خوشی چاہتے اور جب احرام سے نکلو تو شکار کرسکتے ہو اور تمہیں کسی قوم کی عداوت کہ انہوں نے تم کو مسجد حرام سے روکا تھا، زیادتی کرنے پر نہ ابھارے اور نیکی اور پرہیزگاری پر ایک دوسرے کی مدد کرو اور گناہ اور زیادتی پر باہم مدد نہ دو اور اللہ سے ڈرتے رہو بیشک اللہ کا عذاب سخت ہے،\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@dclxxii{تم پر حرام ہے مُردار اور خون اور سور کا گوشت اور وہ جس کے ذبح میں غیر خدا کا نام پکارا گیا اور جو گلا گھونٹنے سے مرے اور بے دھار کی چیز سے مارا ہوا اور جو گر کر مرا اور جسے کسی جانور نے سینگ مارا اور جسے کوئی درندہ کھا گیا مگر جنہیں تم ذبح کرلو، اور جو کسی تھان پر ذبح کیا گیا اور پانسے ڈال کر بانٹا کرنا یہ گناہ کا کا م ہے، آج تمہارے دین کی طرف سے کافروں کی آس نوٹ گئی تو اُن سے نہ ڈرو اور مجھ سے ڈرو آج میں نے تمہارے لئے دین کامل کردیا اور تم پر اپنی نعمت پوری کردی اور تمہارے لئے اسلام کو دین پسند کیا تو جو بھوک پیاس کی شدت میں ناچار ہو یوں کہ گناہ کی طرف نہ جھکے تو بیشک اللہ بخشنے والا مہربان ہے،\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@dclxxiii{اے محبوب! تم سے پوچھتے ہیں کہ اُن کے لئے کیا حلال ہوا تم فرمادو کہ حلال کی گئیں تمہارے لئے پاک چیزیں اور جو شکاری جانور تم نے سدھالیے انہیں شکار پر دوڑاتے جو علم تمہیں خدا نے دیا اس سے انہیں سکھاتے تو کھاؤ اس میں سے جو وہ مار کر تمہارے لیے رہنے دیں اور اس پر اللہ کا نام لو اور اللہ سے ڈرتے رہو بیشک اللہ کو حساب کرتے دیر نہیں لگتی،\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@dclxxiv{آج تمہارے لئے پاک چیزیں حلال ہوئیں، اور کتابیوں کا کھانا تمہارے لیے حلال ہوا، اور تمہارا کھانا ان کے لئے حلال ہے، اور پارسا عورتیں مسلمان اور پارسا عورتیں ان میں سے جن کو تم سے پہلے کتاب ملی جب تم انہیں ان کے مہر دو قید میں لاتے ہوئے نہ مستی نکالتے اور نہ ناآشنا بناتے اور جو مسلمان سے کافر ہو اس کا کیا دھرا سب اکارت گیا اور وہ آخرت میں زیاں کار ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@dclxxv{اے ایمان والو جب نماز کو کھڑے ہونا چاہو تو اپنا منہ دھوؤ اور کہنیوں تک ہاتھ اور سروں کا مسح کرو اور گٹوں تک پاؤ ں دھوؤ اور اگر تمہیں نہانے کی حاجت ہو تو خوب ستھرے ہولو اور اگر تم بیمار ہو یا سفر میں ہو یا تم میں سے کوئی قضائے حاجت سے آیا یا تم نے عورتوں سے صحبت کی اور ان صورتوں میں پانی نہ پایا مٹی سے تیمم کرو تو اپنے منہ اور ہاتھوں کا اس سے مسح کرو، اللہ نہیں چاہتا کہ تم پر کچھ تنگی رکھے ہاں یہ چاہتا ہے کہ تمہیں خوب ستھرا کردے اور اپنی نعمت تم پر پوری کردے کہ کہیں تم احسان مانو،\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@dclxxvi{اور یاد کرو اللہ کا احسان اپنے اوپر اور وہ عہد جو اس نے تم سے لیا جبکہ تم نے کہا ہم نے سنا اور مانا اور اللہ سے ڈرو بیشک اللہ دلوں کی بات جانتا ہے،\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@dclxxvii{اے ایمان والوں اللہ کے حکم پر خوب قائم ہوجاؤ انصاف کے ساتھ گواہی دیتے اور تم کو کسی قوم کی عداوت اس پر نہ اُبھارے کہ انصاف نہ کرو، انصاف کرو، وہ پرہیزگاری سے زیادہ قریب ہے، اور اللہ سے ڈرو، بیشک اللہ کو تمہارے کامو ں کی خبر ہے،\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@dclxxviii{ایمان والے نیکو کاروں سے اللہ کا وعدہ ہے کہ ان کے لئے بخشش اور بڑا ثواب ہے،\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@dclxxix{اور وہ جنہوں نے کفر کیا اور ہماری آیتیں جھٹلائیں وحی دوزخ والے ہیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@dclxxx{اے ایمان والو! اللہ کا احسان اپنے اوپر یاد کرو جب ایک قوم نے چاہا کہ تم پر دست درازی کریں تو اس نے ان کے ہاتھ تم پر سے روک دیئے اور اللہ سے ڈرو اور مسلمانوں کو اللہ ہی پر بھروسہ چاہئے،\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@dclxxxi{اور بیشک اللہ نے بنی اسرائیل سے عہد کیا اور ہم نے ان میں بارہ سردار قائم کیے اور اللہ نے فرمایا بیشک میں تمہارے ساتھ ہوں ضرور اگر تم نماز قائم رکھو اور زکوٰة دو اور میرے سوالوں پر ایمان لاؤ اور ان کی تعظیم کرو اور اللہ کو قرض حسن دو بیشک میں تمہارے گناہ اتار دوں گا اور ضرور تمہیں باغوں میں لے جاؤں گا جن کے نیچے نہریں رواں، پھر اس کے بعد جو تم میں سے کفر کرے وہ ضرور سیدھی راہ سے بہکا\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@dclxxxii{تو ان کی کیسی بد عہدیوں پر ہم نے انہیں لعنت کی اور ان کے دل سخت کردیئے اللہ کی باتوں کو ان کے ٹھکانوں سے بدلتے ہیں اور بُھلا بیٹھے بڑا حصہ ان نصیحتوں کا جو انہیں دی گئیں اور تم ہمیشہ ان کی ایک نہ ایک دغا پر مطلع ہوتے رہو گے سوا تھوڑوں کے تو انہیں معاف کردو اور ان سے درگزرو بیشک احسان والے ا لله کو محبوب ہیں،\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@dclxxxiii{اور وہ جنہوں نے دعویٰ کیا کہ ہم نصاریٰ ہیں ہم نے ان سے عہد لیا تو وہ بھلا بیٹھے بڑا حصہ ان نصیحتوں کا جو انہیں دی گئیں تو ہم نے ان کے آپس میں قیامت کے دن تک بَیر اور بغض ڈال دیا اور عنقریب اللہ انہیں بتادے گا جو کچھ کرتے تھے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@dclxxxiv{اے کتاب والو بیشک تمہارے پاس ہمارے یہ رسول تشریف لائے کہ تم پر ظاہر فرماتے ہیں بہت سی وہ چیزیں جو تم نے کتاب میں چھپا ڈالی تھیں اور بہت سی معاف فرماتے ہیں بیشک تمہارے پاس اللہ کی طرف سے ایک نور آیا اور روشن کتاب\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@dclxxxv{اللہ اس سے ہدایت دیتا ہے اسے جو اللہ کی مرضی پر چلا سلامتی کے ساتھ اور انہیں اندھیریوں سے روشنی کی طرف لے جاتا ہے اپنے حکم سے اور انہیں سیدھی راہ دکھاتا ہے،\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@dclxxxvi{بیشک کافر ہوئے وہ جنہوں نے کہا کہ اللہ مسیح بن مریم ہی ہے تم فرما دو پھر اللہ کا کوئی کیا کرسکتا ہے اگر وہ چاہے کہ ہلاک کردے مسیح بن مریم اور اس کی ماں اور تمام زمین والوں کو اور اللہ ہی کے لیے ہے سلطنت آسمانوں اور زمین اور ان کے درمیان کی جو چاہے پیدا کرتا ہے، اور اللہ سب کچھ کرسکتا ہے،\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@dclxxxvii{اور یہودی اور نصرانی بولے کہ ہم اللہ کے بیٹے اور اس کے پیارے ہیں تم فرما دو پھر تمہیں کیوں تمہارے گناہوں پر عذاب فرماتا ہے بلکہ تم آدمی ہو اس کی مخلوقات سے جسے چاہے بخشتا ہے اور جسے چاہے سزا دیتا ہے، اور اللہ ہی کے لئے ہے سلطنت آسمانوں اور زمین اور اس کے درمیان کی، اور اسی کی طرف پھرنا ہے،\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@dclxxxviii{اے کتاب والو! بیشک تمہارے پاس ہمارے یہ رسول تشریف لائے کہ تم پر ہمارے احکام ظاہر فرماتے ہیں بعد اس کے کہ رسولوں کا آنا مدتوں بند رہا تھا کہ کبھی کہو کہ ہمارے پاس کوئی خوشی اور ڈر سنانے والا نہ آیا تو یہ خوشی اور ڈر سنانے والے تمہارے پاس تشریف لائے ہیں، اور اللہ کو سب قدرت ہے،\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@dclxxxix{اور جب موسیٰ نے کہا اپنی قوم سے اے میری قوم اللہ کا احسان اپنے اوپر یاد کرو کہ تم میں سے پیغمبر کیے اور تمہیں بادشاہ کیا اور تمہیں وہ دیا جو آج سارے جہان میں کسی کو نہ دیا\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@dcxc{اے قوم اس پاک زمین میں داخل ہو جو اللہ نے تمہارے لیے لکھی ہے اور پیچھے نہ پلٹو کہ نقصان پر پلٹو گے،\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@dcxci{بولے اے موسیٰ اس میں تو بڑے زبردست لوگ ہیں، اور ہم اس میں ہرگز داخل نہ ہوں گے جب تک وہ وہاں سے نکل نہ جائیں ہاں وہ وہاں سے نکل جائیں تو ہم وہاں جائیں،\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@dcxcii{دو مرد کہ اللہ سے ڈرنے والوں میں سے تھے ا لله نے انہیں نوازا بولے کہ زبردستی دروازے میں ان پر داخل ہو اگر تم دروازے میں داخل ہوگئے تو تمہارا ہی غلبہ ہے اور اللہ ہی پر بھروسہ کرو اگر تمہیں ایمان ہے،\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@dcxciii{بولے اے موسیٰ ہم تو وہاں کبھی نہ جائیں گے جب تک وہ وہاں ہیں تو آپ جائیے اور آپ کا رب تم دونوں لڑو ہم یہاں بیٹھے ہیں،\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@dcxciv{موسیٰ نے عرض کی کہ اے رب! میرے مجھے اختیار نہیں مگر اپنا اور اپنے بھائی کا تو تو ہم کو ان بے حکموں سے جدا رکھ\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@dcxcv{فرمایا تو وہ زمین ان پر حرام ہے چالیس برس تک بھٹکتے پھریں زمین میں تو تم ان بے حکموں کا افسوس نہ کھاؤ،\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@dcxcvi{اور انہیں پڑھ کر سناؤ آدم کے دو بیٹوں کی سچی خبر جب دونوں نے ایک ایک نیاز پیش کی تو ایک کی قبول ہوئی اور دوسرے کی نہ قبول ہوئی بولا قسم ہے میں تجھے قتل کردوں گا کہا اللہ اسی سے قبول کرتا ہے، سے ڈر ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@dcxcvii{بیشک اگر تو اپنا ہاتھ مجھ پر بڑھائے گا کہ مجھے قتل کرے تو میں اپنا ہاتھ تجھ پر نہ بڑھاؤں گا کہ تجھے قتل کروں میں اللہ سے ڈرتا ہوں جو مالک ہے سارے جہاں کا،\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@dcxcviii{میں تو یہ چاہتا ہوں کہ میرا اور تیرا گناہ دونوں تیرے ہی پلہ پڑے تو تو دوز خی ہوجائے، اور بے انصافوں کی یہی سزا ہے،\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@dcxcix{تو اسکے نفس نے اسے بھائی کے قتل کا چاؤ دلایا تو اسے قتل کردیا تو رہ گیا نقصان میں\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@dcc{تو اللہ نے ایک کوا بھیجا زمین کریدتا کہ اسے دکھائے کیونکر اپنے بھائی کی لاش چھپائے بولا ہائے خرابی میں اس کوے جیسا بھی نہ ہوسکا کہ میں اپنے بھائی کی لاش چھپاتا تو پچتاتا رہ گیا\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@dcci{اس سبب سے ہم نے بنی اسرائیل پر لکھ دیا کہ جس نے کوئی جان قتل کی بغیر جان کے بدلے یا زمین میں فساد کیے تو گویا اس نے سب لوگوں کو قتل کیا اور جس نے ایک جان کو جِلا لیا اس نے گویا سب لوگوں کو جلالیا، اور بیشک ان کے پاس ہمارے رسول روشن دلیلوں کے ساتھ آئے پھر بیشک ان میں بہت اس کے بعد زمین میں زیادتی کرنے والے ہیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@dccii{وہ کہ اللہ اور اس کے رسول سے لڑتے اور ملک میں فساد کرتے پھرتے ہیں ان کا بدلہ یہی ہے کہ گن گن کر قتل کیے جائیں یا سولی دیے جائیں یا ان کے ایک طرف کے ہاتھ اور دوسری طرف کے پاؤں کاٹے جائیں یا زمین سے دور کردیے جائیں، یہ دنیا میں ان کی رسوائی ہے، اور آخرت میں ان کے لیے بڑا غداب،\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@dcciii{مگر وہ جنہوں نے توبہ کرلی اس سے پہلے کہ تم ان پر قابو پاؤ تو جان لو کہ اللہ بخشنے والا مہربان ہے،\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@dcciv{اے ایمان والو! اللہ سے ڈرو اور اس کی طرف وسیلہ ڈھونڈو اور اس کی راہ میں جہاد کرو اس امید پر کہ فلاح پاؤ،\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@dccv{بیشک وہ جو کافر ہوئے جو کچھ زمین میں ہے سب اور اس کی برابر اور اگر ان کی ملک ہو کہ اسے دے کر قیامت کے عذاب سے اپنی جان چھڑائیں تو ان سے نہ لیا جائے گا اور ان کے لئے دکھ کا عذاب ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@dccvi{دوزخ سے نکلنا چاہیں گے اور وہ اس سے نہ نکلیں گے اور ان کو دوامی سزا ہے،\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@dccvii{اور جو مرد یا عورت چور ہو تو ان کا ہاتھ کاٹو ان کے کیے کا بدلہ اللہ کی طرف سے سزا، اور اللہ غالب حکمت والا ہے،\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@dccviii{تو جو اپنے ظلم کے بعد توبہ کرے اور سنور جائے تو اللہ اپنی مہر سے اس پر رجوع فرمائے گا بیشک اللہ بخشنے والا مہربان ہے،\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@dccix{کیا تجھے معلوم نہیں کہ اللہ کے لئے ہے آسمانوں اور زمین کی بادشاہی، سزا دیتا ہے جسے چاہے اور بخشتا ہے جسے چاہے، اور اللہ سب کچھ کرسکتا ہے،\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@dccx{اے رسول! تمہیں غمگین نہ کریں وہ جو کفر پڑ دوڑتے ہیں جو کچھ وہ اپنے منہ سے کہتے ہیں ہم ایمان لائے اور ان کے دل مسلمان نہیں اور کچھ یہودی جھوٹ خوب سنتے ہیں اور لوگوں کی خوب سنتے ہیں جو تمہارے پاس حاضر نہ ہوئے اللہ کی باتوں کو ان کے ٹھکانوں کے بعد بدل دیتے ہیں، کہتے ہیں یہ حکم تمہیں ملے تو مانو اور یہ نہ ملے تو بچو اور جسے اللہ گمراہ کرنا چاہے تو ہرگز تو اللہ سے اس کا کچھ بنا نہ سکے گا، وہ ہیں کہ اللہ نے ان کا دل پاک کرنا نہ چاہا، انہیں دنیا میں رسوائی ہے، اور انہیں آخرت میں بڑا عذاب،\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@dccxi{بڑے جھوٹ سننے والے بڑے حرام خور تو اگر تمہارے حضور حاضر ہوں تو ان میں فیصلہ فرماؤ یا ان سے منہ پھیرلو اور اگر تم ان سے منہ پھیرلو گے تو وہ تمہارا کچھ نہ بگاڑیں گے اور اگر ان میں فیصلہ فرماؤ تو انصاف سے فیصلہ کرو، بیشک انصاف والے اللہ کو پسند ہیں،\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@dccxii{اور وہ تم سے کیونکر فیصلہ چاہیں گے، حالانکہ ان کے پاس توریت ہے جس میں اللہ کا حکم موجود ہے بایں ہمہ اسی سے منہ پھیرتے ہیں اور وہ ایمان لانے والے نہیں،\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@dccxiii{بیشک ہم نے توریت اتاری اس میں ہدایت اور نور ہے، اس کے مطابق یہود کو حکم دیتے تھے ہمارے فرمانبردار نبی اور عالم اور فقیہہ کہ ان سے کتاب اللہ کی حفاظت چاہی گئی تھی اور وہ اس پر گواہ تھے تو لوگوں سے خوف نہ کرو اور مجھ سے ڈرو اور میری آیتوں کے بدلے ذلیل قیمت نہ لو اور جو اللہ کے اتارے پر حکم نہ کرے وہی لوگ کافر ہیں،\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@dccxiv{اور ہم نے توریت میں ان پر واجب کیا کہ جان کے بدلے جان اور آنکھ کے بدلے آنکھ اور ناک کے بدلے ناک اور کان کے بدلے کان اور دانت کے بدلے دانت اور زخموں میں بدلہ ہے پھر جو دل کی خوشی سے بدلہ کراوے تو وہ اس کا گناہ اتار دے گا اور جو اللہ کے اتارے پر حکم نہ کرے تو وہی لوگ ظالم ہیں،\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@dccxv{اور ہم ان نبیوں کے پیچھے ان کے نشانِ قدم پر عیسیٰ بن مریم کو لائے تصدیق کرتا ہوا توریت کی جو اس سے پہلے تھی اور ہم نے اسے انجیل عطا کی جس میں ہدایت اور نور ہے اور تصدیق فرماتی ہے توریت کی کہ اس سے پہلی تھی اور ہدایت اور نصیحت پرہیزگاروں کو،\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@dccxvi{اور چاہئے کہ انجیل والے حکم کریں اس پر جو اللہ نے اس میں اتارا اور جو اللہ کے اتارے پر حکم نہ کریں تو وہی لوگ فاسق ہیں،\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@dccxvii{اور اے محبوب ہم نے تمہاری طرف سچی کتاب اتاری اگلی کتابوں کی تصدیق فرماتی اور ان پر محافظ و گواہ تو ان میں فیصلہ کرو اللہ کے اتارے سے اور اسے سننے والے ان کی خواہشوں کی پیروی نہ کرنا اپنے پاس آیا ہوا حق چھوڑ کر، ہم نے تم سب کے لیے ایک ایک شریعت اور راستہ رکھا اور اللہ چاہتا تو تم سب کو ایک ہی امت کردیتا مگر منظور یہ ہے کہ جو کچھ تمہیں دیا اس میں تمہیں آزمائے تو بھلائیوں کی طرف سبقت چاہو، تم سب کا پھرنا اللہ ہی کی طرف ہے تو وہ تمہیں بتادے گا جس بات میں تم جھگڑتے تھے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@dccxviii{اور یہ کہ اے مسلمان! اللہ کے اتارے پر حکم کر اور ان کی خواہشوں پر نہ چل اور ان سے بچتا رہ کہ کہیں تجھے لغزش نہ دے دیں کسی حکم میں جو تیری طرف اترا پھر اگر وہ منہ پھیریں تو جان لو کہ اللہ ان کے بعض گناہوں کی سزا ان کو پہنچایا چاہتا ہے اور بیشک بہت آدمی بے حکم ہیں،\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@dccxix{تو کیا جاہلیت کا حکم چاہتے ہیں اور اللہ سے بہتر کس کا حکم یقین والوں کے لیے،\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@dccxx{اے ایمان والو! یہود و نصاریٰ کو دوست نہ بناؤ وہ آپس میں ایک دوسرے کے دوست ہیں اور تم میں جو کوئی ان سے دوستی رکھے گا تو وہ انہیں میں سے ہے بیشک اللہ بے انصافوں کو راہ نہیں دیتا\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@dccxxi{اب تم انہیں دیکھو گے جن کے دلوں میں آزار ہے کہ یہود و نصاریٰ کی طرف دوڑتے ہیں کہتے ہیں ہم ڈرتے ہیں کہ ہم پر کوئی گردش آجائے تو نزدیک ہے کہ اللہ فتح لائے یا اپنی طرف سے کوئی حکم پھر اس پر جو اپنے دلوں میں چھپایا تھا پچھتائے رہ جائیں\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@dccxxii{اور ایمان والے کہتے ہیں کیا یہی ہیں جنہوں نے اللہ کی قسم کھائی تھی اپنے حلف میں پوری کوشش سے کہ وہ تمہارے ساتھ ہیں ان کا کیا دھرا سب اکارت گیا تو رہ گئے نقصان میں\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@dccxxiii{اے ایمان والو! تم میں جو کوئی اپنے دین سے پھرے گا تو عنقریب اللہ ایسے لوگ لائے گا کہ وہ اللہ کے پیارے اور اللہ ان کا پیارا مسلمانوں پر نرم اور کافروں پر سخت اللہ کی راہ میں لڑیں گے اور کسی ملامت کرنے والے کی ملامت کا اندیشہ نہ کریں گے یہ اللہ کا فضل ہے جسے چاہے دے، اور اللہ وسعت والا علم والا ہے،\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@dccxxiv{تمہارے دوست نہیں مگر اللہ اور اس کا رسول اور ایمان والے کہ نماز قائم کرتے ہیں اور زکوٰة دیتے ہیں اور اللہ کے حضور جھکے ہوئے ہیں\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@dccxxv{اور جو اللہ اور اس کے رسول اور مسلمانوں کو اپنا دوست بنائے تو بیشک اللہ ہی کا گروہ غالب ہے،\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@dccxxvi{اے ایمان والو! جنہوں نے تمہارے دین کو ہنسی کھیل بنالیا ہے وہ جو تم سے پہلے کتاب دیے گئے اور کافر ان میں کسی کو اپنا دوست نہ بناؤ اور اللہ سے ڈرتے رہو اگر ایمان رکھتے ہو\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@dccxxvii{اور جب تم نماز کے لئے اذان دو تو اسے ہنسی کھیل بناتے ہیں یہ اس لئے کہ وہ نرے بے عقل لوگ ہیں\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@dccxxviii{تم فرماؤ اے کتابیوں تمہیں ہمارا کیا برا لگا یہی نہ کہ ہم ایمان لائے اللہ پر اور اس پر جو ہماری طرف اترا اور اس پر جو پہلے اترا اور یہ کہ تم میں اکثر بے حکم ہیں،\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@dccxxix{تم فرماؤ کیا میں بتادوں جو اللہ کے یہاں اس سے بدتر درجہ میں ہیں وہ جن پر اللہ نے لعنت کی اور ان پر غضب فرمایا اور ان میں سے کردیے بندر اور سور اور شیطان کے پجاری ان کا ٹھکانا زیادہ برا ہے اور یہ سیدھی راہ سے زیادہ بہکے،\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@dccxxx{اور جب تمہارے پاس آئیں ہم مسلمان ہیں اور وہ آتے وقت بھی کافر تھے اور جاتے وقت بھی کافر، اور اللہ خوب جانتا ہے جو چھپا رہے ہیں\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@dccxxxi{اور ان میں تم بہتوں کو دیکھو گے کہ گناہ اور زیادتی اور حرام خوری پر دوڑتے ہیں بیشک بہت ہی برے کام کرتے ہیں،\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@dccxxxii{انہیں کیوں نہیں منع کرتے ان کے پادری اور درویش گناہ کی بات کہنے اور حرام کھانے سے، بیشک بہت ہی برے کام کررہے ہیں\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@dccxxxiii{اور یہودی بولے اللہ کا ہاتھ بندھا ہوا ہے ان کے ہاتھ باندھے جائیں اور ان پر اس کہنے سے لعنت ہے بلکہ اس کے ہاتھ کشادہ ہیں عطا فرماتا ہے جیسے چاہے اور اے محبوب! یہ جو تمہاری طرف تمہارے رب کے پاس سے اترا اس سے ان میں بہتوں کو شرارت اور کفر میں ترقی ہوگی اور ان میں ہم نے قیامت تک آپس میں دشمنی اور بیر ڈال دیا جب کبھی لڑائی کی آگ بھڑکاتے ہیں اللہ اسے بجھا دیتا ہے اور زمین میں فساد کے لیے دوڑتے پھرتے ہیں، اور اللہ فسادیوں کو نہیں چاہتا،\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@dccxxxiv{اور اگر کتاب والے ایمان لاتے اور پرہیزگاری کرتے تو ضرور ہم ان کے گناہ اتار دیتے اور ضرور انہیں چین کے باغوں میں لے جاتے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@dccxxxv{اور اگر وہ قائم رکھتے توریت اور انجیل اور جو کچھ ان کی طرف ان کے رب کی طرف سے اترا تو انہیں رزق ملتا اوپر سے اور ان کے پاؤں کے نیچے سے ان میں کوئی گروہ اگر اعتدال پر ہے اور ان میں اکثر بہت ہی برے کام کررہے ہیں\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@dccxxxvi{اے رسول پہنچا دو جو کچھ اترا تمہیں تمہارے رب کی طرف سے اور ایسا نہ ہو تو تم نے اس کا کوئی پیام نہ پہنچایا اور اللہ تمہاری نگہبانی کرے گا لوگوں سے بیشک اللہ کافروں کو راہ نہیں دیتا،\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@dccxxxvii{تم فرمادو، اے کتابیو! تم کچھ بھی نہیں ہو جب تک نہ قائم کرو توریت اور انجیل اور جو کچھ تمہاری طرف تمہارے رب کے پاس سے اترا اور بیشک اے محبوب! وہ جو تمہاری طرف تمہارے رب کے پاس سے اترا اس میں بہتوں کو شرارت اور کفر کی اور ترقی ہوگی تو تم کافروں کا کچھ غم نہ کھاؤ،\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@dccxxxviii{بیشک وہ جو اپنے آپ کو مسلمان کہتے ہیں اور اسی طرح یہودی اور ستارہ پرت اور نصرانی ان میں جو کوئی سچے دل سے اللہ اور قیامت پر ایمان لائے اور اچھے کام کرے توان پر نہ کچھ اندیشہ ہے اور نہ کچھ غم،\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@dccxxxix{بیشک ہم نے بنی اسرائیل سے عہد لیا اور ان کی طرف رسول بھیجے، جب کبھی ان کے پاس کوئی رسول وہ بات لے کر آیا جو ان کے نفس کی خواہش نہ تھی ایک گروہ کو جھٹلایا اور ایک گروہ کو شہید کرتے ہیں\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@dccxl{اور اس گمان میں ہیں کہ کوئی سزا نہ ہوگی تو اندھے اور بہرے ہوگئے پھر اللہ نے ان کی توبہ قبول کی پھر ان میں بہتیرے اندھے اور بہرے ہوگئے اور اللہ ان کے کام دیکھ رہا ہے،\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@dccxli{بیشک کافر ہیں وہ جو کہتے ہیں کہ اللہ وہی مسیح مریم کا بیٹا ہے اور مسیح نے تو یہ کہا تھا، اے بنی اسرائیل اللہ کی بندگی کرو جو میرا رب اور تمہارا رب، بیشک جو اللہ کا شریک ٹھہرائے تو اللہ نے اس پر جنت حرام کردی اور اس کا ٹھکانا دوزخ ہے اور ظالموں کا کوئی مددگار نہیں،\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@dccxlii{بیشک کافر ہیں وہ جو کہتے ہیں اللہ تین خداؤں میں کا تیسرا ہے اور خدا تو نہیں مگر ایک خدا اور اگر اپنی بات سے باز نہ آئے تو جو ان میں کافر مریں گے ان کو ضرور دردناک عذاب پہنچے گا،\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@dccxliii{تو کیوں نہیں رجوع کرتے اللہ کی طرف اور اس سے بخشش مانگتے، اور اللہ بخشنے والا مہربان،\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@dccxliv{مسیح بن مریم نہیں مگر ایک رسول اس سے پہلے بہت رسول ہو گزرے اور اس کی ماں صدیقہ ہے دونوں کھانا کھاتے تھے دیکھو تو ہم کیسی صاف نشانیاں ان کے لئے بیان کرتے ہیں پھر دیکھو وہ کیسے اوندھے جاتے ہیں،\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@dccxlv{تم فرماؤ کیا اللہ کے سوا ایسے کو پوجتے ہو جو تمہارے نقصان کا مالک نہ نفع کا اور اللہ ہی سنتا جانتا ہے،\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@dccxlvi{تم فرماؤ اے کتاب والو! اپنے دین میں ناحق زیادتی نہ کرو اور ایسے لوگوں کی خواہش پر نہ چلو جو پہلے گمراہ ہوچکے اور بہتوں کو گمراہ کیا اور سیدھی راہ سے بہک گئے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@dccxlvii{لعنت کیے گئے وہ جنہوں نے کفر کیا بنی اسرائیل میں داؤد اور عیسیٰ بن مریم کی زبان پر یہ بدلہ ان کی نافرمانی اور سرکشی کا،\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@dccxlviii{جو بری بات کرتے آپس میں ایک دوسرے کو نہ روکتے ضرور بہت ہی برے کام کرتے تھے\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@dccxlix{ان میں تم بہت کو دیکھو گے کہ کافروں سے دوستی کرتے ہیں، کیا ہی بری چیز اپنے لیے خود آگے بھیجی یہ کہ اللہ کا ان پر غضب ہوا اور وہ عذاب میں ہمیشہ رہیں گے\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@dccl{اور اگر وہ ایمان لاتے اللہ اور ان نبی پر اور اس پر جو ان کی طرف اترا تو کافروں سے دوستی نہ کرتے مگر ان میں تو بہتیرے فاسق ہیں،\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@dccli{ضرور تم مسلمانوں کا سب سے بڑھ کر دشمن یہودیوں اور مشرکوں کو پاؤ گے اور ضرور تم مسلمانوں کی دوستی میں سب سے زیادہ قریب ان کو پاؤ گے جو کہتے تھے ہم نصاریٰ ہیں یہ اس لئے کہ ان میں عالم اور درویش ہیں اور یہ غرور نہیں کرتے -\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@dcclii{اور جب سنتے ہیں وہ جو رسول کی طرف اترا تو ان کی آنکھیں دیکھو کہ آنسوؤں سے ابل رہی ہیں اس لیے کہ وہ حق کو پہچان گئے، کہتے ہیں اے رب ہمارے! ہم ایمان لائے تو ہمیں حق کے گواہوں میں لکھ لے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@dccliii{اور ہمیں کیا ہوا کہ ہم ایمان نہ لائیں اللہ پر اور اس حق پر کہ ہمارے پاس آیا اور ہم طمع کرتے ہیں کہ ہمیں ہمارا رب نیک لوگوں کے ساتھ داخل کرے\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@dccliv{تو اللہ نے ان کے اس کہنے کے بدلے انہیں باغ دیے جن کے نیچے نہریں رواں ہمیشہ ان میں رہیں گے، یہ بدلہ ہے نیکوں کا\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@dcclv{اور وہ جنہوں کفر کیا اور ہماری آیتیں جھٹلائیں وہ ہیں دوزخ والے،\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@dcclvi{اے ایمان والو! حرام نہ ٹھہراؤ وہ ستھری چیزیں کہ اللہ نے تمہارے لیے حلال کیں اور حد سے نہ بڑھو، بیشک حد سے بڑھنے والے اللہ کو ناپسند ہیں،\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@dcclvii{اور کھاؤ جو کچھ تمہیں اللہ نے روزی دی حلال پاکیزہ او ر ڈرو اللہ سے جس پر تمہیں ایمان ہے،\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@dcclviii{اللہ تمہیں نہیں پکڑتا تمہاری غلط فہمی کی قسموں پر ہاں ان قسموں پر گرفت فرماتے ہے جنہیں تم نے مضبوط کیا تو ایسی قسم کا بدلہ دس مسکینوں کو کھانا دینا اپنے گھر والوں کو جو کھلاتے ہو اس کے اوسط میں سے یا انہیں کپڑے دینا یا ایک بردہ آزاد کرنا تو جو ان میں سے کچھ نہ پائے تو تین دن کے روزے یہ بدلہ ہے تمہاری قسموں کا، جب قسم کھاؤ اور اپنی قسموں کی حفاظت کرو اسی طرح اللہ تم سے اپنی آیتیں بیان فرماتا ہے کہ کہیں تم احسان مانو،\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@dcclix{اے ایمان والو! شراب اور جوا اور بت اور پانسے ناپاک ہی ہیں شیطانی کام تو ان سے بچتے رہنا کہ تم فلاح پاؤ،\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@dcclx{شیطان یہی چاہتا ہے کہ تم میں بَیر اور دشمنی ڈلوا دے شراب اور جوئے میں اور تمہیں اللہ کی یاد اور نماز سے روکے تو کیا تم باز آئے،\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@dcclxi{اور حکم مانو اللہ کا اور حکم مانو رسول کا اور ہوشیار رہو، پھر اگر تم پھر جاؤ تو جان لو کہ ہمارے رسول کا ذمہ صرف واضح طور پر حکم پہنچادینا ہے\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@dcclxii{جو ایمان لائے اور نیک کام کیے ان پر کچھ گناہ نہیں جو کچھ انہوں نے چکھا جب کہ ڈریں اور ایمان رکھیں اور نیکیاں کریں پھر ڈریں اور ایمان رکھیں پھر ڈریں اور نیک رہیں، اور اللہ نیکوں کو دوست رکھتا ہے\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@dcclxiii{اے ایمان والوں ضرور اللہ تمہیں آزمائے گا ایسے بعض شکار سے جس تک تمہارا ہاتھ اور نیزے پہنچیں کہ اللہ پہچان کرادے ان کی جو اس سے بن دیکھے ڈرتے ہیں، پھر اس کے بعد جو حد سے بڑھے اس کے لئے دردناک عذاب ہے،\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@dcclxiv{اے ایمان والو! شکار نہ مارو جب تم احرام میں ہو اور تم میں جو اسے قصداً قتل کرے تو اس کا بدلہ یہ ہے کہ ویسا ہی جانور مویشی سے دے تم میں کہ دو ثقہ آدمی اس کا حکم کریں یہ قربانی ہو کہ کعبہ کو پہنچتی یا کفار ہ دے چند مسکینوں کا کھانا یا اس کے برابر روزے کہ اپنے کام کا وبال چکھے اللہ نے معاف کیا جو ہو گزرا اور جو اب کرے گا اس سے بدلہ لے گا، اور اللہ غالب ہے بدلہ لینے والا،\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@dcclxv{حلال ہے تمہارے لیے دریا کا شکار اور اس کا کھانا تمہارے اور مسافروں کے فائدے کو اور تم پرحرام ہے خشکی کا شکار جب تک تم احرام میں ہو اور اللہ سے ڈرو جس کی طرف تمہیں اٹھنا ہے،\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@dcclxvi{اللہ نے ادب والے گھر کعبہ کو لوگوں کے قیام کا باعث کیا اور حرمت والے مہینہ اور حرم کی قربانی اور گلے میں علامت آویزاں جانوروں کو یہ اس لیے کہ تم یقین کرو کہ اللہ جانتا ہے جو کچھ آسمانوں میں ہے اور جو کچھ زمین میں اور یہ کہ اللہ سب کچھ جانتا ہے،\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@dcclxvii{جان رکھو کہ اللہ کا عذاب سخت ہے اور اللہ بخشنے والا مہربان،\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@dcclxviii{رسول پر نہیں مگر حکم پہنچانا اور اللہ جانتا ہے جو تم ظاہر کرتے اور جو تم چھپاتے ہو\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@dcclxix{تم فرمادو کہ گندہ اور ستھرا برابر نہیں اگرچہ تجھے گندے کی کثرت بھائے، تو اللہ سے ڈرتے رہو اے عقل والو! کہ تم فلاح پاؤ،\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@dcclxx{اے ایمان والو! ایسی باتیں نہ پوچھو جو تم پر ظاہر کی جائیں تو تمہیں بری لگیں اور اگر انہیں اس وقت پوچھو گے کہ قرآن اتر رہا ہے تو تم پر ظاہر کردی جائیں گی، اللہ انہیں معاف کرچکا ہے اور اللہ بخشنے والا حلم والا ہے،\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@dcclxxi{تم سے اگلی ایک قوم نے انہیں پوچھا پھر ان سے منکر ہو بیٹھے،\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@dcclxxii{اللہ نے مقرر نہیں کیا ہے کان چِرا ہوا اور نہ بجار اور نہ وصیلہ اور نہ حامی ہاں کافر لوگ اللہ پر جھوٹا افترا باندھتے ہیں اور ان میں اکثر نرے بے عقل ہیں\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@dcclxxiii{اور جب ان سے کہا جائے آؤ اس طرف جو اللہ نے اُتارا اور رسول کی طرف کہیں ہمیں وہ بہت ہے جس پر ہم نے اپنے باپ دادا کو پایا، کیا اگرچہ ان کے باپ دادا نہ کچھ جانیں نہ راہ پر ہوں\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@dcclxxiv{اے ایمان والو! تم اپنی فکر رکھو تمہارا کچھ نہ بگاڑے گا جو گمراہ ہوا جب کہ تم راہ پر ہو تم سب کی رجوع اللہ ہی کی طرف ہے پھر وہ تمہیں بتا دے گا جو تم کرتے تھے،\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@dcclxxv{اے ایمان والوں تمہاری آپس کی گواہی جب تم میں کسی کو موت آئے وصیت کرتے وقت تم میں کے دو معتبر شخص ہیں یا غیروں میں کے دو جب تم ملک میں سفر کو جاؤ پھر تمہیں موت کا حادثہ پہنچے، ان دونوں کو نماز کے بعد روکو وہ اللہ کی قسم کھائیں اگر تمہیں کچھ شک پڑے ہم حلف کے بدلے کچھ مال نہ خریدیں گے اگرچہ قریب کا رشتہ دار ہو اور اللہ کی گواہی نہ چھپائیں گے ایسا کریں تو ہم ضرور گنہگاروں میں ہیں،\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@dcclxxvi{پھر اگر پتہ چلے کہ وہ کسی گناہ کے سزاوار ہوئے تو ان کی جگہ دو اور کھڑے ہوں ان میں سے کہ اس گناہ یعنی جھوٹی گواہی نے ان کا حق لے کر ان کو نقصان پہنچایا جو میت سے زیادہ قریب ہوں تو اللہ کی قسم کھائیں کہ ہماری گواہی زیادہ ٹھیک ہے ان دو کی گواہی سے اور ہم حد سے نہ بڑھے ایسا ہو تو ہم ظالموں میں ہوں،\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@dcclxxvii{یہ قریب تر ہے اس سے کہ گواہی جیسی چاہیے ادا کریں یا ڈریں کہ کچھ قسمیں رد کردی جائیں ان کی قسموں کے بعد اور اللہ سے ڈرو اور حکم سنو، اور اللہ بے حکموں کو راہ نہیں دیتا،\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@dcclxxviii{جس دن اللہ جمع فرمائے گا رسولوں کو پھر فرمائے گا تمہیں کیا جواب ملا عرض کریں گے ہمیں کچھ علم نہیں، بیشک تو ہی ہے سب غیبوں کا جاننے والا\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@dcclxxix{جب اللہ فرمائے گا اے مریم کے بیٹے عیسیٰ! یاد کر میرا احسان اپنے اوپر اور اپنی ماں پر جب میں نے پاک روح سے تیری مدد کی تو لوگوں سے باتیں کرتا پالنے میں اور پکی عمر ہوکر اور جب میں نے تجھے سکھائی کتاب اور حکمت اور توریت اور انجیل اور جب تو مٹی سے پرند کی سی مورت میرے حکم سے بناتا پھر اس میں پھونک مارتا تو وہ میرے حکم سے اڑنے لگتی اور تو مادر زاد اندھے اور سفید داغ والے کو میرے حکم سے شفا دیتا اور جب تو مُردوں کو میرے حکم سے زندہ نکالتا اور جب میں نے بنی اسرائیل کو تجھ سے روکا جب تو ان کے پاس روشن نشانیاں لے کر آیا تو ان میں کے کافر بولے کہ یہ تو نہیں مگر کھلا جادو،\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@dcclxxx{اور جب میں نے حواریوں کے دل میں ڈالا کہ مجھ پر اور میرے رسول پر ایمان لاؤ بولے ہم ایمان لائے اور گواہ رہ کہ ہم مسلمان ہیں\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@dcclxxxi{جب حواریوں نے کہا اے عیسیٰ بن مریم! کیا آپ کا رب ایسا کرے گا کہ ہم پر آسمان سے ایک خوان اُتارے کہا اللہ سے ڈرو! اگر ایمان رکھتے ہو\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@dcclxxxii{بولے ہم چاہتے ہیں کہ اس میں سے کھائیں اور ہمارے دل ٹھہریں اور ہم آنکھوں دیکھ لیں کہ آپ نے ہم سے سچ فرمایا اور ہم اس پر گواہ ہوجائیں\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@dcclxxxiii{عیسیٰ بن مریم نے عرض کی، اے اللہ! اے رب ہمارے! ہم پر آسمان سے ایک خوان اُتار کہ وہ ہمارے لیے عید ہو ہمارے اگلے پچھلوں کی اور تیری طرف سے نشانی اور ہمیں رزق دے اور تو سب سے بہتر روزی دینے والا ہے،\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@dcclxxxiv{اللہ نے فرمایا کہ میں اسے تم پر اُتارتا ہوں، پھر اب جو تم میں کفر کرے گا تو بیشک میں اسے وہ عذاب دوں گا کہ سارے جہان میں کسی پر نہ کروں گا\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@dcclxxxv{اور جب اللہ فرمائے گا اے مریم کے بیٹے عیسیٰ! کیا تو نے لوگوں سے کہہ دیا تھا کہ مجھے اور میری ماں کو دو خدا بنالو اللہ کے سوا عرض کرے گا، پاکی ہے تجھے مجھے روا نہیں کہ وہ بات کہوں جو مجھے نہیں پہنچتی اگر میں نے ایسا کہا ہو تو ضرور تجھے معلوم ہوگا تو جانتا ہے جو میرے جی میں ہے اور میں نہیں جانتا جو تیرے علم میں ہے، بیشک تو ہی ہے سب غیبوں کا خوب جاننے والا\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@dcclxxxvi{میں نے تو ان سے نہ کہا مگر وہی جو تو نے مجھے حکم دیا تھا کہ ا لله کو پوجو جو میرا بھی رب اور تمھا ر ا بھی رب اور میں ان پر مطلع تھا جب تک ان میں رہا، پھر جب تو نے مجھے اٹھالیا تو تُو ہی ان پر نگاہ رکھتا تھا، اور ہر چیز تیرے سامنے حاضر ہے\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@dcclxxxvii{اگر تو انہیں عذاب کرے تو وہ تیرے بندے ہیں، اور اگر تو انہیں بخش دے تو بیشک تو ہی ہے غالب حکمت والا\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@dcclxxxviii{اللہ نے فرمایا کہ یہ ہے وہ دن جس میں سچوں کو ان کا سچ کام آئے گا، ان کے لئے باغ ہیں جن کے نیچے نہریں رواں ہمیشہ ہمیشہ رہیں گے، اللہ ان سے راضی اور وہ اللہ سے راضی، یہ ہے بڑی کامیابی،\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@dcclxxxix{اللہ ہی کے لئے ہے آسمانوں اور زمین اور جو کچھ ان میں ہے سب کی سلطنت، اور وہ ہر چیز پر قادر ہے\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@dccxc{\basmalahur سب خوبیاں اللہ کو جس نے آسمان اور زمین بنائے اور اندھیریاں اور روشنی پیدا کی اس پر کافر لوگ اپنے رب کے برابر ٹھہراتے ہیں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@dccxci{وہی ہے جس نے تمہیں مٹی سے پیدا کیا پھر ایک میعاد کا حکم رکھا اور ایک مقررہ وعدہ اس کے یہاں ہے پھر تم لوگ شک کرتے ہو،\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@dccxcii{اور وہی اللہ ہے آسمانوں اور زمین کا اسے تمہارا چھپا اور ظاہر سب معلوم ہے اور تمہارے کام جانتا ہے،\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@dccxciii{اور ان کے پاس کوئی بھی نشانی اپنے رب کی نشانیوں سے نہیں آتی مگر اس سے منہ پھیرلیتے ہیں،\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@dccxciv{تو بیشک انہوں نے حق کو جھٹلایا جب ان کے پاس آیا، تو اب انہیں خبر ہوا چاہتی ہے اس چیز کی جس پر ہنس رہے تھے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@dccxcv{کیا انہوں نے نہ د یکھا کہ ہم نے ان سے پہلے کتنی سنگتیں کھپا دیں انہیں ہم نے زمین میں وہ جماؤ دیا جو تم کو نہ دیا اور ان پر موسلا دھار پانی بھیجا اور ان کے نیچے نہریں بہائیں تو انہیں ہم نے ان کے گناہوں کے سبب ہلاک کیا اور ان کے بعد اور سنگت اٹھائی\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@dccxcvi{اور اگر ہم تم پر کاغذ میں کچھ لکھا ہوا اتارتے کہ وہ اسے اپنے ہاتھوں سے چھوتے جب بھی کافر کہتے کہ یہ نہیں مگر کھلا جادو،\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@dccxcvii{اور بولے ان پر کوئی فرشتہ کیوں نہ اتارا گیا، اور اگر ہم فرشتہ اتارتے تو کام تمام ہوگیا ہوتا پھر انہیں مہلت نہ دی جاتی\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@dccxcviii{اور اگر ہم نبی کو فرشتہ کرتے جب بھی اسے مرد ہی بناتے اور ان پر وہی شبہ رکھتے جس میں اب پڑے ہیں،\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@dccxcix{اور ضرور اے محبوب تم سے پہلے رسولوں کے ساتھ بھی ٹھٹھا کیا گیا تو وہ جو ان سے ہنستے تھے ان کی ہنسی انہیں کو لے بیٹھی\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@dccc{تم فرمادو زمین میں سیر کرو پھر دیکھو کہ جھٹلانے والوں کا کیسا انجام ہوا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@dccci{تم فرماؤ کس کا ہے جو کچھ آسمانوں اور زمین میں تم فرماؤ اللہ کا ہے اس نے اپنے کرم کے ذمہ پر رحمت لکھ لی ہے بیشک ضرور تمہیں قیامت کے دن جمع کرے گا اس میں کچھ شک نہیں، وہ جنہوں نے اپنی جان نقصان میں ڈالی ایمان نہیں لاتے،\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@dcccii{اور اسی کا ہے جو بستا ہے رات اور دن میں اور وہی ہے سنتا جانتا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@dccciii{تم فرماؤ کیا اللہ کے سوا کسی اور کو والی بناؤں وہ اللہ جس نے آسمان اور زمین پیدا کیے اور وہ کھلاتا ہے اور کھانے سے پاک ہے تم فرماؤ مجھے حکم ہوا ہے کہ سب سے پہلے گردن رکھوں اور ہرگز شرک والوں میں سے نہ ہونا،\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@dccciv{تم فرماؤ اگر میں اپنے رب کی نافرمانی کروں تو مجھے بڑے دن کے عذاب کا ڈر ہے،\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@dcccv{اس دن جس سے عذاب پھیر دیا جائے ضرور اس پر اللہ کی مہر ہوئی، اور یہی کھلی کامیابی ہے،\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@dcccvi{اور اگر تجھے اللہ کوئی برائی پہنچائے تو اس کے سوا اس کا کوئی دور کرنے والا نہیں، اور اگر تجھے بھلائی پہنچائے تو وہ سب کچھ کرسکتا ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@dcccvii{اور وہی غالب ہے اپنے بندوں پر، اور وہی ہے حکمت والا خبردار،\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@dcccviii{تم فرماؤ سب سے بڑی گواہی کس کی تم فرماؤ کہ اللہ گواہ ہے مجھ میں اور تم میں اور میر ی طر ف اس قر آ ن کی وحی ہوئی ہے کہ میں اس سے تمھیں ڈراؤ ں اورجن جن کو پہنچے تو کیا تم یہ گواہی دیتے ہو کہ اللہ کے ساتھ اور خدا ہیں، تم فرماؤ کہ میں یہ گواہی نہیں دیتا تم فرماؤ کہ وہ تو ایک ہی معبود ہے اور میں بیزار ہوں ان سے جن کو تم شریک ٹھہراتے ہو\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@dcccix{جن کو ہم نے کتاب دی اس نبی کو پہچانتے ہیں جیسا اپنے بیٹے کو پہچانتے ہیں جنہوں نے اپنی جان نقصان میں ڈالی وہ ایمان نہیں لاتے،\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@dcccx{اور اس سے بڑھ کر ظالم کون جو اللہ پر جھوٹ باندھے یا اس کی آیتیں جھٹلائے، بیشک ظالم فلاح نہ پائیں گے،\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@dcccxi{اور جس دن ہم سب کو اٹھائیں گے پھر مشرکوں سے فرمائیں گے کہاں ہیں تمہارے وہ شریک جن کا تم دعویٰ کرتے تھے،\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@dcccxii{پھر ان کی کچھ بناوٹ نہ رہی مگر یہ کہ بولے ہمیں اپنے رب اللہ کی قسم کہ ہم مشرک نہ تھے،\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@dcccxiii{دیکھو کیسا جھوٹ باندھا خود اپنے اوپر اور گم گئیں ان سے جو باتیں بناتے تھے،\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@dcccxiv{اور ان میں کوئی وہ ہے جو تمہاری طرف کان لگاتا ہے اور ہم نے ان کے دلوں پر غلاف کردیے ہیں کہ اسے نہ سمجھیں اور ان کے کانٹ میں ٹینٹ (روئی) اور اگر ساری نشانیاں دیکھیں تو ان پر ایمان نہ لائیں گے یہاں تک کہ جب تمہارے حضور تم سے جھگڑتے حاضر ہوں تو کافر کہیں یہ تو نہیں مگر اگلوں کی داستانیں\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@dcccxv{اور وہ اس سے روکتے اور اس سے دور بھاگتے ہیں اور بلاک نہیں کرتے مگر اپنی جانیں اور انہیں شعور نہیں،\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@dcccxvi{اور کبھی تم دیکھو جب وہ آگ پر کھڑے کئے جائیں گے تو کہیں گے کاش کسی طرح ہم واپس بھیجے جائیں اور اپنے رب کی آیتیں نہ جھٹلائیں اور مسلمان ہوجائیں،\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@dcccxvii{بلکہ ان پر کھل گیا جو پہلے چھپاتے تھے اور اگر واپس بھیجے جائیں تو پھر وہی کریں جس سے منع کیے گئے تھے اور بیشک وہ ضرور جھوٹے ہیں،\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@dcccxviii{اور بولے وہ تو یہی ہماری دنیا کی زندگی ہے اور ہمیں اٹھنا نہیں\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@dcccxix{اور کبھی تم دیکھو جب اپنے رب کے حضور کھڑے کیے جائیں گے، فرمائے گا کیا یہ حق نہیں کہیں گے کیوں نہیں، ہمیں اپنے رب کی قسم، فرمائے گا تو اب عذاب چکھو بدلہ اپنے کفر کا،\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@dcccxx{بیشک ہار میں رہے وہ جنہوں نے اپنے رب سے ملنے کا انکار کیا، یہاں تک کہ جب ان پر قیامت اچانک آگئی بولے ہائے افسوس ہمارا اس پر کہ اس کے ماننے میں ہم نے تقصیر کی، اور وہ اپنے بوجھ اپنی پیٹھ پر لادے ہوئے ہیں ارے کتنا برُا بوجھ اٹھائے ہوئے ہیں\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@dcccxxi{اور دنیا کی زندگی نہیں مگر کھیل کود اور بیشک پچھلا گھر بھلا ان کے لئے جو ڈرتے ہیں تو کیا تمہیں سمجھ نہیں،\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@dcccxxii{ہمیں معلوم ہے کہ تمہیں رنج دیتی ہے وہ بات جو یہ کہہ رہے ہیں تو وہ تمہیں نہیں جھٹلاتے بلکہ ظالم اللہ کی آیتوں سے انکار کرتے ہیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@dcccxxiii{اور تم سے پہلے رسول جھٹلائے گئے تو انہوں نے صبر کیا اس جھٹلانے اور ایذائیں پانے پر یہاں تک کہ انہیں ہماری مدد آئی اور اللہ کی باتیں بدلنے والا کوئی نہیں اور تمہارے پاس رسولوں کی خبریں آ ہی چکیں ہیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@dcccxxiv{اور اگر ان کا منہ پھیرنا تم پر شاق گزرا ہے تو اگر تم سے ہوسکے تو زمین میں کوئی سرنگ تلاش کرلو یا آسمان میں زینہ پھر ان کے لیے نشانی لے آؤ اور اللہ چاہتا تو انہیں ہدایت پر اکٹھا کردیتا تو اے سننے والے تو ہرگز نادان نہ بن،\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@dcccxxv{مانتے تو وہی ہیں جو سنتے ہیں اور ان مردہ دلوں کو اللہ اٹھائے گا پھر اس کی طرف ہانکے جائیں گے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@dcccxxvi{اور بولے ان پر کوئی نشانی کیوں نہ اتری ان کے رب کی طرف سے تم فرماؤ کہ اللہ قادر ہے کہ کوئی نشانی اتارے لیکن ان میں بہت نرے (بالکل) جاہل ہیں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@dcccxxvii{اور نہیں کوئی زمین میں چلنے والا اور نہ کوئی پرند کہ اپنے پروں پر اڑتا ہے مگر تم جیسی اُمتیں ہم نے اس کتاب میں کچھ اٹھا نہ رکھا پھر اپنے رب کی طرف اٹھائے جائیں گے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@dcccxxviii{اور جنہوں نے ہماری آیتیں جھٹلائیں بہرے اور گونگے ہیں اندھیروں میں اللہ جسے چاہے گمراہ کرے اور جسے چاہے سیدھے راستہ ڈال دے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@dcccxxix{تم فرماؤ بھلا بتاؤ تو اگر تم پر اللہ کا عذاب آئے یا قیامت قائم ہو کیا اللہ کے سوا کسی اور کو پکارو گے اگر سچے ہو\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@dcccxxx{بلکہ اسی کو پکارو گے تو وہ اگر چاہے جس پر اسے پکارتے ہو اسے اٹھالے اور شریکوں کو بھول جاؤ گے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@dcccxxxi{اور بیشک ہم نے تم سے پہلی اُمتوں کی طرف رسول بھیجے تو انہیں سختی اور تکلیف سے پکڑا کہ وہ کسی طرح گڑگڑائیں\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@dcccxxxii{تو کیوں نہ ہوا کہ جب ان پر ہمارا عذاب آیا تو گڑگڑائے ہوتے لیکن ان کے دل تو سخت ہوگئے اور شیطان نے ان کے کام ان کی نگاہ میں بھلے کر دکھائے،\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@dcccxxxiii{پھر جب انہوں نے بھلا دیا جو نصیحتیں ان کو کی گئیں تھیں ہم نے ان پر ہر چیز کے دروازے کھول دیے یہاں تک کہ جب خوش ہوئے اس پر جو انہیں ملا تو ہم نے اچانک انہیں پکڑلیا اب وہ آس ٹوٹے رہ گئے،\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@dcccxxxiv{تو جڑ کاٹ دی گئی ظالموں کی اور سب خوبیاں سراہا اللہ رب سارے جہاں کا\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@dcccxxxv{تم فرماؤ بھلا بتاؤ تو اگر اللہ تمہارے کان آنکھ لے لے اور تمہارے دلوں پر مہر کردے تو اللہ سوا کون خدا ہے کہ تمہیں یہ چیزیں لادے دیکھو ہم کس کس رنگ سے آیتیں بیان کرتے ہیں پھر وہ منہ پھیر لیتے ہیں،\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@dcccxxxvi{تم فرماؤ بھلا بتاؤ تو اگر تم پر اللہ کا عذاب آئے اچانک یا کھلم کھلا تو کون تباہ ہوگا سوا ظالموں کے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@dcccxxxvii{اور ہم نہیں بھیجتے رسولوں کو مگر خوشی اور ڈر سناتے تو جو ایمان لائے اور سنورے ان کو نہ کچھ اندیشہ نہ کچھ غم،\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@dcccxxxviii{اور جنہوں نے ہماری آیتیں جھٹلائیں انہیں عذاب پہنچے گا بدلہ ان کی بے حکمی کا،\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@dcccxxxix{تم فرمادو میں تم سے نہیں کہتا میرے پاس اللہ کے خزانے ہیں اور نہ یہ کہوں کہ میں آپ غیب جان لیتا ہوں اور نہ تم سے یہ کہوں کہ میں فرشتہ ہوں میں تو اسی کا تا بع ہوں جو مجھے وحی آتی ہے تم فر ماؤ کیا برابر ہو جائیں گے اندھے اور انکھیا رے تو کیا تم غور نہیں کرتے،\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@dcccxl{اور اس قرآن سے انہیں ڈراؤ جنہیں خوف ہو کہ اپنے رب کی طرف یوں اٹھائے جائیں کہ اللہ کے سوا نہ ان کا کوئی حمایتی ہو نہ کوئی سفارشی اس امید پر کہ وہ پرہیزگار ہوجائیں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@dcccxli{اور دور نہ کرو انہیں جو اپنے رب کو پکارتے ہیں صبح اور شام اس کی رضا چاہتے تم پر ان کے حساب سے کچھ نہیں اور ان پر تمہارے حساب سے کچھ نہیں پھر انہیں تم دور کرو تو یہ کام انصاف سے بعید ہے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@dcccxlii{اور یونہی ہم نے ان میں ایک دوسرے کے لئے فتنہ بنایا کہ مالدار کافر محتاج مسلمانوں کو دیکھ کر کہیں کیا یہ ہیں جن پر اللہ نے احسان کیا ہم میں سے کیا اللہ خوب نہیں جانتا حق ماننے والوں کو،\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@dcccxliii{اور جب تمہارے حضور وہ حاضر ہوں جو ہماری آیتوں پر ایمان لاتے ہیں تو ان سے فرماؤ تم پر سلام تمہارے رب نے اپنے ذمہ کرم پر رحمت لازم کرلی ہے کہ تم میں جو کوئی نادانی سے کچھ برائی کر بیٹھے پھر اس کے بعد توبہ کرے اور سنور جائے تو بیشک اللہ بخشنے والا مہربان ہے،\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@dcccxliv{اور اسی طرح ہم آیتوں کو مفصل بیان فرماتے ہیں اور اس لیے کہ مجرموں کا راستہ ظاہر ہوجائے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@dcccxlv{تم فرماؤ مجھے منع کیا گیا ہے کہ انہیں پوجوں جن کو تم اللہ کے سوا پوجتے ہو تم فرماؤ میں تمہاری خواہشوں پر نہیں چلتا یوں ہو تو میں بہک جاؤں اور راہ پر نہ رہوں،\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@dcccxlvi{تم فرماؤ میں تو اپنے رب کی طرف سے روشن دلیل پر ہوں اور تم اسے جھٹلاتے ہو میرے پاس نہیں جس کی تم جلدی مچارہے ہو حکم نہیں مگر اللہ کا وہ حق فرماتا ہے اور وہ سب سے بہتر فیصلہ کرنے والا،\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@dcccxlvii{تم فرماؤ اگر میرے پاس ہوتی وہ چیز جس کی تم جلدی کررہے ہو تو مجھ میں تم میں کام ختم ہوچکا ہوتا اور اللہ خوب جانتا ہے ستمگاروں کو،\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@dcccxlviii{اور اسی کے پاس ہیں کنجیاں غیب کی انہیں وہی جانتا ہے اور جانتا ہے جو کچھ خشکی اور تری میں ہے، اور جو پتّا گرتا ہے وہ اسے جانتا ہے اور کوئی دانہ نہیں زمین کی اندھیریوں میں اور نہ کوئی تر اور نہ خشک جو ایک روشن کتاب میں لکھا نہ ہو\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@dcccxlix{اور وہی ہے جو رات کو تمہاری روحیں قبض کرتا ہے اور جانتا ہے جو کچھ دن میں کماؤ پھر تمہیں دن میں اٹھاتا ہے کہ ٹھہرائی ہوئی میعاد پوری ہو پھر اسی کی طرف پھرنا ہے پھر وہ بتادے گا جو کچھ تم کرتے تھے،\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@dcccl{اور وہی غالب ہے اپنے بندوں پر اور تم پر نگہبان بھیجتا ہے یہاں تک کہ جب تم میں کسی کو موت آتی ہے ہمارے فرشتے اس کی روح قبض کرتے ہیں اور وہ قصور نہیں کرتے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@dcccli{پھر پھیرے جاتے ہیں اپنے سچے مولیٰ اللہ کی طرف سنتا ہے اسی کا حکم اور وہ سب سے جلد حساب کرنے والا\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@dccclii{تم فرماؤ وہ کون ہے جو تمہیں نجات دیتا ہے جنگل اور دریا کی آفتوں سے جسے پکارتے ہو گِڑ گِڑا کر اور آہستہ کہ اگر وہ ہمیں اس سے بچاوے تو ہم ضرور احسان مانیں گے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@dcccliii{تم فرماؤ اللہ تمہیں نجات دیتا ہے اس سے اور ہر بے چینی سے پھر تم شریک ٹھہراتے ہو\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@dcccliv{تم فرماؤ وہ قادر ہے کہ تم پر عذاب بھیجے تمہارے اوپر سے یا تمہارے پاؤں کے تلے (نیچے) سے یا تمہیں بھڑا دے مختلف گروہ کرکے اور ایک کو دوسرے کی سختی چکھائے، دیکھو ہم کیونکر طرح طرح سے آیتیں بیان کرتے ہیں کہ کہیں ان کو سمجھ ہو\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@dccclv{اور اسے جھٹلایا تمہاری قوم نے اور یہی حق ہے، تم فرماؤ میں تم پر کچھ کڑوڑا (حاکمِ اعلیٰ) نہیں\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@dccclvi{ہر چیز کا ایک وقت مقرر ہے اور عنقریب جان جاؤ گے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@dccclvii{اور اے سننے والے! جب تو انہیں دیکھے جو ہماری آیتوں میں پڑتے ہیں تو ان سے منہ پھیر لے جب تک اور بات میں پڑیں، اور جو کہیں تجھے شیطان بھلاوے تو یاد آئے پر ظالموں کے پاس نہ بیٹھ،\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@dccclviii{اور پرہیز گاروں پر ان کے حساب سے کچھ نہیں ہاں نصیحت دینا شاید وہ باز آئیں\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@dccclix{اور چھوڑ دے ان کو جنہوں نے اپنا دین ہنسی کھیل بنا لیا اور انہیں دنیا کی زندگانی نے فریب دیا اور قرآن سے نصیحت دو کہ کہیں کوئی جان اپنے کئے پر پکڑی نہ جائے اللہ کے سوا نہ اس کا کوئی حمایتی ہو نہ سفارشی اور اگر اپنے عوض سارے بدلے دے تو اس سے نہ لیے جائیں یہ ہیں وہ جو اپنے کیے پر پکڑے گئے انہیں پینے کا کھولتا پانی اور درد ناک عذاب بدلہ ان کے کفر کا،\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@dccclx{تم فرماؤ کیا ہم اللہ کے سوا اس کو پوجیں جو ہمارا نہ بھلا کرے نہ برُا اور الٹے پاؤں پلٹا دیے جائیں بعد اس کے کہ اللہ نے ہمیں راہ دکھائی اس کی طرح جسے شیطان نے زمین میں راہ بھلادی حیران ہے اس کے رفیق اسے راہ کی طرف بلا رہے ہیں کہ ادھر آ، تم فرماؤ کہ اللہ ہی کی ہدایت ہدایت ہے اور ہمیں حکم ہے کہ ہم اس کے لیے گردن رکھ دیں جو رب ہے سارے جہان\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@dccclxi{اور یہ کہ نماز قائم رکھو اور اس سے ڈرو، اور وہی ہے جس کی طرف اٹھنا ہے،\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@dccclxii{اور وہی ہے جس نے آسمان و زمین ٹھیک بنائے اور جس دن فنا ہوئی ہر چیز کو کہے گا ہو جا وہ فوراً ہوجائے گی، اس کی بات سچی ہے، اور اسی کی سلطنت ہے جس دن صور پھونکا جائے گا ہر چھپے اور ظاہر کو جاننے والا، اور وہی حکمت والا خبردار،\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@dccclxiii{اور یاد کرو جب ابراہیم نے اپنے باپ آزر سے کہا، کیا تم بتوں کو خدا بناتے ہو، بیشک میں تمہیں اور تمہاری قوم کو کھلی گمراہی میں پاتا ہوں\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@dccclxiv{اور اسی طرح ہم ابراہیم کو دکھاتے ہیں ساری بادشاہی آسمانوں اور زمین کی اور اس لیے کہ وہ عین الیقین والوں میں ہوجائے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@dccclxv{پھر جب ان پر رات کا اندھیرا آیا ایک تارا دیکھا بولے اسے میرا رب ٹھہراتے ہو پھر جب وہ ڈوب گیا بولے مجھے خوش نہیں آتے ڈوبنے والے،\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@dccclxvi{پھر جب چاند چمکتا دیکھا بولے اسے میرا رب بتاتے ہو پھر جب وہ ڈوب گیا کہا اگر مجھے میرا رب ہدایت نہ کرتا تو میں بھی انہیں گمراہوں میں ہوتا\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@dccclxvii{پھر جب سورج جگمگاتا دیکھا بولے اسے میرا رب کہتے ہو یہ تو ان سب سے بڑا ہے، پھر جب وہ ڈوب گیا کہا اے قوم میں بیزار ہوں ان چیزوں سے جنہیں تم شریک ٹھہراتے ہو\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@dccclxviii{میں نے اپنا منہ اس کی طرف کیا جس نے آسمان اور زمین بنائے ایک اسی کا ہوکر اور میں مشرکین میں نہیں،\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@dccclxix{اور ان کی قوم ان سے جھگڑے لگی کہا کیا اللہ کے بارے میں مجھ سے جھگڑتے ہو تو وہ مجھے راہ بتا چکا اور مجھے ان کا ڈر نہیں جنہیں تم شریک بتاتے ہو ہاں جو میرا ہی رب کوئی بات چاہے میرے رب کا علم ہر چیز کو محیط ہے، تو کیا تم نصیحت نہیں مانتے\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@dccclxx{اور میں تمہارے شریکوں سے کیونکر ڈروں اور تم نہیں ڈرتے کہ تم نے اللہ کا شریک اس کو ٹھہرایا جس کی تم پر اس نے کوئی سند نہ اتاری، تو دونوں گروہوں میں امان کا زیادہ سزا وار کون ہے اگر تم جانتے ہو،\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@dccclxxi{وہ جو ایمان لائے اور اپنے ایمان میں کسی ناحق کی آمیزش نہ کی انہیں کے لیے امان ہے اور وہی راہ پر ہیں،\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@dccclxxii{اور یہ ہماری دلیل ہے کہ ہم نے ابراہیم کو اس کی قوم پر عطا فرمائی، ہم جسے چاہیں درجوں بلند کریں بیشک تمہارا رب علم و حکمت والا ہے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@dccclxxiii{اور ہم نے انہیں اسحاق اور یعقوب عطا کیے، ان سب کو ہم نے راہ دکھائی اور ان سے پہلے نوح کو راہ دکھائی اور میں اس کی اولاد میں سے داؤد اور سلیمان اور ایوب اور یوسف اور موسیٰ اور ہارون کو، اور ہم ایسا ہی بدلہ دیتے ہیں نیکوکاروں کو،\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@dccclxxiv{اور زکریا اور یحییٰ اور عیسیٰ اور الیاس کو یہ سب ہمارے قرب کے لائق ہیں\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@dccclxxv{اور اسماعیل اور یسع اور یونس اور لوط کو، اور ہم نے ہر ایک کو اس کے وقت میں سب پر فضیلت دی\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@dccclxxvi{اور کچھ ان کے باپ دادا اور اولاد اور بھائیوں میں سے بعض کو اور ہم نے انہیں چن لیا اور سیدھی راہ دکھائی،\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@dccclxxvii{یہ اللہ کی ہدایت ہے کہ اپنے بندوں میں جسے چاہے دے، اور اگر وہ شرک کرتے تو ضرور ان کا کیا اکارت جاتا،\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@dccclxxviii{یہ ہیں جن کو ہم نے کتاب اور حکم اور نبوت عطا کی تو اگر یہ لوگ اس سے منکر ہوں تو ہم نے اس کیلئے ایک ایسی قوم لگا رکھی ہے جو انکار والی نہیں\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@dccclxxix{یہ ہیں جن کو اللہ نے ہدایت کی تو تم انہیں کی راہ چلو تم فرماؤ میں قرآن پر تم سے کوئی اجرت نہیں مانگتا وہ تو نہیں مگر نصیحت سارے جہان کو\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@dccclxxx{اور یہود نے اللہ کی قدر نہ جانی جیسی چاہیے تھی جب بولے ا لله نے کسی آدمی پر کچھ نہیں اتارا، تم فرماؤ کس نے اُتاری وہ کتاب جو موسیٰ لائے تھے روشنی اور لوگوں کے لیے ہدایت جس کے تم نے الگ الگ کاغذ بنالیے ظاہر کرتے ہو اور بہت سے چھپالیتے ہو اور تمہیں وہ سکھایا جاتا ہے جو نہ تم کو معلوم تھا نہ تمہارے باپ دادا کو، اللہ کہو پھر انہیں چھوڑ دو ان کی بیہودگی میں انہیں کھیلتا\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@dccclxxxi{اور یہ ہے برکت والی کتاب کہ ہم نے اُتاری تصدیق فرماتی ان کتابوں کی جو آگے تھیں اور اس لیے کہ تم ڈر سناؤ سب بستیوں کے سردار کو اور جو کوئی سارے جہاں میں اس کے گرد ہیں اور جو آخرت پر ایمان لاتے ہیں اس کتاب پر ایمان لاتے ہیں اور اپنی نماز کی حفاظت کرتے ہیں،\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@dccclxxxii{اور اس سے بڑھ کر ظالم کون جو اللہ پر جھوٹ باندھے یا کہے مجھے وحی ہوئی اور اسے کچھ وحی نہ ہوئی اور جو کہے ابھی میں اُتارتا ہوں ایسا جیسا اللہ نے اُتارا اور کبھی تم دیکھوں جس وقت ظالم موت کی سختیوں میں ہیں اور فرشتے ہاتھ پھیلاتے ہوئے ہیں کہ نکالو اپنی جانیں، آج تمہیں خواری کا عذاب دیا جائے گا بدلہ اس کا کہ اللہ پر جھوٹ لگاتے تھے اور اس کی آیتوں سے تکبر کرتے،\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@dccclxxxiii{اور بیشک تم ہمارے پاس اکیلے آئے جیسا ہم نے تمہیں پہلی بار پیدا کیا تھا اور پیٹھ پیچھے چھوڑ آئے جو مال و متاع ہم نے تمہیں دیا تھا اور ہم تمہارے ساتھ تمہارے ان سفارشیوں کو نہیں دیکھتے جن کا تم اپنے میں ساجھا بتاتے تھے بیشک تمہارے آپس کی ڈور کٹ گئی اور تم سے گئے جو دعوے کرتے تھے\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@dccclxxxiv{بیشک اللہ دانے اور گٹھلی کو چیر نے والا ہے زندہ کو مردہ سے نکالنے اور مردہ کو زندہ سے نکالنے والا یہ ہے اللہ تم کہاں اوندھے جاتے ہو\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@dccclxxxv{تاریکی چاک کرکے صبح نکالنے والا اور اس نے رات کو چین بنایا اور سورج اور چاند کو حساب یہ سادھا (سدھایا ہوا) ہے زبردست جاننے والے کا،\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@dccclxxxvi{اور وہی ہے جس نے تمہارے لیے تارے بنائے کہ ان سے راہ پاؤ خشکی اور تری کے اندھیروں میں، ہم نے نشانیاں مفصل بیان کردیں علم والوں کے لیے،\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@dccclxxxvii{اور وہی ہے جس نے تم کو ایک جان سے پیدا کیا پھر کہیں تمہیں ٹھہرنا ہے اور کہیں امانت رہنا بیشک ہم نے مفصل آیتیں بیان کردیں سمجھ والوں کے لیے،\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@dccclxxxviii{اور وہی ہے جس نے آسمان سے پانی اُتارا، تو ہم نے اس سے ہر اُگنے والی چیز نکالی تو ہم نے اس سے نکالی سبزی جس میں سے دانے نکالتے ہیں ایک دوسرے پر چڑھے ہوئے اور کھجور کے گابھے سے پاس پاس گچھے اور انگور کے باغ اور زیتون اور انار کسی بات میں ملتے اور کسی بات میں الگ، اس کا پھل دیکھو جب پھلے اور اس کا پکنا بیشک اس میں نشانیاں ہیں ایمان والوں کے لیے،\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@dccclxxxix{اور اللہ کا شریک ٹھہرایا جنوں کو حالانکہ اسی نے ان کو بنایا اور اس کے لیے بیٹے اور بیٹیاں گڑھ لیں جہالت سے، پاکی اور برتری ہے اس کو ان کی باتوں سے،\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@dcccxc{بے کسی نمو نہ کے آسمانوں اور زمین کا بنانے والا، اسکے بچہ کہاں سے ہو حالانکہ اس کی عورت نہیں اور اس نے ہر چیز پیدا کی اور وہ سب کچھ جانتا ہے،\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@dcccxci{یہ ہے اللہ تمہارا رب اور اس کے سوا کسی کی بندگی نہیں ہر چیز کا بنانے والا تو اسے پوجو وہ ہر چیز پر نگہبان ہے\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@dcccxcii{آنکھیں اسے احاطہ نہیں کرتیں اور سب آنکھیں اس کے احاطہ میں ہیں اور وہی ہے پورا باطن پورا خبردار،\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@dcccxciii{تمہارے پاس آنکھیں کھولنے والی دلیلیں آئیں تمہارے رب کی طرف سے تو جس نے دیکھا تو اپنے بھلے کو اور جو اندھا ہوا اپنے برُے کو، اور میں تم پر نگہبان نہیں،\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@dcccxciv{اور ہم اسی طرح آیتیں طرح طرح سے بیان کرتے اور اس لیے کہ کافر بول اٹھیں کہ تم تو پڑھے ہو اور اس لیے کہ اسے علم والوں پر واضح کردیں،\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@dcccxcv{اس پر چلو جو تمہیں تمہارے رب کی طرف سے وحی ہوتی ہے اس کے سوا کوئی معبود نہیں اور مشرکوں سے منہ پھیر لو\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@dcccxcvi{اور اللہ چاہتا تو وہ شرک نہیں کرتے، اور ہم نے تمہیں ان پر نگہبان نہیں کیا اور تم ان پر کڑوڑے (حاکمِ اعلیٰ) نہیں،\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@dcccxcvii{اور انہیں گالی نہ دو وہ جن کو وہ اللہ کے سوا پوجتے ہیں کہ وہ اللہ کی شان میں بے ادبی کریں گے زیادتی اور جہالت سے یونہی ہم نے ہر اُمت کی نگاہ میں اس کے عمل بھلے کردیے ہیں پھر انہیں اپنے رب کی طرف پھرنا ہے اور وہ انہیں بتادے گا جو کرتے تھے،\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@dcccxcviii{اور انہوں نے اللہ کی قسم کھائی اپنے حلف میں پوری کوشش سے کہ اگر ان کے پاس کوئی نشانی آئی تو ضرور اس پر ایمان لائیں گے، م فرما دو کہ نشانیاں تو اللہ کے پاس ہیں اور تمہیں کیا خبر کہ جب وہ آئیں تو یہ ایمان نہ لائینگے\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@dcccxcix{اور ہم پھیردیتے ہیں ان کے دلوں اور آنکھوں کو جیسا وہ پہلی بار ایمان نہ لائے تھے اور انہیں چھوڑ دیتے ہیں کہ اپنی سرکشی میں بھٹکا کریں،\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@cm{اور اگر ہم ان کی طرف فرشتے اُتارتے اور ان سے مردے باتیں کرتے اور ہم ہر چیز ان کے سامنے اٹھا لاتے جب بھی وہ ایمان لانے والے نہ تھے مگر یہ کہ خدا چاہتا و لیکن ان میں بہت نرے جاہل ہیں\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@cmi{اور اسی طرح ہم نے ہر نبی کے دشمن کیے ہیں آدمیوں اور جنوں میں کے شیطان کہ ان میں ایک دوسرے پر خفیہ ڈالتا ہے بناوٹ کی بات دھوکے کو، اور تمہارا رب چاہتا تو وہ ایسا نہ کرتے تو انہیں ان کی بناوٹوں پر چھوڑ دو\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@cmii{اور اس لیے کہ اس کی طرف ان کے دل جھکیں جنہیں آخرت پر ایمان نہیں اور اسے پسند کریں اور گناہ کمائیں جو انہیں کمانا ہے،\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@cmiii{تو کیا اللہ کے سوا میں کسی اور کا فیصلہ چاہوں اور وہی ہے جس نے تمہاری طرف مفصل کتاب اُتاری اور جنکو ہم نے کتاب دی وہ جانتے ہیں کہ یہ تیرے رب کی طرف سے سچ اترا ہے تو اے سننے والے تو ہر گز شک والوں میں نہ ہو،\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@cmiv{اور پوری ہے تیرے رب کی بات سچ اور انصاف میں اس کی باتوں کا کوئی بدلنے والا نہیں اور وہی ہے سنتا جانتا،\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@cmv{اور اے سننے والے زمین میں اکثر وہ ہیں کہ تو ان کے کہے پر چلے تو تجھے اللہ کی راہ سے بہکا دیں، وہ صرف گمان کے پیچھے ہیں اور نری اٹکلیں (فضول اندازے) دوڑاتے ہیں\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@cmvi{تیرا رب خوب جانتا ہے کہ کون بہکا اس کی راہ سے اور وہ خوب جانتا ہے ہدایت والوں کو،\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@cmvii{تو کھاؤ اسمیں سے جس پر اللہ کا نام لیا گیا اگر تم اسکی آیتیں مانتے ہو،\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@cmviii{اور تمہیں کیا ہوا کہ اس میں سے نہ کھاؤ جس پر اللہ کا نام لیا گیا وہ تم سے مفصل بیان کرچکا جو کچھ تم پر حرام ہوا مگر جب تمہیں اس سے مجبوری ہو اور بیشک بہتیرے اپنی خواہشوں سے گمراہ کرتے ہیں بے جانے بیشک تیرا رب حد سے بڑھنے والوں کو خوب جانتا ہے،\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@cmix{اور چھوڑ دو کھلا اور چھپا گناہ، وہ جو گناہ کماتے ہیں عنقریب اپنی کمائی کی سزا پائیں گے،\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@cmx{اور اُسے نہ کھاؤ جس پر اللہ کا نام نہ لیا گیا اور وہ بیشک حکم عدولی ہے، اور بیشک شیطان اپنے دوستوں کے دلوں میں ڈالتے ہیں کہ تم سے جھگڑیں اور اگر تم ان کا کہنا مانو تو اس وقت تم مشرک ہو\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@cmxi{اور کیا وہ کہ مردہ تھا تو ہم نے اسے زندہ کیا اور اس کے لیے ایک نور کردیا جس سے لوگوں میں چلتا ہے وہ اس جیسا ہوجائے گا جو اندھیریوں میں ہے ان سے نکلنے والا نہیں، یونہی کافروں کی آنکھ میں ان کے اعمال بھلے کردیے گئے ہیں،\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@cmxii{اور اسی طرح ہم نے ہر بستی میں اس کے مجرموں کے سرغنہ کیے کہ اس میں داؤ کھیلیں اور داؤں نہیں کھیلتے مگر اپنی جانوں پر اور انہیں شعورنہیں\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@cmxiii{اور جب ان کے پاس کوئی نشانی آئے تو کہتے ہی ہم ہر گز ایمان نہ لائیں گے جب تک ہمیں بھی ویسا ہی نہ ملے جیسا اللہ کے رسولوں کو ملا اللہ خوب جانتا ہے جہاں اپنی رسالت رکھے عنقریب مجرموں کو اللہ کے یہاں ذلت پہنچے گی اور سخت عذاب بدلہ ان کے مکر کا،\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@cmxiv{اور جسے اللہ راہ دکھانا چاہے اس کا سینہ اسلام کے لیے کھول دیتا ہے اور جسے گمراہ کرنا چاہے اس کا سینہ تنگ خوب رکا ہوا کر دیتا ہے گویا کسی کی زبردستی سے آسمان پر چڑھ رہا ہے، اللہ یونہی عذاب ڈالتا ہے ایمان نہ لانے والوں کو،\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@cmxv{اور یہ تمہارے رب کی سیدھی راہ ہے ہم نے آیتیں مفصل بیان کردیں نصیحت ماننے والوں کے لیے،\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@cmxvi{ان کے لیے سلامتی کا گھر ہے اپنے رب کے یہاں اور وہ ان کا مولیٰ ہے یہ ان کے کاموں کا پھل ہے،\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@cmxvii{اور جس دن اُن سب کو اٹھانے گا اور فرمائے گا، اے جن کے گروہ! تم نے بہت آدمی گھیرلیے اور ان کے دوست آدمی عرض کریں گے اے ہمارے رب! ہم میں ایک نے دوسرے سے فائدہ اٹھایا اور ہم اپنی اس میعاد کو پہنچ گئے جو تو نے ہمارے لیے مقرر فرمائی تھی فرمائے گا آگ تمہارا ٹھکانا ہے ہمیشہ اس میں رہو مگر جسے خدا چاہے اے محبوب! بیشک تمہارا رب حکمت والا علم والا ہے،\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@cmxviii{اور یونہی ہم ظالموں میں ایک کو دوسرے پر مسلط کرتے ہیں بدلہ ان کے کیے کا\qt@no{(129)}}%
\qt@newcmd\qurantrans@ur@cmxix{اے جنوں اور آدمیوں کے گروہ! کیا تمہارے پاس تم میں کے رسول نہ آئے تھے تم پر میری آیتیں پڑھتے اور تمہیں یہ دن دیکھنے سے ڈراتے کہیں گے ہم نے اپنی جانوں پر گواہی دی اور انہیں دنیا کی زندگی نے فریب دیا اور خود اپنی جانوں پر گواہی دیں گے کہ وہ کافر تھے\qt@no{(130)}}%
\qt@newcmd\qurantrans@ur@cmxx{یہ اس لیے کہ تیرا رب بستیوں کو ظلم سے تباہ نہیں کرتا کہ ان کے لوگ بے خبر ہوں\qt@no{(131)}}%
\qt@newcmd\qurantrans@ur@cmxxi{اور ہر ایک کے لیے ان کے کاموں سے درجے ہیں اور تیرا رب ان کے اعمال سے بے خبر نہیں،\qt@no{(132)}}%
\qt@newcmd\qurantrans@ur@cmxxii{اور اے محبوب! تمہارا رب بے پروا ہے رحمت والا، اے لوگو! وہ چاہے تو تمہیں لے جائے اور جسے چاہے تمہاری جگہ لادے جیسے تمہیں اوروں کی اولاد سے پیدا کیا\qt@no{(133)}}%
\qt@newcmd\qurantrans@ur@cmxxiii{بیشک جس کا تمہیں وعدہ دیا جاتا ہے ضرور آنے والی ہے اور تم تھکا نہیں سکتے،\qt@no{(134)}}%
\qt@newcmd\qurantrans@ur@cmxxiv{تم فرماؤ اے میری قوم! تم اپنی جگہ پر کام کیے جاؤ میں اپنا کام کرتا ہوں تو اب جاننا چاہتے ہو کس کا رہتا ہے آحرت کا گھر، بیشک ظالم فلاح نہیں پاتے،\qt@no{(135)}}%
\qt@newcmd\qurantrans@ur@cmxxv{اور اللہ نے جو کھیتی اور مویشی پیدا کیے ان میں اسے ایک حصہ دار ٹھہرایا تو بولے یہ اللہ کا ہے ان کے خیال میں اور یہ ہمارے شریکوں کا تو وہ جو ان کے شریکوں کا ہے وہ تو خدا کو نہیں پہنچتا، اور جو خدا کا ہے وہ ان کے شریکوں کو پہنچتا ہے، کیا ہی برا حکم لگاتے ہیں\qt@no{(136)}}%
\qt@newcmd\qurantrans@ur@cmxxvi{اور یوں ہی بہت مشرکوں کی نگاہ میں ان کے شریکوں نے اولاد کا قتل بھلا کر دکھایا ہے کہ انہیں ہلاک کریں اور ان کا دین اُن پر مشتبہ کردیں اور اللہ چاہتا تو ایسا نہ کرتے تو تم انہیں چھوڑ دو وہ ہیں اور ان کے افتراء،\qt@no{(137)}}%
\qt@newcmd\qurantrans@ur@cmxxvii{اور بولے یہ مویشی اور کھیتی روکی ہوئی ہے اسے وہی کھائے جسے ہم چاہیں اپنے جھوٹے خیال سے اور کچھ مویشی ہیں جن پر چڑھنا حرام ٹھہرایا اور کچھ مویشی کے ذبح پر اللہ کا نام نہیں لیتے یہ سب اللہ پر جھوٹ باندھنا ہے، عنقریب وہ انہیں بدلے دے گا ان کے افتراؤں کا،\qt@no{(138)}}%
\qt@newcmd\qurantrans@ur@cmxxviii{اور بولے جو ان مویشیوں کے پیٹ میں ہے وہ نرا (خالص) ہمارے مردوں کا ہے اور ہماری عورتوں پر حرام ہے، اور مرا ہوا نکلے تو وہ سب اس میں شریک ہیں، قریب ہے کہ اللہ انہیں اِن کی اُن باتوں کا بدلہ دے گا، بیشک وہ حکمت و علم والا ہے،\qt@no{(139)}}%
\qt@newcmd\qurantrans@ur@cmxxix{بیشک تباہ ہوئے وہ جو اپنی اولاد کو قتل کرتے ہیں احمقانہ جہالت سے اور حرام ٹھہراتے ہیں وہ جو اللہ نے انہیں روزی دی اللہ پر جھوٹ باندھنے کو بیشک وہ بہکے اور راہ نہ پائی\qt@no{(140)}}%
\qt@newcmd\qurantrans@ur@cmxxx{اور وہی ہے جس نے پیدا کیے باغ کچھ زمین پر چھئے (چھائے) ہوئے اور کچھ بے چھئے (پھیلے) اور کھجور اور کھیتی جس میں رنگ رنگ کے کھانے اور زیتون اور انار کسی بات میں ملتے اور کسی میں الگ کھاؤ اس کا پھل جب پھل لائے اور اس کا حق دو جس دن کٹے اور بے جا نہ خرچو بیشک بے جا خرچنے والے اسے پسند نہیں،\qt@no{(141)}}%
\qt@newcmd\qurantrans@ur@cmxxxi{اور مویشی میں سے کچھ بوجھ اٹھانے والے اور کچھ زمین پر بچھے کھاؤ اس میں سے جو اللہ نے تمہیں روزی دی اور شیطان کے قدموں پر نہ چلو، بیشک وہ تمہارا صریح دشمن ہے،\qt@no{(142)}}%
\qt@newcmd\qurantrans@ur@cmxxxii{آٹھ نر و مادہ ایک جوڑا بھیڑ کا اور ایک جوڑا بکری کا، تم فرماؤ کیا اس نے دونوں نر حرام کیے یا دونوں مادہ یا وہ جسے دنوں مادہ پیٹ میں لیے ہیں کسی علم سے بتاؤ اگر تم سچے ہو\qt@no{(143)}}%
\qt@newcmd\qurantrans@ur@cmxxxiii{اور ایک جوڑا اونٹ کا اور ایک جوڑا گائے کا، تم فرماؤ کیا اس نے دونوں نر حرام کیے یا دونوں مادہ یا وہ جسے دونوں مادہ پیٹ میں لیے ہیں کیا تم موجود تھے جب اللہ نے تمہیں یہ حکم دیا تو اس سے بڑھ کر ظالم کون جو اللہ پر جھوٹ باندھے کہ لوگوں کو اپنی جہالت سے گمراہ کرے، بیشک اللہ ظالموں کو راہ نہیں دکھاتا،\qt@no{(144)}}%
\qt@newcmd\qurantrans@ur@cmxxxiv{تم فرماؤ میں نہیں پاتا اس میں جو میری طرف وحی ہوئی کسی کھانے والے پر کوئی کھانا حرام مگر یہ کہ مردار ہو یا رگوں کا بہتا خون یا بد جانور کا گوشت وہ نجاست ہے یا وہ بے حکمی کا جانور جس کے ذبح میں غیر خدا کا نام پکارا گیا تو جو ناچار ہوا نہ یوں کہ آپ خواہش کرے اور نہ یوں کہ ضرورت سے بڑھے تو بے شیک اللہ بخشنے والا مہربان ہے\qt@no{(145)}}%
\qt@newcmd\qurantrans@ur@cmxxxv{اور یہودیوں پر ہم نے حرام کیا ہر ناخن والا جانور اور گائے اور بکری کی چربی ان پر حرام کی مگر جو ان کی پیٹھ میں لگی ہو یا آنت یا ہڈی سے ملی ہو، ہم نے یہ ان کی سرکشی کا بدلہ دیا اور بیشک ہم ضرور سچے ہیں،\qt@no{(146)}}%
\qt@newcmd\qurantrans@ur@cmxxxvi{پھر اگر وہ تمہیں جھٹلائیں تو تم فرماؤ کہ تمہارا رب وسیع رحمت والا ہے اور اس کا عذاب مجرموں پر سے نہیں ٹالا جاتا\qt@no{(147)}}%
\qt@newcmd\qurantrans@ur@cmxxxvii{اب کہیں گے مشرک کہ اللہ چاہتا تو نہ ہم شرک کرتے نہ ہمارے باپ دادا نہ ہم کچھ حرام ٹھہراتے ایسا ہی ان کے اگلوں نے جھٹلایا تھا یہاں تک کہ ہمارا عذاب چکھا تم فرماؤ کیا تمہارے پاس کوئی علم ہے کہ اسے ہمارے لیے نکالو، تم تو نرے گمان (خام خیال) کے پیچھے ہو اور تم یونہی تخمینے کرتے ہو\qt@no{(148)}}%
\qt@newcmd\qurantrans@ur@cmxxxviii{تم فرماؤ تو اللہ ہی کی حجت پوری ہے تو وہ چاہتا تو سب کی ہدایت فرماتا،\qt@no{(149)}}%
\qt@newcmd\qurantrans@ur@cmxxxix{تم فرماؤ لاؤ اپنے وہ گواہ جو گواہی دیں کہ اللہ نے اسے حرام کیا پھر اگر وہ گواہی دے بیٹھیں تو تُو اے سننے والے! ان کے ساتھ گواہی نہ دینا اور ان کی خواہشوں کے پیچھے نہ چلنا جو ہماری آیتیں جھٹلاتے ہیں اور جو آخرت پر ایمان نہیں لاتے اور اپنے رب کا برابر والا ٹھہراتے ہیں\qt@no{(150)}}%
\qt@newcmd\qurantrans@ur@cmxl{تم فرماؤ آؤ میں تمہیں پڑھ کر سناؤں جو تم پر تمہارے رب نے حرام کیا یہ کہ اس کا کوئی شریک نہ کرو اور ماں باپ کے ساتھ بھلائی کرو اور اپنی اولاد قتل نہ کرو مفلسی کے باعث، ہم تمہیں اور انہیں سب کو رزق دیں گے اور بے حیائیوں کے پاس نہ جاؤ جو ان میں کھلی ہیں اور جو چھپی اور جس جان کی اللہ نے حرمت رکھی اسے ناحق نہ مارو یہ تمہیں حکم فرمایا ہے کہ تمہیں عقل ہو\qt@no{(151)}}%
\qt@newcmd\qurantrans@ur@cmxli{اور یتیموں کے مال کے پاس نہ جاؤ مگر بہت اچھے طریقہ سے جب تک وہ اپنی جوانی کو پہنچے اور ناپ اور تول انصاف کے ساتھ پوری کرو، ہم کسی جان پر بوجھ نہیں ڈالتے مگر اس کے مقدور بھر، اور جب بات کہو تو انصاف کی کہو اگرچہ تمہارے رشتہ دار کا معاملہ ہو اور اللہ ہی کا عہد پورا کرو، یہ تمہیں تاکید فرمائی کہ کہیں تم نصیحت مانو،\qt@no{(152)}}%
\qt@newcmd\qurantrans@ur@cmxlii{اور یہ کہ یہ ہے میرا سیدھا راستہ تو اس پر چلو اور اور راہیں نہ چلو کہ تمہیں اس کی راہ سے جدا کردیں گی، یہ تمہیں حکم فرمایا کہ کہیں تمہیں پرہیزگاری ملے،\qt@no{(153)}}%
\qt@newcmd\qurantrans@ur@cmxliii{پھر ہم نے موسیٰ کو کتاب عطا فرمائی پورا احسان کرنے کو اس پر جو نیکوکار ہے اور ہر چیز کی تفصیل اور ہدایت اور رحمت کہ کہیں وہ اپنے رب سے ملنے پر ایمان لائیں\qt@no{(154)}}%
\qt@newcmd\qurantrans@ur@cmxliv{اور یہ برکت والی کتاب ہم نے اُتاری تو اس کی پیروی کرو اور پرہیزگاری کرو کہ تم پر رحم ہو،\qt@no{(155)}}%
\qt@newcmd\qurantrans@ur@cmxlv{کبھی کہو کہ کتاب تو ہم سے پہلے دو گروہوں پر اُتری تھی اور ہمیں ان کے پڑھنے پڑھانے کی کچھ خبر نہ تھی\qt@no{(156)}}%
\qt@newcmd\qurantrans@ur@cmxlvi{یا کہو کہ اگر ہم پر کتاب اُترتی تو ہم ان سے زیادہ ٹھیک راہ پر ہوتے تو تمہارے پاس تمہارے رب کی روشن دلیل اور ہدایت او ر رحمت آئی تو اس سے زیادہ ظالم کون جو اللہ کی آیتوں کو جھٹلائے اور ان سے منہ پھیرے عنقریب وہ جو ہماری آیتوں سے منہ پھیرتے ہیں ہم انہیں بڑے عذاب کی سزا دیں گے بدلہ ان کے منہ پھیرنے کا،\qt@no{(157)}}%
\qt@newcmd\qurantrans@ur@cmxlvii{کاہے کے انتظار میں ہیں مگر یہ کہ آئیں ان کے پاس فرشتے یا تمہارے رب کا عذاب یا تمہارے رب کی ایک نشانی آئے جس دن تمہارے رب کی وہ ایک نشانی آئے گی کسی جان کو ایمان لانا کام نہ دے گا جو پہلے ایمان نہ لائی تھی یا اپنے ایمان میں کوئی بھلائی نہ کمائی تھی تم فرماؤ رستہ دیکھو ہم بھی دیکھتے ہیں،\qt@no{(158)}}%
\qt@newcmd\qurantrans@ur@cmxlviii{وہ جنہوں نے اپنے دین میں جُدا جُدا راہیں نکالیں او رکئی گروہ ہوگئے اے محبوب! تمہیں ان سے کچھ علا قہ نہیں ان کا معاملہ اللہ ہی کے حوالے ہے پھر وہ انہیں بتادے گا جو کچھ وہ کرتے تھے\qt@no{(159)}}%
\qt@newcmd\qurantrans@ur@cmxlix{جو ایک نیکی لائے تو اس کے لیے اس جیسی دس ہیں اور جو برائی لائے تو اسے بدلہ نہ ملے گا مگر اس کے برابر اور ان پر ظلم نہ ہوگا،\qt@no{(160)}}%
\qt@newcmd\qurantrans@ur@cml{تم فرماؤ بیشک مجھے میرے رب نے سیدھی راہ دکھائی ٹھیک دین ابراہیم کی ملّت جو ہر باطل سے جُدا تھے، اور مشرک نہ تھے\qt@no{(161)}}%
\qt@newcmd\qurantrans@ur@cmli{تم فرماؤ بیشک میری نماز اور میری قربانیاں اور میرا جینا اور میرا مرنا سب اللہ کے لیے ہے جو رب سارے جہان کا\qt@no{(162)}}%
\qt@newcmd\qurantrans@ur@cmlii{اس کا کوئی شریک نہیں، مجھے یہی حکم ہوا ہے اور میں سب سے پہلا مسلمان ہوں\qt@no{(163)}}%
\qt@newcmd\qurantrans@ur@cmliii{تم فرماؤ کیا اللہ کے سوا اور رب چاہوں حالانکہ وہ ہر چیز کا رب ہے اور جو کوئی کچھ کمائے وہ اسی کے ذمہ ہے، اور کوئی بوجھ اٹھانے والی جان دوسرے کا بوجھ نہ اٹھائے گی پھر تمہیں اپنے رب کی طرف پھرنا ہے وہ تمہیں بتادے گا جس میں اختلاف کرتے تھے،\qt@no{(164)}}%
\qt@newcmd\qurantrans@ur@cmliv{اور وہی ہے جس نے زمین میں تمہیں نائب کیا اور تم میں ایک کو دوسرے پر درجوں بلندی دی کہ تمہیں آزمائے اس چیز میں جو تمہیں عطا کی بیشک تمہارے رب کو عذاب کرتے دیر نہیں لگتی اور بیشک وہ ضرور بخشنے والا مہربان ہے،\qt@no{(165)}}%
\qt@newcmd\qurantrans@ur@cmlv{\basmalahur المص\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@cmlvi{اے محبوب! ایک کتاب تمہاری طرف اُتاری گئی تو تمہارا جی اس سے نہ رُکے اس لیے کہ تم اس سے ڈر سناؤ اور مسلمانوں کو نصیحت،\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@cmlvii{اے لوگو! اس پر چلو جو تمہاری طرف تمہارے رب کے پاس سے اُترا اور اسے چھوڑ کر اور حاکموں کے پیچھے نہ جاؤ، بہت ہی کم سمجھتے ہو،\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@cmlviii{اور کتنی ہی بستیاں ہم نے ہلاک کیں تو ان پر ہمارا عذاب رات میں آیا جب وہ دوپہر کو سوتے تھے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@cmlix{تو ان کے منہ سے کچھ نہ نکلا جب ہمارا عذاب ان پر آیا مگر یہی بولے کہ ہم ظالم تھے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@cmlx{تو بیشک ضرور ہمیں پوچھنا ہے ان سے جن کے پاس رسول گئے اور بیشک ضرور ہمیں پوچھنا ہے رسولوں سے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@cmlxi{تو ضرور ہم ان کو بتادیں گے اپنے علم سے اور ہم کچھ غائب نہ تھے،\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@cmlxii{اور اس دن تول ضرور ہونی ہے تو جن کے پلے بھاری ہوئے وہی مراد کو پہنچے،\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@cmlxiii{اور جن کے پلے ہلکے ہوئے تو وہی ہیں جنہوں نے اپنی جان گھاٹے میں ڈالی ان زیادتیوں کا بدلہ جو ہماری آیتوں پر کرتے تھے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@cmlxiv{اور بیشک ہم نے تمہیں زمین میں جماؤ (ٹھکانا) دیا اور تمہارے لیے اس میں زندگی کے اسباب بنائے بہت ہی کم شکر کرتے ہو\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@cmlxv{اور بیشک ہم نے تمہیں پیدا کیا پھر تمہارے نقشے بنائے پھر ہم نے ملائکہ سے فرمایا کہ آدم کو سجدہ کرو، تو وہ سب سجدے میں گرے مگر ابلیس، یہ سجدہ کرنے والوں میں نہ ہوا،\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@cmlxvi{فرمایا کس چیز نے تجھے روکا کہ تو نے سجدہ نہ کیا جب میں نے تجھے حکم دیا تھا بولا میں اس سے بہتر ہوں تو نے مجھے آگ سے بنایا اور اسے مٹی سے بنایا\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@cmlxvii{فرمایا تو یہاں سے اُ تر جا تجھے نہیں پہنچتا کہ یہاں رہ کر غرور کرے نکل تو ہے ذلت والوں میں\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@cmlxviii{بولا مجھے فرصت دے اس دن تک کہ لوگ اٹھائے جائیں،\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@cmlxix{فرمایا تجھے مہلت ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@cmlxx{بولا تو قسم اس کی کہ تو نے مجھے گمراہ کیا میں ضرور تیرے سیدھے راستہ پر ان کی تاک میں بیٹھوں گا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@cmlxxi{پھر ضرور میں ان کے پاس آؤں گا ان کے آگے اور ان کے پیچھے او ر ان کے دائیں اور ان کے بائیں سے اور تو ان میں سے اکثر کو شکر گزار نہ پائے گا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@cmlxxii{فرمایا یہاں سے نکل جا رد کیا گیا راندہ ہوا، ضرور جو اُن میں سے تیرے کہے پر چلا میں تم سب سے جہنم بھردوں گا\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@cmlxxiii{اور اے آدم تو اور تیرا جوڑا جنت میں رہو تو اُس سے جہاں چاہو کھاؤ اور اس پیڑ کے پاس نہ جانا کہ حد سے بڑھنے والوں میں ہو گے،\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@cmlxxiv{پھر شیطان نے ان کے جی میں خطرہ ڈالا کہ ان پر کھول دے ان کی شرم کی چیزیں جو ان سے چھپی تھیں اور بولا تمہیں تمہارے رب نے اس پیڑ سے اسی لیے منع فرمایا ہے کہ کہیں تم دو فرشتے ہوجاؤ یا ہمیشہ جینے والے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@cmlxxv{اور ان سے قسم کھائی کہ میں تم دونوں کا خیر خواہ ہوں،\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@cmlxxvi{تو اُتار لایا انہیں فریب سے پھر جب انہوں نے وہ پیڑ چکھا ان پر اُن کی شرم کی چیزیں کھل گئیں اور اپنے بدن پر جنت کے پتے چپٹانے لگے، اور انہیں ان کے رب نے فرمایا کیا میں نے تمہیں اس پیڑ سے منع نہ کیا اور نہ فرمایا تھا کہ شیطان تمہارا کھلا دشمن ہے،\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@cmlxxvii{دونوں نے عرض کی، اے رب ہمارے! ہم نے اپنا آپ بُرا کیا، تو اگر تُو ہمیں نہ بخشے اور ہم پر رحم نہ کرے تو ہم ضرور نقصان والوں میں ہوئے،\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@cmlxxviii{فرمایا اُترو تم میں ایک دوسرے کا دشمن ہے اور تمہیں زمین میں ایک وقت تک ٹھہرنا اور برتنا ہے،\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@cmlxxix{فرمایا اسی میں جیوگے اور اسی میں مرو گے اور اسی میں اٹھائے جاؤ گے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@cmlxxx{اے آدم کی اولاد! بیشک ہم نے تمہاری طرف ایک لباس وہ اُتارا کہ تمہاری شرم کی چیزیں چھپائے اور ایک وہ کہ تمہاری آرائش ہو اور پرہیزگاری کا لباس وہ سب سے بھلا یہ اللہ کی نشانیوں میں سے ہے کہ کہیں وہ نصیحت مانیں،\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@cmlxxxi{اے آدم کی اولاد! خبردار! تمہیں شیطان فتنہ میں نہ ڈالے جیسا تمہارے ماں باپ کو بہشت سے نکالا اتروا دیئے ان کے لباس کہ ان کی شرم کی چیزیں انہیں نظر پڑیں، بیشک وہ اور اس کا کنبہ تمہیں وہاں سے دیکھتے ہیں کہ تم انہیں نہیں دیکھتے بیشک ہم نے شیطانوں کو ان کا دوست کیا ہے جو ایمان نہیں لاتے،\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@cmlxxxii{اور جب کوئی بے حیائی کریں تو کہتے ہیں ہم نے اس پر اپنے باپ دادا کو پایا اور اللہ نے ہمیں اس کا حکم دیا تو فرماؤ بیشک اللہ بے حیائی کا حکم نہیں دیتا، کیا اللہ پر وہ بات لگاتے ہو جس کی تمہیں خبر نہیں،\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@cmlxxxiii{تم فرماؤ میرے رب نے انصاف کا حکم دیا ہے، اور اپنے منہ سیدھے کرو ہر نماز کے وقت اور اس کی عبادت کرو نرے (خالص) اس کے بندے ہوکر، جیسے اس نے تمہارا آغاز کیا ویسے ہی پلٹو گے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@cmlxxxiv{ایک فرقے کو راہ دکھائی اور ایک فرقے کو گمراہی ثابت ہوئی انہوں نے اللہ کو چھوڑ کر شیطانوں کو والی بنایا اور سمجھتے یہ ہیں کہ وہ راہ پر ہیں،\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@cmlxxxv{اے آدم کی اولاد! اپنی زینت لو جب مسجد میں جاؤ اور کھاؤ اور پیو اور حد سے نہ بڑھو، بیشک حد سے بڑھنے والے اسے پسند نہیں،\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@cmlxxxvi{تم فرماؤ کس نے حرام کی اللہ کی وہ زینت جو اس نے اپنے بندو ں کے لیے نکالی اور پاک رزق تم فرماؤ کہ وہ ایمان والوں کے لیے ہے دنیا میں اور قیامت میں تو خاص انہی کی ہے، ہم یونہی مفصل آیتیں بیان کرتے ہیں علم والوں کے لیے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@cmlxxxvii{تم فرماؤ میرے رب نے تو بے حیائیاں حرام فرمائی ہیں جو ان میں کھلی ہیں اور جو چھپی اور گناہ اور ناحق زیادتی اور یہ کہ اللہ کا شریک کرو جس کی اس نے سند نہ اتاری اور یہ کہ اللہ پر وہ بات کہو جس کا علم نہیں رکھتے،\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@cmlxxxviii{اور ہر گروہ کا ایک وعدہ ہے تو جب ان کا وعدہ آئے گا ایک گھڑی نہ پیچھے ہو نہ آگے،\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@cmlxxxix{اے آدم کی اولاد! اگر تمہارے پاس تم میں کے رسول آئیں میری آیتیں پڑھتے تو جو پرہیزگاری کرے اور سنورے تو اس پر نہ کچھ خوف اور نہ کچھ غم،\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@cmxc{اور جنہوں نے ہماری آیتیں جھٹلائیں اور ان کے مقابل تکبر کیا وہ دوز خی ہیں انہیں اس میں ہمیشہ رہنا،\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@cmxci{تو اس سے بڑھ کر ظالم کون جس نے اللہ پر جھوٹ باندھا یا اس کی آیتیں جھٹلائیں، انہیں ان کے نصیب کا لکھا پہنچے گا یہاں تک کہ جب ان کے پاس ہمارے بھیجے ہوئے ان کی جان نکالنے آئیں تو ان سے کہتے ہیں کہاں ہیں وہ جن کو تم اللہ کے سوا پوجتے تھے، کہتے ہیں وہ ہم سے گم گئے اور اپنی جانوں پر آپ گواہی دیتے ہیں کہ وہ کافر تھے،\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@cmxcii{اللہ ان سے فرماتا ہے کہ تم سے پہلے جو اور جماعتیں جن اور آدمیوں کی آگ میں گئیں، انہیں میں جاؤ جب ایک گروہ داخل ہوتا ہے دوسرے پر لعنت کرتا ہے یہاں تک کہ جب سب اس میں جا پڑے تو پچھلے پہلوں کو کہیں گے اے رب ہمارے! انہوں نے ہم کو بہکایا تھا تو انہیں آگ کا دُونا عذاب دے، فرمائے گا سب کو دُونا ہے مگر تمہیں خبر نہیں\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@cmxciii{اور پہلے پچھلوں سے کہیں گے تو تم کچھ ہم سے اچھے نہ رہے تو چکھو عذاب بدلہ اپنے کیے کا\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@cmxciv{وہ جنہوں نے ہماری آیتیں جھٹلائیں اور ان کے مقابل تکبر کیا ان کے لیے آسمان کے دروازے نہ کھولے جائیں گے اور نہ وہ جنت میں داخل ہوں جب تک سوئی کے ناکے اونٹ داخل نہ ہو اور مجرموں کو ہم ایسا ہی بدلہ دیتے ہیں\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@cmxcv{انہیں آگ ہی بچھونا اور آگ ہی اوڑھنا اور ظالموں کو ہم ایسا ہی بدلہ دیتے ہیں،\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@cmxcvi{اور وہ جو ایمان لائے اور طاقت بھر اچھے کام کیے ہم کسی پر طاقت سے زیادہ بوجھ نہیں رکھتے، وہ جنت والے ہیں، انہیں اس میں ہمیشہ رہنا،\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@cmxcvii{اور ہم نے ان کے سینوں سے کینے کھینچ لیے ان کے نیچے نہریں بہیں گی اور کہیں گے سب خوبیاں اللہ کو جس نے ہمیں اس کی راہ دکھائی اور ہم راہ نہ پاتے اگر اللہ ہمیں راہ نہ دکھاتا، بیشک ہمارے رب کے رسول حق لائے اور ندا ہوئی کہ یہ جنت تمہیں میراث ملی صلہ تمہارے اعمال کا،\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@cmxcviii{اور جنت والوں نے دوزخ والوں کو پکارا کہ ہمیں تو مل گیا جو سچا وعدہ ہم سے ہمارے رب نے کیا تھا تو کیا تم نے بھی پایا جو تمہارے رب نے سچا وعدہ تمہیں دیا تھا بولے، ہاں! اور بیچ میں منادی نے پکار دیا کہ اللہ کی لعنت ظالموں پر\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@cmxcix{جو اللہ کی راہ سے روکتے ہیں اور اسے کجی چاہتے ہیں اور آخرت کا انکار رکھتے ہیں،\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@m{اور جنت و دوزخ کے بیچ میں ایک پردہ ہے اور اعراف پر کچھ مرد ہوں گے کہ دونوں فریق کو ان کی پیشانیوں سے پہچانیں گے اور وہ جنتیوں کو پکاریں گے کہ سلام تم پر یہ جنت میں نہ گئے اور اس کی طمع رکھتے ہیں،\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mi{اور جب ان کی آنکھیں دوزخیوں کی طرف پھریں گی کہیں گے اے ہمارے رب! ظالموں کے ساتھ نہ کر،\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mii{اور اعراف والے کچھ مردوں کو پکاریں گے جنہیں ان کی پیشانی سے پہچانتے ہیں کہیں گے تمہیں کیا کام آیا تمہارا جتھا اور وہ جو تم غرور کرتے تھے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@miii{کیا یہ ہیں وہ لوگ جن پر تم قسمیں کھاتے تھے کہ اللہ ان پر اپنی رحمت کچھ نہ کرے گا ان سے تو کہا گیا کہ جنت میں جاؤ نہ تم کو اندیشہ نہ کچھ غم،\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@miv{اور دوزخی بہشتیوں کو پکاریں گے کہ ہمیں اپنے پانی کا فیض دو یا اس کھانے کا جو اللہ نے تمہیں دیا کہیں گے بیشک اللہ نے ان دونوں کو کافروں پر حرام کیا ہے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mv{جنہوں نے اپنے دین کو کھیل تماشا بنایا اور دنیا کی زیست نے انہیں فریب دیا تو آج ہم انہیں چھوڑ دیں گے جیسا انہوں نے اس دن کے ملنے کا خیال چھوڑا تھا اور جیسا ہماری آیتوں سے انکار کرتے تھے،\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mvi{اور بیشک ہم ان کے پاس ایک کتاب لائے جسے ہم نے ایک بڑے علم سے مفصل کیا ہدایت و رحمت ایمان والوں کے لیے،\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mvii{کاہے کی راہ دیکھتے ہیں مگر اس کی کہ اس کتاب کا کہا ہوا انجام سامنے آئے جس دن اس کا بتایا انجام واقع ہوگا بول اٹھیں گے وہ جو اسے پہلے سے بھلائے بیٹھے تھے کہ بیشک ہمارے رب کے رسول حق لائے تھے تو ہیں کوئی ہمارے سفارشی جو ہماری شفاعت کریں یا ہم واپس بھیجے جائیں کہ پہلے کاموں کے خلاف کام کریں بیشک انہوں نے اپنی جانیں نقصان میں ڈالیں اور ان سے کھوئے گئے جو بہتان اٹھاتے تھے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mviii{بیشک تمہارا رب اللہ ہے جس نے آسمان اور زمین چھ دن میں بنائے پھر عرش پر استواء فرمایا جیسا اس کی شان کے لائق ہے رات دن کو ایک دوسرے سے ڈھانکتا ہے کہ جلد اس کے پیچھے لگا آتا ہے اور سورج اور چاند اور تاروں کو بنایا سب اس کے حکم کے دبے ہوئے، سن لو اسی کے ہاتھ ہے پیدا کرنا اور حکم دینا، بڑی برکت والا ہے اللہ رب سارے جہان کا،\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mix{اپنے رب سے دعا کرو گڑگڑاتے اور آہستہ، بیشک حد سے بڑھنے والے اسے پسند نہیں،\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mx{اور زمین میں فساد نہ پھیلاؤ اس کے سنورنے کے بعد اور اس سے دعا کرو ڈرتے اور طمع کرتے، بیشک اللہ کی رحمت نیکوں سے قریب ہے،\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mxi{اور وہی ہے کہ ہوائیں بھیجتا ہے اس کی رحمت کے آگے مژدہ سناتی یہاں تک کہ جب اٹھا لائیں بھاری بادل ہم نے اسے کسی مردہ شہر کی طرف چلایا پھر اس سے پانی اتارا پھر اس سے طرح طرح کے پھل نکالے اسی طرح ہم مُردوں کو نکالیں گے کہیں تم نصیحت مانو،\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mxii{اور جو اچھی زمین ہے اس کا سبزہ اللہ کے حکم سے نکلتا ہے اور جو خراب ہے اس میں نہیں نکلتا مگر تھوڑا بمشکل ہم یونہی طرح طرح سے آیتیں بیان کرتے ہیں ان کے لیے جو احسان مانیں،\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mxiii{بیشک ہم نے نوح کو اس کی قوم کی طرف بھیجا تو اس نے کہا میری قوم اللہ کو پوجو اسکے سوا تمہارا کوئی معبود نہیں بیشک مجھے تم پر بڑے دن کے عذاب کا ڈر ہے\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mxiv{اس کی قوم کے سردار بولے بیشک ہم تمہیں کھلی گمراہی میں دیکھتے ہیں،\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mxv{کہا اے میری قوم مجھ میں گمراہی کچھ نہیں میں تو رب العالمین کا رسول ہوں،\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mxvi{تمہیں اپنے رب کی رسالتیں پہنچاتا اور تمہارا بھلا چاہتا اور میں اللہ کی طرف سے وہ علم رکھتا ہوں جو تم نہیں رکھتے،\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mxvii{اور کیا تمہیں اس کا اچنبا ہوا کہ تمہارے پاس رب کی طرف سے ایک نصیحت آئی تم میں کے ایک مرد کی معرفت کہ وہ تمہیں ڈرائے اور تم ڈرو اور کہیں تم پر رحم ہو،\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mxviii{تو انہوں نے اسے جھٹلایا تو ہم نے اسے اور جو اس کے ساتھ کشتی میں تھے نجات دی اور اپنی آیتیں جھٹلانے والوں کو ڈبو دیا، بیشک وہ اندھا گروہ تھا\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mxix{اور عاد کی طرف ان کی برادری سے ہود کو بھیجا کہا اے میری قوم اللہ کی بندگی کرو اس کے سوا تمہارا کوئی معبود نہیں، تو کیا تمہیں ڈر نہیں\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mxx{اس کی قوم کے سردار بولے بیشک ہم تمہیں بیوقوف سمجھتے ہیں اور بیشک ہم تمہیں جھوٹوں میں گمان کرتے ہیں\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mxxi{کہا اے میری قوم مجھے بے وقوفی سے کیا علاقہ میں تو پروردگار عالم کا رسول ہوں،\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mxxii{تمہیں اپنے رب کی رسالتیں پہنچاتا ہوں اور تمہارا معتمد خیرخواہ ہوں\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mxxiii{اور کیا تمہیں اس کا اچنبا ہوا کہ تمہارے پاس تمہارے رب کی طرف سے ایک نصیحت آئی تم میں سے ایک مرد کی معرفت کہ وہ تمہیں ڈرائے اور یاد کرو جب اس نے تمہیں قوم نوح کا جانشین کیا اور تمہارے بدن کا پھیلاؤ بڑھایا تو اللہ کی نعمتیں یاد کرو کہ کہیں تمہارا بھلا ہو،\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mxxiv{بولے کیا تم ہمارے پاس اس لیے آئے ہو کہ ہم ایک اللہ کو پوجیں اور جو ہمارے باپ دادا پوجتے تھے، انہیں چھوڑ دیں تو لاؤ جس کا ہمیں وعدہ دے رہے ہو اگر سچے ہو،\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mxxv{کہا ضرور تم پر تمہارے رب کا عذاب اور غضب پڑ گیا کیا مجھ سے خالی ان ناموں میں جھگڑ رہے ہو جو تم نے اور تمہارے باپ دادا نے رکھ لیے اللہ نے ان کی کوئی سند نہ اتاری، تو راستہ دیکھو میں بھی تمہارے ساتھ دیکھتا ہوں،\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mxxvi{تو ہم نے اسے اور اس کے ساتھ والوں کو اپنی ایک بڑی رحمت فرماکر نجات دی اور جو ہماری آیتیں جھٹلاتے تھے ان کی جڑ کاٹ دی اور وہ ایمان والے نہ تھے،\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mxxvii{اور ثمود کی طرف ان کی برادری سے صالح کو بھیجا کہا اے میری قوم اللہ کو پوجو اس کے سوا تمہارا کوئی معبود نہیں، بیشک تمہارے پاس تمہارے رب کی طرف سے روشن دلیل آئی یہ اللہ کا ناقہ ہے تمہارے لیے نشانی، تو اسے چھوڑ دو کہ اللہ کی زمین میں کھائے اور اسے برائی سے ہاتھ نہ لگاؤ کہ تمہیں درد ناک عذاب آئے گا،\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mxxviii{اور یاد کرو جب تم کو عاد کا جانشین کیا اور ملک میں جگہ دی کہ نرم زمین میں محل بناتے ہو اور پہاڑوں میں مکان تراشتے ہو تو اللہ کی نعمتیں یاد کرو اور زمین میں فساد مچاتے نہ پھرو،\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mxxix{اس کی قوم کے تکبر والے کمزور مسلمانوں سے بولے کیا تم جانتے ہو کہ صالح اپنے رب کے رسول ہیں، بولے وہ جو کچھ لے کے بھیجے گئے ہم اس پر ایمان رکھتے ہیں\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mxxx{متکبر بولے جس پر تم ایمان لائے ہمیں اس سے انکار ہے،\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mxxxi{پس ناقہ کی کُوچیں کاٹ دیں اور اپنے رب کے حکم سے سرکشی کی اور بولے اے صالح! ہم پر لے آؤ جس کا تم سے وعد دے رہے ہو اگر تم رسول ہو،\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mxxxii{تو انہیں زلزلے نے ا ٓلیا تو صبح کو اپنے گھروں میں اوندھے پڑے رہ گئے،\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mxxxiii{تو صالح نے ان سے منہ پھیرا اور کہا اے میری قوم! بیشک میں نے تمہیں اپنے رب کی رسالت پہنچادی اور تمہارا بھلا چاہا مگر تم خیر خواہوں کے غرضی (پسند کرنے والے) ہی نہیں،\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mxxxiv{اور لوط کو بھیجا جب اس نے اپنی قوم سے کہا کیا وہ بے حیائی کرتے ہو جو تم سے پہلے جہان میں کسی نے نہ کی،\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mxxxv{تم تو مردوں کے پاس شہوت سے جاتے ہو عورتیں چھوڑ کر، بلکہ تم لوگ حد سے گزر گئے\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mxxxvi{اور اس کی قوم کا کچھ جواب نہ تھا مگر یہی کہنا کہ ان کو اپنی بستی سے نکال دو، یہ لوگ تو پاکیزگی چاہتے ہیں\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mxxxvii{تو ہم نے اسے اور اس کے گھر والوں کو نجات دی مگر اس کی عورت وہ رہ جانے والوں میں ہوئی\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mxxxviii{اور ہم نے ان پر ایک مینھ برسایا تو دیکھو کیسا انجام ہوا مجرموں کا\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mxxxix{اور مدین کی طرف ان کی برادری سے شعیب کو بھیجا کہا اے میری قوم! اللہ کی عبادت کرو اس کے سوا تمہارا کوئی معبود نہیں، بے شک تمہارے پاس تمہارے رب کی طرف سے روشن دلیل آئی تو ناپ اور تول پوری کرو اور لوگوں کی چیزیں گھٹا کر نہ دو اور زمین میں انتظام کے بعد فساد نہ پھیلاؤ، یہ تمہارا بھلا ہے اگر ایمان لاؤ،\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mxl{اور ہر راستہ پر یوں نہ بیٹھو کہ راہگیروں کو ڈراؤ اور اللہ کی راہ سے انہیں روکو جو اس پر ایمان لائے اور اس میں کجی چاہو، اور یاد کرو جب تم تھوڑے تھے اس نے تمہیں بڑھادیا اور دیکھو فسادیوں کا کیسا انجام ہوا،\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mxli{اور اگر تم میں ایک گروہ اس پر ایمان لایا جو میں لے کر بھیجا گیا اور ایک گروہ نے نہ مانا تو ٹھہرے رہو یہاں تک کہ اللہ ہم میں فیصلہ کرے اور اللہ کا فیصلہ سب سے بہتر\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mxlii{اس کی قوم کے متکبر سردار بولے، اے شعیب قسم ہے کہ ہم تمہیں اور تمہارے ساتھ والے مسلمانوں کو اپنی بستی سے نکا ل دیں گے یا تم ہمارے دین میں ا ٓجا ؤ کہا کیا اگرچہ ہم بیزار ہوں\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mxliii{ضرور ہم اللہ پر جھوٹ باندھیں گے اگر تمہارے دین میں آجائیں بعد اس کے کہ اللہ نے ہمیں اس سے بچایا ہے اور ہم مسلمانوں میں کسی کا کام نہیں کہ تمہارے دین میں آئے مگر یہ کہ اللہ چاہے جو ہمارا رب ہے، ہمارے رب کا علم ہر چیز کو محیط ہے، اللہ ہی پر بھروسہ کیا اے ہمارے رب! ہم میں اور ہماری قوم میں حق فیصلہ کر اور تیرا فیصلہ سب سے بہتر ہے،\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mxliv{اور اسکی قوم کے کافر سردار بولے کہ اگر تم شعیب کے تابع ہوئے تو ضرور نقصان میں رہو گے،\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mxlv{تو انہیں زلز لہ نے ا ٓ لیا تو صبح اپنے گھروں میں اوندھے پڑے رہ گئے\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mxlvi{شعیب کو جھٹلانے والے گویا ان گھروں میں کبھی رہے ہی نہ تھے، شعیب کو جھٹلانے والے ہی تباہی میں پڑے،\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mxlvii{تو شعیب نے ان سے منہ پھیرا اور کہا اے میری قوم! میں تمہیں رب کی رسالت پہنچا چکا اور تمہارے بھلے کو نصیحت کی تو کیونکر غم کروں کافروں کا،\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mxlviii{اور نہ بھیجا ہم نے کسی بستی میں کوئی نبی مگر یہ کہ اس کے لوگوں کو سختی اور تکلیف میں پکڑا کہ وہ کسی طرح زاری کریں\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mxlix{پھر ہم نے برائی کی جگہ بھلائی بدل دی یہاں تک کہ وہ بہت ہوگئے اور بولے بیشک ہمارے باپ دادا کو رنج و راحت پہنچے تھے تو ہم نے انہیں اچانک ان کی غفلت میں پکڑ لیا\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@ml{اور اگر بستیو ں والے ایمان لاتے اور ڈرتے تو ضرور ہم ان پر آسمان اور زمین سے برکتیں کھول دیتے مگر انہوں نے تو جھٹلایا تو ہم نے انہیں ان کے کیے پر گرفتار کیا\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mli{کیا بستیوں والے نہیں ڈرتے کہ ان پر ہمارا عذاب رات کو آئے جب وہ سوتے ہوں\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mlii{یا بستیوں والے نہیں ڈرتے کہ ان پر ہمارا عذاب دن چڑھے آئے جب وہ کھیل رہے ہوں\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mliii{کیا اللہ کی خفی تدبیر سے بے خبر ہیں تو اللہ کی خفی تدبیر سے نذر نہیں ہوتے مگر تباہی والے\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mliv{اور کیا وہ جو زمین کے ما لکوں کے بعد اس کے وارث ہوئے انہیں اتنی ہدایت نہ ملی کہ ہم چاہیں تو انہیں ان کے گناہوں پر آ فت پہنچائیں اور ہم ان کے دلوں پر مہر کرتے ہیں کہ وہ کچھ نہیں سنتے\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mlv{یہ بستیاں ہیں جن کے احوال ہم تمہیں سناتے ہیں اور بیشک ان کے پاس ان کے رسول روشن دلیلیں لے کر آئے تو وہ اس قابل نہ ہوئے کہ وہ اس پر ایمان لاتے جسے پہلے جھٹلاچکے تھے اللہ یونہی چھاپ لگادیتا ہے کا فروں کے دلوں پر\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mlvi{اور ان میں اکثر کو ہم نے قول کا سچا نہ پایا اور ضرور ان میں اکثر کو بے حکم ہی پایا،\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mlvii{پھر ان کے بعد ہم نے موسیٰ کو اپنی نشانیوں کے ساتھ فرعون اور اس کے درباریوں کی طرف بھیجا تو انہوں نے ان نشانیوں پر زیادتی کی تو دیکھو کیسا انجام ہوا مفسدوں کا،\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mlviii{اور موسیٰ نے کہا اے فرعون! میں پرور دگا ر عالم کا رسول ہوں،\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mlix{مجھے سزاوار ہے کہ اللہ پر نہ کہوں مگر سچی بات میں تم سب کے پاس تمہارے رب کی طرف سے نشانی لےکر آیا ہوں تو بنی اسرائیل کو میرے ساتھ چھوڑ دے\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mlx{بولا اگر تم کوئی نشانی لے کر آئے ہو تو لاؤ اگر سچے ہو،\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mlxi{تو موسیٰ نے اپنا عصا ڈال دیا وہ فورا ً ایک ظاہر اژدہا ہوگیا\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mlxii{اور اپنا ہاتھ گریبان میں ڈال کر نکا لا تو وہ دیکھنے والوں کے سامنے جگمگانے لگا\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mlxiii{قوم فرعون کے سردار بولے یہ تو ایک علم والا جادوگر ہے\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mlxiv{تمہیں تمہارے ملک سے نکا لا چاہتا ہے تو تمہارا کیا مشورہ ہے،\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mlxv{بولے انہیں اور ان کے بھائی کو ٹھہرا اور شہروں میں لوگ جمع کرنے والے بھیج دے،\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mlxvi{کہ ہر علم والے جادوگر کو تیرے پاس لے آئیں\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@mlxvii{اور جادوگر فرعون کے پاس آئے بولے کچھ ہمیں انعام ملے گا اگر ہم غالب آئیں،\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@mlxviii{بولا ہاں اور اس وقت تم مقرب ہوجا ؤ گے،\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@mlxix{بولے اے موسیٰ یا تو آپ ڈالیں یا ہم ڈالنے والے ہوں\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@mlxx{کہا تمہیں ڈالو جب انہوں نے ڈالا لوگوں کی آنکھوں پر جادو کردیا اور انہیں ڈرایا اور بڑا جادو لائے،\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@mlxxi{اور ہم نے موسیٰ کو وحی فرمائی کہ اپنا عصا ڈال تو ناگاہ ان کی بناوٹوں کو نگلنے لگا\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@mlxxii{تو حق ثابت ہوا اور ان کا کام باطل ہوا،\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@mlxxiii{تو یہاں وہ مغلوب پڑے اور ذلیل ہوکر پلٹے\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@mlxxiv{اور جادوگر سجدے میں گرادیے گئے\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@mlxxv{بولے ہم ایمان لائے جہان کے رب پر،\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@mlxxvi{جو رب ہے موسیٰ اور ہارون کا،\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@mlxxvii{فرعون بولا تم اس پر ایمان لے آئے قبل اس کے کہ میں تمہیں اجازت دوں، یہ تو بڑا جعل (فریب) ہے جو تم سب نے شہر میں پھیلایا ہے کہ شہر والوں کو اس سے نکال دو تو اب جان جاؤ گے\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@mlxxviii{قسم ہے کہ میں تمہارے ایک طرف کہ ہاتھ اور دوسری طرف کے پاؤں کاٹوں گا پھر تم سب کو سُو لی دوں گا\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@mlxxix{بولے ہم اپنے رب کی طرف پھرنے والے ہیں\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@mlxxx{اور تجھے ہمارا کیا برا لگا یہی نہ کہ ہم اپنے رب کی نشانیوں پر ایمان لائے جب وہ ہمارے پاس آئیں، اے رب ہمارے! ہم پر صبر انڈیل دے اور ہمیں مسلمان اٹھا\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@mlxxxi{اور قوم فرعون کے سردار بولے کیا تو موسیٰ اور اس کی قوم کو اس لیے چھوڑ تا ہے کہ وہ زمین میں فساد پھیلائیں اور موسیٰ تجھے اور تیرے ٹھہرائے ہوئے معبودوں کو چھوڑدے بولا اب ہم ان کے بیٹوں کو قتل کریں گے اور ان کی بیٹیاں زندہ رکھیں گے اور ہم بیشک ان پر غالب ہیں\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@mlxxxii{موسیٰ نے اپنی قوم سے فرمایا اللہ کی مدد چاہو اور صبر کرو بیشک زمین کا مالک اللہ ہے اپنے بندوں میں جسے چاہے وارث بنائے اور آخر میدان پرہیزگاروں کے ہاتھ ہے\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@mlxxxiii{بولے ہم ستائے گئے آپ کے آنے سے پہلے اور آپ کے تشریف لانے کے بعد کہا قریب ہے کہ تمہارا رب تمہارے دشمن کو ہلاک کرے اور اس کی جگہ زمین کا مالک تمہیں بنائے پھر دیکھے کیسے کام کرتے ہو\qt@no{(129)}}%
\qt@newcmd\qurantrans@ur@mlxxxiv{اور بیشک ہم نے فرعون والوں کو برسوں کے قحط اور پھلوں کے گھٹانے سے پکڑا کہ کہیں وہ نصیحت مانیں\qt@no{(130)}}%
\qt@newcmd\qurantrans@ur@mlxxxv{تو جب انہیں بھلائی ملتی کہتے یہ ہمارے لیے ہے اور جب برائی پہنچتی تو موسیٰ اور اس کے ساتھ والوں سے بدشگونی لیتے سن لو ان کے نصیبہ کی شامت تو اللہ کے یہاں ہے لیکن ان میں اکثر کو خبر نہیں،\qt@no{(131)}}%
\qt@newcmd\qurantrans@ur@mlxxxvi{اور بولے تم کیسی بھی نشانی لے کر ہمارے پاس آؤ کہ ہم پر اس سے جادو کرو ہم کسی طرح تم پر ایمان لانے والے نہیں\qt@no{(132)}}%
\qt@newcmd\qurantrans@ur@mlxxxvii{تو بھیجا ہم نے ان پر طوفان اور ٹڈی اور گھن (یا کلنی یا جوئیں) اور مینڈک اور خون جدا جدا نشانیاں تو انہوں نے تکبر کیا اور وہ مجرم قوم تھی\qt@no{(133)}}%
\qt@newcmd\qurantrans@ur@mlxxxviii{اور جب ان پر عذاب پڑتا کہتے اے موسیٰ ہمارے لیے اپنے رب سے دعا کرو اس عہد کے سبب جو اس کا تمہارے پاس ہے بیشک اگر تم ہم پر عذاب اٹھادو گے تو ہم ضرور تم پر ایمان لائیں گے اور بنی اسرائیل کو تمہارے ساتھ کردیں گے،\qt@no{(134)}}%
\qt@newcmd\qurantrans@ur@mlxxxix{پھر جب ہم ان سے عذاب اٹھالیتے ایک مدت کے کیے جس تک انہیں پہنچنا ہے جبھی وہ پھر جاتے،\qt@no{(135)}}%
\qt@newcmd\qurantrans@ur@mxc{تو ہم نے ان سے بدلہ لیا تو انہیں دریا میں ڈبو دیا اس لیے کہ ہماری آیتیں جھٹلاتے اور ان سے بے خبر تھے\qt@no{(136)}}%
\qt@newcmd\qurantrans@ur@mxci{اور ہم نے اس قوم کو جو دبا لی گئی تھی اس زمین کے پورب پچھم کا وارث کیا جس میں ہم نے برکت رکھی اور تیرے رب کا اچھا وعدہ بنی اسرائیل پر پورا ہوا، بدلہ ان کے صبر کا، اور ہم نے برباد کردیا جو کچھ فرعون اور اس کی قوم بناتی اور جو چنائیاں اٹھاتے (تعمیر کرتے) تھے،\qt@no{(137)}}%
\qt@newcmd\qurantrans@ur@mxcii{اور ہم نے بنی اسرائیل کو دریا پار اتارا تو ان کا گزر ایک ایسی قوم پر ہوا کہ اپنے بتوں کے آگے آسن مارے (جم کر بیٹھے) تھے بولے اے موسیٰ! ہمیں ایک خدا بنادے جیسا ان کے لیے اتنے خدا ہیں، بولا تم ضرور جا ہل لوگ ہو،\qt@no{(138)}}%
\qt@newcmd\qurantrans@ur@mxciii{یہ حال تو بربادی کا ہے جس میں یہ لوگ ہیں اور جو کچھ کررہے ہیں نرا باطل ہے،\qt@no{(139)}}%
\qt@newcmd\qurantrans@ur@mxciv{کہا کیا اللہ کے سوا تمہارا اور کوئی خدا تلاش کروں حالانکہ اس نے تمہیں زمانے بھر پر فضیلت دی\qt@no{(140)}}%
\qt@newcmd\qurantrans@ur@mxcv{اور یاد کرو جب ہم نے تمہیں فرعون والوں سے نجات بحشی کہ تمہیں بری مار دیتے تمہارے بیٹے ذبح کرتے اور تمہاری بیٹیاں باقی رکھتے، اور اس میں رب کا بڑا فضل ہوا\qt@no{(141)}}%
\qt@newcmd\qurantrans@ur@mxcvi{اور ہم نے موسیٰ سے تیس رات کا وعدہ فرمایا اور ان میں دس اور بڑھا کر پوری کیں تو اس کے رب کا وعدہ پوری چالیس رات کا ہوا اور موسیٰ نے اپنے بھائی ہارون سے کہا میری قوم پر میرے نائب رہنا اور اصلاح کرنا اور فسادیوں کی راہ کو دخل نہ دینا،\qt@no{(142)}}%
\qt@newcmd\qurantrans@ur@mxcvii{اور جب موسیٰ ہمارے وعدہ پر حاضر ہوا اور اس سے اس کے رب نے کلام فرمایا عرض کی اے رب میرے! مجھے اپنا دیدار دکھا کہ میں تجھے دیکھوں فرمایا تو مجھے ہر گز نہ دیکھ سکے گا ہاں اس پہاڑ کی طرف دیکھ یہ اگر اپنی جگہ پر ٹھہرا رہا تو عنقریب تو مجھے دیکھ لے گا پھر جب اس کے رب نے پہاڑ پر اپنا نو ر چمکایا اسے پاش پاش کردیا اور موسیٰ گرا بیہوش پھر جب ہوش ہوا بولا پاکی ہے تجھے میں تیری طرف رجوع لایا اور میں سب سے پہلا مسلمان ہوں\qt@no{(143)}}%
\qt@newcmd\qurantrans@ur@mxcviii{فرمایا اے موسیٰ میں نے تجھے لوگوں سے چن لیا اپنی رسالتوں اور اپنے کلام سے، تو لے جو میں نے تجھے عطا فرمایا اور شکر والوں میں ہو،\qt@no{(144)}}%
\qt@newcmd\qurantrans@ur@mxcix{اور ہم نے اس کے لیے تختیوں میں لکھ دی ہر چیز کی نصیحت اور ہر چیز کی تفصیل، اور فرمایا اے موسیٰ اسے مضبوطی سے لے اور اپنی قوم کو حکم دے کر اس کی اچھی باتیں اختیار کریں عنقریب میں تمہیں دکھاؤں گا بے حکموں کا گھر\qt@no{(145)}}%
\qt@newcmd\qurantrans@ur@mc{اور میں اپنی آیتوں سے انہیں پھیردوں گا جو زمین میں ناحق اپنی بڑا ئی چاہتے ہیں اور اگر سب نشانیاں دیکھیں ان پر ایمان نہ لائیں اور اگر ہدایت کی راہ دیکھیں اس میں چلنا پسند نہ کریں اور گمراہی کا راستہ نظر پڑے تو اس میں چلنے کو موجود ہوجائیں، یہ اس لیے کہ انہوں نے ہماری آیتیں جھٹلائیں اور ان سے بے خبر بنے،\qt@no{(146)}}%
\qt@newcmd\qurantrans@ur@mci{اور جنہوں نے ہماری آیتیں اور آخرت کے دربار کو جھٹلایا ان کا سب کیا دھرا اَکارت گیا، انہیں کیا بدلہ ملے گا مگر وہی جو کرتے تھے،\qt@no{(147)}}%
\qt@newcmd\qurantrans@ur@mcii{اور موسیٰ کے بعد اس کی قوم اپنے زیوروں سے ایک بچھڑا بنا بیٹھی بے جان کا دھڑ گائے کی طرف آواز کرتا، کیا نہ دیکھا کہ وہ ان سے نہ بات کرتا ہے اور نہ انہیں کچھ راہ بتائے اسے لیا اور وہ ظالم تھے\qt@no{(148)}}%
\qt@newcmd\qurantrans@ur@mciii{اور جب پچھتائے اور سمجھے کہ ہم بہکے بولے اگر ہمارا رب ہم پر مہر ہ کرے اور ہمیں نہ بخشے تو ہم تباہ ہوئے،\qt@no{(149)}}%
\qt@newcmd\qurantrans@ur@mciv{اور جب موسیٰ اپنی قوم کی طرف پلٹا غصہ میں بھرا جھنجلایا ہوا کہا تم نے کیا بری میری جانشینی کی میرے بعد کیا تم نے اپنے رب کے حکم سے جلدی کی اور تختیاں ڈال دیں اور اپنے بھائی کے سر کے بال پکڑ کر اپنی طرف کھینچنے لگا کہا اے میرے ماں جائے قوم نے مجھے کمزور سمجھا اور قریب تھا کہ مجھے مار ڈالیں تو مجھ پر دشمنوں کو نہ ہنسا اور مجھے ظالموں میں نہ ملا\qt@no{(150)}}%
\qt@newcmd\qurantrans@ur@mcv{عرض کی اے میرے رب! مجھے اور میرے بھائی کو بخش دے اور ہمیں اپنی رحمت کے اندر لے لے اور تو سب مہر والوں سے بڑھ کر مہر والا\qt@no{(151)}}%
\qt@newcmd\qurantrans@ur@mcvi{بیشک وہ جو بچھڑا لے بیٹھے عنقریب انہیں ان کے رب کا غضب اور ذلت پہنچناہے دنیا کی زندگی میں، اور ہم ایسی ہی بدلہ دیتے ہیں بہتان ہایوں (باندھنے والوں) کو،\qt@no{(152)}}%
\qt@newcmd\qurantrans@ur@mcvii{اور جنہوں نے برائیاں کیں اور ان کے بعد توبہ کی اور ایمان لائے تو اس کے بعد تمہارا رب بخشنے والا مہربان ہے\qt@no{(153)}}%
\qt@newcmd\qurantrans@ur@mcviii{اور جب موسیٰ کا غصہ تھما تختیاں اٹھالیں اور ان کی تحریر میں ہدایت اور رحمت ہے ان کے لیے جو اپنے رب سے ڈرتے ہیں،\qt@no{(154)}}%
\qt@newcmd\qurantrans@ur@mcix{اور موسیٰ نے اپنی قوم سے سترّ ۷۰، مرد ہمارے وعدہ کے لیے چنے پھر جب انہیں زلزلہ نے لیا موسیٰ نے عرض کی اے رب میرے! تو چاہتا تو پہلے ہی انہیں اور مجھے ہلاک کردیتا کیا تو ہمیں اس کام پر ہلاک فرمائے گا جو ہمارے بے عقلوں نے کیا وہ نہیں مگر تیرا آزمانا، تو اس سے بہکائے جسے چاہے اور راہ دکھائے جسے چاہے تو ہمارا مولیٰ ہے تو ہمیں بخش دے اور ہم پر مہر کر اور تو سب سے بہتر بخشنے والا ہے،\qt@no{(155)}}%
\qt@newcmd\qurantrans@ur@mcx{اور ہمارے لیے اس دنیا میں بھلائی لکھ اور آخرت میں بیشک ہم تیری طرف رجوع لائے، فرمایا میرا عذاب میں جسے چاہوں دوں اور میری رحمت ہر چیز کو گھیرے ہے تو عنقریب میں نعمتوں کو ان کے لیے لکھ دوں گا جو ڈرتے اور زکوٰة دیتے ہیں اور وہ ہماری آیتوں پر ایمان لاتے ہیں،\qt@no{(156)}}%
\qt@newcmd\qurantrans@ur@mcxi{وہ جو غلامی کریں گے اس رسول بے پڑھے غیب کی خبریں دینے والے کی جسے لکھا ہوا پائیں گے اپنے پاس توریت اور انجیل میں وہ انہیں بھلائی کا حکم دے گا اور برائی سے منع کرے گا اور ستھری چیزیں ان کے لیے حلال فرمائے گا اور گندی چیزیں ان پر حرام کرے گا اور ان پر سے وہ بوجھ اور گلے کے پھندے جو ان پر تھے اتا رے گا، تو وہ جو اس پر ایمان لائیں اور اس کی تعظیم کریں اور اسے مدد دیں اور اس نور کی پیروی کریں جو اس کے ساتھ اترا وہی بامراد ہوئے،\qt@no{(157)}}%
\qt@newcmd\qurantrans@ur@mcxii{تم فرماؤ اے لوگو! میں تم سب کی طرف اس اللہ کا رسول ہوں کہ آسمانوں اور زمین کی بادشاہی اسی کو ہے اس کے سوا کوئی معبود نہیں جلائے اور مارے تو ایمان لاؤ اللہ اور اس کے رسول بے پڑھے غیب بتانے والے پر کہ اللہ اور اس کی باتوں پر ایمان لاتے ہیں اور ان کی غلامی کرو کہ تم راہ پاؤ،\qt@no{(158)}}%
\qt@newcmd\qurantrans@ur@mcxiii{اور موسیٰ کی قوم سے ایک گروہ ہے کہ حق کی راہ بتا تا اور اسی سے انصاف کرتا،\qt@no{(159)}}%
\qt@newcmd\qurantrans@ur@mcxiv{اور ہم نے انہیں بانٹ دیا بارہ قبیلے گروہ گروہ، اور ہم نے وحی بھیجی موسیٰ کو جب اس سے اس کی قوم نے پانی ما نگا کہ اس پتھر پر اپنا عصا مارو تو اس میں سے بارہ چشمے پھوٹ نکلے ہر گروہ نے اپنا گھاٹ پہچان لیا، اور ہم نے ان پر ابر کا سائبان کیا اور ان پر من و سلویٰ اتارا، کھاؤ ہماری دی ہوئی پاک چیزیں اور انہوں نے ہمارا کچھ نقصان نہ کیا لیکن اپنی ہی جانوں کا برا کرتے ہیں،\qt@no{(160)}}%
\qt@newcmd\qurantrans@ur@mcxv{اور یاد کرو جب ان سے فرمایا گیا اس شہر میں بسو اور اس میں جو چاہو کھاؤ اور کہو گناہ اترے اور دروازے میں سجدہ کرتے داخل ہو ہم تمہارے گناہ بخش دیں گے، عنقریب نیکوں کو زیادہ عطا فرمائیں گے،\qt@no{(161)}}%
\qt@newcmd\qurantrans@ur@mcxvi{تو ان میں کے ظالموں نے بات بدل دی اس کے خلاف جس کا انہیں حکم تھا تو ہم نے ان پر آسمان سے عذاب بھیجا بدلہ ان کے ظلم کا\qt@no{(162)}}%
\qt@newcmd\qurantrans@ur@mcxvii{اور ان سے حال پوچھو اس بستی کا کہ دریا کنارے تھی جب وہ ہفتے کے بارے میں حد سے بڑھتے جب ہفتے کے دن ان کی مچھلیاں پانی پر تیرتی ان کے سامنے آتیں اور جو دن ہفتے کا نہ ہوتا نہ آتیں اس طرح ہم انہیں آزمانتے تھے ان کی بے حکمی کے سبب،\qt@no{(163)}}%
\qt@newcmd\qurantrans@ur@mcxviii{اور جب ان میں سے ایک گروہ نے کہا کیوں نصیحت کرتے ہو ان لوگوں کو جنہیں اللہ ہلاک کرنے والا ہے یا انہیں سخت عذاب دینے والا، بولے تمہارے رب کے حضور معذرت کو اور شاید انہیں ڈر ہو\qt@no{(164)}}%
\qt@newcmd\qurantrans@ur@mcxix{پھر جب بھلا بیٹھے جو نصیحت انہیں ہوئی تھی ہم نے بچالیے وہ جو برائی سے منع کرتے تھے اور ظالموں کو برے عذاب میں پکڑا بدلہ ان کی نافرمانی کا،\qt@no{(165)}}%
\qt@newcmd\qurantrans@ur@mcxx{پھر جب انہوں نے ممانعت کے حکم سے سرکشی کی ہم نے ان سے فرمایا ہوجاؤ بند ر دھتکارے ہوئے\qt@no{(166)}}%
\qt@newcmd\qurantrans@ur@mcxxi{اور جب تمہارے رب نے حکم سنادیا کہ ضرور قیامت کے دن تک ان پر ایسے کو بھیجتا رہوں گا جو انہیں بری مار چکھائے بیشک تمہارا رب ضرور جلد عذاب والا ہے اور بیشک وہ بخشنے والا مہربان ہے\qt@no{(167)}}%
\qt@newcmd\qurantrans@ur@mcxxii{اور انہیں ہم نے زمین میں متفرق کردیا گروہ گروہ، ان میں کچھ نیک ہیں اور کچھ اور طرح کے اور ہم نے انہیں بھلائیوں اور برائیوں سے آزمایا کہ کہیں وہ رجوع لائیں\qt@no{(168)}}%
\qt@newcmd\qurantrans@ur@mcxxiii{پھر ان کی جگہ ان کے بعد وہ ناخلف آئے کہ کتاب کے وارث ہوئے اس دنیا کا مال لیتے ہیں اور کہتے اب ہماری بخشش ہوگی اور اگر ویسا ہی مال ان کے پاس اور آئے تو لے لیں کیا ان پر کتاب میں عہد نہ لیا گیا کہ اللہ کی طرف نسبت نہ کریں مگر حق اور انہوں نے اسے پڑھا اور بیشک پچھلا گھر بہتر ہے پرہیزگاروں کو تو کیا تمہیں عقل نہیں،\qt@no{(169)}}%
\qt@newcmd\qurantrans@ur@mcxxiv{اور وہ جو کتاب کو مضبوط تھامتے ہیں اور انہوں نے نماز قائم رکھی، ہم نیکوں کا نیگ (اجر) نہیں گنواتے،\qt@no{(170)}}%
\qt@newcmd\qurantrans@ur@mcxxv{اور جب ہم نے پہاڑ ان پر اٹھایا گویا وہ سائبان ہے اور سمجھے کہ وہ ان پر گر پڑے گا تو جو ہم نے تمہیں دیا زور سے اور یاد کرو جو اس میں ہے کہ کہیں تم پرہیزگار ہو،\qt@no{(171)}}%
\qt@newcmd\qurantrans@ur@mcxxvi{اور اے محبوب! یاد کرو جب تمہارے رب نے اولاد آدم کی پشت سے ان کی نسل نکالی اور انہیں خود ان پر گواہ کیا، کیا میں تمہارا رب نہیں سب بولے کیوں نہیں ہم گواہ ہوئے کہ کہیں قیامت کے دن کہو کہ ہمیں اس کی خبر نہ تھی\qt@no{(172)}}%
\qt@newcmd\qurantrans@ur@mcxxvii{یا کہو کہ شرک تو پہلے ہمارے باپ دادا نے کیا اور ہم ان کے بعد بچے ہوئے تو کیا تو ہمیں اس پر ہلاک فرمائے گا جو اہل باطل نے کیا\qt@no{(173)}}%
\qt@newcmd\qurantrans@ur@mcxxviii{اور ہم اسی طرح آیتیں رنگ رنگ سے بیان کرتے ہیں اور اس لیے کہ کہیں وہ پھر آئیں\qt@no{(174)}}%
\qt@newcmd\qurantrans@ur@mcxxix{اور اے محبوب! انہیں اس کا احوال سناؤ جسے ہم نے اپنی آیتیں دیں تو وہ ان سے صاف نکل گیا تو شیطان اس کے پیچھے لگا تو گمراہوں میں ہوگیا،\qt@no{(175)}}%
\qt@newcmd\qurantrans@ur@mcxxx{اور ہم چاہتے تو آیتوں کے سبب اسے اٹھالیتے مگر وہ تو زمین پکڑ گیا اور اپنی خواہش کا تابع ہوا تو اس کا حال کتے کی طرح ہے تو اس پر حملہ کرے تو زبان نکالے اور چھوڑ دے تو زبان نکالے یہ حال ہے ان کا جنہوں نے ہماری آیتیں جھٹلائیں تو تم نصیحت سناؤ کہ کہیں وہ دھیان کریں،\qt@no{(176)}}%
\qt@newcmd\qurantrans@ur@mcxxxi{کیا بری کہاوت ہے ان کی جنہوں نے ہماری آیتیں جھٹلائیں اور اپنی ہی جان کا برا کرتے تھے،\qt@no{(177)}}%
\qt@newcmd\qurantrans@ur@mcxxxii{جسے اللہ راہ دکھائے تو وہی راہ پر ہے، اور جسے گمراہ کرے تو وہی نقصان میں رہے،\qt@no{(178)}}%
\qt@newcmd\qurantrans@ur@mcxxxiii{اور بیشک ہم نے جہنم کے لیے پیدا کیے بہت جن اور آدمی اور دل رکھتے ہیں جن میں سمجھ نہیں اور وہ آنکھیں جن سے دیکھتے نہیں اور وہ کان جن سے سنتے نہیں وہ چوپایوں کی طرح ہیں بلکہ ان سے بڑھ کر گمراہ وہی غفلت میں پڑے ہیں،\qt@no{(179)}}%
\qt@newcmd\qurantrans@ur@mcxxxiv{اور اللہ ہی کے ہیں بہت اچھے نام تو اسے ان سے پکارو اور انہیں چھوڑ دو جو اس کے ناموں میں حق سے نکلتے ہیں وہ جلد اپنا کیا پائیں گے،\qt@no{(180)}}%
\qt@newcmd\qurantrans@ur@mcxxxv{اور ہمارے بنائے ہوؤں میں ایک گروہ وہ ہے کہ حق بتائیں اور اس پر انصاف کریں\qt@no{(181)}}%
\qt@newcmd\qurantrans@ur@mcxxxvi{اور جنہوں نے ہماری آیتیں جھٹلائیں جلد ہم انہیں آہستہ آہستہ عذاب کی طرف لے جائیں گے جہاں سے انہیں خبر نہ ہوگی\qt@no{(182)}}%
\qt@newcmd\qurantrans@ur@mcxxxvii{اور میں انہیں ڈھیل دوں گا بیشک میری خفیہ تدبیر بہت پکی ہے\qt@no{(183)}}%
\qt@newcmd\qurantrans@ur@mcxxxviii{کیا سوچتے نہیں کہ ان کے صاحب کو جنوں سے کچھ علاقہ نہیں، وہ تو صا ف ڈر سنانے والے ہیں\qt@no{(184)}}%
\qt@newcmd\qurantrans@ur@mcxxxix{کیا انہو ں نے نگاہ نہ کی آسمانوں اور زمین کی سلطنت میں اور جو جو چیز اللہ نے بنائی اور یہ کہ شاید ان کا وعدہ نزدیک آگیا ہو تو اس کے بعد اور کونسی بات پر یقین لائیں گے\qt@no{(185)}}%
\qt@newcmd\qurantrans@ur@mcxl{جسے اللہ گمراہ کرے اسے کوئی راہ دکھانے والا نہیں اور انہیں چھوڑتا ہے کہ اپنی سرکشی میں بھٹکا کریں،\qt@no{(186)}}%
\qt@newcmd\qurantrans@ur@mcxli{تم سے قیامت کو پوچھتے ہیں کہ وہ کب کو ٹھہری ہے تم فرماؤ اس کا علم تو میرے رب کے پاس ہے، اسے وہی اس کے وقت پر ظاہر کرے گا بھاری پڑ رہی ہے آسمانوں او رزمین میں، تم پر نہ آئے گی مگر اچانک، تم سے ایسا پوچھتے ہیں گویا تم نے اسے خوب تحقیق کر رکھا ہے، تم فرماؤ اس کا علم تو اللہ ہی کے اس ہے لیکن بہت لوگ جانتے نہیں\qt@no{(187)}}%
\qt@newcmd\qurantrans@ur@mcxlii{تم فرماؤ میں اپنی جان کے بھلے برے کا خودمختار نہیں مگر جو اللہ چاہے اور اگر میں غیب جان لیا کرتا تو یوں ہوتا کہ میں نے بہت بھلائی جمع کرلی، اور مجھے کوئی برائی نہ پہنچی میں تو یہی ڈر اور خوشی سنانے والا ہوں انہیں جو ایمان رکھتے ہیں،\qt@no{(188)}}%
\qt@newcmd\qurantrans@ur@mcxliii{وہی ہے جس نے تمہیں ایک جان سے پیدا کیا اور اسی میں سے اس کا جوڑا بنایا کہ اس سے چین پائے پھر جب مرد اس پر چھایا اسے ایک ہلکا سا پیٹ رہ گیا تو اسے لیے پھراکی پھر جب بوجھل پڑی دونوں نے اپنے رب سے دعا کی ضرور اگر تو ہمیں جیسا چاہیے بچہ دے گا تو بیشک ہم شکر گزار ہوں گے،\qt@no{(189)}}%
\qt@newcmd\qurantrans@ur@mcxliv{پھر جب اس نے انہیں جیسا چاہیے بچہ عطا فرمایا انہوں نے اس کی عطا میں اس کے ساجھی ٹھہرائے تو اللہ کو برتری ہے ان کے شرک سے\qt@no{(190)}}%
\qt@newcmd\qurantrans@ur@mcxlv{کیا اسے شریک کرتے ہیں جو کچھ نہ بنائے اور وہ خود بنائے ہوئے ہیں،\qt@no{(191)}}%
\qt@newcmd\qurantrans@ur@mcxlvi{اور نہ وہ ان کو کوئی مدد پہنچاسکیں اور نہ اپنی جانو ں کی مدد کریں\qt@no{(192)}}%
\qt@newcmd\qurantrans@ur@mcxlvii{اور اگر تم انہیں راہ کی طرف بلاؤ تو تمہارے پیچھے نہ آئیں تم پر ایک سا ہے چاہے انہیں پکارو یا چپ رہو\qt@no{(193)}}%
\qt@newcmd\qurantrans@ur@mcxlviii{بیشک وہ جن کو تم اللہ کے سوا پوجتے ہو تمہاری طرح بندے ہیں تو انہیں پکارو پھر وہ تمہیں جواب دیں اگر تم سچے ہو،\qt@no{(194)}}%
\qt@newcmd\qurantrans@ur@mcxlix{کیا ان کے پاؤں ہیں جن سے چلیں یا ان کے ہاتھ ہیں جن سے گرفت کریں یا ان کے آنکھیں ہیں جن سے دیکھیں یا ان کے کان ہیں جن سے سنیں تم فرماؤ کہ اپنے شریکوں کو پکارو اور مجھ پر داؤ چلو اور مجھے مہلت نہ دو\qt@no{(195)}}%
\qt@newcmd\qurantrans@ur@mcl{بیشک میرا والی اللہ ہے جس نے کتاب ا تاری اور وہ نیکوں کو دوست رکھتا ہے\qt@no{(196)}}%
\qt@newcmd\qurantrans@ur@mcli{اور جنہیں اس کے سوا پوجتے ہو وہ تمہاری مدد نہیں کرسکتے، اور نہ خود اپنی مدد کریں\qt@no{(197)}}%
\qt@newcmd\qurantrans@ur@mclii{اور اگر تم انہیں راہ کی طرف بلاؤ تو نہ سنیں اور تو انہیں دیکھے کہ وہ تیری طرف دیکھ رہے ہیں اور انہیں کچھ بھی نہیں سوجھتا،\qt@no{(198)}}%
\qt@newcmd\qurantrans@ur@mcliii{اے محبوب! معاف کرنا اختیار کرو اور بھلائی کا حکم دو اور جاہلوں سے منہ پھیرلو،\qt@no{(199)}}%
\qt@newcmd\qurantrans@ur@mcliv{اور اے سننے والے اگر شیطان تجھے کوئی کونچا دے (کسی برے کام پر اکسائے) تو اللہ کی پناہ مانگ بیشک وہی سنتا جانتا ہے،\qt@no{(200)}}%
\qt@newcmd\qurantrans@ur@mclv{بیشک وہ جو ڈر والے ہیں جب انہیں کسی شیطانی خیال کی ٹھیس لگتی ہے ہوشیار ہوجاتے ہیں اسی وقت ان کی آنکھیں کھل جاتی ہیں\qt@no{(201)}}%
\qt@newcmd\qurantrans@ur@mclvi{اور وہ جو شیطانوں کے بھائی ہیں شیطان انہیں گمراہی میں کھینچتے ہیں پھر کمی نہیں کرتے،\qt@no{(202)}}%
\qt@newcmd\qurantrans@ur@mclvii{اور اے محبوب! جب تم ان کے پاس کوئی آیت نہ لاؤ تو کہتے ہیں تم نے دل سے کیوں نہ بنائی تم فرما ؤ میں تو اسی کی پیروی کرتا ہوں جو میری طرف میرے رب سے وحی ہوتی ہے یہ تمہارے رب کی طرف سے آنکھیں کھولنا ہے اور ہدایت اور رحمت مسلمانوں کے لیے،\qt@no{(203)}}%
\qt@newcmd\qurantrans@ur@mclviii{اور جب قرآن پڑھا جائے تو اسے کان لگا کر سنو اور خاموش رہو کہ تم پر رحم ہو\qt@no{(204)}}%
\qt@newcmd\qurantrans@ur@mclix{اور اپنے رب کو اپن ے دل میں یاد کرو زاری اور ڈر سے اور بے آواز نکلے زبان سے صبح اور شام اور غافلوں میں نہ ہونا،\qt@no{(205)}}%
\qt@newcmd\qurantrans@ur@mclx{بیشک وہ جو تیرے رب کے پاس ہیں اس کی عبادت سے تکبر نہیں کرتے اور اس کی پاکی بولتے اور اسی کو سجدہ کرتے ہیں السجدة ۔۵\qt@no{(206)}}%
\qt@newcmd\qurantrans@ur@mclxi{\basmalahur اے محبوب! تم سے غنیمتوں کو پوچھتے ہیں تم فرماؤ غنیمتوں کے مالک اللہ اور رسول ہیں تو اللہ ڈرو اور اپنے آ پس میں میل (صلح صفائی) رکھو اور اللہ اور رسول کا حکم مانو اگر ایمان رکھتے ہو،\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mclxii{ایمان والے وہی ہیں کہ جب اللہ یاد کیا جائے ان کے دل ڈر جائیں اور جب ان پر اس کی آیتیں پڑھی جائیں ان کا ایمان ترقی پائے اور اپنے رب ہی پر بھروسہ کریں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mclxiii{وہ جو نماز قائم رکھیں اور ہمارے دیے سے کچھ ہماری راہ میں خرچ کریں،\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mclxiv{یہی سچے مسلمان ہیں، ان کے لیے درجے ہیں ان کے رب کے پاس اور بخشش ہے اور عزت کی روزی\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mclxv{جس طرح اے محبوب! تمہیں تمہارے رب نے تمہارے گھر سے حق کے ساتھ برآمد کیا اور بیشک مسلمانوں کا ایک گروہ اس پر ناخوش تھا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mclxvi{سچی بات میں تم سے جھگڑتے تھے بعد اس کے کہ ظاہر ہوچکی گویا وہ آنکھوں دیکھی موت کی طرف ہانکے جاتے ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mclxvii{اور یاد کرو جب اللہ نے تمہیں وعدہ دیا تھا کہ ان دونوں گروہوں میں ایک تمہارے لیے ہے اور تم یہ چاہتے تھے کہ تمہیں وہ ملے جس میں کانٹے کا کھٹکا نہیں (کوئی نقصان نہ ہو) اور اللہ یہ چاہتا تھا کہ اپنے کلام سے سچ کو سچ کر دکھائے اور کافروں کی جڑ کا ٹ دے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mclxviii{کہ سچ کو سچ کرے اور جھوٹ کو جھوٹا پڑے برا مانیں مجرم،\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mclxix{جب تم اپنے رب سے فریا د کرتے تھے تو اس نے تمہاری سن لی کہ میں تمہیں مدد دینے والا ہوں ہزاروں فرشتوں کی قطار سے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mclxx{اور یہ تو اللہ نے کیا مگر تمہاری خوشی کو اور اس لیے کہ تمہارے دل چین پائیں، اور مدد نہیں مگر اللہ کی طرف سے بیشک اللہ غالب حکمت والا ہے،\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mclxxi{جب اس نے تمہیں اونگھ سے گھیر دیا تو اس کی طرف سے چین (تسکین) تھی اور آسمان سے تم پر پانی اتارا کہ تمہیں اس سے ستھرا کردے اور شیطان کی ناپاکی تم سے دور فرمادے اور تمہارے دلو ں کی ڈھارس بندھائے اور اس سے تمہارے قدم جمادے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mclxxii{جب اے محبوب! تمہارا رب فرشتوں کو وحی بھیجتا تھا کہ میں تمہارے ساتھ ہوں تم مسلمانوں کو ثابت رکھو عنقریب میں کافروں کے دلوں میں ہیبت ڈالوں گا تو کافروں کی گردنوں سے اوپر مارو اور ان کی ایک ایک پور (جوڑ) پر ضرب لگا ؤ\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mclxxiii{یہ اس لیے کہ انہوں نے اللہ اور اس کے رسول سے مخا لفت کی اور جو اللہ اور اس کے رسول سے مخالفت کرے تو بیشک اللہ کا عذاب سخت ہے،\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mclxxiv{یہ تو چکھو اور اس کے ساتھ یہ ہے کہ کافروں کو آ گ کا عذاب ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mclxxv{اے ایمان والو! جب کافروں کے لام (لشکر) سے تمہارا مقابلہ ہو تو انہیں پیٹھ نہ دو\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mclxxvi{اور جو اس دن انہیں پیٹھ دے گا مگر لڑائی کا ہنرَ کرنے یا اپنی جماعت میں جاملنے کو، تو وہ اللہ کے غضب میں پلٹا اور اس کا ٹھکانا دوزخ ہے، اور کیا بری جگہ ہے پلٹنے کی،\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mclxxvii{تو تم نے انہیں قتل نہ کیا بلکہ اللہ نے انہیں قتل کیا، اور اے محبوب! وہ خاک جو تم نے پھینکی تھی بلکہ اللہ نے پھینکی اور اس لیے کہ مسلمانوں کو اس سے اچھا انعام عطا فرمائے، بیشک اللہ سنتا جانتا ہے،\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mclxxviii{یہ تو لو اور اس کے ساتھ یہ ہے کہ اللہ کافروں کا داؤ سست کرنے والا ہے،\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mclxxix{اے کافرو! اگر تم فیصلہ مانگتے ہو تو یہ فیصلہ تم پر آچکا اور اگر با ز ا ٓ ؤ تو تمہارا بھلا ہے اور اگر تم پھر شرارت کرو تو ہم پھر نہ دیں گے اور تمہارا جتھا تمہیں کچھ کام نہ دے گا چاہے کتنا ہی بہت ہو اور اس کے ساتھ یہ ہے کہ اللہ مسلمانوں کے ساتھ ہے،\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mclxxx{اے ایمان والو! اللہ اور اس کے رسول کا حکم مانو اور سن سنا کہ اسے نہ پھرو،\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mclxxxi{اور ان جیسے نہ ہونا جنہوں نے کہا ہم نے سنا او ر وہ نہیں سنتے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mclxxxii{بیشک سب جانوروں میں بدتر اللہ کے نزدیک وہ ہیں جو بہرے گونگے ہیں جن کو عقل نہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mclxxxiii{اور اگر اللہ ان میں کچھ بھلائی جانتا تو انہیں سنادیتا اور اگر سنا دیتا جب بھی انجام کا ر منہ پھیر کر پلٹ جاتے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mclxxxiv{اے ایمان والو! اللہ اور اس کے رسول کے بلانے پر حاضر ہو جب رسول تمہیں اس چیز کے لیے بلائیں جو تمہیں زندگی بخشے گی اور جان لو کہ اللہ کا حکم آدمی اور اس کے دلی ارادوں میں حائل ہوجا تا ہے اور یہ کہ تمہیں اس کی طرف اٹھنا ہے،\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mclxxxv{اور اس فتنہ سے ڈرتے رہو جو ہرگز تم میں خاص ظالموں کو ہی نہ پہنچے گا اور جان لو کہ اللہ کا عذاب سخت ہے،\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mclxxxvi{اور یاد کرو جب تم تھوڑے تھے ملک میں دبے ہوئے ڈرتے تھے کہ کہیں لوگ تمہیں اچک نہ لے جائیں تو اس نے تمہیں جگہ دی اور اپنی مدد سے زور دیا اور ستھری چیزیں تمہیں روزی دیں کہ کہیں تم احسان مانو،\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mclxxxvii{اے ایمان والو! اللہ اور رسول سے دغا نہ کرو اور نہ اپنی امانتوں میں دانستہ خیانت،\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mclxxxviii{اور جان رکھو کہ تمہارے مال اور تمہاری اولاد سب فتنہ ہے اور اللہ کے پاس بڑا ثواب ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mclxxxix{اے ایمان والو! اگر اللہ سے ڈرو گے تو تمہیں وہ دیگا جس سے حق کو باطل سے جدا کرلو اور تمہاری برائیاں اتار دے گا اور تمہیں بخش دے گا اور اللہ بڑے فضل والا ہے،\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mcxc{اور اے محبوب یاد کرو جب کافر تمہارے ساتھ مکر کرتے تھے کہ تمہیں بند کرلیں یا شہید کردیں یا نکا ل دیں اپنا سا مکر کرتے تھے اور اللہ اپنی خفیہ تدبیر فرماتا تھا اور اللہ کی خفیہ تدبیر سب سے بہتر،\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mcxci{اور جب ان پر ہماری آیتیں پڑھی جائیں تو کہتے ہیں ہاں ہم نے سنا ہم چاہتے تو ایسی ہم بھی کہہ دیتے یہ تو نہیں مگر اگلوں کے قصے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mcxcii{اور جب بولے کہ اے اللہ اگر یہی (قرآن) تیری طرف سے حق ہے تو ہم پر آسمان سے پتھر برسا یا کوئی دردناک عذاب ہم پر لا،\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mcxciii{اور اللہ کا کام نہیں کہ انہیں عذاب کرے جب تک اے محبوب! تم ان میں تشریف فرما ہو اور اللہ انہیں عذاب کرنے والا نہیں جب تک وہ بخشش مانگ رہے ہیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mcxciv{اور انہیں کیا ہے کہ اللہ انہیں عذاب نہ کرے وہ تو مسجد حرام سے روک رہے ہیں اور وہ اس کے اہل نہیں اس کے اولیاء تو پرہیزگار ہی ہیں مگر ان میں اکثر کو علم نہیں،\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mcxcv{اور کعبہ کے پاس ان کی نماز نہیں مگر سیٹی اور تالی تو اب عذاب چکھو بدلہ اپنے کفر کا،\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mcxcvi{بیشک کافر اپنے مال خرچ کرتے ہیں کہ اللہ کی راہ سے روکیں تو اب انہیں خرچ کریں گے پھر وہ ان پر پچھتاوا ہوں گے پھر مغلوب کردیے جائیں گے اور کافروں کا حشر جہنم کی طرف ہوگا،\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mcxcvii{اس لیے کہ اللہ گندے کو ستھرے سے جدا فرمادے اور نجاستوں کو تلے اوپر رکھ کر سب ایک ڈھیر بناکر جہنم میں ڈال دے وہی نقصان پانے والے ہیں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mcxcviii{تم کافروں سے فرماؤ اگر وہ باز رہے تو جو ہو گزرا وہ انہیں معاف فرمادیا جائے گا اور اگر پھر وہی کریں تو اگلوں کا دستور گزر چکا ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mcxcix{اور اگر ان سے لڑو یہاں تک کہ کوئی فساد باقی نہ رہے اور سارا دین اللہ ہی کا ہوجائے، اگر پھر وہ باز رہیں تو اللہ ان کے کام دیکھ رہا ہے،\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mcc{اور اگر وہ پھریں تو جان لو کہ اللہ تمہارا مولیٰ ہے تو کیا ہی اچھا مولیٰ اور کیا ہی اچھا مددگار،\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mcci{اور جان لو کہ جو کچھ غنیمت لو تو اس کا پانچواں حصہ خاص اللہ اور رسول و قرابت داروں اور یتیموں اور محتاجوں اور مسافروں کا ہے اگر تم ایمان لائے ہو اللہ پر اور اس پر جو ہم نے اپنے بندے پر فیصلہ کے دن اتارا جس دن دونوں فوجیں ملیں تھیں اور اللہ سب کچھ کرسکتا ہے،\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mccii{جب تم نالے کے کنا رے تھے اور کافر پرلے کنا رے اور قا فلہ تم سے ترائی میں اور اگر تم آپس میں کوئی وعدہ کرتے تو ضرور وقت پر برابر نہ پہنچتے لیکن یہ اس لیے کہ اللہ پورا کرے جو کام ہونا ہے کہ جو ہلاک ہو دلیل سے ہلاک ہو اور جو جئے دلیل سے جئے اور بیشک اللہ ضرور سنتا جانتا ہے،\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mcciii{جب کہ اے محبوب! اللہ ٹمہیں کافروں کو تمہاری خواب میں تھو ڑا دکھاتا تھا اور اے مسلمانو! اگر وہ تمہیں بہت کرکے دکھاتا تو ضرور تم بزدلی کرتے اور معاملہ میں جھگڑا ڈالتے مگر اللہ نے بچا لیا بیشک وہ دلوں کی بات جانتا ہے،\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mcciv{او ر جب لڑتے وقت تمہیں کا فر تھو ڑے کرکے دکھائے اور تمہیں ان کی نگاہوں میں تھو ڑا کیا کہ اللہ پو را کرے جو کام ہونا ہے اور اللہ کی طرف سب کاموں کی رجوع ہے،\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mccv{اے ایمان والو! جب کسی فوج سے تمہارا مقابلہ ہو تو ثابت قدم رہو اور اللہ کی یاد بہت کرو کہ تم مراد کو پہنچو،\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mccvi{اور اللہ اور اس کے رسول کا حکم مانو اور آپس میں جھگڑ و نہیں کہ پھر بز د لی کرو گے اور تمہاری بندھی ہوئی ہوا جاتی رہے گی اور صبر کرو، بیشک اللہ صبر والوں کے ساتھ ہے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mccvii{اور ان جیسے نہ ہوتا جو اپنے گھر سے نکلے اتراتے اور لوگوں کے دکھانے کو اور اللہ کی راہ سے روکتے اور ان کے سب کام اللہ کے قابو میں ہیں،\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mccviii{اور جبکہ شیطان نے ان کی نگاہ میں ان کے کام بھلے کر دکھائے اور بولا آج تم پر کوئی شخص غالب آنے والا نہیں اور تم میری پناہ میں ہو تو جب دونوں لشکر آمنے سامنے ہوئے الٹے پاؤں بھاگا اور بولا میں تم سے الگ ہوں میں وہ دیکھتا ہوں جو تمہیں نظر نہیں آتا میں اللہ سے ڈرتا ہوں اور اللہ کا عذاب سخت ہے،\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mccix{جب کہتے تھے منافق اور وہ جن کے دلوں میں ا ٓزا ر ہے کہ یہ مسلمان اپنے دین پر مغرور ہیں اور جو اللہ پر بھروسہ کرے تو بیشک اللہ غالب حکمت والا ہے،\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mccx{اور کبھی تو دیکھے جب فرشتے کافروں کی جان نکالتے ہیں مار رہے ہیں ان کے منہ پر او ر ان کی پیٹھ پر اور چکھو آ گ کا عذاب،\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mccxi{یہ بدلہ ہے اس کا جو تمہارے ہاتھوں نے آگے بھیجا اور اللہ بندوں پر ظلم نہیں کرتا\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mccxii{جیسے فرعون والوں اور ان سے اگلوں کا دستور وہ اللہ کی آیتوں کے منکر ہوئے تو اللہ نے انہیں ان کے گناہوں پر پکڑا بیشک اللہ قوت والا سخت عذاب و ا لا ہے،\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mccxiii{یہ اس لیے کہ اللہ کسی قوم سے جو نعمت انہیں دی تھی بدلتا نہیں جب تک وہ خود نہ بدل جائیں اور بیشک اللہ سنتا جانتا ہے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mccxiv{جیسے فرعون والوں اور ان سے اگلوں کا دستور، انہوں نے اپنے رب کی آیتیں جھٹلائیں تو ہم نے ان کو ان کے گناہوں کے سبب ہلاک کیا اور ہم نے فرعون والوں کو ڈبو دیا اور وہ سب ظالم تھے،\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mccxv{بیشک سب جانوروں (کا فر و ں) میں بدتر اللہ کے نزدیک وہ ہیں جنہوں نے کفر کیا اور ایمان نہیں لاتے،\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mccxvi{وہ جن سے تم نے معاہدہ کیا تھا پھر ہر با ر اپنا عہد توڑ دیتے ہیں اور ڈرتے نہیں\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mccxvii{تو اگر تم انہیں کہیں لڑائی میں پا ؤ تو انہیں ایسا قتل کرو جس سے ان کے پس ماندوں کو بھگاؤ اس امید پر کہ شاید انہیں عبرت ہو\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mccxviii{اور اگر تم کسی قوم سے دغا کا اندیشہ کرو تو ان کا عہد ان کی طرف پھینک دو برابری پر بیشک دغا والے اللہ کو پسند نہیں،\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mccxix{اور ہرگز کا فر اس گھمنڈ میں نہ رہیں کہ وہ ہاتھ سے نکل گئے بیشک وہ عاجز نہیں کرتے\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mccxx{اور ان کے لیے تیار رکھو جو قوت تمہیں بن پڑے اور جتنے گھوڑے باندھ سکو کہ ان سے ان کے دلوں میں دھاک بٹھاؤ جو اللہ کے دشمن ہیں اور ان کے سوا کچھ اوروں کے دلوں میں جنہیں تم نہیں جانتے اللہ انہیں جانتا ہے اور اللہ کی راہ میں جو کچھ خرچ کرو گے تمہیں پورا دیا جائے گا اور کسی طرح گھاٹے میں نہ رہو گے،\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mccxxi{اور اگر وہ صلح کی طرف جھکیں تو تم بھی جھکو اور اللہ پر بھروسہ رکھو، بیشک وہی ہے سنتا جانتا،\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mccxxii{اور اگر وہ تمہیں فریب دیا چاہیں تو بیشک اللہ تمہیں کافی ہے، وہی ہے جس نے تمہیں زور دیا اپنی مدد کا اور مسلمانوں کا،\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mccxxiii{اور ان کے دلوں میں میل کردیا اگر تم زمین میں جو کچھ ہے سب خرچ کردیتے ان کے دل نہ ملا سکتے لیکن اللہ نے ان کے دل ملادیئے، بیشک وہی ہے غالب حکمت والا،\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mccxxiv{اے غیب کی خبریں بتانے والے (نبی) اللہ تمہیں کافی ہے اور یہ جتنے مسلمان تمہارے پیرو ہوئے،\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mccxxv{اے غیب کی خبریں بتانے والے! مسلمانوں کو جہاد کی ترغیب دو اگر تم میں کے بیس صبر والے ہوں گے دو سو پر غالب ہوں گے اور اگر تم میں کے سو ہوں تو کافروں کے ہزا ر پر غالب آئیں گے اس لیے کہ وہ سمجھ نہیں رکھتے،\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mccxxvi{اب اللہ نے تم پر سے تخفیف فرمائی اور اسے علم کہ تم کمزو ر ہو تو اگر تم میں سو صبر والے ہوں د و سو پر غالب آئیں گے اور اگر تم میں کے ہزار ہوں تو دو ہزار پر غالب ہوں گے اللہ کے حکم سے اور اللہ صبر والوں کے ساتھ ہے،\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mccxxvii{کسی نبی کو لائئق نہیں کہ کافروں کو زندہ قید کرلے جب تک زمین میں ان کا خون خوب نہ بہائے تم لوگ دنیا کا مال چا ہتے ہو او ر اللہ آخرت چاہتا ہے اور اللہ غالب حکمت والا ہے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mccxxviii{اگراللہ پہلے ایک بات لکھ نہ چکا ہوتا تو اے مسلمانو! تم نے جو کافروں سے بدلے کا مال لے لیا اس میں تم پر بڑا عذاب آتا،\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mccxxix{تو کھاؤ جو غنیمت تمہیں ملی حلال پاکیزہ اور اللہ سے ڈرتے رہو بیشک اللہ بخشنے والا مہربان ہے،\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mccxxx{اے غیب کی خبریں بتانے والے جو قیدی تمہارے ہاتھ میں ہیں ان سے فرماؤ اگر اللہ نے تمہارے دل میں بھلائی جانی تو جو تم سے لیا گیا اس سے بہتر تمہیں عطا فرمائے گا اور تمہیں بخش دے گا اور اللہ بخشنے والا مہربان ہے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mccxxxi{اور اے محبوب اگر وہ تم سے دغا چاہیں گے تو اس سے پہلے اللہ ہی کی خیانت کرچکے ہیں جس پر اس نے اتنے تمہارے قابو میں دے دیے اور اللہ جاننے والا حکمت والا ہے،\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mccxxxii{بیشک جو ایمان لائے اور اللہ کے لیے گھر بار چھوڑے اور اللہ کی راہ میں اپنے مالوں اور جانوں سے لڑے اور وہ جنہوں نے جگہ دی اور مدد کی وہ ایک دوسرے کے وارث ہیں اور وہ جو ایمان لائے اور ہجرت نہ کی انہیں ان کا ترکہ کچھ نہیں پہنچتا جب تک ہجرت نہ کریں اور اگر وہ دین میں تم سے مدد چاہیں تو تم پر مدد دینا واجب ہے مگر ایسی قوم پر کہ تم میں ان میں معاہدہ ہے، اور اللہ تمہارے کام دیکھ رہا ہے،\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mccxxxiii{اور کافر ا ٓ پس میں ایک دوسرے کے وارث ہیں ایسا نہ کرو گے تو زمین میں فتنہ اور بڑا فساد ہوگا\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mccxxxiv{اور وہ جو ایمان لائے اور ہجرت کی اور اللہ کی راہ میں لڑے اور جنہوں نے جگہ دی اور مدد کی وہی سچے ایمان والے ہیں، ان کے لیے بخشش ہے اور عزت کی روزی\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mccxxxv{اور جو بعد کو ایمان لائے اور ہجرت کی اور تمہارے ساتھ جہاد کیا وہ بھی تمہیں میں سے ہیں اور رشتہ والے ایک دوسرے سے زیادہ نزدیک ہیں اللہ کی کتاب میں بیشک اللہ سب کچھ جانتا ہے،\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mccxxxvi{\basmalahur بیزاری کا حکم سنانا ہے اللہ اور اس کے رسول کی طرف سے ان مشرکوں کو جن سے تمہارا معاہدہ تھا اور وہ قائم نہ رہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mccxxxvii{تو چا ر مہینے زمین پر چلو پھرو اور جان رکھو کہ تم اللہ کو تھکا نہیں سکتے اور یہ کہ اللہ کافروں کو رسوا کرنے والا ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mccxxxviii{اور منادی پکار دیتا اللہ اور اس کے رسول کی طرف سے سب لوگوں میں بڑے حج کے دن کہ اللہ بیزار ہے، مشرکوں سے اور اس کا رسول تو اگر تم توبہ کرو تو تمہا را بھلا ہے اور اگر منہ پھیرو تو جان لو کہ اللہ کو نہ تھکا سکو گے اور کافروں کو خوشخبری سناؤ دردناک عذاب کی،\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mccxxxix{مگر وہ مشرک جن سے تمہارہ معاہدہ تھا پھر انہوں نے تمہارے عہد میں کچھ کمی نہیں کی اور تمہارے مقابل کسی کو مدد نہ دی تو ان کا عہد ٹھہری ہوئی مدت تک پورا کرو، بیشک اللہ پرہیزگاروں کو دوست رکھتا ہے،\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mccxl{پھر جب حرمت والے مہینے نکل جائیں تو مشرکوں کو مارو جہاں پا ؤ اور انہیں پکڑو اور قید کرو اور ہر جگہ ان کی تاک میں بیٹھو پھر اگر وہ توبہ کریں اور نماز قائم رکھیں اور زکوٰة دیں تو ان کی راہ چھوڑ دو بیشک اللہ بخشنے والا مہربان ہے،\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mccxli{اور اے محبوب اگر کوئی مشرک تم سے پناہ مانگے تو اسے پناہ دو کہ وہ اللہ کا کلام سنے پھر اسے اس کی امن کی جگہ پہنچا دو یہ اس لیے کہ وہ نادان لوگ ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mccxlii{مشرکوں کے لیے اللہ اور اس کے رسول کے پاس کوئی عہد کیونکر ہوگا مگر وہ جن سے تمہارا معاہدہ مسجد حرام کے پاس ہوا تو جب تک وہ تمہارے لیے عہد پر قائم رہیں تم ان کے لیے قائم رہو، بیشک پرہیزگار اللہ کو خوش آتے ہیں،\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mccxliii{بھلا کیونکر ان کا حال تو یہ ہے کہ تم پر قابو پائیں تو نہ قرابت کا لحاظ کریں نہ عہد کا، اپنے منہ سے تمہیں راضی کرتے ہیں اور ان کے دلوں میں انکار ہے اور ان میں اکثر بے حکم ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mccxliv{اللہ کی آیتوں کے بدلے تھو ڑے دام مول لیے تو اس کی راہ سے روکا بیشک وہ بہت ہی بڑے کام کرتے ہیں،\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mccxlv{کسی مسلمان میں نہ قراب کا لحاظ کریں نہ عہد کا اور وہی سرکش ہیں،\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mccxlvi{پھر اگر وہ توبہ کریں اور نماز قائم رکھیں اور زکوٰة دیں تو وہ تمہارے دینی بھائی ہیں اور ہم آیتیں مفصل بیان کرتے ہیں جاننے والوں کے لیے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mccxlvii{اور اگر عہد کرکے اپنی قسمیں توڑیں اور تمہارے دین پر منہ آئیں تو کفر کے سرغنوں سے لڑو بیشک ان کی قسمیں کچھ نہیں اس امید پر کہ شاید وہ باز آئیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mccxlviii{کیا اس قوم سے نہ لڑو گے جنہوں نے اپنی قسمیں توڑیں اور رسول کے نکالنے کا ارادہ کیا حالانکہ انہیں کی طرف سے پہلی ہوتی ہے، کیا ان سے ڈرتے ہو تو اللہ کا زیادہ مستحق ہے کہ اس سے ڈرو اگر ایمان رکھتے ہو،\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mccxlix{تو ان سے لڑو اللہ انہیں عذاب دیگا تمہارے ہاتھوں اور انہیں رسوا کرے گا اور تمہیں ان پر مدد دے گا اور ایمان والوں کا جی ٹھنڈا کرے گا،\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mccl{اور ان کے دلوں کی گھٹن دور فرمائے گا اور اللہ جس کی چاہے تو یہ قبول فرمائے اور اللہ علم و حکمت والا ہے،\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mccli{کیا اس گمان میں ہو کہ یونہی چھوڑ دیئے جاؤ گے اور ابھی اللہ نے پہچان نہ کرائی ان کی جو تم میں سے جہاد کریں گے اور اللہ اور اس کے رسول اور مسلمانوں کے سوا کسی کو اپنا محرم راز نہ بنائیں گے اور اللہ تمہارے کاموں سے خبردار ہے،\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mcclii{مشرکوں کو نہیں پہنچتا کہ اللہ کی مسجدیں آباد کریں خود اپنے کفر کی گواہی دے کر ان کا تو سب کیا دھرا اِکا رت ہے اور وہ ہمیشہ آگ میں رہیں گے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mccliii{اللہ کی مسجدیں وہی آباد کرتے ہیں جو اللہ اور قیامت پر ایمان لاتے اور نما ز قائم کرتے ہیں اور زکوٰة دیتے ہیں اور اللہ کے سوا کسی سے نہیں ڈرتے تو قریب ہے کہ یہ لوگ ہدایت والوں میں ہوں،\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mccliv{تو کیا تم نے حا جیوں کی سبیل اور مسجد حرام کی خدمت اس کے برابر ٹھہرا لی جو اللہ اور قیامت پر ایمان لایا اور اللہ کی راہ میں جہاد کیا، وہ اللہ کے نزدیک برابر نہیں، اور اللہ ظالموں کو راہ نہیں دیتا\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mcclv{وہ جو ایمان لائے اور ہجرت کی اور اپنے مال و جان سے اللہ کی راہ میں لڑے، اللہ کے یہاں ان کا درجہ بڑا ہے اور وہی مراد کو پہنچے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mcclvi{ان کا رب انہیں خوشی سنا تا ہے اپنی رحمت اور اپنی رضا کی اور ان باغوں کی جن میں انہیں دائمی نعمت ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mcclvii{ہمیشہ ہمیشہ ان میں رہیں گے، بیشک اللہ کے پاس بڑا ثواب ہے،\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mcclviii{اے ایمان والو! اپنے باپ اور اپنے بھائیوں کو دوست نہ سمجھو اگر وہ ایمان پر کفر پسند کریں، اور تم میں جو کوئی ان سے دوستی کرے گا تو وہی ظالم ہیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mcclix{تم فرماؤ اگر تمہارے باپ اور تمہارے بیٹے اور تمہارے بھائی اور تمہاری عورتیں اور تمہارا کنبہ اور تمہاری کمائی کے مال او ر وہ سودا جس کے نقصان کا تمہیں ڈر ہے اور تمہارے پسند کا مکان یہ چیزیں اللہ اور اس کے رسول اور اس کی راہ میں لڑے سے زیاد ہ پیاری ہوں تو راستہ دیکھو یہاں تک کہ اللہ اپنا حکم لائے اور اللہ فاسقوں کو راہ نہیں دیتا،\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mcclx{بیشک اللہ نے بہت جگہ تمہاری مدد کی اور حنین کے دن جب تم اپنی کثرت پر اترا گئے تھے تو وہ تمہارے کچھ کام نہ ا ٓئی اور زمین اتنی وسیع ہوکر تم پر تنگ ہوگئی پھر تم پیٹھ دے کر پھرگئے،\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mcclxi{پھر اللہ نے اپنی تسکین اتا ری اپنے رسول پر اور مسلمانوں پر اور وہ لشکر اتارے جو تم نے نہ دیکھے اور کافروں کو عذاب دیا اور منکروں کی یہی سزا ہے،\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mcclxii{پھر اس کے بعد اللہ جسے چاہے گا توبہ دے گا اور اللہ بخشنے والا مہربان ہے،\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mcclxiii{اے ایمان والو! مشرک نرے ناپاک ہیں تو اس برس کے بعد وہ مسجد حرام کے پاس نہ آنے پائیں اور اگر تمہاری محتاجی کا ڈر ہے تو عنقریب اللہ تمہیں دولت مند کردے گا اپنے فضل سے اگر چاہے بیشک اللہ علم و حکمت والا ہے،\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mcclxiv{لڑو ان سے جو ایمان نہیں لاتے اللہ پر اور قیامت پر اور حرام نہیں مانتے اس چیز کو جس کو حرام کیا اللہ اور اس کے رسول نے اور سچے دین کے تابع نہیں ہوتے یعنی وہ جو کتاب دیے گئے جب تک اپنے ہاتھ سے جزیہ نہ دیں ذلیل ہوکر\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mcclxv{اور یہودی بولے عزیر اللہ کا بیٹا ہے اور نصرانی بولے مسیح اللہ کا بیٹا ہے، یہ باتیں وہ اپنے منہ سے بکتے ہیں اگلے کافرو ں کی سی بات بناتے ہیں، اللہ انہیں مارے، کہاں اوندھے جاتے ہیں\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mcclxvi{انہوں نے اپنے پادریوں اور جوگیوں کو اللہ کے سوا خدا بنالیا اور مسیح بن مریم کو اور انہیں حکم نہ تھا مگر یہ کہ ایک اللہ کو پوجیں اس کے سوا کسی کی بندگی نہیں، اسے پاکی ہے ان کے شرک سے،\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mcclxvii{چاہتے ہیں کہ اللہ کا نور اپنے منہ سے بُجھا دیں اور اللہ نہ مانے گا مگر اپنے نور کا پورا کرنا پڑے برا مانیں کافر،\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mcclxviii{وہی ہے جس نے اپنا رسول ہدایت اور سچے دین کے ساتھ بھیجا کہ اسے سب دینوں پر غالب کرے پڑے برا مانیں مشرک،\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mcclxix{اے ایمان والو! بیشک بہت پادری اور جوگی لوگوں کا مال ناحق کھا جاتے ہیں اور اللہ کی راہ سے روکتے ہیں، اور وہ کہ جوڑ کر رکھتے ہیں سونا اور چاندی اور اسے اللہ کی راہ میں خرچ نہیں کرتے انہیں خوشخبری سناؤ دردناک عذاب کی،\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mcclxx{جس دن تپایا جائے گا جہنم کی آ گ میں پھر اس سے داغیں گے ان کی پیشانیاں اور کروٹیں اور پیٹھیں یہ ہے وہ جو تم نے اپنے لیے جوڑ کر رکھا تھا اب چکھو مزا اس جوڑنے کا،\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mcclxxi{بیشک مہینوں کی گنتی اللہ کے نزدیک بارہ مہینے ہے اللہ کی کتاب میں جب سے اس نے آسمان اور زمین بنائے ان میں سے چار حرمت والے ہیں یہ سیدھا دین ہے، تو ان مہینوں میں اپنی جان پر ظلم نہ کرو اور مشرکوں سے ہر وقت لڑو جیسا وہ تم سے ہر وقت لڑتے ہیں، اور جان لو کہ اللہ پرہیزگاروں کے ساتھ ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mcclxxii{ان کا مہینے پیچھے ہٹانا نہیں مگر اور کفر میں بڑھنا اس سے کافر بہکائے جاتے ہیں ایک برس اسے حلال ٹھہراتے ہیں اور دوسرے برس اسے حرام مانتے ہیں کہ اس گنتی کے برابر ہوجائیں جو اللہ نے حرام فرمائی اور اللہ کے حرام کیے ہوئے حلال کرلیں، ان کے برے کا م ان کی آنکھوں میں بھلے لگتے ہیں، اور اللہ کافروں کو راہ نہیں دیتا،\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mcclxxiii{اے ایمان والو! تمہیں کیا ہوا جب تم سے کہا جائے کہ خدا کی راہ میں کوچ کرو تو بوجھ کے مارے زمین پر بیٹھ جاتے ہو کیا تم نے دنیا کی زندگی آخرت کے بدلے پسند کرلی اور جیتی دنیا کا اسباب آخرت کے سامنے نہیں مگر تھوڑا\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mcclxxiv{اگر نہ کوچ کرو گے انہیں سخت سزا دے گا اور تمہاری جگہ اور تمہاری جگہ اور لوگ لے آئے گا اور تم اس کا کچھ نہ بگا ڑ سکوگے، اور اللہ سب کچھ کرسکتا ہے،\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mcclxxv{اگر تم محبوب کی مدد نہ کرو تو بیشک اللہ نے ان کی مدد فرمائی جب کافروں کی شرارت سے انہیں باہر تشریف لے جانا ہوا صرف دو جان سے جب وہ دونوں غار میں تھے جب اپنے یار سے فرماتے تھے غم نہ کھا بیشک اللہ ہمارے ساتھ ہے تو اللہ نے اس پر اپنا سکینہ اتارا اور ان فوجوں سے اس کی مدد کی جو تم نے نہ دیکھیں اور کافروں کی بات نیچے ڈالی اللہ ہی کا بول بالا ہے اور اللہ غالب حکمت والا ہے،\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mcclxxvi{کوچ کرو ہلکی جان سے چاہے بھاری دل سے اور اللہ کی راہ میں لڑو اپنے مال اور جان سے، یہ تمہارے لیے بہتر ہے اگر جانو\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mcclxxvii{اگر کوئی قریب مال یا متوسط سفر ہوتا تو ضرور تمہارے ساتھ جاتے مگر ان پر تو مشقت کا راستہ دور پڑ گیا، اور اب اللہ کی قسم کھائیں گے کہ ہم سے بن پڑتا تو ضرور تمہارے ساتھ چلتے اپنی جانو کو ہلاک کرتے ہیں اور اللہ جانتا ہے کہ وہ بیشک ضرور جھوٹے ہیں،\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mcclxxviii{اللہ تمہیں معاف کرے تم نے انہیں کیوں اِذن دے دیا جب تک نہ کھلے تھے تم پر سچے اور ظاہر نہ ہوئے تھے جھوٹے،\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mcclxxix{اور وہ جو اللہ اور قیامت پر ایمان رکھتے ہیں تم سے چھٹی نہ مانگیں گے اس سے کہ اپنے مال اور جان سے جہاد کریں، اور اللہ خوب جا نتا ہے پرہیزگا روں کو،\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mcclxxx{تم سے یہ چھٹی وہی مانگتے ہیں جو اللہ اور قیامت پر ایمان نہیں رکھتے اور ان کے دل شک میں پڑے ہیں تو وہ اپنے شک میں ڈانواں ڈول ہیں\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mcclxxxi{انہیں نکلنا منظور ہوتا تو اس کا سامان کرتے مگر خدا ہی کو ان کا اٹھنا پسند ہوا تو ان میں کاہلی بھردی اور فرمایا گیا کہ بیٹھ رہو بیٹھ رہنے والے کے ساتھ\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mcclxxxii{اگر وہ تم میں نکلتے تو ان سے سوا نقصان کے تمہیں کچھ نہ بڑھتنا اور تم میں فتنہ ڈالنے کو تمہارے بیچ یں غرابیں دوڑاتے (فساد ڈالتے) اور تم میں ان کے جاسوس موجود ہیں اور اللہ خوب جانتا ہے ظالموں کو،\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mcclxxxiii{بیشک انہوں نے پہلے ہی فتنہ چا ہا تھا اور اے محبوب! تمہارے لیے تدبیریں الٹی پلٹیں یہاں تک کہ حق آیا اور اللہ کا حکم ظاہر ہوا اور انہیں ناگوار تھا،\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mcclxxxiv{اور ان میں کوئی تم سے یوں عرض کرتا ہے کہ مجھے رخصت دیجیے اور فتنہ میں نہ ڈالیے سن لو وہ فتنہ ہی میں پڑے اور بیشک جہنم گھیرے ہوئے ہے کافروں کو،\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mcclxxxv{اگر تمہیں بھلائی پہنچے تو انہیں برا لگے اور اگر تمہیں کوئی مصیبت پہنچے تو کہیں ہم نے اپنا کام پہلے ہی ٹھیک کرلیا تھا اور خوشیاں مناتے پھر جائیں،\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mcclxxxvi{تم فرماؤ ہمیں نہ پہنچے گا مگر جو اللہ نے ہمارے لیے لکھ دیا وہ ہمارا مولیٰ ہے اور مسلمانوں کو اللہ ہی پر بھروسہ چاہیے،\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mcclxxxvii{تم فرماؤ تم ہم پر کس چیز کا انتظار کرتے ہو مگر دو خوبیوں میں سے ایک کا اور ہم تم پر اس انتظار میں ہیں کہ اللہ تم پر عذاب ڈالے اپنے پاس سے یا ہمارے ہاتھوں تو اب راہ دیکھو ہم بھی تمہارے ساتھ راہ دیکھ رہے ہیں\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mcclxxxviii{تم فرماؤ کہ دل سے خرچ کرو یا ناگواری سے تم سے ہر گز قبول نہ ہوگا بیشک تم بے حکم لوگ ہو،\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mcclxxxix{اور وہ جو خرچ کرتے ہیں اس کا قبول ہونا بند نہ ہوا مگر اسی لیے کہ وہ اللہ اور رسول سے منکر ہوئے اور نماز کو نہیں آتے مگر جی ہارے اور خرچ نہیں کرتے مگر ناگواری سے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mccxc{تو تمہیں ان کے مال اور ان کی اولاد کا تعجب نہ آئے، اللہ ہی چاہتا ہے کہ دنیا کی زندگی میں ان چیزوں سے ان پر وبال ڈالے اور اگر کفر ہی پر ان کا دم نکل جائے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mccxci{اور اللہ کی قسمیں کھاتے ہیں کہ وہ تم میں سے ہیں اور تم میں سے ہیں نہیں ہاں وہ لوگ ڈرتے ہیں\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mccxcii{اگر پائیں کوئی پناہ یا غار یا سما جانے کی جگہ تو رسیاں تڑاتے ادھر پھر جائیں گے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mccxciii{اور ان میں کوئی وہ ہے کہ صدقے بانٹنے میں تم پر طعن کرتا ہے تو اگر ان میں سے کچھ ملے تو راضی ہوجائیں اور نہ ملے تو جبھی وہ ناراض ہیں،\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mccxciv{اور کیا اچھا ہوتا اگر وہ اس پر راضی ہوتے جو اللہ و رسول نے ان کو دیا اور کہتے ہمیں اللہ کافی ہے اب دیتا ہے ہمیں اللہ اپنے فضل سے اور اللہ کا رسول، ہمیں اللہ ہی کی طرف رغبت ہے\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mccxcv{زکوٰة تو انہیں لوگوں کے لیے ہے محتاج اور نرے نادار اور جو اسے تحصیل کرکے لائیں اور جن کے دلوں کو اسلام سے الفت دی جائے اور گردنیں چھڑانے میں اور قرضداروں کو اور اللہ کی راہ میں اور مسافر کو، یہ ٹھہرایا ہوا ہے اللہ کا، اور اللہ علم و حکمت والا ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mccxcvi{اور ان میں کوئی وہ ہیں کہ ان غیب کی خبریں دینے والے کو ستاتے ہیں اور کہتے ہیں وہ تو کان ہیں، تم فرماؤ تمہارے بھلے کے لیے کا ن ہیں اللہ پر ایمان لاتے ہیں اور مسلمانوں کی بات پر یقین کرتے ہیں اور جو تم میں مسلمان ہیں ان کے واسطے رحمت ہیں، اور جو رسول اللہ کو ایذا دیتے ہیں ان کے لیے دردناک عذاب ہے،\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mccxcvii{تمہارے سامنے اللہ کی قسم کھاتے ہیں کہ تمہیں راضی کرلیں اور اللہ و رسول کا حق زائد تھا کہ اسے راضی کرتے اگر ایمان رکھتے تھے،\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mccxcviii{کیا انہیں خبر نہیں کہ جو خلاف کرے اللہ اور اس کے رسول کا تو اس کے لیے جہنم کی آ گ ہے کہ ہمیشہ اس میں رہے گا، یہی بڑی رسوائی ہے،\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mccxcix{منافق ڈرتے ہیں کہ ان پر کوئی سورة ایسی اترے جو ان کے دلوں کی چھپی جتادے تم فرماؤ ہنسے جاؤ اللہ کو ضرور ظاہر کرنا ہے جس کا تمہیں ڈر ہے،\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mccc{اور اے محبوب اگر تم ان سے پوچھو تو کہیں گے کہ ہم تو یونہی ہنسی کھیل میں تھے تم فرماؤ کیا اللہ اور اس کی آیتوں اور اس کے رسول سے ہنستے ہو،\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mccci{بہانے نہ بنا ؤ تم کافر ہوچکے مسلمان ہوکر اگر ہم تم میں سے کسی کو معاف کریں تو اوروں کو عذاب دیں گے اس لیے کہ وہ مجرم تھے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mcccii{منافق مرد اور منافق عورتیں ایک تھیلی کے چٹے بٹے ہیں برائی کا حکم دیں اور بھلائی سے منع کریں اور اپنی مٹھی بند رکھیں وہ اللہ کو چھوڑ بیٹھے تو اللہ نے انہیں چھوڑدیا بیشک منافق وہی پکے بے حکم ہیں،\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mccciii{اللہ نے منافق مردوں اور منافق عورتوں اور کافروں کو جہنم کی آگ کا وعدہ دیا ہے جس میں ہمیشہ رہیں گے، وہ انہیں بس ہے اور اللہ کی ان پر لعنت ہے اور ان کے لیے قائم رہنے والا عذاب ہے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mccciv{جیسے وہ جو تم سے پہلے تھے تم سے زور میں بڑھ کر تھے اور ان کے مال اور اولاد سے زیادہ، تو وہ اپنا حصہ برت گئے تو تم نے اپنا حصہ برتا جیسے اگلے اپنا حصہ برت گئے اور تم بیہودگی میں پڑے جیسے وہ پڑے تھے ان کے عمل اکارت گئے دنیا اور آخرت میں اور وہی لوگ گھاٹے میں ہیں\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mcccv{کیا انہیں اپنے سے اگلوں کی خبر نہ آئی نوح کی قوم اور عاد اور ثمود اور ابراہیم کی قوم اور مدین والے اور وہ بستیاں کہ الٹ دی گئیں ان کے رسول روشن دلیلیں ان کے پاس لائے تھے تو اللہ کی شان نہ تھی کہ ان پر ظلم کرتا بلکہ وہ خود ہی اپنی جانوں پر ظالم تھے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mcccvi{اور مسلمان مرد اور مسلمان عورتیں ایک دوسرے کے رفیق ہیں بھلائی کا حکم دیں اور برائی سے منع کریں اور نماز قائم رکھیں اور زکوٰة دیں اور اللہ و رسول کا حکم مانیں، یہ ہیں جن پر عنقریب اللہ رحم کرے گا، بیشک اللہ غالب حکمت والا ہے،\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mcccvii{اللہ نے مسلمان مردوں اور مسلمان عورتوں کو باغوں کا وعدہ دیا ہے جن کے نیچے نہریں رواں ان میں ہمیشہ رہیں گے اور پاکیزہ مکانوں کا بسنے کے باغوں میں، اور اللہ کی رضا سب سے بڑی یہی ہے بڑی مراد پانی،\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mcccviii{اے غیب کی خبریں دینے والے (نبی) جہاد فرماؤ کافروں اور منافقوں پر اور ان پر سختی کرو، اور ان کا ٹھکانا دوزخ ہے، اور کیا ہی بری جگہ پلٹنے کی،\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mcccix{اللہ کی قسم کھاتے ہیں کہ انہوں نے نہ کہا اور بیشک ضرور انہوں نے کفر کی بات کہی اور اسلام میں آکر کافر ہوگئے اور وہ چاہا تھا جو انہیں نہ ملا اور انہیں کیا برا لگا یہی نہ کہ اللہ و رسول نے انہیں اپنے فضل سے غنی کردیا تو اگر وہ توبہ کریں تو ان کا بھلا ہے، اور اگر منہ پھیریں تو اللہ انہیں سخت عذاب کرے گا دنیا اور آخرت میں، اور زمین میں کوئی نہ ان کا حمایتی ہوگا اور نہ مددگار\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mcccx{اور ان میں کوئی وہ ہیں جنہوں نے اللہ سے عہد کیا تھا کہ اگر ہمیں اپنے فضل سے دے تو ہم ضرور خیرات کریں گے اور ہم ضرور بھلے آدمی ہوجائیں گے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mcccxi{تو جب اللہ نے انہیں اپنے فضل سے دیا اس میں بخل کرنے لگے اور منہ پھیر کر پلٹ گئے،\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mcccxii{تو اس کے پیچھے اللہ نے ان کے دلوں میں نفاق رکھ دیا اس دن تک کہ اس سے ملیں گے بدلہ اس کا کہ انہوں نے اللہ سے وعدہ جھوٹا کیا اور بدلہ اس کا کہ جھوٹ بولتے تھے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mcccxiii{کیا انہیں خبر نہیں کہ اللہ ان کے دل کی چھپی اور ان کی سرگوشی کو جانتا ہے اور یہ کہ اللہ سب غیبوں کا بہت جاننے والا ہے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mcccxiv{اور جو عیب لگاتے ہیں ان مسلمانوں کو کہ دل سے خیرات کرتے ہیں اور ان کو جو نہیں پاتے مگر اپنی محنت سے تو ان سے ہنستے ہیں اللہ ان کی ہنسی کی سزا دے گا، اور ان کے لیے دردناک عذاب ہے،\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mcccxv{تم ان کی معافی چاہو یا نہ چاہو، اگر تم ستر بار ان کی معافی چاہو گے تو اللہ ہرگز انھیں نہیں بخشے گا یہ اس لیے کہ وہ اللہ اور اس کے رسول سے منکر ہوئے، اور اللہ فاسقوں کو راہ نہیں دیتا\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mcccxvi{پیچھے رہ جانے والے اس پر خوش ہوئے کہ وہ رسول کے پیچھے بیٹھ رہے اور انہیں گوارا نہ ہوا کہ اپنے مال اور جان سے اللہ کی راہ میں لڑیں اور بولے اس گرمی میں نہ نکلو، تم فرماؤ جہنم کی آگ سب سے سخت گرم ہے، کسی طرح انہیں سمجھ ہو تی\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mcccxvii{تو انہیں چاہیے تھوڑا ہنسیں اور بہت روئیں بدلہ اس کا جو کماتے تھے\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mcccxviii{پھر اے محبوب! اگر اللہ تمہیں ان میں سے کسی گروہ کی طرف واپس لے جائے اور وہ تم سے جہاد کو نکلنے کی اجازت مانگے تو تم فرمانا کہ تم کبھی میرے ساتھ نہ چلو اور ہرگز میرے ساتھ کسی دشمن سے نہ لڑو، تم نے پہلی دفعہ بیٹھ رہنا پسند کیا تو بیٹھ رہو پیچھے رہ جانے والوں کے ساتھ\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mcccxix{اور ان میں سے کسی کی میت پر کبھی نماز نہ پڑھنا اور نہ اس کی قبر پر کھڑے ہونا، بیشک اللہ اور رسول سے منکر ہوئے اور فسق ہی میں مر گئے\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mcccxx{اور ان کے مال یا اولاد پر تعجب نہ کرنا، اللہ یہی چاہتا ہے کہ اسے دنیا م یں ان پر وبال کرے اور کفر ہی پر ان کا دم نکل جائے،\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mcccxxi{اور جب کوئی سورت اترے کہ اللہ پر ایمان لاؤ اور اس کے رسول کے ہمراہ جہاد کرو تو ان کے مقدور والے تم سے رخصت مانگتے ہیں اور کہتے ہیں ہمیں چھوڑ دیجیے کہ بیٹھ رہنے والوں کے ساتھ ہولیں،\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mcccxxii{انہیں پسند آیا کہ پیچھے رہنے والی عورتوں کے ساتھ ہوجائیں اور ان کے دلوں پر مہُر کردی گئیں تو وہ کچھ نہیں سمجھتے\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mcccxxiii{لیکن رسول اور جو ان کے ساتھ ایمان لائے انہوں نے اپنے مالوں جانوں سے جہاد کیا، اور انہیں کے لیے بھلائیاں ہیں اور یہی مراد کو پہنچے،\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mcccxxiv{اللہ نے ان کے لیے تیار کر رکھی ہیں بہشتیں جن کے نیچے نہریں رواں ہمیشہ ان میں رہیں گے، یہی بڑی مراد ملنی ہے،\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mcccxxv{اور بہانے بنانے والے گنوار آئے کہ انہیں رخصت دی جائے اور بیٹھ رہے وہ جنہوں نے اللہ و رسول سے جھوٹ بولا تھا جلد ان میں کے کافروں کو دردناک عذاب پہنچے گا\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mcccxxvi{ضعیفوں پر کچھ حرج نہیں اور نہ بیماروں پر اور نہ ان پر جنہیں خرچ کا مقدور نہ ہو جب کہ اللہ اور رسول کے خیر خواہ رہیں نیکی والوں پر کوئی راہ نہیں اور اللہ بخشنے والا مہربان ہے،\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mcccxxvii{اور نہ ان پر جو تمہارے حضور حاضر ہوں کہ تم انہیں سواری عطا فرماؤ تم سے یہ جواب پائیں کہ میرے پاس کوئی چیز نہیں جس پر تمہیں سوار کروں اس پر یوں واپس جائیں کہ ان کی آنکھوں سے آنسو ابلتے ہوں اس غم سے کہ خرچ کا مقدور نہ پایا،\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mcccxxviii{مؤاخذہ تو ان سے ہے جو تم سے رخصت مانگتے ہیں اور وہ دولت مند ہیں انہیں پسند آیا کہ عورتوں کے ساتھ پیچھے بیٹھ رہیں اور اللہ نے ان کے دلوں پر مہر کردی تو وہ کچھ نہیں جانتے\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mcccxxix{تم سے بہانے بنائیں گے جب تم ان کی طرف لوٹ کر جاؤ گے تم فرمانا، بہانے نہ بناؤ ہم ہرگز تمہارا یقین نہ کریں گے اللہ نے ہمیں تمہاری خبریں دے دی ہیں، اور اب اللہ و رسول تمہارے کام دیکھیں گے پھر اس کی طرف پلٹ کر جاؤ گے جو چھپے اور ظاہر سب کو جانتا ہے وہ تمہیں جتادے گا جو کچھ تم کرتے تھے،\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mcccxxx{اب تمہارے آگے اللہ کی قسمیں کھائیں گے جب تم ان کی طرف پلٹ کر جاؤ گے اس لیے کہ تم ان کے خیال میں نہ پڑو تو ہاں تم ان کا خیال چھوڑو وہ تو نرے پلید ہیں اور ان کا ٹھکانا جہنم ہے بدلہ اس کا جو کماتے تھے\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mcccxxxi{تمہارے آگے قسمیں کھاتے ہیں کہ تم ان سے راضی ہوجاؤ تو اگر تم ان سے راضی ہوجاؤ تو بیشک اللہ تو فاسق لوگوں سے راضی نہ ہوگا\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mcccxxxii{گنوار کفر اور نفاق میں زیادہ سخت ہیں اور اسی قابل ہیں کہ اللہ نے جو حکم اپنے رسول پر اتارے اس سے جاہل رہیں، اور اللہ علم و حکمت والا ہے،\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mcccxxxiii{اور کچھ گنوار وہ ہیں کہ جو اللہ کی راہ میں خرچ کریں تو اسے تاوان سمجھیں اور تم پر گردشیں آنے کے انتظار میں رہیں انہیں پر ہے بری گردش اور اللہ سنتا جانتا ہے،\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mcccxxxiv{اور کچھ گاؤں والے وہ ہیں جو اللہ اور قیامت پر ایمان رکھتے ہیں اور جو خرچ کریں اسے اللہ کی نزدیکیوں اور رسول سے دعائیں لینے کا ذریعہ سمجھیں ہاں ہاں وہ ان کے لیے باعث قرب ہے اللہ جلد انہیں اپنی رحمت میں داخل کرے گا، بیشک اللہ بخشنے والا مہربان ہے،\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mcccxxxv{اور سب میں اگلے پہلے مہاجر اور انصار اور جو بھلائی کے ساتھ ان کے پیرو ہوئے اللہ ان سے راضی اور وہ اللہ سے راضی اور ان کے لیے تیار کر رکھے ہیں باغ جن کے نیچے نہریں بہیں ہمیشہ ہمیشہ ان میں رہیں، یہی بڑی کامیابی ہے،\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mcccxxxvi{اور تمہارے آس پاس کے کچھ گنوار منافق ہیں، اور کچھ مدینہ والے، ان کی خو ہوگئی ہے نفاق، تم انہیں نہیں جانتے، ہم انھیں جانتے ہیں جلد ہم انہیں دوبارہ عذاب کریں گے پھر بڑے عذاب کی طرف پھیرے جائیں گے\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mcccxxxvii{اور کچھ اور ہیں جو اپنے گناہوں کے مقر ہوئے اور ملایا ایک کام اچھا اور دوسرا بڑا قریب ہے کہ اللہ ان کی توبہ قبول کرے، بیشک اللہ بخشنے والا مہربان ہے،\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mcccxxxviii{اے محبوب! ان کے مال میں سے زکوٰة تحصیل کرو جس سے تم انھیں ستھرا اور پاکیزہ کردو اور ان کے حق میں دعائے خیر کرو بیشک تمہاری دعا ان کے دلوں کا چین ہے، اور اللہ سنتا جانتا ہے،\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mcccxxxix{کیا انہیں خبر نہیں کہ اللہ ہی اپنے بندوں کی توبہ قبول کرتا اور صدقے خود اپنی دست قدرت میں لیتا ہے اور یہ کہ اللہ ہی توبہ قبول کرنے والا مہربان ہے\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mcccxl{اور تم فرما ؤ کام کرو اب تمہارے کام دیکھے گا اللہ اور اس کے رسول اور مسلمان، اور جلد اس کی طرف پلٹوگے جو چھپا اور کھلا سب جانتا ہے تو وہ تمہارے کام تمہیں جتاوے گا،\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mcccxli{اور کچھ موقوف رکھے گئے اللہ کے حکم پر، یا ان پر عذاب کرے یا ان کی توبہ قبول کرے اور اللہ علم و حکمت والا ہے،\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mcccxlii{اور وہ جنہوں نے مسجد بنائی نقصان پہنچانے کو اور کفر کے سبب اور مسلمانوں میں تفرقہ ڈالنے کو اور اس کے انتظار میں جو پہلے سے اللہ اور اس کے رسول کا مخالف ہے اور وہ ضرور قسمیں کھائیں گے ہم نے تو بھلائی چاہی، اور اللہ گواہ ہے کہ وہ بیشک جھوٹے ہیں،\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mcccxliii{اس مسجد میں تم کبھی کھڑے نہ ہونا، بیشک وہ مسجد کہ پہلے ہی دن سے جس کی بنیاد پرہیزگاری پر رکھی گئی ہے وہ اس قابل ہے کہ تم اس میں کھڑے ہو، اس میں وہ لوگ ہیں کہ خوب ستھرا ہونا چاہتے ہیں اور ستھرے اللہ کو پیارے ہیں،\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mcccxliv{تو کیا جس نے اپنی بنیاد رکھی اللہ سے ڈر اور اس کی رضا پر وہ بھلا یا وہ جس نے اپنی نیو چنی ایک گراؤ (ٹوٹے ہوئے کناروں والے) گڑھے کے کنارے تو وہ اسے لے کر جہنم کی آ گ میں ڈھے پڑا اور اللہ ظالموں کو راہ نہیں دیتا،\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mcccxlv{وہ تعمیر جو چنی (کی) ہمیشہ ان کے دلوں میں کھٹکتی رہے گی مگر یہ کہ ان کے دل ٹکڑے ٹکڑے ہوجائیں اور اللہ علم و حکمت والا ہے،\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mcccxlvi{بیشک اللہ نے مسلمانوں سے ان کے مال اور جان خریدلیے ہیں اس بدلے پر کہ ان کے لیے جنت ہے اللہ کی راہ میں لڑیں تو ماریں اور مریں اس کے ذمہ کرم پر سچا وعدہ توریت اور انجیل اور قرآن میں اور اللہ سے زیادہ قول کا پورا کون تو خوشیاں مناؤ اپنے سودے کی جو تم نے اس سے کیا ہے، اور یہی بڑی کامیابی ہے،\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mcccxlvii{توبہ والے عبادت والے سراہنے والے روزے والے رکوع والے سجدہ والے بھلائی کے بتانے والے اور برائی سے روکنے والے اور اللہ کی حدیں نگاہ رکھنے والے اور خوشی سناؤ مسلمانوں\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@mcccxlviii{نبی اور ایمان والوں کو لائق نہیں کہ مشرکوں کی بخشش چاہیں اگرچہ وہ رشتہ دار ہوں جبکہ انہیں کھل چکا کہ وہ دوزخی ہیں\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@mcccxlix{اور ابراہیم کا اپنے باپ کی بخشش چاہنا وہ تو نہ تھا مگر ایک وعدے کے سبب جو اس سے کرچکا تھا پھر جب ابراہیم کو کھل گیا کہ وہ اللہ کا دشمن ہے اس سے تنکا توڑ دیا (لاتعلق ہوگیا) بیشک ابراہیم بہت آہیں کرنے والا متحمل ہے،\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@mcccl{اور اللہ کی شان نہیں کہ کسی قوم کو ہدایت کرکے گمراہ فرمائے جب تک انہیں صاف نہ بتادے کہ کسی چیز سے انہیں بچنا ہے بیشک اللہ سب کچھ جانتا ہے،\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@mcccli{بیشک اللہ ہی کے لیے ہے آسمانوں اور زمین کی سلطنت، جِلاتا ہے اور مارتا ہے، اور اللہ کے سوا نہ تمہارا کوئی والی اور نہ مددگار،\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@mccclii{بیشک اللہ کی رحمتیں متوجہ ہوئیں ان غیب کی خبریں بتانے والے اور ان مہاجرین اور انصار پر جنہوں نے مشکل کی گھڑی میں ان کا ساتھ دیا بعد اس کے کہ قریب تھا کہ ان میں کچھ لوگوں کے دل پھر جائیں پھر ان پر رحمت سے متوجہ ہوا بیشک وہ ان پر نہایت مہربان رحم والا ہے\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@mcccliii{اور ان تین پر جو موقوف رکھے گئے تھے یہاں تک کہ جب زمین اتنی وسیع ہوکر ان پر تنگ ہوگئی اور ہو اپنی جان سے تنگ آئے اور انہیں یقین ہوا کہ اللہ سے پناہ نہیں مگر اسی کے پاس، پھر ان کی توبہ قبول کی کہ تائب رہیں، بیشک اللہ ہی توبہ قبول کرنے والا مہربان ہے،\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@mcccliv{اے ایمان والو! اللہ سے ڈرو اور سچوں کے ساتھ ہو\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@mccclv{مدینہ والوں اور ان کے گرد دیہات والوں کو لائق نہ تھا کہ رسول اللہ سے پیچھے بیٹھ رہیں اور نہ یہ کہ ان کی جان سے اپنی جان پیاری سمجھیں یہ اس لیے کہ انہیں جو پیاس یا تکلیف یا بھوک اللہ کی راہ میں پہنچتی ہے اور جہاں ایسی جگہ قدم رکھتے ہیں جس سے کافروں کو غیظ آئے اور جو کچھ کسی دشمن کا بگاڑتے ہیں اس سب کے بدلے ان کے لیے نیک عمل لکھا جاتا ہے بیشک اللہ نیکوں کا نیگ (اجر) ضائع نہیں کرتا،\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@mccclvi{اور جو کچھ خرچ کرتے ہیں چھوٹا یا بڑا اور جو نالا طے کرتے ہیں سب ان کے لیے لکھا جاتا ہے تاکہ اللہ ان کے سب سے بہتر کاموں کا انہیں صلہ دے\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@mccclvii{اور مسلمانوں سے یہ تو ہو نہیں سکتا کہ سب کے سب نکلیں تو کیوں نہ ہو کہ ان کے ہر گروہ میں سے ایک جماعت نکلے کہ دین کی سمجھ حاصل کریں اور واپس آکر اپنی قوم کو ڈر سنائیں اس امید پر کہ وہ بچیں\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@mccclviii{اے ايما ن والوں جہاد کرو ان کافروں سے جو تمہارے قريب ہيں اور چاہیئے کہ وہ تم میں سختی پائیں، اور جان رکھو کہ اللہ پرہیزگاروں کے ساتھ ہے\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@mccclix{اور جب کوئی سورت اترتی ہے تو ان میں کوئی کہنے لگتا ہے کہ اس نے تم میں کس کے ایمان کو ترقی دی تو وہ جو ایمان والے ہیں ان کے ایمان کو ترقی دی اور وہ خوشیاں منارہے ہیں،\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@mccclx{اور جن کے دلوں میں آزار ہے انہیں اور پلیدی پر پلیدی بڑھائی اور وہ کفر ہی پر مر گئے،\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@mccclxi{کیا انہیں نہیں سوجھتا ک ہ ہر سال ایک یا دو بار آزمائے جاتے ہیں پھر نہ تو توبہ کرتے ہیں نہ نصیحت مانتے ہیں،\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@mccclxii{اور جب کوئی سورت اترتی ہے ان میں ایک دوسرے کو دیکھنے لگتا ہے کہ کوئی تمہیں دیکھتا تو نہیں پھر پلٹ جاتے ہیں اللہ نے ان کے دل پلٹ دیئے ہیں کہ وہ ناسمجھ لوگ ہیں\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@mccclxiii{بیشک تمہارے پاس تشریف لائے تم میں سے وہ رسول جن پر تمہارا مشقت میں پڑنا گِراں ہے تمہاری بھلائی کے نہایت چاہنے والے مسلمانوں پر کمال مہربان مہربان\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@mccclxiv{پھر اگر وہ منہ پھیریں تو تم فرمادو کہ مجھے اللہ کافی ہے اس کے سوا کسی کی بندگی نہیں، میں نے اسی پر بھروسہ کیا اور وہ بڑے عرش کا مالک ہے\qt@no{(129)}}%
\qt@newcmd\qurantrans@ur@mccclxv{\basmalahur یہ حکمت والی کتاب کی آیتیں ہیں،\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mccclxvi{کیا لوگوں کو اس کا اچنبا ہوا کہ ہم نے ان میں سے ایک مرد کو وحی بھیجی کہ لوگوں کو ڈر سناؤ اور ایمان والوں کو خوشخبری دو کہ ان کے لیے ان کے رب کے پاس سچ کا مقام ہے، کافر بولے بیشک یہ تو کھلا جادوگر ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mccclxvii{بیشک تمہارا رب اللہ ہے جس نے آسمان اور زمین چھ دن میں بنائے پھر عرش پر استوا فرمایا جیسا اس کی شان کے لائق ہے کام کی تدبیر فرما تا ہے کوئی سفارشی نہیں مگر اس کی اجازت کے بعد یہ ہے اللہ تمہارا رب تو اس کی بندگی کرو تو کیا تم دھیان نہیں کرتے،\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mccclxviii{اسی کی طرف تم سب کو پھرنا ہے اللہ کا سچا وعدہ بیشک وہ پہلی بار بناتا ہے پھر فنا کے بعد دوبارہ بنائے گا کہ ان کو جو ایمان لائے اور اچھے کام کیے انصاف کا صلہ دے اور کافروں کے لیے پینے کو کھولتا پانی اور دردناک عذاب بدلہ ان کے کفر کا،\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mccclxix{وہی ہے جس نے سورج کو جگمگاتا بنا یا اور چاند چمکتا اور اس کے لیے منزلیں ٹھہرائیں کہ تم برسوں کی گنتی اور حساب جانو، اللہ نے اسے نہ بنایا مگر حق نشانیاں مفصل بیان فرماتا ہے علم والوں کے لیے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mccclxx{بیشک رات اور دن کا بدلتا آنا اور جو کچھ اللہ نے آسمانوں اور زمین میں پیدا کیا ان میں نشانیاں ہیں ڈر والوں کے لیے،\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mccclxxi{بیشک وہ جو ہمارے ملنے کی امید نہیں رکھتے اور دنیا کی زندگی پسند کر بیٹھے اور اس پر مطمئن ہوگئے اور وہ جو ہماری آیتوں سے غفلت کرتے ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mccclxxii{ان لوگوں کا ٹھکانا دوزخ ہے بدلہ ان کی کمائی کا،\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mccclxxiii{بیشک جو ایمان لائے اور اچھے کام کیے ان کا رب ان کے ایمان کے سبب انھیں راہ دے گا ان کے نیچے نہریں بہتی ہوں گی نعمت کے باغوں میں،\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mccclxxiv{ان کی دعا اس میں یہ ہوگی کہ اللہ تجھے پاکی ہے اور ان کے ملتے وقت خوشی کا پہلا بول سلام ہے اور ان کی دعا کا خاتمہ یہ ہے کہ سب خوبیوں کو سراہا اللہ جو رب ہے سارے جہان کا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mccclxxv{اور اگر اللہ لوگوں پر برائی ایسی جلدبھیجتا جیسی وہ بھلائی کی جلدی کرتے ہیں تو ان کا وعدہ پورا ہوچکا ہوتا تو ہم چھوڑتے انہیں جو ہم سے ملنے کی امید نہیں رکھتے کہ اپنی سرکشی میں بھٹکا کریں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mccclxxvi{اور جب آدمی کو تکلیف پہنچتی ہے ہمیں پکارتا ہے لیٹے اور بیٹھے اور کھڑے پھر جب ہم اس کی تکلیف دور کردیتے ہیں چل دیتا ہے گویا کبھی کسی تکلیف کے پہنچنے پر ہمیں پکارا ہی نہ تھا یونہی بھلے کر دکھائے ہیں حد سے بڑھنے والے کو ان کے کام\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mccclxxvii{اور بیشک ہم نے تم سے پہلی سنگتیں (قومیں) ہلاک فرمادیں جب وہ حد سے بڑھے اور ان کے رسول ان کے پاس روشن دلیلیں لے کر آئے اور وہ ایسے تھے ہی نہیں کہ ایمان لاتے، ہم یونہی بدلہ دیتے ہیں مجرموں کو،\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mccclxxviii{پھر ہم نے ان کے بعد تمہیں زمین میں جانشین کیا کہ دیکھیں تم کیسے کام کرتے ہو\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mccclxxix{اور جب ان پر ہماری روشن آیتیں پڑھی جاتی ہیں تو وہ کہنے لگتے ہیں جنہیں ہم سے ملنے کی امید نہیں کہ اس کے سوا اور قرآن لے آیئے یا اسی کو بدل دیجیے تم فرماؤ مجھے نہیں پہنچتا کہ میں اسے اپنی طرف سے بدل دوں میں تو اسی کا تابع ہوں جو میری طرف وحی ہوتی ہے میں اگر اپنے رب کی نافرمانی کروں تو مجھے بڑے دن کے عذاب کا ڈر ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mccclxxx{تم فرماؤ اگر اللہ چاہتا تو میں اسے تم پر نہ پڑھتا نہ وہ تم کو اس سے خبردار کرتا تو میں اس سے پہلے تم میں اپنی ایک عمر گزار چکا ہوں تو کیا تمہیں عقل نہیں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mccclxxxi{تو اس سے بڑھ کر ظالم کون جو اللہ پر جھوٹ باندھے یا اس کی آیتیں جھٹلائے، بیشک مجرموں کا بھلا نہ ہوگا،\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mccclxxxii{اور اللہ کے سوا ایسی چیز کو پوجتے ہیں جو ان کا کچھ بھلا نہ کرے اور کہتے ہیں کہ یہ اللہ کے یہاں ہمارے سفارشی ہیں تم فرماؤ کیا اللہ کو وہ بات بتاتے ہو جو اس کے علم میں نہ آسمانوں میں ہے نہ زمین میں اسے پاکی اور برتری ہے ان کے شرک سے،\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mccclxxxiii{اور لوگ ایک ہی امت تھے پھر مختلف ہوئے، اور اگر تیرے رب کی طرف سے ایک بات پہلے نہ ہوچکی ہوتی تو یہیں ان کے اختلافوں کا ان پر فیصلہ ہوگیا ہوتا\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mccclxxxiv{اور کہتے ہیں ان پر ان کے رب کی طرف سے کوئی نشانی کیوں نہیں اتری تم فرماؤ غیب تو اللہ کے لیے ہے اب راستہ دیکھو میں بھی تمہارے ساتھ راہ دیکھ رہا ہوں،\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mccclxxxv{اور جب کہ ہمارے آدمیوں کو رحمت کا مزہ دیتے ہیں کسی تکلیف کے بعد جو انہیں پہنچی تھی جبھی وہ ہماری آیتوں کے ساتھ داؤں چلتے ہیں تم فرمادو اللہ کی خفیہ تدبیر سب سے جلد ہوجاتی ہے بیشک ہمارے فرشتے تمہارے مکر لکھ رہے ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mccclxxxvi{وہی ہے کہ تمہیں خشکی اور تری میں چلاتا ہے یہاں تک کہ جب تم کشتی میں ہو اور وہ اچھی ہوا سے انھیں لے کر چلیں اور اس پر خوش ہوئے ان پر آندھی کا جھونکا آیا اور ہر طرف لہروں نے انہیں آلیا اور سمجھ لے کہ ہم گِھر گئے اس وقت اللہ کو پکارتے ہیں نرے اس کے بندے ہوکر، کہ اگر تو اس سے ہمیں بچالے گا تو ہم ضرور شکر گزار ہوں گے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mccclxxxvii{پھر اللہ جب انہیں بچا لیتا ہے جبھی وہ زمین میں ناحق زیادتی کرنے لگتے ہیں اے لوگو! تمہاری زیادتی تمہارے ہی جانوں کا وبال ہے دنیا کے جیتے جی برت لو (فائد اٹھالو)، پھر تمہیں ہماری طرف پھرنا ہے اس وقت ہم تمہیں جتادیں گے جو تمہارے کوتک تھے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mccclxxxviii{دنیا کی زندگی کی کہا وت تو ایسی ہی ہے جیسے وہ پانی کہ ہم نے آسمان سے اتارا تو اس کے سبب زمین سے اگنے والی چیزیں سب گھنی ہوکر نکلیں جو کچھ آدمی اور چوپائے کھاتے ہیں یہاں تک کہ جب زمین میں اپنا سنگھار لے لیا اور خوب آراستہ ہوگئی اور اس کے مالک سمجھے کہ یہ ہمارے بس میں آگئی ہمارا حکم اس پر آیا رات میں یا دن میں تو ہم نے اسے کردیا کاٹی ہوئی گویا کل تھی ہی نہیں ہم یونہی آیتیں مفصل بیان کرتے ہیں غور کرنے والوں کے لیے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mccclxxxix{اور اللہ سلامتی کے گھر کی طرف پکارتا ہے اور جسے چاہے سیدھی راہ چلاتا ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mcccxc{بھلائی والوں کے لیے بھلائی ہے اور اس سے بھی زائد اور ان کے منہ پر نہ چڑھے گی سیاہی اور نہ خواری وہی جنت والے ہیں وہ اس میں ہمیشہ رہیں گے،\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mcccxci{اور جنہوں نے برائیاں کمائیں تو برائی کا بدلہ اسی جیسا اور ان پر ذلت چڑھے گی، انہیں اللہ سے بچانے والا کوئی نہ ہوگا، گویا ان کے چہروں پر اندھیری رات کے ٹکڑے چڑھا دیئے ہیں وہی دوزخ والے ہیں، وہ اس میں ہمیشہ رہیں گے،\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mcccxcii{اور جس دن ہم ان سب کو اٹھائیں گے پھر مشرکوں سے فرمائیں گے اپنی جگہ رہو تم اور تمہارے شریک تو ہم انہیں مسلمانوں سے جدا کردیں گے اور ان کے شریک ان سے کہیں گے تم ہمیں کب پوجتے تھے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mcccxciii{تو اللہ گواہ کافی ہے ہم میں اور تم میں کہ ہمیں تمہارے پوجنے کی خبر بھی نہ تھی،\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mcccxciv{یہاں ہر جان جا نچ لے گی جو آگے بھیجا اور اللہ کی طرف پھیرے جائیں گے جو ان کا سچا مولیٰ ہے اور ان کی ساری بناوٹیں ان سے گم ہوجائیں گی\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mcccxcv{تم فرماؤ تمہیں کون روزی دیتا ہے آسمان اور زمین سے یا کون مالک ہے کان اور آنکھوں کا اور کون نکالتا ہے زندہ کو مردے سے اور نکالتا ہے مردہ کو زندہ سے اور کون تمام کاموں کی تدبیر کرتا ہے تو اب کہیں گے کہ اللہ تو تم فرماؤ تو کیوں نہیں ڈرتے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mcccxcvi{تو یہ اللہ ہے تمہارا سچا رب پھر حق کے بعد کیا ہے مگر گمراہی پھر کہاں پھرے جاتے ہو،\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mcccxcvii{یونہی ثابت ہوچکی ہے تیرے رب کی بات فاسقوں پر تو وہ ایمان نہیں لائیں گے،\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mcccxcviii{تم فرماؤ تمہارے شریکوں میں کوئی ایسا ہے کہ اول بنائے پھر فنا کے بعد دوبارہ بنائے تم فرماؤ اللہ اوّل بناتا ہے پھر فنا کے بعد دوبارہ بنائے گا تو کہاں اوندھے جاتے ہو\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mcccxcix{تم فرماؤ تمہارے شریکوں میں کوئی ایسا ہے کہ حق کی راہ دکھائے تم فرماؤ کہ اللہ حق کی راہ دکھاتا ہے، تو کیا جو حق کی راہ دکھائے اس کے حکم پر چلنا چاہیے یا اس کے جو خود ہی راہ نہ پائے جب تک راہ نہ دکھایا جائے تو تمہیں کیا ہوا کیسا حکم لگاتے ہو،\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mcd{اور ان میں اکثر تو نہیں چلتے مگر گمان پر بیشک گمان حق کا کچھ کام نہیں دیتا، بیشک اللہ ان کاموں کو جانتا ہے،\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mcdi{اور اس قرآن کی یہ شان نہیں کہ کوئی اپنی طرف سے بنالے بے اللہ کے اتارے ہاں وہ اگلی کتابوں کی تصدیق ہے اور لوح میں جو کچھ لکھا ہے سب کی تفصیل ہے اس میں کچھ شک نہیں ہے پروردگار عالم کی طرف سے ہے،\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mcdii{کیا یہ کہتے ہیں کہ انہوں نے اسے بنالیا ہے تم فرماؤ تو اس جیسی کوئی ایک سورة لے آؤ اور اللہ کو چھوڑ کر جو مل سکیں سب کو بلا لاؤ اگر تم سچے ہو،\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mcdiii{بلکہ اسے جھٹلایا جس کے علم پر قابو نہ پایا اور ابھی انہوں نے اس کا انجام نہیں دیکھا ایسے ہی ان سے اگلوں نے جھٹلایا تھا تو دیکھو ظالموں کیسا انجام ہوا\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mcdiv{اور ان میں کوئی اس پر ایمان لاتا ہے اور ان میں کوئی اس پر ایمان نہیں لاتا ہے، اور تمہارا رب مفسدوں کو خوب جانتا ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mcdv{اور اگر وہ تمہیں جھٹلائیں تو فرمادو کہ میرے لیے میری کرنی اور تمہارے لیے تمہاری کرنی (اعمال) تمہیں میرے کام سے علاقہ نہیں اور مجھے تمہارے کام سے لاتعلق نہیں\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mcdvi{اور ان میں کوئی وہ ہیں جو تمہاری طرف کان لگاتے ہیں تو کیا تم بہروں کو سنا دو گے اگرچہ انہیں عقل نہ ہو\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mcdvii{اور ان میں کوئی تمہاری طرف تکتا ہے کیا تم اندھوں کو راہ دکھا دو گے اگرچہ وہ نہ سوجھیں،\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mcdviii{بیشک اللہ لوگوں پر کچھ ظلم نہیں کرتا ہاں لوگ ہی اپنی جانوں پر ظلم کرتے ہیں\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mcdix{اور جس دن انہیں اٹھائے گا گویا دنیا میں نہ رہے تھے مگر اس دن کی ایک گھڑی آپس میں پہچان کریں گے کہ پورے گھاٹے میں رہے وہ جنہوں نے اللہ سے ملنے کو جھٹلایا اور ہدایت پر نہ تھے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mcdx{اور اگر ہم تمہیں دکھا دیں کچھ اس میں سے جو انہیں وعدہ دے رہے ہیں یا تمہیں پہلے ہی اپنے پاس بلالیں بہرحال انہیں ہماری طرف پلٹ کر آنا ہے پھر اللہ گواہ ہے ان کے کاموں پر،\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mcdxi{اور ہر امت میں ایک رسول ہوا جب ان کا رسول ان کے پاس آتا ان پر انصاف کا فیصلہ کردیا جاتا اور ان پر ظلم نہیں ہوتا،\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mcdxii{اور کہتے ہیں یہ وعدہ کب آئے گا اگر تم سچے ہو\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mcdxiii{تم فرماؤ میں اپنی جان کے برے بھلے کا (ذاتی) اختیار نہیں رکھتا مگر جو اللہ چاہے ہر گروہ کا ایک وعدہ ہے جب ان کا وعدہ آئے گا تو ایک گھڑی نہ پیچھے ہٹیں نہ آگے بڑھیں،\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mcdxiv{تم فرماؤ بھلا بتاؤ تو اگر اس کا عذاب تم پر رات کو آئے یا دن کو تو اس میں وہ کونسی چیز ہے کہ مجرموں کو جس کی جلدی ہے،\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mcdxv{تو کیا جب ہو پڑے گا اس وقت اس کا یقین کرو گے کیا اب مانتے ہو پہلے تو اس کی جلدی مچارہے تھے،\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mcdxvi{پھر ظالموں سے کہا جائے گا ہمیشہ کا عذاب چکھو تمہیں کچھ اور بدلہ نہ ملے گا مگر وہی جو کماتے تھے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mcdxvii{اور تم سے پوچھتے ہیں کیا وہ حق ہے، تم فرماؤ، ہاں! میرے رب کی قسم بیشک وہ ضرور حق ہے، اور تم کچھ تھکا نہ سکو گے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mcdxviii{اور اگر ہر ظالم جان، زمین میں جو کچھ ہے سب کی مالک ہوتی، ضرور اپنی جان چھڑانے میں دیتی اور دل میں چپکے چپکے پشیمان ہوئے جب عذاب دیکھا اور ان میں انصاف سے فیصلہ کردیا گیا اور ان پر ظلم نہ ہوگا،\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mcdxix{سن لو بیشک اللہ ہی کا ہے جو کچھ آسمانوں میں ہے اور زمین میں سن لو بیشک اللہ کا وعدہ سچا ہے مگر ان میں اکثر کو خبر نہیں،\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mcdxx{وہ جِلاتا اور مارتا ہے اور اسی کی طرف پھرو گے،\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mcdxxi{اے لوگو! تمہارے پاس تمہارے رب کی طرف سے نصیحت آئی اور دلوں کی صحت اور ہدایت اور رحمت ایمان والوں کے لیے،\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mcdxxii{تم فرماؤ اللہ ہی کے فضل اور اسی کی رحمت اور اسی پر چاہیے کہ خوشی کریں وہ ان کے سب دھن دولت سے بہتر ہے،\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mcdxxiii{تم فرماؤ بھلا بتاؤ تو وہ جو اللہ نے تمہارے لیے رزق اتارا اس میں تم نے اپنی طرف سے حرام و حلال ٹھہرالیا تم فرماؤ کیا اللہ نے اس کی تمہیں اجازت دی یا اللہ پر جھوٹ باندھتے ہو\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mcdxxiv{اور کیا گمان ہے ان کا، جو اللہ پر جھوٹ باندھتے ہیں کہ قیامت میں ان کا کیا حال ہوگا، بیشک اللہ لوگوں پر فضل کرتا ہے مگر اکثر لوگ شکر نہیں کرتے،\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mcdxxv{اور تم کسی کام میں ہو اور اس کی طرف سے کچھ قرآن پڑھو اور تم لوگ کوئی کام کرو ہم تم پر گواہ ہوتے ہیں جب تم اس کو شروع کرتے ہو، اور تمہارے رب سے ذرہ بھر کوئی چیز غائب نہیں زمین میں نہ آسمان میں اور نہ اس سے چھوٹی اور نہ اس سے بڑی کوئی چیز نہیں جو ایک روشن کتاب میں نہ ہو\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mcdxxvi{سن لو بیشک اللہ کے ولیوں پر نہ کچھ خو ف ہے نہ کچھ غم\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mcdxxvii{وہ جو ایمان لائے اور پرہیزگاری کرتے ہیں،\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mcdxxviii{انہیں خوشخبری ہے دنیا کی زندگی میں اور آخرت میں، اللہ کی باتیں بدل نہیں سکتیں یہی بڑی کامیابی ہے،\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mcdxxix{اور تم ان کی باتو ں کا غم نہ کرو بیشک عزت ساری اللہ کے لیے ہے وہی سنتا جانتا ہے،\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mcdxxx{سن لو بیشک اللہ ہی کے مِلک ہیں جتنے آسمانوں میں ہیں اور جتنے زمینوں میں اور کاہے کے پیچھے جارہے ہیں وہ جو اللہ کے سوا شریک پکار رہے ہیں، وہ تو پیچھے نہیں جاتے مگر گمان کے اور وہ تو نہیں مگر اٹکلیں دوڑاتے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mcdxxxi{وہی ہے جس نے تمہارے لیے رات بنائی کہ اس میں چین پاؤ اور دن بنایا تمہاری آنکھوں کھولتا بیشک اس میں نشانیاں ہیں سننے والوں کے لیے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mcdxxxii{بولے اللہ نے اپنے لیے اولاد بنائی پاکی اس کو، وہی بے نیاز ہے، اسی کا ہے جو کچھ آسمانوں میں ہے اور جو کچھ زمین میں تمہارے پاس اس کی کوئی بھی سند نہیں، کیا اللہ پر وہ بات بتاتے ہو جس کا تمہیں علم نہیں،\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mcdxxxiii{تم فرماؤ وہ جو اللہ پر جھوٹ باندھتے ہیں ان کا بھلا نہ ہوگا،\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mcdxxxiv{دنیا میں کچھ برت لینا (فائدہ اٹھانا) ہے پھر انہیں ہماری طرف واپس آنا پھر ہم انہیں سخت عذاب چکھائیں گے بدلہ ان کے کفر کا،\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mcdxxxv{اور انہیں نوح کی خبر پڑھ کر سناؤ جب اس نے اپنی قوم سے کہا اے میری قوم اگر تم پر شاق گزرا ہے میرا کھڑا ہونا اور اللہ کی نشانیاں یاد دلانا تو میں نے اللہ ہی پر بھروسہ کیا تو مِل کر کام کرو اور اپنے جھوٹے معبودوں سمیت اپنا کام پکا کرلو تمہارے کام میں تم پر کچھ گنجلک (الجھن) نہ رہے پھر جو ہو سکے میرا کرلو اور مجھے مہلت نہ دو\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mcdxxxvi{پھر اگر تم منہ پھیرو تو میں تم سے کچھ اجرت نہیں مانگتا میرا اجر تو نہیں مگر اللہ پر اور مجھے حکم ہے کہ میں مسلمانوں سے ہوں،\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mcdxxxvii{تو انہوں نے اسے جھٹلایا تو ہم نے اسے اور جو اس کے ساتھ کشتی میں تھے ان کو نجات دی اور انہیں ہم نے نائب کیا اور جنہوں نے ہماری آیتیں جھٹلائیں ان کو ہم نے ڈبو دیا تو دیکھو ڈرائے ہوؤں کا انجام کیسا ہوا،\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mcdxxxviii{پھر اس کے بعد اور رسول ہم نے ان کی قوموں کی طرف بھیجے تو وہ ان کے پاس روشن دلیلیں لائے تو وہ ایسے نہ تھے کہ ایمان لاتے اس پر جسے پہلے جھٹلا چکے تھے، ہم یونہی مہر لگادیتے ہیں سرکشوں کے دلوں پر،\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mcdxxxix{پھر ان کے بعد ہم نے موسٰی اور ہارون کو فرعون اور اس کے درباریوں کی طرف اپنی نشانیاں دے کر بھیجا تو انہوں نے تکبر کیا اور وہ مجرم لوگ تھے،\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mcdxl{تو جب ان کے پاس ہماری طرف سے حق آیا بولے یہ تو ضرور کھلا جادو ہے،\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mcdxli{موسیٰ نے کہا کیا حق کی نسبت ایسا کہتے ہو جب وہ تمہارے پاس آیا کیا یہ جادو ہے اور جادوگر مراد کو نہیں پہنچتے،\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mcdxlii{بولے کیا تم ہمارے پاس اس لیے آئے ہو کہ ہمیں اس سے پھیردو جس پر ہم نے اپنے باپ دادا کو پایا اور زمین میں تمہیں دونوں کی بڑائی رہے، اور ہم تم پر ایمان لانے کے نہیں،\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mcdxliii{اور فرعون بولا ہر جادوگر علم والے کو میرے پاس لے آؤ،\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mcdxliv{پھر جب جادوگر آئے ان سے موسیٰ نے کہا ڈالو جو تمہیں ڈالنا ہے\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mcdxlv{پھر جب انہوں نے ڈالا موسیٰ نے کہا یہ جو تم لائے یہ جادو ہے اب اللہ اسے باطل کردے گا، اللہ مفسدوں کا کام نہیں بناتا،\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mcdxlvi{اور اللہ اپنی باتوں سے حق کو حق کر دکھاتا ہے پڑے برا مانیں مجرم،\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mcdxlvii{تو موسیٰ پر ایمان نہ لائے مگر اس کی قوم کی اولاد سے کچھ لوگ فرعون اور اس کے درباریوں سے ڈرتے ہوئے کہ کہیں انہیں ہٹنے پر مجبور نہ کردیں اور بیشک فرعون زمین پر سر اٹھانے والا تھا، اور بیشک وہ حد سے گزر گیا\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mcdxlviii{اور موسیٰ نے کہا اے میری قوم اگر تم اللہ پر ایمان لائے تو اسی پر بھروسہ کرو اگر تم اسلام رکھتے ہو،\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mcdxlix{بولے ہم نے اللہ پر بھروسہ کیا الہٰی ہم کو ظالم لوگوں کے لیے آزمائش نہ بنا\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mcdl{اور اپنی رحمت فرماکر ہمیں کافروں سے نجات دے\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mcdli{اور ہم نے موسیٰ اور اس کے بھائی کو وحی بھیجی کہ مصر میں اپنی قوم کے لیے مکانات بناؤ اور اپنے گھروں کو نماز کی جگہ کرو اور نماز قائم رکھو، اور مسلمانوں کو خوشخبری سناؤ\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mcdlii{اور موسیٰ نے عرض کی اے رب ہمارے تو نے فرعون اور اس کے سرداروں کو آرائش اور مال دنیا کی زندگی میں دیے، اے رب ہمارے! اس لیے کہ تیری راہ سے بہکادیں، اے رب ہمارے! ان کے مال برباد کردے اور ان کے دل سخت کردے کہ ایمان نہ لائیں جب تک دردناک عذاب نہ دیکھ لیں\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mcdliii{فرمایا تم دونوں کی دعا قبول ہوئی تو ثابت قدم رہو اور نادانوں کی راہ نہ چلو\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mcdliv{اور ہم بنی اسرائیل کو دریا پار لے گئے تو فرعون اور اس کے لشکروں نے ان کا پیچھا کیا سرکشی اور ظلم سے یہاں تک کہ جب اسے ڈوبنے نے ا ٓ لیا بولا میں ایمان لایا کہ کوئی سچا معبود نہیں سوا اس کے جس پر بنی اسرائیل ایمان لائے اور میں مسلمان ہوں\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mcdlv{کیا اب اور پہلے سے نافرمان رہا اور تو فسادی تھا\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mcdlvi{آج ہم تیری لاش کو اوترا دیں (باقی رکھیں) گے تو اپنے پچھلوں کے لیے نشانی ہو اور بیشک لوگ ہما ری آ یتو ں سے غافل ہیں،\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mcdlvii{اور بیشک ہم نے بنی اسرائیل کو عزت کی جگہ دی اور انہیں ستھری روزی عطا کی تو اختلاف میں نہ پڑے مگر علم آنے کے بعد بیشک تمہارا رب قیامت کے دن ان میں فیصلہ کردے گا جس بات میں جھگڑتے تھے\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mcdlviii{اور اے سننے والے! اگر تجھے کچھ شبہ ہو اس میں جو ہم نے تیری طرف اتارا تو ان سے پوچھ دیکھ جو تجھ سے پہلے کتاب پڑھنے والے ہیں بیشک تیرے پاس تیرے رب کی طرف سے حق آیا تو تُو ہر گز شک والوں میں نہ ہو،\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mcdlix{اور ہرگز ان میں نہ ہونا جنہوں نے اللہ کی آیتیں جھٹلائیں کہ تو خسارے والوں میں ہوجائے گا،\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mcdlx{بیشک وہ جن پر تیرے رب کی بات ٹھیک پڑچکی ہے ایمان نہ لائیں گے،\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mcdlxi{اگرچہ سب نشانیاں ان کے پاس آئیں جب تک دردناک عذاب نہ دیکھ لیں\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mcdlxii{تو ہوئی ہوتی نہ کوئی بستی کہ ایمان لاتی تو اس کا ایمان کام آتا ہاں یونس کی قوم، جب ایمان لائے ہم نے ان سے رسوائی کا عذاب دنیا کی زندگی میں ہٹادیا اور ایک وقت تک انہیں برتنے دیا\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mcdlxiii{اور اگر تمہارا رب چاہتا زمین میں جتنے ہیں سب کے سب ایمان لے آتے تو کیا تم لوگوں کو زبردستی کرو گے یہاں تک کہ مسلمان ہوجائیں\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mcdlxiv{اور کسی جان کی قدرت نہیں کہ ایمان لے آئے مگر اللہ کے حکم سے اور عذاب ان پر ڈالنا ہے جنہیں عقل نہیں،\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mcdlxv{تم فرماؤ دیکھو آسمانوں اور زمین میں کیا ہے اور آیتیں اور رسول انہیں کچھ نہیں دیتے جن کے نصیب میں ایمان نہیں،\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mcdlxvi{تو انہیں کاہے کا انتظار ہے مگر انہیں لوگوں کے سے دنوں کا جو ان سے پہلے ہو گزرے تم فرماؤ تو انتظار کرو میں بھی تمہارے ساتھ انتظار میں ہوں\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mcdlxvii{پھر ہم اپنے رسولوں اور ایمان والوں کو نجات دیں گے بات یہی ہے ہمارے ذمہ کرم پر حق ہے مسلمانوں کو نجات دینا،\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mcdlxviii{تم فرماؤ، اے لوگو! اگر تم میرے دین کی طرف سے کسی شبہ میں ہو تو میں تو اسے نہ پوجوں کا جسے تم اللہ کے سوا پوجتے ہو ہاں اس اللہ کو پوجتا ہوں جو تمہاری جان نکالے گا اور مجھے حکم ہے کہ ایمان والوں میں ہوں،\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mcdlxix{اور یہ کہ اپنا منہ دین کے لیے سیدھا رکھ سب سے الگ ہوکر اور ہرگز شرک والوں میں نہ ہونا،\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mcdlxx{اور اللہ کے سوا اس کی بندگی نہ کر جو نہ تیرا بھلا کرسکے نہ برا، پھر اگر ایسا کرے تو اس وقت تو ظالموں سے ہوگا،\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mcdlxxi{اور اگر تجھے اللہ کوئی تکلیف پہنچائے تو اس کا کوئی ٹالنے والا نہیں اس کے سوا، اور اگر تیرا بھلا چاہے تو اس کے فضل کے رد کرنے والا کوئی نہیں اسے پہنچا تا ہے اپنے بندوں میں جسے چاہے، اور وہی بخشنے والا مہربان ہے،\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mcdlxxii{تم فرماؤ اے لوگو! تمہارے پاس تمہارے رب کی طرف سے حق آیا تو جو راہ پر آیا وہ اپنے بھلے کو راہ پر آیا اور جو بہکا وہ اپنے برے کو بہکا اور کچھ میں کڑوڑا (حاکمِ اعلیٰ) نہیں\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mcdlxxiii{اور اس پر چلو جو تم پر وحی ہوتی ہے اور صبر کرو یہاں تک کہ اللہ حکم فرمائے اور وہ سب سے بہتر حکم فرمانے والا ہے\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mcdlxxiv{\basmalahur یہ ایک کتاب ہے جس کی آیتیں حکمت بھری ہیں پھر تفصیل کی گئیں حکمت والے خبردار کی طرف سے،\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mcdlxxv{کہ بندگی نہ کرو مگر اللہ کی بیشک میں تمہارے لیے اس کی طرف سے ڈر اور خوشی سنانے والا ہوں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mcdlxxvi{اور یہ کہ اپنے رب سے معافی مانگو پھر اس کی طرف توبہ کرو تمہیں بہت اچھا برتنا (فائدہ اٹھانا) دے گا ایک ٹھہرائے وعدہ تک اور ہر فضیلت والے کو اس کا فضل پہنچائے گا اور اگر منہ پھیرو تو میں تم پر بڑے دن کے عذاب کا خوف کرتا ہوں،\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mcdlxxvii{تمہیں اللہ ہی کی طرف پھرنا ہے اور وہ ہر شے پر قادر\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mcdlxxviii{سنو وہ اپنے سینے دوہرے کرتے (منہ چھپاتے) ہیں کہ اللہ سے پردہ کریں سنو جس وقت وہ اپنے کپڑوں سے سارا بدن ڈھانپ لیتے ہیں اس وقت بھی اللہ ان کا چھپا اور ظاہر سب کچھ جانتا ہے بیشک وہ دلوں کی بات جاننے والا ہے،\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mcdlxxix{اور زمین پر چلنے والا کوئی ایسا نہیں جس کا رزق اللہ کے ذمہٴ کرم پر نہ ہو اور جانتا ہے کہ کہاں ٹھہرے گا اور کہاں سپرد ہوگا سب کچھ ایک صاف بیان کرنے والی کتاب میں ہے،\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mcdlxxx{اور وہی ہے جس نے آسمانوں اور زمین کو چھ دن میں بنایا اور اس کا عرش پانی پر تھا کہ تمہیں آزمائے تم میں کس کا کام اچھا ہے، اور اگر تم فرماؤ کہ بیشک تم مرنے کے بعد اٹھائے جاؤ گے تو کافر ضرور کہیں گے کہ یہ تو نہیں مگر کھلا جادو\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mcdlxxxi{اور اگر ہم ان سے عذاب کچھ گنتی کی مدت تک ہٹادیں تو ضرور کہیں گے کس چیز نے روکا ہے سن لو جس دن ان پر آئے گا ان سے پھیرا نہ جائے گا، اور انہیں گھیرے گا وہی عذاب جس کی ہنسی اڑاتے تھے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mcdlxxxii{اور اگر ہم آدمی کو اپنی کسی رحمت کا مزہ دیں پھر اسے اس سے چھین لیں ضرور وہ بڑا ناامید ناشکرا ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mcdlxxxiii{اور اگر ہم اسے نعمت کا مزہ دیں اس مصیبت کے بعد جس اسے پہنچی تو ضرور کہے گا کہ برائیاں مجھ سے دور ہوئیں بیشک وہ خوش ہونے والا بڑائی مارنے والا ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mcdlxxxiv{مگر جنہوں نے صبر کیا اور اچھے کام کیے ان کے لیے بخشش اور بڑا ثواب ہے،\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mcdlxxxv{تو کیا جو وحی تمہاری طرف ہوتی ہے اس میں سے کچھ تم چھوڑ دو گے اور اس پر دل تنگ ہوگے اس بناء پر کہ وہ کہتے ہیں ان کے ساتھ کوئی خزانہ کیوں نہ اترا ان کے ساتھ کوئی فرشتہ آتا، تم تو ڈر سنانے والے ہو اور اللہ ہر چیز پر محافظ ہے،\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mcdlxxxvi{کیا یہ کہتے ہیں کہ انھوں نے اسے جی سے بنالیا، تم فرماؤ کہ تم ایسی بنائی ہوئی دس سورتیں لے آؤ اور اللہ کے سوا جو مل سکیں سب کو بلالو اگر تم سچے ہو\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mcdlxxxvii{تو اے مسلمانو اگر وہ تمہاری اس بات کا جواب نہ دے سکیں تو سمجھ لو کہ وہ اللہکے علم ہی سے اترا ہے اور یہ کہ اس کے سوا کوئی سچا معبود نہیں تو کیا اب تم مانو گے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mcdlxxxviii{جو دنیا کی زندگی اور آرائش چاہتا ہو ہم اس میں ان کا پورا پھل دے دیں گے اور اس میں کمی نہ دیں گے،\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mcdlxxxix{یہ ہیں وہ جن کے لیے آخرت میں کچھ نہیں مگر آ گ اور اکارت گیا جو کچھ وہاں کرتے تھے اور نابود ہوئے جو ان کے عمل تھے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mcdxc{تو کیا وہ جو اپنے رب کی طرف سے روشن دلیل پر ہو اور اس پر اللہ کی طرف سے گواہ آئے اور اس سے پہلے موسیٰ کی کتاب پیشوا اور رحمت وہ اس پر ایمان لاتے ہیں، اور جو اس کا منکر ہو سارے گروہوں میں تو آگ اس کا وعدہ ہے تو اے سننے والے! تجھے کچھ اس میں شک نہ ہو، بیشک وہ حق ہے تیرے رب کی طرف سے لیکن بہت آدمی ایمان نہیں رکھتے،\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mcdxci{اور اس سے بڑھ کر ظالم کون جو اللہ پر جھوٹ باندھے اور اپنے رب کے حضور پیش کیے جائیں گے اور گواہ کہیں گے یہ ہیں جنہوں نے اپنے رب پر جھوٹ بولا تھا، ارے ظا لموں پر خدا کی لعنت\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mcdxcii{جو اللہ کی راہ سے روکتے ہیں اور اس میں کجی چاہتے ہیں، اور وہی آخرت کے منکر ہیں،\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mcdxciii{وہ تھکانے والے نہیں زمین میں اور نہ اللہ سے جدا ان کے کوئی حمایتی انہیں عذاب پر عذاب ہوگا وہ نہ سن سکتے تھے اور نہ دیکھتے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mcdxciv{وہی ہیں جنہوں نے اپنی جانیں گھاٹے میں ڈالیں اور ان سے کھوئی گئیں جو باتیں جوڑتے تھے خواہ نخواہ\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mcdxcv{(ضرور) وہی آخرت میں سب سے زیادہ نقصان میں ہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mcdxcvi{بیشک جو ایمان لائے اور اچھے کام کیے اور اپنے رب کی طرف رجوع لائے وہ جنت والے ہیں، وہ اس میں ہمیشہ رہیں گے،\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mcdxcvii{دونوں فریق کا حال ایسا ہے جیسے ایک اندھا اور بہرا اور دوسرا دیکھتا اور سنتا کيا ان دونوں حال کا ايک سا ہے تو کياتم دہيان نہيں کرتے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mcdxcviii{اور بے شک ہم نے نوح کو اس کی قوم کی طرف بھيجا کہ میں تمہارے لیے صریح ڈر سنانے والا ہوں\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mcdxcix{کہ اللہ کے سوا کسی کو نہ پوجو، بیشک میں تم پر ایک مصیبت والے دن کے عذاب سے ڈرتا ہوں\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@md{تو اس کی قوم کے سردار جو کافر ہوئے تھے بولے ہم تو تمہیں اپنے ہی جیسا آدمی دیکھتے ہیں اور ہم نہیں دیکھتے کہ تمہاری پیروی کسی نے کی ہو مگر ہمارے کمینوں نے سرسری نظر سے اور ہم تم میں اپنے اوپر کوئی بڑائی نہیں پاتے بلکہ ہم تمہیں جھوٹا خیال کرتے ہیں،\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mdi{بولا اے میری قوم! بھلا بتاؤ تو اگر میں اپنے رب کی طرف سے دلیل پر ہوں اور اس نے مجھے اپنے پاس سے رحمت بخشی تو تم اس سے اندھے رہے، کیا ہم اسے تمہارے گلے چپیٹ (چپکا) دیں اور تم بیزار ہو\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mdii{اور اے قوم! میں تم سے کچھ اس پر مال نہیں مانگتا میرا اجر تو اللہ ہی پر ہے اور میں مسلمانوں کو دور کرنے والا نہیں بیشک وہ اپنے رب سے ملنے والے ہیں لیکن میں تم کو نرے جاہل لوگ پا تا ہوں\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mdiii{اور اے قوم مجھے اللہ سے کون بچالے گا اگر میں انہیں دور کروں گا، تو کیا تمہیں دھیان نہیں،\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mdiv{اور میں تم سے نہیں کہتا کہ میرے پاس اللہ کے خزانے ہیں اور نہ یہ کہ میں غیب جان جانتا ہوں اور نہ یہ کہتا ہوں کہ میں فرشتہ ہوں اور میں انہیں نہیں کہتا جن کو تمہاری نگاہیں حقیر سمجھتی ہیں کہ ہرگز انہیں اللہ کوئی بھلائی نہ دے گا، اللہ خوب جانتا ہے جو ان کے دلوں میں ہے ایسا کروں تو ضرور میں ظالموں میں سے ہوں\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mdv{بولے اے نوح تم ہم سے جھگڑے اور بہت ہی جھگڑے تو لے ا ٓ ؤ جس کا ہمیں وعدے دے رہے ہو اگر تم سچے ہو،\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mdvi{بولا وہ تو اللہ تم پر لائے گا اگر چاہے اور تم تھکا نہ سکو گے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mdvii{اور تمہیں میری نصیحت نفع نہ دے گی اگر میں تمہارا بھلا چاہوں جبکہ اللہ تمہاری گمراہی چاہے، وہ تمہارا رب ہے، اور اسی کی طرف پھرو گے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mdviii{کیا یہ کہتے ہیں کہ انہوں نے اپنے جی سے بنالیا تم فرماؤ اگر میں نے بنالیا ہوگا تو میرا گناہ مجھ پر ہے اور میں تمہارے گناہ سے الگ ہوں،\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mdix{اور نوح کو وحی ہوئی تمہاری قوم سے مسلمان نہ ہوں گے مگر جتنے ایمان لاچکے تو غم نہ کھا اس پر جو وہ کرتے ہیں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mdx{اور کشتی بناؤ ہمارے سامنے اور ہمارے حکم سے اور ظالموں کے بارے میں مجھ سے بات نہ کرنا وہ ضرور ڈوبائے جائیں گے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mdxi{اور نوح کشتی بناتا ہے اور جب اس کی قوم کے سردار اس پر گزرتے اس پر ہنستے بولا اگر تم ہم پر ہنستے ہو تو ایک وقت ہم تم پر ہنسیں گے جیسا تم ہنستے ہو\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mdxii{تو اب جان جاؤ گے کس پر آتا ہے وہ عذاب کہ اسے رسوا کرے اور اترتا ہے وہ عذاب جو ہمیشہ رہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mdxiii{یہاں تک کہ کہ جب ہمارا حکم آیا اور تنور اُبلا ہم نے فرمایا کشتی میں سوار کرلے ہر جنس میں سے ایک جوڑا نر و مادہ اور جن پر بات پڑچکی ہے ان کے سوا اپنے گھر والوں اور باقی مسلمانوں کو اور اس کے ساتھ مسلمان نہ تھے مگر تھوڑے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mdxiv{اور بولا اس میں سوار ہو اللہ کے نام پر اس کا چلنا اور اس کا ٹھہرنا بیشک میرا رب ضرور بخشنے والا مہربان ہے،\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mdxv{اور وہی انہیں لیے جارہی ہے ایسی موجوں میں جیسے پہاڑ اور نوح نے اپنے بیٹے کو پکارا اور وہ اس سے کنارے تھا اے میرے بچے ہمارے ساتھ سوار ہوجا اور کافروں کے ساتھ نہ ہو\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mdxvi{بولا اب میں کسی پہاڑ کی پناہ لیتا ہوں وہ مجھے پانی سے بچالے گا، کہا آج اللہ کے عذاب سے کوئی بچانے والا نہیں مگر جس پر وہ رحم کرے اور ان کے بیچ میں موج آڑے آئی تو وہ ڈوبتوں میں رہ گیا\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mdxvii{اور حکم فرمایا گیا کہ اے زمین! اپنا پانی نگل لے اور اے آسمان! تھم جا اور پانی خشک کردیا گیا اور کام تمام ہوا اور کشتی کوہ ِ جودی پر ٹھہری اور فرمایا گیا کہ دور ہوں بے انصاف لوگ،\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mdxviii{اور نوح نے اپنے رب کو پکارا عرض کی اے میرے رب میرا بیٹا بھی تو میرا گھر والا ہے اور بیشک تیرا وعدہ سچا ہے اور تو سب سے بڑا حکم والا\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mdxix{فرمایا اے نوح! وہ تیرے گھر والوں میں نہیں بیشک اس کے کام بڑے نالائق ہیں، تو مجھ سے وہ بات نہ مانگ جس کا تجھے علم نہیں میں تجھے نصیحت فرماتا ہوں کہ نادان نہ بن،\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mdxx{عرض کی اے رب میرے میں تیری پناہ چاہتا ہوں کہ تجھ سے وہ چیز مانگوں جس کا مجھے علم نہیں، اور اگر تو مجھے نہ بخشے اور رحم نہ کرے تو میں زیاں کار ہوجاؤں،\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mdxxi{فرمایا گیا اے نوح! کشتی سے اتر ہماری طرف سے سلام اور برکتوں کےساتھ جو تجھ پر ہیں اور تیرے ساتھ کے کچھ گروہوں پر اور کچھ گروہ ہیں جنہیں ہم دنیا برتنے دیں گے پھر انہیں ہماری طرف سے دردناک عذاب پہنچے گا\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mdxxii{یہ غیب کی خبریں ہم تمہاری طرف وحی کرتے ہیں انہیں نہ تم جانتے تھے نہ تمہاری قوم اس سے پہلے، تو صبر کرو بیشک بھلا انجام پرہیزگاروں کا\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mdxxiii{اور عاد کی طرف ان کے ہم قوم ہود کو کہا اے میری قوم! اللہ کو پوجو اس کے سوا تمہارا کوئی معبود نہیں، تم تو بڑے مفتری (بالکل جھوٹے الزام عائد کرنے والے) ہو\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mdxxiv{اے قوم! میں اس پر تم سے کچھ اجرت نہیں مانگتا، میری مزدوری تو اسی کے ذمہ ہے جس نے مجھے پیدا کیا تو کیا تمہیں عقل نہیں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mdxxv{اور اے میری قوم اپنے رب سے معافی چاہو پھر اس کی طرف رجوع لاؤ تم پر زور کا پانی بھیجے گا، اور تم میں جتنی قوت ہے اس سے زیادہ دے گا اور جرم کرتے ہوئے روگردانی نہ کرو\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mdxxvi{بولے اے ہود تم کوئی دلیل لے کر ہمارے پاس نہ آئے اور ہم خالی تمہارے کہنے سے اپنے خداؤں کو چھوڑنے کے نہیں نہ تمہاری بات پر یقین لائیں،\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mdxxvii{ہم تو یہی کہتے ہیں کہ ہمارے کسی خدا کی تمہیں بری جھپٹ (پکڑ) پہنچی کہا میں اللہ کو گواہ کرتا ہوں اور تم سب گواہ ہوجاؤ کہ میں بیزار ہوں ان سب سے جنہیں تم اللہ کے سوا اس کا شریک ٹھہراتے ہو،\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mdxxviii{تم سب مل کر میرا برا چاہو پھر مجھے مہلت نہ دو\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mdxxix{میں نے اللہ پر بھروسہ کیا جو میرا رب ہے اور تمہارا رب، کوئی چلنے والا نہیں جس کی چوٹی اس کے قبضہٴ قدرت میں نہ ہو بیشک میرا رب سیدھے راستہ پر ملتا ہے،\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mdxxx{پھر اگر تم منہ پھیرو تو میں تمہیں پہنچا چکا جو تمہاری طرف لے کر بھیجا گیا اور میرا رب تمہاری جگہ اوروں کو لے آئے گا اور تم اس کا کچھ نہ بگاڑ سکو گے بیشک میرا رب ہر شے پر نگہبان ہے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mdxxxi{اور جب ہمارا حکم آیا ہم نے ہود اور اس کے ساتھ کے مسلمانوں کو اپنی رحمت فرما کر بچالیا اور انہیں سخت عذاب سے نجات دی،\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mdxxxii{اور یہ عاد ہیں کہ اپنے رب کی آیتوں سے منکر ہوئے اور اس کے رسولوں کی نافرمانی کی اور ہر بڑے سرکش ہٹ دھرم کے کہنے پر چلے،\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mdxxxiii{اور ان کے پیچھے لگی اس دنیا میں لعنت اور قیامت کے دن، سن لو! بیشک عاد اپنے رب سے منکر ہوئے، ارے دور ہوں عاد ہود کی قوم،\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mdxxxiv{اور ثمود کی طرف ان کے ہم قوم صا لح کو کہا اے میری قوم اللہ کو پوجو اس کے سوا تمہارا کوئی معبود نہیں اس نے تمہیں زمین میں پیدا کیا اور اس میں تمہیں بسایا تو اس سے معافی چاہو پھر اس کی طرف رجوع لاؤ، بیشک میرا رب قریب ہے دعا سننے والا،\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mdxxxv{بولے اے صا لح! اس سے پہلے تو تم ہم میں ہونہار معلوم ہوتے تھے کیا تم ہمیں اس سے منع کرتے ہو کہ اپنے باپ دادا کے معبودوں کو پوجیں اور بیشک جس بات کی طرف ہمیں بلاتے ہو ہم اس سے ایک بڑے دھوکا ڈالنے والے شک میں ہیں،\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mdxxxvi{بولا اے میری قوم! بھلا بتاؤ تو اگر میں اپنے رب کی طرف سے روشن دلیل پر ہوں اور اس نے مجھے اپنے پاس سے رحمت بخشی تو مجھے اس سے کون بچائے گا اگر میں اس کی نافرمانی کروں تو تم مجھے سوا نقصان کے کچھ نہ بڑھاؤ گے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mdxxxvii{اور اے میری قوم! یہ اللہ کا ناقہ ہے تمہارے لیے نشانی تو اسے چھوڑ دو کہ اللہ کی زمین میں کھائے اور اسے بری طرح ہاتھ نہ لگانا کہ تم کو نزدیک عذاب پہنچے گا\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mdxxxviii{تو انہوں نے اس کی کونچیں کاٹیں تو صا لح نے کہا اپنے گھرو ں میں تین دن اور برت لو (فائدہ اٹھالو) یہ وعدہ ہے کہ جھوٹا نہ ہوگا\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mdxxxix{پھر جب ہمارا حکم آیا ہم نے صا لح اور اس کے ساتھ کے مسلمانوں کو اپنی رحمت فرماکر بچالیا اور اس دن کی رسوائی سے، بیشک تمہارا رب قومی عزت والا ہے،\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mdxl{اور ظالموں کو چنگھاڑ نے آ لیا تو صبح اپنے گھروں میں گھٹنوں کے بل پڑے رہ گئے،\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mdxli{گویا کبھی یہاں بسے ہی نہ تھے، سن لو! بیشک ثمود اپنے رب سے منکر ہوئے ارے لعنت ہو ثمود پر،\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mdxlii{اور بیشک ہمارے فرشتے ابراہیم کے پاس مژدہ لے کر آئے بولے سلام کہا کہا سلام پھر کچھ دیر نہ کی کہ ایک بچھڑا بھنا لے آئے\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mdxliii{پھر جب دیکھا کہ ان کے ہاتھ کھانے کی طرف نہیں پہنچتے ان کو اوپری سمجھا اور جی ہی جی میں ان سے ڈرنے لگا، بولے ڈریے نہیں ہم قوم لوط کی طرف بھیجے گئے ہیں،\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mdxliv{اور اس کی بی بی کھڑی تھی وہ ہنسنے لگی تو ہم نے اسے اسحاق کی خوشخبری دی اور اسحاق کے پیچھے یعقوب کی\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mdxlv{بولی ہائے خرابی کیا میرے بچہ ہوگا اور میں بوڑھی ہوں اور یہ ہیں میرے شوہر بوڑھے بیشک یہ تو اچنبھے کی بات ہے،\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mdxlvi{فرشتے بولے کیا اللہ کے کام کا اچنبھا کرتی ہو اللہ کی رحمت اور اس کی برکتیں تم پر اس گھر والو! بیشک وہی ہے سب خوبیوں والا عزت والا،\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mdxlvii{پھر جب ابراہیم کا خوف زائل ہوا اور اسے خوشخبری ملی ہم سے قوم لوط کے بارے میں جھگڑنے لگا،\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mdxlviii{بیشک ابراہیم تحمل والا بہت آہیں کرنے والا رجوع کرنے والا ہے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mdxlix{اے ابراہیم اس خیال میں نہ پڑ بیشک تیرے رب کا حکم آچکا اور بیشک ان پر عذاب آنے والا ہے کہ پھیرا نہ جائے گا،\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mdl{اور جب لوط کے یہاں ہمارے فرشتے آئے اسے ان کا غم ہوا او ر ان کے سبب دل تنگ ہوا اور بولا یہ بڑی سختی کا دن ہے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mdli{اور اس کے پاس کی قوم دوڑتی آئی، ور انہیں آگے ہی سے برے کاموں کی عادت پڑی تھی کہا اے قوم! یہ میری قوم کی بیٹیاں ہیں یہ تمہارے لیے ستھری ہیں تو اللہ سے ڈرو اور مجھے میرے مہمانوں میں رسوا نہ کرو، کیا تم میں ایک آدمی بھی نیک چلن نہیں،\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mdlii{بولے تمہیں معلوم ہے کہ تمہاری قوم کی بیٹیوں میں ہمارا کوئی حق نہیں اور تم ضرور جانتے ہو جو ہماری خواہش ہے،\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mdliii{بولے اے کاش! مجھے تمہارے مقابل زور ہوتا یا کسی مضبوط پائے کی پناہ لیتا\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mdliv{فرشتے بولے اے لوط ہم تمہارے رب کے بھیجے ہوئے ہیں وہ تم تک نہیں پہنچ سکتے تو اپنے گھر والوں کو راتوں رات لے جاؤ اور تم میں کوئی پیٹھ پھیر کر نہ دیکھے سوائے تمہاری عورت کے اسے بھی وہی پہنچنا ہے جو انہیں پہنچے گا بیشک ان کا وعدہ صبح کے وقت کا ہے کیا صبح قریب نہیں،\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mdlv{پھر جب ہمارا حکم آیا ہم نے اس بستی کے اوپر کو اس کا نیچا کردیا اور اس پر کنکر کے پتھر لگا تار برسائے،\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mdlvi{جو نشان کیے ہوئے تیرے رب کے پاس ہیں اور وہ پتھر کچھ ظالموں سے دور نہیں\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mdlvii{اور مدین کی طرف ان کے ہم قوم شعیب کو کہا اے میری قوم اللہ کو پوجو اس کے سوا کوئی معبود نہیں اور ناپ اور تول میں کمی نہ کرو بیشک میں تمہیں آسودہ حال دیکھتا ہوں اور مجھے تم پر گھیر لینے والے دن کا عذاب کا ڈر ہے\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mdlviii{اور اے میری قوم ناپ اور تول انصاف کے ساتھ پوری کرو اور لوگوں کو ان کی چیزیں گھٹا کر نہ دو اور زمین میں فساد مچاتے نہ پھرو،\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mdlix{اللہ کا دیا جو بچ رہے وہ تمہارے لیے بہتر ہے اگر تمہیں یقین ہو اور میں کچھ تم پر نگہبان نہیں\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mdlx{بولے اے شعیب! کیا تمہاری نماز تمہیں یہ حکم دیتی ہے کہ ہم اپنے باپ دادا کے خداؤں کو چھوڑ دیں یا اپنے مال میں جو چا ہیں نہ کریں ہاں جی تمہیں بڑے عقلمند نیک چلن ہو،\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mdlxi{کہا اے میری قوم بھلا بتاؤ تو اگر میں اپنے رب کی طرف سے ایک روشن دلیل پر ہوں او راس نے مجھے اپنے پاس سے اچھی روزی دی اور میں نہیں چاہتا ہوں کہ جس بات سے تمہیں منع کرتا ہوں آپ اس کے خلاف کرنے لگوں میں تو جہاں تک بنے سنوارنا ہی چاہتا ہوں، اور میری توفیق اللہ ہی کی طرف سے ہے، میں نے اسی پر بھروسہ کیا اور اسی کی طرف رجوع ہوتا ہوں،\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mdlxii{اور اے میری قوم تمہیں میری ضد یہ نہ کموادے کہ تم پر پڑے جو پڑا تھا نوح کی قوم یا ہود کی قوم یا صا لح کی قوم پر، اور لوط کی قوم تو کچھ تم سے دور نہیں\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mdlxiii{اور اپنے رب سے معافی چاہو پھر اس کی طرف رجوع لاؤ، بیشک میرا رب مہربان محبت والا ہے،\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mdlxiv{بولے اے شعیب! ہماری سمجھ میں نہیں آتیں تمہاری بہت سی باتیں اور بیشک ہم تمہیں اپنے میں کمزور دیکھتے ہیں اور اگر تمہارا کنبہ نہ ہوتا تو ہم نے تمہیں پتھراؤ کردیا ہوتا اور کچھ ہماری نگاہ میں تمہیں عزت نہیں،\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mdlxv{کہا اے میری قوم کیا تم پر میرے کنبہ کا دباؤ اللہ سے زیادہ ہے اور اسے تم نے اپنی پیٹھ کے پیچھے ڈال رکھا بیشک جو کچھ تم کرتے ہو سب میرے رب کے بس میں ہے،\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mdlxvi{اور اے قوم تم اپنی جگہ اپنا کام کیے جا ؤ میں اپنا کام کرتا ہوں، اب جاننا چاہتے ہو کس پر آتا ہے وہ عذاب کہ اسے رسوا کرے گا اور کون جھوٹا ہے، اور انتظار کرو میں بھی تمہارے ساتھ انتظار میں ہوں،\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mdlxvii{اور جب ہمارا حکم آیا ہم نے شعیب اور اس کے ساتھ کے مسلمانوں کو اپنی رحمت فرماکر بچالیا اور ظالموں کو چنگھاڑ نے آ لیا تو صبح اپنے گھروں میں گھٹنوں کے بل پڑے رہ گئے،\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mdlxviii{گویا کبھی وہاں بسے ہی نہ تھے، ارے دُور ہوں مدین جیسے دور ہوئے ثمود\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mdlxix{اور بیشک ہم نے موسیٰ کو اپنی آیتوں اور صریح غلبے کے ساتھ،\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mdlxx{فرعون اور ا س کے درباریوں کی طرف بھیجا تو وہ فرعون کے کہنے پر چلے اور فرعون کا کام راستی کا نہ تھا\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mdlxxi{اپنی قوم کے آگے ہوگا قیامت کے دن تو انہیں دوزخ میں لا اتارے گا اور و ه کیا ہی برا گھاٹ اترنے کا،\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mdlxxii{اور ان کے پیچھے پڑی اس جہان میں لعنت اور قیامت کے دن کیا ہی برا انعام جو انہیں ملا،\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mdlxxiii{یہ بستیوں کی خبریں ہیں کہ ہم تمہیں سناتے ہیں ان میں کوئی کھڑی ہے اور کوئی کٹ گئی\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mdlxxiv{اور ہم نے ان پر ظلم نہ کیا خود انہوں نے اپنا برا کیا تو ان کے معبود جنہیں اللہ کے سوا پوجتے تھے ان کے کچھ کام نہ آئے جب تمہارے رب کا حکم آیا اور ان سے انہیں ہلاک کے سوا کچھ نہ بڑھا،\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mdlxxv{اور ایسی ہی پکڑ ہے تیرے رب کی جب بستیوں کو پکڑتا ہے ان کے ظلم پر، بیشک اس کی پکڑ دردناک کرّ ی ہے\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mdlxxvi{بیشک اس میں نشانی ہے اس کے لیے جو آخرت کے عذاب سے ڈرے وہ دن ہے جس میں سب لوگ اکٹھے ہوں گے اور وہ دن حاضری کا ہے\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mdlxxvii{اور ہم اسے پیچھے نہیں ہٹاتے مگر ایک گنی ہوئی مدت کے لیئے\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mdlxxviii{جب وہ دن آئے گا کوئی بے حکم خدا بات نہ کرے گا تو ان میں کوئی بدبخت ہے اور کوئی خوش نصیب\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mdlxxix{تو وہ جو بدبخت ہیں وہ تو دوزخ میں ہیں وہ اس گدھے کی طرح رینکیں گے\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mdlxxx{وہ اس میں رہیں گے جب تک آسمان و زمین رہیں مگر جتنا تمہارے رب نے چاہا بیشک تمہارا رب جب جو چاہے کرے،\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mdlxxxi{اور وہ جو خوش نصیب ہوئے وہ جنت میں ہیں ہمیشہ اس میں رہیں گے جب تک آسمان و زمین مگر جتنا تمہارے رب نے چاہا یہ بخشش ہے کبھی ختم نہ ہوگی،\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mdlxxxii{تو اے سننے والے! دھوکا میں نہ پڑ اس سے جیسے یہ کافر پوجتے ہیں یہ ویسا ہی پوجتے ہیں جیسا پہلے ان کے باپ دادا پوجتے تھے اور بیشک ہم ان کا حصہ انہیں پورا پھیردیں گے جس میں کمی نہ ہوگی،\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mdlxxxiii{اور بیشک ہم نے موسیٰ کو کتاب دی تو اس میں پھوٹ پڑگئی اگر تمہارے رب کی ایک بات پہلے نہ ہوچکی ہوتی تو جبھی ان کا فیصلہ کردیا جاتا اور بیشک وہ اس کی طرف سے دھوکا ڈالنے والے شک میں ہیں\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mdlxxxiv{اور بیشک جتنے ہیں ایک ایک کو تمہارا رب اس کا عمل پورا بھردے گا اسے ان کے کا موں کی خبر ہے،\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mdlxxxv{تو قائم رہو جیسا تمہیں حکم ہے اور جو تمہارے ساتھ رجوع لایا ہے اور اے لوگو! سرکشی نہ کرو بیشک وہ تمہارے کام دیکھ رہا ہے،\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@mdlxxxvi{اور ظالموں کی طرف نہ جھکو کہ تمہیں آ گ چھوئے گی اور اللہ کے سوا تمہارا کوئی حما یتی نہیں پھر مدد نہ پاؤ گے،\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@mdlxxxvii{اور نماز قائم رکھو دن کے دونوں کناروں اور کچھ رات کے حصوں میں بیشک نیکیاں برائیوں کو مٹادیتی ہیں، یہ نصیحت ہے نصیحت ماننے والوں کو،\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@mdlxxxviii{اور صبر کرو کہ اللہ نیکوں کا نیگ (اجر) ضائع نہیں کرتا،\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@mdlxxxix{تو کیوں نہ ہوئے تم میں سے اگلی سنگتوں (قوموں) میں ایسے جن میں بھلائی کا کچھ حصہ لگا رہا ہوتا کہ زمین میں فساد سے روکتے ہاں ان میں تھوڑے تھے وہی جن کو ہم نے نجات دی اور ظالم اسی عیش کے پیچھے پڑے رہے جو انہیں دیا گیا اور وہ گنہگار تھے،\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@mdxc{اور تمہارا رب ایسا نہیں کہ بستیوں کو بے وجہ ہلاک کردے اور ان کے لوگ اچھے ہوں،\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@mdxci{اور اگرتمہارا رب چاہتا تو سب آدمیوں کو ایک ہی امت کردیتا اور وہ ہمیشہ اختلاف میں رہیں گے\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@mdxcii{مگر جن پر تمہارے رب نے رحم کیا اور لوگ اسی لیے بنائے ہیں اور تمہارے رب کی بات پوری ہوچکی کہ بیشک ضرور جہنم بھر دوں گا جنوں اور آدمیوں کو ملا کر\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@mdxciii{اور سب کچھ ہم تمہیں رسولوں کی خبریں سناتے ہیں جس سے تمہا را دل ٹھیرائیں اور اس سورت میں تمہارے پاس حق آیا اور مسلمانوں کو پند و نصیحت\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@mdxciv{اور کافروں سے فرماؤ تم اپنی جگہ کام کیے جاؤ ہم اپنا کام کرتے ہیں\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@mdxcv{اور راہ دیکھو ہم بھی راہ دیکھتے ہیں\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@mdxcvi{اور اللہ ہی کے لیے ہیں آسمانوں اور زمین کے غیب اور اسی کی طرف سب کاموں کی رجوع ہے تو اس کی بندگی کرو اور اس پر بھروسہ رکھو، اور تمہارا رب تمہارے کا موں سے غافل نہیں،\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@mdxcvii{\basmalahur یہ روشن کتاب کی آیتیں ہیں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mdxcviii{بیشک ہم نے اسے عربی قرآن اتارا کہ تم سمجھو،\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mdxcix{ہم تمہیں سب اچھا بیان سناتے ہیں اس لیے کہ ہم نے تمہاری طرف اس قرآن کی وحی بھیجی اگرچہ بیشک اس سے پہلے تمہیں خبر نہ تھی،\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mdc{یاد کرو جب یوسف نے اپنے با پ سے کہا اے میرے باپ میں نے گیارہ تارے اور سورج اور چاند دیکھے انہیں اپنے لیے سجدہ کرتے دیکھا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mdci{کہا اے میرے بچے اپنا خواب اپنے بھائیوں سے نہ کہنا وہ تیرے ساتھ کوئی چا ل چلیں گے بیشک شیطان آدمی کا کھلا دشمن ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mdcii{اور اسی طرح تجھے تیرا رب چن لے گا اور تجھے باتوں کا انجام نکا لنا سکھائے گا اور تجھ پر اپنی نعمت پوری کرے گا اور یعقوب کے گھر والوں پر جس طرح تیرے پہلے دنوں باپ دادا ابراہیم ؑ اور اسحق ؑ پر پوری کی بیشک تیرا رب علم و حکمت والا ہے،\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mdciii{بیشک یوسف اور اس کے بھائیوں میں پوچھنے والوں کے لیے نشانیاں ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mdciv{جب بولے کہ ضرور یوسف اور اس کا بھائی ہمارے باپ کو ہم سے زیادہ پیارے ہیں اور ہم ایک جماعت ہیں بیشک ہمارے باپ صراحةً ان کی محبت میں ڈوبے ہوئے ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mdcv{یوسف کو مار ڈالو یا کہیں زمین میں پھینک آؤ کہ تمہارے باپ کا منہ صرف تمہاری ہی طرف رہے اور اس کے بعد پھر نیک ہوجانا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mdcvi{ان میں ایک کہنے والا بولا یوسف کو مارو نہیں اور اسے اندھے کنویں میں ڈال دو کہ کوئی چلتا اسے آکر لے جائے اگر تمہیں کرنا ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mdcvii{بولے اے ہمارے باپ! آپ کو کیا ہوا کہ یوسف کے معامل ہ میں ہمارا اعتبار نہیں کرتے اور ہم تو اس کے خیر خواہ ہیں،\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mdcviii{کل اسے ہمارے ساتھ بھیج دیجئے کہ میوے کھائے اور کھیلے اور بیشک ہم اس کے نگہبان ہیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mdcix{بولا بیشک مجھے رنج دے گا کہ اسے لے جاؤ اور ڈرتا ہوں کہ اسے بھیڑیا کھالے اور تم اس سے بے خبر رہو\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mdcx{بولے اگر اسے بھیڑیا کھا جائے اور ہم ایک جماعت ہیں جب تو ہم کسی مصرف کے نہیں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mdcxi{پھر جب اسے لے گئے اور سب کی رائے یہی ٹھہری کہ اسے اندھے کنویں میں ڈال دیں اور ہم نے اسے وحی بھیجی کہ ضرور تو انہیں ان کا یہ کام جتادے گا ایسے وقت کہ وہ نہ جانتے ہوں گے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mdcxii{اور رات ہوئے اپنے باپ کے پاس روتے ہوئے آئے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mdcxiii{بولے اے ہمارے باپ ہم دوڑ کرتے نکل گئے اور یوسف کو اپنے اسباب کے پاس چھوڑا تو اسے بھیڑیا کھا گیا اور آپ کسی طرح ہمارا یقین نہ کریں گے اگرچہ ہم سچے ہوں\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mdcxiv{اور اس کے کر ُتے پر ایک جھوٹا خون لگا لائے کہا بلکہ تمہارے دلوں نے ایک بات تمہارے واسطے بنالی ہے تو صبر اچھا، اور اللہ ہی مدد چاہتا ہوں ان باتوں پر جو تم بتارہے ہو\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mdcxv{اور ایک قافلہ آیا انہوں نے اپنا پانی لانے والا بھیجا تو اس نے اپنا ڈول ڈال بولا آہا کیسی خوشی کی بات ہے یہ تو ایک لڑکا ہے اور اسے ایک پونجی بناکر چھپالیا اور اللہ جانتا ہے جو وہ کرتے ہیں،\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mdcxvi{اور بھائیوں نے اسے کھوٹے داموں گنتی کے روپوں پر بیچ ڈالا اور انہیں اس میں کچھ رغبت نہ تھی\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mdcxvii{اور مصر کے جس شخص نے اسے خریدا وہ اپنی عورت سے بولا انہیں عزت سے رکھو شاید ان سے ہمیں نفع پہنچے یا ان کو ہم بیٹا بنالیں اور اسی طرح ہم نے یوسف کو اس زمین میں جماؤ (رہنے کا ٹھکانا) دیا اور اس لیے کہ اسے باتوں کا انجام سکھائیں ۰ف۵۳) اور اللہ اپنے کام پر غالب ہے مگر اکثر آدمی نہیں جانتے،\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mdcxviii{اور جب اپنی پوری قوت کو پہنچا ہم نے اسے حکم اور علم عطا فرمایا اور ہم ایسا ہی صلہ دیتے ہیں نیکوں کو،\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mdcxix{اور وہ جس عورت کے گھر میں تھا اس نے اسے لبھایا کہ اپنا آپا نہ روکے اور دروازے سب بند کردیے اور بولی آؤ تمہیں سے کہتی ہوں کہا اللہ کی پناہ وہ عزیز تو میرا رب یعنی پرورش کرنے والا ہے اس نے مجھے اچھی طرح رکھا بیشک ظالموں کا بھلا نہیں ہوتا،\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mdcxx{اور بیشک عورت نے اس کا ارادہ کیا اور وہ بھی عورت کا ارادہ کرتا اگر اپنے رب کی دلیل نہ دیکھ لیتا ہم نے یوں ہی کیا کہ اس سے برائی اور بے حیائی کو پھیر دیں بیشک وہ ہمارے چنے ہوئے بندوں میں سے ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mdcxxi{اور دونوں دروازے کی طرف دوڑے اور عورت نے اس کا کر ُتا پیچھے سے چیر لیا اور دونوں کو عورت کا میاں دروازے کے پاس ملا بولی کیا سزا ہے اس کی جس نے تیری گھر والی سے بدی چاہی مگر یہ کہ قید کیا جائے یا دکھ کی مار\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mdcxxii{کہا اس نے مجھ کو لبھایا کہ میں اپنی حفاظت نہ کروں اور عورت کے گھر والوں میں سے ایک گواہ نے گواہی دی اگر ان کا کر ُتا آگے سے چرا ہے تو عورت سچی ہے اور انہوں نے غلط کہا\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mdcxxiii{اور اگر ان کا کر ُتا پیچھے سے چاک ہوا تو عورت جھوٹی ہے اور یہ سچے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mdcxxiv{پھر جب عزیز نے اس کا کر ُتا پیچھے سے چرا دیکھا بولا بیشک یہ تم عورتوں کا چرتر (فریب) ہے بیشک تمہارا چرتر (فریب) بڑا ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mdcxxv{اے یوسف! تم اس کا خیال نہ کرو اور اے عورت! تو اپنے گناہ کی معافی مانگ بیشک تو خطاواروں میں ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mdcxxvi{اور شہر میں کچھ عورتیں بولیں کہ عزیز کی بی بی اپنے نوجوان کا دل لبھاتی ہ ے بیشک ان کی محبت اس کے دل میں پَیر گئی (سماگئی) ہے ہم تو اسے صر یح خود رفتہ پاتے ہیں\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mdcxxvii{تو جب زلیخا نے ان کا چرچا سنا تو ان عورتوں کو بلا بھیجا اور ان کے لیے مسندیں تیار کیں اور ان میں ہر ایک کو ایک چھری دی اور یوسف سے کہا ان پر نکل آؤ جب عورتوں نے یوسف کو دیکھا اس کی بڑائی بولنے لگیں اور اپنے ہاتھ کاٹ لیے اور بولیں اللہ کو پاکی ہے یہ تو جنس بشر سے نہیں یہ تو نہیں مگر کوئی معزز فرشتہ،\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mdcxxviii{زلیخا نے کہا تو يہ ہیں وہ جن پر مجھے طعنہ دیتی تھیں اور بیشک میں نے ان کا جِی لبھانا چاہا تو انہوں نے اپنے آپ کو بچا یا اور بیشک اگر وہ یہ کام نہ کریں گے جو میں ان سے کہتی ہوں تو ضرور قید میں پڑیں گے اور وہ ضرور ذلت اٹھائیں گے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mdcxxix{یوسف نے عرض کی اے میرے رب! مجھے قید خانہ زیادہ پسند ہے اس کام سے جس کی طرف یہ مجھے بلاتی ہیں اور اگر تو مجھ سے ان کا مکر نہ پھیرے گا تو میں ان کی طرف مائل ہوں گا اور نادان بنوں گا،\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mdcxxx{تو اس کے رب نے اس کی سن لی اور اس سے عورتوں کا مکر پھیردیا، بیشک وہی سنتا جانتا ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mdcxxxi{پھر سب کچھ نشانیاں دیکھ دکھا کر پچھلی مت انہیں یہی آئی کہ ضرور ایک مدت تک اسے قیدخانہ میں ڈالیں\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mdcxxxii{اور اس کے ساتھ قیدخانہ میں دو جوان داخل ہوئے ان میں ایک بولا میں نے خواب میں دیکھا کہ شراب نچوڑتا ہوں اور دوسرا بولا میں نے خواب دیکھا کہ میرے سر پر کچھ روٹیاں ہیں جن میں سے پرند کھاتے ہیں، ہمیں اس کی تعبیر بتایے، بیشک ہم آپ کو نیکو کار دیکھتے ہیں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mdcxxxiii{یوسف نے کہا جو کھانا تمہیں ملا کرتا ہے وہ تمہارے پاس نہ آنے پائے گا کہ میں اس کی تعبیر اس کے آنے سے پہلے تمہیں بتادوں گا یہ ان علموں میں سے ہے جو مجھے میرے رب نے سکھایا ہے، بیشک میں نے ان لوگوں کا دین نہ مانا جو اللہ پر ایمان نہیں لاتے اور وہ آخرت سے منکر ہیں،\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mdcxxxiv{اور میں نے اپنے باپ دادا ابراہیم ؑ اور اسحق ؑ اور یعقوب کا دین اختیار کیا ہمیں نہیں پہنچتا کہ کسی چیز کو اللہ کا شریک ٹھہرائیں، یہ اللہ کا ایک فضل ہے ہم پر اور لوگوں پر مگر اکثر لوگ شکر نہیں کرتے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mdcxxxv{اے میرے قیدخانہ کے دونوں ساتھیو! کیا جدا جدا رب اچھے یا ایک اللہ جو سب پر غالب،\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mdcxxxvi{تم اس کے سوا نہیں پوجتے مگر نرے نام (فرضی نام) جو تم نے اور تمہارے باپ دادا نے تراش لیے ہیں اللہ نے ان کی کوئی سند نہ اتاری، حکم نہیں مگر اللہ کا اس نے فرمایا کہ اس کے سوا کسی کو نہ پوجو یہ سیدھا دین ہے لیکن اکثر لوگ نہیں جانتے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mdcxxxvii{اے قید خانہ کے دونوں ساتھیو! تم میں ایک تو اپنے رب (بادشاہ) کو شراب پلائے گا رہا دوسرا وہ سو ُلی دیا جائے گا تو پرندے اس کا سر کھائیں گے حکم ہوچکا اس بات کا جس کا تم سوال کرتے تھے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mdcxxxviii{اور یوسف نے ان دونوں میں سے جسے بچتا سمجھا اس سے کہا اپنے رب (بادشاہ) کے پاس میرا ذکر کرنا تو شیطان نے اسے بھلا دیا کہ اپنے رب (بادشاہ) کے سامنے یوسف کا ذکر کرے تو یوسف کئی برس اور جیل خانہ میں رہا\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mdcxxxix{اور بادشاہ نے کہا میں نے خواب میں دیکھیں سات گائیں فربہ کہ انہیں سات دُبلی گائیں کھارہی ہیں اور سات بالیں ہری اور دوسری سات سوکھی اے درباریو! میرے خواب کا جواب دو اگر تمہیں خواب کی تعبیر آتی ہو،\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mdcxl{بولے پریشان خوابیں ہیں اور ہم خواب کی تعبیر نہیں جانتے،\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mdcxli{اور بولا وہ جو ان دونوں میں سے بچا تھا اور ایک مدت بعد اسے یاد آیا میں تمہیں اس کی تعبیر بتاؤں گا مجھے بھیجو\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mdcxlii{اے یوسف! اے صدیق! ہمیں تعبیر دیجئے سات فربہ گایوں کی جنہیں سات دُبلی کھاتی ہیں اور سات ہری بالیں اور دوسری سات سوکھی شاید میں لوگوں کی طرف لوٹ کر جاؤں شاید وہ آگاہ ہوں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mdcxliii{کہا تم کھیتی کرو گے سات برس لگارتار تو جو کاٹو اسے اس کی بال میں رہنے دو مگر تھوڑا جتنا کھالو\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mdcxliv{پھر اس کے بعد سات برس کرّے (سخت تنگی والے) آئیں گے کہ کھا جائیں گے جو تم نے ان کے لیے پہلے جمع کر رکھا تھا مگر تھوڑا جو بچالو\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mdcxlv{پھر ان کے بعد ایک برس آئے گا جس میں لوگوں کو مینھ دیا جائے گا اور اس میں رس نچوڑیں گے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mdcxlvi{اور بادشاہ بولا کہ انہیں میرے پاس لے آؤ تو جب اس کے پاس ایلچی آیا کہا اپنے رب (بادشاہ) کے پاس پلٹ جا پھر اس سے پوچھ کیا حال ہے اور عورتوں کا جنہوں نے اپنے ہاتھ کاٹے تھے، بیشک میرا رب ان کا فریب جانتا ہے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mdcxlvii{بادشاہ نے کہا اے عورتو! تمہارا کیا کام تھا جب تم نے یوسف کا دل لبھانا چاہا، بولیں اللہ کو پاکی ہے ہم نے ان میں کوئی بدی نہیں پائی عزیز کی عورت بولی اب اصلی بات کھل گئی، میں نے ان کا جی لبھانا چاہا تھا اور وہ بیشک سچے ہیں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mdcxlviii{یوسف نے کہا یہ میں نے اس لیے کیا کہ عزیز کو معلوم ہوجائے کہ میں نے پیٹھ پیچھے اس کی خیانت نہ کی اور اللہ دغا بازوں کا مکر نہیں چلنے دیتا،\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mdcxlix{اور میں اپنے نفس کو بے قصور نہیں بتاتا بیشک نفس تو برائی کا بڑا حکم دینے والا ہے مگر جس پر میرا رب رحم کرے بیشک میرا رب بخشنے والا مہربان ہے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mdcl{اور بادشاہ بولا انہيں میرے پاس لے آؤ کہ میں انہیں اپنے لیے چن لوں پھر جب اس سے بات کی کہا بیشک آج آپ ہمارے یہاں معزز معتمد ہیں\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mdcli{یوسف نے کہا مجھے زمین کے خزانوں پر کردے بیشک میں حفاظت والا علم والا ہوں\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mdclii{اور یوں ہی ہم نے یوسف کو اس ملک پر قدرت بخشی اس میں جہاں چاہے رہے ہم اپنی رحمت جسے چاہیں پہنچائیں اور ہم نیکوں کا نیگ (اَجر) ضائع نہیں کرتے،\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mdcliii{اور بیشک آخرت کا ثواب ان کے لیے بہتر جو ایمان لائے اور پرہیزگار رہے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mdcliv{اور یوسف کے بھائی آئے تو اس کے پاس حاضر ہوئے تو یوسف نے انہیں پہچان لیا اور وہ اس سے انجان رہے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mdclv{اور جب ان کا سامان مہیا کردیا کہ اپنا سوتیلا بھائی میرے پاس لے آؤ کیا نہیں دیکھتے کہ میں پورا ناپتا ہوں اور میں سب سے بہتر مہمان نواز ہوں،\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mdclvi{پھر اگر اسے لیکر میرے پاس نہ آؤ تو تمہارے لیے میرے یہاں ماپ نہیں اور میرے پاس نہ پھٹکنا،\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mdclvii{بولے ہم اس کی خواہش کریں گے اس کے باپ سے اور ہمیں یہ ضرور کرنا،\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mdclviii{اور یوسف نے اپنے غلاموں سے کہا ان کی پونجی ان کی خورجیوں میں رکھ دو شاید وہ اسے پہچانیں جب اپنے گھر کی طرف لوٹ کر جائیں شاید وہ واپس آئیں،\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mdclix{پھر جب وہ اپنے باپ کی طرف لوٹ کر گئے بولے اے ہمارے باپ ہم سے غلہ روک دیا گیا ہے تو ہمارے بھائی کو ہمارے پاس بھیج دیجئے کہ غلہ لائیں اور ہم ضرور اس کی حفاظت کریں گے،\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mdclx{کہا کیا اس کے بارے میں تم پر ویسا ہی اعتبار کرلوں جیسا پہلے اس کے بھائی کے بارے میں کیا تھا تو اللہ سب سے بہتر نگہبان اور وہ ہر مہربان سے بڑھ کر مہربان،\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mdclxi{اور جب انہوں نے اپنا اسباب کھولا اپنی پونجی پائی کہ ان کو پھیر دی گئی ہے، بولے اے ہمارے باپ اب اور کیا چاہیں، یہ ہے ہماری پونجی ہمیں واپس کردی گئی اور ہم اپنے گھر کے لیے غلہ لائیں اور اپنے بھائی کی حفاظت کریں اور ایک اونٹ کا بوجھ اور زیادہ پائیں، یہ دنیا بادشاہ کے سامنے کچھ نہیں\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mdclxii{کہا میں ہرگز اسے تمہارے ساتھ نہ بھیجوں گا جب تک تم مجھے کا اللہ کا یہ عہد نہ دے دو کہ ضرور اسے لے کر آ ؤ گے مگر یہ کہ تم گھِر جاؤ پھر انہوں نے یعقوب کو عہد دے دیا کہا اللہ کا ذمہ ہے ان باتوں پر جو کہہ رہے ہیں،\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mdclxiii{اور کہا اے میرے بیٹوں! ایک دروازے سے نہ داخل ہونا اور جدا جدا دروا زوں سے جانا میں تمہیں اللہ سے بچا نہیں سکتا حکم تو سب اللہ ہی کا ہے، میں نے اسی پر بھروسہ کیا اور بھروسہ کرنے والوں کو اسی پر بھروسہ چاہیے،\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mdclxiv{اور جب وہ داخل ہوئے جہاں سے ان کے باپ نے حکم دیا تھا وہ کچھ انہیں کچھ انہیں اللہ سے بچا نہ سکتا ہاں یعقوب کے جی کی ایک خواہش تھی جو اس نے پوری کرلی، اور بیشک وہ صاحب علم ہے ہمارے سکھائے سے مگر اکثر لوگ نہیں جانتے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mdclxv{اور جب وہ یوسف کے پاس گئے اس نے اپنے بھائی کو اپنے پاس جگہ دی کہا یقین جان میں ہی تیرا بھائی ہوں تو یہ جو کچھ کرتے ہیں اس کا غم نہ کھا\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mdclxvi{پھر جب ان کا سامان مہیا کردیا پیالہ اپنے بھائی کے کجاوے میں رکھ دیا پھر ایک منادی نے ندا کی اے قافلہ والو! بیشک تم چور ہو،\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mdclxvii{بولے اور ان کی طرف متوجہ ہوئے تم کیا نہیں پاتے،\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mdclxviii{بولے، بادشاہ کا پیمانہ نہیں ملتا اور جو اسے لائے گا اس کے لیے ایک اونٹ کا بوجھ ہے اور میں اس کا ضامن ہوں،\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mdclxix{بولے خدا کی قسم! تمہیں خوب معلوم ہے کہ ہم زمین میں فساد کرنے نہ آئے اور نہ ہم چور ہیں،\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mdclxx{بولے پھر کیا سزا ہے اس کی اگر تم جھوٹے ہو\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mdclxxi{بولے اس کی سزا یہ ہے کہ جس کے اسباب میں ملے وہی اس کے بدلے میں غلام بنے ہمارے یہاں ظالموں کی یہی سزا ہے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mdclxxii{تو اول ان کی خرُجیوں سے تلاشی شروع کی اپنے بھائی کی خرُجی سے پہلے پھر اسے اپنے بھائی کی خرُجی سے نکال لیا ہم نے یوسف کو یہی تدبیر بتائی بادشاہی قانون میں اسے نہیں پہنچتا تھا کہ اپنے بھائی کو لے لے مگر یہ کہ خدا چاہے ہم جسے چاہیں درجوں بلند کریں اور ہر علم والے اوپر ایک علم والا ہے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mdclxxiii{بھائی بولے اگر یہ چوری کرے تو بیشک اس سے پہلے اس کا بھائی چوری کرچکا ہے تو یوسف نے یہ بات اپنے دل میں رکھی اور ان پر ظاہر نہ کی، جی میں کہا تم بدتر جگہ ہو اور اللہ خوب جانتا ہے جو باتیں بناتے ہو،\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mdclxxiv{بولے اے عزیز! اس کے ایک باپ ہیں بوڑھے بڑے تو ہم میں اس کی جگہ کسی کو لے لو، بیشک ہم تمہارے احسان دیکھ رہے ہیں،\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mdclxxv{کہا خدا کی پناہ کہ ہم میں مگر اسی کو جس کے پاس ہمارا مال ملا جب تو ہم ظالم ہوں گے،\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mdclxxvi{پھر جب اس سے نا امید ہوئے الگ جاکر سرگوشی کرنے لگے، ان کا بڑا بھائی بولا کیا تمہیں خبر نہیں کہ تمہارے باپ نے تم سے اللہ کا عہد لے لیا تھا اور اس سے پہلے یوسف کے حق میں تم نے کیسی تقصیر کی تو میں یہاں سے نہ ٹلوں گا یہاں تک کہ میرے باپ اجازت دیں یا اللہ مجھے حکم فرمائے اور اس کا حکم سب سے بہتر،\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mdclxxvii{اپنے باپ کے پاس لوٹ کر جاؤ پھر عرض کرو اے ہمارے باپ بیشک آپ کے بیٹے نے چوری کی اور ہم تو اتنی ہی بات کے گواہ ہوئے تھے جتنی ہمارے علم میں تھی اور ہم غیب کے نگہبان نہ تھے\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mdclxxviii{اور اس بستی سے پوچھ دیکھئے جس میں ہم تھے اور اس قافلہ سے جس میں ہم آئے، اور ہم بیشک سچے ہیں\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mdclxxix{کہا تمہارے نفس نے تمہیں کچھ حیلہ بنادیا، تو اچھا صبر ہے، قریب ہے کہ اللہ ان سب کو مجھ سے لا، ملائے بیشک وہی علم و حکمت والا ہے،\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mdclxxx{اور ان سے منہ پھیرا اور کہا ہائے افسوس! یوسف کی جدائی پر اور اس کی آنکھیں غم سے سفید ہوگئیں وہ غصہ کھا تا رہا،\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mdclxxxi{بولے خدا کی قسم! آپ ہمیشہ یوسف کی یاد کرتے رہیں گے یہاں تک کہ گور کنارے جا لگیں یا جان سے گزر جائیں،\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mdclxxxii{کہا میں تو اپنی پریشانی اور غم کی فریاد اللہ ہی سے کرتا ہوں اور مجھے اللہ کی وہ شانیں معلوم ہیں جو تم نہیں جانتے\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mdclxxxiii{اے بیٹو! جا ؤ یوسف اور اس کے بھائی کا سراغ لگاؤ اور اللہ کی رحمت سے مایوس نہ ہو، بیشک اللہ کی رحمت سے نا امید نہیں ہوتے مگر کافر لوگ\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mdclxxxiv{پھر جب وہ یوسف کے پاس پہنچے بولے اے عزیز ہمیں اور ہمارے گھر والوں کو مصیبت پہنچی اور ہم بے قدر پونجی لے کر آئے ہیں تو آپ ہمیں پورا ناپ دیجئے اور ہم پر خیرات کیجئے بیشک اللہ خیرات والوں کو صلہ دیتا ہے\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mdclxxxv{بولے کچھ خبر ہے تم نے یوسف اور اس کے بھائی کے ساتھ کیا کِیا تھا جب تم نادان تھے\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mdclxxxvi{بولے کیا سچ مچ آپ ہی یوسف ہیں، کہا میں یوسف ہوں اور یہ میرا بھائی، بیشک اللہ نے ہم پر احسان کیا بیشک جو پرہیزگاری اور صبر کرے تو اللہ نیکوں کا نیگ (اجر) ضائع نہیں کرتا\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mdclxxxvii{بولے خدا کی قسم! بیشک اللہ نے آپ کو ہم پر فضیلت دی اور بیشک ہم خطاوار تھے\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mdclxxxviii{کہا آج تم پر کچھ ملامت نہیں، اللہ تمہیں معاف کرے، اور وہ سب مہربانوں سے بڑھ کر مہربان ہے\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mdclxxxix{میرا یہ کرتا لے جاؤ اسے میرے باپ کے منہ پر ڈالو ان کی آنکھیں کھل جائیں گی اور اپنے سب گھر بھر کو میرے پاس لے آ ؤ،\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mdcxc{جب قافلہ مصر سے جدا ہوا یہاں ان کے باپ نے کہا بیشک میں یوسف کی خوشبو پا تا ہوں اگر مجھے یہ نہ کہو کہ سٹھ (بہک) گیا ہے،\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mdcxci{بیٹے بولے خدا کی قسم! آپ اپنی اسی پرانی خود رفتگی میں ہیں\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mdcxcii{پھر جب خوشی سنانے والا آیا اس نے وہ کرتا یعقوب کے منہ پر ڈالا اسی وقت اس کی آنکھیں پھر آئیں (دیکھنے لگیں) کہ میں نہ کہتا تھا کہ مجھے اللہ کی وہ شانیں معلوم ہیں جو تم نہیں جانتے\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mdcxciii{بولے اے ہمارے باپ! ہمارے گناہوں کی معافی مانگئے بیشک ہم خطاوار ہیں،\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mdcxciv{کہا جلد میں تمہاری بخشش اپنے رب سے چاہو ں گا، بیشک وہی بخشنے والا مہربان ہے\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mdcxcv{پھر جب وہ سب یوسف کے پاس پہنچے اس نے اپنے ماں باپ کو اپنے پاس جگہ دی اور کہا مصر میں داخل ہو اللہ چاہے تو امان کے ساتھ\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mdcxcvi{اور اپنے ماں باپ کو تخت پر بٹھایا اور سب اس کے لیے سجدے میں گرے اور یوسف نے کہا اے میرے باپ یہ میرے پہلے خواب کی تعبیر ہے بیشک اسے میرے رب نے سچا کیا، اور بیشک اس نے مجھ پر احسان کیا کہ مجھے قید سے نکالا اور آپ سب کو گاؤں سے لے آیا بعد اس کے کہ شیطان نے مجھ میں اور میرے بھائیوں میں ناچاقی کرادی تھی، بیشک میرا رب جس بات کو چاہے آسان کردے بیشک وہی علم و حکمت والا ہے\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mdcxcvii{اے میرے رب بیشک تو نے مجھے ایک سلطنت دی اور مجھے کچھ باتوں کا انجام نکالنا سکھایا، اے آسمانوں اور زمین کے بنانے والے تو میرا کام بنانے والا ہے دنیا اور آخرت میں، مجھے مسلمان اٹھا اور ان سے مِلا جو تیرے قرب خاص کے لائق ہیں\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mdcxcviii{یہ کچھ غیب کی خبریں ہیں جو ہم تمہاری طرف وحی کرتے ہیں اور تم ان کے پاس نہ تھے جب انہوں نے اپنا کام پکا کیا تھا اور وہ داؤں چل رہے تھے\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mdcxcix{اور اکثر آدمی تم کتنا ہی چاہو ایمان نہ لائیں گے،\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mdcc{اور تم اس پر ان سے کچھ اجرت نہ مانگتے یہ تو نہیں مگر سارے جہان کو نصیحت،\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mdcci{اور کتنی نشانیاں ہیں آسمانوں اور زمین میں کہ اکثر لوگ ان پر گزرتے ہیں اور ان سے بے خبر رہتے ہیں،\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mdccii{اور ان میں اکثر وہ ہیں کہ اللہ پر یقین نہیں لاتے مگر شرک کرتے ہوئے\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mdcciii{کیا اس سے نڈر ہو بیٹھے کہ اللہ کا عذاب انہیں آکر گھیر لے یا قیامت ان پر اچانک آجائے اور انہیں خبر نہ ہو،\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mdcciv{تم فرماؤ یہ میری راہ ہے میں اللہ کی طرف بلاتا ہوں میں اور جو میرے قدموں پرچلیں دل کی آنکھیں رکھتے ہیں ۰ف۲۳۳) اور اللہ کو پاکی ہے اور میں شریک کرنے والا نہیں،\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mdccv{اور ہم نے تم سے پہلے جتنے رسول بھیجے سب مرد ہی تھے جنہیں ہم وحی کرتے اور سب شہر کے ساکن تھے تو یہ لوگ زمین پرچلے نہیں تو دیکھتے ان سے پہلوں کا کیا انجام ہوا اور بیشک آخرت کا گھر پرہیزگاروں کے لیے بہتر تو کیا تمہیں عقل نہیں،\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mdccvi{یہاں تک جب رسولوں کو ظاہری اسباب کی امید نہ رہی اور لوگ سمجھے کہ رسولوں نے غلط کہا تھا اس وقت ہماری مدد آئی تو جسے ہم نے چاہا بچالیا گیا اور ہمارا عذاب مجرموں سے پھیرا نہیں جاتا،\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mdccvii{بیشک ان کی خبروں سے عقل مندوں کی آنکھیں کھلتی ہیں یہ کوئی بناوٹ کی بات نہیں لیکن اپنوں سے اگلے کاموں کی تصدیق ہے اور ہر چیز کا مفصل بیان اور مسلمانوں کے لیے ہدایت اور رحمت،\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mdccviii{\basmalahur یہ کتاب کی آیتیں ہیں اور وہ جو تمہاری طرف تمہارے رب کے پاس سے اترا حق ہے مگر اکثر آدمی ایمان نہیں لاتے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mdccix{اللہ ہے جس نے آسمانوں کو بلند کیا بے ستونوں کے کہ تم دیکھو پھر عرش پر استوا فرمایا جیسا اس کی شان کے لائق ہے اور سورج اور چاند کو مسخر کیا ہر ایک، ایک ٹھہرائے ہوئے وعدہ تک چلتا ہے اللہ کام کی تدبیر فرماتا اور مفصل نشانیاں بتاتا ہے کہیں تم اپنے رب رب کا ملنا یقین کرو\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mdccx{اور وہی ہے جس نے زمین کو پھیلا اور اس میں لنگر اور نہریں بنائیں، اور زمین ہر قسم کے پھل دو دو طرح کے بنائے رات سے دن کو چھپا لیتا ہے، بیشک اس میں نشانیاں ہیں دھیان کرنے والوں کو\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mdccxi{اور زمین کے مختلف قطعے ہیں اور ہیں پاس پاس اور باغ ہیں انگوروں کے اور کھیتی اور کھجور کے پیڑ ایک تھالے (تھال) سے اُگے اور الگ الگ سب کو ایک ہی پانی دیا جا تا ہے اور پھلوں میں ہم ایک کو دوسرے سے بہتر کرتے ہیں، بیشک اس میں نشانیاں ہیں عقل مندوں کے لیے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mdccxii{اور اگر تم تعجب کرو تو اچنبھا تو ان کے اس کہنے کا ہے کہ کیا ہم مٹی ہو کر پھر نئے بنیں گے وہ ہیں جو اپنے رب سے منکر ہوئے اور وہ ہیں جن کی گردنوں میں طوق ہوں گے اور وہ دوزخ والے ہیں انھیں اسی میں رہنا،\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mdccxiii{اور تم سے عذاب کی جلدی کرتے ہیں رحمت سے پہلے اور ان اگلوں کی سزائیں ہوچکیں اور بیشک تمہارا رب تو لوگوں کے ظلم پر بھی انہیں ایک طرح کی معافی دیتا ہے اور بیشک تمہارے رب کا عذاب سخت ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mdccxiv{اور کا فر کہتے ہیں ان پر ان کی طرف سے کوئی نشانی کیو ں نہیں اتری تم تو ڈر سنانے والے ہو اور ہر قوم کے ہادی\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mdccxv{اللہ جانتا ہے جو کچھ کسی مادہ کے پیٹ میں ہے اور پیٹ جو کچھ گھٹتے بڑھتے ہیں اور ہر چیز اس کے پاس ایک اندازے سے ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mdccxvi{ہر چھپے اور کھلے کا جاننے والا سب سے بڑا بلندی والا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mdccxvii{برابر ہیں جو تم میں بات آہستہ کہے اور جو آواز سے اور جو رات میں چھپا ہے اور جو دن میں راہ چلتا ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mdccxviii{آدمی کے لیے بدلی والے فرشتے ہیں اس کے آگے پیچھے کہ بحکم خدا اس کی حفاظت کرتے ہیں بیشک اللہ کسی قوم سے اپنی نعمت نہیں بدلتا جب تک وہ خود اپنی حالت نہ بدلیں، اور جب کسی قوم سے برائی چاہے تو وہ پھر نہیں سکتی، اور اس کے سوا ان کا کوئی حمایتی نہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mdccxix{وہی ہے تمہیں بجلی دکھاتا ہے ڈر کو اور امید کو اور بھاری بدلیاں اٹھاتا ہے،\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mdccxx{اور گر ج اسے سراہتی ہوئی اس کی پاکی بولتی ہے اور فرشتے اس کے ڈر سے اور کڑک بھیجتا ہے تو اسے ڈالتا ہے جس پر چاہے اور وہ اللہ میں جھگڑتے ہوتے ہیں اور اس کی پکڑ سخت ہے،\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mdccxxi{اسی کا پکارنا سچا ہے اور اُس کے سوا جن کو پکارتے ہیں وہ ان کی کچھ بھی نہیں سنتے مگر اس کی طرح جو پانی کے سامنے اپنی ہتھیلیاں پھیلائے بیٹھا ہے کہ اس کے منہ میں پہنچ جائے اور وہ ہرگز نہ پہنچے گا، اور کافروں کی ہر دعا بھٹکتی پھرتی ہے،\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mdccxxii{اور اللہ ہی کو سجدہ کرتے ہیں جتنے آسمانوں اور زمین میں ہیں خوشی سے خواہ مجبوری سے اور ان کی پرچھائیاں ہر صبح و شام السجدة ۔۲\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mdccxxiii{تم فرماؤ کون رب ہے آسمانوں اور زمین کا، تم خود ہی فرما ؤ اللہ تم فرما ؤ تو کیا اس کے سوا تم نے وہ حمایتی بنائے ہیں جو اپنا بھلا برا نہیں کرسکتے ہیں تم فرما ؤ کیا برابر ہوجائیں گے اندھا اور انکھیارا (بینا) یا کیا برابر ہوجائیں گی اندھیریاں اور اجالا کیا اللہ کے لیے ایسے شریک ٹھہراتے ہیں جنہوں نے اللہ کی طرح کچھ بنایا تو انہیں ان کا اور اس کا بنانا ایک سا معلوم ہوا تم فرما ؤ اللہ ہر چیز کا بنانے والا ہے اور وہ اکیلا سب پر غالب ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mdccxxiv{اس نے آسمان سے پانی اتارا تو نالے اپنے اپنے لائق بہہ نکلے تو پانی کی رو اس پر ابھرے ہوئے جھاگ اٹھا لائی، اور جس پر آگ دہکاتے ہیں گہنا یا اور اسباب بنانے کو اس سے بھی ویسے ہی جھاگ اٹھتے ہیں اللہ بتاتا ہے کہ حق و باطل کی یہی مثال ہے، تو جھاگ تو پھک (جل) کر دور ہوجاتا ہے، اور وہ جو لوگوں کے کام آئے زمین میں رہتا ہے اللہ یوں ہی مثالیں بیان فرماتا ہے،\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mdccxxv{جن لوگوں نے اپنے رب کا حکم مانا انہیں کے لیے بھلائی ہے اور جنہوں نے اس کا حکم نہ مانا اگر زمین میں جو کچھ ہے وہ سب اور اس جیسا اور ان کی ملِک میں ہوتا تو اپنی جان چھڑانے کو دے دیتے یہی ہیں جن کا برُ ا حساب ہوگا اور ان کا ٹھکانا جہنم ہے، اور کیا ہی بُرا بچھونا،\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mdccxxvi{تو کیا وہ جانتا ہے جو کچھ تمہاری طرف تمہارے رب کے پاس سے اترا حق ہے وہ اس جیسا ہوگا جو اندھا ہے نصیحت وہی مانتے ہیں جنہیں عقل ہے،\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mdccxxvii{وہ جو اللہ کا عہد پورا کرتے ہیں اور قول باندھ کر پھرتے نہیں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mdccxxviii{اور وہ کہ جوڑتے ہیں اسے جس کے جوڑنے کا اللہ نے حکم دیا اور اپنے رب سے ڈرتے ہیں اور حساب کی بُرائی سے اندیشہ رکھتے ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mdccxxix{اور وہ جنہوں نے صبر کیا اپنے رب کی رضا چاہنے کو اور نماز قائم رکھی اور ہمارے دیئے سے ہماری راہ میں چھپے اور ظاہر کچھ خرچ کیا اور برائی کے بدلے بھلائی کرکے ٹالتے ہیں انہیں کے لیے پچھلے گھر کا نفع ہے،\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mdccxxx{بسنے کے باغ جن میں وہ داخل ہوں گے اور جو لائق ہوں ان کے باپ دادا اور بیبیوں اور اولاد میں اور فرشتے ہر دروازے سے ان پر یہ کہتے آئیں گے،\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mdccxxxi{سلامتی ہو تم پر تمہارے صبر کا بدلہ تو پچھلا گھر کیا ہی خوب ملا،\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mdccxxxii{اور وہ جو اللہ کا عہد اس کے پکے ہونے کے بعد توڑتے اور جس کے جوڑنے کو اللہ نے فرمایا اسے قطع کرتے اور زمین میں فساد پھیلاتے ہیں ان کا حصہ لعنت ہی ہے اور اُن کا نصیبہ بُرا گھر\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mdccxxxiii{اللہ جس کے لیے چاہے رزق کشادہ اور تنگ کرتا ہے، اور کا فر دنیا کی زندگی پر اترا گئے (نازاں ہوئے) اور دنیا کی زندگی آخرت کے مقابل نہیں مگر کچھ دن برت لینا،\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mdccxxxiv{اور کافر کہتے ان پر کوئی نشانی ان کے رب کی طرف سے کیوں نہ اتری، تم فرماؤ بیشک اللہ جسے چاہے گمراہ کرتا ہے اور اپنی راہ اسے دیتا ہے جو اس کی طرف رجوع لائے،\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mdccxxxv{وہ جو ایمان لائے اور ان کے دل اللہ کی یاد سے چین پاتے ہیں، سن لو اللہ کی یاد ہی میں دلوں کا چین ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mdccxxxvi{وہ جو ایمان لائے اور اچھے کام کیے ان کو خوشی ہے اور اچھا انجام\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mdccxxxvii{اسی طرح ہم نے تم کو اس امت میں بھیجا جس سے پہلے امتیں ہو گزریں کہ تم انہیں پڑھ کر سناؤ جو ہم نے تمہاری طرف وحی کی اور وہ رحمن کے منکر ہورہے ہیں تم فرماؤ وہ میرا رب ہے اس کے سوا کسی کی بندگی نہیں میں نے اسی پر بھروسہ کیا اور اسی کی طرف میری رجوع ہے،\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mdccxxxviii{اور اگر کوئی ایسا قرآن آتا جس سے پہاڑ ٹل جاتے یا زمین پھٹ جاتی یا مردے باتیں کرتے جب بھی یہ کافر نہ مانتے بلکہ سب کام اللہ ہی کے اختیار ميں ہیں تو کیا مسلمان اس سے نا امید نہ ہوئے کہ اللہ چاہتا تو سب آدمیوں کو ہدایت کردیتا اور کافروں کو ہمیشہ کے لیے یہ سخت دھمک (ہلادینے والی مصیبت) پہنچتی رہے گی یا ان کے گھروں کے نزدیک اترے گی یہاں تک کہ اللہ کا وعدہ آئے بیشک اللہ وعدہ خلاف نہیں کرتا\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mdccxxxix{اور بیشک تم سے اگلے رسولوں سے بھی ہنسی کی گئی تو میں نے کافروں کو کچھ دنوں ڈھیل دی پھر انہیں پکڑا تو میرا عذاب کیسا تھا،\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mdccxl{تو کیا وہ ہر جان پر اس کے اعمال کی نگہداشت رکھتا ہے اور وہ اللہ کے شریک ٹھہراتے ہیں، تم فرماؤ ان کا نام تو لو یا اسے وہ بتاتے ہو جو اس کے علم میں ساری زمین میں نہیں یا یوں ہی اوپری بات بلکہ کافروں کی نگاہ میں ان کا فریب اچھا ٹھہرا ہے اور راہ سے روکے گئے اور جسے اللہ گمراہ کرے اسے کوئی ہدایت کرنے والا نہیں،\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mdccxli{انہیں دنیا کے جیتے عذاب ہوگا اور بیشک آخرت کا عذاب سب سے سخت اور انہیں اللہ سے بچانے والا کوئی نہیں،\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mdccxlii{احوال اس جنت کا کہ ڈر والوں کے لیے جس کا وعدہ ہے، اس کے نیچے نہریں بہتی ہیں، اس کے میوے ہمیشہ اور اس کا سایہ ڈر والوں کا تو یہ انجام ہے اور کافروں کا انجام آ گ،\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mdccxliii{اور جن کو ہم نے کتاب دی وہ اس پر خوش ہوتے جو تمہاری طرف اترا اور ان گروہوں میں کچھ وہ ہیں کہ اس کے بعض سے منکر ہیں، تم فرماؤ مجھے تو یہی حکم ہے کہ اللہ کی بندگی کروں اور اس کا شریک نہ ٹھہراؤں، ميں اسی کی طرف بلاتا ہوں اور اسی کی طرف مجھے پھرنا\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mdccxliv{اور اسی طرح ہم نے اسے عربی فیصلہ اتارا اور اے سننے والے! اگر تو ان کی خواہشوں پر چلے گا بعد اس کے کہ تجھے علم آچکا تو اللہ کے آگے نہ تیرا کوئی حمایتی ہوگا نہ بچانے والا،\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mdccxlv{اور بیشک ہم نے تم سے پہلے رسول بھیجے اور ان کے لیے بیبیاں اور بچے کیے اور کسی رسول کا کام نہیں کہ کوئی نشانی لے آئے مگر اللہ کے حکم سے، ہر وعدہ کی ایک لکھت ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mdccxlvi{اللہ جو چاہے مٹاتا اور ثابت کرتا ہے اور اصل لکھا ہوا اسی کے پاس\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mdccxlvii{اور اگر ہمیں تمہیں دکھا د یں کوئی وعدہ جو انہیں دیا جاتا ہے یا پہلے ہی اپنے پاس بلائیں تو بہرحال تم پر تو ضرور پہنچانا ہے اور حساب لینا ہمارا ذمہ\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mdccxlviii{کیا انہیں نہیں سوجھتا کہ ہر طرف سے ان کی آبادی گھٹاتے آرہے ہیں اور اللہ حکم فرماتا ہے اس کا حکم پیچھے ڈالنے والا کوئی نہیں اور اسے حساب لیتے دیر نہیں لگتی،\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mdccxlix{اور ان سے اگلے فریب کرچکے ہیں تو ساری خفیہ تدبیر کا مالک تو اللہ ہی ہے جانتا ہے جو کچھ کوئی جان کمائے اور اب جاننا چاہتے ہیں کافر، کسے ملتا ہے پچھلا گھر\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mdccl{اور کافر کہتے ہی تم رسول نہیں، تم فرماؤ اللہ گواہ کافی ہے مجھ میں اور تم میں اور وہ جسے کتاب کا علم ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mdccli{\basmalahur ایک کتاب ہے کہ ہم نے تمہاری طرف اتاری کہ تم لوگوں کو اندھیریوں سے اجالے میں لا ؤ ان کے رب کے حکم سے اس کی راہ کی طرف جو عزت والا سب خوبیوں والا ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mdcclii{اللہ کہ اسی کا ہے جو کچھ آسمانوں میں ہے اور جو کچھ زمین میں اور کافروں کی خرابی ہے ایک سخت عذاب سے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mdccliii{جنہیں آخرت سے دنیا کی زندگی پیاری ہے اور اللہ کی راہ سے روکتے اور اس میں کجی چاہتے ہیں، وہ دور کی گمراہی میں ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mdccliv{اور ہم نے ہر رسول اس کی قوم ہی کی زبان میں بھیجا کہ وہ انہیں صاف بتائے پھراللہ گمراہ کرتا ہے جسے چاہے اور وہ راہ دکھاتا ہے جسے چاہے، اور وہی عزت و حکمت والا ہے،\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mdcclv{اور بیشک ہم نے موسیٰ کو اپنی نشانیاں دے کر بھیجا کہ اپنی قوم کو اندھیریوں سے اجالے میں لا، اور انہیں اللہ کے دن یا د دِلا بیشک اس میں نشانیاں ہیں ہر بڑے صبرے والے شکر گزار کرو،\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mdcclvi{اور جب موسیٰ نے اپنی قوم سے کہا یاد کرو اپنے اوپر اللہ کا احسان جب اس نے تمہیں فرعون والوں سے نجات دی جو تم کو بری مار دیتے تھے اور تمہارے بیٹوں کو ذبح کرتے اور تمہاری بیٹیاں زندہ رکھتے، اور اس میں تمہارے رب کا بڑا فضل ہوا،\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mdcclvii{اور یاد کرو جب تمہارے رب نے سنادیا کہ اگر احسان مانو گے تو میں تمہیں اور دونگا اور اگر ناشکری کرو تو میرا عذاب سخت ہے،\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mdcclviii{اور موسیٰ نے کہا اگر تم اور زمین میں جتنے ہیں سب کا فر ہوجاؤ تو بیشک اللہ بے پروہ سب خوبیوں والا ہے،\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mdcclix{کیا تمہیں ان کی خبریں نہ آئیں جو تم سے پہلے تھی نوح کی قوم اور عاد اور ثمود اور جو ان کے بعد ہوئے، انہیں اللہ ہی جانے ان کے پاس ان کے رسول روشن دلیلیں لے کر آئے تو وہ اپنے ہاتھ اپنے منہ کی طرف لے گئے اور بولے ہم منکر ہیں اس کے جو تمہارے ہاتھ بھیجا گیا اور جس راہ کی طرف ہمیں بلاتے ہو اس میں ہمیں وہ شک ہے کہ بات کھلنے نہیں دیتا،\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mdcclx{ان کے رسولوں نے کہا کیا اللہ میں شک ہے آسمان اور زمین کا بنانے والا، تمہیں بلاتا ہے کہ تمہارے کچھ گناہ بخشے اور موت کے مقرر وقت تک تمہاری زندگی بے عذاب کاٹ دے، بولے تم تو ہمیں جیسے آدمی ہو تم چاہتے ہو کہ ہمیں اس سے باز رکھو جو ہمارے باپ دادا پوجتے تھے اب کوئی روشن سند ہمارے پاس لے آؤ\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mdcclxi{ان کے رسولوں نے ان سے کہا ہم ہیں تو تمہاری طرح انسان مگر اللہ اپنے بندوں میں جس پر چاہے احسان فرماتا ہے اور ہمارا کام نہیں کہ ہم تمہارے پاس کچھ سند لے آئیں مگر اللہ کے حکم سے، اور مسلمانوں کو اللہ ہی پر بھروسہ چاہیے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mdcclxii{اور ہمیں کیا ہوا کہ اللہ پر بھروسہ نہ کریں اس نے تو ہماری راہیں ہمیں دکھادیں اور تم جو ہمیں ستا رہے ہو ہم ضرور اس پر صبر کریں گے، اور بھروسہ کرنے والوں کو اللہ ہی پر بھروسہ چاہیے،\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mdcclxiii{اور کافروں نے اپنے رسولوں سے کہا ہم ضرور تمہیں اپنی زمین سے نکال دیں گے یا تم ہمارے دین پر کچھ ہوجاؤ، تو انہیں ان کے رب نے وحی بھیجی کہ ہم ضرور ظالموں کو ہلاک کریں گے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mdcclxiv{اور ضرور ہم تم کو ان کے بعد زمین میں بسائیں گے یہ اس لیے ہے جو میرے حضو ر کھڑے ہونے سے ڈرے اور میں نے جو عذاب کا حکم سنایا ہے، اس سے خوف کرے،\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mdcclxv{اور انہوں نے فیصلہ مانگا اور ہر سرکش ہٹ دھرم نا مُراد ہوا\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mdcclxvi{جہنم اس کے پیچھے لگی اور اسے پیپ کا پانی پلایا جائے گا،\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mdcclxvii{بہ مشکل اس کا تھوڑا تھوڑا گھونٹ لے گا اور گلے سے نیچے اتارنے کی امید نہ ہوگی اور اسے ہر طرف سے موت آئے گی اور مرے گا نہیں، اور اس کے پیچھے ایک گاڑھا عذاب\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mdcclxviii{اپنے رب سے منکروں کا حال ایسا ہے کہ ان کے کام ہیں جیسے راکھ کہ اس پر ہوا کا سخت جھونکا آیا آندھی کے دن میں ساری کمائی میں سے کچھ ہاتھ نہ لگا، یہی ہے دور کی گمراہی،\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mdcclxix{کیا تو نے نہ دیکھا کہ اللہ نے آسمان اور زمین حق کے ساتھ بنائے اگر چاہے تو تمہیں لے جائے اور ایک نئی مخلوق لے آئے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mdcclxx{اور یہ اللہ پر کچھ دشوار نہیں،\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mdcclxxi{اور سب اللہ کے حضور اعلانیہ حاضر ہوں گے تو جو کمزور تھے بڑائی والوں سے کہیں گے ہم تمہارے تابع تھے کیا تم سے ہوسکتا ہے کہ اللہ کے عذاب میں سے کچھ ہم پر سے ٹال دو کہیں گے اللہ ہمیں ہدایت کرتا تو ہم تمہیں کرتے ہم پر ایک سا ہے چاہے بے قراری کریں یا صبر سے رہیں ہمیں کہیں پناہ نہیں،\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mdcclxxii{اور شیطان کہے گا جب فیصلہ ہوچکے گا بیشک اللہ نے تم کو سچا وعدہ دیا تھا اور میں نے جو تم کو وعدہ دیا تھا وہ میں نے تم سے جھوٹا کیا اور میرا تم پر کچھ قابو نہ تھا مگر یہی کہ میں نے تم کو بلایا تم نے میری مان لی تو اب مجھ پر الزام نہ رکھو خود اپنے اوپر الزام رکھو نہ میں تمہاری فریاد کو پہنچ سکوں نہ تم میری فریاد کو پہنچ سکو، وہ جو پہلے تم نے مجھے شریک ٹھہرایا تھا میں اس سے سخت بیزار ہوں، بیشک ظالموں کے لیے دردناک عذاب ہے،\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mdcclxxiii{اور وہ جو ایمان لائے اور اچھے کام کیے وہ باغوں میں داخل کیے جائیں گے جن کے نیچے نہریں رواں ہمیشہ ان میں رہیں اپنے رب کے حکم سے، اس میں ان کے ملتے وقت کا اکرام سلام ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mdcclxxiv{کیا تم نے نہ دیکھا اللہ نے کیسی مثال بیان فرمائی پاکیزہ بات کی جیسے پاکیزہ درخت جس کی جڑ قائم اور شاخیں آسمان میں،\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mdcclxxv{ہر وقت پھل دیتا ہے اپنے رب کے حکم سے اور اللہ لوگوں کے لیے مثالیں بیان فرماتا ہے کہ کہیں وہ سمجھیں\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mdcclxxvi{اور گندی بات کی مثال جیسے ایک گندہ پیڑ کہ زمین کے اوپر سے کاٹ دیا گیا اب اسے کوئی قیام نہیں\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mdcclxxvii{اللہ ثابت رکھتا ہے ایمان والوں کو حق بات پر دنیا کی زندگی میں اور آخرت میں اور اللہ ظالموں کو گمراہ کرتا ہے اور اللہ جو چاہے کرے،\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mdcclxxviii{کیا تم نے انہیں نہ دیکھا جنہوں نے اللہ کی نعمت ناشکری سے بدل دی اور اپنی قوم کو تباہی کے گھر لا اتار،\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mdcclxxix{وہ جو دوزخ ہے اس کے اندر جائیں گے، اور کیا ہی بری ٹھہرنے کی جگہ،\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mdcclxxx{اور اللہ کے لیے برابر والے ٹھہراے کہ اس کی راہ سے بہکاویں تم فرماؤ کچھ برت لو کہ تمہارا انجام آگ ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mdcclxxxi{میرے ان بندوں سے فرماؤ جو ایمان لائے کہ نماز قائم رکھیں اور ہمارے دیے میں سے کچھ ہماری راہ میں چھپے اور ظاہر خرچ کریں اس دن کے آنے سے پہلے جس میں نہ سوداگری ہوگی نہ یارانہ\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mdcclxxxii{اللہ ہے جس نے آسمان اور زمین بنائے اور آسمان سے پانی اتارا تو اس سے کچھ پھل تمہارے کھانے کو پیدا کیے اور تمہارے لیے کشتی کو مسخر کیا کہ اس کے حکم سے دریا میں چلے اور تمہارے لیے ندیاں مسخر کیں،\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mdcclxxxiii{اور تمہارے لیے سورج اور چاند مسخر کیے جو برابر چل رہے ہیں اور تمہارے لیے رات اور دن مسخر کیے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mdcclxxxiv{اور تمہیں بہت کچھ منہ مانگا دیا، اور اگر اللہ کی نعمتیں گنو تو شمار نہ کرسکو گے، بیشک آدمی بڑا ظالم ناشکرا ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mdcclxxxv{اور یاد کرو جب ابراہیم نے عرض کی اے میرے رب اس شہر کو امان والا کردے اور مجھے اور میرے بیٹوں کو بتوں کے پوجنے سے بچا\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mdcclxxxvi{اے میرے رب بیشک بتوں نے بہت لوگ بہکائے دیے تو جس نے میرا ساتھ دیا وہ تو میرا ہے اور جس نے میرا کہا نہ مانا تو بیشک تو بخشنے والا مہربان ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mdcclxxxvii{اے میرے رب میں نے اپنی کچھ اولاد ایک نالے میں بسائی جس میں کھیتی نہیں ہوتی تیرے حرمت والے گھر کے پاس اے میرے رب اس لیے کہ وہ نماز قائم رکھیں تو تو لوگوں کے کچھ دل ان کی طرف مائل کردے اور انہیں کچھ پھل کھانے کو دے شاید وہ احسان مانیں،\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mdcclxxxviii{اے ہمارے رب تو جانتا ہے جو ہم چھپاتے ہیں اور ظاہر کرتے اور اللہ پر کچھ چھپا نہیں زمین میں اور نہ آسمان میں\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mdcclxxxix{سب خوبیاں اللہ کو جس نے مجھے بڑھاپے میں اسماعیل و اسحاق دیئے بیشک میرا رب دعا سننے والا ہے،\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mdccxc{اے میرے رب! مجھے نماز قائم کرنے والا رکھ اور کچھ میری اولاد کو اے ہمارے رب اور ہماری دعا سن لے،\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mdccxci{اے ہمارے رب مجھے بخش دے اور میرے ماں باپ کو اور سب مسلمانوں کو جس دن حساب قائم ہوگا،\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mdccxcii{اور ہرگز اللہ کو بےخبر نہ جاننا ظالموں کے کام سے انہیں ڈھیل نہیں دے رہا ہے مگر ایسے دن کے لیے جس میں\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mdccxciii{آنکھیں کھلی کی کھلی رہ جائیں گی بے تحاشا دوڑے نکلیں گے اپنے سر اٹھائے ہوئے کہ ان کی پلک ان کی طرف لوٹتی نہیں اور ان کے دلوں میں کچھ سکت نہ ہوگی\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mdccxciv{اور لوگوں کو اس دن سے ڈراؤ جب ان پر عذاب آئے گا تو ظالم کہیں گے اے ہمارے رب! تھوڑی دیر ہمیں مہلت دے کہ ہم تیرا بلانا مانیں اور رسولوں کی غلامی کریں تو کیا تم پہلے قسم نہ کھاچکے تھے کہ ہمیں دنیا سے کہیں ہٹ کر جانا نہیں\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mdccxcv{اور تم ان کے گھروں میں بسے جنہوں نے اپنا برا کیا تھا اور تم پر خوب کھل گیا ہم نے ان کے ساتھ کیسا کیا اور ہم نے تمہیں مثالیں دے کر بتادیا\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mdccxcvi{اور بیشک وہ اپنا سا داؤں (فریب) چلے اور ان کا داؤں اللہ کے قابو میں ہے، اور ان کا داؤں کچھ ایسانہ تھا جس سے یہ پہاڑ ٹل جائیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mdccxcvii{تو ہر گز خیال نہ کرنا کہ اللہ اپنے رسولوں سے وعدہ خلاف کرے گا بیشک اللہ غالب ہے بدلہ لینے والا،\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mdccxcviii{جس دن بدل دی جائے گی زمین اس زمین کے سوا اور آسمان اور لوگ سب نکل کھڑے ہوں گے ایک اللہکے سامنے جو سب پر غالب ہے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mdccxcix{اور اس دن تم مجرموں کو دیکھو گے کہ بیڑیوں میں ایک دوسرے سے جڑے ہوں گے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mdccc{ان کے کرُتے رال ہوں گے اور ان کے چہرے آ گ ڈھانپ لے گی\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mdccci{اس لیے کہ اللہ ہر جان کو اس کی کمائی کا بدلہ دے، بیشک اللہ کو حساب کرتے کچھ دیر نہیں لگتی،\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mdcccii{یہ لوگوں کو حکم پہنچانا ہے اور اس لیے کہ وہ اس سے ڈرائے جائیں اور اس لیے کہ وہ جان لیں کہ وہ ایک ہی معبود ہے اور اس لیے کہ عقل والے نصیحت مانیں،\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mdccciii{\basmalahur یہ آیتیں ہیں کتاب اور روشن قرآن کی-\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mdccciv{بہت آرزوئیں کریں گے کافر کاش مسلمان ہوتے،\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mdcccv{انہیں چھوڑو کہ کھائیں اور برتیں اور امید انہیں کھیل میں ڈالے تو اب جانا چاہتے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mdcccvi{اور جو بستی ہم نے ہلاک کی اس کا ایک جانا ہوا نوشتہ تھا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mdcccvii{کو ئی گروہ اپنے وعدہ سے آگے نہ بڑھے نہ پیچھے ہٹے،\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mdcccviii{اور بولے کہ اے وہ جن پر قرآن اترا بیشک مجنون ہو\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mdcccix{ہمارے پاس فرشتے کیوں نہیں لاتے اگر تم سچے ہو\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mdcccx{ہم فرشتے بیکار نہیں اتارتے اور وہ اتریں تو انہیں مہلت نہ ملے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mdcccxi{بیشک ہم نے اتارا ہے یہ قرآن اور بیشک ہم خود اس کے نگہبان ہیں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mdcccxii{اور بیشک ہم نے تم سے پہلے اگلی امتوں میں رسول بھیجے،\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mdcccxiii{اور ان کے پاس کوئی رسول نہیں آتا مگر اس سے ہنسی کرتے ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mdcccxiv{ایسے ہی ہم اس ہنسی کو ان مجرموں کے دلوں میں راہ دیتے ہیں،\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mdcccxv{وہ اس پر ایمان نہیں لاتے اور اگلوں کی راہ پڑچکی ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mdcccxvi{اور اگر ہم ان کے لیے آسمان میں کوئی دروازہ کھول دیں کہ دن کو اس میں چڑھتے،\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mdcccxvii{جب بھی یہی کہتے کہ ہماری نگاہ باندھ دی گئی ہے بلکہ ہم پر جادو ہوا ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mdcccxviii{اور بیشک ہم نے آسمان میں برج بنائے اور اسے دیکھنے والو ں کے لیے آراستہ کیا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mdcccxix{اور اسے ہم نے ہر شیطان مردود سے محفوظ رکھا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mdcccxx{مگر جو چوری چھپے سننے جائے تو اس کے پیچھے پڑتا ہے روشن شعلہ\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mdcccxxi{اور ہم نے زمین پھیلائی اور اس میں لنگر ڈالے اور اس میں ہر چیز اندازے سے اگائی،\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mdcccxxii{اور تمہارے لیے اس میں روزیاں کردیں اور وہ کردیے جنہیں تم رزق نہیں دیتے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mdcccxxiii{اور کوئی چیز نہیں جس کے ہمارے پاس خزانے نہ ہوں اور ہم اسے نہیں اتارتے مگر ایک معلوم انداز سے،\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mdcccxxiv{اور ہم نے ہوائیں بھیجیں بادلوں کو با رور کرنے والیاں تو ہم نے آسمان سے پانی اتارا پھر وہ تمہیں پینے کو دیا اور تم کچھ اس کے خزانچی نہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mdcccxxv{اور بیشک ہم ہی جِلائیں اور ہم ہی ماریں اور ہم ہی وارث ہیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mdcccxxvi{اور بیشک ہمیں معلوم ہیں جو تم میں آگے بڑھے اور بیشک ہمیں معلوم ہیں جو تم میں پیچھے رہے،\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mdcccxxvii{اور بیشک تمہارا رب ہی تمہیں قیامت میں اٹھائے گا بیشک وہی علم و حکمت والا ہے،\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mdcccxxviii{اور بیشک ہم نے آدمی کو بجتی ہوئی مٹی سے بنایا جو اصل میں ایک سیاہ بودار گارا تھی، ف۳۳)\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mdcccxxix{اور جِن کو اس سے پہلے بنایا بے دھوئیں کی آگ سے،\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mdcccxxx{اور یاد کرو جب تمہارے رب نے فرشتوں سے فرمایا کہ میں آدمی کو بنانے والا ہوں بجتی مٹی سے جو بدبودار سیاہ گارے سے ہے،\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mdcccxxxi{تو جب میں اسے ٹھیک کرلوں اور اور میں اپنی طرف کی خاص معز ز ر وح پھونک دوں تو اس کے لیے سجدے میں گر پڑنا،\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mdcccxxxii{تو جتنے فرشتے تھے سب کے سب سجدے میں گرے،\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mdcccxxxiii{سوا ابلیس کے، اس نے سجدہ والوں کا ساتھ نہ مانا\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mdcccxxxiv{فرمایا اے ابلیس تجھے کیا ہوا کہ سجدہ کرنے والوں سے الگ رہا،\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mdcccxxxv{بولا مجھے زیبا نہیں کہ بشر کو سجدہ کروں جسے تو نے بجتی مٹی سے بنایا جو سیاہ بودار گارے سے تھی،\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mdcccxxxvi{فرمایا تو جنت سے نکل جا کہ تو مردود ہے،\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mdcccxxxvii{اور بیشک قیامت تک تجھ پر لعنت ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mdcccxxxviii{بولا اے میرے رب تو مجھے مہلت دے اس دن تک کہ وہ اٹھائے جائیں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mdcccxxxix{فرمایا تو ان میں سے ہے جن کو اس معلوم،\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mdcccxl{وقت کے دن تک مہلت ہے،\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mdcccxli{بولا اے رب میرے! قسم اس کی کہ تو نے مجھے گمراہ کیا میں انہیں زمین میں بھلاوے دوں گا اور ضرور میں ان سب کو بے راہ کروں گا\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mdcccxlii{مگر جو ان میں تیرے چنے ہوئے بندے ہیں،\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mdcccxliii{فرمایا یہ راستہ سیدھا میری طرف آتا ہے،\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mdcccxliv{بیشک میرے بندوں پر تیرا کچھ قابو نہیں سوا ان گمراہوں کے جو تیرا ساتھ دیں،\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mdcccxlv{اور بیشک جہنم ان سب کا وعدہ ہے،\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mdcccxlvi{اس کے سات دروازے ہیں، ہر دروازے کے لیے ان میں سے ایک حصہ بٹا ہوا ہے،\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mdcccxlvii{بیشک ڈر والے باغوں اور چشموں میں ہیں\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mdcccxlviii{ان میں داخل ہو سلامتی کے ساتھ امان میں،\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mdcccxlix{اور ہم نے ان کے سینوں میں جو کچھ کینے تھے سب کھینچ لیے آپس میں بھائی ہیں تختوں پر روبرو بیٹھے،\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mdcccl{نہ انہیں اس میں کچھ تکلیف پہنچے نہ وہ اس میں سے نکالے جائیں،\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mdcccli{خبردو (۵۴) میرے بندوں کو کہ بیشک میں ہی ہوں بخشے والا مہربان،\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mdccclii{اور میرا ہی عذاب دردناک عذاب ہے،\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mdcccliii{اور انہیں احوال سناؤ ابراہیم کے مہمانوں کا،\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mdcccliv{جب وہ اس کے پاس آئے تو بولے سلام کہا ہمیں تم سے ڈر معلوم ہوتا ہے،\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mdccclv{انہوں نے کہا ڈریے نہیں ہم آپ کو ایک علم والے لڑکے کی بشارت دیتے ہیں،\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mdccclvi{کہا کیا اس پر مجھے بشارت دیتے ہو کہ مجھے بڑھاپا پہنچ گیا اب کاہے پر بشارت دیتے ہو،\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mdccclvii{کہا ہم نے آپ کو سچی بشارت دی ہے آپ ناامید نہ ہوں،\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mdccclviii{کہا اپنے رب کی رحمت سے کون ناامید ہو مگر وہی جو گمراہ ہوئے، ف۶۱)\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mdccclix{کہا پھر تمہارا کیا کام ہے اے فرشتو!\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mdccclx{بولے ہم ایک مجرم قوم کی طرف بھیجے گئے ہیں،\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mdccclxi{مگر لوط کے گھر والے، ان سب کو ہم بچالیں گے،\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mdccclxii{مگر اس کی عورت ہم ٹھہراچکے ہیں کہ وہ پیچھے رہ جانے والوں میں ہے، ف۶۵)\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mdccclxiii{تو جب لوط کے گھر فرشتے آئے، ۶۶)\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mdccclxiv{کہا تم تو کچھ بیگانہ لوگ ہو، ف۶۷)\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mdccclxv{کہا بلکہ ہم تو آپ کے پاس وہ لائے ہیں جس میں یہ لوگ شک کرتے تھے،\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mdccclxvi{اور ہم آپ کے پاس سچا حکم لائے ہیں اور ہم بیشک سچے ہیں،\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mdccclxvii{تو اپنے گھر والوں کو کچھ رات رہے لے کر باہر جایے اور آپ ان کے پیچھے چلئے اور تم میں کوئی پیچھے پھر کر نہ دیکھے اور جہاں کو حکم ہے سیدھے چلے جایئے،\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mdccclxviii{اور ہم نے اسے اس حکم کا فیصلہ سنادیا کہ صبح ہوتے ان کافروں کی جڑ کٹ جائے گی،\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mdccclxix{اور شہر والے خوشیاں مناتے آئے،\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mdccclxx{لوط نے کہا یہ میرے مہمان ہیں مجھے فضیحت (رُسوا) نہ کرو، ف۷۵)\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mdccclxxi{اور اللہ سے ڈرو اور مجھے رسوا نہ کرو،\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mdccclxxii{بولے کیا ہم نے تمہیں منع نہ کیا تھا کہ اوروں کے معاملہ میں دخل نہ دو،\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mdccclxxiii{کہا یہ قوم کی عورتیں میری بیٹیاں ہیں اگر تمہیں کرنا ہے،\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mdccclxxiv{اے محبوب تمہاری جان کی قسم بیشک وہ اپنے نشہ میں بھٹک رہے ہیں،\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mdccclxxv{تو دن نکلتے انہیں چنگھاڑ نے آلیا\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mdccclxxvi{تو ہم نے اس بستی کا اوپر کا حصہ اس نے نیچے کا حصہ کردیا اور ان پر کنکر کے پتھر برسائے،\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mdccclxxvii{بیشک اس میں نشانیاں ہیں فراست والوں کے لیے،\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mdccclxxviii{اور بیشک وہ بستی اس راہ پر ہے جو اب تک چلتی ہے،\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mdccclxxix{بیشک اس میں نشانیاں ہیں ایمان والوں کو،\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mdccclxxx{اور بیشک جھاڑی والے ضرور ظالم تھے، ف۸۲)\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mdccclxxxi{تو ہم نے ان سے بدلہ لیا اور بیشک دونوں بستیاں کھلے راستہ پر پڑتی ہیں،\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mdccclxxxii{اور بیشک حجر والو ں نے رسولوں کو جھٹلایا\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mdccclxxxiii{اور ہم نے ان کو اپنی نشانیاں دیں تو وہ ان سے منہ پھیرے رہے،\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mdccclxxxiv{اور وہ پہاڑوں میں گھر تراشتے تھے بے خوف\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mdccclxxxv{تو انہیں صبح ہوتے چنگھاڑ نے آلیا\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mdccclxxxvi{تو ان کی کمائی کچھ ان کے کام نہ آئی\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mdccclxxxvii{اور ہم نے آسمان اور زمین اور جو کچھ ان کے درمیان ہے عبث نہ بنایا، اور بیشک قیامت آنے والی ہے تو تم اچھی طرح درگزر کرو، ف۹۳)\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mdccclxxxviii{بیشک تمہارا رب ہی بہت پیدا کرنے والا جاننے والا ہے\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mdccclxxxix{اور بیشک ہم نے تم کو سات آیتیں دیں جو دہرائی جاتی ہیں اور عظمت والا قرآن،\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mdcccxc{اپنی آنکھ اٹھاکر اس چیز کو نہ دیکھو جو ہم نے ان کے جوڑوں کو برتنے کو دی اور ان کا کچھ غم نہ کھاؤ اور مسلمانوں کو اپنی رحمت کے پروں میں لے لو،\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mdcccxci{اور فرماؤ کہ میں ہی ہوں صاف ڈر سنانے والا (اس عذاب سے)،\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mdcccxcii{جیسا ہم نے بانٹنے والوں پر اتارا،\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mdcccxciii{جنہوں نے کلامِ الٰہی کو تکے بوٹی کرلیا، ف۹۹)\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mdcccxciv{تو تمہارے رب کی قسم ہم ضرور ان سب سے پوچھیں گے،\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mdcccxcv{جو کچھ وہ کرتے تھے،\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mdcccxcvi{تو اعلانیہ کہہ دو جس بات کا تمہیں حکم ہے اور مشرکوں سے منہ پھیر لو، ف۱۰۳)\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mdcccxcvii{بیشک ان ہنسنے والوں پر ہم تمہیں کفا یت کرتے ہیں\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mdcccxcviii{جو ا لله کے ساتھ دوسرا معبود ٹھہراتے ہیں تو اب جان جائیں گے،\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mdcccxcix{اور بیشک ہمیں معلوم ہے کہ ان کی باتوں سے تم دل تنگ ہوتے ہو،\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mcm{تو اپنے رب کو سراہتے ہوئے اس کی پاکی بولو اور سجدہ والوں میں ہو،\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mcmi{اور مرتے دم تک اپنے رب کی عبادت میں رہو،\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mcmii{\basmalahur اب آتا ہے اللہ کا حکم تو اس کی جلدی نہ کرو پاکی اور برتری ہے اسے ان شریکوں سے،\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mcmiii{ملائکہ کو ایمان کی جان یعنی وحی لے کر اپنے جن بندوں پر چاہے اتارتا ہے کہ ڈر سناؤ کہ میرے سوا کسی کی بندگی نہیں تو مجھ سے ڈرو\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mcmiv{اس نے آسمان اور زمین بجا بنائے وہ ان کے شرک سے برتر ہے،\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mcmv{(اس نے) آدمی کو ایک نِتھری بوند سے بنایا تو جبھی کھلا جھگڑالو ہے،\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mcmvi{اور چوپائے پیدا کیے ان میں تمہارے لیے گرم لباس اور منفعتیں ہیں اور ان میں سے کھاتے ہو،\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mcmvii{اور تمہارا ان میں تجمل ہے جب انہیں شام کو واپس لاتے ہو اور جب چرنے کو چھوڑتے ہو،\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mcmviii{اور وہ تمہارے بوجھ اٹھا کر لے جاتے ہیں ایسے شہر کی طرف کہ اس تک نہ پہنچتے مگر ادھ مرے ہوکر، بیشک تمہارا رب نہایت مہربان رحم والا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mcmix{اور گھوڑے اور خچر اور گدھے کہ ان پر سوار ہو اور زینت کے لیے، اور وہ پیدا کرے گا جس کی تمہیں خبر نہیں،\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mcmx{اور بیچ کی راہ ٹھیک اللہ تک ہے اور کوئی راہ ٹیڑھی ہے اور چاہتا تو تم سب کو راہ پر لاتا،\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mcmxi{وہی ہے جس نے آسمان سے پانی اتارا اس سے تمہارا پینا ہے اور اس سے درخت ہیں جن سے چَراتے ہو\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mcmxii{اس پانی سے تمہارے لیے کھیتی اگاتا ہے اور زیتون اور کھجور اور انگور اور ہر قسم کے پھل بیشک اس میں نشانی ہے دھیان کرنے والوں کو،\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mcmxiii{اور اس نے تمہارے لیے مسخر کیے رات اور دن اور سورج اور چاند، اور ستارے اس کے حکم کے باندھے ہیں بیشک اس آیت میں نشانیاں ہیں عقل مندوں کو\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mcmxiv{اور وہ جو تمہارے لیے زمین میں پیدا کیا رنگ برنگ بیشک اس میں نشانی ہے یاد کرنے والوں کو\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mcmxv{اور وہی ہے جس نے تمہارے لیے دریا مسخر کیا کہ اس میں سے تازہ گوشت کھاتے ہو اور اس میں سے گہنا (زیور) نکالتے ہو جسے پہنتے ہو اور تو اس میں کشتیاں دیکھے کہ پانی چیر کر چلتی ہیں اور اس لیے کہ تم اس کا فضل تلاش کرو اور کہیں احسان مانو،\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mcmxvi{اور اس نے زمین میں لنگر ڈالے کہ کہیں تمہیں لے کر نہ کانپے اور ندیاں اور رستے کہ تم راہ پاؤ\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mcmxvii{اور علامتیں اور ستارے سے وہ راہ پاتے ہیں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mcmxviii{تو کیا جو بنائے وہ ایسا ہوجائے گا جو نہ بنائے تو کیا تم نصیحت نہیں مانتے،\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mcmxix{اور اگر اللہ کی نعمتیں گنو تو انہیں شمار نہ کرسکو گے بیشک اللہ بخشنے والا مہربان ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mcmxx{اور اللہ جانتا ہے جو چھپاتے اور ظاہر کرتے ہو،\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mcmxxi{اور اللہ کے سوا جن کو پوجتے ہو ہیں (۳۲) وہ کچھ بھی نہیں بناتے اور وہ خود بنائے ہوئے ہیں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mcmxxii{مُردے ہیں زندہ نہیں اور انہیں خبر نہیں لوگ کب اٹھائے جایں گے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mcmxxiii{تمہارا معبوثد ایک معبود ہے تو وہ جو آخرت پر ایمان نہیں لاتے ان کے دل منکر ہیں اور وہ مغرور ہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mcmxxiv{فی الحقیقت اللہ جانتا ہے جو چھپاتے اور جو ظاہر کرتے ہیں، بیشک وہ مغروروں کو پسند نہیں فرماتا،\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mcmxxv{اور جب ان سے کہا جائے تمہارے رب نے کیا اتارا کہیں اگلوں کی کہانیاں ہیں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mcmxxvi{کہ قیامت کے دن اپنے بوجھ پورے اٹھائیں اور کچھ بوجھ ان کے جنہیں اپنی جہالت سے گمراہ کرتے ہیں، سن لو کیا ہی برا بوجھ اٹھاتے ہیں،\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mcmxxvii{بیشک ان سے اگلوں نے فریب کیا تھا تو اللہ نے ان کی چنائی کو نیو سے (تعمیر کو بنیاد) سے لیا تو اوپر سے ان پر چھت گر پڑی اور عذاب ان پر وہاں سے آیا جہاں کی انہیں خبر نہ تھی\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mcmxxviii{پھر قیامت کے دن انہیں رسوا کرے گا اور فرمائے گا کہاں ہیں میرے وہ شریک جن میں تم جھگڑتے تھے علم والے کہیں گے آج ساری رسوائی اور برائی کافروں پر ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mcmxxix{وہ کہ فرشتے ان کی جان نکالتے ہیں اس حال پر کیا وہ اپنا برا کررہے تھے اب صلح ڈالیں گے کہ ہم تو کچھ برائی نہ کرتے تھے ہاں کیوں نہیں، بیشک اللہ خوب جانتا ہے جو تمہارے کوتک (برے اعمال) تھے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mcmxxx{اب جہنم کے دروازوں میں جاؤ کہ ہمیشہ اس میں رہو، تو کیا ہی برا ٹھکانا مغروروں کا،\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mcmxxxi{اور ڈر والوں سے کہا گیا تمہارے رب رب نے کیا اتارا، بولے خوبی جنہوں نے اس دنیا میں بھلائی کی ان کے لیے بھلائی ہے اور بیشک پچھلا گھر سب سے بہتر، اور ضرور کیا ہی اچھا گھر پرہیزگاروں کا\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mcmxxxii{بسنے کے باغ جن میں جائیں گے ان کے نیچے نہریں رواں انہیں وہاں ملے گا جو چاہیں اللہ ایسا ہی صلہ دیتا ہے پرہیزگاروں کو\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mcmxxxiii{وہ جن کی جان نکالتے ہیں فرشتے ستھرے پن میں یہ کہتے ہوئے کہ سلامتی ہو تم پر جنت میں جاؤ بدلہ اپنے کیے کا،\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mcmxxxiv{کاہے کے انتظار میں ہیں مگر اس کے کہ فرشتے ان پر آئیں یا تمہارے رب کا عذاب آئے ان سے اگلوں نے ایسا ہی کیا اور اللہ نے ان پر کچھ ظلم نہ کیا، ہاں وہ خود ہی اپنی جانوں پر ظلم کرتے تھے،\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mcmxxxv{تو ان کی بری کمائیاں ان پر پڑیں اور انہیں گھیرلیا اس نے جس پر ہنستے تھے،\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mcmxxxvi{اور مشرک بولے اللہ چاہتا تو اس کے سوا کچھ نہ پوجنے نہ ہم اور نہ ہمارے باپ دادا اور نہ اس سے جدا ہو کر ہم کوئی چیز حرام ٹھہراتے جیسا ہی ان سے اگلوں نے کیا تو رسولوں پر کیا ہے مگر صاف پہنچا دینا،\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mcmxxxvii{اور بیشک ہر امت میں ہم نے ایک رسول بھیجا کہ اللہ کو پوجو اور شیطان سے بچو تو ان میں کسی کو اللہ نے راہ دکھائی اور کسی پر گمراہی ٹھیک اتری تو زمین میں چل پھر کر دیکھو کیسا انجام ہوا جھٹلانے والوں کا\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mcmxxxviii{اگر تم ان کی ہدایت کی حرص کرو تو بیشک اللہ ہدایت نہیں دیتا جسے گمراہ کرے اور ان کا کوئی مددگار نہیں،\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mcmxxxix{اور انہوں نے اللہ کی قسم کھائی اپنے حلف میں حد کی کوشش سے کہ اللہ مُردے نہ اٹھائے گا ہاں کیوں نہیں (۷۹) سچا وعدہ اس کے ذمہ پر لیکن اکثر لوگ نہیں جانتے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mcmxl{اس لیے کہ انہیں صاف بتادے جس بات میں جھگڑتے تھے اور اس لیے کہ کافر جان لیں کہ وہ جھوٹے تھے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mcmxli{جو چیز ہم چاہیں اس سے ہمارا فرمانا یہی ہوتا ہے کہ ہم کہیں ہوجا وہ فوراً ہوجاتی ہے،\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mcmxlii{اور جنہوں نے اللہ کی راہ مں ی اپنے گھر بار چھوڑے مظلوم ہوکر ضرور ہم انہیں دنیا میں اچھی جگہ دیں گے اور بیشک آخرت کا ثواب بہت بڑا ہے کسی طرح لوگ جانتے، ف۸۶)\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mcmxliii{وہ جنہوں نے صبر کیا اور اپنے رب ہی پر بھروسہ کرتے ہیں\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mcmxliv{اور ہم نے تم سے پہلے نہ بھیجے مگر مرد جن کی طرف ہم وحی کرتے، تو اے لوگو! علم والوں سے پوچھو اگر تمہیں علم نہیں، ف۹۰)\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mcmxlv{روشن دلیلیں اور کتابیں لے کر اور اے محبوب ہم نے تمہاری ہی طرف یہ یاد گار اتاری کہ تم لوگوں سے بیان کردو جو ان کی طرف اترا اور کہیں وہ دھیان کریں،\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mcmxlvi{تو کیا جو لوگ بڑے مکر کرتے ہیں اس سے نہیں ڈرتے کہ اللہ انہیں زمین میں دھنسادے یا انہیں وہاں سے عذاب آئے جہاں سے انہیں خبر نہ ہو،\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mcmxlvii{یا انہیں چلتے پھرتے پکڑ لے کہ وہ تھکا نہیں سکتے، ف۹۸)\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mcmxlviii{یا انہیں نقصان دیتے دیتے گرفتار کرلے کہ بیشک تمہارا رب نہایت مہربان رحم والا ہے،\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mcmxlix{اور کیا انہوں نے نہ دیکھا کہ جو چیز اللہ نے بنائی ہے اس کی پرچھائیاں دائیں اور بائیں جھکتی ہیں اللہ کو سجدہ کرتی اور وہ اس کے حضور ذلیل ہیں\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mcml{اور اللہ ہی کو سجدہ کرتے ہیں جو کچھ آسمانوں میں ہیں اور جو کچھ زمین میں چلنے والا ہے اور فرشتے اور وہ غرور نہیں کرتے،\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mcmli{اپنے اوپر اپنے رب کا خوف کرتے ہیں اور وہی کرتے ہیں جو انہیں حکم ہو،\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mcmlii{اور اللہ نے فرمادیا دو خدا نہ ٹھہراؤ وہ تو ایک ہی معبود ہے تو مجھ ہی سے ڈرو، ف۱۰۶)\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mcmliii{اور اسی کا ہے جو کچھ آسمانوں اور زمین میں ہے اور اسی کی فرمانبرداری لازم ہے، تو اللہ کے سوا کسی دوسرے سے ڈرو گے،\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mcmliv{اور تمہارے پاس جو نعمت ہے سب اللہ کی طرف سے ہے پھر جب تمہیں تکلیف پہنچتی ہے تو اسی کی طرف پناہ لے جاتے ہو، ف۱۰۹)\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mcmlv{پھر جب وہ تم سے برائی ٹال دیتا ہے تو تم میں ایک گروہ اپنے رب کا شریک ٹھہرانے لگتا ہے، ف۱۱۰)\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mcmlvi{کہ ہماری دی ہوئی نعمتوں کی ناشکری کریں، تو کچھ برت لو (۱۱۱) کہ عنقریب جان جاؤ گے،\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mcmlvii{اور انجانی چیزوں کے لیے ہماری دی ہوئی روزی میں سے حصہ مقرر کرتے ہیں خدا کی قسم تم سے ضرور سوال ہونا ہے جو کچھ جھوٹ باندھتے تھے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mcmlviii{اور اللہ کے لیے بیٹیاں ٹھہراتے ہیں پاکی ہے اس کو اور اپنے لیے جو اپنا جی چاہتا ہے،\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mcmlix{اور جب ان میں کسی کو بیٹی ہونے کی خوشخبری دی جاتی ہے تو دن بھر اس کا منہ کالا رہتا ہے اور وہ غصہ کھا تا ہے،\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mcmlx{لوگوں سے چھپا پھرتا ہے اس بشارت کی برائی کے سبب، کیا اسے ذلت کے ساتھ رکھے گا یا اسے مٹی میں دبادے گا ارے بہت ہی برا حکم لگاتے ہیں،\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mcmlxi{جو آخرت پر ایمان نہیں لاتے انہیں کا بر ا حال ہے، اور اللہ کی شان سب سے بلند، اور وہی عزت و حکمت والا ہے،\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mcmlxii{اور اگر اللہ لوگوں کو ان کے ظلم پر گرفت کرتا تو زمین پر کوئی چلنے والا نہیں چھوڑتا لیکن انہیں ایک ٹھہرائے وعدے تک مہلت دیتا ہے پھر جب ان کا وعدہ آئے گا نہ ایک گھڑی پیچھے ہٹیں نہ آگے بڑھیں،\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mcmlxiii{اور اللہ کے لیے وہ ٹھہراتے ہیں جو اپنے لیے ناگوار ہے اور ان کی زبانیں جھوٹ کہتی ہیں کہ ان کے لیے بھلائی ہے تو آپ ہی ہوا کہ ان کے لیے آگ ہے اور وہ حد سے گزارے ہوئے ہیں،\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mcmlxiv{خدا کی قسم ہم نے تم سے پہلے کتنی امتوں کی طرف رسول بھیجے تو شیطان نے ان کے کوتک (برُے اعمال) ان کی آنکھوں میں بھلے کر دکھائے تو آج وہی ان کا رفیق ہے اور ان کے لیے دردناک عذاب ہے،\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mcmlxv{اور ہم نے تم پر یہ کتاب نہ اتاری مگر اس لیے کہ تم لوگوں پر روشن کردو جس بات میں اختلاف کریں اور ہدایت اور رحمت ایمان والوں کے لیے،\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mcmlxvi{اور اللہ نے آسمان سے پانی اتارا تو اس سے زمین کو زندہ کردیا اس کے مرے پیچھے بیشک اس میں نشانی ہے ان کو جو کان رکھتے ہیں،\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mcmlxvii{اور بیشک تمہارے لیے چوپایوں میں نگاہ حاصل ہونے کی جگہ ہے ہم تمہیں پلاتے ہیں اس چیز میں سے جو ان کے پیٹ میں ہے، گوبر اور خون کے بیچ میں سے خالص دودھ گلے سے سہل اترتا پینے والوں کے لیے،\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mcmlxviii{اور کھجور اور انگور کے پھلوں میں سے کہ اس سے نبیذ بناتے ہو اور اچھا رزق بیشک اس میں نشانی ہے عقل والوں کو،\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mcmlxix{اور تمہارے رب نے شہد کی مکھی کو الہام کیا کہ پہاڑوں میں گھر بنا اور درختوں میں اور چھتوں میں،\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mcmlxx{پھر ہر قسم کے پھل میں سے کھا اور اپنے رب کی راہیں چل کر تیرے لیے نرم و آسان ہیں، اس کے پیٹ سے ایک پینے کی چیز رنگ برنگ نکلتی ہے، جس میں لوگوں کی تندرستی ہے، بیشک اس میں نشانی ہے دھیان کرنے والوں کو،\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mcmlxxi{اور اللہ نے تمہیں پیدا کیا پھر تمہاری جان قبض کرے گا اور تم میں کوئی سب سے ناقض عمر کی طرف پھیرا جاتا ہے کہ جاننے کے بعد کچھ نہ جانے بیشک اللہ کچھ جانتا ہے سب کچھ کرسکتا ہے،\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mcmlxxii{اور اللہ نے تم میں ایک دوسرے پر رزق میں بڑائی دی تو جنہیں بڑائی دی ہے وہ اپنا رزق اپنے باندی غلاموں کو نہ پھیر دیں گے کہ وہ سب اس میں برابر ہوجائیں تو کیا اللہ کی نعمت سے مکرتے ہیں،\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mcmlxxiii{اور اللہ نے تمہارے لیے تمہاری جنس سے عورتیں بنائیں اور تمہارے لیے تمہاری عورتوں سے بیٹے اور پوتے نواسے پیدا کیے اور تمہیں ستھری چیزوں سے روز ی دی تو کیا جھوٹی بات پر یقین لاتے ہیں اور اللہ کے فضل سے منکر ہوتے ہیں،\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mcmlxxiv{اور اللہ کے سوا ایسوں کو پوجتے ہیں جو انہیں آسمان اور زمین سے کچھ بھی روزی دینے کا اختیار نہیں رکھتے نہ کچھ کرسکتے ہیں،\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mcmlxxv{تو اللہ کے لیے مانند نہ ٹھہراؤ بیشک اللہ جانتا ہے اور تم نہیں جانتے،\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mcmlxxvi{اللہ نے ایک کہاوت بیان فرمائی ایک بندہ ہے دوسرے کی ملک آپ کچھ مقدور نہیں رکھتا اور ایک جسے ہم نے اپنی طرف سے اچھی روزی عطا فرمائی تو وہ اس میں سے خرچ کرتا ہے چھپے اور ظاہر کیا وہ برابر ہوجائیں گے سب خوبیاں اللہ کو ہیں بلکہ ان میں اکثر کو خبر نہیں\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mcmlxxvii{اور اللہ نے کہاوت بیان فرمائی دو مرد ایک گونگا جو کچھ کام نہیں کرسکتا اور وہ اپنے آقا پر بوجھ ہے جدھر بھیجے کچھ بھلائی نہ لائے کیا برابر ہوجائے گا ہ اور وہ جو انصاف کا حکم کرتا ہے اور وہ سیدھی راہ پر ہے، ف۱۶۷)\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mcmlxxviii{اور اللہ ہی کے لیے ہیں آسمانوں اور زمین کی چھپی چیزیں اور قیامت کا معاملہ نہیں مگر جیسے ایک پلک کا مارنا بلکہ اس سے بھی قریب بیشک اللہ سب کچھ کرسکتا ہے،\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mcmlxxix{اور اللہ نے تمہیں تمہاری ماؤوں کے پیٹ سے پیدا کیا کہ کچھ نہ جانتے تھے اور تمہیں کان اور آنکھ اور دل دیئے کہ تم احسان مانو، ف۱۷۲)\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mcmlxxx{کیا انہوں نے پرندے نے پرندے نہ دیکھے حکم کے باندھے آسمان کی فضا میں، انہیں کوئی نہیں روکتا سوا اللہ کے بیشک اس میں نشانیاں ہیں ایمان والوں کو، ف۱۷۴)\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mcmlxxxi{اور اللہ نے تمہیں گھر دیئے بسنے کو اور تمہارے لیے چوپایوں کی کھالوں سے کچھ گھر بناےٴ جو تمھیں ہلکے پڑتے ہیں تمھارے سفر کے دن اور منزلوں پرٹھہر نے کے دن، اور ان کی اون اور ببری (رونگٹوں) اور بالوں سے کچھ گرہستی (خانگی ضروریات) کا سامان اور برتنے کی چیزیں ایک وقت تک،\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mcmlxxxii{اور اللہ نے تمہیں اپنی بنائی ہوئی چیزوں سے سائے دیئے اور تمہارے لیے پہاڑوں میں چھپنے کی جگہ بنائی اور تمہارے لیے کچھ پہنادے بنائے کہ تمہیں گرمی سے بچائیں اور کچھ پہناوے کہ لڑائیں میں تمہاری حفاظت کریں یونہی اپنی نعمت تم پر پوری کرتا ہے کہ تم فرمان مانو\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mcmlxxxiii{پھر اگر وہ منہ پھیریں تو اے محبوب! تم پر نہیں مگر صاف پہنچا دینا،\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mcmlxxxiv{اللہ کی نعمت پہنچانتے ہیں پھر اس سے منکر ہوتے ہیں اور ان میں اکثر کافر ہیں،\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mcmlxxxv{اور جس دن ہم اٹھائیں گے ہر امت میں سے ایک گواہ پھر کافروں کو نہ اجازت ہو نہ وہ منائے جائیں، ف۱۹۳)\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mcmlxxxvi{اور ظلم کرنے والے جب عذاب دیکھیں گے اسی وقت سے نہ وہ ان پر سے ہلکا ہو نہ انہیں مہلت ملے،\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mcmlxxxvii{اور شرک کرنے والے جب اپنے شریکوں کو دیکھیں گے کہیں گے اے ہمارے رب! یہ ہیں ہمارے شریک کہ ہم تیرے سوا پوجتے تھے، تو وہ ان پر بات پھینکیں گے کہ تم بیشک جھوٹے ہو،\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mcmlxxxviii{اور اس دن اللہ کی طرف عاجزی سے گریں گے اور ان سے گم ہوجائیں گی جو بناوٹیں کرتے تھے، ف۱۹۹)\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mcmlxxxix{جنہوں نے کفر کیا اور اللہ کی راہ سے روکا ہم نے عذاب پر عذاب بڑھایا بدلہ ان کے فساد کا،\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mcmxc{اور جس دن ہم ہر گروہ میں ایک گواہ انہیں میں سے اٹھائیں گے کہ ان پر گواہی دے اور اے محبوب! تمہیں ان سب پر شاہد بناکر لائیں گے، اور ہم نے تم پر یہ قرآن اتارا کہ ہر چیز کا روشن بیان ہے اور ہدایت اور رحمت اور بشارت مسلمانوں کو،\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mcmxci{بیشک اللہ حکم فرماتا ہے انصاف اور نیکی اور رشتہ داروں کے دینے کا اور منع فرماتا بے حیائی اور برُی بات اور سرکشی سے تمہیں نصیحت فرماتا ہے کہ تم دھیان کرو،\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mcmxcii{اور اللہ کا عہد پورا کرو جب قول باندھو اور قسمیں مضبوط کرکے نہ توڑو اور تم اللہ کو اپنے اوپر ضامن کرچکے ہو، بیشک تمہارے کام جانتا ہے،\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mcmxciii{اور اس عورت کی طرح نہ ہو جس نے اپنا سُوت مضبوطی کے بعد ریزہ ریزہ کرکے توڑ دیا اپنی قسمیں آپس میں ایک بے اصل بہانہ بناتے ہو کہ کہیں ایک گروہ دوسرے گروہ سے زیادہ نہ ہو اللہ تو اس سے تمہیں آزماتا ہے اور ضرور تم پر صاف ظاہر کردے گا قیامت کے دن جس بات میں جھگڑتے تھے،\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mcmxciv{اور اللہ چاہتا تو تم کو ایک ہی امت کرتا لیکن اللہ گمراہ کرتا ہے جسے چاہے، اور راہ دیتا ہے جسے چاہے، اور ضرور تم سے تمہارے کام پوچھے جائیں گے،\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mcmxcv{اور اپنی قسمیں آپس میں بے اصل بہانہ نہ بنالو کہ کہیں کوئی پاؤں جمنے کے بعد لغزش نہ کرے اور تمہیں برائی چکھنی ہو بدلہ اس کا کہ اللہ کی راہ سے روکتے تھے اور تمہیں بڑا عذاب ہو\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mcmxcvi{اور اللہ کے عہد پر تھوڑے دام مول نہ لو بیشک وہ جو اللہ کے پاس ہے تمہارے لیے بہتر ہے اگر تم جانتے ہو،\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mcmxcvii{جو تمہارے پاس ہے ہوچکے گا اور جو اللہ کے پاس ہے ہمیشہ رہنے والا، اور ضرور ہم صبر کرنے والوں کو ان کا وہ صلہ دیں گے جو ان کے سب سے اچھے کام کے قابل ہو،\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mcmxcviii{جو اچھا کام کرے مرد ہو یا عورت اور ہو مسلمان تو ضرور ہم اسے اچھی زندگی جِلائیں گے اور ضرور انہیں ان کا نیگ (اجر) دیں گے جو ان کے سب سے بہتر کام کے لائق ہوں،\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mcmxcix{تو جب تم قرآن پڑھو تو اللہ کی پناہ مانگو شیطان مردود سے،،\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mm{بیشک اس کا کوئی قابو ان پر نہیں جو ایمان لائے اور اپنے رب ہی پر بھروسہ رکھتے ہیں\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mmi{اس کا قابو تو انہیں پر ہے جو اس سے دوستی کرتے ہیں اور اسے شریک ٹھہراتے ہیں،\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mmii{اور جب ہم ایک آیت کی جگہ دوسری آیت بدلیں اور اللہ خوب جانتا ہے جو اتارتا ہے کافر کہیں تم تو دل سے بنا لاتے ہو بلکہ ان میں اکثر کو علم نہیں،\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mmiii{تم فرماؤ اسے پاکیزگی کی روح نے اتارا تمہارے رب کی طرف سے ٹھیک ٹھیک کہ اس سے ایمان والوں کو ثابت قدم کرے اور ہدایت اور بشارت مسلمانوں کو،\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mmiv{اور بیشک ہم جانتے ہیں کہ وہ کہتے ہیں، یہ تو کوئی آدمی سکھاتا ہے، جس کی طرف ڈھالتے ہیں اس کی زبان عجمی ہے اور یہ روشن عربی زبان\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mmv{بیشک وہ جو اللہ کی آیتوں پر ایمان نہیں لاتے اللہ انھیں راہ نهیں دیتا اور ان کے لے درد ناک عذاب ہے،\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mmvi{جھوٹ بہتان دہی باندھتے ہین جو اللہ کی آیتوں پر ایمان نہیں رکھتے اور دہی جھوٹے ہیں،\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mmvii{جو ایمان لا کر اللہ کا منکر ہو سوا اس کے مجبور کیا جا ےٴ اور اس کا دل ایمان پر جما ہوا ہو، ہاں وہ جو دل کھول کر کافر ہو ان پر اللہ کا غضب ہے اور ان کو بڑاعذاب ہے،\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mmviii{یہ اس لےٴ کہ انھوں نے دنیا کی زندگی آخرت سے پیاری جانی، اور اس لےٴ کہ اللہ (ایسے) کافروں کو راہ نہیں دیتا،\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mmix{یہ ہیں وه جن کے دل اور کان اور آنکھو ں پر اللہ نے مہر کر دی ہے اور وہی غفلت مین پڑے ہیں،\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mmx{آپ ہی ہوا کہ آخرت میں وہی خراب\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mmxi{پھر بیشک تمہارا رب ان کے لیے جنہوں نے اپنے گھر چھوڑے بعد اس کے کہ ستائے گئے پھر انہوں نے جہاد کیا اور صابر رہے بیشک تمہارا رب اس کے بعد ضرور بخشنے والا ہے مہربان،\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mmxii{جس دن ہر جان اپنی ہی طرف جھگڑتی آئے گی اور ہر جان کو اس کا کیا پورا بھردیا جائے گا اور ان پر ظلم نہ ہوگا\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mmxiii{اور اللہ نے کہاوت بیان فرمائی ایک بستی کہ امان و اطمینان سے تھی ہر طرف سے اس کی روزی کثرت سے آتی تو وہ اللہ کی نعمتوں کی ناشکری کرنے لگی تو اللہ نے اسے یہ سزا چکھائی کہ اسے بھوک اور ڈر کا پہناوا پہنایا بدلہ ان کے کیے کا،\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@mmxiv{اور بیشک ن کے پاس انہیں میں سے ایک رسول تشریف لایا تو انہوں نے اسے جھٹلایا تو انہیں عذاب نے پکڑا اور وہ بے انصاف تھے،\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@mmxv{تو اللہ کی دی ہوئی روزی حلال پاکیزہ کھاؤ اور اللہ کی نعمت کا شکر کرو اگر تم اسے پوجتے ہو،\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@mmxvi{تم پر تو یہی حرام کیا ہے مُردار اور خون اور سور کا گوشت اور وہ جس کے ذبح کرتے وقت غیر خدا کا نام پکارا گیا پھر جو لاچار ہو نہ خواہش کرتا اور نہ حد سے بڑھتا تو بیشک اللہ بخشنے والا مہربان ہے،\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@mmxvii{اور نہ کہو اسے جو تمہاری زبانیں جھوٹ بیان کرتی ہیں یہ حلال ہے اور یہ حرام ہے کہ اللہ پر جھوٹ باندھو بیشک جو اللہ پر جھوٹ باندھتے ہیں ان کا بھلا نہ ہوگا،\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@mmxviii{تھوڑا برتنا ہے اور ان کے لیے دردناک عذاب\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@mmxix{اور خاص یہودیوں پر ہم نے حرام فرمائیں وہ چیزیں جو پہلے تمہیں ہم نے سنائیں اور ہم نے ان پر ظلم نہ کیا ہاں وہی اپنی جانوں پر ظلم کرتے تھے،\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@mmxx{پھر بیشک تمہارا رب ان کے لیے جو نادانی سے برائی کر بیٹھیں پھر اس کے بعد توبہ کریں اور سنور جائیں بیشک تمہارا رب اس کے بعد ضرور بخشنے والا مہربان ہے،\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@mmxxi{بیشک ابراہیم ایک امام تھا اللہ کا فرمانبردار اور سب سے جدا اور مشرک نہ تھا،\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@mmxxii{اس کے احسانوں پر شکر کرنے والا، اللہ نے اسے چن لیا اور اسے سیدھی راہ دکھائی،\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@mmxxiii{اور ہم نے اسے دنیا میں بھلائی دی اور بیشک وہ آخرت میں شایان قرب ہے،\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@mmxxiv{پھر ہم نے تمہیں وحی بھیجی کہ دین ابراہیم کی پیروی کرو جو ہر باطل سے الگ تھا اور مشرک نہ تھا،\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@mmxxv{ہفتہ تو انہیں پر رکھا گیا تھا جو اس میں مختلف ہوگئے اور بیشک تمہارا رب قیا مت کے دن ان میں فیصلہ کردے گا جس بات میں اختلاف کرتے تھے،\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@mmxxvi{اپنے رب کی راہ کی طرف بلاؤ پکی تدبیر اور اچھی نصیحت سے اور ان سے اس طریقہ پر بحث کرو جو سب سے بہتر ہو بیشک تمہارا رب خوب جانتا ہے جو اس کی راہ سے بہکا اور وہ خوب جانتا ہے راہ والوں کو،\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@mmxxvii{اور اگر تم سزا دو تو ایسی ہی سزا دو جیسی تمہیں تکلیف پہونچائی تھی اور اگر تم صبر کرو تو بیشک صبر والوں کو صبر سب سے اچھا،\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@mmxxviii{اور اے محبوب! تم صبر کرو اور تمہارا صبر اللہ ہی کی توفیق سے ہے اور ان کا غم نہ کھاؤ اور ان کے فریبوں سے دل تنگ نہ ہو، ف۲۸۹)\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@mmxxix{بیشک اللہ ان کے ساتھ ہے جو ڈرتے ہیں اور جو نیکیاں کرتے ہیں،\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@mmxxx{\basmalahur پاکی ہے اسے جو اپنے بندے کو، راتوں رات لے گیا مسجد حرام سے مسجد اقصیٰ تک جس کے گرداگرد ہم نے برکت رکھی کہ ہم اسے اپنی عظیم نشانیاں دکھائیں، بیشک وہ سنتا دیکھتا ہے،\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmxxxi{اور ہم نے موسیٰ کو کتاب عطا فرمائی اور اسے بنی اسرائیل کے لیے ہدایت کیا کہ میرے سوا کسی کو کارسام نہ ٹھہراؤ،\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmxxxii{اے ان کی اولاد! جن کو ہم نے نوح کے ساتھ سوار کیا بیشک وہ بڑا شکرا گزار بندہ تھا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmxxxiii{اور ہم نے بنی اسرائیل کو کتاب میں وحی بھیجی کہ ضرور تم زمین میں دوبارہ فساد مچاؤ گے اور ضرور بڑا غرور کرو گے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmxxxiv{پھر جب ان میں پہلی بار کا وعدہ آیا ہم نے تم پر اپنے بندے بھیجے سخت لڑائی والے تو وہ شہروں کے اندر تمہاری تلاش کو گھسے اور یہ ایک وعدہ تھا جسے پورا ہونا تھا،\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmxxxv{پھر ہم نے ان پر اُلٹ کر تمہارا حملہ کردیا اور تم کو مالوں اور بیٹوں سے مدد دی اور تمہارا جتھا بڑھا دیا،\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmxxxvi{اگر تم بھلائی کرو گے اپنا بھلا کرو گے اور اگر بُرا کرو گے تو اپنا، پھر جب دوسری بار کا وعدہ آیا کہ دشمن تمہارا منہ بگاڑ دیں اور مسجد میں داخل ہوں جیسے پہلی بار داخل ہوئے تھے اور جس چیز پر قابو پائیں تباہ کرکے برباد کردیں،\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmxxxvii{قریب ہے کہ تمہارا رب تم پر رحم کرے اور اگر تم پھر شرارت کرو تو ہم پھر عذاب کریں گے اور ہم نے جہنم کو کافروں کا قید خانہ بنایا ہے،\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmxxxviii{بیشک یہ قرآن وہ راہ دکھاتا ہے جو سب سے سیدھی ہے اور خوشی سناتا ہے ایمان والوں کو جو اچھے کام کریں کہ ان کے لیے بڑا ثواب ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmxxxix{اور یہ کہ جو آخرت پر ایمان نہیں لاتے ہم نے ان کے لیے دردناک عذاب تیار کر رکھا ہے،\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmxl{اور آدمی برائی کی دعا کرتا ہے جیسے بھلائی مانگتا ہے اور آدمی بڑا جلد باز ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmxli{اور ہم نے رات اور دن کو دو نشانیاں بنایا تو رات کی نشانی مٹی ہوئی رکھی اور دن کی نشانیاں دکھانے والی کہ اپنے کا فضل تلاش کرو اور برسوں کی گنتی اور حساب جانو اور ہم نے ہر چیز خوب جدا جدا ظاہر فرمادی\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmxlii{اور ہر انسان کی قسمت ہم نے اس کے گلے سے لگادی اور اس کے لیے قیامت کے دن ایک نوشتہ نکالیں گے جسے کھلا ہوا پائے گا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmxliii{فرمایا جائے گا کہ اپنا نامہ (نامہٴ اعمال) پڑھ آج تو خود ہی اپنا حساب کرنے کو بہت ہے،\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmxliv{جو راہ پر آیا وہ اپنے ہی بھلے کو راہ پر آیا اور جو بہکا تو اپنے ہی برے کو بہکا اور کوئی بوجھ اٹھانے والی جان دوسرے کا بوجھ نہ اٹھائے گی اور ہم عذاب کرنے والے نہیں جب تک رسول نہ بھیج لیں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmxlv{اور جب ہم کسی بستی کو ہلاک کرنا چاہتے ہیں اس کے خوشحالوں پر احکام بھیجتے ہیں پھر وہ اس میں بے حکمی کرتے ہیں تو اس پر بات پوری ہوجاتی ہے تو ہم اسے تباہ کرکے برباد کردیتے ہیں،\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmxlvi{اور ہم نے کتنی ہی سنگتیں (قومیں) نوح کے بعد ہلاک کردیں اور تمہارا رب کافی ہے اپنے بندوں کے گناہوں سے خبردار دیکھنے والا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmxlvii{جو یہ جلدی والی چاہے ہم اسے اس میں جلد دے دیں جو چاہیں جسے چاہیں پھر اس کے لیے جہنم کردیں کہ اس میں جائے مذمت کیا ہوا دھکے کھاتا،\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmxlviii{اور جو آخرت چاہے اور اس کی سی کوشش کرے اور ہو ایمان والا تو انہیں کی کوشش ٹھکانے لگی،\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmxlix{ہم سب کو مدد دیتے ہیں اُن کو بھی اور اُن کو بھی، تمہارے رب کی عطا سے اور تمہارے رب کی عطا پر روک نہیں،\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mml{دیکھو ہم نے ان میں ایک کو ایک پر کیسی بڑائی دی اور بیشک آخرت درجوں میں سب سے بڑی اور فضل میں سب سے اعلیٰ ہے،\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmli{اے سننے والے اللہ کے ساتھ دوسرا خدا نہ ٹھہرا کہ تُو بیٹھ رہے گا مذمت کیا جاتا بیکس\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmlii{اور تمہارے رب نے حکم فرمایا کہ اس کے سوا کسی کو نہ پُوجو اور ماں باپ کے ساتھ اچھا سلوک کرو، اگر تیرے سامنے ان میں ایک یا دونوں بڑھاپے کو پہنچ جائیں تو ان سے ہُوں، نہ کہنا اور انہیں نہ جھڑکنا اور ان سے تعظیم کی بات کہنا\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmliii{اور ان کے لیے عاجزی کا بازو بچھا نرم دلی سے اور عرض کر کہ اے میرے رب تو ان دونوں پر رحم کر جیسا کہ ان دنوں نے مجھے چھٹپن (بچپن) میں پالا\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmliv{تمہارا رب خوب جانتا ہے جو تمہارے دلوں میں ہے اگر تم لائق ہوئے تو بیشک وہ توبہ کرنے والوں کو بخشنے والا ہے،\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmlv{اور رشتہ داروں کو ان کا حق دے اور مسکین اور مسافر کو اور فضول نہ اڑا\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmlvi{بیشک اڑانے والے شیطانوں کے بھائی ہیں اور شیطان اپنے رب کا بڑا ناشکرا ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmlvii{اور اگر تو ان سے منہ پھیرے اپنے رب کی رحمت کے انتظار میں جس کی تجھے امید ہے تو ان سے آسان بات کہہ\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmlviii{اور اپنا ہاتھ اپنی گردن سے بندھا ہوا نہ رکھ اور نہ پورا کھول دے کہ تو بیٹھ رہے ملامت کیا ہوا تھکا ہوا\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmlix{بیشک تمہارا رب جسے چاہے رزق کشادہ دیتا اور کستا ہے (تنگی دیتا ہے) بیشک وہ اپنے بندوں کو خوب جانتا دیکھتا ہے،\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmlx{اور اپنی اولاد کو قتل نہ کرو مفلسی کے ڈر سے ہم انہیں بھی رزق دیں گے اور تمہیں بھی، بیشک ان کا قتل بڑی خطا ہے،\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmlxi{اور بدکاری کے پاس نہ جاؤ بیشک وہ بے حیائی ہے، اور بہت ہی بری راہ،\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmlxii{اور کوئی جان جس کی حرمت اللہ نے رکھی ہے ناحق نہ مارو، اور جو ناحق نہ مارا جائے تو بیشک ہم نے اس کے وارث کو قابو دیا تو وہ قتل میں حد سے نہ بڑھے ضرور اس کی مدد ہونی ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmlxiii{اور یتیم کے مال کے پاس تو جاؤ مگر اس راہ سے جو سب سے بھلی ہے یہاں تک کہ وہ اپنی جوانی کو پہنچے اور عہد پورا کرو بیشک عہد سے سوال ہونا ہے،\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmlxiv{اور ماپو تو پورا ماپو اور برابر ترازو سے تولو، یہ بہتر ہے اور اس کا انجام اچھا،\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmlxv{اور اس بات کے پیچھے نہ پڑ جس کا تجھے علم نہیں بیشک کان اور آنکھ اور دل ان سب سے سوال ہونا ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmlxvi{اور زمین میں اتراتا نہ چل بیشک ہر گز زمین نہ چیر ڈالے گا، اور ہرگز بلندی میں پہاڑوں کو نہ پہنچے گا\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmlxvii{یہ جو کچھ گزرا ان میں کی بُری بات تیرے رب کو ناپسند ہے،\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmlxviii{یہ ان وحیوں میں سے ہے جو تمہارے رب نے تمہاری طرف بھیجی حکمت کی باتیں اور اے سننے والے اللہ ساتھ دوسرا خدا نہ ٹھہرا کہ تو جہنم میں پھینکا جائے گا طعنہ پاتا دھکے کھاتا،\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmlxix{کیا تمہارے رب نے تم کو بیٹے چن دیے اور اپنے لیے فرشتوں سے بیٹیاں بنائیں بیشک تم بڑا بول بولتے ہو\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmlxx{اور بیشک ہم نے اس قرآن میں طرح طرح سے بیان فرمایا کہ وہ سمجھیں اور اس سے انھیں نہیں بڑھتی مگر نفرت\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmlxxi{تم فرماؤ اگر اس کے ساتھ اور خدا ہوتے جیسا یہ بکتے ہیں جب تو وہ عرش کے مالک کی طرف کوئی راہ ڈھونڈ نکالتے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmlxxii{اسے پاکی اور برتری ان کی باتوں سے بڑی برتری،\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmlxxiii{اس کی پاکی بولتے ہیں ساتوں آسمان اور زمین اور جو کوئی ان میں ہیں اور کوئی چیز نہیں جو اسے سراہتی ہوتی اس کی پاکی نہ بولے ہاں تم ان کی تسبیح نہیں سمجھتے بیشک وہ حلم والا بخشنے والا ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmlxxiv{اور اے محبوب! تم نے قرآن پڑھا ہم نے تم پر اور ان میں کہ آخرت پر ایمان ہیں لاتے ایک چھپا ہوا پردہ کردیا\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmlxxv{اور ہم نے ان کے دلوں پر غلاف ڈال دیے ہیں کہ اسے نہ سمجھیں اور ان کے کانوں میں ٹینٹ (روئی) اور جب تم قرآن میں اپنے اکیلے رب کی یاد کرتے ہو وہ پیٹھ پھیر کر بھاگتے ہیں نفرت کرتے،\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmlxxvi{ہم خوب جانتے ہیں جس لیے وہ سنتے ہیں جب تمہاری طرف کان لگاتے ہیں اور جب آپس میں مشورہ کرتے ہیں جبکہ ظالم کہتے ہیں تم پیچھے نہیں چلے مگر ایک ایسے مرد کے جس پر جادو ہوا\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmlxxvii{دیکھو انہوں نے تمہیں کیسی تشبیہیں دیں تو گمراہ ہوئے کہ راہ نہیں پاسکتے،\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmlxxviii{اور بولے کیا جب ہم ہڈیاں اور ریزہ ریزہ ہوجائیں گے کیا سچ مچ نئے بن کر اٹھیں گے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmlxxix{تم فرماؤ کہ پتھر یا لوہا ہوجاؤ،\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmlxxx{یا اور کوئی مخلوق جو تمہارے خیال میں بڑی ہو (۱۰۴) تو اب کہیں گے ہمیں کون پھر پیدا کرتے گا، تم فرماؤ وہی جس نے تمہیں پہلی بار پیدا کیا، تو اب تمہاری طرف مسخرگی سے سر ہِلا کر کہیں گے یہ کب ہے تم فرماؤ شاید نزدیک ہی ہو،\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmlxxxi{جس دن وہ تمہیں بُلائے گا تو تم اس کی حمد کرتے چلے آؤ گے اور سمجھو گے کہ نہ رہے (۱۰۸) تھے مگر تھوڑا،\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmlxxxii{اور میرے بندوں سے فرماؤ وہ بات کہیں جو سب سے اچھی ہو بیشک شیطان ان کے آپس میں فساد ڈالتا ہے، بیشک شیطان آدمی کا کھلا دشمن ہے،\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmlxxxiii{تمہارا رب تمہیں خوب جانتا ہے، وہ چاہے تو تم پر رحم کرے چاہے تو تمہیں عذاب کرے، اور ہم نے تم کو ان پر کڑوڑا (حاکمِ اعلیٰ) بناکر نہ بھیجا\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmlxxxiv{اور تمہارا رب خوب جانتا ہے جو کوئی آسمانوں اور زمین میں ہیں اور بیشک ہم نے نبیوں میں ایک کو ایک پر بڑائی دی اور داؤد کو زبور عطا فرمائی\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmlxxxv{تم فرماؤ پکارو انہیں جن کو اللہ کے سوا گمان کرتے ہو تو وہ اختیار نہیں رکھتے تم سے تکلیف دو کرنے اور نہ پھیر دینے کا\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmlxxxvi{وہ مقبول بندے جنہیں یہ کافر پوجتے ہیں وہ آپ ہی اپنے رب کی طرف وسیلہ ڈھونڈتے ہیں کہ ان میں کون زیادہ مقرب ہے اس کی رحمت کی امید رکھتے اور اس کے عذاب سے ڈرتے ہیں بیشک تمہارے رب کا عذاب ڈر کی چیز ہے،\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmlxxxvii{اور کوئی بستی نہیں مگر یہ کہ ہم اسے روزِ قیامت سے پہلے نیست کردیں گے یا اسے سخت عذاب دیں گے یہ کتاب میں لکھا ہوا ہے،\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmlxxxviii{اور ہم ایسی نشانیاں بھیجنے سے یوں ہی باز رہے کہ انہیں اگلوں نے جھٹلایا اور ہم نے ثمود کو ناقہ دیا آنکھیں کھولنے کو تو انہوں نے اس پر ظلم کیا اور ہم ایسی نشانیاں نہیں بھیجتے مگر ڈرانے کو\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmlxxxix{اور جب ہم نے تم سے فرمایا کہ سب لوگ تمہارے رب کے قابو میں ہیں اور ہم نے نہ کیا وہ دکھاوا جو تمہیں دکھایا تھا مگر لوگوں کی آزمائش کو اور وہ پیڑ جس پر قرآن میں لعنت ہے اور ہم انہیں ڈراتے ہیں تو انھیں نہیں بڑھتی مگر بڑی سرکشی،\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmxc{اور یاد کرو جب ہم نے فرشتوں کو حکم دیا کہ آدم کو سجدہ کرو تو ان سب نے سجدہ کیا سوا ابلیس کے، بولا کیا میں اسے سجدہ کروں جسے تو نے مٹی سے بنایا\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmxci{بولا دیکھ تو جو یہ تو نے مجھ سے معزز رکھا اگر تو نے مجھے قیامت تک مہلت دی تو ضرور میں اس کی اولاد کو پیس ڈالوں گا مگر تھوڑا\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmxcii{فرمایا، دور ہو تو ان میں جو تیری پیروی کرے گا تو بیشک سب کا بدلہ جہنم ہے بھرپور سزا،\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmxciii{اور ڈگا دے (بہکادے) ان میں سے جس پر قدرت پائے اپنی آواز سے اور ان پر لام باندھ (فوج چڑھا) لا اپنے سواروں اور اپنے پیادوں کا اور ان کا ساجھی ہو مالوں اور بچو ں میں اور انہیں وعدہ دے اور شیطان انہیں وعدہ نہیں دیتا مگر فریب سے،\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmxciv{بیشک جو میرے بندے ہیں ان پر تیرا کچھ قابو نہیں، اور تیرا رب کافی ہے کام بنانے کو\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmxcv{تمہارا رب وہ ہے کہ تمہارے لیے دریا میں کشتی رواں کرتا ہے کہ تم اس کا فضل تلاش کرو، بیشک وہ تم پر مہربان ہے،\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmxcvi{اور جب تمہیں دریا میں مصیبت پہنچتی ہے تو اس کے سوا جنہیں پوجتے ہیں سب گم ہوجاتے ہیں پھر جب تمہیں خشکی کی طرف نجات دیتا ہے تو منہ پھیر لیتے ہیں اور انسان بڑا ناشکرا ہے،\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmxcvii{کیا تم اس سے نڈر ہوئے کہ وہ خشکی ہی کا کوئی کنارہ تمہارے ساتھ دھنسادے یا تم پر پتھراؤ بھیجے پھر اپنا کوئی حمایتی نہ پاؤ\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmxcviii{یا اس سے نڈر ہوئے کہ تمہیں دوبارہ دریا میں لے جائے پھر تم پر جہاز توڑنے والی آندھی بھیجے تو تم کو تمہارے کفر کے سبب ڈبو دے پھر اپنے لیے کوئی ایسا نہ پاؤ کہ اس پر ہمارا پیچھا کرے\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmxcix{اور بیشک ہم نے اولادِ آدم کو عزت دی اور ان کی خشکی اور تری میں سوار کیا اور ان کو ستھری چیزیں روزی دیں اور ان کو اپنی بہت مخلوق سے افضل کیا\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmc{جس دن ہم ہر جماعت کو اس کے امام کے ساتھ بلائیں گے تو جو اپنا نامہ داہنے ہاتھ میں دیا گیا یہ لوگ اپنا نامہ پڑھیں گے اور تاگے بھر ان کا حق نہ دبایا جائے گا\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmci{اور جو اس زندگی میں اندھا ہو وہ آخرت میں اندھا ہے اور اوربھی زیادہ گمراہ،\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmcii{اور وہ تو قریب تھا کہ تمہیں کچھ لغزش دیتے ہماری وحی سے جو ہم نے تم کو بھیجی کہ تم ہماری طرف کچھ اور نسبت کردو، اور ایسا ہوتا تو وہ تم کو اپنا گہرا دو ست بنالیتے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmciii{اور اگر ہم تمہیں ثابت قدم نہ رکھتے تو قریب تھا کہ تم ان کی طرف کچھ تھوڑا سا جھکتے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmciv{اور ایسا ہوتا تو ہم تم کو دُونی عمر اور دو چند موت کا مزہ دیتے پھر تم ہمارے مقابل اپنا کوئی مددگار نہ پاتے،\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmcv{اور بیشک قریب تھا کہ وہ تمہیں اس زمین سے ڈگا دیں (کھسکادیں) کہ تمہیں اس سے باہر کردیں اور ایسا ہوتا تو وہ تمہارے پیچھے نہ ٹھہرتے مگر تھوڑا\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmcvi{دستور ان کا جو ہم نے تم سے پہلے رسول بھیجے اور تم ہمارا قانون بدلتا نہ پاؤ گے،\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmcvii{نماز قائم رکھو سورج ڈھلنے سے رات کی اندھیری تک اور صبح کا قرآن بیشک صبح کے قرآن میں فرشتے حاضر ہوتے ہیں\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmcviii{اور رات کے کچھ حصہ میں تہجد کرو یہ خاص تمہارے لیے زیادہ ہے قریب ہے کہ تمہیں تمہارا رب ایسی جگہ کھڑا کرے جہاں سب تمہاری حمد کریں\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmcix{اور یوں عرض کرو کہ اے میرے رب مجھے سچی طرح داخل کر اور سچی طرح باہر لے جا اور مجھے اپنی طرف سے مددگار غلبہ دے\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmcx{اور فرماؤ کہ حق آیا اور باطل مٹ گیا بیشک باطل کو مٹنا ہی تھا\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmcxi{اور ہم قرآن میں اتارتے ہیں وہ چیز (۱۷۹) جو ایمان والوں کے لیے شفا اور رحمت ہے اور اس سے ظالموں کو نقصان ہی بڑھتا ہے،\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmcxii{اور جب ہم آدمی پر احسان کرتے ہیں منہ پھیرلیتا ہے اور اپنی طرف دور ہٹ جاتا ہے اور جب اسے برائی پہنچے تو ناامید ہوجاتا ہے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmcxiii{تم فرماؤ سب اپنے کینڈے (انداز) پر کام کرتے ہیں تو تمہارا رب خوب جانتا ہے کون زیادہ راہ پر ہے،\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmcxiv{اور تم سے روح کو پوچھتے ہیں ہیں، تم فرماؤ روح میرے رب کے حکم سے ایک چیز ہے اور تمہیں علم نہ ملا مگر تھوڑا\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmcxv{اور اگر ہم چاہتے تو یہ وحی جو ہم نے تمہاری طرف کی اسے لے جاتے پھر تم کوئی نہ پاتے کہ تمہارے لیے ہمارے حضور اس پر وکالت کرتا\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmcxvi{مگر تمہارے رب کی رحمت بیشک تم پر اس کا بڑا فضل ہے\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmcxvii{تم فرماؤ اگر آدمی اور جن سب اس بات پر متفق ہوجائیں کہ اس قرآن کی مانند لے آئیں تو اس کا مثل نہ لاسکیں گے اگرچہ ان میں ایک دوسرے کا مددگار ہو\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmcxviii{اور بیشک ہم نے لوگوں کے لیے اس قرآن میں ہم قسم کی مثل طرح طرح بیان فرمائی تو اکثر آدمیوں نے نہ مانا مگر ناشکری کرنا\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmcxix{اور بولے کہ ہم تم پر ہرگز ایمان نہ لائیں گے یہاں تک کہ تم ہمارے لیے زمین سے کوئی چشمہ بہا دو\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmcxx{یا تمہارے لیے کھجوروں اور انگوروں کا کوئی باغ ہو پھر تم اس کے لیے اندر بہتی نہریں رواں کرو\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmcxxi{یا تم ہم پر آسمان گرا دو جیسا تم نے کہا ہے ٹکڑے ٹکڑے یااللہ اور فرشتوں کو ضامن لے آؤ\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmcxxii{یا تمہارے لیے طلائی گھر ہو یا تم آسمان پر چڑھ جاؤ اور ہم تمہارے چڑھ جانے پر بھی ہرگز ایمان نہ لائیں گے جب تک ہم پر ایک کتاب نہ اتارو جو ہم پڑھیں، تم فرماؤ پاکی ہے میرے رب کو میں کون ہوں مگر آدمی اللہ کا بھیجا ہوا\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmcxxiii{اور کس بات نے لوگوں کو ایمان لانے سے روکا جب ان کے پاس ہدایت آئی مگر اسی نے کہ بولے کیا اللہ نے آدمی اللہ کا بھیجا ہوا اور کس بات نے لوگوں کو ایمان لانے سے روکا جب ان کے پاس ہدایت آئی مگر اسی نے کہ بولے کیا اللہ نے آدمی کو رسول بناکر بھیجا\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mmcxxiv{تم فرماؤ اگر زمین میں فرشتے ہوتے چین سے چلتے تو ان پر ہم رسول بھی فرشتہ اتارتے\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mmcxxv{تم فرماؤ اللہ بس ہے گواہ میرے تمہارے درمیان (۲۰۰) بیشک وہ اپنے بندوں کو جانتا دیکھتا ہے،\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mmcxxvi{اور جسے اللہ راہ دے وہی راہ پر ہے اور جسے گمراہ کرے تو ان کے لیے اس کے سوا کوئی حمایت والے نہ پاؤ گے اور ہم انہیں قیامت کے دن ان کے منہ کے بل اٹھائیں گے اندھے اور گونگے اور بہرے ان کا ٹھکانا جہنم ہے جب کبھی بجھنے پر آئے گی ہم اسے اور بھڑکادیں گے،\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mmcxxvii{یہ ان کی سزا ہے اس پر کہ انہوں نے ہماری آیتوں سے انکار کیا اور بولے کیا جب ہم ہڈیاں اور ریزہ ریزہ ہوجائیں گے تو کیا سچ مچ ہم نئے بن کر اٹھائے جائیں گے،\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mmcxxviii{اور کیا وہ نہیں دیکھتے کہ وہ اللہ جس نے آسمان اور زمین بنائے ان لوگوں کی مثل بناسکتا ہے اور اس نے ان کے لیے ایک میعاد ٹھہرا رکھی ہے جس میں کچھ شبہ نہیں تو ظالم نہیں مانتے بے ناشکری کیے\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mmcxxix{تم فرماؤ اگر تم لوگ میرے رب کی رحمت کے خزانوں کے مالک ہوتے تو انہیں بھی روک رکھتے اس ڈر سے کہ خرچ نہ ہوجائیں، اور آدمی بڑا کنجوس ہے،\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mmcxxx{اور بیشک ہم نے موسیٰ کو نو روشن نشانیاں دیں تو بنی اسرائیل سے پوچھو جب وہ ان کے پاس آیا تو اس سے فرعون نے کہا، اے موسیٰ! میرے خیال میں تو تم پر جادو ہوا\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mmcxxxi{کہا یقیناً تو خوب جانتا ہے کہ انہیں نہ اتارا مگر آسمانوں اور زمین کے مالک نے دل کی آنکھیں کھولنے والیاں اور میرے گمان میں تو اے فرعون! تو ضرور ہلاک ہونے والا ہے\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mmcxxxii{تو اس نے چاہا کہ ان کو زمین سے نکال دے تو ہم نے اسے اور اس کے ساتھیوں کو سب کو ڈبو دیا\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mmcxxxiii{اور اس کے بعد ہم نے بنی اسرائیل سے فرمایا اس زمین میں بسو پھر جب آخرت کا وعدہ آئے گا ہم تم سب کو گھال میل (لپیٹ کر) لے آئیں گے\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mmcxxxiv{اور ہم نے قرآن کو حق ہی کے ساتھ اتارا اور حق وہی کے لیے اترا اور ہم نے تمہیں نہ بھیجا مگر خوشی اور ڈر سناتا،\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mmcxxxv{اور قرآن ہم نے جدا جدا کرکے اتارا کہ تم اسے لوگوں پر ٹھہر ٹھہر کر پڑھو اور ہم نے اسے بتدریج رہ رہ کر اتارا\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mmcxxxvi{تم فرماؤ کہ تم لوگ اس پر ایمان لاؤ یا نہ لاؤ بیشک وہ جنہیں اس کے اترنے سے پہلے علم ملا اب ان پر پڑھا جاتا ہے، ٹھوڑی کے بل سجدہ میں گر پڑتے ہیں،\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mmcxxxvii{اور کہتے ہیں پاکی ہے ہمارے رب کو بیشک ہمارے اب کا وعدہ پورا ہوتا تھا\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mmcxxxviii{اور تھوڑی کے بل گرتے ہیں روتے ہوئے اور یہ قرآن ان کے دل کا جھکنا بڑھاتا ہے، (السجدة) ۴\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mmcxxxix{تم فرماؤ اللہ کہہ کر پکارو رحمان کہہ کر، جو کہہ کر پکارو سب اسی کے اچھے نام ہیں اور اپنی نماز نہ بہت آواز سے پڑھو نہ بالکل آہستہ اور ان دنوں کے بیچ میں راستہ چاہو\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mmcxl{اور یوں کہو سب خوبیاں اللہ کو جس نے اپنے لیے بچہ اختیار نہ فرمایا اور بادشاہی میں کوئی اس کا شریک نہیں اور کمزوری سے کوئی اس کا حمایتی نہیں اور اس کی بڑائی بولنے کو تکبیر کہو\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mmcxli{\basmalahur سب خوبیاں اللہ کو جس نے اپنے بندے پر کتاب اتاری اور اس میں اصلاً (بالکل، ذرا بھی) کجی نہ رکھی،\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmcxlii{عدل والی کتاب کہ اللہ کے سخت عذاب سے ڈرائے اور ایمان والوں کو جو نیک کام کریں بشارت دے کہ ان کے لیے اچھا ثواب ہے،\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmcxliii{جس میں ہمیشہ رہیں گے،\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmcxliv{اور ان کو ڈرائے جو کہتے ہیں کہ اللہ نے اپنا کوئی بچہ بنایا،\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmcxlv{اس بارے میں نہ وہ کچھ علم رکھتے ہیں نہ ان کے باپ دادا کتنا بڑا بول ہے کہ ان کے منہ سے نکلتا ہے، نِرا جھوٹ کہہ رہے ہیں،\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmcxlvi{تو کہیں تم اپنی جان پر کھیل جاؤ گے ان کے پیچھے اگر وہ اس بات پر ایمان نہ لائیں غم سے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmcxlvii{بیشک ہم نے زمین کا سنگھار کیا جو کچھ اس پر ہے کہ انہیں آزمائیں ان میں کس کے کام بہتر ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmcxlviii{اور بیشک جو کچھ اس پر ہے ایک دن ہم اسے پٹ پر میدان (سفید زمین) کو چھوڑیں گے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmcxlix{کیا تمہیں معلوم ہوا کہ پہاڑ کی کھوہ اور جنگل کے کنارے والے ہماری ایک عجیب نشانی تھے،\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmcl{جب ان نوجوانوں نے غار میں پناہ لی پھر بولے اے ہمارے رب ہمیں اپنے پاس سے رحمت دے اور ہمارے کام میں ہمارے لیے راہ یابی کے سامان کر،\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmcli{تو ہم نے اس غار میں ان کے کے کانوں پر گنتی کے کئی برس تھپکا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmclii{پھر ہم نے انھیں جگایا کہ دیکھیں دو گروہوں میں کون ان کے ٹھہرنے کی مدت زیادہ ٹھیک بتاتا ہے،\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmcliii{ہم ان کا ٹھیک ٹھیک حال تمہیں سنائیں، وہ کچھ جوان تھے کہ اپنے رب پر ایمان لائے اور ہم نے ان کو ہدایت بڑھائی،\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmcliv{اور ہم نے ان کی ڈھارس بندھائی جب کھڑے ہوکر بولے کہ ہمارا رب وہ ہے جو آسمان اور زمین کا رب ہے ہم اس کے سوا کسی معبود کو نہ پوجیں گے ایسا ہو تو ہم نے ضرور حد سے گزری ہوئی بات کہی،\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmclv{یہ جو ہماری قوم ہے اس نے اللہ کے سوا خدا بنا رکھے ہیں، کیوں نہیں لاتے ان پر کوئی روشن سند، تو اس سے بڑھ کر ظالم کون جو اللہ پر جھوٹ باندھے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmclvi{اور جب تم ان سے اور جو کچھ وہ اللہ سوا پوجتے ہیں سب سے الگ ہوجاؤ تو غار میں پناہ لو تمہارا رب تمہارے لیے اپنی رحمت پھیلادے گا اور تمہارے کام میں آسانی کے سامان بنادے گا،\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmclvii{اور اے محبوب! تم سورج کو دیکھو گے کہ جب نکلتا ہے تو ان کے غار سے داہنی طرف بچ جاتا ہے اور جب ڈوبتا ہے تو ان سے بائیں طرف کترا جاتا ہے حالانکہ وہ اس غار کے کھلے میدان میں میں ہیں یہ اللہ کی نشانیوں میں سے ہے جسے اللہ راہ دے تو وہی راہ پر ہے، اور جسے گمراہ کرے تو ہرگز اس کا کوئی حمایتی راہ دکھانے والا نہ پاؤ گے،\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmclviii{اور تم انھیں جاگتا سمجھو اور وہ سوتے ہیں اور ہم ان کی داہنی بائیں کروٹیں بدلتے ہیں اور ان کا کتا اپنی کلائیاں پھیلائے ہوئے ہے غار کی چوکھٹ پر اے سننے! والے اگر تو انہیں جھانک کر دیکھے تو ان سے پیٹھ پھیر کر بھاگے اور ان سے ہیبت میں بھر جائے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmclix{اور یوں ہی ہم نے ان کو جگایا کہ آپس میں ایک دوسرے سے احوال پوچھیں ان میں ایک کہنے والا بولا تم یہاں کتنی دیر رہے، کچھ بولے کہ ایک دن رہے یا دن سے کم دوسرے بولے تمہارا رب خوب جانتا ہے جتنا تم ٹھہرے تو اپنے میں ایک کو یہ چاندی لے کر شہر میں بھیجو پھر وہ غور کرے کہ وہاں کون سا کھانا زیادہ ستھرا ہے کہ تمہارے لیے اس میں سے کھانے کو لائے اور چاہیے کہ نرمی کرے اور ہرگز کسی کو تمہاری اطلاع نہ دے،\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmclx{بیشک اگر وہ تمہیں جان لیں گے تو تمہیں پتھراؤ کریں گے یا اپنے دین میں پھیر لیں گے اور ایسا ہوا تو تمہارا کبھی بھلا نہ ہوگا،\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmclxi{اور اسی طرح ہم نے ان کی اطلاع کردی کہ لوگ جان لیں کہ اللہ کا وعدہ سچا ہے اور قیامت میں کچھ شبہ نہیں، جب وہ لوگ ان کے معاملہ میں باہم جھگڑنے لگے تو بولے ان کے غار پر کوئی عمارت بناؤ، ان کا رب انہیں خوب جانتا ہے، وہ بولے جو اس کام میں غالب رہے تھے قسم ہے کہ ہم تو ان پر مسجد بنائیں گے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmclxii{اب کہیں گے کہ وہ تین ہیں چوتھا ان کا کتا اور کچھ کہیں گے پانچ ہیں، چھٹا ان کا کتا بے دیکھے الاؤتکا (تیر تکا) بات اور کچھ کہیں گے سات ہیں اور آٹھواں ان کا کتا تم فرماؤ میرا رب ان کی گنتی خوب جانتا ہے انہیں نہیں جانتے مگر تھوڑے تو ان کے بارے میں بحث نہ کرو مگر اتنی ہی بحث جو ظاہر ہوچکی\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmclxiii{اور ان کے بارے میں کسی کتابی سے کچھ نہ پوچھو، اور ہر گز کسی بات کو نہ کہنا میں کل یہ کردوں گا،\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmclxiv{مگر یہ کہ اللہ چاہے اور اپنے رب کی یاد کر جب تو بھول جائے اور یوں کہو کہ قریب ہے میرا رب مجھے اس سے نزدیک تو راستی کی راہ دکھائے،\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmclxv{اور وہ اپنے غار میں تین سو برس ٹھہرے نو اوپر، ف۵۲)\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmclxvi{تم فرماؤ اللہ خوب جانتا ہے وہ جتنا ٹھہرے اسی کے لیے ہیں آسمانوں اور زمینوں کے سب غیب، وہ کیا ہی دیکھتا اور کیا ہی سنتا ہے اس کے سوا ان کا کوئی والی نہیں، اور وہ اپنے حکم میں کسی کو شریک نہیں کرتا،\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmclxvii{اور تلاوت کرو جو تمہارے رب کی کتاب تمہیں وحی ہوئی اس کی باتوں کا کوئی بدلنے والا نہیں اور ہرگز تم اس کے سوا پناہ نہ پاؤ گے،\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmclxviii{اور اپنی جان ان سے مانوس رکھو جو صبح و شام اپنے رب کو پکارتے ہیں اس کی رضا چاہتے ہیں اور تمہاری آنکھیں انہیں چھوڑ کر اور پر نہ پڑیں کیا تم دنیا کی زندگانی کا سنگھار چاہو گے، اور اس کا کہا نہ مانو جس کا دل ہم نے اپنی یاد سے غافل کردیا اور وہ اپنی خواہش کے پیچھے چلا اور اس کا کام حد سے گزر گیا،\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmclxix{اور فرما دو کہ حق تمہارے رب کی طرف سے ہے تو جو چاہے ایمان لائے اور جو چاہے کفر کرے بیشک ہم نے ظالموں کے لیے وہ آگ تیار کر رکھی ہے جس کی دیواریں انہیں گھیر لیں گی، اور اگر پانی کے لیے فریاد کریں تو ان کی فریاد رسی ہوگی اس پانی سے کہ چرخ دے (کھولتے ہوئے) دھات کی طرح ہے کہ ان کے منہ بھون دے گا کیا ہی برا پینا ہے اور دوزخ کیا ہی بری ٹھہرنے کی جگہ،\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmclxx{بیشک جو ایمان لائے اور نیک کام کیے ہم ان کے نیگ (اجر) ضائع نہیں کرتے جن کے کام اچھے ہوں،\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmclxxi{ان کے لیے بسنے کے باغ ہیں ان کے نیچے ندیاں بہیں وہ اس میں سونے کے کنگن بہنائے جایں گے اور سبز کپڑے کریب اور قناویز کے پہنیں گے وہاں تختوں پر تکیہ لگائے کیا ہی اچھا ثواب اور جنت کی کیا ہی اچھی آرام کی جگہ،\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmclxxii{اور ان کے سامنے دو مردوں کا حال بیان کرو کہ ان میں ایک کو ہم نے انگوروں کے دو باغ دیے اور ان کو کھجوروں سے ڈھانپ لیا اور ان کے بیچ میں کھیتی رکھی\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmclxxiii{دونوں باغ اپنے پھل لائے اور اس میں کچھ کمی نہ دی اور دونوں کے بیچ میں ہم نے نہر بہائی\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmclxxiv{اور وہ پھل رکھتا تھا تو اپنے ساتھی سے بولا اور وہ اس سے رد و بدل کرتا تھا میں تجھ سے مال میں زیادہ ہوں اور آدمیوں کا زیادہ زور رکھتا ہوں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmclxxv{اپنے باغ میں گیا اور اپنی جان پر ظلم کرتا ہوا بولا مجھے گمان نہیں کہ یہ کبھی فنا ہو،\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmclxxvi{اور میں گمان نہیں کرتا کہ قیامت قائم ہو اور اگر میں اپنے رب کی طرف پھر گیا بھی تو ضرور اس باغ سے بہتر پلٹنے کی جگہ پاؤں گا\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmclxxvii{اس کے ساتھی نے اس سے اُلٹ پھیر کرتے ہوئے جواب دیا کیا تو اس کے ساتھ کفر کرتا ہے جس نے تجھے مٹی سے بنایا پھر نطفہ سے پھر تجھے ٹھیک مرد کیا\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmclxxviii{لیکن میں تو یہی کہتا ہوں کہ وہ اللہ ہی میرا رب ہے او ر میں کسی کو اپنے رب کا شریک نہیں کرتا ہوں،\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmclxxix{اور کیوں نہ ہوا کہ جب تو اپنے باغ میں گیا تو کہا ہوتا جو چاہے اللہ، ہمیں کچھ زور نہیں مگر اللہ کی مدد کا اگر تو مجھے اپنے سے مال و اولاد میں کم دیکھتا تھا\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmclxxx{تو قریب ہے کہ میرا رب مجھے تیرے باغ سے اچھا دے اور تیرے باغ پر آسمان سے بجلیاں اتارے تو وہ پٹ پر میدان (سفید زمین) ہوکر رہ جائے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmclxxxi{یا اس کا پانی زمین میں دھنس جائے پھر تو اسے ہرگز تلاش نہ کرسکے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmclxxxii{اور اس کے پھل گھیر لیے گئے تو اپنے ہاتھ ملتا رہ گیا اس لاگت پر جو اس باغ میں خرچ کی تھی اور وہ اپنی ٹیٹوں پر (اوندھے منہ) گرا ہوا تھا اور کہہ رہا ہے، اے کاش! میں نے اپنے رب کا کسی کو شریک نہ کیا ہوتا،\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmclxxxiii{اور اس کے پاس کوئی جماعت نہ تھی کہ اللہ کے سامنے اس کی مدد کرتی نہ وہ بدلہ لینے کے قابل تھا\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmclxxxiv{یہاں کھلتا ہے کہ اختیار سچے اللہ کا ہے، اس کا ثواب سب سے بہتر اور اسے ماننے کا انجام سب سے بھلا،\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmclxxxv{اور ان کے سامنے زندگانی دنیا کی کہاوت بیان کرو جیسے ایک پانی ہم نے آسمان اتارا تو اس کے سبب زمین کا سبزہ گھنا ہوکر نکلا کہ سوکھی گھاس ہوگیا جسے ہوائیں اڑائیں اور اللہ ہر چیز پر قابو والا ہے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmclxxxvi{مال اور بیٹے یہ جیتی دنیا کا سنگھار ہے اور باقی رہنے والی اچھی باتیں ان کا ثواب تمہارے رب کے یہاں بہتر اور وہ امید میں سب سے بھلی،\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmclxxxvii{اور جس دن ہم پہاڑوں کو چلائیں گے اور تم زمین کو صاف کھلی ہوئی دیکھو گے اور ہم انہیں اٹھائیں گے تو ان میں سے کسی کو نہ چھوڑیں گے،\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmclxxxviii{اور سب تمہارے رب کے حضور پرا باندھے پیش ہوں گے بیشک تم ہمارے پاس ویسے ہی آئےجیسا ہم نے تمہیں پہلی بار بنایا تھا بلکہ تمہارا گمان تھا کہ ہم ہر گز تمہارے لیے کوئی وعدہ کا وقت نہ رکھیں گے،\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmclxxxix{اور نامہٴ اعمال رکھا جائے گا تو تم مجرموں کو دیکھو گے کہ اس کے لکھے سے ڈرتے ہوں گے اور کہیں گے ہائے خرابی ہماری اس نوشتہ کو کیا ہوا نہ اس نے کوئی چھوٹا گناہ چھوڑا نہ بڑا جسے گھیر لیا ہو اور اپنا سب کیا انہوں نے سامنے پایا، اور تمہارا رب کسی پر ظلم نہیں کرتا\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmcxc{اور یاد کرو جب ہم نے فرشتوں کو فرمایا کہ آدم کو سجدہ کرو تو سب نے سجدہ کیا سوا ابلیس کے، قومِ جن سے تھا تو اپنے رب کے حکم سے نکل گیا بھلا کیا اسے اور اس کی اولاد و میرے سوا دوست بناتے ہو اور وہ ہمارے دشمن ہیں ظالموں کو کیا ہی برا بدل (بدلہ) ملا،\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmcxci{نہ میں نے آسمانوں اور زمین کو بناتے وقت انہیں سامنے بٹھالیا تھا، نہ خود ان کے بناتے وقت اور نہ میری شان، کہ گمراہ کرنے والوں کو بازوں بناؤں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmcxcii{اور جس دن فرمائے گا کہ پکارو میرے شریکوں کو جو تم گمان کرتے تھے تو انہیں پکاریں گے وہ انہیں جواب نہ دیں گے اور ہم ان کے درمیان ایک ہلاکت کا میدان کردیں گے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmcxciii{اور مجرم دوزخ کو دیکھیں گے تو یقین کریں گا کہ انہیں اس میں گرنا ہے اور اس سے پھرنے کی کوئی جگہ نہ پائیں گے،\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmcxciv{اور بیشک ہم نے لوگوں کے لیے اس قرآن میں ہر قسم کی مثل طرح طرح بیان فرمائی اور آدمی ہر چیز سے بڑھ کر جھگڑالو ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmcxcv{اور آدمیوں کو کسی چیز نے اس سے روکا کہ ایمان لاتے جب ہدایت ان کے پاس آئی اور اپنے رب سے معافی مانگتے مگر یہ کہ ان پر اگلوں کا دستور آئے یا ان پر قسم قسم کا عذاب آئے،\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmcxcvi{اور ہم رسولوں کو نہیں بھیجتے مگر خوشی ڈر سنانے والے اور جو کافر ہیں وہ باطل کے ساتھ جھگڑتے ہیں کہ اس سے حق کو ہٹادیں اور انہوں نے میری آیتوں کی اور جو ڈر انہیں سناتے گئے تھے،\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmcxcvii{ان کی ہنسی بنالی اور اس سے بڑھ کر ظالم کون جسے اس کے رب کی آیتیں یاد دلائی جائیں تو وہ ان سے منہ پھیرلے اور اس کے ہاتھ جو آگے بھیج چکے اسے بھول جائے ہم نے ان کے دلوں پر غلاف کردیے ہیں کہ قرآن نہ سمجھیں اور ان کے کانوں میں گرانی اور اگر تم انہیں ہدایت کی طرف بلاؤ تو جب بھی ہرگز کبھی راہ نہ پائیں گے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmcxcviii{اور تمہارا رب بخشنے والا مہر وا لا ہے، اگر وہ انہیں ان کے کیے پر پکڑتا تو جلد ان پر عذاب بھیجتا بلکہ ان کے لیے ایک وعدہ کا وقت ہے جس کے سامنے کوئی پناہ نہ پائیں گے،\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmcxcix{اور یہ بستیاں ہم نے تباہ کردیں جب انہوں نے ظلم کیا اور ہم نے ان کی بربادی کا ایک وعدہ رکھا تھا،\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmcc{اور یاد کرو جب موسیٰ نے اپنے خادم سے کہا میں باز نہ رہوں گا جب تک وہاں نہ پہنچوں جہاں دو سمندر ملے ہیں یا قرنوں (مدتوں تک) چلا جاؤں\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmcci{پھر جب وہ دونوں ان دریاؤں کے ملنے کی جگہ پہنچے اپنی مچھلی بھول گئے اور اس نے سمندر میں اپنی راہ لی سرنگ بناتی،\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmccii{پھر جبب وہاں سے گزر گئے موسیٰ نے خادم سے کہا ہمارا صبح کا کھانا لاؤ بیشک ہمیں اپنے اس سفر میں بڑی مشقت کا سامنا ہوا،\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmcciii{بولا بھلا دیکھئے تو جب ہم نے اس چٹان کے پاس جگہ لی تھی تو بیشک میں مچھلی کو بھول گیا، اور مجھے شیطان ہی نے بھلا دیا کہ میں اس کا مذکور کروں اور اس نے تو سمندر میں اپنی راہ لی، اچنبھا ہے،\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmcciv{موسیٰ نے کہا یہی تو ہم چاہتے تھے تو پیچھے پلٹے اپنے قدموں کے نشان دیکھتے،\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmccv{تو ہمارے بندوں میں سے ایک بندہ پایا جسے ہم نے اپنے پاس سے رحمت دی اور اسے اپنا علم لدنی عطا کیا\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmccvi{اس سے موسیٰ نے کہا کیا میں تمہارے ساتھ رہوں اس شرط پر کہ تم مجھے سکھادو گے نیک بات جو تمہیں تعلیم ہوئی\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmccvii{کہا آپ میرے ساتھ ہرگز نہ ٹھہر سکیں گے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmccviii{اور اس بات پر کیونکر صبر کریں گے جسے آپ کا علم محیط نہیں\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmccix{کہا عنقریب اللہ چاہے تو تم مجھے صابر پاؤ گے اور میں تمہارے کسی حکم کے خلاف نہ کروں گا،\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmccx{کہا تو اگر آپ میرے ساتھ رہنے ہیں تو مجھ سے کسی بات کو نہ پوچھنا جب تک میں خود اس کا ذکر نہ کروں\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmccxi{اب دونوں چلے یہاں تک کہ جب کشتی میں سوار ہوئے اس بندہ نے اسے چیر ڈالا موسیٰ نے کہا کیا تم نے اسے اس لیے چیرا کہ اس کے سواروں کو ڈبا دو بیشک یہ تم نے بری بات کی،\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmccxii{کہا میں نہ کہتا تھا کہ آپ میرے ساتھ ہرگز نہ ٹھہر سکیں گے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmccxiii{کہا مجھ سے میری بھول پر گرفت نہ کرو اور مجھ پر میرے کام میں مشکل نہ ڈالو،\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmccxiv{پھر دونوں چلے یہاں تک کہ جب ایک لڑکا ملا اس بندہ نے اسے قتل کردیا، موسیٰ نے کہا کیا تم نے ایک ستھری جان بے کسی جان کے بدلے قتل کردی، بیشک تم نے بہت بری بات کی،\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmccxv{کہا میں نے آپ سے نہ کہا تھا کہ آپ ہرگز میرے ساتھ نہ ٹھہرسکیں گے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmccxvi{کہا اس کے بعد میں تم سے کچھ پوچھوں تو پھر میرے ساتھ نہ رہنا، بیشک میری طرف سے تمہارا عذر پورا ہوچکا،\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmccxvii{پھر دونوں چلے یہاں تک کہ جب ایک گاؤں والوں کے پاس آئے ان دہقانوں سے کھانا مانگا انہوں نے انہیں دعوت دینی قبول نہ کی پھر دونوں نے اس گاؤں میں ایک دیوار پا ئی کہ گرا چاہتی ہے اس بندہ نے اسے سیدھا کردیا، موسیٰ نے کہا تم چاہتے تو اس پر کچھ مزدوری لے لیتے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmccxviii{کہا یہ میری اور آپ کی جدائی ہے اب میں آپ کو ان باتوں کا پھیر (بھید) بتاؤں گا جن پر آپ سے صبر نہ ہوسکا\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmccxix{وہ جو کشتی تھی وہ کچھ محتاجوں کی تھی کہ دریا میں کام کرتے تھے، تو میں نے چاہا کہ اسے عیب دار کردوں اور ان کے پیچھے ایک بادشاہ تھا کہ ہر ثابت کشتی زبردستی چھین لیتا\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmccxx{اور وہ جو لڑکا تھا اس کے ماں باپ مسلمان تھے تو ہمیں ڈر ہوا کہ وہ ان کو سرکشی اور کفر پر چڑھاوے\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmccxxi{تو ہم نے چاہا کہ ان دونوں کا رب اس سے بہتر ستھرا اور اس سے زیادہ مہربانی میں قریب عطا کرے\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmccxxii{رہی وہ دیوار وہ شہر کے دو یتیم لڑکوں کی تھی اور اس کے نیچے ان کا خزانہ تھا اور ان کا باپ نیک آدمی تھا تو آپ کے رب نے چاہا کہ وہ دونوں اپنی جوانی کو پہنچیں اور اپنا خزانہ نکالیں، آپ کے رب کی رحمت سے اور یہ کچھ میں نے اپنے حکم سے نہ کیا یہ پھیر ہے ان باتوں کا جس پر آپ سے صبر نہ ہوسکا\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmccxxiii{اور تم سے ذوالقرنین کو پوچھتے ہیں تم فرماؤ میں تمہیں اس کا مذکور پڑھ کر سناتا ہوں،\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmccxxiv{بیشک ہم نے اسے زمین میں قابو دیا اور ہر چیز کا ایک سامان عطا فرمایا\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmccxxv{تو وہ ایک سامان کے پیچھے چلا\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmccxxvi{یہاں تک کہ جب سورج ڈوبنے کی جگہ پہنچا اسے ایک سیاہ کیچڑ کے چشمے میں ڈوبتا پایا اور وہاں ایک قوم ملی ہم نے فرمایا اے ذوالقرنین یا تو تُو انہیں عذاب دے یا ان کے ساتھ بھلائی اختیار کرے\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmccxxvii{عرض کی کہ وہ جس نے ظلم کیا اسے تو ہم عنقریب سزادیں گے پھر اپنے رب کی طرف پھیرا جائے گا وہ اسے بری مار دے گا،\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmccxxviii{اور جو ایمان لایا اور نیک کام کیا تو اس کا بدلہ بھلائی ہے اور عنقریب ہم اسے آسان کام کہیں گے\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmccxxix{پھر ایک سامان کے پیچھے چلا\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmccxxx{یہاں تک کہ جب سورج نکلنے کی جگہ پہنچا، اسے ایسی قوم پر نکلتا پایا جن کے لیے ہم نے سورج سے کوئی آڑ نہیں رکھی\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmccxxxi{بات یہی ہے، اور جو کچھ اس کے پاس تھا سب کو ہمارا علم محیط ہے\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmccxxxii{پھر ایک ساما ن کے پیچھے چلا\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmccxxxiii{یہاں تک کہ جب دو پہاڑوں کے بیچ پہنچا ان سے ادھر کچھ ایسے لوگ پائے کہ کوئی بات سمجھتے معلوم نہ ہوتے تھے\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmccxxxiv{انھوں نے کہا، اے ذوالقرنین! بیشک یاجوج ماجوج زمین میں فساد مچاتے ہیں تو کیا ہم آپ کے لیے کچھ مال مقرر کردیں اس پر کہ آپ ہم میں اور ان میں ایک دیوار بنادیں\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mmccxxxv{کہا وہ جس پر مجھے میرے رب نے قابو دیا ہے بہتر ہے تو میری مدد طاقت سے کرو میں تم میں اور ان میں ایک مضبوط آڑ بنادوں\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mmccxxxvi{میرے پاس لوہے کے تختے لاؤ یہاں تک کہ وہ جب دیوار دونوں پہاڑوں کے کناروں سے برابر کردی، کہا دھونکو، یہاں تک کہ جب اُسے آگ کردیا کہا لاؤ، میں اس پر گلا ہوا تانبہ اُنڈیل دوں،\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mmccxxxvii{تو یاجوج و ماجوج اس پر نہ چڑھ سکے اور نہ اس میں سوراخ کرسکے،\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mmccxxxviii{کہا یہ میرے رب کی رحمت ہے، پھر جب میرے رب کا وعدہ آئے گا اسے پاش پاش کردے گا اور میرے رب کا وعدہ سچا ہے\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mmccxxxix{اور اس دن ہم انہیں چھوڑ دیں گے کہ ان کا ایک گروہ دوسرے پر ریلا (سیلاب کی طرح) آوے گا اور صُور پھونکا جائے گا تو ہم سب کو اکٹھا کر لائیں گے\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mmccxl{اور ہم اس دن جہنم کافروں کے سامنے لائیں گے\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mmccxli{وہ جن کی آنکھوں پر میری یاد سے پردہ پڑا تھا اور حق بات سن نہ سکتے تھے\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mmccxlii{تو کیا کافر یہ سمجھتے ہیں کہ میرے بندوں کو میرے سوا حمایتی بنالیں گے بیشک ہم نے کافروں کی مہمانی کو جہنم تیار کر رکھی ہے،\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mmccxliii{تم فرماؤ کیا ہم تمہیں بتادیں کہ سب سے بڑھ کر ناقص عمل کن کے ہیں\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mmccxliv{ان کے جن کی ساری کوشش دنیا کی زندگی میں گم گئی اور وہ اس خیال میں ہیں کہ اچھا کام کررہے ہیں،\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mmccxlv{یہ لوگ جنہوں نے اپنے رب کی آیتیں اور اس کا ملنا نہ مانا تو ان کا کیا دھرا سب اکارت ہے تو ہم ان کے لیے قیامت کے دن کوئی تول نہ قائم کریں گے\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mmccxlvi{یہ ان کا بدلہ ہے جہنم، اس پر کہ انہوں نے کفر کیا اور میری آیتوں اور میرے رسولوں کی ہنسی بنائی،\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mmccxlvii{بیشک جو ایمان لائے اور اچھے کام کیے فردوس کے باغ ان کی مہمانی ہے\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mmccxlviii{وہ ہمیشہ ان ہی میں رہیں گے ان سے جگہ بدلنا نہ چاہیں گے\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mmccxlix{تم فرمادو اگر سمندر میرے رب کی باتوں کے لیے، سیاہی ہو تو ضرور سمندر ختم ہوجائے گا اور میرے رب کی باتیں ختم نہ ہوں گی اگرچہ ہم ویسا ہی اور اس کی مدد کو لے آئیں\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mmccl{تو فرماؤ ظاہر صورت بشری میں تو میں تم جیسا ہوں مجھے وحی آتی ہے کہ تمہارا معبود ایک ہی معبود ہے تو جسے اپنے رب سے ملنے کی امید ہو اسے چاہیے کہ نیک کام کرے اور اپنے رب کی بندگی میں کسی کو شریک نہ کرے\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mmccli{\basmalahur کھیٰعص\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmcclii{یہ مذکور ہے تیرے رب کی اس رحمت کا جو اس نے اپنے بندہ زکریا پر کی،\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmccliii{جب اس نے اپنے رب کو آہستہ پکارا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmccliv{عرض کی اے میرے رب میری ہڈی کمزور ہوگئی اور سرے سے بڑھاپے کا بھبھوکا پھوٹا (شعلہ چمکا) اور اے میرے رب میں تجھے پکار کر کبھی نامراد نہ رہا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmcclv{اور مجھے اپنے بعد اپنے قرابت والوں کا ڈر ہے اور میری عورت بانجھ ہے تو مجھے اپنے پاس سے کوئی ایسا دے ڈال جو میرا کام اٹھائے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmcclvi{وہ میرا جانشین ہو اور اولاد یعقوب کا وارث ہو، اور اے میرے رب! اسے پسندیدہ کر\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmcclvii{اے زکریا ہم تجھے خوشی سناتے ہیں ایک لڑکے کی جن کا نام یحییٰ ہے اس کے پہلے ہم نے اس نام کا کوئی نہ کیا،\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmcclviii{عرض کی اے میرے رب! میرے لڑکا کہاں سے ہوگا میری عورت تو بانجھ ہے اور میں بڑھاپے سے سوکھ جانے کی حالت کو پہنچ گیا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmcclix{فرمایا ایسا ہی ہے تیرے رب نے فرمایا وہ مجھے آسان ہے اور میں نے تو اس سے پہلے تجھے اس وقت بنایا جب تک کچھ بھی نہ تھا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmcclx{عرض کی اے میرے رب! مجھے کوئی نشانی دے دے فرمایا تیری نشانی یہ ہے کہ تو تین رات دن لوگوں سے کلام نہ کرے بھلا چنگا ہوکر\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmcclxi{تو اپنی قوم پر مسجد سے باہر آیا تو انہیں اشارہ سے کہا کہ صبح و شام تسبیح کرتے رہو،\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmcclxii{اے یحییٰ کتاب مضبوط تھام، اور ہم نے اسے بچپن ہی میں نبوت دی\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmcclxiii{اور اپنی طرف سے مہربانی اور ستھرائی اور کمال ڈر والا تھا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmcclxiv{اور اپنے ماں باپ سے اچھا سلوک کرنے والا تھا زبردست و نافرمان نہ تھا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmcclxv{اور سلامتی ہے اس پر جس دن پیدا ہوا اور جس دن مرے گا اورجس دن مردہ اٹھایا جائے گا\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmcclxvi{اور کتاب میں مریم کو یاد کرو جب اپنے گھر والوں سے پورب کی طرف ایک جگہ الگ گئی\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmcclxvii{تو ان سے ادھر ایک پردہ کرلیا، تو اس کی طرف ہم نے اپنا روحانی (روح الامین) بھیجا وہ اس کے سامنے ایک تندرست آدمی کے روپ میں ظاہر ہوا،\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmcclxviii{بولی میں تجھ سے رحمان کی پناہ مانگتی ہوں اگر تجھے خدا کا ڈر ہے،\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmcclxix{بولا میں تیرے رب کا بھیجا ہوا ہوں، کہ میں تجھے ایک ستھرا بیٹا دوں،\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmcclxx{بولی میرے لڑکا کہاں سے ہوگا مجھے تو کسی آدمی نے ہاتھ نہ لگایا نہ میں بدکار ہوں،\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmcclxxi{کہا یونہی ہے تیرے رب نے فرمایا ہے کہ یہ مجھے آسان ہے، اور اس لیے کہ ہم اسے لوگوں کے واسطے نشانی کریں اور اپنی طرف سے ایک رحمت اور یہ کام ٹھہرچکا ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmcclxxii{اب مریم نے اسے پیٹ میں لیا پھر اسے لیے ہوئے ایک دور جگہ چلی گئی\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmcclxxiii{پھر اسے جننے کا درد ایک کھجور کی جڑ میں لے آیا بولی ہائے کسی طرح میں اس سے پہلے مرگئی ہوتی اور بھولی بسری ہوجاتی،\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmcclxxiv{تو اسے اس کے تلے سے پکارا کہ غم نہ کھا بیشک تیرے رب نے نیچے ایک نہر بہادی ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmcclxxv{اور کھجور کی جڑ پکڑ کر اپنی طرف ہلا تجھ پر تازی پکی کھجوریں گریں گی\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmcclxxvi{تو کھا اور پی اور آنکھ ٹھنڈی رکھ پھر اگر تو کسی آدمی کو دیکھے تو کہہ دینا میں نے آج رحمان کا روزہ مانا ہے تو آج ہرگز کسی آدمی سے بات نہ کرو ں گی\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmcclxxvii{تو اسے گود میں لے اپنی قوم کے پاس آئی بولے اے مریم! بیشک تو نے بہت بری بات کی،\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmcclxxviii{اے ہارون کی بہن تیرا باپ برا آدمی نہ تھا اور نہ تیری ماں بدکار،\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmcclxxix{اس پر مریم نے بچے کی طرف اشارہ کیا وہ بولے ہم کیسے بات کریں اس سے جو پالنے میں بچہ ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmcclxxx{بچہ نے فرمایا میں اللہ کا بندہ اس نے مجھے کتاب دی اور مجھے غیب کی خبریں بتانے والا (نبی) کیا\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmcclxxxi{اور اس نے مجھے مبارک کیا میں کہیں ہوں اور مجھے نماز و زکوٰة کی تاکید فرمائی جب تک جیوں،\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmcclxxxii{اور اپنی ماں سے اچھا سلوک کرنے والا اور مجھے زبردست بدبخت نہ کیا،\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmcclxxxiii{اور وہی سلامتی مجھ پر جس دن میں پیدا ہوا اور جس دن مروں اور جس دن زندہ اٹھایا جاؤں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmcclxxxiv{یہ ہے عیسیٰ مریم کا بیٹا سچی بات جس میں شک کرتے ہیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmcclxxxv{اللہ کو لائق نہیں کہ کسی کو اپنا بچہ ٹھہرائے پاکی ہے اس کو جب کسی کام کا حکم فرماتا ہے تو یونہی کہ اس سے فرماتا ہے ہوجاؤ وہ فوراًٰ ہوجاتا ہے،\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmcclxxxvi{اور عیسیٰ نے کہا بیشک اللہ رب ہے میرا اور تمہارا تو اس کی بندگی کرو، یہ راہ سیدھی ہے،\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmcclxxxvii{پھر جماعتیں آپس میں مختلف ہوگئیں تو خرابی ہے، کافروں کے لیے ایک بڑے دن کی حاضری سے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmcclxxxviii{کتنا سنیں گے اور کتنا دیکھیں گے جس دن ہمارے پاس حاضر ہونگے مگر آج ظالم کھلی گمراہی میں ہیں\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmcclxxxix{اور انہیں ڈر سناؤ پچھتاوے کے دن کا جب کام ہوچکے گا اور وہ غفلت میں ہیں اور نہیں مانتے،\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmccxc{بیشک زمین اور جو کچھ اس پر ہے سب کے وارث ہم ہوں گے اور وہ ہماری ہی طرف پھریں گے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmccxci{اور کتاب میں ابراہیم کو یاد کرو بیشک وہ صدیق تھا (نبی) غیب کی خبریں بتاتا،\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmccxcii{جب اپنے باپ سے بولا اے میرے باپ کیوں ایسے کو پوجتا ہے جو نہ سنے نہ دیکھے اور نہ کچھ تیرے کام آئے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmccxciii{اے میرے باپ بیشک میرے پاس وہ علم آیا جو تجھے نہ آیا تو تُو میرے پیچھے چلا آ میں تجھے سیدھی راہ دکھاؤں\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmccxciv{اے میرے باپ شیطان کا بندہ نہ بن بیشک شیطان رحمان کا نافرمان ہے،\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmccxcv{اے میرے باپ میں ڈرتا ہوں کہ تجھے رحمن کا کوئی عذاب پہنچے تو تُو شیطان کا رفیق ہوجائے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmccxcvi{بولا کیا تو میرے خداؤں سے منہ پھیرتا ہے، اے ابراہیم بیشک اگر تو باز نہ آیا تو میں تجھے پتھراؤ کروں گا اور مجھ سے زمانہ دراز تک بے علاقہ ہوجا\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmccxcvii{کہا بس تجھے سلام ہے قریب ہے کہ میں تیرے لیے اپنے رب سے معافی مانگوں گا بیشک وہ مجھ مہربان ہے،\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmccxcviii{اور میں ایک کنارے ہوجاؤں گا تم سے اور ان سب سے جن کو اللہ کے سوا پوجتے ہو اور اپنے رب کو پوجوں گا قریب ہے کہ میں اپنے رب کی بندگی سے بدبخت نہ ہوں\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmccxcix{پھر جب ان سے اور اللہ کے سوا ان کے معبودوں سے کنارہ کر گیا ہم نے اسے اسحاق اور یعقوب عطا کیے، اور ہر ایک کو غیب کی خبریں بتانے والا کیا،\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmccc{اور ہم نے انہیں اپنی رحمت عطا کی اور ان کے لیے سچی بلند ناموری رکھی\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmccci{اور کتاب میں موسیٰ کو یاد کرو، بیشک وہ چنا ہوا تھا اور رسول تھا غیب کی خبریں بتانے والا،\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmcccii{اور اسے ہم نے طور کی داہنی جانب سے ندا فرمائی اور اسے اپنا راز کہنے کو قریب کیا\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmccciii{اور اپنی رحمت سے اس کا بھائی ہارون عطا کیا (غیب کی خبریں بتانے والا نبی)\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmccciv{اور کتاب میں اسماعیل کو یاد کرو بیشک وہ وعدے کا سچا تھا اور رسول تھا غیب کی خبریں بتاتا،\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmcccv{اور اپنے گھر والوں کو نماز اور زکوٰة کا حکم دیتا اور اپنے رب کو پسند تھا\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmcccvi{اور کتاب میں ادریس کو یاد کرو بیشک وہ صدیق تھا غیب کی خبریں دیتا،\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmcccvii{اور ہم نے اسے بلند مکان پر اٹھالیا\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmcccviii{یہ ہیں جن پر ا لله نے احسان کیا غیب کی خبریں بتانے میں سے آدم کی اولاد سے اور ان میں جن کو ہم نے نوح کے ساتھ سوار کیا تھا اور ابراہیم اور یعقوب کی اولاد سے اور ان میں سے جنہیں ہم نے راہ دکھائی اور چن لیا جب ان پر رحمن کی آیتیں پڑھی جاتیں گر پڑتے سجدہ کرتے اور روتے (السجدة) ۵\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmcccix{تو ان کے بعد ان کی جگہ وہ ناخلف آئے جنہوں نے نمازیں گنوائیں اور اپنی خواہشوں کے پیچھے ہوئے تو عنقریب وہ دوزخ میں غی کا جنگل پائیں گے\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmcccx{مگر جو تائب ہوئے اور ایمان لائے اور اچھے کام کیے تو یہ لوگ جنت میں جائیں گے اور انہیں کچھ نقصان نہ دیا جائے گا\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmcccxi{بسنے کے باغ جن کا وعدہ رحمن نے اپنے بندوں سے غیب میں کیا بیشک اس کا وعدہ آنے والا ہے،\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmcccxii{وہ اس میں کوئی بیکار بات نہ سنیں گے مگر سلام اور انہیں اس میں ان کا رزق ہے صبح و شام\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmcccxiii{یہ وہ باغ ہے جس کا وارث ہم اپنے بندوں میں سے اسے کریں گے جو پرہیزگار ہے،\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmcccxiv{(اور جبریل نے محبوب سے عرض کی (ٖف ۱۰۹) ہم فرشتے نہیں اترتے مگر حضور کے رب کے حکم سے اسی کا ہے جو ہمارے آگے ہے اور جو ہمارے پیچھے اور جو اس کے درمیان ہے اور حضور کا رب بھولنے والا نہیں\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmcccxv{آسمانوں اور زمین اور جو کچھ ان کے بیچ میں ہے سب کا مالک تو اے پوجو اور اس کی بندگی پر ثابت رہو، کیا اس کے نام کا دوسرا جانتے ہو\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmcccxvi{اور آدمی کہتا ہے کیا جب میں مرجاؤں گا تو ضرور عنقریب جِلا کر نکالا جاؤں گا\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmcccxvii{اور کیا آدمی کو یاد نہیں کہ ہم نے اس سے پہلے اسے بنایا اور وہ کچھ نہ تھا\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmcccxviii{تو تمہارے رب کی قسم ہم انہیں اور شیطانوں سب کو گھیر لائیں گے اور انہیں دوزخ کے آس پاس حاضر کریں گے گھٹنوں کے بل گرے،\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmcccxix{پھر ہم ہر گروہ سے نکالیں گے جو ان میں رحمن پر سب سے زیادہ بے باک ہوگا\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmcccxx{پھر ہم خوب جانتے ہیں جو اس آگ میں بھوننے کے زیادہ لائق ہیں،\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmcccxxi{اور تم میں کوئی ایسا نہیں جس کا گزر دوزخ پر نہ ہو تمہارے رب کے ذمہ پر یہ ضرور ٹھہری ہوئی بات ہے\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmcccxxii{پھر ہم ڈر والوں کو بچالیں گے اور ظالموں کو اس میں چھوڑ دیں گے گھٹنوں کے بل گرے،\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmcccxxiii{اور جب ان پر ہماری روشن آیتیں پڑھی جاتی ہیں کافر مسلمانوں سے کہتے ہیں کون سے گروہ کا مکان اچھا اورمجلس بہتر ہے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmcccxxiv{اور ہم نے ان سے پہلے کتنی سنگتیں کھپادیں (قومیں ہلاک کردیں) کہ وہ ان سے بھی سامان اور نمود میں بہتر تھے،\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmcccxxv{تم فرماؤ جو گمراہی میں ہو تو اسے رحمن خوب ڈھیل دے یہاں تک کہ جب وہ دیکھیں وہ چیز جس کا انہیں وعدہ دیا جاتا ہے یا تو عذاب یا قیامت تو اب جان لیں گے کہ کس کا برا درجہ ہے اور کس کی فوج کمزور\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmcccxxvi{او رجنہوں نے ہدایت پائی اللہ انھیں اور ہدایت بڑھائے گا اور باقی رہنے والی نیک باتوں کا تیرے رب کے یہاں سب سے بہتر ثواب اور سب سے بھلا انجام\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmcccxxvii{تو کیا تم نے اسے دیکھا جو ہماری آیتوں سے منکر ہوا اور کہتا ہے مجھے ضرو ر مال و اولاد ملیں گے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmcccxxviii{کیا غیب کو جھانک آیا ہے یا رحمن کے پاس کوئی قرار رکھا ہے،\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmcccxxix{ہرگز نہیں اب ہم لکھ رکھیں گے جو وہ کہتا ہے اور اسے خوب لمبا عذاب دیں گے،\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmcccxxx{اور جو چیزیں کہہ رہا ہے ان کے ہمیں وارث ہوں گے اور ہمارے پاس اکیلا آئے گا\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmcccxxxi{اور اللہ کے سوا اور خدا بنالیے کہ وہ انہیں زور دیں\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmcccxxxii{ہرگز نہیں کوئی دم جاتا ہے کہ وہ ان کی بندگی سے منکر ہوں گے اور ان کے مخالفت ہوجائیں گے\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmcccxxxiii{کیا تم نے نہ دیکھا کہ ہم نے کافروں پر شیطان بھیجے کہ وہ انہیں خوب اچھالتے ہیں\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmcccxxxiv{تو تم ان پر جلدی نہ کرو، ہم تو ان کی گنتی پوری کرتے ہیں\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmcccxxxv{جس دن ہم پرہیزگاروں کو رحمن کی طرف لے جائیں گے مہمان بناکر\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmcccxxxvi{اور مجرموں کو جہنم کی طرف ہانکیں گے پیاسے\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmcccxxxvii{لوگ شفاعت کے مالک نہیں مگر وہی جنہوں نے رحمن کے پاس قرار رکھا ہے\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmcccxxxviii{اور کافر بولے رحمن نے اولاد اختیار کی،\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmcccxxxix{بیشک تم حد کی بھاری بات لائے\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmcccxl{قریب ہے کہ آسمان اس سے پھٹ پڑیں اور زمین شق ہوجائے اور پہاڑ گر جائیں ڈھ کر (مسمار ہوکر)\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmcccxli{اس پر کہ انہوں نے رحمن کے لیے اولاد بتائی،\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmcccxlii{اور رحمن کے لائق نہیں کہ اولاد اختیار کرے\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmcccxliii{آسمانوں اور زمین میں جتنے ہیں سب اس کے حضور بندے ہو کر حاضر ہوں گے،\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmcccxliv{بیشک وہ ان کا شمار جانتا ہے اور ان کو ایک ایک کرکے گن رکھا ہے\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mmcccxlv{اور ان میں ہر ایک روز قیامت اس کے حضور اکیلا حاضر ہوگا\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mmcccxlvi{بیشک وہ جو ایمان لائے اور اچھے کام کیے عنقریب ان کے لیے رحمن محبت کردے گا\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mmcccxlvii{تو ہم نے یہ قرآن تمہاری زبان میں یونہی آسان فرمایا کہ تم اس سے ڈر والوں کو خوشخبری دو اور جھگڑالو لوگوں کو اس سے ڈر سناؤ،\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mmcccxlviii{اور ہم نے ان سے پہلے کتنی سنگتیں کھپائیں (قومیں ہلاک کیں) کیا تم ان میں کسی کو دیکھتے ہو یا ان کی بھنک (ذرا بھی آواز) سنتے ہو\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mmcccxlix{\basmalahur طٰهٰ\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmcccl{اے محبوب! ہم نے تم پر یہ قرآن اس لیے نہ اتارا کہ مشقت میں پڑو\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmcccli{ہاں اس کو نصیحت جو ڈر رکھتا ہو\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmccclii{اس کا اتارا ہوا جس نے زمین اور اونچے آسمان بنائے،\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmcccliii{وہ بڑی مہر والا، اس نے عرش پر استواء فرمایا جیسا اس کی شان کے لائق ہے،\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmcccliv{اس کا ہے جو کچھ آسمانوں میں ہے اور جو کچھ زمین میں اور جو کچھ ان کے بیچ میں اور جو کچھ اس گیلی مٹی کے نیچے ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmccclv{اور اگر تو بات پکار کر کہے تو وہ تو بھید کو جانتا ہے اور اسے جو اس سے بھی زیادہ چھپا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmccclvi{اللہ کہ اس کے سوا کسی کی بندگی نہیں، اسی کے ہیں سب اچھے نام\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmccclvii{اور کچھ تمہیں موسیٰ کی خبر آئی\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmccclviii{جب اس نے ایک آگ دیکھی تو اپنی بی بی سے کہا ٹھہرو مجھے ایک آگ نظر پڑی ہے شاید میں تمہارے لیے اس میں سے کوئی چنگاری لاؤں یا آ گ پر راستہ پاؤں،\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmccclix{پھر جب آگ کے پاس آیا ندا فرمائی گئی کہ اے موسیٰ،\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmccclx{بیشک میں تیرا رب ہوں تو تو اپنے جوتے اتار ڈال بیشک تو پاک جنگل طویٰ میں ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmccclxi{اور میں نے تجھے پسند کیا اب کان لگا کر سن جو تجھے وحی ہوتی ہے،\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmccclxii{بیشک میں ہی ہوں اللہ کہ میرے سوا کوئی معبود نہیں تو میری بندگی کر اور میری یاد کے لیے نماز قائم رکھ\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmccclxiii{بیشک قیامت آنے والی ہے قریب تھا کہ میں اسے سب سے چھپاؤں کہ ہر جان اپنی کوشش کا بدلہ پائے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmccclxiv{تو ہرگز تجھے اس کے ماننے سے وہ باز نہ رکھے جو اس پر ایمان نہیں لاتا اور اپنی خواہش کےم پیچھے چلا پھر تو ہلاک ہوجائے،\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmccclxv{اور یہ تیرے داہنے ہاتھ میں کیا ہے اے موسیٰ\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmccclxvi{عرض کی یہ میرا عصا ہے میں اس پر تکیہ لگاتا ہوں اور اس سے اپنی بکریوں پر پتے جھاڑتا ہوں اور میرے اس میں اور کام ہیں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmccclxvii{فرمایا اسے ڈال دے اے موسیٰ،\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmccclxviii{تو موسیٰ نے ڈال دیا تو جبھی وہ دوڑتا ہوا سانپ ہوگیا\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmccclxix{فرمایا اسے اٹھالے اور ڈر نہیں، اب ہم اسے پھر پہلی طرح کردیں گے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmccclxx{اور اپنا ہاتھ اپنے بازو سے ملا خوب سپید نکلے گا بے کسی مرض کے ایک اور نشانی\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmccclxxi{کہ ہم تجھے اپنی بڑی بڑی نشانیاں دکھائیں،\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmccclxxii{فرعون کے پاس جا اس نے سر اٹھایا\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmccclxxiii{عرض کی اے میرے رب میرے لیے میرا سینہ کھول دے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmccclxxiv{اور میرے لیے میرا کام آسان کر،\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmccclxxv{اور میری زبان کی گرہ کھول دے،\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmccclxxvi{کہ وہ میری بات سمجھیں،\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmccclxxvii{اور میرے لیے میرے گھر والوں میں سے ایک وزیر کردے،\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmccclxxviii{وہ کون میرا بھائی ہارون،\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmccclxxix{اس سے میری کمر مضبوط کر،\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmccclxxx{اور اسے میرے کام میں شریک کر\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmccclxxxi{کہ ہم بکثرت تیری پاکی بولیں،\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmccclxxxii{اور بکثرت تیری یاد کریں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmccclxxxiii{بیشک تو ہمیں دیکھ رہا ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmccclxxxiv{فرمایا اے موسیٰ تیری مانگ تجھے عطا ہوئی،\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmccclxxxv{اور بیشک ہم نے تجھ پر ایک بار اور احسان فرمایا\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmccclxxxvi{جب ہم نے تیری ماں کو الہام کیا جو الہام کرنا تھا\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmccclxxxvii{کہ اس بچے کو صندوق میں رکھ کر دریا میں ڈال دے، و دریا اسے کنارے پر ڈالے کہ اسے وہ اٹھالے جو میرا دشمن اور اس کا دشمن اور میں نے تجھ پر اپنی طرف کی محبت ڈالی اور اس لیے کہ تو میری نگاہ کے سامنے تیار ہو\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmccclxxxviii{تیری بہن چلی پھر کہا کیا میں تمہیں وہ لوگ بتادوں جو اس بچہ کی پرورش کریں تو ہم تجھے تیری ماں کے پاس پھیر لائے کہ اس کی آنکھ ٹھنڈی ہو اور غم نہ کرے اور تو نے ایک جان کو قتل کیا تو ہم نے تجھے غم سے نجات دی اور تجھے خوب جانچ لیا تُو تو کئی برس مدین والوں میں رہا پھر تو ایک ٹھہرائے وعدہ پر حاضر ہوا اے موسیٰ!\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmccclxxxix{اور میں نے تجھے خاص اپنے لیے بنایا\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmcccxc{تو اور تیرا بھائی دونوں میری نشانیاں لے کر جاؤ اور میری یاد میں سستی نہ کرنا،\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmcccxci{دونوں فرعون کے پاس جاؤ بیشک اس نے سر اٹھایا،\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmcccxcii{تو اس سے نرم بات کہنا اس امید پر کہ وہ دھیان کرے یا کچھ ڈرے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmcccxciii{دونوں نے عرض کیا، اے ہمارے رب! بیشک ہم ڈرتے ہیں کہ وہ ہم پر زیادتی کرے یا شرارت سے پیش آئے،\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmcccxciv{فرمایا ڈرو نہیں میں تمہارے ساتھ ہوں سنتا اور دیکھتا\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmcccxcv{تو اس کے پاس جاؤ اور اس سے کہو کہ ہم تیرے رب کے بھیجے ہوئے ہیں تو اولاد یعقوب کو ہمارے ساتھ چھوڑ دے اور انہیں تکلیف نہ دے بیشک ہم تیرے رب کی طرف سے نشانی لائے ہیں اور سلامتی اسے جو ہدایت کی پیروی کرے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmcccxcvi{بیشک ہماری طرف وحی ہوتی ہے کہ عذاب اس پر ہے جو جھٹلائے اور منہ پھیرے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmcccxcvii{بولا تو تم دونوں کا خدا کون ہے اے موسیٰ،\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmcccxcviii{کہا ہمارا رب وہ ہے جس نے ہر چیز کو اس کے لائق صورت دی پھر راہ دکھائی\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmcccxcix{بولا اگلی سنگتوں (قوموں) کا کیا حال ہے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmcd{کہا ان کا علم میرے رب کے پاس ایک کتاب میں ہے میرا رب نہ بہکے نہ بھولے،\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmcdi{وہ جس نے تمہارے لیے زمین کو بچھونا کیا اور تمہارے لیے اس میں چلتی راہیں رکھیں اور آسمان سے پانی اتارا تو ہم نے اس سے طرح طرح کے سبزے کے جوڑے نکالے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmcdii{تم کھاؤ اور اپنے مویشیوں کو چَراؤ بیشک اس میں نشانیاں ہیں عقل والوں کو،\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmcdiii{ہم نے زمین ہی سے تمہیں بنایا اور اسی میں تمہیں پھر لے جائیں گے اور اسی سے تمہیں دوبارہ نکالیں گے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmcdiv{اور بیشک ہم نے اسے اپنی سب نشانیاں دکھائیں تو اس نے جھٹلایا اور نہ مانا\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmcdv{بولا کیا تم ہمارے پاس اس لیے آئے ہو کہ ہمیں اپنے جادو کے سبب ہماری زمین سے نکال دو اے موسیٰ\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmcdvi{تو ضرور ہم بھی تمہارے آگے ویسا ہی جادو لائیں گے تو ہم میں اور اپنے میں ایک وعدہ ٹھہرادو جس سے نہ ہم بدلہ لیں نہ تم ہموار جگہ ہو،\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmcdvii{موسیٰ نے کہا تمہارا وعدہ میلے کا دن ہے اور یہ کہ لوگ دن چڑھے جمع کیے جائیں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmcdviii{تو فرعون پھرا اور اپنے داؤں (فریب) اکٹھے کیے پھر آیا\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmcdix{ان سے موسیٰ نے کہا تمہیں خرابی ہو اللہ پر جھوٹ نہ باندھو کہ وہ تمہیں عذاب سے ہلاک کردے اور بیشک نامراد رہا جس نے جھوٹ باندھا\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmcdx{تو اپنے معاملہ میں باہم مختلف ہوگئے اور چھپ کر مشاورت کی،\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmcdxi{بولے بیشک یہ دونوں ضرور جادوگر ہیں چاہتے ہیں کہ تمہیں تمہاری زمین زمین سے اپنے جادو کے زور سے نکال دیں اور تمہارا اچھا دین لے جائیں،\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmcdxii{تو اپنا داؤ (فریب) پکا کرلو پھر پرا باندھ (صف باندھ) کر آ ؤ آج مراد کو پہنچا جو غالب رہا،\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmcdxiii{بولے اے موسیٰ یا تو تم ڈالو یا ہم پہلے ڈالیں\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmcdxiv{موسیٰ نے کہا بلکہ تمہیں ڈالو جبھی ان کی رسیاں اور لاٹھیاں ان کے جادو کے زور سے ان کے خیال میں دوڑتی معلوم ہوئیں\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmcdxv{تو اپنے جی میں موسیٰ نے خوف پایا،\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmcdxvi{ہم نے فرمایا ڈر نہیں بیشک تو ہی غالب ہے،\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmcdxvii{اور ڈال تو دے جو تیرے داہنے ہاتھ میں ہے اور ان کی بناوٹوں کو نگل جائے گا، وہ جو بناکر لائے ہیں وہ تو جادوگر کا فریب ہے، اور جادوگر کا بھلا نہیں ہوتا کہیں آوے\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmcdxviii{تو سب جادوگر سجدے میں گرالیے گئے بولے ہم اس پر ایمان لائے جو ہارون اور موسیٰ کا رب ہے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmcdxix{فرعون بولا کیا تم اس پر ایمان لائے قبل اس کے کہ میں تمہیں اجازت دوں، بیشک وہ تمہارا بڑا ہے جس نے تم سب کو جادو سکھایا تو مجھے قسم ہے ضرور میں تمہارے ایک طرف کے ہاتھ اور دوسری طرف کے پاؤں کاٹوں گا اور تمہیں کھجور کے ڈھنڈ (تنے) پر سُولی چڑھاؤں گا، اور ضرور تم جان جاؤ گے کہ ہم میں کس کا عذاب سخت اور دیرپا ہے\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmcdxx{بولے ہم ہرگز تجھے ترجیح نہ دیں گے ان روشن دلیلوں پر جو ہمارے پاس آئیں ہمیں اپنے پیدا کرنے والے والے کی قسم تو تُو کر چُک جو تجھے کرنا ہے تو اس دنیا ہی کی زندگی میں تو کرے گا\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmcdxxi{بیشک ہم اپنے رب پر ایمان لائے کہ وہ ہماری خطائیں بخش دے اور وہ جو تو نے ہمیں مجبور کیا جادو پر اور ا لله بہتر ہے اور سب سے زیادہ باقی رہنے والا\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmcdxxii{بیشک جو اپنے رب کے حضور مجرم ہوکر آئے تو ضرور اس کے لیے جہنم ہے جس میں نہ مرے نہ جئے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmcdxxiii{اور جو اس کے حضور ایمان کے ساتھ آئے کہ اچھے کام کیے ہوں تو انہیں کے درجے اونچے،\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmcdxxiv{بسنے کے باغ جن کے نیچے نہریں بہیں ہمیشہ ان میں رہیں، اور یہ صلہ ہے اس کا جو پاک ہوا\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmcdxxv{اور بیشک ہم نے موسیٰ کو وحی کی کہ راتوں رات میرے بندوں کو لے چل اور ان کے لیے دریا میں سوکھا راستہ نکال دے تجھے ڈر نہ ہوگا کہ فرعون آلے اور نہ خطرہ\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmcdxxvi{تو ان کے پیچھے فرعون پڑا اپنے لشکر لے کر تو انہیں دریا نے ڈھانپ لیا جیسا ڈھانپ لیا،\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmcdxxvii{اور فرعون نے اپنی قوم کو گمراہ کیا اور راہ نہ دکھائی\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmcdxxviii{اے بنی اسرائیل بیشک ہم نے تم کو تمہارے دشمن سے نجات دی اور تمہیں طور کی داہنی طرف کا وعدہ دیا اور تم پر من اور سلوی ٰ اتارا\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmcdxxix{کھاؤ جو پاک چیزیں ہم نے تمہیں روزی دیں اور اس میں زیادتی نہ کرو کہ تم پر میرا غضب اترے اور جس پر میرا غضب اترا بیشک وہ گرا\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmcdxxx{اور بیشک میں بہت بخشنے والا ہوں اسے جس نے توبہ کی اور ایمان لایا اور اچھا کام کیا پھر ہدایت پر رہا\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmcdxxxi{اور تو نے اپنی قوم سے کیوں جلدی کی اے موسیٰ\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmcdxxxii{عرض کی کہ وہ یہ ہیں میرے پیچھے اور اے میرے رب تیری طرف میں جلدی کرکے حاضر ہوا کہ تو راضی ہو،\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmcdxxxiii{فرمایا، تو ہم نے تیرے آنے کے بعد تیری قوم بلا میں ڈالا اور انہیں سامری نے گمراہ کردیا،\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmcdxxxiv{تو موسیٰ اپنی قوم کی طرف پلٹا غصہ میں بھرا افسوس کرتا کہا اے میری قوم کیا تم سے تمہارے رب نے اچھا وعدہ نہ تھا کیا تم پر مدت لمبی گزری یا تم نے چاہا کہ تم پر تمہارے رب کا غضب اترے تو تم نے میرا وعدہ خلاف کیا\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmcdxxxv{بولے ہم نے آپ کا وعدہ اپنے اختیار سے خلاف نہ کیا لیکن ہم سے کچھ بوجھ اٹھوائے گئے اس قوم کے گہنے کے تو ہم نے انہیں ڈال دیا پھر اسی طرح سامری نے ڈالا\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmcdxxxvi{تو اس نے ان کے لیے ایک بچھڑا نکالا بے جان کا دھڑ گائے کی طرح بولتا یہ ہے تمہارا معبود اور موسیٰ کا معبود تو بھول گئے\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmcdxxxvii{تو کیا نہیں دیکھتے کہ وہ انہیں کسی بات کا جواب نہیں دیتا اور ان کے سوا کسی برے بھلے کا اختیار نہیں رکھتا\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmcdxxxviii{اور بیشک ان سے ہارون نے اس سے پہلے کہا تھا کہ اے میری قوم یونہی ہے کہ تم اس کے سبب فتنے میں پڑے اور بیشک تمہارا رب رحمن ہے تو میری پیروی کرو اور میرا حکم مانو،\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmcdxxxix{بولے ہم تو اس پر آسن مارے جمے (پوجا کے لیے بیٹھے) رہیں گے جب تک ہمارے پاس موسیٰ لوٹ کے آئیں\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmcdxl{موسیٰ نے کہا، اے ہارون! تمہیں کس بات نے روکا تھا جب تم نے انہیں گمراہ ہوتے دیکھا تھا کہ میرے پیچھے آتے\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmcdxli{تو کیا تم نے میرا حکم نہ مانا،\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmcdxlii{کہا اے میرے ماں جائے! نہ میری ڈاڑھی پکڑو اور نہ میرے سر کے بال مجھے یہ ڈر ہوا کہ تم کہو گے تم نے بنی اسرائیل میں تفرقہ ڈال دیا اور تم نے میری بات کا انتظار نہ کیا\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mmcdxliii{موسیٰ نے کہا اب تیرا کیا حال ہے اے سامری!\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mmcdxliv{بولا میں نے وہ دیکھا جو لوگوں نے نہ دیکھا تو ایک مٹھی بھر لی فرشتے کے نشان سے پھر اسے ڈال دیا اور میرے جی کو یہی بھلا لگا\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mmcdxlv{کہا تو چلتا بن کہ دنیا کی زندگی میں تیری سزا یہ ہے کہ تو کہے چھو نہ جا اور بیشک تیرے لیے ایک وعدہ کا وقت ہے جو تجھ سے خلاف نہ ہوگا اور اپنے اس معبود کو دیکھ جس کے سامنے تو دن بھر آسن مارے (پوجا کے لیے بیٹھا) رہا قسم ہے ہم ضرور اسے جلائیں گے پھر ریزہ ریزہ کرکے دریا میں بہائیں گے\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mmcdxlvi{تمہارا معبود تو وہی اللہ ہے جس کے سوا کسی کی بندگی نہیں ہر چیز کو اس کا علم محیط ہے،\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mmcdxlvii{ہم ایسا ہی تمہارے سامنے اگلی خبریں بیان فرماتے ہیں اور ہم نے تم کو اپنے پاس سے ایک ذکر عطا فرمایا\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mmcdxlviii{جو اس سے منہ پھیرے تو بیشک وہ قیامت کے دن ایک بوجھ اٹھائے گا\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mmcdxlix{وہ ہمیشہ اس میں رہیں گے اور وہ قیامت کے دن ان کے حق میں کیا ہی بڑا بوجھ ہوگا،\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mmcdl{جس دن صُور پھونکا جائے گا اور ہم اس دن مجرموں کو اٹھائیں گے نیلی آنکھیں\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mmcdli{آپس میں چپکے چپکے کہتے ہوں گے کہ تم دنیا میں نہ رہے مگر دس رات\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mmcdlii{ہم خوب جانتے ہیں جو وہ کہیں گے جبکہ ان میں سب سے بہتر رائے والا کہے گا کہ تم صرف ایک ہی دن رہے تھے\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mmcdliii{اور تم سے پہاڑوں کو پوچھتے ہیں تم فرماؤ انہیں میرا رب ریزہ ریزہ کرکے اڑا دے گا،\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mmcdliv{تو زمین کو پٹ پر (چٹیل میدان) ہموار کر چھوڑے گا\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mmcdlv{کہ تو اس میں نیچا اونچا کچھ نہ دیکھے،\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mmcdlvi{اس دن پکارنے والے کے پیچھے دوڑیں گے اس میں کجی نہ ہوگی اور سب آوازیں رحمن کے حضو ر پست ہوکر رہ جائیں گی تو تُو نہ سنے گا مگر بہت آہستہ آواز\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mmcdlvii{اس دن کسی کی شفاعت کام نہ دے گی، مگر اس کی جسے رحمن نے اذن دے دیا ہے اور اس کی بات پسند فرمائی،\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mmcdlviii{وہ جانتا ہے جو کچھ ان کے آگے ہے اور جو کچھ ان کے پیچھے اور ان کا علم اسے نہیں گھیر سکتا\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mmcdlix{اور سب منہ جھک جائیں گے اس زندہ قائم رکھنے والے کے حضور اور بیشک نامراد رہا جس نے ظلم کا بوجھ لیا\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mmcdlx{اور جو کچھ نیک کام کرے اور ہو مسلمان تو اسے نہ زیادتی کا خوف ہوگا اور نہ نقصان کا\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@mmcdlxi{اور یونہی ہم نے اسے عربی قرآن اتارا اور اس میں طرح طرح سے عذاب کے وعدے دیے کہ کہیں انہیں ڈر ہو یا ان کے دل میں کچھ سوچ پیدا کرے\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@mmcdlxii{تو سب سے بلند ہے ا لله سچا بادشاہ اور قرآن میں جلدی نہ کرو جب تک اس کی وحی تمہیں پوری نہ ہولے اور عرض کرو کہ اے میرے رب! مجھے علم زیادہ دے،\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@mmcdlxiii{اور بیشک ہم نے آدم کو اس سے پہلے ایک تاکیدی حکم دیا تھا تو وہ بھول گیا اور ہم نے اس کا قصد نہ پایا،\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@mmcdlxiv{اور جب ہم نے فرشتوں سے فرمایا کہ آدم کو سجدہ کرو تو سب سجدہ میں گرے مگر ابلیس، اس نے نہ مانا،\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@mmcdlxv{تو ہم نے فرمایا، اے آدم! بیشک یہ تیرا اور تیری بی بی کا دشمن ہے تو ایسا نہ ہو کہ وہ تم دونوں کو جنت سے نکال دے پھر تو مشقت میں پڑے\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@mmcdlxvi{بیشک تیرے لیے جنت میں یہ ہے کہ نہ تو بھوکا ہو اور نہ ننگا ہو،\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@mmcdlxvii{اور یہ کہ تجھے نہ اس میں پیاس لگے نہ دھوپ\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@mmcdlxviii{تو شیطان نے اسے وسوسہ دیا بولا، اے آدم! کیا میں تمہیں بتادوں ہمیشہ جینے کا پیڑ اور وہ بادشاہی کہ پرانی نہ پڑے\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@mmcdlxix{تو ان دونوں نے اس میں سے کھالیا اب ان پر ان کی شرم کی چیزیں ظاہر ہوئیں اور جنت کے پتے اپنے اوپر چپکانے لگے اور آدم سے اپنے رب کے حکم میں لغزش واقع ہوئی تو جو مطلب چاہا تھا اس کی راہ نہ پائی\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@mmcdlxx{پھر اس کے رب نے چن لیا تو اس پر اپنی رحمت سے رجوع فرمائی اور اپنے قرب خاص کی راہ دکھائی،\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxi{فرمایا تم دونوں مل کر جنت سے اترو تم میں ایک دوسرے کا دشمن ہے، پھر اگر تم سب کو میری طرف سے ہدایت آئے، تو جو میری ہدایت کا پیرو ہو ا وہ نہ بہکے نہ بدبخت ہو\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxii{اور جس نے میری یاد سے منہ پھیرا تو بیشک اس کے لیے تنگ زندگانی ہے اور ہم اسے قیامت کے دن اندھا اٹھائیں گے،\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxiii{کہے گا اے رب میرے! مجھے تو نے کیوں اندھا اٹھایا میں تو انکھیارا (بینا) تھا\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxiv{فرمائے گا یونہی تیرے پاس ہماری آیتیں آئیں تھیں تو نے انہیں بھلادیا اور ایسے ہی آج تیری کوئی نہ لے گا\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxv{اور ہم ایسا ہی بدلہ دیتے ہیں جو حد سے بڑھے اور اپنے رب کی آیتوں پر ایمان نہ لائے، اور بیشک آخرت کا عذاب سب سے سخت تر اور سب سے دیرپا ہے،\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxvi{تو کیا انہیں اس سے راہ نہ ملی کہ ہم نے ان سے پہلے کتنی سنگتیں (قومیں) ہلاک کردیں کہ یہ ان کے بسنے کی جگہ چلتے پھرتے ہیں بیشک اس میں نشانیاں ہیں عقل والوں کو\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxvii{اور اگر تمہارے رب کی ایک بات نہ گزر چکی ہوتی تو ضرور عذاب انھیں لپٹ جاتا اور اگر نہ ہوتا ایک وعدہ ٹھہرایا ہوا\qt@no{(129)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxviii{تو ان کی باتوں پر صبر کرو اور اپنے رب کو سراہتے ہوئے اس کی پاکی بولو سورج چمکنے سے پہلے اور اس کے ڈوبنے سے پہلے اور رات کی گھڑیوں میں اس کی پاکی بولو اور دن کے کناروں پر اس امید پر کہ تم راضی ہو\qt@no{(130)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxix{اور اے سننے والے اپنی آنکھیں نہ پھیلا اس کی طرف جو ہم نے کافروں کے جوڑوں کو برتنے کے لیے دی ہے جتنی دنیا کی تازگی کہ ہم انہیں اس کے سبب فتنہ میں ڈالیں اور تیرے رب کا رزق سب سے اچھا اور سب سے دیرپا ہے،\qt@no{(131)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxx{اور اپنے گھر والوں کو نماز کا حکم دے اور خود اس پر ثابت رہ، کچھ ہم تجھ سے روزی نہیں مانگتے ہم تجھے روزی دیں گے اور انجام کا بھلا پرہیزگاری کے لیے،\qt@no{(132)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxi{اور کافر بولے یہ اپنے رب کے پاس سے کوئی نشانی کیوں نہیں لاتے اور کیا انہیں اس کا بیان نہ آیا جو اگلے صحیفوں میں ہے\qt@no{(133)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxii{اور اگر ہم انہیں کسی عذاب سے ہلاک کردیتے رسول کے آنے سے پہلے تو ضرور کہتے اے ہمارے رب! تو نے ہماری طرف کوئی رسول کیوں نہ بھیجا کہ ہم تیری آیتوں پر چلتے قبل اس کے کہ ذلیل و رسوا ہوتے،\qt@no{(134)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxiii{تم فرماؤ سب راہ دیکھ رہے ہیں تو تم بھی راہ دیکھو تو اب جان جاؤ گے کہ کون ہیں سیدھی راہ والے اور کس نے ہدایت پائی،\qt@no{(135)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxiv{\basmalahur لوگوں کا حساب نزدیک اور وہ غفلت میں منہ پھیرے ہیں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxv{جب ان کے رب کے پاس سے انہیں کوئی نئی نصیحت آتی ہے تو اسے نہیں سنتے مگر کھیلتے ہوئے،\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxvi{ان کے دل کھیل میں پڑے ہیں اور ظالموں نے آپس میں خفیہ مشورت کی کہ یہ کون ہیں ایک تم ہی جیسے آدمی تو ہیں کیا جادو کے پاس جاتے ہو دیکھ بھال کر،\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxvii{نبی نے فرمایا میرا رب جانتا ہے آسمانوں اور زمین میں ہر بات کو، اور وہی ہے سنتا جانتا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxviii{بلکہ بولے پریشان خوابیں ہیں بلکہ ان کی گڑھت (گھڑی ہوئی چیز) ہے بلکہ یہ شاعر ہیں تو ہمارے پاس کوئی نشانی لائیں جیسے اگلے بھیجے گئے تھے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxix{ان سے پہلے کوئی بستی ایمان نہ لائی جسے ہم نے ہلاک کیا، تو کیا یہ ایمان لائیں گے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmcdxc{اور ہم نے تم سے پہلے نہ بھیجے مگر مرد جنہیں ہم وحی کرتے تو اے لوگو! علم والوں سے پوچھو اگر تمہیں علم نہ ہو\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmcdxci{اور ہم نے انہیں خالی بدن نہ بنایا کہ کھانا نہ کھائیں اور نہ وہ دنیا میں ہمیشہ رہیں،\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmcdxcii{پھر ہم نے اپنا وعدہ انہیں سچا کر دکھایا تو انہیں نجات دی اور جن کو چاہی اور حد سے بڑھنے والوں کو ہلاک کردیا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmcdxciii{بیشک ہم سے تمہاری طرف ایک کتاب اتاری جس میں تمہاری ناموری ہے تو کیا تمہیں عقل نہیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmcdxciv{اور کتنی ہی بستیاں ہم نے تباہ کردیں کہ وہ ستمگار تھیں اور ان کے بعد اور قوم پیدا کی،\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmcdxcv{تو جب انہوں نے ہمارا عذاب پایا جبھی وہ اس سے بھاگنے لگے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmcdxcvi{نہ بھاگو اور لوٹ کے جاؤ ان آسائشوں کی طرف جو تم کو دی گئیں تھیں اور اپنے مکانوں کی طرف شاید تم سے پوچھنا ہو\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmcdxcvii{بولے ہائے خرابی ہماری بیشک ہم ظالم تھے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmcdxcviii{تو وہ یہی پکارتے رہے یہاں تک کہ ہم نے انہیں کردیا کاٹے ہوئے بجھے ہوئے،\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmcdxcix{اور ہم نے آسمان اور زمین اور جو کچھ ان کے درمیان ہے عبث نہ بنائے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmd{اگر ہم کوئی بہلاوا اختیار کرنا چاہتے تو اپنے پاس سے اختیار کرتے اگر ہمیں کرنا ہوتا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmdi{بلکہ ہم حق کو باطل پر پھینک مارتے ہیں تو وہ اس کا بھیجہ نکال دیتا ہے تو جبھی وہ مٹ کر رہ جاتا ہے اور تمہاری خرابی ہے ان باتوں سے جو بناتے ہو\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmdii{اور اسی کے ہیں جتنے آسمانوں اور زمین میں ہیں اور اس کے پاس والے اس کی عبادت سے تکبر نہیں کرتے اور نہ تھکیں،\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmdiii{رات دن اس کی پاکی بولتے ہیں اور سستی نہیں کرتے،\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmdiv{کیا انہوں نے زمین میں سے کچھ ایسے خدا بنالیے ہیں کہ وہ کچھ پیدا کرتے ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmdv{اگر آسمان و زمین میں اللہ کے سوا اور خدا ہوتے تو ضرور وہ تباہ ہوجاتے تو پاکی ہے اللہ عرش کے مالک کو ان باتوں سے جو یہ بناتے ہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmdvi{اس سے نہیں پوچھا جاتا جو وہ کرے اور ان سب سے سوال ہوگا\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmdvii{کیا اللہ کے سوا اور خدا بنا رکھے ہیں، تم فرماؤ اپنی دلیل لاؤ یہ قرآن میرے ساتھ والوں کا ذکر ہے اور مجھ سے اگلوں کا تذکرہ بلکہ ان میں اکثر حق کو نہیں جانتے تو وہ رو گرداں، ہیں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmdviii{اور ہم نے تم سے پہلے کوئی رسول نہ بھیجا مگر یہ کہ ہم اس کی طرف وحی فرماتے کہ میرے سوا کوئی معبود نہیں تو مجھی کو پوجو،\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmdix{اور بولے رحمن نے بیٹا اختیار کیا پاک ہے وہ بلکہ بندے ہیں عزت والے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmdx{بات میں اس سے سبقت نہیں کرتے اور وہ اسی کے حکم پر کاربند ہوتے ہیں،\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmdxi{وہ جانتا ہے جو ان کے آگے ہے اور جو ان کے پیچھے ہے اور شفاعت نہیں کرتے مگر اس کے لیے جسے وہ پسند فرمائے اور وہ اس کے خوف سے ڈر رہے ہیں،\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmdxii{اور ان میں جو کوئی کہے کہ میں اللہ کے سوا معبود ہوں تو اسے ہم جہنم کی جزا دیں گے، ہم ایسی ہی سزا دیتے ہیں ستمگاروں کو،\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmdxiii{کیا کافروں نے یہ خیال نہ کیا کہ آسمان اور زمین بند تھے تو ہم نے انہیں کھولا اور ہم نے ہر جاندار چیز پانی سے بنائی تو کیا وہ ایمان لائیں گے،\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmdxiv{اور زمین میں ہم نے لنگر ڈالے کہ انھیں لے کر نہ کانپے اور ہم نے اس میں کشادہ راہیں رکھیں کہ کہیں وہ راہ پائیں\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmdxv{اور ہم نے آسمان کو چھت بنایا نگاہ رکھی گئی اور وہ اس کی نشانیوں سے روگرداں ہیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmdxvi{اور وہی ہے جس نے بنائے رات اور دن اور سورج اور چاند ہر ایک ایک گھیرے میں پیر رہا ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmdxvii{اور ہم نے تم سے پہلے کسی آدمی کے لیے دنیا میں ہمیشگی نہ بنائی تو کیا اگر تم انتقال فرماؤ تو یہ ہمیشہ رہیں گے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmdxviii{ہر جان کو موت کا مزہ چکھنا ہے، اور ہم تمہاری آزمائش کرتے ہیں برائی اور بھلائی سے جانچنے کو اور ہماری ہی طرف تمہیں لوٹ کر آنا ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmdxix{اور جب کافر تمہیں دیکھتے ہیں تو تمہیں نہیں ٹھہراتے مگر ٹھٹھا کیا یہ ہیں وہ جو تمہارے خداؤں کو برا کہتے ہیں اور وہ رحمن ہی کی یاد سے منکر ہیں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmdxx{آدمی جلد باز بنایا گیا، اب میں تمہیں اپنی نشانیاں دکھاؤں گا مجھ سے جلدی نہ کرو\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmdxxi{اور کہتے ہیں کب ہوگا یہ وعدہ اگر تم سچے ہو،\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmdxxii{کسی طرح جانتے کافر اس وقت کو جب نہ روک سکیں گے اپنے مونہوں سے آگے اور نہ اپنی پیٹھوں سے اور نہ ان کی مدد ہو\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmdxxiii{بلکہ وہ ان پر اچانک آپڑے گی تو انہیں بے حواس کردے گی پھر نہ وہ اسے پھیرسکیں گے اور نہ انہیں مہلت دی جائے گی\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmdxxiv{اور بیشک تم سے اگلے رسولوں کے ساتھ ٹھٹھا کیا گیا تو مسخرگی کرنے والوں کا ٹھٹھا انہیں کو لے بیٹھا\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmdxxv{تم فرماؤ شبانہ روز تمہاری کون نگہبانی کرتا ہے رحمان سے بلکہ وہ اپنے رب کی یاد سے منہ پھیرے ہیں\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmdxxvi{کیا ان کے کچھ خدا ہیں جو ان کو ہم سے بچاتے ہیں وہ اپنی ہی جانوں کو نہیں بچاسکتے اور نہ ہماری طرف سے ان کی یاری ہو،\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmdxxvii{بلکہ ہم نے ان کو اور ان کے باپ دادا کو برتاوا دیا یہاں تک کہ زندگی ان پر دراز ہوئی تو کیا نہیں دیکھتے کہ ہم زمین کو اس کے کناروں سے گھٹاتے آرہے ہیں تو کیا یہ غالب ہوں گے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmdxxviii{تم فرماؤ کہ میں تم کو صرف وحی سے ڈراتا ہوں اور بہرے پکارنا نہیں سنتے جب ڈرائے جائیں،\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmdxxix{اور اگر انہیں تمہارے رب کے عذاب کی ہوا چھو جائے تو ضرور کہیں گے ہائے خرابی ہماری بیشک ہم ظالم تھے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmdxxx{اور ہم عدل کی ترازوئیں رکھیں گے قیامت کے دن تو کسی جان پر کچھ ظلم نہ ہوگا، اور اگر کوئی چیز رائی کے دانہ کے برابر ہو تو ہم اسے لے آئیں گے، اور ہم کافی ہیں حساب کو،\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmdxxxi{اور بیشک ہم نے موسیٰ اور ہارون کو فیصلہ دیا اور اجالا اور پرہیزگاروں کو نصیحت\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmdxxxii{وہ جو بے دیکھے اپنے رب سے ڈرتے ہیں اور انہیں قیامت کا اندیشہ لگا ہوا ہے،\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmdxxxiii{اور یہ ہے برکت والا ذکر کہ ہم نے اتارا تو کیا تم اس کے منکر ہو،\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmdxxxiv{اور بیشک ہم نے ابراہیم کو پہلے ہی سے اس کی نیک راہ عطا کردی اور ہم اس سے خبردار تھے،\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmdxxxv{جب اس نے اپنے باپ اور قوم سے کہا یہ مورتیں کیا ہیں جن کے آگے تم آسن مارے (پوجا کے لیے بیٹھے) ہو\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmdxxxvi{بولے ہم نے اپنے دادا کو ان کی پوجا کرتے پایا\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmdxxxvii{کہا بے شک تم اور تمہارے باپ دادا سب کھلی گمراہی میں ہو،\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmdxxxviii{بولے کیا تم ہمارے پاس حق لائے ہو یا یونہی کھیلتے ہو\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmdxxxix{کہا بلکہ تمہارا رب وہ ہے جو رب ہے آسمان اور زمین کا جس نے انہیں پیدا کیا، اور میں اس پر گواہوں میں سے ہوں،\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmdxl{اور مجھے اللہ کی قسم ہے میں تمہارے بتوں کا برا چاہوں گا بعد اس کے کہ تم پھر جاؤ پیٹھ دے کر\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmdxli{تو ان سب کو چورا کردیا مگر ایک کو جو ان کا سب سے بڑا تھا کہ شاید وہ اس سے کچھ پوچھیں\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmdxlii{بولے کس نے ہمارے خداؤں کے ساتھ یہ کام کیا بیشک وہ ظالم ہے،\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmdxliii{ان میں کے کچھ بولے ہم نے ایک جوان کو انہیں برا کہتے سنا جسے ابراہیم کہتے ہیں\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmdxliv{بولے تو اسے لوگوں کے سامنے لاؤ شاید وہ گواہی دیں\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmdxlv{بولے کیا تم نے ہمارے خداؤں کے ساتھ یہ کام کیا اے ابراہیم\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmdxlvi{فرمایا بلکہ ان کے اس بڑے نے کیا ہوگا تو ان سے پوچھو اگر بولتے ہوں\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmdxlvii{تو اپنے جی کی طرف پلٹے اور بولے بیشک تمہیں ستمگار ہو\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmdxlviii{پھر اپنے سروں کے بل اوندھائے گئے کہ تمہیں خوب معلوم ہے یہ بولتے نہیں\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmdxlix{کہا تو کیا اللہ کے سوا ایسے کو پوجتے ہو جو نہ تمہیں نفع دے اور نہ نقصان پہنچائے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmdl{تف ہے تم پر اور ان بتوں پر جن کو اللہ کے سوا پوجتے ہو، تو کیا تمہیں عقل نہیں\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmdli{بولے ان کو جلادو اور اپنے خداؤں کی مدد کروں اگر تمہیں کرنا ہے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmdlii{ہم نے فرمایا اے آگ ہو جا ٹھنڈی اور سلامتی ابراہیم پر\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmdliii{اور انہوں نے اس کا برا چاہا تو ہم نے انہیں سب سے بڑھ کر زیاں کار کردیا\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmdliv{اور ہم اسے اور لوط کو نجات بخشی اس زمین کی طرف جس میں ہم نے جہاں والوں کے لیے برکت رکھی\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmdlv{اور ہم نے اسے اسحاق عطا فرمایا اور یعقوب پوتا، اور ہم نے ان سب کو اپنے قرب خاص کا سزاوار کیا،\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmdlvi{اور ہم نے انہیں امام کیا کہ ہمارے حکم سے بلاتے ہیں اور ہم نے انہیں وحی بھیجی اچھے کام کرنے اور نماز برپا رکھنے اور زکوٰة دینے کی اور وہ ہماری بندگی کرتے تھے،\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmdlvii{اور لوط کو ہم نے حکومت اور علم دیا اور اسے اس بستی سے نجات بخشی جو گندے کام کرتی تھی بیشک وہ برُے لوگ بے حکم تھے،\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmdlviii{اور ہم نے اسے اپنی رحمت میں داخل کیا، بیشک وہ ہمارے قرب خاص سزاواروں میں ہے،\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmdlix{اور نوح کو جب اس سے پہلے اس نے ہمیں پکارا تو ہم نے اس کی دعا قبول کی اور اسے اور اس کے گھر والوں کو بڑی سختی سے نجات دی\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmdlx{اور ہم نے ان لوگوں پر اس کو مدد دی جنہوں نے ہماری آیتیں جھٹلائیں، بیشک وہ برے لوگ تھے تو ہم نے ان سب کو ڈبو دیا،\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmdlxi{اور داؤد اور سلیمان کو یاد کرو جب کھیتی کا ایک جھگڑا چکاتے تھے، جب رات کو اس میں کچھ لوگوں کی بکریاں چھوٹیں اور ہم ان کے حکم کے وقت حاضر تھے،\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmdlxii{ہم نے وہ معاملہ سلیمان کو سمجھادیا اور دونوں کو حکومت اور علم عطا کیا اور داؤد کے ساتھ پہاڑ مسخر فرمادیے کہ تسبیح کرتے اور پرندے اور یہ ہمارے کام تھے،\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmdlxiii{اور ہم نے اسے تمہارا ایک پہناوا بنانا سکھایا کہ تمہیں تمہاری آنچ سے (زخمی ہونے سے) بچائے تو کیا تم شکر کروگے،\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmdlxiv{اور سلیمان کے لیے تیز ہوا مسخر کردی کہ اس کے حکم سے چلتی اس زمین کی طرف جس میں ہم نے برکت رکھی اور ہم کو ہر چیز معلوم ہے،\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmdlxv{اور شیطانوں میں سے جو اس کے لیے غوطہ لگاتے اور اس کے سوا اور کام کرتے اور ہم انہیں روکے ہوئے تھے\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmdlxvi{اور ایوب کو (یاد کرو) جب اس نے اپنے رب کو پکارا کہ مجھے تکلیف پہنچی اور تو سب مہر والوں سے بڑھ کر مہر والا ہے،\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmdlxvii{تو ہم نے اس کی دعا سن لی تو ہم نے دور کردی جو تکلیف اسے تھی اور ہم نے اسے اس کے گھر والے اور ان کے ساتھ اتنے ہی اور عطا کیے اپنے پاس سے رحمت فرما کر اور بندی والوں کے لیے نصیحت\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmdlxviii{اور اسماعیل اور ادریس اور ذوالکفل کو (یاد کرو)، وہ سب صبر والے تھے\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmdlxix{اور انہیں ہم نے اپنی رحمت میں داخل کیا، بیشک وہ ہمارے قربِ خاص کے سزاواروں میں ہیں،\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmdlxx{اور ذوالنون، کو (یاد کرو) جب چلا غصہ میں بھرا تو گمان کیا کہ ہم اس پر تنگی نہ کریں گے تو اندھیریوں میں پکارا کوئی معبود نہیں سوا تیرے پاکی ہے تجھ کو، بیشک مجھ سے بے جا ہوا\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmdlxxi{تو ہم نے اس کی پکار سن لی اور سے غم سے نجات بخشی اور ایسی ہی نجات دیں گے مسلمانوں کو\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmdlxxii{اور زکریا کو جب اس نے اپنے رب کو پکارا، اے میرے رب مجھے اکیلا نہ چھوڑ اور تو سب سے بہتر اور وارث\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmdlxxiii{تو ہم نے اس کی دعا قبول کی اور اسے یحییٰ عطا فرمایا اور اس کے لیے اس کی بی بی سنواری بیشک وہ بھلے کاموں میں جلدی کرتے تھے اور ہمیں پکارتے تھے امید اور خوف سے، اور ہمارے حضور گڑگڑاتے ہیں،\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmdlxxiv{اور اس عورت کو اس نے اپنی پارسائی نگاہ رکھی تو ہم نے اس میں اپنی روح پھونکی اور اسے اور اس کے بیٹے کو سارے جہاں کے لیے نشانی بنایا\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmdlxxv{بیشک تمہارا یہ دین ایک ہی دین ہے اور میں تمہارا رب ہوں تو میری عبادت کرو،\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmdlxxvi{اور اَوروں نے اپنے کام آپس میں ٹکڑے ٹکڑے کرلیے سب کو ہماری طرف پھرنا ہے،\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmdlxxvii{تو جو کچھ بھلے کام کرے اور ہو ایمان والا تو اس کی کوشش کی بے قدری نہیں، اور ہم اسے لکھ رہے ہیں،\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mmdlxxviii{اور حرام ہے اس بستی پر جسے ہم نے ہلاک کردیا کہ پھر لوٹ کر آئیں\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mmdlxxix{یہاں تک کہ جب کھولے جائیں گے یاجوج و ماجوج اور وہ ہر بلندی سے ڈھلکتے ہوں گے،\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mmdlxxx{اور قریب آیا سچا وعدہ تو جبھی آنکھیں پھٹ کر رہ جائیں گی کافروں کی کہ ہائے ہماری خرابی بیشک ہم اس سے غفلت میں تھے بلکہ ہم ظالم تھے\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mmdlxxxi{بیشک تم اور جو کچھ اللہ کے سوا تم پوجتے ہو سب جہنم کے ایندھن ہو، تمہیں اس میں جانا،\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mmdlxxxii{اگر یہ خدا ہوتے جہنم میں نہ جاتے، اور ان سب کو ہمیشہ اس میں رہنا\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mmdlxxxiii{وہ اس میں رینکیں گے اور وہ اس میں کچھ نہ سنیں گے\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mmdlxxxiv{بیشک وہ جن کے لیے ہمارا وعدہ بھلائی کا ہوچکا وہ جنہم سے دور رکھے گئے ہیں\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mmdlxxxv{وہ اس کی بھنک (ہلکی سی آواز بھی) نہ سنیں گے اور وہ اپنی من مانتی خواہشوں میں ہمیشہ رہیں گے،\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mmdlxxxvi{انہیں غم میں نہ ڈالے گی وہ سب سے بڑی گھبراہٹ اور فرشتے ان کی پیشوائی کو آئیں گے کہ یہ ہے تمہارا وہ دن جس کا تم سے وعدہ تھا،\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mmdlxxxvii{جس دن ہم آسمان کو لپیٹیں گے جیسے سجل فرشتہ نامہٴ اعمال کو لپیٹتا ہے، جیسے پہلے اسے بنایا تھا ویسے ہی پھر کردیں گے یہ وعدہ ہے ہمارے ذمہ، ہم کو اس کا ضرور کرنا،\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mmdlxxxviii{اور بیشک ہم نے زبور میں نصیحت کے بعد لکھ دیا کہ اس زمین کے وارث میرے نیک بندے ہوں گے\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mmdlxxxix{بیشک یہ قرآن کافی ہے عبادت والوں کو\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mmdxc{اور ہم نے تمہیں نہ بھیجا مگر رحمت سارے جہان کے لیے\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mmdxci{تم فرماؤ مجھے تو یہی وحی ہوتی ہے کہ تمہارا خدا نہیں مگر ایک اللہ تو کیا تم مسلمان ہوتے ہو،\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mmdxcii{پھر اگر وہ منہ پھیریں تو فرمادو میں نے تمہیں لڑائی کا اعلان کردیا، برابری پر اور میں کیا جانوں کہ پاس ہے یا دور ہے وہ جو تمہیں وعدہ دیا جاتا ہے\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mmdxciii{بیشک اللہ جانتا ہے آواز کی بات اور جانتا ہے جو تم چھپاتے ہو\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mmdxciv{اور میں کیا جانوں شاید وہ تمہاری جانچ ہو اور ایک وقت تک برتوانا\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mmdxcv{نبی نے عرض کی کہ اے میرے رب حق فیصلہ فرمادے اور ہمارے رب رحمنٰ ہی کی مدد درکار ہے ان باتوں پر جو تم بتاتے ہو،\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@mmdxcvi{\basmalahur اے لوگو! اپنے رب سے ڈرو بیشک قیامت کا زلزلہ بڑی سخت چیز ہے،\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmdxcvii{جس دن تم اسے دیکھو گے ہر دودھ پلانے والی اپنے دودھ پیتے کو بھول جائے گی اور ہر گابھ اپنا گابھ ڈال دے گی اور تو لوگوں کو دیکھے گا جیسے نشہ میں ہیں اور نشہ میں نہ ہوں گے مگر ہے یہ کہ اللہ کی مار کڑی ہے،\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmdxcviii{اور کچھ لوگ وہ ہیں کہ اللہ کے معاملہ میں جھگڑتے ہیں بے جانے بوجھے، اور ہر سرکش شیطان کے پیچھے ہو لیتے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmdxcix{جس پر لکھ دیا گیا ہے کہ جو اس کی دوستی کرے گا تو یہ ضرور اسے گمراہ کردے گا اور اسے عذاب دوزخ کی راہ بتائے گا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmdc{اے لوگو! اگر تمہیں قیامت کے دن جینے میں کچھ شک ہو تو یہ غور کرو کہ ہم نے تمہیں پیدا کیا مٹی سے پھر پانی کی بوند سے پھر خون کی پھٹک سے (ف۹۱۲ پھر گوشت کی بوٹی سے نقشہ بنی اور بے بنی تاکہ ہم تمہارے لیے اپنی نشانیاں ظاہر فرمائیں اور ہم ٹھہرائے رکھتے ہیں ماؤں کے پیٹ میں جسے چاہیں ایک مقرر میعاد تک پھر تمہیں نکالتے ہیں بچہ پھر اس لیے کہ تم اپنی جوانی کو پہنچو اور تم میں کوئی پہلے ہی مرجاتا ہے اور کوئی سب میں نکمی عمر تک ڈالا جاتا ہے کہ جاننے کے بعد کچھ نہ جانے اور تو زمین کو دیکھے مرجھائی ہوئی پھر جب ہم نے اس پر پانی اتارا تر و تازہ ہوئی اور ابھر آئی اور ہر رونق دار جوڑا اُگا لائی\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmdci{یہ اس لیے ہے کہ اللہ ہی حق ہے اور یہ کہ وہ مردے جِلائے گا اور یہ کہ وہ سب کچھ کرسکتا ہے،\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmdcii{اور اس لیے کہ قیامت آنے والی اس میں کچھ شک نہیں، اور یہ کہ اللہ اٹھائے گا انہیں جو قبروں میں ہیں،\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmdciii{اور کوئی آدمی وہ ہے کہ اللہ کے بارے میں یوں جھگڑتا ہے کہ نہ تو علم نہ کوئی دلیل اور نہ کوئی روشن نوشتہ (تحریر)\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmdciv{حق سے اپنی گردن موڑے ہوئے تاکہ اللہ کی راہ سے بہکادے اس کے لیے دنیا میں رسوائی ہے اور قیامت کے دن ہم اسے آگ کا عذاب چکھائیں گے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmdcv{یہ اس کا بدلہ ہے جو تیرے ہاتھوں نے آگے بھیجا اور اللہ بندوں پر ظلم نہیں کرتا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmdcvi{اور کچھ آدمی اللہ کی بندگی ایک کنارہ پر کرتے ہیں پھر اگر انہیں کوئی بھلائی پہنچ گئی جب تو چین سے ہیں اور جب کوئی جانچ آکر پڑی منہ کے بل پلٹ گئے، ف۳۲) دنیا اور آخرت دونوں کا گھاٹا یہی ہے صر یح نقصان\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmdcvii{اللہ کے سوا ایسے کو پوجتے ہیں جو ان کا برا بھلا کچھ نہ کرے یہی ہے دور کی گمراہی،\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmdcviii{ایسے کو پوجتے نہیں جس کے نفع سے نقصان کی توقع زیادہ ہے بیشک کیا ہی برا مولیٰ اور بیشک کیا ہی برا رفیق،\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmdcix{بیشک اللہ داخل کرے گا انہیں جو ایمان لائے اور بھلے کام کیے باغوں میں جن کے نیچے نہریں رواں، بیشک اللہ کرتا ہے جو چاہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmdcx{جو یہ خیال کرتا ہو کہ اللہ اپنے نبی کی مدد نہ فرمائے گا دنیا اور آخرت میں تو اسے چاہیے کہ اوپر کو ایک رسی تانے پھر اپنے آپ کو پھانسی دے لے پھر دیکھے کہ اس کا یہ داؤں کچھ لے گیا اس بات کو جس کی اسے جلن ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmdcxi{اور بات یہی ہے کہ ہم نے یہ قرآن اتارا روشن آیتیں اور یہ کہ اللہ راہ دیتا ہے جسے چاہے،\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmdcxii{بیشک مسلمان اور یہودی اور ستارہ پرست اور نصرانی اور آتش پرست اور مشرک، بیشک اللہ ان سب میں قیامت کے دن فیصلہ کردے گا بیشک ہر چیز اللہ کے سامنے ہے،\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmdcxiii{کیا تم نے نہ دیکھا کہ اللہ کے لیے سجدہ کرتے ہیں وہ جو آسمانوں اور زمین میں ہیں اور سورج اور چاند اور تارے اور پہاڑ اور درخت اور چوپائے اور بہت آدمی اور بہت وہ ہیں جن پر عذاب مقرر ہوچکا اور جسے اللہ ذلیل کرے اسے کوئی عزت دینے والا نہیں، بیشک اللہ جو چاہے کرے، (السجدة) ۶\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmdcxiv{یہ دو فریق ہیں کہ اپنے رب میں جھگڑے تو جو کافر ہوئے ان کے لیے آگ کے کپڑے بیونتے (کاٹے) گئے ہیں اور ان کے سروں پر کھولتا پانی ڈالا جائے گا\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmdcxv{جس سے گل جائے گا جو کچھ ان کے پیٹوں میں ہے اور ان کی کھالیں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmdcxvi{اور ان کے لیے لوہے کے گرز ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmdcxvii{جب گھٹن کے سبب اس میں سے نکلنا چاہیں گے اور پھر اسی میں لوٹا دیے جائیں گے، اور حکم ہوگا کہ چکھو آگ کا عذاب،\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmdcxviii{بیشک اللہ داخل کرے گا انہیں جو ایمان لائے اور اچھے کام کیے بہشتوں میں جن کے نیچے نہریں بہیں اس میں پہنائے جائیں گے سونے کے کنگن اور موتی اور وہاں ان کی پوشاک ریشم ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmdcxix{اور انہیں پاکیزہ بات کی ہدایت کی گئی اور سب خوبیوں سراہے کی راہ بتائی گئی\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmdcxx{بیشک وہ جنہوں نے کفر کیا اور روکتے ہیں اللہ کی راہ اور اس ادب والی مسجد سے جسے ہم نے سب لوگوں کے لیے مقرر کیا کہ اس میں ایک سا حق ہے وہاں کے رہنے والے اور پردیسی کا، اور جو اس میں کسی زیادتی کا ناحق ارادہ کرے ہم اسے دردناک عذاب چکھائیں گے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmdcxxi{اور جب کہ ہم نے ابراہیم کو اس گھر کا ٹھکانا ٹھیک بتادیا اور حکم دیا کہ میرا کوئی شریک نہ کر اور میرا گھر ستھرا رکھ طواف والوں اور اعتکاف والوں اور رکوع سجدے والوں کے لیے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmdcxxii{اور لوگوں میں حج کی عام ندا کردے وہ تیرے پاس حاضر ہوں گے پیادہ اور ہر دبلی اونٹنی پر کہ ہر دور کی راہ سے آتی ہیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmdcxxiii{تاکہ وہ اپنا فائدہ پائیں اور اللہ کا نام لیں جانے ہوئے دنوں میں اس پر کہ انہیں روزی دی بے زبان چوپائے تو ان میں سے خود کھاؤ اور مصیبت زدہ محتاج کو کھلاؤ\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmdcxxiv{پھر اپنا میل کچیل اتاریں اور اپنی منتیں پوری کریں اور اس آزاد گھر کا طواف کریں\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmdcxxv{بات یہ ہے اور جو اللہ کی حرمتوں کی تعظیم کرے تو وہ اس کے لیے اس کے رب کے یہاں بھلا ہے، اور تمہارے لیے حلال کیے گئے بے زبان چوپائے سوا ان کے جن کی ممانعت تم پر پڑھی جاتی ہے تو دور ہو بتوں کی گندگی سے اور بچو جھوٹی بات سے،\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmdcxxvi{ایک اللہ کے ہوکر کہ اس کا ساجھی کسی کو نہ کرو، اور جو اللہ کا شریک کرے وہ گویا گرا آسمان سے کہ پرندے اسے اچک لے جاتے ہیں یا ہوا اسے کسی دور جگہ پھینکتی ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmdcxxvii{بات یہ ہے، اور جو اللہ کے نشانوں کی تعظیم کرے تو یہ دلوں کی پرہیزگاری سے ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmdcxxviii{تمہارے لیے چوپایوں میں فائدے ہیں ایک مقررہ میعاد تک پھر ان کا پہنچنا ہے اس آزاد گھر تک\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmdcxxix{اور ہر امت کے لیے ہم نے ایک قربانی مقرر فرمائی کہ اللہ کا نام لیں اس کے دیے ہوئے بے زبان چوپایوں پر تو تمہارا معبود ایک معبود ہے تو اسی کے حضور گردن رکھو اور اے محبوب خوشی سنادو ان تواضع والوں کو،\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmdcxxx{کہ جب اللہ کا ذکر ہوتا ہے ان کے دل ڈرنے لگتے ہیں اور جو افتاد پڑے اس کے سنے والے اور نماز برپا رکھنے والے اور ہمارے دیے سے خرچ کرتے ہیں\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmdcxxxi{اور قربانی کے ڈیل دار جانور اور اونٹ اور گائے ہم نے تمہارے لیے اللہ کی نشانیوں سے کیے تمہارے لیے ان میں بھلائی ہے تو ان پر اللہ کا نام لو ایک پاؤں بندھے تین پاؤں سے کھڑے پھر جب ان کی کروٹیں گرجائیں تو ان میں سے خود کھاؤ اور صبر سے بیٹھنے والے اور بھیک مانگنے والے کو کھلاؤ، ہم نے یونہی ان کو تمہارے بس میں دے دیا کہ تم احسان مانو،\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmdcxxxii{اللہ کو ہرگز نہ ان کے گوشت پہنچتے ہیں نہ ان کے خون ہاں تمہاری پرہیزگاری اس تک باریاب ہوتی ہے یونہی ان کو تمہارے پس میں کردیا کہ تم اللہ کی بڑائی بولو اس پر کہ تم کو ہدایت فرمائی، اور اے محبوب! خوشخبری سناؤ نیکی والوں کو\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmdcxxxiii{بیشک اللہ بلائیں ٹالتا ہے، مسلمانوں کی بیشک اللہ دوست نہیں رکھتا ہر بڑے دغا باز ناشکرے کو\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmdcxxxiv{پروانگی (اجازت) عطا ہوئی انہیں جن سے کافر لڑتے ہیں اس بناء پر کہ ان پر ظلم ہوا اور بیشک اللہ ان کی مدد کرنے پر ضرور قادر ہے،\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmdcxxxv{وہ جو اپنے گھروں سے ناحق نکالے گئے صرف اتنی بات پر کہ انہوں نے کہا ہمارا رب اللہ ہے اور اللہ اگر آدمیوں میں ایک کو دوسرے سے دفع نہ فرماتا تو ضرور ڈھادی جاتیں خانقاہیں اور گرجا اور کلیسے اور مسجدیں جن میں اللہ کا بکثرت نام لیا جاتا ہے، اور بیشک اللہ ضرور مدد فرمائے گا اس کی جو اس کے دین کی مدد کرے گا بیشک ضرور اللہ قدرت والا غالب ہے،\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmdcxxxvi{وہ لوگ کہ اگر ہم انہیں زمین میں قابو دیں تو نماز برپا رکھیں اور زکوٰة اور بھلائی کا حکم کریں اور برائی سے روکیں اور اللہ ہی کے لیے سب کاموں کا انجام،\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmdcxxxvii{اور اگر یہ تمہاری تکذیب کرتے ہیں تو بیشک ان سے پہلے جھٹلا چکی ہے نوح کی قوم اور عاد اور ثمود\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmdcxxxviii{اور ابراہیم کی قوم اور لوط کی قوم،\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmdcxxxix{اور مدین والے اور موسیٰ کی تکذیب ہوئی تو میں نے کافرو ں کو ڈھیل دی پھر انہیں پکڑا تو کیسا ہوا میرا عذاب\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmdcxl{اور کتنی ہی بستیاں ہم نے کھپادیں (ہلاک کردیں) کہ وہ ستمگار تھیں تو اب وہ اپنی چھتوں پر ڈہی (گری) پڑی ہیں اور کتنے کنویں بیکار پڑے اور کتنے محل گچ کیے ہوئے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmdcxli{تو کیا زمین میں نہ چلے کہ ان کے دل ہوں جن سے سمجھیں یا کان ہوں جن سے سنیں تو یہ کہ آنکھیں اندھی نہیں ہوتیں بلکہ وہ دل اندھے ہوتے ہیں جو سینو ں میں ہیں،\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmdcxlii{اور یہ تم سے عذاب مانگنے میں جلدی کرتے ہیں اور اللہ ہرگز اپنا وعدہ جھوٹا نہ کرے گا اور بیشک تمہارے رب کے یہاں ایک دن ایسا ہے جیسے تم لوگوں کی گنتی میں ہزار برس\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmdcxliii{اور کتنی بستیاں کہ ہم نے ان کو ڈھیل دی اس حال پر کہ وہ ستمگار تھیں پھر میں نے انہیں پکڑا اور میری ہی طرف پلٹ کر آتا ہے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmdcxliv{تم فرمادو کہ اے لوگو! میں تو یہی تمہارے لیے صریح ڈر سنانے والا ہوں،\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmdcxlv{تو جو ایمان لائے اور اچھے کام کیے ان کے لیے بخشش ہے اور عزت کی روزی\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmdcxlvi{اور وہ جو کوشش کرتے ہیں ہماری آیتوں میں ہار جیت کے ارادہ سے وہ جہنمی ہیں،\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmdcxlvii{اور ہم نے تم سے پہلے جتنے رسول یا نبی بھیجے سب پر کبھی یہ واقعہ گزرا ہے کہ جب انہوں نے پڑھا تو شیطان نے ان کے پڑھنے میں لوگوں پر کچھ اپنی طرف سے ملادیا تو مٹا دیتا ہے اللہ اس شیطان کے ڈالے ہوئے کو پھر اللہ اپنی آیتیں پکی کردیتا ہے اور اللہ علم و حکمت والا ہے،\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmdcxlviii{تاکہ شیطان کے ڈالے ہوئے کو فتنہ کردے ان کے لیے جن کے دلوں میں بیماری ہے اور جن کے دل سخت ہیں اور بیشک ستمگار دُھرکے (پرلے درجے کے) جھگڑالو ہیں،\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmdcxlix{اور اس لیے کہ جان لیں وہ جن کو علم ملا ہے کہ وہ تمہارے رب کے پاس سے حق ہے تو اس پر ایمان لائیں تو جھک جائیں اس کے لیے ان کے دل، اور بیشک اللہ ایمان والوں کو سیدھی راہ چلانے والا ہے،\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmdcl{اور کافر اس سے ہمیشہ شک میں رہیں گے یہاں تک کہ ان پر قیامت آجائے اچانک یا ان پر ایسے دن کا عذاب آئے جس کا پھل ان کے لیے کچھ اچھا نہ ہو\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmdcli{بادشاہی اس دن اللہ ہی کی ہے، وہ ان میں فیصلہ کردے گا، تو جو ایمان لائے اور اچھے کام کیے وہ چین کے باغوں میں ہیں،\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmdclii{اور جنہوں نے کفر کیا اور ہماری آیتیں جھٹلائیں ان کے لیے ذلت کا عذاب ہے،\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmdcliii{اور وہ جنہوں نے اللہ کی راہ میں اپنے گھر بار چھوڑے پھر مارے گئے یا مرگئے تواللہ ضرور انہیں اچھی روزی دے گا اور بیشک اللہ کی روزی سب سے بہتر ہے،\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmdcliv{ضرور انہیں ایسی جگہ لے جائے گا جسے وہ پسند کریں گے اور بیشک اللہ علم اور حلم والا ہے،\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmdclv{بات یہ ہے اور جو بدلہ لے جیسی تکلیف پہنچائی گئی تھی پھر اس پر زیادتی کی جائے تو بیشک اللہ اس کی مدد فرمائے گا بیشک اللہ معاف کرنے والا بخشنے والا ہے،\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmdclvi{یہ اس لیے کہ اللہ تعالیٰ رات کو ڈالتا ہے دن کے حصہ میں اور دن کو لاتا ہے رات کے حصہ میں اور اس لیے کہ اللہ سنتا دیکھتا ہے،\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmdclvii{یہ اس لیے کہ اللہ ہی حق ہے اور اس کے سوا جسے پوجتے ہیں وہی باطل ہے اور اس لیے کہ اللہ ہی بلندی بڑائی والا ہے،\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmdclviii{کیا تو نے نہ دیکھا کہ اللہ نے آسمان سے پانی اتارا تو صبح کو زمین ہریالی ہوگئی، بیشک اللہ پاک خبردار ہے،\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmdclix{اسی کا مال ہے جو کچھ آسمانوں میں ہے اور جو کچھ زمین میں ہے، اور بیشک اللہ ہی بے نیاز سب خوبیوں سراہا ہے،\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmdclx{کیا تو نے نہ دیکھا کہ اللہ نے تمہارے بس میں کردیا جو کچھ زمین میں ہے اور کشتی کہ دریا میں اس کے حکم سے چلتی ہے اور وہ روکے ہوئے ہے آسمان کو کہ زمین پر نہ گر پڑے مگر اس کے حکم سے، بیشک اللہ آدمیوں پر بڑی مہر والا مہربان ہے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmdclxi{اور وہی ہے جس نے تمہیں زندہ کیا اور پھر تمہیں مارے گا پھر تمہیں جِلائے گا بیشک آدمی بڑا ناشکرا ہے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmdclxii{ہر امت کے لیے ہم نے عبادت کے قاعدے بنادیے کہ وہ ان پر چلے تو ہرگز وہ تم سے اس معاملہ میں جھگڑا نہ کریں اور اپنے رب کی طرف بلاؤ بیشک تم سیدھی راہ پر ہو،\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmdclxiii{اور اگر وہ تم سے جھگڑیں تو فرمادو کہ اللہ خوب جانتا ہے تمہارے کوتک (تمہاری کرتوت)\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmdclxiv{اللہ تم پر فیصلہ کردے گا قیامت کے دن جس بات میں اختلاف کرتے ہو\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmdclxv{کیا تو نے نہ جانا کہ اللہ جانتا ہے جو کچھ آسمانوں اور زمین میں ہے، بیشک یہ سب ایک کتاب میں ہے بیشک یہ اللہ پر آسان ہے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmdclxvi{اور اللہ کے سوا ایسوں کو پوجتے ہیں جن کی کوئی سند اس نے نہ اتاری اور ایسوں کو جن کا خود انہیں کچھ علم نہیں اور ستمگاروں کا کوئی مددگار نہیں\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmdclxvii{اور جب ان پر ہماری روشن آیتیں پڑھی جائیں تو تم ان کے چہروں پر بگڑنے کے آثار دیکھو گے جنہوں نے کفر کیا، قریب ہے کہ لپٹ پڑیں ان کو جو ہماری آیتیں ان پر پڑھتے ہیں، تم فرمادو کیا میں تمہیں بتادوں جو تمہارے اس حال سے بھی بدتر ہے وہ آگ ہے، اللہ نے اس کا وعدہ دیا ہے کافروں کو، اور کیا ہی بری پلٹنے کی جگہ،\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmdclxviii{اے لوگو! ایک کہاوت فرمائی جاتی ہے اسے کان لگا کر سنو وہ جنہیں اللہ کے سوا تم پوجتے ہو ایک مکھی نہ بناسکیں گے اگرچہ سب اس پر اکٹھے ہوجائیں اور اگر مکھی ان سے کچھ چھین کرلے جائے تو اس سے چھڑا نہ سکیں کتنا کمزور چاہنے والا اور وہ جس کو چاہا\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmdclxix{اللہ کی قدر نہ جانی جیسی چاہیے تھی بیشک اللہ قوت والا غالب ہے،\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmdclxx{اللہ چن لیتا ہے فرشتوں میں سے رسول اور آدمیوں میں سے بیشک اللہ سنتا دیکھتا ہے،\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmdclxxi{جانتا ہے جو ان کے آگے ہے اور جو ان کے پیچھے ہے اور سب کاموں کی رجوع اللہ کی طرف ہے،\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmdclxxii{اے ایمان والو! رکوع اور سجدہ کرو اور اپنے رب کی بندگی کرو اور بھلے کام کرو اس امید پر کہ تمہیں چھٹکارا ہو، (السجدة) عندالشافعیؒ،\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmdclxxiii{اور اللہ کی راہ میں جہاد کرو جیسا حق ہے جہاد کرنے کا اس نے تمہیں پسند کیا اور تم پر دین میں کچھ تنگی نہ رکھی تمہارے باپ ابراہیم کا دین اللہ نے تمہارا نام مسلمان رکھا ہے اگلی کتابوں میں اور اس قرآن میں تاکہ رسول تمہارا نگہبان و گواہ ہو اور تم اور لوگوں پر گواہی دو تو نماز برپا رکھو اور زکوٰة دو اور اللہ کی رسی مضبوط تھام لو وہ تمہارا مولیٰ ہے تو کیا ہی اچھا مولیٰ اور کیا ہی اچھا مددگار،\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmdclxxiv{\basmalahur بیشک مراد کو پہنچے ایمان والے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmdclxxv{جو اپنی نماز میں گڑگڑاتے ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmdclxxvi{اور وہ جو کسی بیہودہ بات کی طرف التفات نہیں کرتے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmdclxxvii{اور وہ کہ زکوٰة دینے کا کام کرتے ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmdclxxviii{اور وہ جو اپنی شرمگاہوں کی حفاظت کرتے ہیں،\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmdclxxix{مگر اپنی بیبیوں یا شرعی باندیوں پر جو ان کے ہاتھ کی مِلک ہیں کہ ان پر کوئی ملامت نہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmdclxxx{تو جو ان دو کے سوا کچھ اور چاہے وہی حد سے بڑھنے والے ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmdclxxxi{اور وہ جو اپنی امانتوں اور اپنے عہد کی رعایت کرتے ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmdclxxxii{اور وہ جو اپنی نمازوں کی نگہبانی کرتے ہیں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmdclxxxiii{یہی لوگ وارث ہیں،\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmdclxxxiv{کہ فردوس کی میراث پائیں گے، وہ اس میں ہمیشہ رہیں گے،\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmdclxxxv{اور بیشک ہم نے آدمی کو چنی ہوئی (انتخاب کی) مٹی سے بنایا،\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmdclxxxvi{پھر اسے پانی کی بوند کیا ایک مضبوط ٹھہراؤ میں\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmdclxxxvii{پھر ہم نے اس پانی کی بوند کو خون کی پھٹک کیا پھر خون کی پھٹک کو گوشت کی بوٹی پھر گوشت کی بوٹی کو ہڈیاں پھر ان ہڈیوں پر گوشت پہنایا، پھر اسے اور صورت میں اٹھان دی تو بڑی برکت والا ہے اللہ سب سے بہتر بتانے والا،\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmdclxxxviii{پھر اس کے بعد تم ضرور مرنے والے ہو،\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmdclxxxix{پھر تم سب قیامت کے دن اٹھائے جاؤ گے،\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmdcxc{اور بیشک ہم نے تمہارے اوپر سات راہیں بنائیں اور ہم خلق سے بے خبر نہیں\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmdcxci{اور ہم نے آسمان سے پانی اتارا ایک اندازہ پر پھر اسے زمین میں ٹھہرایا اور بیشک ہم اس کے لے جانے پر قادر ہیں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmdcxcii{تو اس سے ہم نے تمہارے باغ پیدا کیے کھجوروں اور انگوروں کے تمہارے لیے ان میں بہت سے میوے ہیں اور ان میں سے کھاتے ہو\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmdcxciii{اور وہ پیڑ پیدا کیا کہ طور سینا سے نکلتا ہے لے کر اگتا ہے تیل اور کھانے والوں کے لیے سالن\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmdcxciv{اور بیشک تمہارے لیے چوپایوں میں سمجھنے کا مقام ہے، ہم تمہیں پلاتے ہیں اس میں سے جو ان کے پیٹ میں ہے اور تمہارے لیے ان میں بہت فائدے ہیں اور ان سے تمہاری خوراک ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmdcxcv{اور ان پر اور کشتی پر سوار کیے جاتے ہو،\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmdcxcvi{اور بیشک ہم نے نوح کو اس کی قوم کی طرف بھیجا تو اس نے کہا اے میری قوم اللہ کو پوجو اس کے سوا تمہارا کوئی خدا نہیں، تو کیا تمہیں ڈر نہیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmdcxcvii{تو اس کی قوم کے جن سرداروں نے کفر کیا بولے یہ تو نہیں مگر تم جیسا آدمی چاہتا ہے کہ تمہارا بڑا بنے اور اللہ چاہتا تو فرشتے اتارتا ہم نے تو یہ اگلے باپ داداؤں میں نہ سنا\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmdcxcviii{وہ تو نہیں مگر ایک دیوانہ مرد تو کچھ زمانہ تک اس کا انتظار کیے رہو\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmdcxcix{نوح نے عرض کی اے میرے رب! میری مدد فرما اس پر کہ انہوں نے مجھے جھٹلایا،\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmdcc{تو ہم نے اسے وحی بھیجی کہ ہماری نگاہ کے سامنے اور ہمارے حکم سے کشتی بنا پھر جب ہمارا حکم آئے اور تنور ابلے تو اس میں بٹھالے ہر جوڑے میں سے دو اور اپنے گھر والے مگر ان میں سے وہ جن پر بات پہلے پڑچکی اور ان ظالموں کے معاملہ میں مجھ سے بات نہ کرنا یہ ضرور ڈبوئے جائیں گے،\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmdcci{پھر جب ٹھیک بیٹھ لے کشتی پر تُو اور تیرے ساتھ والے تو کہہ سب خوبیاں اللہ کو جس نے ہمیں ان ظالموں سے نجات دی،\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmdccii{اور عرض کر کہ اے میرے رب مجھے برکت والی جگہ اتار اور تو سب سے بہتر اتارنے والا ہے،\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmdcciii{بیشک اس میں ضرو ر نشانیاں اور بیشک ضرور ہم جانچنے والے تھے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmdcciv{پھر ان کے بعد ہم نے اور سنگت (قوم) پیدا کی\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmdccv{تو ان میں ایک رسول انہیں میں سے بھیجا کہ اللہ کی بندگی کرو اس کے سوا تمہارا کوئی خدا نہیں، تو کیا تمہیں ڈر نہیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmdccvi{اور بولے اس قوم کے سردار جنہوں نے کفر کیا اور آخرت کی حاضری کو جھٹلایا اور ہم نے انہیں دنیا کی زندگی میں چین دیا کہ یہ تو نہیں مگر جیسا آدمی جو تم کھاتے ہو اسی میں سے کھاتا ہے اور جو تم پیتے ہو اسی میں سے پیتا ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmdccvii{اور اگر تم کسی اپنے جیسے آدمی کی اطاعت کرو جب تو تم ضرور گھاٹے میں ہو،\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmdccviii{کیا تمہیں یہ وعدہ دیتا ہے کہ تم جب مرجاؤ گے اور مٹی اور ہڈیاں ہوجاؤ گے اس کے بعد پھر نکالے جاؤ گے،\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmdccix{کتنی دور ہے کتنی دور ہے جو تمہیں وعدہ دیا جاتا ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmdccx{وہ تو نہیں مگر ہماری دنیا کی زندگی کہ ہم مرتے جیتے ہیں اور ہمیں اٹھنا نہیں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmdccxi{وہ تو نہیں مگر ایک مرد جس نے اللہ پر جھوٹ باندھا اور ہم اسے ماننے کے نہیں\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmdccxii{عرض کی کہ اے میرے رب میری مدد فرما اس پر کہ انہوں نے مجھے جھٹلایا،\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmdccxiii{اللہ نے فرمایا کچھ دیر جاتی ہے کہ یہ صبح کریں گے پچھتاتے ہوئے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmdccxiv{تو انہیں آلیا سچی چنگھاڑ نے تو ہم نے انہیں گھاس کوڑا کردیا تو دور ہوں ظالم لوگ،\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmdccxv{پھر ان کے بعد ہم نے اور سنگتیں (قومیں) پیدا کیں\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmdccxvi{کوئی امت اپنی میعاد سے نہ پہلے جائے نہ پیچھے رہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmdccxvii{پھر ہم نے اپنے رسول بھیجے ایک پیچے دوسرا جب کسی امت کے پاس اس کا رسول آیا انہوں نے اسے جھٹلایا تو ہم نے اگلوں سے پچھلے ملادیے اور انہیں کہانیاں کر ڈالا تو دور ہوں وہ لوگ کہ ایمان نہیں لاتے،\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmdccxviii{پھر ہم نے موسیٰ اور اس کے بھائی ہارون کو اپنی آیتوں اور روشن سند کے ساتھ بھیجا،\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmdccxix{فرعون اور اس کے درباریوں کی طرف تو انہوں نے غرور کیا اور وہ لوگ غلبہ پائے ہوئے تھے،\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmdccxx{تو بولے کیا ہم ایمان لے آئیں اپنے جیسے دو آدمیوں پر اور ان کی قوم ہماری بندگی کررہی ہے،\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmdccxxi{تو انہوں نے ان دونوں کو جھٹلایا تو ہلاک کیے ہوؤں میں ہوگئے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmdccxxii{اور بیشک ہم نے موسیٰ کو کتاب عطا فرمائی کہ ان کو ہدایت ہو،\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmdccxxiii{اور ہم نے مریم اور اس کے بیٹے کو نشانی کیا اور انہیں ٹھکانا دیا ایک بلند زمین جہاں بسنے کا مقام اور نگاہ کے سامنے بہتا پانی،\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmdccxxiv{اے پیغمبرو! پاکیزہ چیزیں کھاؤ اور اچھا کام کرو، میں تمہارے کاموں کو جانتا ہوں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmdccxxv{اور بیشک یہ تمہارا دین ایک ہی دین ہے اور میں تمہارا رب ہوں تو مجھ سے ڈرو،\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmdccxxvi{تو ان کی امتوں نے اپنا کام آپس میں ٹکڑے ٹکڑے کرلیا ہر گروہ جو اس کے پاس ہے اس پر خوش ہے،\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmdccxxvii{تو تم ان کو چھوڑ دو ان کے نشہ میں ایک وقت تک\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmdccxxviii{کیا یہ خیال کررہے ہیں کہ وہ جو ہم ان کی مدد کررہے ہیں مال اور بیٹوں سے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmdccxxix{یہ جلد جلد ان کو بھلائیاں دیتے ہیں بلکہ انہیں خبر نہیں\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmdccxxx{بیشک وہ جو اپنے رب کے ڈر سے سہمے ہوئے ہیں\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmdccxxxi{اور وہ جو اپنے رب کی آیتوں پر ایمان لاتے ہیں\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmdccxxxii{اور وہ جو اپنے رب کا کوئی شریک نہیں کرتے،\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmdccxxxiii{اور وہ جو دیتے ہیں جو کچھ دیں اور ان کے دل ڈر رہے ہیں یوں کہ ان کو اپنے رب کی طرف پھرنا ہے،\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmdccxxxiv{یہ لوگ بھلائیوں میں جلدی کرتے ہیں اور یہی سب سے پہلے انہیں پہنچے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmdccxxxv{اور ہم کسی جان پر بوجھ نہیں رکھتے مگر اس کی طاقت بھر اور ہمارے پاس ایک کتاب ہے کہ حق بولتی ہے اور ان پر ظلم نہ ہوگا، ف۹۸)\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmdccxxxvi{بلکہ ان کے دل اس سے غفلت میں ہیں اور ان کے کام ان کاموں سے جدا ہیں جنہیں وہ کررہے ہیں،\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmdccxxxvii{یہاں تک کہ جب ہم نے ان کے امیروں کو عذاب میں پکڑا تو جبھی وہ فریاد کرنے لگے،\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmdccxxxviii{آج فریاد نہ کرو، ہماری طرف سے تمہاری مدد نہ ہوگی،\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmdccxxxix{بیشک میری آیتیں تم پر پڑھی جاتی تھیں تو تم اپنی ایڑیوں کے بل الٹے پلٹتے تھے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmdccxl{خدمت حرم پر بڑائی مارتے ہو رات کو وہاں بیہودہ کہانیاں بکتے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmdccxli{حق کو چھوڑے ہوئے کیا انہوں نے بات کو سوچا نہیں یا ان کے پاس وہ آیا جو ان کے باپ دادا کے پاس نہ آیا تھا\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmdccxlii{یا انہوں نے اپنے رسول کو نہ پہچانا تو وہ اسے بیگانہ سمجھ رہے ہیں\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmdccxliii{یا کہتے ہیں اسے سودا ہے بلکہ وہ تو ان کے پاس حق لائے اور ان میں اکثر حق برا لگتا ہے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmdccxliv{اور اگر حق ان کی خواہشوں کی پیروی کرتا تو ضرور آسمان اور زمین اور جو کوئی ان میں ہیں سب تباہ ہوجاتے بلکہ ہم تو ان کے پاس وہ چیز لائے جس میں ان کی ناموری تھی تو وہ اپنی عزت سے ہی منہ پھیرے ہوئے ہیں،\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmdccxlv{کیا تم ان سے کچھ اجرت مانگتے ہو تو تمہارے رب کا اجر سب سے بھلا اور وہ سب سے بہتر روزی دینے والا\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmdccxlvi{اور بیشک تم انہیں سیدھی راہ کی طرف بلاتے ہو\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmdccxlvii{اور بیشک جو آخرت پر ایما ن نہیں لاتے ضرور سیدھی راہ سے کترائے ہوئے ہیں،\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmdccxlviii{اور اگر ہم ان پر رحم کریں اور جو مصیبت ان پر پڑی ہے ٹال دیں تو ضرور بھٹ پنا (احسان فراموشی) کریں گے اپنی سرکشی میں بہکتے ہوئے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmdccxlix{اور بیشک ہم نے انہیں عذاب میں پکڑا تو نہ وہ اپنے رب کے حضور میں جھکے اور نہ گڑگڑاتے ہیں\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmdccl{یہاں تک کہ جب ہم نے ان پر کھولا کسی سخت عذاب کا دروازہ تو وہ اب اس میں ناامید پڑے ہیں،\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmdccli{اور وہی ہے جس نے بنائے تمہارے لیے کان اور آنکھیں اور دل تم بہت ہی کم حق مانتے ہو\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmdcclii{اور وہی ہے جس نے تمہیں زمین میں پھیلایا اور اسی کی طرف اٹھنا ہے\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmdccliii{اور وہی جٕلائے اور مارے اور اسی کے لیے ہیں رات اور دن کی تبدیلیاں تو کیا تمہیں سمجھ نہیں\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmdccliv{بلکہ انہوں نے وہی کہی جو اگلے کہتے تھے،\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmdcclv{بولے کیا جب ہم مرجائیں اور مٹی اور ہڈیاں ہوجائیں کیا پھر نکالے جائیں گے،\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmdcclvi{بیشک یہ وعدہ ہم کو اور ہم سے پہلے ہمارے باپ دادا کو دیا گیا یہ تو نہیں مگر وہی اگلی داستانیں\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmdcclvii{تم فرماؤ کس کا مال ہے زمین اور جو کچھ اس میں ہے اگر تم جانتے ہو\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmdcclviii{اب کہیں گے کہ اللہ کا تم فرماؤ پھر کیوں نہیں سوچتے\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmdcclix{تم فرماؤ کون ہے مالک سوتوں آسمانوں کا اور مالک بڑے عرش کا،\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmdcclx{اب کہیں گے یہ اللہ ہی کی شان ہے، تم فرماؤ پھر کیوں نہیں ڈرتے\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmdcclxi{تم فرماؤ کس کے ہاتھ ہے ہر چیز کا قابو اور وہ پناہ دیتا ہے اور اس کے خلاف کوئی پناہ نہیں دے سکتا اگر تمہیں علم ہو\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmdcclxii{اب کہیں گے یہ اللہ ہی کی شان ہے، تم فرماؤ پھر کس جادو کے فریب میں پڑے ہو\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmdcclxiii{بلکہ ہم ان کے پاس حق لائے اور وہ بیشک جھوٹے ہیں\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmdcclxiv{اللہ نے کوئی بچہ اختیار نہ کیا اور نہ اس کے ساتھ کوئی دوسرا خدا یوں ہوتا تو ہر خدا اپنی مخلوق لے جاتا اور ضرور ایک دوسرے پر اپنی تعلی چاہتا پاکی ہے اللہ کو ان باتوں سے جو یہ بناتے ہیں\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmdcclxv{جاننے والا ہر نہاں و عیاں کا تو اسے بلندی ہے ان کے شرک سے،\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmdcclxvi{تم عرض کرو کہ اے میرے رب! اگر تو مجھے دکھائے جو انہیں وعدہ دیا جاتا ہے،\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmdcclxvii{تو اے میرے رب! مجھے ان ظالموں کے ساتھ نہ کرنا\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mmdcclxviii{اور بیشک ہم قادر ہیں کہ تمہیں دکھادیں جو انہیں وعدہ دے رہے ہیں\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mmdcclxix{سب سے اچھی بھلائی سے برائی کو دفع کرو ہم خوب جانتے ہیں جو باتیں یہ بناتے ہیں\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mmdcclxx{اور تم عرض کرو کہ اے میرے رب تیری پناہ شیاطین کے وسوسو ں سے\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxi{اور اے میرے رب تیری پناہ کہ وہ میرے پاس آئیں،\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxii{یہاں تک کہ جب ان میں کسی کو موت آئے تو کہتا ہے کہ اے میرے رب مجھے واپس پھر دیجئے،\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxiii{شاید اب میں کچھ بھلائی کماؤں اس میں جو چھوڑ آیا ہوں ہشت یہ تو ایک بات ہے جو وہ اپنے منہ سے کہتا ہے اور ان کے آگے ایک آڑ ہے اس دن تک جس دن اٹھائے جائیں گے،\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxiv{تو جب صُور پھونکا جائے گا تو نہ ان میں رشتے رہیں گے اور نہ ایک دوسرے کی بات پوچھے\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxv{تو جن کی تولیں بھاری ہولیں وہی مراد کچھ پہنچے،\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxvi{اور جن کی تولیں ہلکی پڑیں وہی ہیں جنہوں نے اپنی جانیں گھاٹے میں ڈالیں ہمیشہ دوزخ میں رہیں گے،\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxvii{ان کے منہ پر آگ لپیٹ مارے گی اور وہ اس میں منہ چڑائے ہوں گے\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxviii{کیا تم پر میری آیتیں نہ پڑھی جاتی تھیں تو تم انہیں جھٹلاتے تھے،\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxix{کہیں گے اے ہمارے رب ہم پر ہماری بدبختی غالب آئی اور ہم گمراہ لوگ تھے،\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxx{اے رب ہمارے ہم کو دوزخ سے نکال دے پھر اگر ہم ویسے ہی کریں تو ہم ظالم ہیں\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxi{رب فرمائے گا دھتکارے (خائب و خاسر) پڑے رہو اس میں اور مجھ سے بات نہ کرو\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxii{بیشک میرے بندوں کا ایک گروہ کہتا تھا اے ہمارے رب! ہم ایمان لائے تو ہمیں بخش دے اور ہم پر رحم کر اور تو سب سے بہتر رحم کرنے والا ہے،\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxiii{تو تم نے انہیں ٹھٹھا بنالیا یہاں تک کہ انہیں بنانے کے شغل میں میری یاد بھول گئے اور تم ان سے ہنسا کرتے،\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxiv{بیشک آج میں نے ان کے صبر کا انہیں یہ بدلہ دیا کہ وہی کامیاب ہیں،\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxv{فرمایا تم زمین میں کتنا ٹھہرے برسوں کی گنتی سے\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxvi{، بولے ہم ایک دن رہے یا دن کا حصہ تو گننے والوں سے دریافت فرما\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxvii{فرمایا تم نہ ٹھہرے مگر تھوڑا اگر تمہیں علم ہوتا،\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxviii{تو کیا یہ سمجھتے ہو کہ ہم نے تمہیں بیکار بنایا اور تمہیں ہماری طرف پھرنا نہیں\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxix{تو بہت بلندی والا ہے اللہ سچا بادشاہ کوئی معبود نہیں سوا اس کے عزت والے عرش کا مالک،\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@mmdccxc{اور جو اللہ کے ساتھ کسی دوسرے خدا کو پوجے جس کی اس کے پاس کوئی سند نہیں تو اس کا حساب اس کے رب کے یہاں ہے، بیشک کافروں کا چھٹکارا نہیں،\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@mmdccxci{اور تم عرض کرو، اے میرے رب بخش دے اور رحم فرما اور تو سب سے برتر رحم کرنے والا،\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@mmdccxcii{\basmalahur یہ ایک سورة ہے کہ ہم نے اتاری اور ہم نے اس کے احکام فرض کیے اور ہم نے اس میں روشن آیتیں نازل فرمائیں کہ تم دھیان کرو،\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmdccxciii{جو عورت بدکار ہو اور جو مرد تو ان میں ہر ایک کو سو کوڑے لگاؤ اور تمہیں ان پر ترس نہ آئے اللہ کے دین میں اگر تم ایمان لاتے ہو اللہ اور پچھلے دن پر اور چاہیے کہ ان کی سزا کے وقت مسلمانوں کا ایک گروہ حاضر ہو\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmdccxciv{بدکار مرد نکاح نہ کرے مگر بدکار عورت یا شرک والی سے، اور بدکار عورت سے نکاح نہ کرے مگر بدکار مرد یا مشرک اور یہ کام ایمان والوں پر حرام ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmdccxcv{اور جو پارسا عورتوں کو عیب لگائیں پھر چار گواہ معائنہ کے نہ لائیں تو انہیں اسی کوڑے لگاؤ اور ان کی گواہی کبھی نہ مانو اور وہی فاسق ہیں،\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmdccxcvi{مگر جو اس کے بعد توبہ کرلیں اور سنور جائیں تو بیشک اللہ بخشنے والا مہربان ہے،\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmdccxcvii{اور وہ جو اپنی عورتوں کو عیب لگائیں اور ان کے پاس اپنے بیان کے سوا گواہ نہ ہوں تو ایسے کسی کی گواہی یہ ہے کہ چار بار گواہی دے اللہ کے نام سے کہ وہ سچا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmdccxcviii{اور پانچویں یہ کہ اللہ کی لعنت ہو اس پر اگر جھوٹا ہو،\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmdccxcix{اور عورت سے یوں سزا ٹل جائے گی کہ وہ اللہ کا نام لے کر چار بار گواہی دے کہ مرد جھوٹا ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmdccc{اور پانچویں یوں کہ عورت پر غضب اللہ کا اگر مرد جھوٹا ہے اور پانچویں یوں کہ عورت پر غضب اللہ کا اگر مرد سچا ہو\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmdccci{اور اگر اللہ کا فضل اور اس کی رحمت تم پر نہ ہوتی اور یہ کہ اللہ توبہ قبول فرماتا حکمت والا ہے،\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmdcccii{تو تمہارا پردہ کھول دیتا بیشک وہ کہ یہ بڑا بہتان لائے ہیں تمہیں میں کی ایک جماعت ہے اسے اپنے لیے برا نہ سمجھو، بلکہ وہ تمہارے لیے بہتر ہے ان میں ہر شخص کے لیے وہ گناہ ہے جو اس نے کمایا اور ان میں وہ جس نے سب سے بڑا حصہ لیا اس کے لیے بڑا عذاب ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmdccciii{کیوں نہ ہوا ہوا جب تم نے اسے سنا تھا کہ مسلمان مردوں اور مسلمان عورتوں نے اپنوں پر نیک گمان کیا ہوتا اور کہتے یہ کھلا بہتان ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmdccciv{اس پر چار گواہ کیوں نہ لائے، تو جب گواہ نہ لائے تو وہی اللہ کے نزدیک جھوٹے ہیں،\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmdcccv{اور اگر اللہ کا فضل اور اس کی رحمت تم پر دنیا اور آخرت میں نہ ہو تی تو جس چرچے میں تم پڑے اس پر تمہیں بڑا عذاب پہنچتا،\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmdcccvi{جب تم ایسی بات اپنی زبانوں پر ایک دوسرے سے سن کر لاتے تھے اور اپنے منہ سے وہ نکالتے تھے جس کا تمہیں علم نہیں اور اسے سہل سمجھتے تھے اور وہ اللہ کے نزدیک بڑی بات ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmdcccvii{اور کیوں نہ ہوا جب تم نے سنا تھا کہا ہوتا کہ ہمیں نہیں پہنچتا کہ ایسی بات کہیں الہٰی پاکی ہے تجھے یہ بڑا بہتان ہے،\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmdcccviii{اللہ تمہیں نصیحت فرماتا ہے کہ اب کبھی ایسا نہ کہنا اگر ایمان رکھتے ہو،\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmdcccix{اور اللہ تمہارے لیے آیتیں صاف بیان فرماتا ہے، اور اللہ علم و حکمت والا ہے،\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmdcccx{وہ لوگ جو چاہتے ہیں کہ مسلمانوں میں برا چرچا پھیلے ان کے لیے دردناک عذاب ہے دنیا اور آخرت میں اور اللہ جانتا ہے اور تم نہیں جانتے،\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmdcccxi{اور اگر اللہ کا فضل اور اس کی رحمت تم پر نہ ہوتی اور یہ کہ اللہ تم پر نہایت مہربان مہروالا ہے،\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmdcccxii{تو تم اس کا مزہ چکھتے اے ایمان والو! شیطان کے قدموں پر نہ چلو، اور جو شیطان کے قدموں پر چلے تو وہ تو بے حیائی اور بری ہی بات بتائے گا اور اگر اللہ کا فضل اور اس کی رحمت تم پر نہ ہوتی تو تم میں کوئی بھی کبھی ستھرا نہ ہوسکتا ہاں اللہ ستھرا کردیتا ہے جسے چاہے اور اللہ سنتا جانتا ہے،\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmdcccxiii{اور قسم نہ کھائیں وہ جو تم میں فضیلت والے اور گنجائش والے ہیں قرابت والوں اور مسکینوں اور اللہ کی راہ میں ہجرت کرنے والوں کو دینے کی، اور چاہیے کہ معاف کریں اور درگزریں، کیا تم اسے دوست نہیں رکھتے کہ اللہ تمہاری بخشش کرے، اور اللہ بخشنے والا مہربان ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmdcccxiv{بیشک وہ جو عیب لگاتے ہیں انجان پارسا ایمان والیوں کو ان پر لعنت ہے دنیا اور آخرت میں اور ان کے لیے بڑا عذاب ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmdcccxv{جس دن ان پر گواہی دیں گے ان کی زبانیں اور ان کے ہاتھ اور ان کے پاؤں جو کچھ کرتے تھے،\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmdcccxvi{اس دن اللہ انہیں ان کی سچی سزا پوری دے گا اور جان لیں گے کہ اللہ ہی صریح حق ہے،\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmdcccxvii{گندیاں گندوں کے لیے اور گندے گندیوں کے لیے اور ستھریاں ستھروں کے لیے اور ستھرے ستھریوں کے لیے وہ پاک ہیں ان باتوں سے جو یہ کہہ رہے ہیں، ان کے لیے بخشش اور عزت کی روزی ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmdcccxviii{اے ایمان والو! اپنے گھروں کے سوا اور گھروں میں نہ جاؤ جب تک اجازت نہ لے لو اور ان کے ساکنوں پر سلام نہ کرلو یہ تمہارے لیے بہتر ہے کہ تم دھیان کرو،\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmdcccxix{پھر اگر ان میں کسی کو نہ پاؤ جب بھی بے ما لکوں کی اجازت کے ان میں نہ جاؤ اور اگر تم سے کہا جائے واپس جاؤ تو واپس ہو یہ تمہارے لیے بہت ستھرا ہے، اللہ تمہارے کاموں کو جانتا ہے،\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmdcccxx{اس میں تم پر کچھ گناہ نہیں کہ ان گھروں میں جاؤ جو خاص کسی کی سکونت کے نہیں اور ان کے برتنے کا تمہیں اختیار ہے، اور اللہ جانتا ہے جوتم ظاہر کرتے ہو، اور جو تم چھپاتے ہو،\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxi{مسلمان مردوں کو حکم دو اپنی نگاہیں کچھ نیچی رکھیں اور اپنی شرمگاہوں کی حفاظت کریں یہ ان کے لیے بہت ستھرا ہے، بیشک اللہ کو ان کے کاموں کی خبر ہے،\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxii{اور مسلمان عورتوں کو حکم دو اپنی نگاہیں کچھ نیچی رکھیں اور اپنی پارسائی کی حفاظت کریں اور اپنا بناؤ نہ دکھائیں مگر جتنا خود ہی ظاہر ہے اور وہ دوپٹے اپنے گریبانوں پر ڈالے رہیں، اور اپنا سنگھار ظاہر نہ کریں مگر اپنے شوہروں پر یا اپنے باپ یا شوہروں کے باپ یا اپنے بیٹوں یا شوہروں کے بیٹے یا اپنے بھائی یا اپنے بھتیجے یا اپنے بھانجے یا اپنے دین کی عورتیں یا اپنی کنیزیں جو اپنے ہاتھ کی ملک ہوں یا نوکر بشرطیکہ شہوت والے مرد نہ ہوں یا وہ بچے جنہیں عورتوں کی شرم کی چیزوں کی خبر نہیں اور زمین پر پاؤں زور سے نہ رکھیں کہ جانا جائے ان کا چھپا ہوا سنگھار اور اللہ کی طرف توبہ کرو اے مسلمانو! سب کے سب اس امید پر کہ تم فلاح پاؤ،\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxiii{اور نکاح کردو اپنوں میں ان کا جو بے نکاح ہوں اور اپنے لائق بندوں اور کنیزوں کا اگر وہ فقیر ہوں تو اللہ انہیں غنی کردے گا اپنے فضل کے سبب اور اللہ وسعت والا علم والا ہے،\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxiv{اور چاہیے کہ بچے رہیں وہ جو نکاح کا مقدور نہیں رکھتے یہاں تک کہ اللہ مقدور والا کردے اپنے فضل سے اور تمہارے ہاتھ کی مِلک باندی غلاموں میں سے جو یہ چاہیں کہ کچھ مال کمانے کی شرط پر انہیں آزادی لکھ دو تو لکھ دو اگر ان میں کچھ بھلائی جانو اور اس پر ان کی مدد کرو اللہ کے مال سے جو تم کو دیا اور مجبور نہ کرو اپنی کنیزوں کو بدکاری پر جب کہ وہ بچنا چاہیں تاکہ تم دنیوی زندگی کا کچھ مال چاہو اور جو انہیں مجبور کرے گا تو بیشک اللہ بعد اس کے کہ وہ مجبوری ہی کی حالت پر رہیں بخشنے والا مہربان ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxv{اور بیشک ہم نے اتاریں تمہاری طرف روشن آیتیں اور کچھ ان لوگوں کا بیان جو تم سے پہلے ہو گزرے اور ڈر والوں کے لیے نصیحت،\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxvi{اللہ نور ہے آسمانوں اور زمینوں کا، اس کے نور کی مثال ایسی جیسے ایک طاق کہ اس میں چراغ ہے وہ چراغ ایک فانوس میں ہے وہ فانوس گویا ایک ستارہ ہے موتی سا چمکتا روشن ہوتا ہے برکت والے پیڑ زیتون سے جو نہ پورب کا نہ پچھم کا قریب ہے کہ اس کا تیل بھڑک اٹھے اگرچہ اسے آگ نہ چھوئے نور پر نور ہے اللہ اپنے نور کی راہ بتاتا ہے جسے چاہتا ہے، اور اللہ مثالیں بیان فرماتا ہے لوگوں کے لیے، اور اللہ سب کچھ جانتا ہے،\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxvii{ان گھروں میں جنہیں بلند کرنے کا اللہ نے حکم دیا ہے اور ان میں اس کا نام لیا جاتا ہے، اللہ کی تسبیح کرتے ہیں ان میں صبح اور شام\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxviii{وہ مرد جنہیں غافل نہیں کرتا کوئی سودا اور نہ خرید و فروخت اللہ کی یاد اور نماز برپا رکھنے اور زکوٰة دینے سے ڈرتے ہیں اس دن سے جس میں الٹ جائیں گے دل اور آنکھیں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxix{تاکہ اللہ انہیں بدلہ دے ان کے سب سے بہتر کام کام اور اپنے فضل سے انہیں انعام زیادہ دے، اور اللہ روزی دیتا ہے جسے چاہے بے گنتی،\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxx{اور جو کافر ہوئے ان کے کام ایسے ہیں جیسے دھوپ میں چمکتا ریتا کسی جنگل میں کہ پیاسا اسے پانی سمجھے، یہاں تک جب اس کے پاس آیا تو اسے کچھ نہ پایا اور اللہ کو اپنے قریب پایا تو اس نے اس کا حساب پورا بھردیا، اور اللہ جلد حساب کرلیتا ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxi{یا جیسے اندھیریاں کسی کنڈے کے (گہرائی والے) دریا میں اس کے اوپر موج مو ج کے اوپر اور موج اس کے اوپر بادل، اندھیرے ہیں ایک پر ایک جب اپنا ہاتھ نکالے تو سوجھائی دیتا معلوم نہ ہو اور جسے اللہ نور نہ دے اس کے لیے کہیں نور نہیں\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxii{کیا تم نے نہ دیکھا کہ اللہ کی تسبیح کرتے ہیں جو کوئی آسمانوں اور زمین میں ہیں اور پرندے پر پھیلائے سب نے جان رکھی ہے اپنی نماز اور اپنی تسبیح، اور اللہ ان کے کاموں کو جانتا ہے،\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxiii{اور اللہ ہی کے لیے ہے سلطنت آسمانوں اور زمین کی اور اللہ ہی کی طرف پھر جانا،\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxiv{کیا تو نے نہ دیکھا کہ اللہ نرم نرم چلاتا ہے بادل کو پھر انہیں آپس میں مِلاتا ہے پھر انہیں تہہ پر تہہ کردیتا ہے تو تُو دیکھے کہ اس کے بیچ میں سے مینہ نکلتا ہے اور اتارتا ہے آسمان سے اس میں جو برف کے پہاڑ ہیں ان میں سے کچھ اولے پھر ڈالنا ہے انہیں جس پر چاہے اور پھیردیتا ہے انہیں جس سے چاہے قریب ہے کہ اس کی بجلی کی چمک آنکھ لے جائے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxv{اللہ بدلی کرتا ہے رات اور دن کی بیشک اس میں سمجھنے کا مقام ہے نگاہ والوں کو،\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxvi{اور اللہ نے زمین پر ہر چلنے والا پانی سے بنایا تو ان میں کوئی اپنے پیٹ پر چلتا ہے اور ان میں کوئی دو پاؤں پر چلتا ہے اور ان میں کوئی چار پاؤں پر چلتا ہے اللہ بناتا ہے جو چاہے، بیشک اللہ سب کچھ کرسکتا ہے،\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxvii{بیشک ہم نے اتاریں صاف بیان کرنے والی آیتیں اور اللہ جسے چاہے سیدھی راہ دکھائے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxviii{اور کہتے ہیں ہم ایمان لائے اللہ اور رسول پر اور حکم مانا پھر کچھ ان میں کے اس کے بعد پھر جاتے ہیں اور وہ مسلمان نہیں\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxix{اور جب بلائے جائیں اللہ اور اس کے رسول کی طرف کہ رسول ان میں فیصلہ فرمائے تو جبھی ان کا ایک فریق منہ پھیر جاتا ہے،\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmdcccxl{اور اگر ان میں ڈگری ہو (ان کے حق میں فیصلہ ہو) تو اس کی طرف آئیں مانتے ہوئے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmdcccxli{کیا ان کے دلوں میں بیماری ہے یا شک رکھتے ہیں کیا یہ ڈرتے ہیں کہ اللہ و رسول ان پر ظلم کریں گے بلکہ خود ہی ظالم ہیں،\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmdcccxlii{مسلمانوں کی بات تو یہی ہے جب اللہ اور رسول کی طرف بلائے جائیں کہ رسول ان میں فیصلہ فرمائے کہ عرض کریں ہم نے سنا اور حکم مانا او ریہی لوگ مراد کو پہنچے،\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmdcccxliii{اور جو حکم مانے اللہ اور اس کے رسول کا اور اللہ سے ڈرے اور پرہیزگاری کرے تو یہی لوگ کامیاب ہیں،\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmdcccxliv{اور انہوں نے اللہ کی قسم کھائی اپنے حلف میں حد کی کوشش سے کہ اگر تم انہیں حکم دو گے تو وہ ضرور جہاد کو نکلیں گے تم فرماؤ قسمیں نہ کھاؤ موافق شرع حکم برداری چاہیے، اللہ جانتا ہے جو تم کرتے ہو\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmdcccxlv{تم فرماؤ حکم مانو اللہ کا اور حکم مانو رسول کا پھر اگر تم منہ پھیرو تو رسول کے ذمہ وہی ہے جس اس پر لازم کیا گیا اور تم پر وہ ہے جس کا بوجھ تم پر رکھا گیا اور اگر رسول کی فرمانبرداری کرو گے راہ پاؤ گے، اور رسول کے ذمہ نہیں مگر صاف پہنچا دینا\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmdcccxlvi{اللہ نے وعدہ دیا ان کو جو تم میں سے ایمان لائے اور اچھے کام کیے کہ ضرور انہیں زمین میں خلافت دے گا جیسی ان سے پہلوں کو دی اور ضرور ان کے لیے جمادے گا ان کا وہ دین جو ان کے لیے پسند فرمایا ہے اور ضرور ان کے اگلے خوف کو امن سے بدل دے گا میری عبادت کریں میرا شریک کسی کو نہ ٹھہرائیں، اور جو اس کے بعد ناشکری کرے تو وہی لوگ بے حکم ہیں،\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmdcccxlvii{اور نماز برپا رکھو اور زکوٰة دو اور رسول کی فرمانبرداری کرو اس امید پر کہ تم پر رحم ہو،\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmdcccxlviii{ہرگز کافروں کو خیال نہ کرنا کہ وہ کہیں ہمارے قابو سے نکل جائیں زمین میں اور ان کا ٹھکانا آ گ ہے، اور ضرور کیا ہی برا انجام،\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmdcccxlix{اے ایمان والو! چاہیے کہ تم سے اذن لیں تمہارے ہاتھ کے مال غلام اور جو تم میں ابھی جوانی کو نہ پہنچے تین وقت نمازِ صبح سے پہلے اور جب تم اپنے کپڑے اتار رکھتے ہو دوپہر کو اور نماز عشاء کے بعد یہ تین وقت تمہاری شرم کے ہیں ان تین کے بعد کچھ گناہ نہیں تم پر نہ ان پر آمدورفت رکھتے ہیں تمہارے یہاں ایک دوسرے کے پاس اللہ یونہی بیان کرتا ہے تمہارے لیے آیتیں، اور اللہ علم و حکمت والا ہے،\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmdcccl{اور جب تم میں لڑکے جوانی کو پہنچ جائیں تو وہ بھی اذن مانگیں جیسے ان کے اگلوں نے اذن مانگا، اللہ یونہی بیان فرماتا ہے تم سے اپنی آیتیں، اور اللہ علم و حکمت والا ہے،\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmdcccli{اور بوڑھی خانہ نشین عورتیں جنہیں نکاح کی آرزو نہیں ان پر کچھ گناہ نہیں کہ اپنے بالائی کپڑے اتار رکھیں جب کہ سنگھار نہ چمکائیں اور ان سے بھی بچنا ان کے لیے اور بہتر ہے، ور اللہ سنتا جانتا ہے،\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmdccclii{نہ اندھے پر تنگی اور نہ لنگڑے پر مضائقہ اور نہ بیمار پر روک اور نہ تم میں کسی پر کہ کھاؤ اپنی اولاد کے گھر یا اپنے باپ کے گھر یا اپنی ماں کے گھر یا اپنے بھائیوں کے یہاں یا اپنی بہنوں کے گھر ے یا اپنے چچاؤں کے یہاں یا اپنی پھپیوں کے گھر یا اپنے ماموؤں کے یہاں یا اپنی خالاؤں کے گھر یا جہاں کی کنجیاں تمہارے قبضہ میں ہیں یا اپنے دوست کے یہاں تم پر کوئی الزام نہیں کہ مل کر کھاؤ یا الگ الگ پھر جب کسی گھر میں جاؤ تو اپنوں کو سلام کرو ملتے وقت کی اچھی دعا اللہ کے پاس سے مبارک پاکیزہ، اللہ یونہی بیان فرماتا ہے تم سے آیتیں کہ تمہیں سمجھ ہو،\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmdcccliii{ایمان والے تو وہی ہیں جو اللہ اور اس کے رسول پر یقین لائے اور جب رسول کے پاس کسی ایسے کام میں حاضر ہوئے ہوں جس کے لیے جمع کیے گئے ہوں تو نہ جائیں جب تک ان سے اجازت نہ لے لیں وہ جو تم سے اجازت مانگتے ہیں وہی ہیں جو اللہ اور اس کے رسول پر ایمان لاتے ہیں پھر جب وہ تم سے اجازت مانگیں اپنے کسی کام کے لیے تو ان میں جسے تم چاہو اجازت دے دو اور ان کے لیے اللہ سے معافی مانگو بیشک اللہ بخشنے والا مہربان ہے،\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmdcccliv{رسول کے پکارنے کو آپس میں ایسا نہ ٹھہرالو جیسا تم میں ایک دوسرے کو پکارتا ہے بیشک اللہ جانتا ہے جو تم میں چپکے نکل جاتے ہیں کسی چیز کی آڑ لے کر تو ڈریں وہ جو رسول کے حکم کے خلاف کرتے ہیں کہ انہیں کوئی فتنہ پہنچے یا ان پر دردناک عذاب پڑے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmdccclv{سن لو! بیشک اللہ ہی کا ہے جو کچھ آسمانوں اور زمین میں ہے، بیشک وہ جانتا ہے جس حال پر تم ہو اور اس دن کو جس میں اس کی طرف پھیرے جائیں گے تو وہ انہیں بتادے گا جو کچھ انہوں نے کیا، اور اللہ سب کچھ جانتا ہے،\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmdccclvi{\basmalahur بڑی برکت والا ہے وہ کہ جس نے اتارا قرآن اپنے بندہ پر جو سارے جہان کو ڈر سنانے والا ہو\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmdccclvii{وہ جس کے لیے ہے آسمانوں اور زمین کی بادشاہت اور اس نے نہ اختیار فرمایا بچہ اور اس کی سلطنت میں کوئی ساجھی نہیں اس نے ہر چیز پیدا کرکے ٹھیک اندازہ پر رکھی،\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmdccclviii{اور لوگوں نے اس کے سوا اور خدا ٹھہرالیے کہ وہ کچھ نہیں بناتے اور خود پیدا کیے گئے ہیں اور خود اپنی جانوں کے برے بھلے کے مالک نہیں اور نہ مرنے کا اختیار نہ جینے کا نہ اٹھنے کا،\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmdccclix{اور کافر بولے یہ تو نہیں مگر ایک بہتان جو انہوں نے بنالیا ہے اور اس پر اور لوگوں نے انہیں مدد دی ہے بیشک وہ ظلم اور جھوٹ پر آئے،\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmdccclx{اور بولے اگلوں کی کہانیاں ہیں جو انہوں نے لکھ لی ہیں تو وہ ان پر صبح و شام پڑھی جاتی ہیں،\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmdccclxi{تم فرماؤ اسے تو اس نے اتارا ہے جو آسمانوں اور زمین کی ہر بات جانتا ہے بیشک وہ بخشنے والا مہربان ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmdccclxii{اور بولے اور رسول کو کیا ہوا کھانا کھاتا ہے اور بازاروں میں چلتا ہے (ف۹۱۶ کیوں نہ اتارا گیا ان کے ساتھ کوئی فرشتہ کہ ان کے ساتھ ڈر سناتا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmdccclxiii{یا غیب سے انہیں کوئی خزانہ مل جاتا یا ان کا کوئی باغ ہوتا جس میں سے کھاتے اور ظالم بولے تم تو پیروی نہیں کرتے مگر ایک ایسے مرد کی جس پر جادو ہوا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmdccclxiv{اے محبوب دیکھو کیسی کہاوتیں تمہارے لیے بنارہے ہیں تو گمراہ ہوئے کہ اب کوئی راہ نہیں پاتے،\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmdccclxv{بڑی برکت والا ہے وہ کہ اگر چاہے تو تمہارے لیے بہت بہتر اس سے کردے جنتیں جن کے نیچے نہریں بہیں اور کرے گا تمہارے لیے اونچے اونچے محل،\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmdccclxvi{بلکہ یہ تو قیامت کو جھٹلاتے ہیں، اور جو قیامت کو جھٹلائے ہم نے اس کے لیے تیار کر رکھی ہے بھڑکتی ہوئی آگ،\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmdccclxvii{جب وہ انہیں دور جگہ سے دیکھے گی تو سنیں گے اس کا جوش مارنا اور چنگھاڑنا،\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmdccclxviii{اور جب اس کی کسی تنگ جگہ میں ڈالے جائیں گے زنجیروں میں جکڑے ہوئے تو وہاں موت مانگیں گے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmdccclxix{فرمایا جائے گا آج ایک موت نہ مانگو اور بہت سی موتیں مانگو\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmdccclxx{تم فرماؤ کیا یہ بھلا یا وہ ہمیشگی کے باغ جس کا وعدہ ڈر والوں کو ہے، وہ ان کا صلہ اور انجام ہے،\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxi{ان کے لیے وہاں من مانی مرادیں ہیں جن میں ہمیشہ رہیں گے، تمہارے رب کے ذمہ وعدہ ہے مانگا ہوا، ف۲۸)\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxii{اور جس دن اکٹھا کرے گا انہیں اور جن کوا لله کے سوا پوجتے ہیں پھر ان معبودو ں سے فرمائے گا کیا تم نے گمراہ کردیے یہ میرے بندے یا یہ خود ہی راہ بھولے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxiii{وہ عرض کریں گے پاکی ہے تجھ کو ہمیں سزاوار (حق) نہ تھا کہ تیرے سوا کسی اور کو مولیٰ بنائیں لیکن تو نے انہیں اور ان کے باپ داداؤں کو برتنے دیا یہاں تک کہ وہ تیری یاد بھول گئے اور یہ لوگ تھے ہی ہلاک ہونے والے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxiv{تو اب معبودوں نے تمہاری بات جھٹلادی تو اب تم نہ عذاب پھیرسکو نہ اپنی مدد کرسکو اور تم میں جو ظالم ہے ہم اسے بڑا عذاب چکھائیں گے،\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxv{اور ہم نے تم سے پہلے جتنے رسول بھیجے سب ایسے ہی تھے کھانا کھاتے اور بازاروں میں چلتے اور ہم نے تم میں ایک کو دوسرے کی جانچ کیا ہے اور اے لوگو! کیا تم صبر کرو گے اور اے محبوب! تمہارا رب دیکھتا ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxvi{اور بولے وہ جو ہمارے ملنے کی امید نہیں رکھتے ہم پر فرشتے کیوں نہ اتارے یا ہم اپنے رب کو دیکھتے بیشک اپنے جی میں بہت ہی اونچی کھینچی (سرکشی کی) اور بڑی سرکشی پر آئے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxvii{جس دن فرشتوں کو دیکھیں گے وہ دن مجرموں کی کوئی خوشی کا نہ ہوگا اور کہیں گے الٰہی ہم میں ان میں کوئی آڑ کردے رکی ہوئی\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxviii{اور جو کچھ انہوں نے کام کیے تھے ہم نے قصد فرماکر انہیں باریک باریک غبار، کے بکھرے ہوئے ذرے کردیا کہ روزن کی دھوپ میں نظر آتے ہیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxix{جنت والوں کا اس دن اچھا ٹھکانا اور حساب کے دوپہر کے بعد اچھی آرام کی جگہ،\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxx{اور جس دن پھٹ جائے گا آسمان بادلوں سے اور فرشتے اتارے جائیں گے پوری طرح\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxi{اس دن سچی بادشاہی رحمن کی ہے، اور وہ دن کافروں پر سخت ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxii{اور جس دن ظالم اپنے ہاتھ چبا چبا لے گا کہ ہائے کسی طرح سے میں نے رسول کے ساتھ راہ لی ہوتی،\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxiii{وائے خرابی میری ہائے کسی طرح میں نے فلانے کو دوست نہ بنایا ہوتا،\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxiv{بیشک اس نے مجھے بہکادیا میرے پاس آئی ہوئی نصیحت سے اور شیطان آدمی کو بے مدد چھوڑ دیتا ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxv{اور رسول نے عرض کی کہ اے میرے رب! میری قوم نے اس قرآن کو چھوڑنے کے قابل ٹھہرایا\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxvi{اور اسی طرح ہم نے ہر نبی کے لیے دشمن بنادیے تھے مجرم لوگ اور تمہارا رب کافی ہے ہدایت کرنے اور مدد دینے کو،\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxvii{اور کافر بولے قرآن ان پر ایک ساتھ کیوں نہ اتار دیا ہم نے یونہی بتدریج سے اتارا ہے کہ اس سے تمہارا دل مضبوط کریں اور ہم نے اسے ٹھہر ٹھہر کر پڑھا\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxviii{اور وہ کوئی کہاوت تمہارے پاس نہ لائیں گے مگر ہم حق اور اس سے بہتر بیان لے آئیں گے،\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxix{وہ جو جہنم کی طرف ہانکے جائیں گے اپنے منہ کے بل ان کا ٹھکانا سب سے برا اور وہ سب سے گمراہ،\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmdcccxc{اور بیشک ہم نے موسیٰ کو کتاب عطا فرمائی اور اس کے بھائی ہارون کو وزیر کیا،\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmdcccxci{تو ہم نے فرمایا تم دونوں جاؤ اس قوم کی طرف جس نے ہماری آیتیں جھٹلائیں پھر ہم نے انہیں تباہ کرکے ہلاک کردیا،\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmdcccxcii{اور نوح کی قوم کو جب انہوں نے رسولوں کو جھٹلایا ہم نے ان کو ڈبو دیا اور انہیں لوگوں کے لیے نشانی کردیا اور ہم نے ظالموں کے لیے دردناک عذاب تیار کر رکھا ہے،\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmdcccxciii{اور عاد اور ثمود اور کنوئیں والوں کو اور ان کے بیچ میں بہت سی سنگتیں (قومیں)\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmdcccxciv{اور ہم نے سب سے مثالیں بیان فرمائیں اور سب کو تباہ کرکے مٹادیا،\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmdcccxcv{اور ضرور یہ ہو آئے ہیں اس بستی پر جس پر برا برساؤ برسا تھا تو کیا یہ اسے دیکھتے نہ تھے بلکہ انہیں جی اٹھنے کی امید تھی ہی نہیں\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmdcccxcvi{اور جب تمہیں دیکھتے ہیں تو تمہیں نہیں ٹھہراتے مگر ٹھٹھا کیا یہ ہیں جن کو اللہ نے رسول بناکر بھیجا،\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmdcccxcvii{قریب تھا کہ یہ ہمیں ہمارے خداؤں سے بہکادیں اگر ہم ان پر صبر نہ کرتے اور اب جانا چاہتے ہیں جس دن عذاب دیکھیں گے کہ کون گمراہ تھا\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmdcccxcviii{کیا تم نے اسے دیکھا جس نے اپنی جی کی خواہش کو اپنا خدا بنالیا تو کیا تم اس کی نگہبانی کا ذمہ لو گے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmdcccxcix{یا یہ سمجھتے ہو کہ ان میں بہت کچھ سنتے یا سمجھتے ہیں وہ تو نہیں مگر جیسے چوپائے بلکہ ان سے بھی بدتر گمراہ\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmcm{اے محبوب! کیا تم نے اپنے رب کو نہ دیکھا کہ کیسا پھیلا سایہ اور اگر چاہتا تو اسے ٹھہرایا ہوا کردیتا پھر ہم نے سورج کو اس پر دلیل کیا،\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmcmi{پھر ہم نے آہستہ آہستہ اسے اپنی طرف سمیٹا\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmcmii{اور وہی ہے جس نے رات کو تمہارے لیے پردہ کیا اور نیند کو آرام اور دن بنایا اٹھنے کے لیے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmcmiii{اور وہی ہے جس نے ہوائیں بھیجیں اپنی رحمت کے آگے مژدہ سنائی ہوئی اور ہم نے آسمان سے پانی اتارا پاک کرنے والا،\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmcmiv{تاکہ ہم ا سسے زندہ کریں کسی مردہ شہر کو اور اسے پلائیں اپنے بنائے ہوئے بہت سے چوپائے اور آدمیوں کو،\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmcmv{اور بیشک ہم نے ان میں پانی کے پھیرے رکھے کہ وہ دھیان کریں تو بہت لوگوں نے نہ مانا مگر ناشکری کرنا،\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmcmvi{اور ہم چاہتے تو ہر بستی میں ایک ڈر سنانے والا بھیجتے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmcmvii{تو کافروں کا کہا نہ مان اور اس قرآن سے ان پر جہاد کر بڑا جہاد،\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmcmviii{اور وہی ہے جس نے ملے ہوئے رواں کیے دو سمندر یہ میٹھا ہے نہایت شیریں اور یہ کھاری ہے نہایت تلخ اور ان کے بیچ میں پردہ رکھا اور روکی ہوئی آڑ\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmcmix{اور وہی ہے جس نے پانی سے بنایا آدمی پھر اس کے رشتے اور سسرال مقرر کی اور تمہارا رب قدرت والا ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmcmx{اور اللہ کے سوا ایسوں کو پوجتے ہیں جو ان کا بھلا برا کچھ نہ کریں اور کافر اپنے رب کے مقابل شیطان کو مدد دیتا ہے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmcmxi{اور ہم نے تمہیں نہ بھیجا مگر خوشی اور ڈر سناتا،\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmcmxii{تم فرماؤ میں اس پر تم سے کچھ اجرت نہیں مانگتا مگر جو چاہے کہ اپنے رب کی طرف راہ لے،\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmcmxiii{اور بھروسہ کرو اس زندہ پر جو کبھی نہ مرے گا اور اسے سراہتے ہوئے اس کی پاکی بولو اور وہی کافی ہے اپنے بندوں کے گناہوں پر خبردار\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmcmxiv{جس نے آسمان اور زمین اور جو کچھ ان کے درمیان ہے چھ دن میں بنائے پھر عرش پر استواء فرمایا جیسا کہ اس کی شان کے لائق ہے وہ بڑی مہر والا تو کسی جاننے والے سے اس کی تعریف پوچھ\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmcmxv{اور جب ان سے کہا جائے رحمن کو سجدہ کرو کہتے ہیں رحمن کیا ہے، کیا ہم سجدہ کرلیں جسے تم کہو اور اس حکم نے انہیں اور بدکنا بڑھایا السجدة ۔۷\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmcmxvi{بڑی برکت والا ہے وہ جس نے آسمان میں برج بنائے اور ان میں چراغ رکھا اور چمکتا چاند،\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmcmxvii{اور وہی ہے جس نے رات اور دن کی بدلی رکھی اس کے لیے جو دھیان کرنا چاہے یا شکر کا ارادہ کرے،\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmcmxviii{اور رحمن کے وہ بندے کہ زمین پر آہستہ چلتے ہیں اور جب جاہل ان سے بات کرتے ہیں تو کہتے ہیں بس سلام\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmcmxix{اور وہ جو رات کاٹتے ہیں اپنے رب کے لیے سجدے اور قیام میں\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmcmxx{اور وہ جو عرض کرتے ہیں اے ہمارے رب! ہم سے پھیر دے جہنم کا عذاب، بیشک اس کا عذاب گلے کا غل (پھندا) ہے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmcmxxi{بیشک وہ بہت ہی بری ٹھہرنے کی جگہ ہے،\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmcmxxii{اور وہ کہ جب خرچ کرتے ہیں نہ حد سے بڑھیں اور نہ تنگی کریں اور ان دونوں کے بیچ اعتدال پر رہیں\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmcmxxiii{اور وہ جو اللہ کے ساتھ کسی دوسرے معبود کو نہیں پوجتے اور اس جان کو جس کی اللہ نے حرمت رکھی ناحق نہیں مارتے اور بدکاری نہیں کرتے اور جو یہ کام کرے وہ سزا پائے گا،\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmcmxxiv{بڑھایا جائے گا اس پر عذابِ قیامت کے دن اور ہمیشہ اس میں ذلت سے رہے گا،\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmcmxxv{مگر جو توبہ کرے اور ایمان لائے اور اچھا کام کرے اور اچھا کام کرے تو ایسوں کی برائیوں کو اللہ بھلائیوں سے بدل دے گا اور اللہ بخشنے والا مہربان ہے،\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmcmxxvi{اور جو توبہ کرے اور اچھا کام کرے تو وہ اللہ کی طرف رجوع لایا جیسی چاہیے تھی،\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmcmxxvii{اور جو جھوٹی گواہی نہیں دیتے اور جب بیہودہ پر گذرتے ہیں اپنی عزت سنبھالے گزر جاتے ہیں،\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmcmxxviii{اور وہ کہ جب کہ انہیں ان کے رب کی آیتیں یاد د لائی جائیں تو ان پر بہرے اندھے ہوکر نہیں گرتے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmcmxxix{اور وہ جو عرض کرتے ہیں، اے ہمارے رب! ہمیں دے ہماری بیبیوں اور اولاد سے آنکھوں کی ٹھنڈک اور ہمیں پرہیزگاروں کا پیشوا بنا\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmcmxxx{ان کو جنت کا سب سے اونچا بالا خانہ انعام ملے گا بدلہ ان کے صبر کا اور وہاں مجرے اور سلام کے ساتھ ان کی پیشوائی ہوگی\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmcmxxxi{ہمیشہ اس میں رہیں گے، کیا ہی اچھی ٹھہرنے اور بسنے کی جگہ،\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmcmxxxii{تم فرماؤ تمہاری کچھ قدر نہیں میرے رب کے یہاں اگر تم اسے نہ پوجو تو تم نے تو جھٹلایا تو اب ہوگا وہ عذاب کہ لپٹ رہے گا\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmcmxxxiii{\basmalahur طٰسم\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmcmxxxiv{یہ آیتیں ہیں روشن کتا ب کی\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmcmxxxv{کہیں تم اپنی جان پر کھیل جاؤ گے ان کے غم میں کہ وہ ایمان نہیں لائے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmcmxxxvi{اگر ہم چاہیں تو آسمان سے ان پر کوئی نشانی اتاریں کہ ان کے اونچے اونچے اس کے حضور جھکے رہ جائیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmcmxxxvii{اور نہیں آتی ان کے پاس رحمٰان کی طرف سے کوئی نئی نصیحت مگر اس سے منہ پھیر لیتے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmcmxxxviii{تو بیشک انہوں نے جھٹلایا تو اب ان پر آیا چاہتی ہیں خبریں ان کے ٹھٹھے کی\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmcmxxxix{کیا انہوں نے زمین کو نہ دیکھا ہم نے اس میں کتنے عزت والے جوڑے اگائے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmcmxl{بیشک اس میں ضرور نشانی ہے اور ان کے اکثر ایمان لانے والے نہیں،\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmcmxli{اور بیشک تمہارا رب ضرور وہی عزت والا مہربان ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmcmxlii{اور یاد کرو جب تمہارے رب نے موسیٰ کو ندا فرمائی کہ ظالم لوگوں کے پاس جا،\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmcmxliii{جو فرعون کی قوم ہے کیا وہ نہ ڈریں گے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmcmxliv{عرض کی کہ اے میرے رب میں ڈرتا ہوں کہ مجھے جھٹلا ئیں گے،\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmcmxlv{اور میرا سینہ تنگی کرتا ہے اور میری زبان نہیں چلتی تو توُ ہا رون کو بھی رسول کر،\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmcmxlvi{اور ان کا مجھ پر ایک الزام ہے تو میں ڈرتا ہو ں کہیں مجھے کر دیں،\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmcmxlvii{فرما یا یوں نہیں تم دو نوں میری آئتیں لے کر جا ؤ ہم تمھا رے ساتھ سنتے ہیں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmcmxlviii{تو فرعون کے پاس جاؤ پھر اس سے کہو ہم دونو ں اسکے رسل ہیں جو رب ہے سارے جہا ں کا،\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmcmxlix{کہ تو ہما رے ساتھ بنی اسرائیل کو چھوڑ دے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmcml{بو لا کیا ہم نے تمھیں اپنے یہاں بچپن میں نہ پالا اور تم نے ہما رے یہا ں اپنی عمر کے کئی برس گزارے، ف۲۰)\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmcmli{اور تم نے کیا اپنا وہ کام جو تم نے کیا اور تم نا شکر تھے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmcmlii{موسٰی نے فر ما یا میں نے وہ کام کیا جب کہ مجھے راہ کی خبر نہ تھی\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmcmliii{تو میں تمھا رے یہا ں سے نکل گیا جب کے تم سے ڈرا تو میرے رب نے مجھے حکم عطا فرمایا اور مجھے پیغمبروں سے کیا،\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmcmliv{اور یہ کوئی نعمت ہے جس کا تو مجھ پر احسان جتاتا ہے کہ تو نے غَلام بناکر رکھے بنی اسرائیل\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmcmlv{فرعون بولا اور سارے جہان کا رب کیا ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmcmlvi{موسیٰ نے فرمایا رب آسمانوں اور زمین کا اور جو کچھ ان کے درمیان میں ہے، اگر تمہیں یقین ہو\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmcmlvii{اپنے آس پاس والوں سے بولا کیا تم غور سے سنتے نہیں\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmcmlviii{موسیٰ نے فرمایا رب تمہارا اور تمہارے اگلے باپ داداؤں کا\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmcmlix{بولا تمہارے یہ رسول جو تمہاری طرف بھیجے گئے ہیں ضرور عقل نہیں رکھتے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmcmlx{موسیٰ نے فرمایا رب پورب (مشرق) اور پچھم (مغرب) کا اور جو کچھ ان کے درمیان ہے اگر تمہیں عقل ہو\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmcmlxi{بولا اگر تم نے میرے سوا کسی اور کو خدا ٹھہرایا تو میں ضرور تمہیں قید کردوں گا\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmcmlxii{فرمایا کیا اگرچہ میں تیرے پاس کوئی روشن چیز لاؤں\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmcmlxiii{کہا تو لاؤ اگر سچے ہو،\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmcmlxiv{تو موسیٰ نے اپنا عصا ڈال دیا جبھی وہ صریح اژدہا ہوگیا\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmcmlxv{اور اپنا ہاتھ نکالا تو جبھی وہ دیکھنے والوں کی نگاہ میں جگمگانے لگا\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmcmlxvi{بولا اپنے گرد کے سرداروں سے کہ بیشک یہ دانا جادوگر ہیں،\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmcmlxvii{چاہتے ہیں، کہ تمہیں تمہارے ملک سے نکال دیں اپنے جادو کے زور سے، تب تمہارا کیا مشورہ ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmcmlxviii{وہ بولے انہیں ان کے بھائی کو ٹھہرائے رہو اور شہروں میں جمع کرنے والے بھیجو،\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmcmlxix{کہ وہ تیرے پاس لے آئیں ہر بڑے جادوگر دانا کو\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmcmlxx{تو جمع کیے گئے جادوگر ایک مقرر دن کے وعدے پر\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxi{اور لوگوں سے کہا گیا کیا تم جمع ہوگئے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxii{شاید ہم ان جادوگروں ہی کی پیروی کریں اگر یہ غالب آئیں\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxiii{پھر جب جادوگر آئے فرعون سے بولے کیا ہمیں کچھ مزدوری ملے گی اگر ہم غالب آئے،\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxiv{بولا ہاں اور اس وقت تم میرے مقرب ہوجاؤ گے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxv{موسیٰ نے ان سے فرمایا ڈالو جو تمہیں ڈالنا ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxvi{تو انہوں نے اپنی رسیاں اور لاٹھیاں ڈالیں اور بولے فرعون کی عزت کی قسم بیشک ہماری ہی جیت ہے،\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxvii{تو موسیٰ نے اپنا عصا ڈالا جبھی وہ ان کی بناوٹوں کو نگلنے لگا\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxviii{اب سجدہ میں گرے،\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxix{جادوگر، بولے ہم ایمان لائے اس پر جو سارے جہان کا رب ہے،\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxx{جو موسیٰ اور ہارون کا رب ہے،\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxi{فرعون بولا کیا تم اس پر ایمان لائے قبل اس کے کہ میں تمہیں اجازت دوں، بیشک وہ تمہارا بڑا ہے جس نے تمہیں جادو سکھایا تو اب جاننا چاہتے ہو مجھے قسم ہے! بیشک میں تمہارے ہاتھ اور دوسری طرف کے پاؤں کاٹوں گا اور تم سب کو سولی دوں گا\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxii{وہ بولے کچھ نقصان نہیں ہم اپنے رب کی طرف پلٹنے والے ہیں\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxiii{ہمیں طمع ہے کہ ہمارا رب ہماری خطائیں بخش دے اس پر کہ سب سے پہلے ایمان لائے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxiv{اور ہم نے موسٰی کو وحی بھیجی کہ راتوں را ت میرے بندو ں کو لے نکل بیشک تمھارا پیچھا ہو نا ہے، ف۵۵)\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxv{اب فرعون نے شہروں میں جمع کرنے والے بھیجے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxvi{کہ یہ لوگ ایک تھوڑی جماعت ہیں،\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxvii{اور بیشک ہم سب کا دل جلاتے ہیں\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxviii{اور بیشک ہم سب چوکنے ہیں\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxix{تو ہم نے انہیں باہر نکالا باغوں اور چشموں،\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmcmxc{اور خزانوں اور عمدہ مکانوں سے،\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmcmxci{ہم نے ایسا ہی کیا اور ان کا وارث کردیا بنی اسرائیل کو\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmcmxcii{تو فرعونیوں نے ان کا تعاقب کیا دن نکلے،\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmcmxciii{پھر جب آمنا سامنا ہوا دونوں گروہوں کا موسیٰ والوں نے کہا ہم کو انہوں نے آلیا\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmcmxciv{موسیٰ نے فرمایا یوں نہیں بیشک میرا رب میرے ساتھ ہے وہ مجھے اب راہ دیتا ہے،\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmcmxcv{تو ہم نے موسیٰ کو وحی فرمائی کہ دریا پر اپنا عصا مار تو جبھی دریا پھٹ گیا تو ہر حصہ ہوگیا جیسے بڑا پہاڑ\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmcmxcvi{اور وہاں قریب لائے ہم دوسروں کو\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmcmxcvii{اور ہم نے بچالیا موسیٰ اور اس کے سب ساتھ والوں کو\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmcmxcviii{پھر دوسروں کو ڈبو دیا\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmcmxcix{بیشک اس میں ضرور نشانی ہے اور ان میں اکثر مسلمان نہ تھے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmm{اور بیشک تمہارا رب وہی عزت والا مہربان ہے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmi{اور ان پر پڑھو خبر ابراہیم کی\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmii{جب اس نے اپنے باپ اور اپنی قوم سے فرمایا تم کیا پوجتے ہو\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmiii{بولے ہم بتوں کو پوجتے ہیں پھر ان کے سامنے آسن مارے رہتے ہیں،\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmiv{فرمایا کیا وہ تمہاری سنتے ہیں جب تم پکارو،\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmv{یا تمہارا کچھ بھلا برا کرتے ہیں\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmvi{بولے بلکہ ہم نے اپنے باپ دادا کو ایسا ہی کرتے پایا،\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmvii{فرمایا تو کیا تم دیکھتے ہو یہ جنہیں پوج رہے ہو،\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmviii{تم اور تمہارے اگلے باپ دادا\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmix{بیشک وہ سب میرے دشمن ہیں مگر پروردگار عالم\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmx{وہ جس نے مجھے پیدا کیا تو وہ مجھے راہ دے گا\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmxi{اور وہ جو مجھے کھلاتا اور پلاتا ہے\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmmxii{اور جب میں بیمار ہوں تو وہی مجھے شفا دیتا ہے\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmmxiii{اور وہ مجھے وفات دے گا پھر مجھے زندہ کرے گا\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmmxiv{اور وہ جس کی مجھے آس لگی ہے کہ میری خطائیں قیامت کے دن بخشے گا\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmmxv{اے میرے رب مجھے حکم عطا کر اور مجھے ان سے ملادے جو تیرے قرب خاص کے سزاوار ہیں\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmmxvi{اور میری سچی ناموری رکھ پچھلوں میں\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmmxvii{اور مجھے ان میں کر جو چین کے باغوں کے وارث ہیں\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmmxviii{اور میرے باپ کو بخش دے بیشک وہ گمراہ،\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmmxix{اور مجھے رسوا نہ کرنا جس دن سب اٹھائے جائیں گے\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmmxx{جس دن نہ مال کام آئے گا نہ بیٹے،\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmmxxi{مگر وہ جو اللہ کے حضور حاضر ہوا سلامت دل لے کر\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmmxxii{اور قریب لائی جائے گی جنت پرہیزگاروں کے لیے\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmmxxiii{اور ظاہر کی جائے گی دوزخ گمراہوں کے لیے،\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmmxxiv{اور ان سے کہا جائے گا کہاں ہیں وہ جن کو تم پوجتے تھے،\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmmxxv{اللہ کے سوا، کیا وہ تمہاری مدد کریں گے یا بدلہ لیں گے،\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmmxxvi{تو اوندھا دیے گئے جہنم میں وہ اور سب گمراہ\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mmmxxvii{اور ابلیس کے لشکر سارے\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mmmxxviii{کہیں گے اور وہ اس میں باہم جھگڑے ہوں گے،\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mmmxxix{خدا کی قسم بیشک ہم کھلی گمراہی میں تھے،\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mmmxxx{جبکہ انہیں رب العالمین کے برابر ٹھہراتے تھے،\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mmmxxxi{اور ہمیں نہ بہکایا مگر مجرموں نے\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mmmxxxii{تو اب ہمارا کوئی سفارشی نہیں\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mmmxxxiii{اور نہ کوئی غم خوار دوست\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mmmxxxiv{تو کسی طرح ہمیں پھر جانا ہوتا کہ ہم مسلمان ہوجاتے،\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mmmxxxv{بیشک اس میں ضرور نشانی ہے، اور ان میں بہت ایمان والے نہ تھے،\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mmmxxxvi{اور بیشک تمہارا رب وہی عزت والا مہربان ہے،\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mmmxxxvii{نوح کی قوم نے پیغمبروں کو جھٹلایا\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mmmxxxviii{جبکہ ان سے ان کے ہم قوم نوح نے کہا کیا تم ڈرتے نہیں\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mmmxxxix{بیشک میں تمہارے لیے اللہ کا بھیجا ہوا امین ہوں\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mmmxl{تو اللہ سے ڈرو اور میرا حکم مانو\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mmmxli{اور میں اس پر تم سے کچھ اجرت نہیں مانگتا میرا اجر تو اسی پر ہے جو سارے جہان کا رب ہے،\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mmmxlii{تو اللہ سے ڈرو اور میرا حکم مانو،\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mmmxliii{بولے کیا ہم تم پر ایمان لے آئیں اور تمہارے ساتھ کمینے ہو ےٴ ہیں\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mmmxliv{فرمایا مجھے کیا خبر ان کے کام کیا ہیں\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@mmmxlv{ان کا حساب تو میرے رب ہی پر ہے اگر تمہیں حِس ہو\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@mmmxlvi{اور میں مسلمانوں کو دور کرنے والا نہیں\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@mmmxlvii{میں تو نہیں مگر صاف ڈر سنانے والا\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@mmmxlviii{بولے اے نوح! اگر تم باز نہ آئے تو ضرور سنگسار کیے جاؤ گے\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@mmmxlix{عرض کی اے میرے رب میری قوم نے مجھے جھٹلایا\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@mmml{تو مجھ میں اور ان میں پورا فیصلہ کردے اور مجھے اور میرے ساتھ والے مسلمانوں کو نجات دے\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@mmmli{تو ہم نے بچالیا اسے اور اس کے ساتھ والوں کو بھری ہوئی کشتی میں\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@mmmlii{پھر اس کے بعد ہم نے باقیوں کو ڈبو دیا،\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@mmmliii{بیشک اس میں ضرور نشانی ہے، اور ان میں اکثر مسلمان نہ تھے،\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@mmmliv{اور بیشک تمہارا رب ہی عزت والا مہربان ہے،\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@mmmlv{عاد نے رسولوں کو جھٹلایا\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@mmmlvi{جبکہ ان سے ان کے ہم قوم ہود نے فرمایا کیا تم ڈرتے نہیں،\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@mmmlvii{بیشک میں تمہارے لیے امانتدار رسول ہوں،\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@mmmlviii{تو اللہ سے ڈرو اور میرا حکم مانو،\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@mmmlix{اور میں تم سے اس پر کچھ اجرت نہیں مانگتا، میرا اجر تو اسی پر ہے جو سارے جہان کا رب،\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@mmmlx{کیا ہر بلندی پر ایک نشان بناتے ہو راہ گیروں سے ہنسنے کو\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@mmmlxi{اور مضبوط محل چنتے ہو اس امید پر کہ تم ہمیشہ رہوگے\qt@no{(129)}}%
\qt@newcmd\qurantrans@ur@mmmlxii{اور جب کسی پر گرفت کرتے ہو تو بڑی بیدردی سے گرفت کرتے ہو\qt@no{(130)}}%
\qt@newcmd\qurantrans@ur@mmmlxiii{تو اللہ سے ڈرو اور میرا حکم مانو،\qt@no{(131)}}%
\qt@newcmd\qurantrans@ur@mmmlxiv{اور اس سے ڈرو جس نے تمہاری مدد کی ان چیزوں سے کہ تمہیں معلوم ہیں\qt@no{(132)}}%
\qt@newcmd\qurantrans@ur@mmmlxv{تمہاری مدد کی چوپایوں اور بیٹوں،\qt@no{(133)}}%
\qt@newcmd\qurantrans@ur@mmmlxvi{اور باغوں اور چشموں سے،\qt@no{(134)}}%
\qt@newcmd\qurantrans@ur@mmmlxvii{بیشک مجھے تم پر ڈر ہے ایک بڑے دن کے عذاب کا\qt@no{(135)}}%
\qt@newcmd\qurantrans@ur@mmmlxviii{بولے ہمیں برابر ہے چاہے تم نصیحت کرو یا ناصحوں میں نہ ہو\qt@no{(136)}}%
\qt@newcmd\qurantrans@ur@mmmlxix{یہ تو نہیں مگر وہی اگلوں کی ریت\qt@no{(137)}}%
\qt@newcmd\qurantrans@ur@mmmlxx{اور ہمیں عذاب ہونا نہیں\qt@no{(138)}}%
\qt@newcmd\qurantrans@ur@mmmlxxi{تو انہوں نے اسے جھٹلایا تو ہم نے انہیں بلاک کیا بیشک اس میں ضرور نشانی ہے، اور ان میں بہت مسلمان نہ تھے،\qt@no{(139)}}%
\qt@newcmd\qurantrans@ur@mmmlxxii{اور بیشک تمہارا رب ہی عزت والا مہربان ہے،\qt@no{(140)}}%
\qt@newcmd\qurantrans@ur@mmmlxxiii{ثمود نے رسولوں کو جھٹلایا،\qt@no{(141)}}%
\qt@newcmd\qurantrans@ur@mmmlxxiv{جبکہ ان سے ان کے ہم قوم صا لح نے فرمایا کیا ڈرتے نہیں،\qt@no{(142)}}%
\qt@newcmd\qurantrans@ur@mmmlxxv{بیشک میں تمہارے لیے اللہ کا امانتدار رسول ہوں،\qt@no{(143)}}%
\qt@newcmd\qurantrans@ur@mmmlxxvi{تو اللہ سے ڈرو اور میرا حکم مانو،\qt@no{(144)}}%
\qt@newcmd\qurantrans@ur@mmmlxxvii{اور میں تم سے کچھ اس پر اجرت نہیں مانگتا، میرا اجر تو اسی پر ہے جو سارے جہان کا رب ہے،\qt@no{(145)}}%
\qt@newcmd\qurantrans@ur@mmmlxxviii{کیا تم یہاں کی نعمتوں میں چین سے چھوڑ دیے جاؤ گے\qt@no{(146)}}%
\qt@newcmd\qurantrans@ur@mmmlxxix{باغوں اور چشموں،\qt@no{(147)}}%
\qt@newcmd\qurantrans@ur@mmmlxxx{اور کھیتوں اور کھجوروں میں جن کا شگوفہ نرم نازک،\qt@no{(148)}}%
\qt@newcmd\qurantrans@ur@mmmlxxxi{اور پہاڑوں میں سے گھر تراشتے ہو استادی سے\qt@no{(149)}}%
\qt@newcmd\qurantrans@ur@mmmlxxxii{تو اللہ سے ڈرو اور میرا حکم مانو،\qt@no{(150)}}%
\qt@newcmd\qurantrans@ur@mmmlxxxiii{اور حد سے بڑھنے والوں کے کہنے پر نہ چلو\qt@no{(151)}}%
\qt@newcmd\qurantrans@ur@mmmlxxxiv{وہ جو زمین میں فساد پھیلاتے ہیں اور بناؤ نہیں کرتے\qt@no{(152)}}%
\qt@newcmd\qurantrans@ur@mmmlxxxv{بولے تم پر تو جادو ہوا ہے\qt@no{(153)}}%
\qt@newcmd\qurantrans@ur@mmmlxxxvi{تم تو ہمیں جیسے آدمی ہو، تو کوئی نشانی لاؤ اگر سچے ہو\qt@no{(154)}}%
\qt@newcmd\qurantrans@ur@mmmlxxxvii{فرمایا یہ ناقہ ہے ایک دن اس کے پینے کی باری اور ایک معین دن تمہاری باری،\qt@no{(155)}}%
\qt@newcmd\qurantrans@ur@mmmlxxxviii{اور اسے برائی کے ساتھ نہ چھوؤ کہ تمہیں بڑے دن کا عذاب آلے گا\qt@no{(156)}}%
\qt@newcmd\qurantrans@ur@mmmlxxxix{اس پر انہوں نے اس کی کونچیں کاٹ دیں پھر صبح کو پچھتاتے رہ گئے\qt@no{(157)}}%
\qt@newcmd\qurantrans@ur@mmmxc{تو انہیں عذاب نے آلیا بیشک اس میں ضرور نشانی ہے، اور ان میں بہت مسلمان نہ تھے،\qt@no{(158)}}%
\qt@newcmd\qurantrans@ur@mmmxci{اور بیشک تمہارا رب ہی عزت والا مہربان ہے،\qt@no{(159)}}%
\qt@newcmd\qurantrans@ur@mmmxcii{لوط کی قوم نے رسولوں کو جھٹلایا،\qt@no{(160)}}%
\qt@newcmd\qurantrans@ur@mmmxciii{جب کہ ان سے ان کے ہم قوم لوط نے فرمایا کیا تم نہیں ڈرتے،\qt@no{(161)}}%
\qt@newcmd\qurantrans@ur@mmmxciv{بیشک میں تمہارے لیے اللہ کا امانتدار رسول ہوں،\qt@no{(162)}}%
\qt@newcmd\qurantrans@ur@mmmxcv{تو اللہ سے ڈرو اور میرا حکم مانو،\qt@no{(163)}}%
\qt@newcmd\qurantrans@ur@mmmxcvi{اور میں اس پر تم سے کچھ اجرت نہیں مانگتا میرا اجر تو اسی پر ہے جو سارے جان کا رب ہے،\qt@no{(164)}}%
\qt@newcmd\qurantrans@ur@mmmxcvii{کیا مخلوق میں مردوں سے بدفعلی کرتے ہو\qt@no{(165)}}%
\qt@newcmd\qurantrans@ur@mmmxcviii{اور چھوڑتے ہو وہ جو تمہارے لیے تمہارے رب نے جوروئیں بنائیں، بلکہ تم لوگ حد سے بڑھنے والے ہو\qt@no{(166)}}%
\qt@newcmd\qurantrans@ur@mmmxcix{بولے اے لوط! اگر تم باز نہ آئے تو ضرور نکال دیے جاؤ گے\qt@no{(167)}}%
\qt@newcmd\qurantrans@ur@mmmc{فرمایا میں تمہارے کام سے بیزار ہوں\qt@no{(168)}}%
\qt@newcmd\qurantrans@ur@mmmci{اے میرے رب! مجھے اور میرے گھر والوں کو ان کے کام سے بچا\qt@no{(169)}}%
\qt@newcmd\qurantrans@ur@mmmcii{تو ہم نے اسے اور اس کے سب گھر والوں کو نجات بخشی\qt@no{(170)}}%
\qt@newcmd\qurantrans@ur@mmmciii{مگر ایک بڑھیا کہ پیچھے رہ گئی\qt@no{(171)}}%
\qt@newcmd\qurantrans@ur@mmmciv{پھر ہم نے دوسروں کو ہلاک کردیا،\qt@no{(172)}}%
\qt@newcmd\qurantrans@ur@mmmcv{اور ہم نے ان پر ایک برساؤ برسایا تو کیا ہی برا برساؤ تھا ڈرائے گئیوں کا،\qt@no{(173)}}%
\qt@newcmd\qurantrans@ur@mmmcvi{بیشک اس میں ضرور نشانی ہے، اور ان میں بہت مسلمان نہ تھے،\qt@no{(174)}}%
\qt@newcmd\qurantrans@ur@mmmcvii{اور بیشک تمہارا رب ہی عزت والا مہربان ہے،\qt@no{(175)}}%
\qt@newcmd\qurantrans@ur@mmmcviii{بن والوں نے رسولوں کو جھٹلایا\qt@no{(176)}}%
\qt@newcmd\qurantrans@ur@mmmcix{جب ان سے شعیب نے فرمایا کیا ڈرتے نہیں،\qt@no{(177)}}%
\qt@newcmd\qurantrans@ur@mmmcx{بیشک میں تمہارے لیے اللہ کا امانتدار رسول ہوں،\qt@no{(178)}}%
\qt@newcmd\qurantrans@ur@mmmcxi{تو اللہ سے ڈرو اور میرا حکم مانو،\qt@no{(179)}}%
\qt@newcmd\qurantrans@ur@mmmcxii{اور میں اس پر تم سے کچھ اجرت نہیں مانگتا میرا اجر تو اسی پر ہے جو سارے جہان کا رب ہے\qt@no{(180)}}%
\qt@newcmd\qurantrans@ur@mmmcxiii{ناپ پورا کرو اور گھٹانے والوں میں نہ ہو\qt@no{(181)}}%
\qt@newcmd\qurantrans@ur@mmmcxiv{اور سیدھی ترازو سے تولو،\qt@no{(182)}}%
\qt@newcmd\qurantrans@ur@mmmcxv{اور لوگوں کی چیزیں کم کرکے نہ دو اور زمین میں فساد پھیلاتے نہ پھرو\qt@no{(183)}}%
\qt@newcmd\qurantrans@ur@mmmcxvi{اور اس سے ڈرو جس نے تم کو پیدا کیا اور اگلی مخلوق کو،\qt@no{(184)}}%
\qt@newcmd\qurantrans@ur@mmmcxvii{بولے تم پر جادو ہوا ہے،\qt@no{(185)}}%
\qt@newcmd\qurantrans@ur@mmmcxviii{تم تو نہیں مگر ہم جیسے آدمی اور بیشک ہم تمہیں جھوٹا سمجھتے ہیں،\qt@no{(186)}}%
\qt@newcmd\qurantrans@ur@mmmcxix{تو ہم پر آسمان کا کوئی ٹکڑا گرا دو اگر تم سچے ہو\qt@no{(187)}}%
\qt@newcmd\qurantrans@ur@mmmcxx{فرمایا میرا رب خوب جانتا ہے جو تمہارے کوتک (کرتوت) ہیں\qt@no{(188)}}%
\qt@newcmd\qurantrans@ur@mmmcxxi{تو انہوں نے اسے جھٹلایا تو انہیں شامیانے والے دن کے عذاب نے آلیا، بیشک وہ بڑے دن کا عذاب تھا\qt@no{(189)}}%
\qt@newcmd\qurantrans@ur@mmmcxxii{بیشک اس میں ضرور نشانی ہے، اور ان میں بہت مسلمان نہ تھے،\qt@no{(190)}}%
\qt@newcmd\qurantrans@ur@mmmcxxiii{اور بیشک تمہارار ب ہی عزت والا مہربان ہے،\qt@no{(191)}}%
\qt@newcmd\qurantrans@ur@mmmcxxiv{اور بیشک یہ قرآن رب العالمین کا اتارا ہوا ہے،\qt@no{(192)}}%
\qt@newcmd\qurantrans@ur@mmmcxxv{اسے روح الا مین لے کر اترا\qt@no{(193)}}%
\qt@newcmd\qurantrans@ur@mmmcxxvi{تمہارے دل پر کہ تم ڈر سناؤ،\qt@no{(194)}}%
\qt@newcmd\qurantrans@ur@mmmcxxvii{روشن عربی زبان میں،\qt@no{(195)}}%
\qt@newcmd\qurantrans@ur@mmmcxxviii{اور بیشک اس کا چرچا اگلی کتابوں میں ہے\qt@no{(196)}}%
\qt@newcmd\qurantrans@ur@mmmcxxix{اور کیا یہ ان کے لیے نشانی نہ تھی کہ اس نبی کو جانتے ہیں بنی اسرائیل کے عالم\qt@no{(197)}}%
\qt@newcmd\qurantrans@ur@mmmcxxx{اور اگر ہم اسے کسی غیر عربی شخص پر اتارتے،\qt@no{(198)}}%
\qt@newcmd\qurantrans@ur@mmmcxxxi{کہ وہ انہیں پڑھ کر سناتا جب بھی اس پر ایمان نہ لاتے\qt@no{(199)}}%
\qt@newcmd\qurantrans@ur@mmmcxxxii{ہم نے یونہی جھٹلانا پیرا دیا ہے مجرموں کے دلوں میں\qt@no{(200)}}%
\qt@newcmd\qurantrans@ur@mmmcxxxiii{وہ اس پر ایمان نہ لائیں گے یہاں تک کہ دیکھیں دردناک عذاب،\qt@no{(201)}}%
\qt@newcmd\qurantrans@ur@mmmcxxxiv{تو وہ اچانک ان پر آجائے گا اور انہیں خبر نہ ہوگی،\qt@no{(202)}}%
\qt@newcmd\qurantrans@ur@mmmcxxxv{تو کہیں گے کیا ہمیں کچھ مہلت ملے گی\qt@no{(203)}}%
\qt@newcmd\qurantrans@ur@mmmcxxxvi{تو کیا ہمارے عذاب کی جلدی کرتے ہیں،\qt@no{(204)}}%
\qt@newcmd\qurantrans@ur@mmmcxxxvii{بھلا دیکھو تو اگر کچھ برس ہم انہیں برتنے دیں\qt@no{(205)}}%
\qt@newcmd\qurantrans@ur@mmmcxxxviii{پھر آئے ان پر جس کا وہ وعدہ دیے جاتے ہیں\qt@no{(206)}}%
\qt@newcmd\qurantrans@ur@mmmcxxxix{تو کیا کام آئے گا ان کے وہ جو برتتے تھے\qt@no{(207)}}%
\qt@newcmd\qurantrans@ur@mmmcxl{اور ہم نے کوئی بستی ہلاک نہ کی جسے ڈر سنانے والے نہ ہوں،\qt@no{(208)}}%
\qt@newcmd\qurantrans@ur@mmmcxli{نصیحت کے لیے، اور ہم ظلم نہیں کرتے\qt@no{(209)}}%
\qt@newcmd\qurantrans@ur@mmmcxlii{او راس قرآن کو لے کر شیطان نہ اترے\qt@no{(210)}}%
\qt@newcmd\qurantrans@ur@mmmcxliii{اور وہ اس قابل نہیں اور نہ وہ ایسا کرسکتے ہیں\qt@no{(211)}}%
\qt@newcmd\qurantrans@ur@mmmcxliv{وہ تو سننے کی جگہ سے دور کردیے گئے ہیں\qt@no{(212)}}%
\qt@newcmd\qurantrans@ur@mmmcxlv{تو اللہ کے سوا دوسرا خدا نہ پوج کہ تجھ پر عذاب ہوگا،\qt@no{(213)}}%
\qt@newcmd\qurantrans@ur@mmmcxlvi{اور اے محبوب! اپنے قریب تر رشتہ داروں کو ڈراؤ\qt@no{(214)}}%
\qt@newcmd\qurantrans@ur@mmmcxlvii{اور اپنی رحمت کا بازو بچھاؤ اپنے پیرو مسلمانوں کے لیے\qt@no{(215)}}%
\qt@newcmd\qurantrans@ur@mmmcxlviii{تو اگر وہ تمہارا حکم نہ مانیں تو فرمادو میں تمہارے کاموں سے بے علاقہ ہوں،\qt@no{(216)}}%
\qt@newcmd\qurantrans@ur@mmmcxlix{اور اس پر بھروسہ کرو جو عزت والا مہر والا ہے\qt@no{(217)}}%
\qt@newcmd\qurantrans@ur@mmmcl{جو تمہیں دیکھتا ہے جب تم کھڑے ہوتے ہو\qt@no{(218)}}%
\qt@newcmd\qurantrans@ur@mmmcli{اور نمازیوں میں تمہارے دورے کو\qt@no{(219)}}%
\qt@newcmd\qurantrans@ur@mmmclii{بیشک وہی سنتا جانتا ہے\qt@no{(220)}}%
\qt@newcmd\qurantrans@ur@mmmcliii{کیا میں تمہیں بتادوں کہ کس پر اترتے ہیں شیطان،\qt@no{(221)}}%
\qt@newcmd\qurantrans@ur@mmmcliv{اترتے ہیں بڑے بہتان والے گناہگار پر\qt@no{(222)}}%
\qt@newcmd\qurantrans@ur@mmmclv{شیطان اپنی سنی ہوئی ان پر ڈالتے ہیں اور ان میں اکثر جھوٹے ہیں\qt@no{(223)}}%
\qt@newcmd\qurantrans@ur@mmmclvi{اور شاعروں کی پیرو ی گمراہ کرتے ہیں\qt@no{(224)}}%
\qt@newcmd\qurantrans@ur@mmmclvii{کیا تم نے نہ دیکھا کہ وہ ہر نالے میں سرگرداں پھرتے ہیں\qt@no{(225)}}%
\qt@newcmd\qurantrans@ur@mmmclviii{اور وہ کہتے ہیں جو نہیں کرتے\qt@no{(226)}}%
\qt@newcmd\qurantrans@ur@mmmclix{مگر وہ جو ایمان لائے اور اچھے کام کیے اور بکثرت اللہ کی یاد کی اور بدلہ لیا بعد اس کے کہ ان پر ظلم ہوا اور اب جاننا چاہتے ہیں ظالم کہ کس کروٹ پر پلٹا کھائیں گے\qt@no{(227)}}%
\qt@newcmd\qurantrans@ur@mmmclx{\basmalahur یہ آیتیں ہیں قرآن اور روشن کتاب کی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmclxi{ہدایت اور خوشخبری ایمان والوں کو،\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmclxii{وہ جو نماز برپا رکھتے ہیں اور زکوٰة دیتے ہیں اور وہ آخرت پر یقین رکھتے ہیں،\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmclxiii{وہ جو آخرت پر ایمان نہیں لاتے ہم نے ان کے کوتک (برے اعمال) ان کی نگاہ میں بھلے کر دکھائے ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmclxiv{تو وہ بھٹک رہے ہیں یہ وہ ہیں جن کے لیے برا عذاب ہے اور یہی آخرت میں سب سے بڑھ کر نقصان میں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmclxv{اور بیشک تم قرآن سکھائے جاتے اور حکمت والے علم والے کی طرف سے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmclxvi{جب کہ موسیٰ نے اپنی گھر والی سے کہا مجھے ایک آگ نظر پڑی ہے عنقریب میں تمہارے پاس اس کی کوئی خبر لاتا ہوں یا اس میں سے کوئی چمکتی چنگاری لاؤں گا کہ تم تاپو\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmclxvii{پھر جب آگ کے پاس آیا ندا کی گئی کہ برکت دیا گیا وہ جو اس آگ کی جلوہ گاہ میں ہے یعنی موسیٰ اور جو اس کے آس پاس میں یعنی فرشتے اور پاکی ہے اللہ کو جو رب ہے سارے جہان کا،\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmclxviii{اے موسیٰ بات یہ ہے کہ میں ہی ہوں اللہ عزت والا حکمت والا،\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmclxix{اور اپنا عصا ڈال دے پھر موسیٰ نے اسے دیکھا لہراتا ہوا گویا سانپ ہے پیٹھ پھیر کر چلا اور مڑ کر نہ دیکھا، ہم نے فرمایا اے موسیٰ ڈر نہیں، بیشک میرے حضور رسولوں کو خوف نہیں ہوتا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmclxx{ہاں جو کوئی ز یادتی کرے پھر برائی کے بعد بھلائی سے بدلے تو بیشک میں بخشنے والا مہربان ہوں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmclxxi{اور اپنا ہاتھ اپنے گریبان میں ڈال نکلے گا سفید چمکتا بے عیب نو نشانیوں میں فرعون اور اس کی قوم کی طرف، بیشک وہ بے حکم لوگ ہیں،\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmclxxii{پھر جب ہماری نشانیاں آنکھیں کھولتی ان کے پاس آئیں بولے یہ تو صریح جادو ہے،\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmclxxiii{اور ان کے منکر ہوئے اور ان کے دلوں میں ان کا یقین تھا ظلم اور تکبر سے تو دیکھو کیسا انجام ہوا فسادیوں کا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmclxxiv{اور بیشک ہم نے داؤد اور سلیمان کو بڑا علم عطا فرمایا اور دونوں نے کہا سب خوبیاں اللہ کو جس نے ہمیں اپنے بہت سے ایمان والے بندوں پر فضیلت بخشی\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmclxxv{اور سلیمان داؤد کا جانشین ہوا اور کہا اے لوگو! ہمیں پرندوں کی بولی سکھائی گئی اور ہر چیز میں سے ہم کو عطا ہوا بیشک یہی ظاہر فضل ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmclxxvi{اور جمع کیے گئے سلیمان کے لیے اس کے لشکر جنوں اور آدمیوں اور پرندوں سے تو وہ روکے جاتے تھے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmclxxvii{یہاں تک کہ جب چیونٹیوں کے نالے پر آئے ایک چیونٹی بولی اے چیونٹیو! اپنے گھروں میں چلی جاؤ تمہیں کچل نہ ڈالیں سلیمان اور ان کے لشکر بے خبری میں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmclxxviii{تو اس کی بات مسکرا کر ہنسا اور عرض کی اے میرے رب! مجھے توفیق دے کہ میں شکر کروں تیرے احسان کا جو تو نے مجھ پر اور میرے ماں باپ پر کیے اور یہ کہ میں وہ بھلا کام کرو ں جو تجھے پسند آئے اور مجھے اپنی رحمت سے اپنے ان بندوں میں شامل کر جو تیرے قرب خاص کے سزاوار ہیں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmclxxix{اور پرندوں کا جائزہ لیا تو بولا مجھے کیا ہوا کہ میں ہد ہد کو نہیں دیکھتا یا وہ واقعی حاضر نہیں،\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmclxxx{ضرور میں اسے سخت عذاب کرو ں گا یا ذبح کردوں گا یا کوئی روشن سند میرے پاس لائے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmclxxxi{تو ہد ہد کچھ زیادہ دیر نہ ٹھہرا اور آکر عرض کی کہ میں وہ بات دیکھ کر آیا ہوں جو حضور نے نہ دیکھی اور میں شہر سبا سے حضور کے پاس ایک یقینی خبر لایا ہوں،\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmclxxxii{میں نے ایک عورت دیکھی کہ ان پر بادشاہی کررہی ہے اور اسے ہر چیز میں سے ملا ہے اور اس کا بڑا تخت ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmclxxxiii{میں نے اسے اور اس کی قوم کو پایا کہ اللہ کو چھوڑ کر سورج کو سجدہ کرتے ہیں اور شیطان نے ان کے اعمانل ان کی نگاہ میں سنوار کر ان کو سیدھی راہ سے روک دیا تو وہ راہ نہیں پاتے،\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmclxxxiv{کیوں نہیں سجدہ کرتے اللہ کو جو نکالتا ہے آسمانوں اور زمین کی چھپی چیزیں اور جانتا ہے جو کچھ تم چھپاتے ہو اور ظاہر کرتے ہو\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmclxxxv{اللہ ہے کہ اس کے سوا کوئی سچا معبود نہیں وہ بڑے عرش کا مالک ہے، السجد ة۔۸)\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmclxxxvi{سلیمان نے فرمایا اب ہم دیکھیں گے کہ تو نے سچ کہا یا تو جھوٹوں میں ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmclxxxvii{میرا یہ فرمان لے جان کر ان پر ڈال پھر ان سے الگ ہٹ کر دیکھ کہ وہ کیا جواب دیتے ہیں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmclxxxviii{وہ عورت بولی اے سردارو! بیشک میری طرف ایک عزت والا خط ڈالا گیا\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmclxxxix{بیشک وہ سلیمان کی طرف سے ہے اور بیشک وہ اللہ کے نام سے ہے نہایت مہربان رحم والا،\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmcxc{یہ کہ مجھ پر بلندی نہ چاہو اور گردن رکھتے میرے حضور حاضر ہو\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmcxci{بولی اے سردارو! میرے اس معاملے میں مجھے رائے دو میں کسی معاملے میں کوئی قطعی فیصلہ نہیں کرتی جب تک تم میرے پاس حاضر نہ ہو،\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmcxcii{وہ بولے ہم زور والے اور بڑی سخت لڑائی والے ہیں اور اختیار تیرا ہے تو نظر کر کہ کیا حکم دیتی ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmcxciii{بولی بیشک بادشاہ جب کسی بستی میں داخل ہوتے ہیں اسے تباہ کردیتے ہیں اور اس کے عزت والوں کو ذلیل اور ایسا ہی کرتے ہیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmcxciv{اور میں ان کی طرف ایک تحفہ بھیجنے والی ہوں پھر دیکھوں گی کہ ایلچی کیا جواب لے کر پلٹے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmcxcv{پھر جب وہ سلیمان کے پاس آیا فرمایا کیا مال سے میری مدد کرتے ہو تو جو مجھے اللہ نے دیا وہ بہتر ہے اس سے جو تمہیں دیا بلکہ تمہیں اپنے تحفہ پر خوش ہوتے ہو\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmcxcvi{پلٹ جا ان کی طرف تو ضرور ہم ان پر وہ لشکر لائیں گے جن کی انہیں طاقت نہ ہوگی اور ضرور ہم ان کو اس شہر سے ذلیل کرکے نکال دیں گے یوں کہ وہ پست ہوں گے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmcxcvii{سلیمان نے فرمایا، اے درباریو! تم میں کون ہے کہ وہ اس کا تخت میرے پاس لے آئے قبل اس کے کہ وہ میرے حضور مطیع ہوکر حاضر ہوں\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmcxcviii{ایک بڑا خبیث جن بولا کہ میں وہ تخت حضور میں حاضر کردوں گا قبل اس کے کہ حضور اجلاس برخاست کریں اور میں بیشک اس پر قوت والا امانتدار ہوں\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmcxcix{اس نے عرض کی جس کے پاس کتاب کا علم تھا کہ میں اسے حضور میں حاضر کردوں گا ایک پل مارنے سے پہلے پھر جب سلیمان نے تخت کو اپنے پاس رکھا دیکھا کہ یہ میرے رب کے فضل سے ہے، تاکہ مجھے آزمائے کہ میں شکر کرتا ہوں یا ناشکری، اور جو شکر کرے وہ اپنے بھلے کو شکر کرتا ہے اور جو ناشکری کرے تو میرا رب بے پرواہ ہے سب خوبیوں والا،\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmcc{سلیمان نے حکم دیا عورت کا تخت اس کے سامنے وضع بدل کر بیگانہ کردو کہ ہم دیکھیں کہ وہ راہ پاتی ہے یا ان میں ہوتی ہے جو ناواقف رہے،\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmcci{پھر جب وہ آئی اس سے کہا گیا کیا تیرا تخت ایسا ہی ہے، بولی گویا یہ وہی ہے اور ہم کو اس واقعہ سے پہلے خبر مل چکی اور ہم فرمانبردار ہوئے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmccii{اور اسے روکا اس چیز نے جسے وہ اللہ کے سوا پوجتی تھی، بیشک وہ کافر لوگوں میں سے تھی،\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmcciii{اس سے کہا گیا صحن میں آ پھر جب اس نے اسے دیکھا گہرا پانی سمجھی اور اپنی ساقیں کھولیں سلیمان نے فرمایا یہ تو ایک چکنا صحن ہے شیشوں جڑا عورت نے عرض کی اے میرے رب! میں نے اپنی جان پر ظلم کیا اور اب سلیمانے کے ساتھ اللہ کے حضور گردن رکھتی ہوں جو رب سارے جہان کا\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmcciv{اور بیشک ہم نے ثمود کی طرف ان کے ہم قوم صالح کو بھیجا کہ اللہ کو پوجو تو جبھی وہ دو گروہ ہوگئے جھگڑا کرتے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmccv{صا لح نے فرمایا اے میری قوم! کیوں برائی کی جلدی کرتے ہو بھلائی سے پہلے اللہ سے بخشش کیوں نہیں مانگتے شاید تم پر رحم ہو\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmccvi{بولے ہم نے برُا شگون کیا تم سے اور تمہارے ساتھیوں سے فرمایا تمہاری بدشگونی اللہ کے پاس ہے بلکہ تم لوگ فتنے میں پڑے ہو\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmccvii{اور شہر میں نو شخص تھے کہ زمین میں فساد کرتے اور سنوار نہ چاہتے،\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmccviii{آپس میں اللہ کی قسمیں کھا کر بولے ہم ضرور رات کو چھاپا ماریں گے صا لح اور اس کے گھر والوں پر پھر اس کے وارث سے کہیں گے اس گھر والوں کے قتل کے وقت ہم حاضر نہ تھے اور بیشک ہم سچے ہیں،\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmccix{او رانہوں نے اپنا سا مکر کیا اور ہم نے اپنی خفیہ تدبیر فرمائی اور وہ غافل رہے،\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmccx{تو دیکھو کیسا انجام ہوا ان کے مکر کا ہم نے ہلاک کردیا انہیں اور ان کی ساری قوم کو\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmccxi{تو یہ ہیں ان کے گھر ڈھے پڑے بدلہ ان کے ظلم کا، بیشک اس میں نشانی ہے جاننے والوں کے لیے،\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmccxii{اور ہم نے ان کو بچالیا جو ایمان لائے اور ڈرتے تھے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmccxiii{اور لوط کو جب اس نے اپنی قوم سے کہا کیا بے حیائی پر آتے ہو اور تم سوجھ رہے ہو\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmccxiv{کیا تم مردوں کے پاس مستی سے جاتے ہو عورتیں چھوڑ کر بلکہ تم جاہل لوگ ہو\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmccxv{تو اس کی قوم کا کچھ جواب نہ تھا مگر یہ کہ بولے لوط کے گھرانے کو اپنی بستی سے نکال دو یہ لوگ تو ستھراپن چاہتے ہیں\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmccxvi{تو ہم نے اسے اور اس کے گھر والوں کو نجات دی مگر اس کی عورت کو ہم نے ٹھہرادیا تھا کہ وہ رہ جانے والوں میں ہے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmccxvii{اور ہم نے ان پر ایک برساؤ برسایا تو کیا ہی برا برساؤ تھا ڈرا ئے ہوؤں کا،\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmccxviii{تم کہو سب خوبیاں اللہ کو اور سلام اس کے چنے ہوئے بندے پر کیا اللہ بہتر یا ان کے ساختہ شریک\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmccxix{ا وہ جس نے آسمان و زمین بنائے اور تمہارے لیے آسمان سے پانی اتارا تو ہم نے اس سے باغ اگائے رونق والے تمہاری طاقت نہ تھی کہ ان کے پیڑ اگاتے کیا اللہ کے ساتھ کوئی اور خدا ہے بلکہ وہ لوگ راہ سے کتراتے ہیں\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmccxx{یا وہ جس نے زمین بسنے کو بنائی اور اس کے بیچ میں نہریں نکالیں اور اس کے لیے لنگر بنائے اور دونوں سمندروں میں آڑ رکھی کیا اللہ کے ساتھ اور خدا ہے، بلکہ ان میں اکثر جاہل ہیں\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmccxxi{یا وہ جو لاچار کی سنتا ہے جب اسے پکارے اور دور کردیتا ہے برائی اور تمہیں زمین کا وارث کرتا ہے کیا اللہ کے ساتھ اور خدا ہے، بہت ہی کم دھیان کرتے ہو،\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmccxxii{یا وہ جو تمہیں راہ دکھاتا ہے اندھیریوں میں خشکی اور تری کی اور وہ کہ ہوائیں بھیجتا ہے، اپنی رحمت کے آگے خوشحبری سناتی کیا اللہ کے ساتھ کوئی اور خدا ہے، برتر ہے اللہ ان کے شرک سے،\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmccxxiii{یا وہ جو خلق کی ابتداء فرماتا ہے پھر اسے دوبارہ بنائے گا اور وہ جو تمہیں آسمانوں اور زمین سے روزی دیتا ہے کیا اللہ کے ساتھ کوئی اور خدا ہے، تم فرماؤ کہ اپنی دلیل لاؤ اگر تم سچے ہو\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmccxxiv{تم فرماؤ غیب نہیں جانتے جو کوئی آسمانوں اور زمین میں ہیں مگر اللہ اور انہیں خبر نہیں کہ کب اٹھا ےٴ جائیں گے،\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmccxxv{کیا ان کے علم کا سلسلہ آخرت کے جانے تک پہو نچ گیا کوئی نہیں وہ اس کی طرف سے شک میں ہیں بلکہ وہ اس سے اندھے ہیں،\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmccxxvi{اور کافر بولے کیا جب ہم اور ہمارے باپ دادا مٹی ہوجائیں گے کیا ہم پھر نکالے جائیں گے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmccxxvii{بیشک اس کا وعدہ دیا گیا ہم کو اور ہم سے پہلے ہمارے باپ داداؤں کو یہ تو نہیں مگر اگلوں کی کہانیاں،\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmccxxviii{تم فرماؤ زمین میں چل کر دیکھو، کیسا ہوا نجام مجرموں کا\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmccxxix{اور تم ان پر غم نہ کھاؤ اور ان کے مکر سے دل تنگ نہ ہو\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmccxxx{اور کہتے ہیں کب آئے گا یہ وعدہ اگر تم سچے ہو،\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmccxxxi{تم فرماؤ قریب ہے کہ تمہارے پیچھے آ لگی ہو بعض وہ چیز جس کی تم جلدی مچارہے ہو\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmccxxxii{اور بیشک تیرا رب فضل والا ہے آدمیوں پر لیکن اکثر آدمی حق نہیں مانتے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmccxxxiii{اور بیشک تمہارا رب جانتا ہے جو ان کے سینوں میں چھپی ہے اور جو وہ ظاہر کرتے ہیں\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmccxxxiv{اور جتنے غیب ہیں آسمانوں اور زمین کے سب ایک بتانے والی کتاب میں ہیں\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmccxxxv{بیشک یہ قرآن ذکر فرماتا ہے بنی اسرائیل سے اکثر وہ باتیں جس میں وہ اختلاف کرتے ہیں\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmccxxxvi{اور بیشک وہ ہدایت اور رحمت ہے مسلمانوں کے لیے،\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmccxxxvii{بیشک تمہارا رب ان کے آپس میں فیصلہ فرماتا ہے اپنے حکم سے اور وہی ہے عزت و الا علم والا،\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmccxxxviii{تو تم اللہ پر بھروسہ کرو، بیشک تم روشن حق پر ہو،\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmmccxxxix{بیشک تمہارے سنائے نہیں سنتے مردے اور نہ تمہارے سنائے بہرے پکار سنیں جب پھریں پیٹھ دے کر\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmmccxl{اور اندھوں کو گمراہی سے تم ہدایت کرنے والے نہیں، تمہارے سنائے تو وہی سنتے ہیں جو ہماری آیتوں پر ایمان لاتے ہیں اور ہو مسلمان ہیں،\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmmccxli{اور جب بات ان پر آپڑے گی ہم زمین سے ان کے لیے ایک چوپایہ نکالیں گے جو لوگوں سے کلام کرے گا اس لیے کہ لوگ ہماری آیتوں پر ایمان نہ لاتے تھے\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmmccxlii{اور جس دن اٹھائیں گے ہم ہر گروہ میں سے ایک فوج جو ہماری آیتوں کو جھٹلاتی ہے تو ان کے اگلے روکے جائیں گے کہ پچھلے ان سے آملیں،\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmmccxliii{یہاں تک کہ جب سب حاضر ہولیں گے فرمائے گا کیا تم نے میری آیتیں جھٹلائیں حالانکہ تمہارا علم ان تک نہ پہنچتا تھا یا کیا کام کرتے تھے\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmmccxliv{اور بات پڑچکی ان پر ان کے ظلم کے سبب تو وہ اب کچھ نہیں بولتے\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmmccxlv{کیا انہوں نے نہ دیکھا کہ ہم نے رات بنائی کہ اس میں آرام کریں اور دن کو بنایا سوجھانے والا، بیشک اس میں ضرور نشانیاں ہیں ان لوگوں کے لیے کہ ایمان رکھتے ہیں\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmmccxlvi{اور جس دن پھونکا جائے گا صُور تو گھبرائے جائیں گے جتنے آسمانوں میں ہیں اور جتنے زمین میں ہیں مگر جسے خدا چاہے اور سب اس کے حضور حاضر ہوئے عاجزی کرتے\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmmccxlvii{اور تو دیکھے گا پہاڑوں کو خیال کرے گا کہ وہ جمے ہوئے ہیں اور وہ چلتے ہوں گے بادل کی چال یہ کام ہے اللہ کا جس نے حکمت سے بنائی ہر چیز، بیشک اسے خبر ہے تمہارے کاموں کی،\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmmccxlviii{جو نیکی لائے اس کے لیے اس سے بہتر صلہ ہے اور ان کو اس دن کی گھبراہٹ سے امان ہے\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmmccxlix{اور جو بدی لائے تو ان کے منہ اوندھائے گئے آ گ میں تمہیں کیا بدلہ ملے گا مگر اسی کا جو کرتے تھے\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmmccl{مجھے تو یہی حکم ہوا ہے کہ پوجوں اس شہر کے رب کو جس نے اسے حرمت والا کیا ہے اور سب کچھ اسی کا ہے، اور مجھے حکم ہوا ہے کہ فرمانبرداروں میں ہوں،\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmmccli{اور یہ کہ قرآن کی تلاوت کروں تو جس نے راہ پائی اس نے اپنے بھلے کو راہ پائی اور جو بہکے تو فرمادو کہ میں تو یہی ڈر سنانے والا ہوں\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmmcclii{اور فرماؤ کہ سب خوبیاں اللہ کے لیے عنقریب وہ تمہیں اپنی نشانیاں دکھائے گا تو انہیں پہچان لو گے اور اے محبوب! تمہارا رب غافل نہیں، اے لوگو! تمہارے اعمال سے،\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmmccliii{\basmalahur طٰسم\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmccliv{یہ آیتیں ہیں روشن کتاب\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmcclv{ہم تم پر پڑھیں موسیٰ اور فرعون کی سچی خبر ان لوگوں کے لیے جو ایمان رکھتے ہیں،\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmcclvi{بیشک فرعون نے زمین میں غلبہ پایا تھا اور اس کے لوگوں کو اپنا تابع بنایا ان میں ایک گروہ کو کمزور دیکھتا ان کے بیٹوں کو ذبح کرتا اور ان کی عورتوں کو زندہ رکھتا بیشک وہ فسادی تھا،\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmcclvii{اور ہم چاہتے تھے کہ ان کمزوریوں پر احسان فرمائیں اور ان کو پیشوا بنائیں اور ان کے ملک و مال کا انہیں کو وارث بنائیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmcclviii{اور انہیں زمین میں قبضہ دیں اور فرعون اور ہامان اور ان کے لشکروں کو وہی دکھادیں جس کا انہیں ان کی طرف سے خطرہ ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmcclix{اور ہم نے موسیٰ کی ماں کو الہام فرمایا کہ اسے دودھ پلا پھر جب تجھے اس سے اندیشہ ہو تو اسے دریا میں ڈال دے اور نہ ڈر اور نہ غم کر بیشک ہم اسے تیری طرف پھیر لائیں اور اسے رسول بنائیں گے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmcclx{تو اسے اٹھالیا فرعون کے گھر والوں نے کہ وہ ان کا دشمن اور ان پر غم ہو بیشک فرعون اور ہامان اور ان کے لشکر خطا کار تھے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmcclxi{اور فرعون کی بی بی نے کہا یہ بچہ میری اور تیری آنکھوں کی ٹھنڈک ہے، اسے قتل نہ کرو، شاید یہ ہمیں نفع دے یا ہم اسے بیٹا بنالیں اور وہ بے خبر تھے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmcclxii{اور صبح کو موسیٰ کی ماں کا دل بے صبر ہوگیا ضرو ر قریب تھا کہ وہ اس کا حال کھول دیتی اگر ہم نہ ڈھارس بندھاتے اس کے دل پر کہ اسے ہمارے وعدہ پر یقین رہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmcclxiii{اور اس کی ماں نے اس کی بہن سے کہا اس کے پیچھے چلی جا تو وہ اسے دور سے دیکھتی رہی اور ان کو خبر نہ تھی\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmcclxiv{اور ہم نے پہلے ہی سب دائیاں اس پر حرام کردی تھیں تو بولی کیا میں تمہیں بتادوں ایسے گھر والے کہ تمہارے اس بچہ کو پال دیں اور وہ اس کے خیر خواہ ہیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmcclxv{تو ہم نے اسے اس کی ماں کی طرف پھیرا کہ ماں کی آنکھ ٹھنڈی ہو اور غم نہ کھائے اور جان لے کہ اللہ کا وعدہ سچا ہے، لیکن اکثر لوگ نہیں جانتے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmcclxvi{اور جب اپنی جوانی کو پہنچا اور پورے زور پر آیا ہم نے اسے حکم اور علم عطا فرمایا اور ہم ایسا ہی صلہ دیتے ہیں نیکوں کو،\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmcclxvii{اور اس شہر میں داخل ہوا جس وقت شہر والے دوپہر کے خواب میں بے خبر تھے تو اس میں دو مرد لڑتے پائے، ایک موسیٰ، کے گروہ سے تھا اور دوسرا اس کے دشمنوں سے تو وہ جو اس کے گروہ سے تھا اس نے موسیٰ سے مدد مانگی، اس پر جو اس کے دشمنوں سے تھا، تو موسیٰ نے اس کے گھونسا مارا تو اس کا کام تما م کردیا کہا یہ کام شیطان کی طرف سے ہوا بیشک وہ دشمن ہے کھلا گمراہ کرنے والا،\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmcclxviii{عرض کی، اے میرے رب! میں نے اپنی جان پر زیادتی کی تو مجھے بخش دے تو رب نے اسے بخش دیا، بیشک وہی بخشنے والا مہربان ہے،\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmcclxix{عرض کی اے میرے رب جیسا تو نے مجھ پر احسان کیا تو اب ہرگز میں مجرموں کا مددگار نہ ہوں گا،\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmcclxx{تو صبح کی، اس شہر میں ڈرتے ہوئے اس انتظار میں کہ کیا ہوتا ہے جبھی دیکھا کہ وہ جس نے کل ان سے مدد چاہی تھی فریاد کررہا ہے موسیٰ نے اس سے فرمایا بیشک تو کھلا گمراہ ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxi{تو جب موسیٰ نے چاہا کہ اس پر گرفت کرے جو ان دونوں کا دشمن ہے وہ بولا اے موسیٰ کیا تم مجھے ویسا ہی قتل کرنا چاہتے ہو جیسا تم نے کل ایک شخص کو قتل کردیا، تم تو یہی چاہتے ہو کہ زمین میں سخت گیر بنو اور اصلاح کرنا نہیں چاہتے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxii{اور شہر کے پرلے کنارے سے ایک شخص دوڑ تا آیا، کہا اے موسیٰ! بیشک دربار والے آپ کے قتل کا مشورہ کررہے ہیں تو نکل جایے میں آپ کا خیر خواہ ہوں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxiii{تو اس شہر سے نکلا ڈرتا ہوا اس انتظار میں کہ اب کیا ہوتا ہے عرض کی، اے میرے رب! مجھے ستمگاروں سے بچالے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxiv{اور جب مدین کی طرف متوجہ ہوا کہا قریب ہے کہ میرا رب مجھے سیدھی راہ بتائے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxv{اور جب مدین کے پانی پر آیا وہاں لوگوں کے ایک گروہ کو دیکھا کہ اپنے جانوروں کو پانی پلارہے ہیں، اور ان سے اس طرف دو عورتیں دیکھیں کہ اپنے جانوروں کو روک رہی ہیں موسیٰ نے فرمایا تم دونوں کا کیا حال ہے وہ بولیں ہم پانی نہیں پلاتے جب تک سب چرواہے پلاکر پھیر نہ لے جائیں اور ہمارے باپ بہت بوڑھے ہیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxvi{تو موسیٰ نے ان دونوں کے جانوروں کو پانی پلا دیا پھر سایہ کی طرف پھرا عرض کی اے میرے رب! میں اس کھانے کا جو تو میرے لیے اتارے محتاج ہوں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxvii{تو ان دونوں میں سے ایک اس کے پاس آئی شرم سے چلتی ہوئی بولی میرا باپ تمہیں بلاتا ہے کہ تمہیں مزدوری دے اس کی جو تم نے ہمارے جانوروں کو پانی پلایا ہے جب موسیٰ اس کے پاس آیا اور اسے باتیں کہہ سنائیں اس نے کہا ڈریے نہیں، آپ بچ گئے ظالموں سے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxviii{ان میں کی ایک بولی اے میرے باپ! ان کو نوکر رکھ لو بیشک بہتر نوکر وہ جو طاقتور اور امانتدار ہو\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxix{کہا میں چاہتا ہوں کہ اپنی دونوں بیٹیوں میں سے ایک تمہیں بیاہ دوں اس مہر پر کہ تم آٹھ برس میری ملازمت کرو پھر اگر پورے دس برس کرلو تو تمہاری طرف سے ہے اور میں تمہیں مشقت میں ڈالنا نہیں چاہتا قریب ہے انشاء اللہ تم مجھے نیکوں میں پاؤ گے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxx{موسیٰ نے کہا یہ میرے اور آپ کے درمیان اقرار ہوچکا، میں ان دونوں میں جو میعاد پوری کردوں تو مجھ پر کوئی مطالبہ نہیں، اور ہمارے اس کہے پر اللہ کا ذمہ ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxi{پھر جب موسیٰ نے اپنی میعاد پوری کردی اور اپنی بی بی کو لے کر چلا طُور کی طرف سے ایک آگ دیکھی اپنی گھر والی سے کہا تم ٹھہرو مجھے طُور کی طرف سے ایک آگ نظر پڑی ہے شاید میں وہاں سے کچھ خبر لاؤ ں یا تمہارے لیے کوئی آ گ کی چنگاری لاؤں کہ تم تاپو،\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxii{پھر جب آگ کے پاس حاضر ہوا ندا کی گئی میدان کے دہنے کنارے سے برکت والے مقام میں پیڑ سے کہ اے موسیٰ! بیشک میں ہی ہوں اللہ رب سارے جہان کا\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxiii{اور یہ کہ ڈال دے اپنا عصا پھر جب موسیٰ نے اسے دیکھا لہراتا ہوا گویا سانپ ہے پیٹھ پھیر کر چلا اور مڑ کر نہ دیکھا اے موسیٰ سامنے آ اور ڈر نہیں، بیشک تجھے امان ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxiv{اپنا ہاتھ گریبان میں ڈال نکلے گا سفید چمکتا بے عیب اور اپنا ہاتھ سینے پر رکھ لے خوف دور کرنے کو تو یہ دو حُجتیں ہیں تیرے رب کی فرعون اور اس کے درباریوں کی طرف، بیشک وہ بے حکم لوگ ہیں،\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxv{عرض کی اے میرے رب! میں نے ان میں ایک جان مار ڈالی ہے تو ڈرتا ہوں کہ مجھے قتل کردیں،\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxvi{اور میرا بھائی ہارون اس کی زبان مجھ سے زیادہ صاف ہے تو اسے میری مدد کے لیے رسول بنا، کہ میری تصدیق کرے مجھے ڈر ہے کہ وہ مجھے جھٹلائیں گے،\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxvii{فرمایا، قریب ہے کہ ہم تیرے بازو کو تیرے بھائی سے قوت دیں گے اور تم دونوں کو غلبہ عطا فرمائیں گے تو وہ تم دونوں کا کچھ نقصان نہ کرسکیں گے، ہماری نشانیوں کے سبب تم دونوں اور جو تمہاری پیروی کریں گے غالب آؤ گے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxviii{پھر جب موسیٰ ان کے پاس ہماری روشن نشانیاں لایا بولے یہ تو نہیں مگر بناوٹ کا جادو اور ہم نے اپنے اگلے باپ داداؤں میں ایسا نہ سنا\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxix{اور موسیٰ نے فرمایا میرا رب خوب جانتا ہے جو اس کے پاس سے ہدایت لایا اور جس کے لیے آخرت کا گھر ہوگا بیشک ظالم مراد کو نہیں پہنچتے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmccxc{اور فرعون بولا، اے درباریو! میں تمہارے لیے اپنے سوا کوئی خدا نہیں جانتا تو اے ہامان! میرے لیے گارا پکا کر ایک محل بنا کہ شاید میں موسیٰ کے خدا کو جھانک آؤں اور بیشک میرے گمان میں تو وہ جھوٹا ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmccxci{اور اس نے اور اس کے لشکریوں نے زمین میں بے جا بڑائی چاہی اور سمجھے کہ انہیں ہماری طرف پھرنا نہیں،\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmccxcii{تو ہم نے اسے اور اس کے لشکر کو پکڑ کر دریا میں پھینک دیا تو دیکھو کیسا انجام ہوا ستمگاروں کا،\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmccxciii{اور انہیں ہم نے دوزخیوں کا پیشوا بنایا کہ آگ کی طرف بلاتے ہیں اور قیامت کے دن ان کی مدد نہ ہوگی،\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmccxciv{اور اس دنیا میں ہم نے ان کے پیچھے لعنت لگائی اور قیامت کے دن ان کا برا ہے،\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmccxcv{اور بیشک ہم نے موسیٰ کو کتاب عطا فرمائی بعد اس کے کہ اگلی سنگتیں (قومیں) ہلاک فرمادیں جس میں لوگوں کے دل کی آنکھیں کھولنے والی باتیں اور ہدایت اور رحمت تاکہ وہ نصیحت مانیں،\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmccxcvi{اور تم طور کی جانت مغرب میں نہ تھے جبکہ ہم نے موسیٰ کو رسالت کا حکم بھیجا اور اس وقت تم حاضر نہ تھے،\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmccxcvii{مگر ہوا یہ کہ ہم نے سنگتیں پیدا کیں کہ ان پر زمانہ دراز گزرا اور نہ تم اہلِ مدین میں مقیم تھے ان پر ہماری آیتیں پڑھتے ہوئے، ہاں ہم رسول بنانے والے ہوئے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmccxcviii{اور نہ تم طور کے کنارے تھے جب ہم نے ندا فرمائی ہاں تمہارے رب کی مہر ہے (کہ تمہیں غیب کے علم دیے) کہ تم ایسی قوم کو ڈر سناؤ جس کے پاس تم سے پہلے کوئی ڈر سنانے والا نہ آیا یہ امید کرتے ہوئے کہ ان کو نصیحت ہو،\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmccxcix{اور اگر نہ ہوتا کہ کبھی پہنچتی انہیں کوئی مصیبت اس کے سبب جو ان کے ہاتھوں نے آگے بھیجا تو کہتے، اے ہمارے رب! تو نے کیوں نہ بھیجا ہماری طرف کوئی رسول کہ ہم تیری آیتوں کی پیروی کرتے اور ایمان لاتے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmccc{پھر جب ان کے پاس حق آیا ہماری طرف سے بولے انہیں کیوں نہ دیا گیا جو موسیٰ کو دیا گیا کیا اس کے منکر نہ ہوئے تھے جو پہلے موسیٰ کو دیا گیا بولے دو جادو ہیں ایک دوسرے کی پشتی (امداد) پر، اور بولے ہم ان دونوں کے منکر ہیں\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmccci{تم فرماؤ تو اللہ کے پاس سے کوئی کتاب لے آؤ جو ان دونوں کتابوں سے زیادہ ہدایت کی ہو میں اس کی پیروی کروں گا اگر تم سچے ہو\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmcccii{پھر اگر وہ یہ تمہارا فرمانا قبول نہ کریں تو جان لو کہ بس وہ اپنی خواہشو ں ہی کے پیچھے ہیں، اور اس سے بڑھ کر گمراہ کون جو اپنی خواہش کی پیروی کرے اللہ کی ہدایت سے جدا، بیشک اللہ ہدایت ہیں فرماتا ظالم لوگوں کو،\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmccciii{اور بیشک ہم نے ان کے لیے بات مسلسل اتاری کہ وہ دھیان کریں،\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmccciv{جن کو ہم نے اس سے پہلے کتاب دی وہ اس پر ایمان لاتے ہیں،\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmcccv{اور جب ان پر یہ آیتیں پڑھی جاتی ہیں کہتے ہیں ہم اس پر ایمان لائے، بیشک یہی حق ہے ہمارے رب کے پا س سے ہم اس سے پہلے ہی گردن رکھ چکے تھے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmcccvi{ان کو ان کا اجر دوبالا دیا جائے گا بدلہ ان کے صبر کا اور وہ بھلائی سے برائی کو ٹالتے ہیں اور ہمارے دیے سے کچھ ہماری راہ میں خرچ کرتے ہیں\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmcccvii{اور جب بیہودہ بات سنتے ہیں اس سے تغافل کرتے ہیں اور کہتے ہیں ہمارے لیے ہمارے عمل اور تمہارے لیے تمہارے عمل، بس تم پر سلام ہم جاہلوں کے غرضی (چاہنے والے) نہیں\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmcccviii{بیشک یہ نہیں کہ تم جسے اپنی طرف سے چاہو ہدایت کردو ہاں اللہ ہدایت فرماتا ہے جسے چاہے، اور وہ خوب جانتا ہے ہدایت والوں کو\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmcccix{اور کہتے ہیں اگر ہم تمہارے ساتھ ہدایت کی پیروی کریں تو لوگ ہمارے ملک سے ہمیں اچک لے جائیں گے کیا ہم نے انہیں جگہ نہ دی امان والی حرم میں جس کی طرف ہر چیز کے پھل لائے جاتے ہیں ہمارے پاس کی روزی لیکن ان میں اکثر کو علم نہیں\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmcccx{اور کتنے شہر ہم نے ہلاک کردیے جو اپنے عیش پر اترا گئے تھے تو یہ ہیں ان کے مکان کہ ان کے بعد ان میں سکونت نہ ہوئی مگر کم اور ہمیں وارث ہیں\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmcccxi{اور تمہارا رب شہروں کو ہلاک نہیں کرتا جب تک ان کے اصل مرجع میں رسول نہ بھیجے جو ان پر ہماری آیتیں پڑھے اور ہم شہروں کو ہلاک نہیں کرتے مگر جبکہ ان کے ساکن ستمگار ہوں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmcccxii{اور جو کچھ چیز تمہیں دی گئی ہے اور دنیوی زندگی کا برتاوا اور اس کا سنگھارہے اور جواللہ کے پاس ہے اور وہ بہتر اور زیادہ باقی رہنے والا تو کیا تمہیں عقل نہیں\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmcccxiii{تو کیا وہ جسے ہم نے اچھا وعدہ دیا تو وہ اس سے ملے گا اس جیسا ہے جسے ہم نے دنیوی زندگی کا برتاؤ برتنے دیا پھر وہ قیامت کے دن گرفتار کرکے حاضر لایا جائے گا\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmcccxiv{اور جس دن انہیں ندا کرے گا تو فرمائے گا کہاں ہیں میرے وہ شریک جنہیں تم گمان کرتے تھے،\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmcccxv{کہیں گے وہ جن پر بات ثابت ہوچکی اے ہمارے رب یہ ہیں وہ جنہیں ہم نے گمراہ کیا، ہم نے انہیں گمراہ کیا جیسے خود گمراہ ہوئے تھے ہم ان سے بیزار ہوکر تیری طرف رجوع لاتے ہیں وہ ہم کو نہ پوجتے تھے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmcccxvi{اور ان سے فرمایا جائے گا اپنے شریکوں کو پکارو تو وہ پکاریں گے تو وہ ان کی نہ سنیں گے اور دیکھیں گے عذاب، کیا اچھا ہوتا اگر وہ راہ پاتے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmcccxvii{اور جس دن انہیں ندا کرتے گا تو فرمائے گا تم نے رسولوں کو کیا جواب دیا\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmcccxviii{تو اس دن ان پر خبریں اندھی ہوجائیں گی تو وہ کچھ پوجھ گچھ نہ کریں گے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmcccxix{تو وہ جس نے توبہ کی اور ایمان لایا اور اچھا کام کیا قریب ہے کہ وہ راہ یاب ہو،\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmcccxx{اور تمہارا رب پیدا کرتا ہے جو چاہے اور پسند فرماتا ہے ان کا کچھ اختیار نہیں، پاکی اور برتری ہے اللہ کو ان کے شرک سے،\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxi{اور تمہارا رب جانتا ہے جو ان کے سینوں میں چھپا ہے اور جو ظاہر کرتے ہیں\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxii{اور وہی ہے اللہ کہ کوئی خدا نہیں اس کے سوا اسی کی تعریف ہے دنیا اور آخرت میں اور اسی کا حکم ہے اور اسی کی طرف پھر جاؤ گے،\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxiii{تم فرماؤ بھلا دیکھو تو اگر اللہ ہمیشہ تم پر قیامت تک رات رکھے تو اللہ کے سوا کون خدا ہے جو تمہیں روشنی لادے تو کیا تم سنتے نہیں\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxiv{تم فرماؤ بھلا دیکھو تو اگر اللہ قیامت تک ہمیشہ دن رکھے تو اللہ کے سوا کون خدا ہے جو تمہیں رات لادے جس میں آرام کرو تو کیا تمہیں سوجھتا نہیں\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxv{اور اس نے اپنی مہر سے تمہارے لیے رات اور دن بنائے کہ رات میں آرام کرو اور دن میں اس کا فضل ڈھونڈو اور اس لیے کہ تم حق مانو\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxvi{اور جس دن انہیں ندا کرتے گا تو فرمائے گا، کہاں ہیں؟ میرے وہ شریک جو تم بکتے تھے،\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxvii{اور ہر گروہ میں سے ایک گواہ نکال کر فرمائیں گے اپنی دلیل لاؤ تو جان لیں گے کہ حق اللہ کا ہے اور ان سے کھوئی جائیں گی جو بناوٹیں کرتے تھے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxviii{بیشک قارون موسیٰ کی قوم سے تھا پھر اس نے ان پر زیادتی کی اور ہم نے اس کو اتنے خزانے دیے جن کی کنجیاں ایک زور آور جماعت پر بھاری تھیں، جب اس سے اس کی قوم نے کہا اِترا نہیں بیشک اللہ اِترانے والوں کو دوست نہیں رکھتا،\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxix{اور جو مال تجھے اللہ نے دیا ہے اس سے آخرت کا گھر طلب کر اور دنیا میں اپنا حصہ نہ بھول اور احسان کر جیسا اللہ نے تجھ پر احسان کیا اور زمیں میں فساد نہ چاه بے شک اللہ فسادیوں کو دوست نہیں رکھتا،\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxx{بو لا یہ تو مجھے ایک علم سے ملا ہے جو میرے پاس ہے اور کیا اسے یہ نہیں معلوم کہ اللہ نے اس سے پہلے وہ سنگتیں (قومیں) ہلاک فرمادیں جن کی قوتیں اس سے سخت تھیں اور جمع اس سے زیادہ اور مجرموں سے ان کے گناہوں کی پوچھ نہیں\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxi{تو اپنی قومی پر نکلا اپنی آرائش میں بولے وہ جو دنیا کی زندگی چاہتے ہیں کسی طرح ہم کو بھی ایسا ملتا جیسا قارون کو ملا بیشک اس کا بڑا نصیب ہے،\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxii{اور بولے وہ جنہیں علم دیا گیا خرابی ہو تمہاری، اللہ کا ثواب بہتر ہے اس کے لیے جو ایمان لائے اور اچھے کام کرے اور یہ انہیں کو ملتا ہے جو صبر والے ہیں\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxiii{تو ہم نے اسے اور اس کے گھر کو زمین میں دھنسایا تو اس کے پاس کوئی جماعت نہ تھی کہ اللہ سے بچانے میں اس کی مدد کرتی اور نہ وہ بدلہ لے سکا\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxiv{اور کل جس نے اس کے مرتبہ کی آرزو کی تھی صبح کہنے لگے عجب بات ہے اللہ رزق وسیع کرتا ہے اپنے بندوں میں جس کے لیے چاہے اور تنگی فرماتا ہے اگر اللہ ہم پر احسان فرماتا تو ہمیں بھی دھنسادیتا، اے عجب، کافروں کا بھلا نہیں،\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxv{یہ آخرت کا گھر ہم ان کے لیے کرتے ہیں جو زمین میں تکبر نہیں چاہتے اور نہ فساد، اور عاقبت پرہیزگاروں ہی کی ہے،\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxvi{جو نیکی لائے اس کے لیے اس سے بہتر ہے اور جو بدی لائے بدکام والوں کو بدلہ نہ ملے گا مگر جتنا کیا تھا،\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxvii{بیشک جس نے تم پر قرآن فرض کیا وہ تمہیں پھیر لے جائے گا جہاں پھرنا چاہتے ہو تم فرماؤ، میرا رب خوب جانتا ہے اسے جو ہدایت لایا اور جو کھلی گمراہی میں ہے\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxviii{اور تم امید نہ رکھتے تھے کہ کتاب تم پر بھیجی جائے گی ہاں تمہارے رب نے رحمت فرمائی تو تم ہرگز کافروں کی پشتی (مدد) نہ کرنا\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxix{اور ہرگز وہ تمہیں اللہ کی آیتوں سے نہ روکیں بعد اس کے کہ وہ تمہاری طرف اتاری گئیں اور اپنے رب کی طرف بلاؤ اور ہرگز شرک والوں میں سے نہ ہونا\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmmcccxl{اور اللہ کے ساتھ دوسرے خدا کو نہ پوج اس کے سوا کوئی خدا نہیں ہر چیز فانی ہے، سوا اس کی ذات کے، اسی کا حکم ہے اور اسی کی طرف پھر جاؤ گے،\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmmcccxli{\basmalahur الم\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmcccxlii{کیا لوگ اس گھمنڈ میں ہیں کہ اتنی بات پر چھوڑ دیے جائیں گے کہ کہیں ہم ایمان لائے، اور ان کی آزمائش نہ ہوگی\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmcccxliii{اور بیشک ہم نے ان سے اگلوں کو جانچا تو ضرور اللہ سچوں کو دیکھے گا اور ضرور جھوٹوں کو دیکھے گا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmcccxliv{یا یہ سمجھے ہوئے ہیں وہ جو برے کام کرتے ہیں کہ ہم سے کہیں نکل جائیں گے کیا ہی برا حکم لگاتے ہیں،\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmcccxlv{جسے اللہ سے ملنے کی امید ہو تو بیشک اللہ کی میعاد ضرور آنے والی ہے اور وہی سنتا جانتا ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmcccxlvi{اور جو اللہ کی راہ میں کوشش کرے تو اپنے ہی بھلے کو کوشش کرتا ہے بیشک اللہ بے پرواہ ہے سارے جہان سے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmcccxlvii{اور جو ایمان لائے اور اچھے کام کیے ہم ضرور ان کی برائیاں اتار دیں گے اور ضرور انہیں اس کام پر بدلہ دیں گے جو ان کے سب کاموں میں اچھا تھا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmcccxlviii{اور ہم نے آدمی کو تاکید کی اپنے ماں باپ کے ساتھ بھلائی کی اور اگر تو وہ تجھ سے کوشش کریں کہ تو میرا شریک ٹھہرائے جس کا تجھے علم نہیں تو تُو ان کا کہا نہ مان میری ہی طرف تمہارا پھرنا ہے تو میں بتادوں گا تمہیں جو تم کرتے تھے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmcccxlix{اور جو ایمان لائے اور اچھے کام کیے ضرور ہم انہیں نیکوں میں شامل کریں گے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmcccl{اور بعض آدمی کہتے ہیں ہم اللہ پر ایمان لائے پھر جب اللہ کی راہ میں انہیں کوئی تکلیف دی جاتی ہے تو لوگوں کے فتنہ کو اللہ کے عذاب کے برابر سمجھتے ہیں اور اگر تمہارے رب کے پاس سے مدد آئے تو ضرور کہیں گے ہم تو تمہارے ہی ساتھ تھے کیا اللہ خوب نہیں جانتا جو کچھ جہاں بھر کے دلوں میں ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmcccli{اور ضرور اللہ ظاہر کردے گا ایمان والوں کو اور ضرور ظاہر کردے گا منافقوں کو\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmccclii{اور کافر مسلمانوں سے بولے ہماری راہ پر چلو اور ہم تمہارے گناہ اٹھالیں گے حالانکہ وہ ان کے گناہوں میں سے کچھ نہ اٹھائیں گے، بیشک وہ جھوٹے ہیں،\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmcccliii{اور بیشک ضرور اپنے بوجھ اٹھائیں گے اور اپنے بوجھوں کے ساتھ اور بوجھ اور ضرور قیامت کے دن پوچھے جائیں گے جو کچھ بہتان اٹھاتے تھے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmcccliv{اور بیشک ہم نے نوح کو اس کی قوم کی طرف بھیجا تو وہ ان میں پچاس سال کم ہزار برس رہا تو انہیں طوفان نے ا ٓ لیا اور وہ ظالم تھے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmccclv{تو ہم نے اسے اور کشتی والوں کو بچالیا اور اس کشتی کو سارے جہاں کے لیے نشانی کیا\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmccclvi{اور ابراہیم کو جب اس نے اپنی قوم سے فرمایا کہ اللہ کو پوجو اور اس سے ڈرو، اس میں تمہارا بھلا ہے اگر تم جانتے،\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmccclvii{تم تو اللہ کے سوا بتوں کو پوجتے ہو اور نرا جھوٹ گڑ ھتے ہو بے شک وه جنھیں تم اللہ کے سوا پو جتے ہو تمہاری روزی کے کچھ مالک نہیں تو اللہ کے پاس رزق ڈھونڈو اور اس کی بندگی کرو اور اس کا احسان مانو، تمہیں اسی کی طرف پھرنا ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmccclviii{اور اگر تم جھٹلاؤ تو تم سے پہلے کتنے ہی گروہ جھٹلا چکے ہیں اور رسول کے ذمہ نہیں مگر صاف پہنچا دینا،\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmccclix{اور کیا انہوں نے نہ دیکھا اللہ کیونکر خلق کی ابتداء فرماتا ہے پھر اسے دوبارہ بنائے گا بیشک یہ اللہ کو آسان ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmccclx{تم فرماؤ زمین میں سفر کرکے دیکھو اللہ کیونکر پہلے بناتا ہے پھر اللہ دوسری اٹھان اٹھاتا ہے بیشک اللہ سب کچھ کرسکتا ہے،\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmccclxi{عذاب دیتا ہے جسے چاہے اور رحم فرماتا ہے جس پر چاہے اور تمہیں اسی کی طرف پھرنا ہے،\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmccclxii{اور نہ تم زمین میں قابو سے نکل سکو اور نہ آسمان میں اور تمہارے لیے اللہ کے سوا نہ کوئی کام بنانے والا اور نہ مددگار،\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmccclxiii{اور وہ جنہوں نے میری آیتوں اور میرے ملنے کو نہ مانا وہ ہیں جنہیں میری رحمت کی آس نہیں اور ان کے لیے دردناک عذاب ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmccclxiv{تو اس کی قوم کو کچھ جواب بن نہ آیا مگر یہ بولے انہیں قتل کردو یا جلادو تو اللہ نے اسے آگ سے بچالیا بیشک اس میں ضرور نشانیاں ہیں ایمان والوں کے لیے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmccclxv{اور ابراہیم نے فرمایا تم نے تو اللہ کے سوا یہ بت بنالیے ہیں جن سے تمہاری دوستی یہی دنیا کی زندگی تک ہے پھر قیامت کے دن تم میں ایک دوسرے کے ساتھ کفر کرے گا اور ایک دوسرے پر لعنت ڈالے گا اور تم سب کا ٹھکانا جہنم ہے اور تمہارا کوئی مددگار نہیں\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmccclxvi{تو لوط اس پر ایمان لایا اور ابراہیم نے کہا میں اپنے رب کی طرف ہجرت کرتا ہوں بیشک وہی عزت و حکمت والا ہے،\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmccclxvii{اور ہم نے اسے اسحاق اور یعقوب عطا فرمائے اور ہم نے اس کی اولاد میں نبوت اور کتاب رکھی اور ہم نے دنیا میں اس کا ثواب اسے عطا فرمایا اور بیشک آخرت میں وہ ہمارے قرب خاص کے سزاواروں میں ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmccclxviii{اور لوط کو نجات دی جب اس نے اپنی قوم سے فرمایا تم بیشک بے حیائی کا کام کرتے ہو، کہ تم سے پہلے دنیا بھر میں کسی نے نہ کیا\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmccclxix{کیا تم مردوں سے بدفعلی کرتے ہو اور راہ مارتے ہو اور اپنی مجلس میں بری بات کرتے ہو تو اس کی قوم کا کچھ جواب نہ ہوا مگر یہ کہ بولے ہم پر اللہ کا عذاب لاؤ اگر تم سچے ہو\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmccclxx{عرض کی، اے میرے رب! میری مدد کر ان فسادی لوگوں پر\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxi{اور جب ہمارے فرشتے ابراہیم کے پاس مژدہ لے کر آئے بولے ہم ضرور اس شہر والوں کو ہلاک کریں گے بیشک اس کے بسنے والے ستمگاروں ہیں،\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxii{کہا اس میں تو لوط ہے فرشتے بولے ہمیں خوب معلوم ہے جو کوئی اس میں ہے، ضرور ہم اسے اور اس کے گھر والوں کو نجات دیں گے مگر اس کی عورت کو، وہ رہ جانے والوں میں ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxiii{اور جب ہمارے فرشتے لوط کے پاس آئے ان کا آنا اسے ناگوار ہوا اور ان کے سبب دل تنگ ہوا اور انہوں نے کہا نہ ڈریے اور نہ غم کیجئے بیشک ہم آپ کو اور آپ کے گھر والوں کو نجات دیں گے مگر آپ کی عورت وہ رہ جانے والوں میں ہے،\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxiv{بیشک ہم اس شہر والوں پر آسمان سے عذاب اتارنے والے ہیں بدلہ ان کی نافرمانیوں کا،\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxv{اور بیشک ہم نے اس سے روشن نشانی باقی رکھی عقل والوں کے لیے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxvi{مدین کی طرف ان کے ہم قوم شعیب کو بھیجا تو اس نے فرمایا، اے میری قوم! اللہ کی بندگی کرو اور پچھلے دن کی امید رکھو اور زمین میں فساد پھیلاتے نہ پھرو،\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxvii{تو انہوں نے اسے جھٹلایا تو انہیں زلزلے نے آلیا تو صبح اپنے گھروں میں گھٹنوں کے بل پڑے رہ گئے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxviii{اور عاد اور ثمود کو ہلاک فرمایا اور تمہیں ان کی بستیاں معلوم ہوچکی ہیں اور شیطان نے ان کے کوتک ان کی نگاہ میں بھلے کر دکھائے اور انہیں راہ سے روکا اور انہیں سوجھتا تھا\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxix{اور قارون اور فرعون اور ہامان کو اور بیشک ان کے پاس موسیٰ روشن نشانیاں لے کر آیا تو انہوں نے زمین میں تکبر کیا اور وہ ہم سے نکل کر جانے والے نہ تھے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxx{تو ان میں ہر ایک کو ہم نے اس کے گناہ پر پکڑا تو ان میں کسی پر ہم نے پتھراؤ بھیجا اور ان میں کسی کو چنگھاڑ نے آلیا اور ان میں کسی کو زمین میں دھنسادیا اور ان میں کسی کو ڈبو دیا اور اللہ کی شان نہ تھی کہ ان پر ظلم کرے ہاں وہ خود ہی اپنی جانوں پر ظلم کرتے تھے،\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxi{ان کی مثال جنہوں نے اللہ کے سوا اور مالک بنالیے ہیں مکڑی کی طرح ہے، اس نے جالے کا گھر بنایا اور بیشک سب گھروں میں کمزور گھر مکڑی کا گھر کیا اچھا ہوتا اگر جانتے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxii{اللہ جانتا ہے جس چیز کی اس کے سوا پوجا کرتے ہیں اور وہی عزت و حکمت والا ہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxiii{اور یہ مثالیں ہم لوگوں کے لیے بیان فرماتے ہیں، اور انہیں نہیں سمجھتے مگر علم والے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxiv{اللہ نے آسمان اور زمین حق بنائے، بیشک اس میں نشانی ہے مسلمانوں کے لیے،\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxv{اے محبوب! پڑھو جو کتاب تمہاری طرف وحی کی گئی اور نماز قائم فرماؤ، بیشک نماز منع کرتی ہے بے حیائی اور بری بات سے اور بیشک اللہ کا ذکر سب سے بڑا اور اللہ جانتا ہے جو تم کرتے ہو،\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxvi{اور اے مسلمانو! کتابیوں سے نہ جھگڑو مگر بہتر طریقہ پر مگر وہ جنہوں نے ان میں سے ظلم کیا اور کہو ہم ایمان لائے اس پر جو ہماری طرف اترا اور جو تمہاری طرف اترا اور ہمارا تمہارا ایک معبود ہے اور ہم اس کے حضور گردن رکھتے ہیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxvii{اور اے محبوب! یونہی تمہاری طرف کتاب اتاری تو وہ جنہیں ہم نے کتا ب عطا فرمائی اس پر ایمان لاتے ہیں، اور کچھ ان میں سے ہیں جو اس پر ایمان لاتے ہیں، اور ہماری آیتوں سے منکر نہیں ہوتے مگر\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxviii{اور اس سے پہلے تم کوئی کتاب نہ پڑھتے تھے اور نہ اپنے ہاتھ سے کچھ لکھتے تھے یوں ہوتا تو باطل ضرور شک لاتے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxix{بلکہ وہ روشن آیتیں ہیں ان کے سینوں میں جن کو علم دیا گیا اور ہماری آیتوں کا انکار نہیں کرتے مگر ظالم\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmcccxc{اور بولے کیوں نہ اتریں کچھ نشانیاں ان پر ان کے رب کی طرف سے تم فرماؤ نشانیاں تو اللہ ہی کے پاس ہیں اور میں تو یہی صاف ڈر سنانے والا ہوں\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmcccxci{اور کیا یہ انہیں بس نہیں کہ ہم نے تم پر کتاب اتاری جو ان پر پڑھی جاتی ہے بیشک اس میں رحمت اور نصیحت ہے ایمان والوں کے لیے،\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmcccxcii{تم فرماؤ اللہ بس ہے میرے اور تمہارے درمیان گواہ جانتا ہے جو کچھ آسمانوں اور زمین میں ہے، اور وہ جو باطل پر یقین لائے اور اللہ کے منکر ہوئے وہی گھاٹے میں ہیں،\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmcccxciii{اور تم سے عذاب کی جلدی کرتے ہیں اور اگر ایک ٹھہرائی مدت نہ ہوتی تو ضرور ان پر عذاب آجاتا اور ضرور ان پر اچانک آئے گا جب وہ بے خبر ہوں گے،\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmcccxciv{تم سے عذاب کی جلدی مچاتے ہیں، اور بیشک جہنم گھیرے ہوئے ہے کافروں کو\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmcccxcv{جس دن انہیں ڈھانپے گا عذاب ان کے اوپر اور ان کے پاؤں کے نیچے سے اور فرمائے گا چکھو اپنے کیے کا مزہ\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmcccxcvi{اے میرے بندو! جو ایمان لائے بیشک میری زمین وسیع ہے تو میری ہی بندگی کرو\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmcccxcvii{ہر جان کو موت کا مز ہ چکھنا ہے پھر ہماری ہی طرف پھروگے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmcccxcviii{اور بیشک جو ایمان لائے اور اچھے کام کیے ضرور ہم انہیں جنت کے بالا خانوں پر جگہ دیں گے جن کے نیچے نہریں بہتی ہوں گی ہمیشہ ان میں رہیں گے، کیا ہی اچھا اجر کام والوں کا\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmcccxcix{وہ جنہوں نے صبر کیا اور اپنے رب ہی پر بھروسہ رکھتے ہیں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmcd{اور زمین پر کتنے ہی چلنے والے ہیں کہ اپنی روزی ساتھ نہیں رکھتے اللہ روزی دیتا ہے انہیں اور تمہیں اور وہی سنتا جانتا ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmcdi{اور اگر تم ان سے پوچھو کس نے بنائے آسمان اور زمین اور کام میں لگائے سورج اور چاند تو ضرور کہیں گے اللہ نے، تو کہاں اوندھے جاتے ہیں\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmcdii{اللہ کشادہ کرتا ہے رزق اپنے بندوں میں جس کے لیے چاہے اور تنگی فرماتا ہے جس کے لیے چاہے، بیشک اللہ سب کچھ جانتا ہے،\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmcdiii{اور جو تم ان سے پوچھو کس نے اتارا آسمان سے پانی تو اس کے سبب زمین زندہ کردی مَرے پیچھے ضرور کہیں گے اللہ نے تم فرماؤ سب خوبیاں اللہ کو، بلکہ ان میں اکثر بے عقل ہیں\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmcdiv{اور یہ دنیا کی زندگی تو نہیں مگر کھیل کود اور بیشک آخرت کا گھر ضرور وہی سچی زندگی ہے کیا اچھا تھا اگر جانتے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmcdv{پھر جب کشتی میں سوار ہوتے ہیں اللہ کو پکارتے ہیں ایک اسی عقیدہ لاکر پھر جب وہ انہیں خشکی کی طرف بچا لاتا ہے جبھی شرک کرنے لگتے ہیں\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmcdvi{کہ ناشکری کریں ہماری دی ہوئی نعمت کی اور برتیں۔ تو اب جانا چاہتے ہیں،\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmcdvii{اور کیا انہوں نے یہ نہ دیکھا کہ ہم نے حرمت والی زمین پناہ بنائی اور ان کے آس پاس والے لوگ اچک لیے جاتے ہیں تو کیا باطل پر یقین لاتے ہیں اور اللہ کی دی ہوئی نعمت سے ناشکری کرتے ہیں،\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmcdviii{اور اس سے بڑھ کر ظالم کون جو اللہ پر جھوٹ باندھے یا حق کو جھٹلائے جب وہ اس کے پاس آئے، کیا جہنم میں کافروں کا ٹھکانا نہیں\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmcdix{اور جنہوں نے ہماری راہ میں کوشش کی ضرور ہم انہیں اپنے راستے دکھادیں گے اور بیشک اللہ نیکوں کے ساتھ ہے\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmcdx{\basmalahur الم\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmcdxi{رومی مغلوب ہوئے،\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmcdxii{پاس کی زمین میں اور اپنی مغلوبی کے عنقریب غالب ہوں گے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmcdxiii{چند برس میں حکم اللہ ہی کا ہے آگے اور پیچھے اور اس دن ایمان والے خوش ہوں گے،\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmcdxiv{اللہ کی مدد سے مدد کرتا ہے جس کی چاہے، اور وہی عزت والا مہربان،\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmcdxv{اللہ کا وعدہ اللہ اپنا وعدہ خلاف نہیں کرتا لیکن بہت لوگ نہیں جانتے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmcdxvi{جانتے ہیں آنکھوں کے سامنے کی دنیوی زندگی اور وہ آخرت سے پورے بے خبر ہیں،\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmcdxvii{کیا انہوں نے اپنے جی میں نہ سوچا کہ، اللہ نے پیدا نہ کیے آسمان اور زمین اور جو کچھ ان کے درمیان ہے مگر حق اور ایک مقرر میعاد سے اور بیشک بہت سے لوگ اپنے رب سے ملنے کا انکار رکھتے ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmcdxviii{اور کیا انہوں نے زمین میں سفر نہ کیا کہ دیکھتے کہ ان سے اگلوں کا انجام کیسا ہوا وہ ان سے زیادہ زور آور تھے اور زمین جوتی اور آباد کی ان کی آبادی سے زیادہ اور ان کے رسول ان کے پاس روشن نشانیاں لائے تو اللہ کی شان نہ تھی کہ ان پر ظلم کرتا ہاں وہ خود ہی اپنی جانوں پر ظلم کرتے تھے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmcdxix{پھر جنہوں نے حد بھر کی برائی کی ان کا انجام یہ ہوا کہ اللہ کی آیتیں جھٹلانے لگے اور ان کے ساتھ تمسخر کرتے،\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmcdxx{اللہ پہلے بناتا ہے پھر دوبارہ بنائے گا پھر اس کی طرف پھروگے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxi{اور جس دن قیامت قائم ہوگی مجرموں کی آس ٹوٹ جائے گی\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxii{اور ان کے شریک ان کے سفارشی نہ ہوں گے اور وہ اپنے شریکوں سے منکر ہوجائیں گے،\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxiii{اور جس دن قیامت قائم ہوگی اس دن الگ ہوجائیں گے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxiv{تو وہ جو ایمان لائے اور اچھے کام کیے باغ کی کیاری میں ان کی خاطرداری ہوگی\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxv{اور جو کافر ہوئے اور ہماری آیتیں اور آخرت کا ملنا جھٹلایا وہ عذاب میں لادھرے (ڈال دیے) جائیں گے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxvi{تو اللہ کی پاکی بولو جب شام کرو اور جب صبح ہو\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxvii{اور اسی کی تعریف ہے آسمانوں اور زمین میں اور کچھ دن رہے اور جب تمہیں دوپہر ہو\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxviii{وہ زندہ کو نکالتا ہے مردے سے اور مردے کو نکالتا ہے زندہ سے اور زمین کو جٕلا تا ہے اس کے مرے پیچھے اور یوں ہی تم نکالے جاؤ گے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxix{اور اس کی نشانیوں سے ہے یہ کہ تمہیں پیدا کیا مٹی سے پھر جبھی تو انسان ہو دنیا میں پھیلے ہوئے،\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxx{اور اس کی نشانیوں سے ہے کہ تمہارے لیے تمہاری ہی جنس سے جوڑے بنائے کہ ان سے آرام پاؤ اور تمہارے آپس میں محبت اور رحمت رکھی بیشک اس میں نشانیاں ہیں دھیان کرنے والوں کے لیے،\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxi{اور اس کی نشانیوں سے ہے آسمانوں اور زمین کی پیدائش اور تمہاری زبانوں اور رنگتوں کا اختلاف بیشک اس میں نشانیاں ہیتں جاننے والوں کے لیے،\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxii{اور اس کی نشانیوں میں ہے رات اور دن میں تمہارا سونا اور اس کا فضل تلاش کرنا بیشک اس میں نشانیاں ہیں سننے والوں کے لیے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxiii{اور اس کی نشانیوں سے ہے کہ تمہیں بجلی دکھاتا ہے ڈراتی اور امید دلاتی اور آسمان سے پانی اتارتا ہے، تو اس سے زمین کو زندہ کرتا ہے اس کے مرے پیچھے، بیشک اس میں نشانیاں ہیں عقل والوں کے لیے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxiv{اور اس کی نشانیوں سے ہے کہ اس کے حکم سے آسمان اور زمین قائم ہیں پھر جب تمہیں زمین سے ایک ندا فرمائے گا جبھی تم نکل پڑو گے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxv{اور اسی کے ہیں جو کوئی آسمانوں اور زمین میں ہیں، سب اس کے زیر حکم ہیں،\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxvi{اور وہی ہے کہ اول بنا تا ہے پھر اسے دوبارہ بنائے گا اور یہ تمہاری سمجھ میں اس پر زیا دہ آسان ہونا چاہیے اور اسی کے لیے ہے سب سے برتر شان آسمانوں اور زمین میں اور وہی عزت و حکمت والا ہے،\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxvii{تمہارے لیے ایک کہاوت بیان فرماتا ہے خود تمہارے اپنے حال سے کیا تمہارے لیے تمہارے ہاتھ کے غلاموں میں سے کچھ شریک ہیں اس میں جو ہم نے تمہیں روزی دی تو تم سب اس میں برابر ہو تم ان سے ڈرو جیسے آپس میں ایک دوسرے سے ڈرتے ہو ہم ایسی مفصل نشانیاں بیان فرماتے ہیں عقل والوں کے لیے،\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxviii{بلکہ ظالم اپنی خواہشوں کے پیچھے ہولیے بے جانے تو اسے کون ہدایت کرے جسے خدا نے گمراہ کیا اور ان کا کوئی مددگار نہیں\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxix{تو اپنا منہ سیدھا کرو اللہ کی اطاعت کے لیے ایک اکیلے اسی کے ہوکر اللہ کی ڈالی ہوئی بنا جس پر لوگوں کو پیدا کیا اللہ کی بنائی چیز نہ بدلنا یہی سیدھا دین ہے، مگر بہت لوگ نہیں جانتے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmcdxl{اس کی طرف رجوع لاتے ہوئے اور اس سے ڈرو اور نماز قائم رکھو اور مشرکوں سے نہ ہو،\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmcdxli{ان میں سے جنہوں نے اپنے دین کو ٹکڑے ٹکڑے کردیا اور ہوگئے گروہ گروہ، ہر گروہ جو اس کے پاس ہے اسی پر خوش ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmcdxlii{اور جب لوگوں کو تکلیف پہنچتی ہے تو اپنے رب کو پکارتے ہیں اس کی طرف رجوع لاتے ہوئے پھر جب وہ انہیں اپنے پاس سے رحمت کا مزہ دیتا ہے جبھی ان میں سے ایک گروہ اپنے رب کا شریک ٹھہرانے لگتا ہے،\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmcdxliii{کہ ہمارے دیے کی ناشکری کریں، تو برت لو اب قریب جاننا چاہتے ہو\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmcdxliv{یا ہم نے ان پر کوئی سند اتاری کہ ہو انہیں ہمارے شریک بتارہی ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmcdxlv{اور جب ہم لوگوں کو رحمت کا مزہ دیتے ہیں اس پر خوش ہوجاتے ہیں اور اگر انہیں کوئی برائی پہنچے بدلہ اس کا جو ان کے ہاتھوں نے بھیجا جبھی وہ ناامید ہوجاتے ہیں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmcdxlvi{اور کیا انہوں نے نہ دیکھا کہ اللہ رزق وسیع فرماتا ہے جس کے لیے چاہے اور تنگی فرماتا ہے جس کے لیے چاہے بیشک اس میں نشانیاں ہیں ایمان والوں کے لیے،\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmcdxlvii{تو رشتہ دار کو اس کا حق دو اور مسکین اور مسافر کو یہ بہتر ہے ان کے لیے جو اللہ کی رضا چاہتے ہیں اور انہیں کا کام بنا،\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmcdxlviii{اور تم جو چیز زیادہ لینے کو دو کہ دینے والے کے مال بڑھیں تو وہ اللہ کے یہاں نہ بڑھے گی اور جو تم خیرات دو اللہ کی رضا چاہتے ہوئے تو انہیں کے دُونے ہیں\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmcdxlix{اللہ ہے جس نے تمہیں پیدا کیا پھر تمہیں روزی دی پھر تمہیں مارے گا پھر تمہیں جِلائے گا کیا تمہارے شریکوں میں بھی کوئی ایسا ہے جو ان کاموں میں سے کچھ کرے پاکی اور برتری ہے اسے ان کے شرک سے،\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmcdl{چمکی خرابی خشکی اور تری میں ان برائیوں سے جو لوگوں کے ہاتھوں نے کمائیں تاکہ انہیں ان کے بعض کوتکوں (برے کاموں) کا مزہ چکھائے کہیں وہ باز آئیں\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmcdli{تم فرماؤ زمین میں چل کر دیکھو کیا انجام ہوا اگلوں کا، ان میں بہت مشرک تھے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmcdlii{تو اپنا منہ سیدھا کر عبادت کے لیے قبل اس کے کہ وہ دن آئے جسے اللہ کی طرف ٹلنا نہیں اس دن الگ پھٹ جائیں گے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmcdliii{جو کفر کرے اس کے کفر کا وبال اسی پر اور جو اچھا کام کریں وہ اپنے ہی لیے تیاری کررہے ہیں\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmcdliv{تاکہ صلہ دے انہیں جو ایمان لائے اور اچھے کام کیے اپنے فضل سے، بیشک وہ کافروں کو دوست نہیں رکھتا،\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmcdlv{اور اس کی نشانیوں سے ہے کہ ہوائیں بھیجتا ہے مژدہ سناتی اور اس لیے کہ تمہیں اپنی رحمت کا ذائقہ دے اور اس لیے کہ کشتی اس کے حکم سے چلے اور اس لیے کہ اس کا فضل تلاش کرو اور اس لیے کہ تم حق مانو\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmcdlvi{اور بیشک ہم نے تم سے پہلے کتنے رسول ان کی قوم کی طرف بھیجے تو وہ ان کے پاس کھلی نشانیاں لائے پھر ہم نے مجرموں سے بدلہ لیا اور ہمارے ذمہٴ کرم پر ہے مسلمانوں کی مدد فرمانا\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmcdlvii{اللہ ہے کہ بھیجتا ہے ہوائیں کہ ابھارتی ہیں بادل پھر اسے پھیلادیتا ہے آسمان میں جیسا چاہے اور اسے پارہ پارہ کرتا ہے تو تُو دیکھے کہ اس کے یبچ میں مینھ نکل رہا ہے پھر جب اسے پہنچاتا ہے اپنے بندوں میں جس کی طرف چاہے جبھی وہ خوشیاں مناتے ہیں،\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmcdlviii{اگرچہ اس کے اتارنے سے پہلے آس توڑے ہوئے تھے،\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmcdlix{تو اللہ کی رحمت کے اثر دیکھو کیونکر زمین کو جِلاتا ہے اس کے مَرے پیچھے بیشک مردوں کو زندہ کرے گا اور وہ سب کچھ کرسکتا ہے،\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmcdlx{اور اگر ہم کوئی ہوا بھیجیں جس سے وہ کھیتی کو زرد دیکھیں تو ضرور اس کے بعد ناشکری کرنے لگے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxi{اس لیے کہ تم مُردوں کو نہیں سناتے اور نہ بہروں کو پکارنا سناؤ جب وہ پیٹھ دے کر پھیریں\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxii{اور نہ تم اندھوں کو ان کی گمراہی سے راہ پر لاؤ، تو تم اسی کو سناتے ہو جو ہماری آیتوں پر ایمان لائے تو وہ گردن رکھے ہوئے ہیں،\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxiii{اللہ ہے جس نے تمہیں ابتداء میں کمزور بنایا پھر تمہیں ناتوانی سے طاقت بخشی پھر قوت کے بعد کمزوری اور بڑھاپا دیا، بناتا ہے جو چاہے اور وہی علم و قدرت والا ہے،\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxiv{اور جس دن قیامت قائم ہوگی مجرم قسم کھائیں گے کہ نہ رہے تھے مگر ایک گھڑی وہ ایسے ہی اوندھے جاتے تھے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxv{اور بولے وہ جن کو علم اور ایمان مِلا بیشک تم رہے اللہ کے لکھے ہوئے میں اٹھنے کے دن تک تو یہ ہے وہ دن اٹھنے کا لیکن تم نہ جانتے تھے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxvi{تو اس دن ظالموں کو نفع نہ دے گی ان کی معذرت اور نہ ان سے کوئی راضی کرنا مانگے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxvii{اور بیشک ہم نے لوگوں کے لیے اس قرآن میں ہر قسم کی مثال بیان فرمائی اور اگر تم ان کے پاس کوئی نشانی لاؤ تو ضرور کافر کہیں گے تم تو نہیں مگر باطل پر،\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxviii{یوں ہی مہر کردیتا ہے اللہ جاہلوں کے دلوں پر\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxix{تو صبرکرو بیشک اللہ کا وعدہ سچا ہے اور تمہیں سبک نہ کردیں وہ جو یقین نہیں رکھتے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxx{\basmalahur الم\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxi{یہ حکمت والی کتاب کی آیتیں ہیں،\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxii{ہدایت اور رحمت ہیں نیکوں کے لیے،\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxiii{وہ جو نماز قائم رکھیں اور زکوٰة دیں اور آخرت پر یقین لائیں،\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxiv{وہی اپنے رب کی ہدایت پر ہیں اور انہیں کا کام بنا،\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxv{اور کچھ لوگ کھیل کی باتیں خریدتے ہیں کہ اللہ کی راہ سے بہکادیں بے سمجھے اور اسے ہنسی بنالیں، ان کے لیے ذلت کا عذاب ہے،\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxvi{اور جب اس پر ہماری آیتیں پڑھی جائیں تو تکبر کرتا ہوا پھرے جیسے انہیں سنا ہی نہیں جیسے اس کے کانوں میں ٹینٹ (روئی کا پھایا) ہے تو اسے دردناک عذاب کا مژدہ دو،\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxvii{بیشک جو ایمان لائے اور اچھے کام کیے ان کے لیے چین کے باغ ہیں،\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxviii{ہمیشہ ان میں رہیں گے، اللہ کا وعدہ ہے سچا، اور وہی عزت و حکمت والا ہے،\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxix{اس نے آسمان بنائے بے ایسے ستونوں کے جو تمہیں نظر آئیں اور زمین میں ڈالے لنگر کہ تمہیں لے کر نہ کانپے اور اس میں ہر قسم کے جانور پھیلائے، اور ہم نے آسمان سے پانی اتارا تو زمین میں ہر نفیس جوڑا اگایا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxx{یہ تو اللہ کا بنایا ہوا ہے مجھے وہ دکھاؤ جو اس کے سوا اوروں نے بنایا بلکہ ظالم کھلی گمراہی میں ہیں،\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxi{اور بیشک ہم نے لقمان کو حکمت عطا فرمائی کہ اللہ کا شکر کر اور جو شکر کرے وہ اپنے بھلے کو شکر کرتا ہے اور جو ناشکری کرے تو بیشک اللہ بے پرواہ ہے سب خوبیاں سراہا،\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxii{اور یاد کرو جب لقمان نے اپنے بیٹے سے کہا اور وہ نصیحت کرتا تھا اے میرے بیٹے اللہ کا کسی کو شریک نہ کرنا، بیشک شرک بڑا ظلم ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxiii{اور ہم نے آدمی کو اس کے ماں باپ کے بارے میں تاکید فرمائی اس کی ماں نے اسے پیٹ میں رکھا کمزوری پر کمزوری جھیلتی ہوئی اور اس کا دودھ چھوٹنا دو برس میں ہے یہ کہ حق مان میرا اور اپنے ماں باپ کا آخر مجھی تک آنا ہے،\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxiv{اور اگر وہ دونوں تجھ سے کوشش کریں کہ میرا شریک ٹھہرائے ایسی چیز کو جس کا تجھے علم نہیں تو ان کا کہنا نہ مان اور دنیا میں اچھی طرح ان کا ساتھ دے اور اس کی راہ چل جو میری طرف رجوع لایا پھر میری ہی طرف تمہیں پھر آنا ہے تو میں بتادوں گا جو تم کرتے تھے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxv{اے میرے بیٹے برائی اگر رائی کے دانہ برابر ہو پھر وہ پتھر کی چٹان میں یا آسمان میں یا زمین میں کہیں ہو اللہ اسے لے آئے گا بیشک اللہ ہر باریکی کا جاننے والا خبردار ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxvi{اے میرے بیٹے! نماز برپا رکھ اور اچھی بات کا حکم دے اور بری بات سے منع کر اور جو افتاد تجھ پر پڑے اس پر صبر کر، بیشک یہ ہمت کے کام ہیں\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxvii{اور کسی سے بات کرنے میں اپنا رخسارہ کج نہ کر اور زمین میں اِتراتا نہ چل، بیشک اللہ کو نہیں بھاتا کوئی اِتراتا فخر کرتا،\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxviii{اور میانہ چال چل اور اپنی آواز کچھ پست کر بیشک سب آوازوں میں بری آواز، آواز گدھے کی\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxix{کیا تم نے نہ دیکھا کہ اللہ نے تمہارے لیے کام میں لگائے جو کچھ آسمانوں اور زمین میں ہیں اور تمہیں بھرپور دیں اپنی نعمتیں ظاہر اور چھپی اور بعضے آدمی اللہ کے بارے میں جھگڑتے ہیں یوں کہ نہ علم نہ عقل نہ کوئی روشن کتاب\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmcdxc{اور جب ان سے کہا جائے اس کی پیروی کرو جو اللہ نے اتارا تو کہتے ہیں بلکہ ہم تو اس کی پیروی کریں گے جس پر ہم نے اپنے باپ دادا کوپایا کیا اگرچہ شیطان ان کو عذاب دوزخ کی طرف بلاتا ہو\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmcdxci{تو جو اپنا منہ اللہ کی طرف جھکادے اور ہو نیکوکار تو بیشک اس نے مضبوط گرہ تھامی، اور اللہ ہی کی طرف ہے سب کاموں کی انتہا،\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmcdxcii{اور جو کفر کرے تو تم اس کے کفر سے غم نہ کھاؤ، انھیں ہماری ہی طرف پھرنا ہے ہم انہیں بتادیں گے جو کرتے تھے بیشک اللہ دلوں کی بات جانتا ہے،\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmcdxciii{ہم انہیں کچھ برتنے دیں گے پھر انہیں بے بس کرکے سخت عذاب کی طرف لے جائیں گے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmcdxciv{اور اگر تم ان سے پوچھو کس نے بنائے آسمان اور زمین تو ضرور کہیں گے اللہ نے، تم فرماؤ سب خوبیاں اللہ کو بلکہ ان میں اکثر جانتے نہیں،\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmcdxcv{اللہ ہی کا ہے جو کچھ آسمانوں اور زمین میں ہے بیشک اللہ ہی بے نیاز ہے سب خوبیوں سراہا،\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmcdxcvi{اور اگر زمین میں جتنے پیڑ ہیں سب قلمیں ہوجائیں اور سمندر اس کی سیاہی ہو اس کے پیچھے سات سمندر اور تو اللہ کی باتیں ختم نہ ہوں گی بیشک اللہ عزت و حکمت والا ہے،\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmcdxcvii{تم سب کا پیدا کرنا اور قیامت میں اٹھانا ایسا ہی ہے جیسا ایک جان کا بیشک اللہ سنتا دیکھتا ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmcdxcviii{اے سننے والے کیا تو نے نہ دیکھا کہ اللہ رات لاتا ہے دن کے حصے میں اور دن کرتا ہے رات کے حصے میں اور اس نے سورج اور چاند کام میں لگائے ہر ایک ایک مقرر میعاد تک چلتا ہے اور یہ کہ اللہ تمہارے کاموں سے خبردار ہے،\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmcdxcix{یہ اس لیے کہ اللہ ہی حق ہے اور اس کے سوا جن کو پوجتے ہیں سب باطل ہیں اور اس لیے کہ اللہ ہی بلند بڑائی والا ہے،\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmd{کیا تو نے نہ دیکھا کہ کشتی دریا میں چلتی ہے، اللہ کے فضل سے تاکہ تمہیں وہ اپنی کچھ نشانیاں دکھائے بیشک اس میں نشانیاں ہیں ہر بڑے صبر کرنے والے شکرگزار کو\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmdi{اور جب ان پر آپڑتی ہے کوئی موج پہاڑوں کی طرح تو اللہ کو پکارتے ہیں نرے اسی پر عقیدہ رکھتے ہوئے پھر جب انہیں خشکی کی طرف بچا لاتا ہے تو ان میں کوئی اعتدال پر رہتا ہے اور ہماری آیتوں کا انکار نہ کرے گا مگر ہر بڑا بے وفا ناشکرا،\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmdii{اے لوگو! اپنے رب سے ڈرو اور اس دن کا خوف کرو جس میں کوئی باپ بچہ کے کام نہ آئے گا، اور نہ کوئی کامی (کاروباری) بچہ اپنے باپ کو کچھ نفع دے بیشک اللہ کا وعدہ سچا ہے تو ہرگز تمہیں دھوکا نہ دے دنیا کی زندگی اور ہرگز تمہیں اللہ کے علم پر دھوکہ نہ دے وہ بڑا فریبی\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmdiii{بیشک اللہ کے پاس ہے قیامت کا علم اور اتارتا ہے مینھ اور جانتا ہے جو کچھ ماؤں کے پیٹ میں ہے، اور کوئی جان نہیں جانتی کہ کل کیا کمائے گی اور کوئی جان نہیں جانتی کہ کس زمین میں مرے گی، بیشک اللہ جاننے والا بتانے والا ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmdiv{\basmalahur الم\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmdv{کتاب کا اتارنا بیشک پروردگار عالم کی طرف سے ہے،\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmdvi{کیا کہتے ہیں ان کی بنائی ہوئی ہے بلکہ وہی حق ہے تمہارے رب کی طرف سے کہ تم ڈراؤ ایسے لوگوں کو جن کے پاس تم سے پہلے کوئی ڈر سنانے والا نہ آیا اس امید پر کہ وہ راہ پائیں،\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmdvii{اللہ ہے جس نے آسمان اور زمین اور جو کچھ ان کے بیچ میں ہے چھ دن میں بنائے پھر عرش پر استوا فرمایا اس سے چھوٹ کر (لا تعلق ہوکر) تمہارا کوئی حمایتی اور نہ سفارشی تو کیا تم دھیان نہیں کرتے،\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmdviii{کام کی تدبیر فرماتا ہے آسمان سے زمین تک پھر اسی کی طرف رجوع کرے گا اس دن کہ جس کی مقدار ہزار برس ہے تمہاری گنتی میں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmdix{یہ ہے ہر نہاں اور عیاں کا جاننے والا عزت و رحمت والا،\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmdx{وہ جس نے جو چیز بتائی خوب بنائی اور پیدائش انسان کی ابتدا مٹی سے فرمائی\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmdxi{پھر اس کی نسل رکھی ایک بے قدر پانی کے خلاصہ سے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmdxii{پھر اسے ٹھیک کیا اور اس میں اپنی طرف کی روح پھونکی اور تمہیں کان اور آنکھیں اور دل عطا فرمائے کیا ہی تھوڑا حق مانتے ہو،\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmdxiii{اور بولے کیا جب ہم مٹی میں مل جائیں گے کیا پھر نئے بنیں گے، بلکہ وہ اپنے رب کے حضور حاضری سے منکر ہیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmdxiv{تم فرماؤ تمہیں وفات دیتا ہے موت کا فرشتہ جو تم پر مقرر ہے پھر اپنے رب کی طرف واپس جاؤ گے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmdxv{اور کہیں تم دیکھو جب مجرم اپنے رب کے پاس سر نیچے ڈالے ہوں گے اے ہمارے رب اب ہم نے دیکھا اور سنا ہمیں پھر بھیج کہ نیک کام کریں ہم کو یقین آگیا\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmdxvi{اور اگر ہم چاہتے ہر جان کو اس کی ہدایت فرماتے مگر میری بات قرار پاچکی کہ ضرور جہنم کو بھردوں گا ان جِنوں اور آدمیوں سب سے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmdxvii{اب چکھو بدلہ اس کا کہ تم اپنے اس دن کی حاضری بھولے تھے ہم نے تمہیں چھوڑ دیا اب ہمیشہ کا عذاب چکھو اپنے کیے کا بدلہ،\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmdxviii{ہماری آیتوں پر وہی ایمان لاتے ہیں کہ جب وہ انہیں یاد دلائی جاتی ہیں سجدہ میں گر جاتے ہیں اور اپنے رب کی تعریف کرتے ہوئے اس کی پاکی بولتے ہیں اور تکبر نہیں کرتے، السجدة۔۹\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmdxix{ان کی کروٹیں جدا ہوتی ہیں خوابگاہوں ہسے اور اپنے رب کو پکارتے ہیں ڈرتے اور امید کرتے اور ہمارے دیے ہوئے سے کچھ خیرات کرتے ہیں،\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmdxx{تو کسی جی کو نہیں معلوم جو آنکھ کی ٹھنڈک ان کے لیے چھپا رکھی ہے صلہ ان کے کاموں کا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmdxxi{تو کیا جو ایمان والا ہے وہ اس جیسا ہوجائے گا جو بے حکم ہے یہ برابر نہیں،\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmdxxii{جو ایمان لائے اور اچھے کام کیے ان کے لیے بسنے کے باغ ہیں، ان کے کاموں کے صلہ میں مہمانداری\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmdxxiii{رہے وہ جو بے حکم ہیں ان کا ٹھکانا آ گ ہے، جب کبھی اس میں سے نکلنا چاہیں گے پھر اسی میں پھیر دیے جائیں گے اور ان سے کہا جائے گا چکھو اس آگ کا عذاب جسے تم جھٹلاتے تھے،\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmdxxiv{اور ضرور ہم انہیں چکھائیں گے کچھ نزدیک کا عذاب اس بڑے عذاب سے پہلے جسے دیکھنے والا امید کرے کہ ابھی باز آئیں گے،\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmdxxv{اور اس سے بڑھ کر ظالم کون جسے اس کے رب کی آیتوں سے نصیحت کی گئی پھر اس نے ان سے منہ پھیر لیا بیشک ہم مجرموں سے بدلہ لینے والے ہیں،\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmdxxvi{اور بیشک ہم نے موسیٰ کو کتاب عطا فرمائی تو تم اس کے ملنے میں شک نہ کرو اور ہم نے اسے بنی اسرائیل کے لیے ہدایت کیا،\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmdxxvii{اور ہم نے ان میں سے کچھ امام بنائے کہ ہمارے حکم سے بناتے جبکہ انہوں نے صبر کیا اور وہ ہماری آیتوں پر یقین لاتے تھے،\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmdxxviii{بیشک تمہارا رب ان میں فیصلہ کردے گا قیامت کے دن جس بات میں اختلاف کرتے تھے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmdxxix{اور کیا انہیں اس پر ہدایت نہ ہوئی کہ ہم نے ان سے پہلے کتنی سنگتیں (قومیں) ہلاک کردیں کہ آج یہ ان کے گھروں میں چل پھر رہے ہیں بیشک اس میں ضرور نشانیاں ہیں تو کیا سنتے نہیں\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmdxxx{اور کیا نہیں دیکھتے کہ ہم پانی بھیجتے ہیں خشک زمین کی طرف پھر اس سے کھیتی نکالتے ہیں کہ اس میں سے ان کے چوپائے اور وہ خود کھاتے ہیں تو کیا انہیں سوجھتانہیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmdxxxi{اور کہتے ہیں یہ فیصلہ کب ہوگا اگر تم سچے ہو\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmdxxxii{تم فرماؤ فیصلہ کے دن کافروں کو ان کا ایمان لانا نفع نہ دے گا اور نہ انہیں مہلت ملے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmdxxxiii{تو ان سے منہ پھیرلو اور انتظار کرو بیشک انہیں بھی انتظار کرنا ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmdxxxiv{\basmalahur اے غیب کی خبریں بتانے والے (نبی) اللہ کا یوں ہی خوف رکھنا اور کافروں اور منافقوں کی نہ سننا بیشک اللہ علم و حکمت والا ہے،\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmdxxxv{اور اس کی پیروی رکھنا جو تمہارے رب کی طرف سے تمہیں وحی ہوتی ہے، اے لوگو! اللہ تمہارے کام دیکھ رہا ہے،\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmdxxxvi{اور اے محبوب! تم اللہ پر بھروسہ رکھو، اور اللہ بس ہے کام بنانے والا،\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmdxxxvii{اللہ نے کسی آدمی کے اندر دو دل نہ رکھے اور تمہاری ان عورتوں کو جنہیں تم کے برابر کہہ دو تمہاری ماں نہ بنایا اور نہ تمہارے لے پالکوں کو تمہارا بیٹا بنایا یہ تمہارے اپنے منہ کا کہنا ہے اور اللہ حق فرماتا ہے اور وہی راہ دکھاتا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmdxxxviii{انہیں ان کے باپ ہی کا کہہ کر پکارو یہ اللہ کے نزدیک زیادہ ٹھیک ہے پھر اگر تمہیں ان کے باپ معلوم نہ ہوں تو دین میں تمہارے بھائی ہیں اور بشریت میں تمہارے چچا زاد اور تم پر اس میں کچھ گناہ نہیں جو نا دانستہ تم سے صادر ہوا ہاں وہ گناہ ہے جو دل کے قصد سے کرو اور اللہ بخشنے والا مہربان ہے،\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmdxxxix{یہ نبی مسلمانوں کا ان کی جان سے زیادہ مالک ہے اور اس کی بیبیاں ان کی مائیں ہیں اور رشتہ والے اللہ کی کتاب میں ایک دوسرے سے زیادہ قریب ہیں بہ نسبت اور مسلمانوں اور مہاجروں کے مگر یہ کہ تم اپنے دوستوں پر احسان کرو یہ کتاب میں لکھا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmdxl{اور اے محبوب! یاد کرو جب ہم نے نبیوں سے عہد لیا اور تم سے اور نوح اور ابراہیم اور موسی ٰ اور عیسیٰ بن مریم سے اور ہم نے ان سے گاڑھا عہد لیا،\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmdxli{تاکہ سچوں سے ان کے سچ کا سوال کرے اور اس نے کافروں کے لیے دردناک عذاب تیار کر رکھا ہے،\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmdxlii{اے ایمان والو! اللہ کا احسان اپنے اوپر یاد کرو جب تم پر کچھ لشکر آئے تو ہم نے ان پر آندھی اور وہ لشکر بھیجے جو تمہیں نظر نہ آئے اور اللہ تمہارے کام دیکھتا ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmdxliii{جب کافر تم پر آئے تمہارے اوپر سے اور تمہارے نیچے سے اور جبکہ ٹھٹک کر رہ گئیں نگاہیں اور دل گلوں کے پاس آگئے اور تم اللہ پر طرح طرح کے گمان کرنے لگے امید و یاس کے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmdxliv{وہ جگہ تھی کہ مسلمانوں کی جانچ ہوئی اور خوب سختی سے جھنجھوڑے گئے،\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmdxlv{اور جب کہنے لگے منافق اور جن کے دلوں میں روگ تھا ہمیں اللہ و رسول نے وعدہ نہ دیا تھا مگر فریب کا\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmdxlvi{اور جب ان میں سے ایک گروہ نے کہا اے مدینہ والو! یہاں تمہارے ٹھہرنے کی جگہ نہیں تم گھروں کو واپس چلو اور ان میں سے ایک گروہ نبی سے اذن مانگتا تھا یہ کہہ کر ہمارے گھر بے حفاظت ہیں، اور وہ بے حفاظت نہ تھے، وہ تو نہ چاہتے تھے مگر بھاگنا،\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmdxlvii{اور اگر ان پر فوجیں مدینہ کے اطراف سے آئیں پھر ان سے کفر چاہتیں تو ضرور ان کا مانگا دے بیٹھتے اور اس میں دیر نہ کرتے مگر تھوڑی\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmdxlviii{اور بیشک اس سے پہلے وہ اللہ سے عہد کرچکے تھے کہ پیٹھ نہ پھیریں گے، اور اللہ کا وعدہ پوچھا جائے گا\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmdxlix{تم فرماؤ ہرگز تمہیں بھاگنا نفع نہ دے گا اگر موت یا قتل سے بھاگو اور جب بھی دنیا نہ برتنے دیے جاؤ گے مگر تھوڑی\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmdl{تم فرماؤ وہ کون ہے جو اللہ کا حکم تم پر سے ٹال دے اگر وہ تمہارا برا چاہے یا تم پر مہر (رحم) فرمانا چاہے اور وہ اللہ کے سوا کوئی حامی نہ پائیں گے نہ مددگار،\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmdli{بیشک اللہ جانتا ہے تمہارے ان کو جو اوروں کو جہاد سے روکتے ہیں اور اپنے بھائیوں سے کہتے ہیں ہماری طرف چلے آؤ اور لڑائی میں نہیں آتے مگر تھوڑے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmdlii{تمہاری مدد میں گئی کرتے (کمی کرتے) ہیں پھر جب ڈر کا وقت آئے تم انہیں دیکھو گے تمہاری طرف یوں نظر کرتے ہیں کہ ان کی آنکھیں گھوم رہی ہیں جیسے کسی پر موت چھائی ہو پھر جب ڈر کا وقت نکل جائے تمہیں طعنے دینے لگیں تیز زبانوں سے مال غنیمت کے لالچ میں یہ لوگ ایمان لائے ہی نہیں تو اللہ نے ان کے عمل اکارت کردیے اور یہ اللہ کو آسان ہے،\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmdliii{وہ سمجھ رہے ہیں کہ کافروں کے لشکر ابھی نہ گئے اور اگر لشکر دوبارہ آئیں تو ان کی خواہش ہوگی کہ کسی طرح گا نؤں میں نکل کر تمہاری خبریں پوچھتے اور اگر وہ تم میں رہتے جب بھی نہ لڑتے مگر تھوڑے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmdliv{بیشک تمہیں رسول اللہ کی پیروی بہتر ہے اس کے لیے کہ اللہ اور پچھلے دن کی امید رکھتا ہو اور اللہ کو بہت یاد کرے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmdlv{اور جب مسلمانوں نے کافروں کے لشکر دیکھے بولے یہ ہے وہ جو ہمیں وعدہ دیا تھا اللہ اور اس کے رسول نے اور سچ فرمایا اللہ اور اس کے رسول نے اور اس سے انہیں نہ بڑھا مگر ایمان اور اللہ کی رضا پر راضی ہونا،\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmdlvi{مسلمانوں میں کچھ وہ مرد ہیں جنہوں نے سچا کردیا جو عہد اللہ سے کیا تھا تو ان میں کوئی اپنی منت پوری کرچکا اور کوئی راہ دیکھ رہا ہے اور وہ ذرا نہ بدلے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmdlvii{تاکہ اللہ سچوں کو ان کے سچ کا صلہ دے اور منافقوں کو عذاب کرے اگر چاہے، یا انہیں توبہ دے، بیشک اللہ بخشنے والا مہربان ہے،\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmdlviii{اور اللہ نے کافروں کو ان کے دلوں کی جلن کے ساتھ پلٹایا کہ کچھ بھلا نہ پایا اور اللہ نے مسلمانوں کو لڑائی کی کفایت فرمادی اور اللہ زبردست عزت والا ہے،\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmdlix{اور جن اہلِ کتاب نے ان کی مدد کی تھی انہیں ان کے قلعوں سے اتارا اور ان کے دلوں میں رُعب ڈالا ان میں ایک گروہ کو تم قتل کرتے ہو اور ایک گروہ کو قید\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmdlx{اور ہم نے تمہارے ہاتھ لگائے ان کی زمین اور ان کی زمین اور ان کے مکان اور ان کے مال اور وہ زمین جس پر تم نے ابھی قدم نہیں رکھا ہے اور اللہ ہر چیز پر قادر ہے،\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmdlxi{اے غیب بتانے والے (نبی)! اپنی بیبیوں سے فرمادے اگر تم دنیا کی زندگی اور اس کی آرائش چاہتی ہو تو آؤ میں تمہیں مال دُوں اور اچھی طرح چھوڑ دُوں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmdlxii{اور اگر تم اللہ اور اس کے رسول اور آخرت کا گھر چاہتی ہو تو بیشک اللہ نے تمہاری نیکی والیوں کے لیے بڑا اجر تیار کر رکھا ہے،\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmdlxiii{اے نبی کی بیبیو! جو تم میں صریح حیا کے خلاف کوئی جرأت کرے اس پر اوروں سے دُونا عذاب ہوگا اور یہ اللہ کو آسان ہے،\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmdlxiv{اور جو تم میں فرمانبردار رہے اللہ اور رسول کی اور اچھا کام کرے ہم اسے اوروں سے دُونا ثواب دیں گے اور ہم نے اس کے لیے عزت کی روزی تیار کر رکھی ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmdlxv{اے نبی کی بیبیو! تم اور عورتوں کی طرح نہیں ہو اگر اللہ سے ڈرو تو بات میں ایسی نرمی نہ کرو کہ دل کا روگی کچھ لالچ کرے ہاں اچھی بات کہو\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmdlxvi{اور اپنے گھروں میں ٹھہری رہو اور بے پردہ نہ رہو جیسے اگلی جاہلیت کی بے پردگی اور نماز قائم رکھو اور زکوٰة دو اور اللہ اور اس کے رسول کا حکم مانو ا لله تو یہی چاہتا ہے، اے نبی کے گھر والو! کہ تم سے ہر ناپاکی دور فرما دے اور تمہیں پاک کرکے خوب ستھرا کردے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmdlxvii{اور یاد کرو جو تمہارے گھروں میں پڑھی جاتی ہیں اللہ کی آیتیں اور حکمت بیشک اللہ ہر باریکی جانتا خبردار ہے،\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmdlxviii{بیشک مسلمان مرد اور مسلمان عورتیں اور ایمان والے اور ایمان والیاں اور فرمانبردار اور فرمانبرداریں اور سچے اور سچیاں اور صبر والے اور صبر والیاں اور عاجزی کرنے والے اور عاجزی کرنے والیاں اور خیرات کرنے والے اور خیرات کرنے والیاں اور روزے والے اورروزے والیاں اور اپنی پارسائی نگاہ رکھنے والے اور نگاہ رکھنے والیاں اور اللہ کو بہت یاد کرنے والے اور یاد کرنے والیاں ان سب کے لیے اس نے بخشش اور بڑا ثواب تیار کر رکھا ہے،\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmdlxix{اور نہ کسی مسلمان مرد نہ مسلمان عورت کو پہنچتا ہے کہ جب اللہ و رسول کچھ حکم فرمادیں تو انہیں اپنے معاملہ کا کچھ اختیار رہے اور جو حکم نہ مانے اللہ اور اس کے رسول کا وہ بیشک صر یح گمراہی بہکا،\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmdlxx{اور اے محبوب! یاد کرو جب تم فرماتے تھے اس سے جسے اللہ نے اسے نعمت دی اور تم نے اسے نعمت دی کہ اپنی بی بی اپنے پاس رہنے دے اور اللہ سے ڈر اور تم اپنے دل میں رکھتے تھے وہ جسے اللہ کو ظاہر کرنا منظور تھا اور تمہیں لوگوں کے طعنہ کا اندیشہ تھا اور اللہ زیادہ سزاوار ہے کہ اس کا خوف رکھو پھر جب زید کی غرض اس سے نکل گئی تو ہم نے وہ تمہارے نکاح میں دے دی کہ مسلمانوں پر کچھ حرج نہ رہے ان کے لے پالکوں (منہ بولے بیٹوں) کی بیبیوں میں جب ان سے ان کا کام ختم ہوجائے اور اللہ کا حکم ہوکر رہنا،\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxi{نبی پر کوئی حرج نہیں اس بات میں جو اللہ نے اس کے لیے مقرر فرمائی اللہ کا دستور چلا آرہا ہے اس میں جو پہلے گزر چکے اور اللہ کا کام مقرر تقدیر ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxii{وہ جو اللہ کے پیام پہنچاتے اور اس سے ڈرتے اور اللہ کے سوا کسی کا خوف نہ کرے، اور اللہ بس ہے حساب لینے والا\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxiii{محمد تمہارے مردوں میں کسی کے باپ نہیں ہاں اللہ کے رسول ہیں اور سب نبیوں کے پچھلے اور اللہ سب کچھ جانتا ہے،\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxiv{اے ایمان والو اللہ کو بہت زیادہ یاد کرو،\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxv{اور صبح و شام اس کی پاکی بولو\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxvi{وہی ہے کہ درود بھیجتا ہے تم پر وہ اور اس کے فرشتے کہ تمہیں اندھیریوں سے اجالے کی طرف نکالے اور وہ مسلمانوں پر مہربان ہے،\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxvii{ان کے لیے ملتے وقت کی دعا سلام ہے اور ان کے لیے عزت کا ثواب تیار کر رکھا ہے،\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxviii{(اے غیب کی خبریں بتانے والے (نبی) بیشک ہم نے تمہیں بھیجا حاضر ناظر اور خوشخبری دیتا اور ڈر سناتا\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxix{اور اللہ کی طرف اس کے حکم سے بلاتا او ر چمکادینے دینے والا ا ٓ فتاب\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxx{اور ایمان والوں کو خوشخبری دو کہ ان کے لیے اللہ کا بڑا فضل ہے،\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxi{اور کافروں اور منافقوں کی خوشی نہ کرو اور ان کی ایذا پر درگزر فرماؤ اور اللہ پر بھروسہ رکھو، اور اللہ بس ہے کارساز،\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxii{اے ایمان والو! جب تم مسلمان عورتوں سے نکاح کرو پھر انہیں بے ہاتھ لگائے چھوڑ دو تو تمہارے لیے کچھ عدت نہیں جسے گنو تو انہیں کچھ فائدہ دو اور اچھی طرح سے چھوڑ دو\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxiii{اے غیب بتانے والے (نبی)! ہم نے تمہارے لیے حلال فرمائیں تمہاری وہ بیبیاں جن کو تم مہر دو اور تمہارے ہاتھ کا مال کنیزیں جو اللہ نے تمہیں غنیمت میں دیں اور تمہارے چچا کی بیٹیاں اور پھپیوں کی بیٹیاں اور ماموں کی بیٹیاں اور خالاؤں کی بیٹیاں جنہوں نے تمہارے ساتھ ہجرت کی اور ایمان والی عورت اگر وہ اپنی جان نبی کی نذر کرے اگر نبی اسے نکاح میں لانا چاہے یہ خاص تمہارے لیے ہہے امت کے لیے نہیں ہمیں معلوم ہے جو ہم نے مسلمانوں پر مقرر کیا ہے ان کی بیبیوں اور ان کے ہاتھ کی مال کنیزوں میں یہ خصوصیت تمہاری اس لیے کہ تم پر کوئی تنگی نہ ہو، اور اللہ بخشنے والا مہربان،\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxiv{پیچھے ہٹاؤ ان میں سے جسے چاہو اور اپنے پاس جگہ دو جسے چاہو اور جسے تم نے کنارے کردیا تھا اسے تمہارا جی چاہے تو اس میں بھی تم پر کچھ گناہ نہیں یہ امر اس سے نزدیک تر ہے کہ ان کی آنکھیں ٹھنڈی ہوں اور غم نہ کریں اور تم انہیں جو کچھ عطا فرماؤ اس پر وہ سب کی سب راضی رہیں اور اللہ جانتا ہے جو تم سب کے دلوں میں ہے، اور اللہ علم و حلم والا ہے،\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxv{ان کے بعد اور عورتیں تمہیں حلال نہیں اور نہ یہ کہ ان کے عوض اور بیبیاں بدلو اگرچہ تمہیں ان کا حسن بھائے مگر کنیز تمہارے ہاتھ کا مالک اور اللہ ہر چیز پر نگہبان ہے،\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxvi{اے ایمان والو! نبی کے گھروں میں نہ حاضر ہو جب تک اذن نہ پاؤ مثلاً کھانے کے لیے بلائے جاؤ نہ یوں کہ خود اس کے پکنے کی راہ تکو ہاں جب بلائے جاؤ تو حاضر ہو اور جب کھا چکو تو متفرق ہوجاؤ نہ یہ کہ بیٹھے باتوں میں دل بہلاؤ بیشک اس میں نبی کو ایذا ہوتی تھی تو وہ تمہارا لحاظ فرماتے تھے اور اللہ حق فرمانے میں نہیں شرماتا، اور جب تم ان سے برتنے کی کوئی چیز مانگو تو پردے کے باہر مانگو، اس میں زیادہ ستھرائی ہے تمہارے دلوں اور ان کے دلوں کی اور تمہیں نہیں پہنچتا کہ رسول اللہ کو ایذا دو اور نہ یہ کہ ان کے بعد کبھی ان کی بیبیوں سے نکاح کرو بیشک یہ اللہ کے نزدیک بڑی سخت بات ہے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxvii{اگر تم کوئی بات ظاہر کرو یا چھپاؤ تو بیشک سب کچھ جانتا ہے،\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxviii{ان پر مضائقہ نہیں ان کے باپ اور بیٹوں اور بھائیوں اور بھتیجوں اور بھانجوں اور اپنے دین کی عورتوں اور اپنی کنیزوں میں اور اللہ سے ڈرتی ہو، بیشک اللہ ہر چیز اللہ کے سامنے ہے،\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxix{بیشک اللہ اور اس کے فرشتے درود بھیجتے ہیں اس غیب بتانے والے (نبی) پر، اے ایمان والو! ان پر درود اور خوب سلام بھیجو\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmdxc{بیشک جو ایذا دیتے ہیں اللہ اور اس کے رسول کو ان پر اللہ کی لعنت ہے دنیا اور آخرت میں اور اللہ نے ان کے لیے ذلت کا عذاب تیار کر رکھا ہے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmdxci{اور جو ایمان والے مردوں اور عورتوں کو بے کئے ستاتے ہیں انہوں نے بہتان اور کھلا گناہ اپنے سر لیا\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmdxcii{اے نبی! اپنی بیبیوں اور صاحبزادیو ں اور مسلمانوں کی عورتوں سے فرمادو کہ اپنی چادروں کا ایک حصہ اپنے منہ پر ڈالے رہیں یہ اس سے نزدیک تر ہے کہ ان کی پہچان ہو تو ستائی نہ جائیں اور اللہ بخشنے والا مہربان ہے،\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmdxciii{اگر باز نہ آئے منافق اور جن کے دلوں میں روگ ہے اور مدینہ میں جھوٹ اڑانے والے تو ضرور ہم تمہیں ان پر شہ دیں گے پھر وہ مدینہ میں تمہارے پاس نہ رہیں گے مگر تھوڑے دن\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmdxciv{پھٹکارے ہوئے، جہاں کہیں ملیں پکڑے جائیں اور گن گن کر قتل کیے جائیں،\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmdxcv{اللہ کا دستور چلا آتا ہے ان لوگوں میں جو پہلے گزر گئے اور تم اللہ کا دستور ہرگز بدلتا نہ پاؤ گے،\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmdxcvi{لوگ تم سے قیامت کا پوچھتے ہیں تم فرماؤ اس کا علم تو اللہ ہی کے پاس ہے، اور تم کیا جانو شاید قیامت پاس ہی ہو\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmdxcvii{بیشک اللہ نے کافروں پر لعنت فرمائی اور ان کے لیے بھڑکتی آگ تیار کر رکھی ہے،\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmdxcviii{اس میں ہمیشہ رہیں گے اس میں نہ کوئی حمایتی پائیں گے نہ مددگار\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmdxcix{جس دن ان کے منہ الٹ الٹ کر آگ میں تلے جائیں گے کہتے ہوں گے ہائے کسی طرح ہم نے اللہ کا حکم مانا ہوتا اور رسول کا حکم مانا\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmdc{اور کہیں گے اے ہمارے رب! ہم اپنے سرداروں اور اپنے بڑوں کے کہنے پر چلے تو انہوں نے ہمیں راہ سے بہکادیا،\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmdci{اے ہمارے رب! انہیں آگ کا دُونا عذاب دے اور ان پر بڑی لعنت کر،\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmdcii{اے ایمان والو! ان جیسے نہ ہونا جنہوں نے موسیٰ کو ستایا تو اللہ نے اسے بَری فرمادیا اس بات سے جو انہوں نے کہی اور موسیٰ اللہ کے یہاں آبرو والا ہے\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmdciii{اے ایمان والو! اللہ سے ڈرو اور سیدھی بات کہو\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmdciv{تمہارے اعمال تمہارے لیے سنواردے گا اور تمہارے گناہ بخش دے گا، اور جو اللہ اور اس کے رسول کی فرمانبرداری کرے اس نے بڑی کامیابی پائی،\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmdcv{بیشک ہم نے امانت پیش فرمائی آسمانوں اور زمین اور پہاڑوں پر تو انہوں نے اس کے اٹھانے سے انکار کیا اور اس سے ڈر گئے اور آدمی نے اٹھالی، بیشک وہ اپنی جان کو مشقت میں ڈالنے والا بڑا نادان ہے،\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmdcvi{تاکہ اللہ عذاب منافق مردوں اور منافق عورتوں اور مشرک مردوں اور مشرک عورتوں کو اور اللہ توبہ قبول فرمائے مسلمان مردوں اور مسلمان عورتوں کی، اور اللہ بخشنے والا مہربان ہے،\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmdcvii{\basmalahur سب خوبیاں اللہ کو کہ اسی کا مال ہے جو کچھ آسمانوں میں ہے اور جو کچھ زمین میں اور آخرت میں اسی کی تعریف ہے اور وہی ہے حکمت والا خبردار،\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmdcviii{جانتا ہے جو کچھ زمین میں جاتا ہے اور جو زمین سے نکلتا ہے اور جو آسمان سے اترتا ہے اور جو اس میں چڑھتا ہے اور وہی ہے مہربان بخشنے والا،\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmdcix{اور کافر بولے ہم پر قیامت نہ آئے گی تم فرماؤ کیوں نہیں میرے رب کی قسم بیشک ضرور آئے گی غیب جاننے والا اس سے غیب نہیں ذرہ بھر کوئی چیز آسمانوں میں اور نہ زمین میں اور نہ اس سے چھوٹی اور نہ بڑی مگر ایک صاف بتانے والی کتاب میں ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmdcx{تاکہ صلہ دے انہیں جو ایمان لائے اور اچھے کام کیے یہ ہیں جن کے لیے بخشش ہے اور عزت کی روزی\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmdcxi{اور جنہوں نے ہماری آیتوں میں ہرانے کی کوشش کی ان کے لیے سخت عذاب دردناک میں سے عذاب ہے،\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmdcxii{اور جنہیں علم والا وہ جانتے ہیں کہ جو کچھ تمہاری طرف تمہارے رب کے پاس سے اترا وہی حق ہے اور عزت والے سب خوبیوں سراہے کی راہ بتاتا ہے،\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmdcxiii{اور کافر بولے کیا ہم تمہیں ایسا مرد بتادیں جو تمہیں خبر دے کہ جب تم پرزہ ہوکر بالکل ریزہ ہوکر بالکل ریزہ ریزہ ہوجاؤ تو پھر تمہیں نیا بَننا ہے،\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmdcxiv{کیا اللہ پر اس نے جھوٹ باندھا یا اسے سودا ہے بلکہ وہ جو آخرت پر ایمان نہیں لاتے عذاب اور دور کی گمراہی میں ہیں،\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmdcxv{تو کیا انہوں نے نہ دیکھا جو ان کے آگے اور پیچھے ہے آسمان اور زمین ہم چاہیں تو انہیں زمین میں دھنسادیں یا ان پر آسمان کا ٹکڑا گرادیں، بیشک اس میں نشانی ہے ہر رجوع لانے والے بندے کے لیے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmdcxvi{اور بیشک ہم نے داؤد کو اپنا بڑا فضل دیا اے پہاڑو! اس کے ساتھ اللہ کی رجوع کرو اور اے پرندو! اور ہم نے اس کے لیے لوہا نرم کیا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmdcxvii{کہ وسیع زِر ہیں بنا اور بنانے میں اندازے کا لحاظ رکھ اور تم سب نیکی کرو، بیشک تمہارے کام دیکھ رہا ہوں،\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmdcxviii{اور سلیمان کے بس میں ہوا کردی اس کی صبح کی منزل ایک مہینہ کی راہ اور شام کی منزل ایک مہینے کی راہ اور ہم نے اس کے لیے پگھلے ہوئے تانبے کا چشمہ بہایا اور جنوں میں سے وہ جو اس کے آگے کا م کرتے اس کے رب کے حکم سے ادر جو ان میں ہما رے حکم سے پھرے ہم اسے بھڑ کتی آ گ کا عذاب چکھائیں گے،\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmdcxix{اس کے لیے بناتے جو وہ چاہتا اونچے اونچے محل اور تصویریں اور بڑے حوضوں کے برابر لگن اور لنگردار دیگیں اے داؤد والو! شکر کرو اور میرے بندوں میں کم ہیں شکر والے،\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmdcxx{پھر جب ہم نے اس پر موت کا حکم بھیجا جنوں کو اس کی موت نہ بتائی مگر زمین کی دیمک نے کہ اس کا عصا کھاتی تھی، پھر جب سلیمان زمین پر آیا جِنوں کی حقیقت کھل گئی اگر غیب جانتے ہوتے تو اس خواری کے عذاب میں نہ ہوتے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxi{بیشک سبا کے لیے ان کی آبادی میں نشانی تھی دو باغ دہنے اور بائیں اپنے رب کا رزق کھاؤ اور اس کا شکر ادا کرو پاکیزہ شہر اور بخشنے والا رب\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxii{تو انہوں نے منہ پھیرا تو ہم نے ان پر زور کا اہلا (سیلاب) بھیجا اور ان کے باغوں کے عوض دو باغ انہیں بدل دیے جن میں بکٹا (بدمزہ) میوہ اور جھاؤ اور کچھ تھوڑی سی بیریاں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxiii{ہم نے انہیں یہ بدلہ دیا ان کی ناشکری کی سزا، اور ہم کسے سزا دیتے ہیں اسی کو جو نا شکرا ہے،\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxiv{اور ہم نے کیے تھے ان میں اور ان شہروں میں ہم نے برکت رکھی سر راہ کتنے شہر اور انہیں منزل کے اندازے پر رکھا ان میں چلو راتوں اور دنوں امن و امان سے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxv{تو بولے اے ہمارے رب! ہمیں سفر میں دوری ڈال اور انہوں نے خود اپنا ہی نقصان کیا تو ہم نے انہیں کہانیاں کردیا اور انہیں پوری پریشانی سے پراگندہ کردیا بیشک اس میں ضروری نشانیاں ہیں ہر بڑے صبر والے ہر بڑے شکر والے کے لیے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxvi{اور بیشک ابلیس نے انہیں اپنا گمان سچ کر دکھایا تو وہ اس کے پیچھے ہولیے مگر ایک گروہ کہ مسلمان تھا\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxvii{اور شیطان کا ان پر کچھ قابو نہ تھا مگر اس لیے کہ ہم دکھادیں کہ کون آخرت پر ایمان لاتا اور کون اس سے شک میں ہے، اور تمہارا رب ہر چیز پر نگہبان ہے،\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxviii{تم فرماؤ پکارو انہیں جنہیں اللہ کے سوا سمجھے بیٹھے ہو وہ ذرہ بھر کے مالک نہیں آسمانوں میں اور نہ زمین میں اور نہ ان کا ان دونوں میں کچھ حصہ اور نہ اللہ کا ان میں سے کوئی مددگار،\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxix{اور اس کے پاس شفاعت کام نہیں دیتی مگر جس کے لیے وہ اذن فرمائے، یہاں تک کہ جب اذن دے کر ان کے دلوں کی گھبراہٹ دور فرمادی جاتی ہے، ایک دوسرے سے کہتے ہیں تمہارے ربنے کیا ہی بات فرمائی، وہ کہتے ہیں جو فرمایا حق فرمایا اور وہی ہے بلند بڑائی والا،\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxx{تم فرماؤ کون جو تمہیں روزی دیتا ہے آسمانوں اور زمین سے تم خود ہی فرماؤ اللہ اور بیشک ہم یا تم یا تو ضرور ہدایت پر ہیں یا کھلی گمراہی میں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxi{تم فرماؤ ہم نے تمہارے گمان میں اگر کوئی جرم کیا تو اس کی تم سے پوچھ نہیں، نہ تمہارے کوتکوں کا ہم سے سوال\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxii{تم فرماؤ ہمارا رب ہم سب کو جمع کرے گا پھر ہم میں سچا فیصلہ فرمادے گا اور وہی ہے بڑا نیاؤ چکانے (درست فیصلہ کرنے) والا سب کچھ جانتا،\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxiii{تم فرماؤ مجھے دکھاؤ تو وہ شریک جو تم نے اس سے ملائے ہیں ہشت، بلکہ وہی ہے اللہ عزت والا حکمت والا،\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxiv{اور اے محبوب! ہم نے تم کو نہ بھیجا مگر ایسی رسالت سے جو تمام آدمیوں کو گھیرنے والی ہے خوشخبری دیتا اور ڈر سناتا لیکن بہت لوگ نہیں جانتے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxv{اور کہتے ہیں یہ وعدہ کب آئے گا اگر تم سچے ہو،\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxvi{تم فرماؤ تمہارے لیے ایک ایسے دن کا وعدہ جس سے تم نہ ایک گھڑی پیچھے ہٹ سکو اور نہ آگے بڑھ سکو\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxvii{اور کافر بولے ہم ہرگز نہ ایمان لائیں گے اس قرآن پر اور نہ ان کتابوں پر جو اس سے آگے تھیں اور کسی طرح تو دیکھے جب ظالم اپنے رب کے پاس کھڑے کیے جائیں گے، ان میں ایک دوسرے پر بات ڈالے گا وہ جو دبے تھے ان سے کہیں گے جو اونچے کھینچتے (بڑے بنے ہوئے) تھے اگر تم نہ ہوتے تو ہم ضرور ایمان لے آتے،\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxviii{وہ جو اونچے کھینچتے تھے ان سے کہیں گے جو دبے ہوئے تھے کیا ہم نے تمہیں روک دیا ہدایت سے بعد اس کے کہ تمہارے پاس آئی بلکہ تم خود مجرم تھے،\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxix{اور کہیں گے وہ جو دبے ہوئے تھے ان سے جو اونچے کھینچتے تھے بلکہ رات دن کا داؤں (فریب) تھا جبکہ تم ہمیں حکم دیتے تھے کہ اللہ کا انکار کریں اور اس کے برابر والے ٹھہرائیں، اور دل ہی دل میں پچھتانے لگے جب عذاب دیکھا اور ہم نے طوق ڈالے ان کی گردنوں میں جو منکر تھے وہ کیا بدلہ پائیں گے مگر وہی جو کچھ کرتے تھے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmdcxl{اور ہم نے جب کبھی کسی شہر میں کوئی ڈر سنانے والا بھیجا وہاں کے آسودوں (امیروں) نے یہی کہا کہ تم جو لے کر بھیجے گئے ہم اس کے منکر ہیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmdcxli{اور بولے ہم مال اور اولاد میں بڑھ کر ہیں اور ہم پر عذاب ہونا نہیں\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmdcxlii{تم فرماؤ بیشک میرا رب رزق وسیع کرتا ہے جس کے لیے چاہے اور تنگی فرماتا ہے لیکن بہت لوگ نہیں جانتے،\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmdcxliii{اور تمہارے مال اور تمہاری اولاد اس قابل نہیں کہ تمہیں ہمارے قریب تک پہنچائیں مگر وہ جو ایمان لائے اور نیکی کی ان کے لیے دُونا دُوں (کئی گنا) صلہ ان کے عمل کا بدلہ اور وہ بالاخانوں میں امن و امان سے ہیں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmdcxliv{اور ہو جو ہماری آیتوں میں ہرانے کی کوشش کرتے ہیں وہ عذاب میں لادھرے جائیں گے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmdcxlv{تم فرماؤ بیشک میرا رب رزق وسیع فرماتا ہے اپنے بندوں میں جس کے لیے چاہے اور تنگی فرماتا ہے جس کے لیے چاہے اور جو چیز تم اللہ کی راہ میں خرچ کرو وہ اس کے بدلے اور دے گا اور وہ سب سے بہتر رزق دینے والا\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmdcxlvi{اور جس دن ان سب کو اٹھائے گا پھر فرشتوں سے فرمائے گا کیا یہ تمہیں پوجتے تھے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmdcxlvii{وہ عرض کریں گے پاکی ہے تجھ کو تو ہمارا دوست ہے نہ وہ بلکہ وہ جِنوں کو پوجتے تھے ان میں اکثر انہیں پر یقین لائے تھے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmdcxlviii{تو آج تم میں ایک دوسرے کو بھلے برے کا کچھ اختیار نہ رکھے گا او رہم فرمائیں گے ظالموں سے اس آگ کا عذاب چکھو جسے تم جھٹلاتے تھے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmdcxlix{اور جب ان پر ہماری روشن آیتیں پڑھی جائیں تو کہتے ہیں یہ تو نہیں مگر ایک مرد کہ تمہیں روکنا چاہتے ہیں تمہارے باپ دادا کے معبودو ں سے اور کہتے ہیں یہ تو نہیں مگر بہتان جوڑا ہوا، اور کافروں نے حق کو کہا جب ان کے پاس آیا یہ تو نہیں مگر کھلا جادو،\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmdcl{اور ہم نے انہیں کچھ کتابیں نہ دیں جنہیں پڑھتے ہوں نہ تم سے پہلے ان کے پاس کوئی ڈر سنانے والا آیا\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmdcli{اور ان سے اگلوں نے جھٹلایا اور یہ اس کے دسویں کو بھی نہ پہنچے جو ہم نے انہیں دیا تھا پھر انہوں نے میرے رسولوں کو جھٹلایا تو کیسا ہوا میرا انکا کرنا\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmdclii{تم فرماؤ میں تمہیں ایک نصیحت کرتا ہوں کہ اللہ کے لیے کھڑے رہو دو دو اور اکیلے اکیلے پھر سوچو کہ تمہارے ان صاحب میں جنون کی کوئی بات نہیں، وہ تو نہیں مگر نہیں مگر تمہیں ڈر سنانے والے ایک سخت عذاب کے آگے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmdcliii{تم فرماؤ میں نے تم سے اس پر کچھ اجر مانگا ہو تو وہ تمہیں کو میرا اجر تو اللہ ہی پر ہے اور وہ ہر چیز پر گواہ ہے،\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmdcliv{تم فرماؤ بیشک میرا رب حق پر القا فرماتا ہے بہت جاننے والا سب نبیوں کا،\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmdclv{تم فرماؤ حق آیا اور باطل نہ پہل کرے اور نہ پھر کر آئے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmdclvi{تم فرماؤ اگر میں بہکا تو اپنے ہی برے کو بہکا اور اگر میں نے راہ پائی تو اس کے سبب جو میرا رب میری طرف وحی فرماتا ہے بیشک وہ سننے والا نزدیک ہے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmdclvii{اور کسی طرح تو دیکھے جب وہ گھبراہٹ میں ڈالے جائیں گے پھر بچ کر نہ نکل سکیں گے اور ایک قریب جگہ سے پکڑ لیے جائیں گے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmdclviii{اور کہیں گے ہم اس پر ایمان لائے اور اب وہ اسے کیونکر پائیں اتنی دور جگہ سے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmdclix{کہ پہلے تو اس سے کفر کرچکے تھے، اور بے دیکھے پھینک مارتے ہیں دور مکان سے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmdclx{اور روک کردی گئی ان میں اور اس میں جسے چاہتے ہیں جیسے ان کے پہلے گروہوں سے کیا گیا تھا بیشک وہ دھوکا ڈالنے والے شک میں تھے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmdclxi{\basmalahur سب خوبیاں اللہ کو جو آسمانوں اور زمین کا بنانے والا فرشتوں کو رسول کرنے والا جن کے دو دو تین تین چار چار پر ہیں، بڑھاتا ہے آفرینش (پیدائش) میں جو چاہے بیشک اللہ ہر چیز پر قادر ہے،\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmdclxii{اللہ جو رحمت لوگوں کے لیے کھولے اس کا کوئی روکنے والا نہیں، اور جو کچھ روک لے تو اس کی روک کے بعد اس کا کوئی چھوڑنے والا نہیں، اور وہی عزت و حکمت والا ہے،\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmdclxiii{اے لوگو! اپنے اوپر اللہ کا احسان یاد کرو کیا اللہ کے سوا اور بھی کوئی خالق ہے کہ آسمان اور زمین سے تمہیں روزی دے، اس کے سوا کوئی معبود نہیں، تو تم کہاں اوندھے جاتے ہو\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmdclxiv{اور اگر یہ تمہیں جھٹلائیں تو بیشک تم سے پہلے کتنے ہی رسول جھٹلائے گئے اور سب کام اللہ ہی کی طرف سے پھرتے ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmdclxv{اے لوگو! بیشک اللہ کا وعدہ سچ ہے تو ہرگز تمہیں دھوکا نہ دے دنیا کی زندگی، اور ہرگز تمہیں اللہ کے حکم پر فریب نہ دے وہ بڑا فریبی\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmdclxvi{بیشک شیطان تمہارا دشمن ہے تو تم بھی اسے دشمن سمجھو وہ تو اپنے گروہ کو اسی لیے بلاتا ہے کہ دوزخیوں میں ہوں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmdclxvii{کافروں کے لیے سخت عذاب ہے، اور جو ایمان لائے اور اچھے کام کیے ان کے لیے بخشش اور بڑا ثواب ہے،\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmdclxviii{تو کیا وہ جس کی نگاہ میں اس کا برا کام آراستہ کیا گیا کہ اس نے اسے بھلا سمجھا ہدایت والے کی طرح ہوجائے گا اس لیے اللہ گمراہ کرتا ہے جسے چاہے اور راہ دیتا ہے جسے چاہے، تو تمہاری جان ان پر حسرتوں میں نہ جائے اللہ خوب جانتا ہے جو کچھ وہ کرتے ہیں،\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmdclxix{اور اللہ ہے جس نے بھیجیں ہوائیں کہ بادل ابھارتی ہیں، پھر ہم اسے کسی مردہ شہر کی طرف رواں کرتے ہیں تو اس کے سبب ہم زمین کو زندہ فرماتے ہیں اس کے مرے پیچھے یونہی حشر میں اٹھنا ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmdclxx{جسے عزت کی چاہ ہو تو عزت تو سب اللہ کے ہاتھ ہے اسی کی طرف چڑھتا ہے پاکیزہ کلام اور جو نیک کام سے وہ اسے بلند کرتا ہے اور وہ جو برے داؤں (فریب) کرتے ہیں ان کے لیے سخت عذاب ہے اور انہیں کا مکر برباد ہوگا (ف۲۸\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxi{اور اللہ نے تمہیں بنایا مٹی سے پھر پانی کی بوند سے پھر تمہیں کیا جوڑے جوڑے اور کسی مادہ کو پیٹ نہیں رہتا اور نہ وہ جتنی ہے مگر اس کے علم سے، اور جس بڑی عمر والے کو عمر دی جائے یا جس کسی کی عمر کم رکھی جائے یہ سب ایک کتاب میں ہے بیشک یہ اللہ کو آسان ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxii{اور دونوں سمندر ایک سے نہیں یہ میٹھا ہے خوب میٹھا پانی خوشگوار اور یہ کھاری ہے تلخ اور ہر ایک میں سے تم کھاتے ہو تازہ گوشت اور نکالتے ہو پہننے کا ایک گہنا (زیور) اور تو کشتیوں کو اس میں دیکھے کہ پانی چیرتی ہیں تاکہ تم اس کا فضل تلاش کرو اور کسی طرح حق مانو\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxiii{رات لاتا ہے دن کے حصہ میں اور دن لاتا ہے رات کے حصہ میں اور اس نے کام میں لگائے سورج اور چاند ہر ایک ایک مقرر میعاد تک چلتا ہے یہ ہے اللہ تمہارا رب اسی کی بادشاہی ہے، اور اس کے سوا جنہیں تم پوجتے ہو دانہ خُرما کے چھلکے تک کے مالک نہیں،\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxiv{تم انہیں پکارو تو وہ تمہاری پکار نہ سنیں، اور بالفرض سن بھی لیں تو تمہاری حاجت روانہ کرسکیں اور قیامت کے دن وہ تمہارے شرک سے منکر ہوں گے اور تجھے کوئی نہ بتائے گا اس بتانے والے کی طرح\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxv{اے لوگو! تم سب اللہ کے محتاج اور اللہ ہی بے نیاز ہے سب خوبیوں سراہا،\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxvi{وہ چاہے تو تمہیں لے جائے اور نئی مخلوق لے آئے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxvii{اور یہ اللہ پر کچھ دشوار نہیں،\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxviii{اور کوئی بوجھ اٹھانے والی جان دوسرے کا بوجھ نہ اٹھائے گی اور اگر کوئی بوجھ والی اپنا بوجھ بٹانے کو کسی کو بلائے تو اس کے بوجھ میں سے کوئی کچھ نہ اٹھائے گا اگرچہ قریب رشتہ دار ہو اے محبوب! تمہارا ڈر سناتا انہیں کو کام دیتا ہے جو بے دیکھے اپنے رب! سے ڈرتے ہیں اور نماز قائم رکھتے ہیں، اور جو ستھرا ہوا تو اپنے ہی بھلے کو ستھرا ہوا اور اللہ ہی کی طرف پھرنا ہے،\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxix{اور برابر نہیں اندھا اور انکھیارا\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxx{اور نہ اندھیریاں اور اجالا\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxi{اور نہ سایہ اور نہ تیز دھوپ\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxii{اور برابر نہیں زندے اور مردے بیشک اللہ سنا تا ہے جسے چاہے اور تم نہیں سنانے والے انہیں جو قبروں میں پڑے ہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxiii{تم تو یہی ڈر سنانے والے ہو\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxiv{اے محبوب! بیشک ہم نے تمہیں حق کے ساتھ بھیجا خوشخبری دیتا اور ڈر سنا تا اور جو کوئی گروہ تھا سب میں ایک ڈر سنانے والا گزر چکا\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxv{اور اگر یہ تمہیں جھٹلائیں تو ان سے اگلے بھی جھٹلاچکے ہیں ان کے پاس ان کے رسول آئے روشن دلیلیں اور صحیفے اور چمکتی کتاب لے کر،\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxvi{پھر میں نے کافروں کو پکڑا تو کیسا ہوا میرا انکار\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxvii{کیا تو نے نہ دیکھا کہ اللہ نے آسمان سے پانی اتارا تو ہم نے اس سے پھل نکالے رنگ برنگ اور پہاڑوں میں راستے ہیں سفید اور سرخ رنگ رنگ کے او رکچھ کالے بھوچنگ (سیاہ کالے)\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxviii{اور آدمیوں اور جانوروں اور چوپایوں کے رنگ یونہی طرح طرح کے ہیں اللہ سے اس کے بندوں میں وہی ڈرتے ہیں جو علم والے ہیں بیشک اللہ بخشنے والا عزت والا ہے،\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxix{بیشک وہ جو اللہ کی کتاب پڑھتے ہیں اور نماز قائم رکھتے اور ہمارے دیے سے کچھ ہماری راہ میں خرچ کرتے ہیں پوشیدہ اور ظاہر وہ ایسی تجارت کے امیدوار ہیں جس میں ہرگز ٹوُٹا (نقصان) نہیں،\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmdcxc{تاکہ ان کے ثواب انہیں بھرپور دے اور اپنے فضل سے اور زیادہ عطا کرے، بیشک وہ بخشنے والا قدر فرمانے والا ہے،\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmdcxci{اور ہو کتاب جو ہم نے تمہاری طرف وحی بھیجی وہی حق ہے اپنے سے اگلی کتابوں کی تصدیق فرماتی ہوئی، بیشک اللہ اپنے بندوں سے خبردار دیکھنے والا ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmdcxcii{پھر ہم نے کتاب کا وارث کیا اپنے چُنے ہوئے بندوں کو تو ان میں کوئی اپنی جان پر ظلم کرتا ہے اور ان میں کوئی میانہ چال پر ہے، اور ان میں کوئی وہ ہے جو اللہ کے حکم سے بھلائیوں میں سبقت لے گیا یہی بڑا فضل ہے،\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmdcxciii{بسنے کے باغوں میں داخل ہوں گے وہ ان میں سونے کے کنگن اور موتی پہنائے جائیں گے اور وہاں ان کی پوشاک ریشمی ہے،\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmdcxciv{اور کہیں گے سب خوبیاں اللہ کو جس نے ہمارا غم دور کیا بیشک ہمارا رب بخشنے والا قدر فرمانے والا ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmdcxcv{وہ جس نے ہمیں آرام کی جگہ اتارا اپنے فضل سے، ہمیں اس میں نہ کوئی تکلیف پہنچے نہ ہمیں اس میں کوئی تکان لاحق ہو،\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmdcxcvi{اور جنہوں نے کفر کیا ان کے لیے جہنم کی آگ ہے نہ ان کی قضا آئے کہ مرجائیں اور نہ ان پر اس کا عذاب کچھ ہلکا کیاجائے، ہم ایسی ہی سزا دیتے ہیں ہر بڑے ناشکرے کو،\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmdcxcvii{اور وہ اس میں چلاتے ہوں گے اے ہمارے رب! ہمیں نکال کہ ہم اچھا کام کریں اس کے خلاف جو پہلے کرتے تھے اور کیا ہم نے تمہیں وہ عمر نہ دی تھی جس میں سمجھ لیتا جسے سمجھنا ہوتا اور ڈر سنانے والا تمہارے پاس تشریف لایا تھا تو اب چکھو کہ ظالموں کا کوئی مددگار نہیں،\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmdcxcviii{بیشک اللہ جاننے والا ہے آسمانوں اور زمین کی ہر چھپی بات کا، بیشک وہ دلوں کی بات جانتا ہے،\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmdcxcix{وہی ہے جس نے تمہیں زمین میں اگلوں کا جانشین کیا تو جو کفر کرے اس کا کفر اسی پر پڑے اور کافروں کو ان کا کفر ان کے رب کے یہاں نہیں بڑھائے گا مگر بیزاری اور کافروں کو ان کا کفر نہ بڑھائے گا مگر نقصان\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmdcc{تم فرماؤ بھلا بتلاؤ تو اپنے وہ شریک جنہیں اللہ کے سوا پوجتے ہو مجھے دکھاؤ انہوں نے زمین میں سے کونسا حصہ بنایا یا آسمانوں میں کچھ ان کا ساجھا ہے یا ہم نے انہیں کوئی کتاب دی ہے کہ وہ اس کی روشن دلیلوں پر ہیں بلکہ ظالم آپس میں ایک دوسرے کو وعدہ نہیں دیتے مگر فریب کا\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmdcci{بیشک اللہ روکے ہوئے ہے آسمانوں اور زمین کو کہ جنبش نہ کریں اور اگر وہ ہٹ جائیں تو انہیں کون روکے اللہ کے سوا، بیشک وہ علم بخشنے والا ہے،\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmdccii{اور انہوں نے اللہ کی قسم کھائی اپنی قسموں میں حد کی کوشش سے کہ اگر ان کے پاس کوئی ڈر سنانے والا آیا تو وہ ضرور کسی نہ کسی گروہ سے زیادہ راہ پر ہوں گے پھر جب ان کے پاس ڈر سنانے والا تشریف لایا تو اس نے انہیں نہ بڑھا مگر نفرت کرنا\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmdcciii{اپنی جان کو زمین میں اونچا کھینچنا اور برا داؤں اور برا داؤں (فریب) اپنے چلنے والے ہی پر پڑتا ہے تو کا ہے کے انتظار میں ہیں مگر اسی کے جو اگلوں کا دستور ہوا تو تم ہرگز اللہ کے دستور کو بدلتا نہ پاؤ گے اور ہرگز اللہ کے قانون کو ٹلتا نہ پاؤ گے،\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmdcciv{اور کیا انہوں نے زمین میں سفر نہ کیا کہ دیکھتے ان سے اگلوں کا کیسا انجام ہوا اور وہ ان سے زور میں سخت تھے اور اللہ وہ نہیں جس کے قابو سے نکل سکے کوئی شئے آسمانوں اور نہ زمین میں، بیشک وہ علم و قدرت والا ہے،\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmdccv{اور اگر اللہ لوگوں کو ان کے کیے پر پکڑتا تو زمین کی پیٹھ پر کوئی چلنے والا نہ چھوڑتا لیکن ایک مقرر میعاد تک انہیں ڈھیل دیتا ہے پھر جب ان کا وعدہ آئے گا تو بیشک اللہ کے سب بندے اس کی نگاہ میں ہیں\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmdccvi{\basmalahur یسٰں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmdccvii{حکمت والے قرآن کی قسم،\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmdccviii{بیشک تم\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmdccix{سیدھی راہ پر بھیجے گئے ہو\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmdccx{عزت والے مہربان کا اتارا ہوا،\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmdccxi{تاکہ تم اس قوم کو ڈر سناؤ جس کے باپ دادا نہ ڈرائے گئے تو وہ بے خبر ہیں،\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmdccxii{بیشک ان میں اکثر پر بات ثابت ہوچکی ہے تو وہ ایمان نہ لائیں گے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmdccxiii{ہم نے ان کی گردنو ں میں طوق کردیے ہیں کہ وہ ٹھوڑیوں تک ہیں تو یہ اوپر کو منہ اٹھائے رہ گئے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmdccxiv{اور ہم نے ان کے آگے دیوار بنادی اور ان کے پیچھے ایک دیوار اور انہیں اوپر سے ڈھانک دیا تو انہیں کچھ نہیں سوجھتا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmdccxv{اور انہیں ایک سا ہے تم انہیں ڈراؤٕ یا نہ ڈراؤ وہ ایمان لانے کے نہیں،\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmdccxvi{تم تو اسی کو ڈر سناتے ہو جو نصیحت پر چلے اور رحمن سے بے دیکھے ڈرے، تو اسے بخشش اور عزت کے ثواب کی بشارت دو\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmdccxvii{بیشک ہم مُردوں کو جِلائیں گے اور ہم لکھ رہے ہیں جو انہوں نے آگے بھیجا اور جو نشانیاں پیچھے چھوڑ گئے اور ہر چیز ہم نے گن رکھی ہے ایک بتانے والی کتاب میں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmdccxviii{اور ان سے نشانیاں بیان کرو اس شہر والوں کی جب ان کے پاس فرستادے (رسول) آئے،\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmdccxix{جب ہم نے ان کی طرف دو بھیجے پھر انہوں نے ان کو جھٹلایا تو ہم نے تیسرے سے زور دیا اب ان سب نے کہا کہ بیشک ہم تمہاری طرف بھیجے گئے ہیں،\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmdccxx{بولے تم تو نہیں مگر ہم جیسے آدمی اور رحمن نے کچھ نہیں اتارا تم نرے جھوٹے ہو،\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxi{وہ بولے ہمارا رب جانتا ہے کہ بیشک ضرور ہم تمہاری طرف بھیجے گئے ہیں،\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxii{اور ہمارے ذمہ نہیں مگر صاف پہنچا دینا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxiii{بولے ہم تمہیں منحوس سمجھتے ہیں بیشک اگر تم باز نہ آئے تو ضرور ہم تمہیں سنگسار کریں گے بیشک ہمارے ہاتھوں تم پر دکھ کی مار پڑے گی،\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxiv{انہوں نے فرمایا تمہاری نحوست تو تمہارے ساتھ ہے کیا اس پر بدکتے ہو کہ تم سمجھائے گئے بلکہ تم حد سے بڑھنے والے لوگ ہو\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxv{اور شہر کے پرلے کنارے سے ایک مرد دوڑتا آیا بولا، اے میری قوم! بھیجے ہوؤں کی پیروی کرو،\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxvi{ایسوں کی پیروی کرو جو تم سے کچھ نیگ (اجر) نہیں مانگتے اور وہ راہ پر ہیں،\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxvii{اور مجھے کیا ہے کہ اس کی بندگی نہ کروں جس نے مجھے پیدا کیا اور اسی کی طرف تمہیں پلٹنا ہے،\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxviii{کیا اللہ کے سوا اور خدا ٹھہراؤں کہ اگر رحمٰن میرا کچھ برا چاہے تو ان کی سفارش میرے کچھ کام نہ آئے اور نہ وہ مجھے بچاسکیں،\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxix{بیشک جب تو میں کھلی گمراہی میں ہو\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxx{مقرر میں تمہارے رب پر ایمان لایا تو میری سنو\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxi{اس سے فرمایا گیا کہ جنت میں داخل ہو کہا کسی طرح میری قوم جانتی،\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxii{جیسی میرے رب نے میری مغفرت کی اور مجھے عزت والوں میں کیا\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxiii{اور ہم نے اس کے بعد اس کی قوم پر آسمان سے کوئی لشکر نہ اتارا اور نہ ہمیں وہاں کوئی لشکر اتارنا تھا،\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxiv{وہ تو بس ایک ہی چیخ تھی جبھی وہ بجھ کر رہ گئے،\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxv{اور کہا گیا کہ ہائے افسوس ان بندوں پر جب ان کے پاس کوئی رسول آتا ہے تو اس سے ٹھٹھا ہی کرتے ہیں،\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxvi{کیا انہوں نے نہ دیکھا ہم نے ان سے پہلے کتنی سنگتیں ہلاک فرمائیں کہ وہ اب ان کی طرف پلٹنے والے نہیں\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxvii{اور جتنے بھی ہیں سب کے سب ہمارے حضور حاضر لائے جائیں گے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxviii{اور ان کے لیے ایک نشانی مردہ زمین ہے ہم نے اسے زندہ کیا اور پھر اس سے اناج نکالا تو اس میں سے کھاتے ہیں،\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxix{اور ہم نے اس میں باغ بنائے کھجوروں اور انگو روں کے اور ہم نے اس میں کچھ چشمے بہائے کہ،\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmdccxl{اس کے پھلوں میں سے کھائیں اور یہ ان کے ہاتھ کے بنائے نہیں تو کیا حق نہ مانیں گے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmdccxli{پاکی ہے اسے جس نے سب جوڑے بنائے ان چیزوں سے جنہیں زمین اگاتی ہے اور خود ان سے اور ان چیزوں سے جن کی انہیں خبر نہیں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmdccxlii{اور ان کے لیے ایک نشانی رات ہے ہم اس پر سے دن کھینچ لیتے ہیں جبھی وہ اندھیروں میں ہیں،\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmdccxliii{اور سورج چلتا ہے اپنے ایک ٹھہراؤ کے لیے یہ حکم ہے زبردست علم والے کا\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmdccxliv{اور چاند کے لیے ہم نے منزلیں مقرر کیں یہاں تک کہ پھر ہوگیا جیسے کھجور کی پرانی ڈال (ٹہنی)\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmdccxlv{سورج کو نہیں پہنچتا کہ چاند کو پکڑے اور نہ رات دن پر سبقت لے جائے اور ہر ایک، ایک گھیرے میں پیر رہا ہے،\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmdccxlvi{اور ان کے لیے نشانی یہ ہے کہ انہیں ان بزرگوں کی پیٹھ میں ہم نے بھری کشتی میں سوار کیا\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmdccxlvii{اور ان کے لیے ویسی ہی کشتیاں بنادیں جن پر سوار ہوتے ہیں،\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmdccxlviii{اور ہم چاہیں تو انہیں ڈبودیں تو نہ کوئی ان کی فریاد کو پہنچنے والا ہو اور نہ وہ بچائے جائیں،\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmdccxlix{مگر ہماری طرف کی رحمت اور ایک وقت تک برتنے دینا\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmdccl{اور جب ان سے فرمایا جاتا ہے ڈرو تم اس سے جو تمہارے سامنے ہے اور جو تمہارے پیچھے آنے والا ہے اس امید پر کہ تم پر مہر ہو تو منہ پھیر لیتے ہیں،\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmdccli{اور جب کبھی ان کے رب کی نشانیوں سے کوئی نشانی ان کے پاس آتی ہے تو اس سے منہ پھیرلیتے ہیں،\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmdcclii{اور جب ان سے فرمایا جائے اللہ کے دیے میں سے کچھ اس کی راہ میں خرچ کرو تو کافر مسلمانوں کے لیے کہتے ہیں کہ کیا ہم اسے کھلائیں جسے اللہ چاہتا تو کھلادیتا تم تو نہیں مگر کھلی گمراہی میں،\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmdccliii{اور کہتے ہیں کب آئے گا یہ وعدہ اگر تم سچے ہو\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmdccliv{راہ نہیں دیکھتے مگر ایک چیخ کی کہ انہیں آلے گی جب وہ دنیا کے جھگڑے میں پھنسے ہوں گے،\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmdcclv{تو نہ وصیت کرسکیں گے اور نہ اپنے گھر پلٹ کرجائیں\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmdcclvi{اور پھونکا جائے گا صور جبھی وہ قبروں سے اپنے رب کی طرف دوڑتے چلیں گے،\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmdcclvii{کہیں گے ہائے ہماری خرابی کس نے ہمیں سوتے سے جگادیا یہ ہے وہ جس کا رحمٰن نے وعدہ دیا تھا اور رسولوں نے حق فرمایا\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmdcclviii{وہ تو نہ ہوگی مگر ایک چنگھاڑ جبھی وہ سب کے سب ہمارے حضور حاضر ہوجائیں گے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmdcclix{تو آج کسی جان پر کچھ ظلم نہ ہوگا اور تمہیں بدلا نہ ملے گا اپنے کیے کا،\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmdcclx{بیشک جنت والے آج دل کے بہلاووں میں چین کرتے ہیں\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxi{وہ اور ان کی بیبیاں سایوں میں ہیں، تختوں پر تکیہ لگائے،\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxii{ان کے لیے اس میں میوہ ہے اور ان کے لیے ہے اس میں جو مانگیں،\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxiii{ان پر سلام ہوگا، مہربان رب کا فرمایا ہوا\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxiv{اور آج الگ پھٹ جاؤ، اے مجرمو!\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxv{اے اولاد آدم کیا میں نے تم سے عہد نہ لیا تھا کہ شیطان کو نہ پوجنا بیشک وہ تمہارا کھلا دشمن ہے،\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxvi{اور میری بندگی کرنا یہ سیدھی راہ ہے،\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxvii{اور بیشک اس نے تم میں سے بہت سی خلقت کو بہکادیا، تو کیا تمہیں عقل نہ تھی\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxviii{یہ ہے وہ جہنم جس کا تم سے وعدہ تھا،\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxix{آج اسی میں جاؤ بدلہ اپنے کفر کا،\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxx{آج ہم ان کے مونھوں پر مہر کردیں گے اور ان کے ہاتھ ہم سے بات کریں گے اور ان پاؤں ان کے کئے کی گواہی دیں گے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxi{اور اگر ہم چاہتے تو ان کی آنکھیں مٹادیتے پھر لپک کر رستہ کی طرف جاتے تو انہیں کچھ نہ سوجھتا\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxii{اور اگر ہم چاہتے تو ان کے گھر بیٹھے ان کی صورتیں بدل دیتے نہ آگے بڑھ سکتے نہ پیچھے لوٹتے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxiii{اور جسے ہم بڑی عمر کا کریں اسے پیدائش میں الٹا پھیریں تو کیا سمجھے نہیں\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxiv{اور ہم نے ان کو شعر کہنا نہ سکھایا اور نہ وہ ان کی شان کے لائق ہے، وہ تو نہیں مگر نصیحت اور روشن قرآن\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxv{کہ اسے ڈرائے جو زندہ ہو اور کافروں پر بات ثابت ہوجائے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxvi{اور کیا انہوں نے نہ دیکھا کہ ہم نے اپنے ہاتھ کے بنائے ہوئے چوپائے ان کے لیے پیدا کیے تو یہ ان کے مالک ہیں،\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxvii{اور انہیں ان کے لیے نرم کردیا تو کسی پر سوار ہوتے ہیں اور کسی کو کھاتے ہیں،\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxviii{اور ان کے لیے ان میں کئی طرح کے نفع اور پینے کی چیزیں ہیں تو کیا شکر نہ کریں گے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxix{اور انہوں نے اللہ کے سوا اور خدا ٹھہرالیے کہ شاید ان کی مدد ہو\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxx{وہ ان کی مدد نہیں کرسکتے اور وہ ان کے لشکر سب گرفتار حاضر آئیں گے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxi{تو تم ان کی بات کا غم نہ کرو بیشک ہم جانتے ہیں جو وہ چھپاتے ہیں اور ظاہر کرتے ہیں\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxii{اور کیا آدمی نے نہ دیکھا کہ ہم نے اسے پانی کی بوند سے بنایا جبھی وہ صریح جھگڑالو ہے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxiii{اور ہمارے لیے کہاوت کہتا ہے اور اپنی پیدائش بھول گیا بولا ایسا کون ہے کہ ہڈیوں کو زندہ کرے جب وہ بالکل گل گئیں،\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxiv{تم فرماؤ وہ زندہ کرے گا جس نے پہلی بار انہیں بنایا، اور اسے ہر پیدائش کا علم ہے\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxv{جس نے تمہارے لیے ہرے پیڑ میں ا ٓ گ پیدا کی جبھی تم اس سے سلگاتے ہو\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxvi{اور کیا وہ جس نے آسمان اور زمین بنائے ان جیسے اور نہیں بناسکتا کیوں نہیں اور وہی بڑا پیدا کرنے والا سب کچھ جانتا،\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxvii{اس کا کام تو یہی ہے کہ جب کسی چیز کو چاہے تو اس سے فرمائے ہو جا وہ فوراً ہوجاتی ہے،\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxviii{تو پاکی ہے، اسے جس کے ہاتھ ہر چیز کا قبضہ ہے، اور اسی کی طرف پھیرے جاؤ گے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxix{\basmalahur قسم ان کی کہ باقاعدہ صف باندھیں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmdccxc{پھر ان کی کہ جھڑک کر چلائیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmdccxci{پھر ان جماعتوں کی، کہ قرآن پڑھیں،\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmdccxcii{بیشک تمہارا معبود ضرور ایک ہے،\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmdccxciii{مالک آسمانوں اور زمین کا اور جو کچھ ان کے درمیان ہے اور مالک مشرقوں کا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmdccxciv{اور بیشک ہم نے نیچے کے آسمان کو تاروں کے سنگھار سے آراستہ کیا،\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmdccxcv{اور نگاہ رکھنے کو ہر شیطان سرکش سے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmdccxcvi{عالم بالا کی طرف کان نہیں لگاسکتے اور ان پر ہر طرف سے مار پھینک ہوتی ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmdccxcvii{انہیں بھگانے کو اور ان کے لیے ہمیشہ کا عذاب،\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmdccxcviii{مگر جو ایک آدھ بار اُچک لے چلا تو روشن انگار اس کے پیچھے لگا،\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmdccxcix{تو ان سے پوچھو کیا ان کی پیدائش زیادہ مضبوط ہے یا ہماری اور مخلوق آسمانوں اور فرشتوں وغیرہ کی بیشک ہم نے ان کو چپکتی مٹی سے بنایا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmdccc{بلکہ تمہیں اچنبھا آیا اور وہ ہنسی کرتے ہیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmdccci{اور سمجھائے نہیں سمجھتے،\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmdcccii{اور جب کوئی نشانی دیکھتے ہیں ٹھٹھا کرتے ہیں،\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmdccciii{اور کہتے ہیں یہ تو نہیں مگر کھلا جادو،\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmdccciv{کیا جب ہم مر کر مٹی اور ہڈیاں ہوجائیں گے کیا ہم ضرور اٹھائے جائیں گے،\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmdcccv{اور کیا ہمارے اگلے باپ دادا بھی\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmdcccvi{تم فرماؤ ہاں یوں کہ ذلیل ہو کے،\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmdcccvii{تو وہ تو ایک ہی جھڑک ہے جبھی وہ دیکھنے لگیں گے،\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmdcccviii{اور کہیں گے ہائے ہماری خرابی ان سے کہا جائے گا یہ انصاف کا دن ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmdcccix{یہ ہے وہ فیصلے کا دن جسے تم جھٹلاتے تھے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmdcccx{ہانکو ظالموں اور ان کے جوڑوں کو اور جو کچھ وہ پوجتے تھے،\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxi{اللہ کے سوا، ان سب کو ہانکو راہِ دوزخ کی طرف،\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxii{اور انہیں ٹھہراؤ ان سے پوچھنا ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxiii{تمہیں کیا ہوا ایک دوسرے کی مدد کیوں نہیں کرتے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxiv{بلکہ وہ آج گردن ڈالے ہیں\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxv{اور ان میں ایک نے دوسرے کی طرف منہ کیا آپس میں پوچھتے ہوئے،\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxvi{بولے تم ہمارے دہنی طرف سے بہکانے آتے تھے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxvii{جواب دیں گے تم خود ہی ایمان نہ رکھتے تھے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxviii{اور ہمارا تم پر کچھ قابو نہ تھا بلکہ تم سرکش لوگ تھے،\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxix{تو ثابت ہوگئی ہم پر ہمارے رب کی بات ہمیں ضرور چکھنا ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxx{تو ہم نے تمہیں گمراہ کیا کہ ہم خود گمراہ تھے،\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxi{تو اس دن وہ سب کے سب عذاب میں شریک ہیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxii{مجرموں کے ساتھ ہم ایسا ہی کرتے ہیں،\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxiii{بیشک جب ان سے کہا جاتا تھا کہ اللہ کے سوا کسی کی بندگی نہیں تو اونچی کھینچتے (تکبر کرتے) تھے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxiv{اور کہتے تھے کیا ہم اپنے خداؤں کو چھوڑدیں ایک دیوانہ شاعر کے کہنے سے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxv{بلکہ وہ تو حق لائے ہیں اور انہوں نے رسولوں کی تصدیق فرمائی\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxvi{بیشک تمہیں ضرور دکھ کی مار چکھنی ہے،\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxvii{تو تمہیں بدلہ نہ ملے گا مگر اپنے کیے کا\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxviii{مگر جو اللہ کے چُنے ہوئے بندے ہیں\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxix{ان کے لیے وہ روزی ہے جو ہمارے علم میں ہیں،\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxx{میوے اور ان کی عزت ہوگی،\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxi{چین کے باغوں میں،\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxii{تختوں پر ہوں گے آمنے سامنے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxiii{ان پر دورہ ہوگا نگاہ کے سامنے بہتی شراب کے جام کا\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxiv{سفید رنگ پینے والوں کے لیے لذت\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxv{نہ اس میں خمار ہے اور نہ اس سے ان کا سَر پِھرے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxvi{اور ان کے پاس ہیں جو شوہروں کے سوا دوسری طرف آنکھ اٹھا کر نہ دیکھیں گی\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxvii{بڑی آنکھوں والیاں گویا وہ انڈے ہیں پوشیدہ رکھے ہوئے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxviii{تو ان میں ایک نے دوسرے کی طرف منہ کیا پوچھتے ہوئے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxix{ان میں سے کہنے والا بولا میرا ایک ہمنشین تھا\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxl{مجھ سے کہا کرتا کیا تم اسے سچ مانتے ہو\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxli{کیا جب ہم مر کر مٹی اور ہڈیاں ہوجائیں گے تو کیا ہمیں جزا سزا دی جائے گی\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxlii{کہا کیا تم جھانک کر دیکھو گے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxliii{پھر جھانکا تو اسے بیچ بھڑکتی آگ میں دیکھا\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxliv{کہا خدا کی قسم قریب تھا کہ تو مجھے ہلاک کردے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxlv{اور میرا رب فضل نہ کرے تو ضرور میں بھی پکڑ کر حاضر کیا جاتا\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxlvi{تو کیا ہمیں مرنا نہیں،\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxlvii{مگر ہماری پہلی موت اور ہم پر عذاب نہ ہوگا\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxlviii{بیشک یہی بڑی کامیابی ہے،\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxlix{ایسی ہی بات کے لیے کامیوں کو کام کرنا چاہیے،\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmdcccl{تو یہ مہمانی بھلی یا تھوہڑ کا پیڑ\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmdcccli{بیشک ہم نے اسے ظالموں کی جانچ کیا ہے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmdccclii{بیشک وہ ایک پیڑ ہے کہ جہنم کی جڑ میں نکلتا ہے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmdcccliii{اس کا شگوفہ جیسے دیووں کے سر\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmdcccliv{پھر بیشک وہ اس میں سے کھائیں گے پھر اس سے پیٹ بھریں گے،\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmdccclv{پھر بیشک ان کے لیے اس پر کھولتے پانی کی ملونی (ملاوٹ) ہے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmdccclvi{پھر ان کی بازگشت ضرور بھڑکتی آگ کی طرف ہے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmdccclvii{بیشک انہوں نے اپنے باپ دادا گمراہ پائے،\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmdccclviii{تو وہ انہیں کے نشان قدم پر دوڑے جاتے ہیں\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmdccclix{اور بیشک ان سے پہلے بہت سے اگلے گمراہ ہوئے\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmdccclx{اور بیشک ہم نے ان میں ڈر سنانے والے بھیجے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxi{تو دیکھو ڈرائے گیوں کا کیسا انجام ہوا\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxii{مگر اللہ کے چُنے ہوئے بندے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxiii{اور بیشک ہمیں نوح نے پکارا تو ہم کیا ہی اچھے قبول فرمانے والے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxiv{اور ہم نے اسے اور اس کے گھر والوں کو بڑی تکلیف سے نجات دی،\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxv{اور ہم نے اسی کی اولاد باقی رکھی\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxvi{اور ہم نے پچھلوں میں اس کی تعریف باقی رکھی\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxvii{نوح پر سلام ہو جہاں والوں میں\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxviii{بیشک ہم ایسا ہی صلہ دیتے ہیں نیکوں کو،\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxix{بیشک وہ ہمارے اعلیٰ درجہ کے کامل الایمان بندوں میں ہے،\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxx{پھر ہم نے دوسروں کو ڈبو دیا\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxi{اور بیشک اسی کے گروہ سے ابراہیم ہے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxii{جبکہ اپنے رب کے پاس حاضر ہوا غیر سے سلامت دل لے کر\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxiii{جب اس نے اپنے باپ اور اپنی قوم سے فرمایا تم کیا پوجتے ہو،\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxiv{کیا بہتان سے اللہ کے سوا اور خدا چاہتے ہو،\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxv{تو تمہارا کیا گمان سے رب العالمین پر\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxvi{پھر اس نے ایک نگاہ ستاروں کو دیکھا\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxvii{پھر کہا میں بیمار ہونے والا ہوں\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxviii{تو وہ اس پر پیٹھ دے کر پھر گئے\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxix{پھر ان کے خداؤں کی طرف چھپ کر چلا تو کہا کیا تم نہیں کھاتے\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxx{تمہیں کیا ہوا کہ نہیں بولتے\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxi{تو لوگوں کی نظر بچا کر انہیں دہنے ہاتھ سے مارنے لگا\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxii{تو کافر اس کی طرف جلدی کرتے آئے\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxiii{فرمایا کیا اپنے ہاتھ کے تراشوں کو پوجتے ہو،\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxiv{اور اللہ نے تمہیں پیدا کیا اور تمہارے اعمال کو\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxv{بولے اس کے لیے ایک عمارت چنو پھر اسے بھڑکتی آگ میں ڈال دو،\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxvi{تو انہوں نے اس پر داؤں چلنا (فریب کرنا) چاہا ہم نے انہیں نیچا دکھایا\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxvii{اور کہا میں اپنے رب کی طرف جانے والا ہوں اب وہ مجھے راہ دے گا\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxviii{الٰہی مجھے لائق اولاد دے،\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxix{تو ہم نے اسے خوشخبری سنائی ایک عقل مند لڑکے کی،\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxc{پھر جب وہ اس کے ساتھ کام کے قابل ہوگیا کہا اے میرے بیٹے میں نے خواب دیکھا میں تجھے ذبح کرتا ہوں اب تو دیکھ تیری کیا رائے ہے کہا اے میرے باپ کی جیئے جس بات کا آپ کو حکم ہوتا ہے، خدا نے چاہتا تو قریب ہے کہ آپ مجھے صابر پائیں گے،\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxci{تو جب ان دونوں نے ہمارے حکم پر گردن رکھی اور باپ نے بیٹے کو ماتھے کے بل لٹایا اس وقت کا حال نہ پوچھ\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxcii{اور ہم نے اسے ندائی فرمائی کہ اے ابراہیم،\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxciii{بیشک تو نے خواب سچ کردکھایا ہم ایسا ہی صلہ دیتے ہیں نیکوں کو،\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxciv{بیشک یہ روشن جانچ تھی،\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxcv{اور ہم نے ایک بڑا ذبیحہ اس کے فدیہ میں دے کر اسے بچالیا\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxcvi{اور ہم نے پچھلوں میں اس کی تعریف باقی رکھی،\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxcvii{سلام ہو ابراہیم پر\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxcviii{ہم ایسا ہی صلہ دیتے ہیں نیکوں کو،\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxcix{بیشک وہ ہمارے اعلیٰ درجہ کے کامل الایمان بندوں میں ہیں،\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mmmcm{اور ہم نے اسے خوشخبری دی اسحاق کی کہ غیب کی خبریں بتانے والا نبی ہمارے قربِ خاص کے سزاواروں میں\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@mmmcmi{اور ہم نے برکت اتاری اس پر اور اسحاق پر اور ان کی اولاد میں کوئی اچھا کام کرنے والا اور کوئی اپنی جان پر صریح ظلم کرنے والا\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@mmmcmii{اور بیشک ہم نے موسیٰ اور ہارون پر احسان فرمایا\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@mmmcmiii{اور انہیں اور ان کی قوم کو بڑی سختی سے نجات بخشی\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@mmmcmiv{اور ان کی ہم نے مدد فرمائی تو وہی غالب ہوئے\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@mmmcmv{اور ہم نے ان دونوں کو روشن کتاب عطا فرمائی\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@mmmcmvi{اور ان کو سیدھی راہ دکھائی،\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@mmmcmvii{اور پچھلوں میں ان کی تعریف باقی رکھی،\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@mmmcmviii{سلام ہو موسیٰ اور ہارون پر،\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@mmmcmix{بیشک ہم ایسا ہی صلہ دیتے ہیں نیکوں کو،\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@mmmcmx{بیشک وہ دونوں ہمارے اعلیٰ درجہ کے کامل الایمان بندوں میں ہیں،\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@mmmcmxi{اور بیشک الیاس پیغمبروں سے ہے\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@mmmcmxii{جب اس نے اپنی قوم سے فرمایا کیا تم ڈرتے نہیں\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@mmmcmxiii{کیا بعل کو پوجتے ہو اور چھوڑتے ہو سب سے اچھا پیدا کرنے والے اللہ کو،\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@mmmcmxiv{جو رب ہے تمہارا اور تمہارے اگلے باپ دادا کا\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@mmmcmxv{پھر انہو ں نے اسے جھٹلایا تو وہ ضرور پکڑے آئیں گے\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@mmmcmxvi{مگر اللہکے چُنے ہوئے بندے\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@mmmcmxvii{اور ہم نے پچھلوں میں اس کی ثنا باقی رکھی،\qt@no{(129)}}%
\qt@newcmd\qurantrans@ur@mmmcmxviii{سلام ہو الیاس پر،\qt@no{(130)}}%
\qt@newcmd\qurantrans@ur@mmmcmxix{بیشک ہم ایسا ہی صلہ دیتے ہیں نیکوں کو،\qt@no{(131)}}%
\qt@newcmd\qurantrans@ur@mmmcmxx{بیشک وہ ہمارے اعلیٰ درجہ کے کامل الایمان بندوں میں ہے،\qt@no{(132)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxi{اور بیشک لوط پیغمبروں میں ہے،\qt@no{(133)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxii{جبکہ ہم نے اسے اور اس کے سب گھر والوں کو نجات بخشی،\qt@no{(134)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxiii{مگر ایک بڑھیا کہ رہ جانے والوں میں ہوئی\qt@no{(135)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxiv{پھر دوسروں کو ہم نے ہلاک فرمادیا\qt@no{(136)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxv{او ربیشک تم ان پر گزرتے ہو صبح کو،\qt@no{(137)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxvi{اور رات میں تو کیا تمہیں عقل نہیں\qt@no{(138)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxvii{اور بیشک یونس پیغمبروں سے ہے،\qt@no{(139)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxviii{جبکہ بھری کشتی کی طرف نکل گیا\qt@no{(140)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxix{تو قرعہ ڈالا تو ڈھکیلے ہوؤں میں ہوا،\qt@no{(141)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxx{پھر اسے مچھلی نے نگل لیا اور وہ اپنے آپ کو ملامت کرتا تھا\qt@no{(142)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxi{تو اگر وہ تسبیح کرنے والا نہ ہوتا\qt@no{(143)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxii{ضرور اس کے پیٹ میں رہتا جس دن تک لوگ اٹھائے جائیں گے\qt@no{(144)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxiii{پھر ہم نے اسے میدان میں ڈال دیا اور وہ بیمار تھا\qt@no{(145)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxiv{اور ہم نے اس پر کدو کا پیڑ اگایا\qt@no{(146)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxv{اور ہم نے اسے لاکھ آدمیوں کی طرف بھیجا بلکہ زیادہ،\qt@no{(147)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxvi{تو وہ ایمان لے آئے تو ہم نے انہیں ایک وقت تک برتنے دیا\qt@no{(148)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxvii{تو ان سے پوچھو کیا تمہارے رب کے لیے بیٹیاں ہیں اور ان کے بیٹے\qt@no{(149)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxviii{یا ہم نے ملائکہ کو عورتیں پیدا کیا اور وہ حاضر تھے\qt@no{(150)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxix{سنتے ہو بیشک وہ اپنے بہتان سے کہتے ہیں،\qt@no{(151)}}%
\qt@newcmd\qurantrans@ur@mmmcmxl{کہ اللہ کی اولاد ہے اور بیشک وہ ضرور جھوٹے ہیں،\qt@no{(152)}}%
\qt@newcmd\qurantrans@ur@mmmcmxli{کیا اس نے بیٹیاں پسند کیں بیٹے چھوڑ کر،\qt@no{(153)}}%
\qt@newcmd\qurantrans@ur@mmmcmxlii{تمہیں کیا ہے، کیسا حکم لگاتے ہو\qt@no{(154)}}%
\qt@newcmd\qurantrans@ur@mmmcmxliii{تو کیا دھیان نہیں کرتے\qt@no{(155)}}%
\qt@newcmd\qurantrans@ur@mmmcmxliv{یا تمہارے لیے کوئی کھلی سند ہے،\qt@no{(156)}}%
\qt@newcmd\qurantrans@ur@mmmcmxlv{تو اپنی کتاب لاؤ اگر تم سچے ہو،\qt@no{(157)}}%
\qt@newcmd\qurantrans@ur@mmmcmxlvi{اور اس میں اور جنوں میں رشتہ ٹھہرایا اور بیشک جنوں کو معلوم ہے کہ وہ ضرور حاضر لائے جائیں گے\qt@no{(158)}}%
\qt@newcmd\qurantrans@ur@mmmcmxlvii{پاکی ہے اللہ کو ان باتوں سے کہ یہ بتاتے ہیں،\qt@no{(159)}}%
\qt@newcmd\qurantrans@ur@mmmcmxlviii{مگر اللہ کے چُنے ہوئے بندے\qt@no{(160)}}%
\qt@newcmd\qurantrans@ur@mmmcmxlix{تو تم اور جو کچھ تم اللہ کے سوا پوجتے ہو\qt@no{(161)}}%
\qt@newcmd\qurantrans@ur@mmmcml{تم اس کے خلاف کسی کو بہکانے والے نہیں\qt@no{(162)}}%
\qt@newcmd\qurantrans@ur@mmmcmli{مگر اسے جو بھڑکتی آگ میں جانے والا ہے\qt@no{(163)}}%
\qt@newcmd\qurantrans@ur@mmmcmlii{اور فرشتے کہتے ہیں ہم میں ہر ایک کا ایک مقام معلوم ہے\qt@no{(164)}}%
\qt@newcmd\qurantrans@ur@mmmcmliii{اور بیشک ہم پر پھیلائے حکم کے منتظر ہیں،\qt@no{(165)}}%
\qt@newcmd\qurantrans@ur@mmmcmliv{اور بیشک ہم اس کی تسبیح کرنے والے ہیں،\qt@no{(166)}}%
\qt@newcmd\qurantrans@ur@mmmcmlv{اور بیشک وہ کہتے تھے\qt@no{(167)}}%
\qt@newcmd\qurantrans@ur@mmmcmlvi{اگر ہمارے پاس اگلوں کی کوئی نصیحت ہوتی\qt@no{(168)}}%
\qt@newcmd\qurantrans@ur@mmmcmlvii{تو ضرور ہم اللہ کے چُنے ہوئے بندے ہوتے\qt@no{(169)}}%
\qt@newcmd\qurantrans@ur@mmmcmlviii{تو اس کے منکر ہوئے تو عنقریب جان لیں گے\qt@no{(170)}}%
\qt@newcmd\qurantrans@ur@mmmcmlix{اور بیشک ہمارا کلام گزر چکا ہے ہمارے بھیجے ہوئے بندوں کے لیے،\qt@no{(171)}}%
\qt@newcmd\qurantrans@ur@mmmcmlx{کہ بیشک انہیں کی مدد ہوگی،\qt@no{(172)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxi{اور بیشک ہمارا ہی لشکر غالب آئے گا،\qt@no{(173)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxii{تو ایک وقت تم ان سے منہ پھیر لو\qt@no{(174)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxiii{اور انہیں دیکھتے رہو کہ عنقریب وہ دیکھیں گے\qt@no{(175)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxiv{تو کیا ہمارے عذاب کی جلدی کرتے ہیں،\qt@no{(176)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxv{پھر جب اترے گا ان کے آنگن میں تو ڈرائے گیوں کی کیا ہی بری صبح ہوگی،\qt@no{(177)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxvi{اور ایک وقت تک ان سے منہ پھیرلو،\qt@no{(178)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxvii{اور انتظار کرو کہ وہ عنقریب دیکھیں گے،\qt@no{(179)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxviii{پاکی ہے تمہارے رب کو عزت والے رب کو ان کی باتوں سے\qt@no{(180)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxix{اور سلام ہے پیغمبروں پر\qt@no{(181)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxx{اور سب خوبیاں اللہ کو سارے جہاں کا رب ہے،\qt@no{(182)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxi{\basmalahur اس نامور قرآن کی قسم\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxii{بلکہ کافر تکبر اور خلاف میں ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxiii{ہم نے ان سے پہلے کتنی سنگتیں کھپائیں تو اب وہ پکاریں اور چھوٹنے کا وقت نہ تھا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxiv{اور انہیں اس کا اچنبھا ہوا کہ ان کے پاس انہیں میں کا ایک ڈر سنانے والا تشریف لایا اور کافر بولے یہ جادوگر ہے بڑا جھوٹا،\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxv{کیا اس نے بہت خداؤں کا ایک خدا کردیا بیشک یہ عجیب بات ہے،\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxvi{اور ان میں کے سردار چلے کہ اس کے پاس سے چل دو اور اپنے خداؤں پر صابر رہو بیشک اس میں اس کا کوئی مطلب ہے،\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxvii{یہ تو ہم نے سب سے پہلے دینِ نصرانیت میں بھی نہ سنی یہ تو نری نئی گڑھت ہے،\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxviii{کیا ان پر قرآن اتارا گیا ہم سب میں سے بلکہ وہ شک میں ہیں میری کتاب سے بلکہ ابھی میری مار نہیں چکھی ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxix{کیا وہ تمہارے رب کی رحمت کے خزانچی ہیں وہ عزت والا بہت عطا فرمانے والا ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxx{کیا ان کے لیے ہے سلطنت آسمانوں اور زمین کی اور جو کچھ ان کے درمیان ہے، تو رسیاں لٹکا کر چڑھ نہ جائیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxi{یہ ایک ذلیل لشکر ہے انہیں لشکروں میں سے جو وہیں بھگادیا جائے گا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxii{ان سے پہلے جھٹلا چکے ہیں نوح کی قوم اور عاد اور چومیخا کرنے والے فرعون\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxiii{اور ثمود اور لوط کی قوم اور بن والے یہ ہیں وہ گروہ\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxiv{ان میں کوئی ایسا نہیں جس نے رسولوں کو نہ جھٹلایا ہو تو میرا عذاب لازم ہوا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxv{اور یہ راہ نہیں دیکھتے مگر ایک چیخ کی جسے کوئی پھیر نہیں سکتا،\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxvi{اور بولے اے ہمارے رب ہمارا حصہ ہمیں جلد دے دے حساب کے دن سے پہلے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxvii{تم ان کی باتوں پر صبر کرو اور ہمارے بندے داؤد نعمتوں والے کو یاد کرو بیشک وہ بڑا رجوع کرنے والا ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxviii{بیشک ہم نے اس کے ساتھ پہاڑ مسخر فرمادیے کہ تسبیح کرتے شام کو اور سورج چمکتے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxix{اور پرندے جمع کیے ہوئے سب اس کے فرمانبردار تھے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmcmxc{اور ہم نے اس کی سلطنت کو مضبوط کیا اور اسے حکمت اور قولِ فیصل دیا\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmcmxci{اور کیا تمہیں اس دعوے والوں کی بھی خبر آئی جب وہ دیوار کود کر داؤد کی مسجد میں آئے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmcmxcii{جب وہ داؤد پر داخل ہوئے تو وہ ان سے گھبرا گیا انہوں نے عرض کی ڈریے نہیں ہم دو فریق ہیں کہ ایک نے دوسرے پر زیادتی کی ہے تو ہم میں سچا فیصلہ فرمادیجئے اور خلافِ حق نہ کیجئے اور ہمیں سیدھی راہ بتایے،\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmcmxciii{بیشک یہ میرا بھائی ہے اس کے پاس ننانوے دُنبیاں ہیں اور میرے پاس ایک دُنبی، اب یہ کہتا ہے وہ بھی مجھے حوالے کردے اور بات میں مجھ پر زور ڈالتا ہے،\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmcmxciv{داؤد نے فرمایا بیشک یہ تجھ پر زیادتی کرتا ہے کہ تیری دُنبی اپنی دُنبیوں میں ملانے کو مانگتا ہے، اور بیشک اکثر ساجھے والے ایک دوسرے پر زیادتی کرتے ہیں مگر جو ایمان لائے اور اچھے کام کیے اور وہ بہت تھوڑے ہیں اب داؤد سمجھا کہ ہم نے یہ اس کی جانچ کی تھی تو اپنے رب سے معافی مانگی اور سجدے میں گر پڑا اور رجوع لایا، (السجدة ۱۰)\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmcmxcv{تو ہم نے اسے یہ معاف فرمایا، اور بیشک اس کے لیے ہماری بارگاہ میں ضرور قرب اور اچھا ٹھکانا ہے،\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmcmxcvi{اے داؤد بیشک ہم نے تجھے زمین میں نائب کیا تو لوگوں میں سچا حکم کر اور خواہش کے پیچھے نہ جانا کہ تجھے اللہ کی راہ سے بہکادے گی، بیشک وہ جو اللہ کی راہ سے بہکتے ہیں ان کے لیے سخت عذاب ہے اس پر کہ وہ حساب کے دن کو بھول بیٹھے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmcmxcvii{اور ہم نے آسمان اور زمین اور جو کچھ ان کے درمیان ہے بیکار نہ بنائے، یہ کافروں کا گمان ہے تو کافروں کی خرابی ہے آگ سے،\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmcmxcviii{کیا ہم انہیں جو ایمان لائے اور اچھے کام کیے ان جیسا کردیں جو زمین میں فساد پھیلاتے ہیں، یا ہم پرہیزگاروں کو شریر بے حکموں کے برابر ٹھہرادیں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmcmxcix{یہ ایک کتاب ہے کہ ہم نے تمہاری طرف اتاری برکت والی تاکہ اس کی آیتوں کو سوچیں اور عقلمند نصیحت مانیں،\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmm{اور ہم نے داؤد کو سلیمان عطا فرمایا، کیا اچھا بندہ بیشک وہ بہت رجوع لانے والا\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmi{جبکہ اس پر پیش کیے گئے تیسرے پہر کو کہ روکئے تو تین پاؤں پر کھڑے ہوں چوتھے سم کا کنارہ زمین پر لگائے ہوئے اور چلائے تو ہوا ہوجائیں\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmii{تو سلیمان نے کہا مجھے ان گھوڑوں کی محبت پسند آئی ہے اپنے رب کی یاد کے لیے پھر انہیں چلانے کا حکم دیا یہاں تک کہ نگاہ سے پردے میں چھپ گئے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmiii{پھر حکم دیا کہ انہیں میرے پاس واپس لاؤ تو ان کی پنڈلیوں اور گردنوں پر ہاتھ پھیرنے لگا\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmiv{اور بیشک ہم نے سلیمان کو جانچا اور اس کے تخت پر ایک بے جان بدن ڈال دیا پھر رجوع لایا\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmv{عرض کی اے میرے رب مجھے بخش دے اور مجھے ایسی سلطنت عطا کر کہ میرے بعد کسی کو لائق نہ ہو بیشک تو ہی بڑی دین والا،\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmvi{تو ہم نے ہوا اس کے بس میں کردی کہ اس کے حکم سے نرم نرم چلتی جہاں وہ چاہتا،\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmvii{اور دیو بس میں کردیے ہر معمار اور غوطہ خور\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmviii{اور دوسرے اور بیڑیوں میں جکڑے ہوئے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmix{یہ ہماری عطا ہے اب تو چاہے تو احسان کر یا روک رکھ تجھ پر کچھ حساب نہیں،\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmx{اور بیشک اس کے لیے ہماری بارگاہ میں ضرور قرب اور اچھا ٹھکانا ہے،\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmxi{اور یاد کرو ہمارے بندہ ایوب کو جب اس نے اپنے رب کو پکارا کہ مجھے شیطان نے تکلیف اور ایذا لگادی،\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmxii{ہم نے فرمایا زمین پر اپنا پاؤں مار یہ ہے ٹھنڈا چشمہ نہانے اور پینے کو\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmxiii{اور ہم نے اسے اس کے گھر والے اور ان کے برابر اور عطا فرمادیے اپنی رحمت کرنے اور عقلمندوں کی نصیحت کو،\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmxiv{اور فرمایا کہ اپنے ہاتھ میں ایک جھاڑو لے کر اس سے مار دے اور قسم نہ توڑ بے ہم نے اسے صابر پایا کیا اچھا بندہ بیشک وہ بہت رجوع لانے والا ہے،\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmxv{اور یاد کرو ہمارے بندوں ابراہیم اور اسحاق اور یعقوب قدرت اور علم والوں کو\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmxvi{بیشک ہم نے انہیں ایک کھری بات سے امتیاز بخشا کہ وہ اس گھر کی یاد ہے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmxvii{اور بیشک وہ ہمارے نزدیک چُنے ہوئے پسندیدہ ہیں،\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmxviii{اور یاد کرو اسماعیل اور یسع اور ذو الکفل کو اورسب اچھے ہیں،\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmxix{یہ نصیحت ہے اور بیشک پرہیزگاروں کا ٹھکانا،\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmxx{بھلا بسنے کے باغ ان کے لیے سب دروازے کھلے ہوئے،\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmxxi{ان میں تکیہ لگائے ان میں بہت سے میوے اور شراب مانگتے ہیں،\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmxxii{اور ان کے پاس وہ بیبیاں ہیں کہ اپنے شوہر کے سوا اور کی طرف آنکھ نہیں اٹھاتیں، ایک عمر کی\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmxxiii{یہ ہے وہ جس کا تمہیں وعدہ دیا جاتا ہے حساب کے دن،\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmxxiv{بیشک یہ ہمارا رزق ہے کہ کبھی ختم نہ ہوگا\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmxxv{ان کو تو یہ ہے اور بیشک سرکشوں کا برا ٹھکانا،\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmxxvi{جہنم کہ اس میں جائیں گے تو کیا ہی برا بچھونا\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmxxvii{ان کو یہ ہے تو اسے چکھیں کھولتا پانی اور پیپ\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmmxxviii{اور اسی شکل کے اور جوڑے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmmxxix{ان سے کہا جائے گا یہ ایک اور فوج تمہارے ساتھ دھنسی پڑتی ہے جو تمہاری تھی وہ کہیں گے ان کو کھلی جگہ نہ ملیو آگ میں تو ان کو جانا ہی ہے،\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmmxxx{وہاں بھی تنگ جگہ میں رہیں تابع بولے بلکہ تمہیں کھلی جگہ نہ ملیو، یہ مصیبت تم ہمارے آگے لائے تو کیا ہی برا ٹھکانا\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmmxxxi{وہ بولے اے ہمارے رب جو یہ مصیبت ہمارے آگے لایا اسے آگ میں دُونا عذاب بڑھا،\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmmxxxii{اور بولے ہمیں کیا ہوا ہم ان مردوں کو نہیں دیکھتے جنہیں برا سمجھتے تھے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmmxxxiii{کیا ہم نے انہیں ہنسی بنالیا یا آنکھیں ان کی طرف سے پھر گئیں\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmmxxxiv{بیشک یہ ضرور حق ہے دوزخیوں کا باہم جھگڑ،\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmmxxxv{تم فرماؤ میں ڈر سنانے والا ہی ہوں اور معبود کوئی نہیں مگر ایک اللہ سب پر غالب،\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmmxxxvi{مالک آسمانوں اور زمین کا اور جو کچھ ان کے درمیان ہے صاحب عزت بڑا بخشنے والا،\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmmxxxvii{تم فرماؤ وہ بڑی خبر ہے،\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmmxxxviii{تم اس سے غفلت میں ہو\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmmxxxix{مجھے عالم بالا کی کیا خبر تھی جب وہ جھگڑتے تھے\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmmxl{مجھے تو یہی وحی ہوتی ہے کہ میں نہیں مگر روشن ڈر سنانے والا\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmmxli{جب تمہارے رب نے فرشتوں سے فرمایا کہ میں مٹی سے انسان بناؤں گا\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmmxlii{پھر جب میں اسے ٹھیک بنالوں اور اس میں اپنی طرف کی روح پھونکوں تو تم اس کے لیے سجدے میں گرنا،\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmmxliii{تو سب فرشتو ں نے سجدہ کیا ایک ایک نے کہ کوئی باقی نہ رہا،\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmmxliv{مگر ابلیس نے اس نے غرور کیا اور وہ تھا ہی کافروں میں\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmmxlv{فرمایا اے ابلیس تجھے کس چیز نے روکا کہ تو اس کے لیے سجدہ کرے جسے میں نے اپنے ہاتھوں سے بنایا تجھے غرور آگیا یا تو تھا ہی مغروروں میں\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmmxlvi{بولا میں اس سے بہتر ہوں تو نے مجھے آگ سے بنایا اور اسے مٹی سے پیدا کیا،\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmmxlvii{فرمایا تو جنت سے نکل جا کہ تو راندھا (لعنت کیا) گیا\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmmxlviii{اور بیشک تجھ پر میری لعنت ہے قیامت تک\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmmxlix{بولا اے میرے رب ایسا ہے تو مجھے مہلت دے اس دن تک کہ اٹھائے جائیں\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmmml{فرمایا تو تُو مہلت والوں میں ہے،\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmmmli{اس جانے ہوئے وقت کے دن تک\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmmmlii{بولا تیری عزت کی قسم ضرور میں ان سب کو گمراہ کردوں گا،\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmmmliii{مگر جو ان میں تیرے چنے ہوئے بندے ہیں،\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmmmliv{فرمایا تو سچ یہ ہے اور میں سچ ہی فرماتا ہوں،\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmmmlv{بیشک میں ضرور جہنم بھردوں گا تجھ سے اور ان میں سے جتنے تیری پیروی کریں گے سب سے،\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmmmlvi{تم فرماؤ میں اس قرآن پر تم سے کچھ اجر نہیں مانگتا اور میں بناوٹ والوں سے نہیں،\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmmmlvii{وہ تو نہیں مگر نصیحت سارے جہان کے لیے،\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmmmlviii{اور ضرور ایک وقت کے بعد تم اس کی خبر جانو گے\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmmmlix{\basmalahur کتاب اتارنا ہے اللہ عزت و حکمت والے کی طرف سے،\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmlx{بیشک ہم نے تمہاری طرف یہ کتاب حق کے ساتھ اتاری تو اللہ کو کو پوجو نرے اس کے بندے ہوکر،\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmlxi{ہاں خالص اللہ ہی کی بندگی ہے اور وہ جنہوں نے اس کے سوا اور والی بنالیے کہتے ہیں ہم تو انہیں صرف اتنی بات کے لیے پوجتے ہیں کہ یہ ہمیں اللہ کے پاس نزدیک کردیں، اللہ ان پر فیصلہ کردے گا اس بات کا جس میں اختلاف کررہے ہیں بیشک اللہ راہ نہیں دیتا اسے جو جھوٹا بڑا ناشکرا ہو\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmlxii{اللہ اپنے لیے بچہ بناتا تو اپنی مخلوق میں سے جسے چاہتا چن لیتا پاکی ہے اسے وہی ہے ایک اللہ سب پر غالب،\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmlxiii{اس نے آسمان اور زمین حق بنائے رات کو دن پر لپیٹتا ہے اور دن کو رات پر لپیٹتا ہے اور اس نے سورج اور چاند کو کام میں لگایا ہر ایک، ایک ٹھہرائی میعاد کے لیے چلتا ہے سنتا ہے وہی صاحب عزت بخشنے والا ہے،\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmlxiv{اس نے تمہیں ایک جان سے بنایا پھر اسی سے اس کا جوڑ پیدا کیا اور تمہارے لیے چوپایوں میں سے آٹھ جوڑے تھے تمہیں تمہاری ماؤں کے پیٹ میں بناتا ہے ایک طرح کے بعد اور طرح تین اندھیریوں میں یہ ہے اللہ تمہارا رب اسی کی بادشاہی ہے، اس کے سوا کسی کی بندگی نہیں، پھر کہیں پھیرے جاتے ہو\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmlxv{اگر تم ناشکری کرو تو بیشک اللہ بے نیاز ہے تم سے اور اپنے بندوں کی ناشکری اسے پسند نہیں، اور اگر شکر کرو تو اسے تمہارے لیے پسند فرماتا ہے اور کوئی بوجھ اٹھانے والی جان دوسرے کا بوجھ نہیں اٹھائے گی پھر تمہیں اپنے رب ہی کی طرف پھرنا ہے تو وہ تمہیں بتادے گا جو تم کرتے تھے بیشک وہ دلوں کی بات جانتا ہے،\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmlxvi{اور جب آدمی کو کوئی تکلیف پہنچتی ہے اپنے رب کو پکارتا ہے اسی طرف جھکا ہوا پھر جب اللہ نے اسے اپنے پاس سے کوئی نعمت دی تو بھول جاتا ہے جس لیے پہلے پکارا تھا اور اللہ کے برابر والے ٹھہرانے لگتا ہے تاکہ اس کی راہ سے بہکادے تم فرماؤ تھوڑے دن اپنے کفر کے ساتھ برت لے بیشک تو دوزخیوں میں ہے،\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmlxvii{کیا وہ جسے فرمانبرداری میں رات کی گھڑیاں گزریں سجود میں اور قیام میں آخرت سے ڈرتا اور اپنے رب کی رحمت کی آس لگائے کیا وہ نافرمانوں جیسا ہو جائے گا تم فرماؤ کیا برابر ہیں جاننے والے اور انجان، نصیحت تو وہی مانتے ہیں جو عقل والے ہیں،\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmlxviii{تم فرماؤ اے میرے بندو! جو ایمان لائے اپنے سے ڈرو، جنہوں نے بھلائی کی ان کے لیے اس دنیا میں بھلائی ہے اور اللہ کی زمین وسیع ہے صابروں ہی کو ان کا ثواب بھرپور دیا جائے گا بے گنتی\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmlxix{تم فرماؤ مجھے حکم ہے کہ اللہ کو پوجوں نرا اس کا بندہ ہوکر،\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmlxx{اور مجھے حکم ہے کہ میں سب سے پہلے گردن رکھوں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxi{تم فرماؤ بالفرض اگر مجھ سے نافرمانی ہوجائے تو مجھے اپنے رب سے ایک بڑے دن کے عذاب کا ڈر ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxii{تم فرماؤ میں اللہ ہی کو پوجتا ہوں نرا اس کا بندہ ہوکر،\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxiii{تو تم اس کے سوا جسے چاہو پوجو تم فرماؤ پوری ہار انہیں جو اپنی جان اور اپنے گھر والے قیامت کے دن ہار بیٹھے ہاں ہاں یہی کھلی ہار ہے،\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxiv{ان کے اوپر آگ کے پہاڑ ہیں اور ان کے نیچے پہاڑ اس سے اللہ ڈراتا ہے اپنے بندوں اے میرے بندو! تم مجھ سے ڈرو\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxv{اور وہ جو بتوں کی پوجا سے بچے اور اللہ کی طرف رجوع ہوئے انہیں کے لیے خوشخبری ہے تو خوشی سناؤ میرے ان بندوں کو،\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxvi{جو کان لگا کر بات سنیں پھر اس کے بہتر پر چلیں یہ ہیں جن کو اللہ نے ہدایت فرمائی اور یہ ہیں جن کو عقل ہیں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxvii{تو کیا وہ جس پر عذاب کی بات ثابت ہوچکی نجات والوں کے برابر ہوجائے گا تو کیا تم ہدایت دے کر آگ کے مستحق کو بچالو گے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxviii{لیکن جو اپنے رب سے ڈرے ان کے لیے بالا خانے ہیں ان پر بالا خانے بنے ان کے نیچے نہریں بہیں، اللہ کا وعدہ، اللہ وعدہ خلاف نہیں کرتا،\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxix{کیا تو نے نہ دیکھا کہ اللہ نے آسمان سے پانی اتارا پھر اس سے زمین میں چشمے بنائے پھر اس سے کھیتی نکالتا ہے کئی رنگت کی پھر سوکھ جاتی ہے تو تُو دیکھے کہ وہ پیلی پڑ گئی پھر اسے ریزہ ریزہ کردیتا ہے، بیشک اس میں دھیان کی بات ہے عقل مندوں کو\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxx{تو کیا وہ جس کا سینہ اللہ نے اسلام کے لیے کھول دیا تو وہ اپنے رب کی طرف سے نور پر ہے اس جیسا ہوجائے گا جو سنگدل ہے تو خرابی ہے ان کی جن کے دل یادِ خدا کی طرف سے سخت ہوگئے ہیں وہ کھلی گمراہی میں ہیں،\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxi{اللہ نے اتاری سب سے اچھی کتاب کہ اول سے آخر تک ایک سی ہے دوہرے بیان والی اس سے بال کھڑے ہوتے ہیں ان کے بدن پر جو اپنے رب سے ڈرتے ہیں، پھر ان کی کھالیں اور دل نرم پڑتے ہیں یادِ خدا کی طرف رغبت میں یہ اللہ کی ہدایت ہے راہ دکھائے اس سے جسے چاہے، اور جسے اللہ گمراہ کرے اسے کوئی راہ دکھانے والا نہیں،\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxii{تو کیا وہ جو قیامت کے دن برے عذاب کی ڈھال نہ پائے گا اپنے چہرے کے سوا نجات والے کی طرح ہوجائے گا اور ظالموں سے فرمایا جائے گا اپنا کمایا چکھو\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxiii{ان سے اگلوں نے جھٹلایا تو انہیں عذاب آیا جہاں سے انہیں خبر نہ تھی\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxiv{اور اللہ نے انہیں دنیا کی زندگی میں رسوائی کا مز ہ چکھایا اور بیشک آخرت کا عذاب سب سے بڑا، کیا اچھا تھا اگر وہ جانتے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxv{اور بیشک ہم نے لوگوں کے لیے اس قرآن میں ہر قسم کی کہاوت بیان فرمائی کہ کسی طرح انہیں دھیان ہو\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxvi{عربی زبان کا قرآن جس میں اصلاً کجی نہیں کہ کہیں وہ ڈریں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxvii{اللہ ایک مثال بیان فرماتا ہے ایک غلام میں کئی بدخو آقا شریک اور ایک نرے ایک مولیٰ کا، کیا ان دونوں کا حال ایک سا ہے سب خوبیاں اللہ کو بلکہ ان کے اکثر نہیں جانتے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxviii{بیشک تمہیں انتقال فرمانا ہے اور ان کو بھی مرنا ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxix{پھر تم قیامت کے دن اپنے رب کے پاس جھگڑو گے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmxc{تو اس سے بڑھ کر ظالم کون جو اللہ پر جھوٹ باندھے اور حق کو جھٹلائے جب اس کے پاس آئے، کیا جہنم میں کافروں کا ٹھکانہ نہیں،\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmxci{اور وہ جو یہ سچ لے کر تشریف لائے اور وہ جنہوں نے ان کی تصدیق کی\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmxcii{یہی ڈر والے ہیں، ان کے لےیے ہے، جو وہ چاہیں اپنے رب کے پاس، نیکوں کا یہی صلہ ہے،\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmxciii{تاکہ اللہ ان سے اتار دے برے سے برا کام جو انہوں نے کیا اور انہیں ان کے ثواب کا صلہ دے اچھے سے اچھے کام پر جو وہ کرتے تھے،\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmxciv{کیا اللہ اپنے بندے کو کافی نہیں اور تمہیں ڈراتے ہیں اس کے سوا اوروں سے اور جسے اللہ گمراہ کرے اس کی کوئی ہدایت کرنے والا نہیں،\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmxcv{اور جسے اللہ ہدایت دے اسے کوئی بہکانے والا نہیں، کیا اللہ عزت والا بدلہ لینے والا نہیں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmxcvi{اور اگر تم ان سے پوچھو آسمان اور زمین کس نے بنائے تو ضرور کہیں گے اللہ نے تم فرماؤ بھلا بتاؤ تو وہ جنہیں تم اللہ کے سوا پوجتے ہو اگر اللہ مجھے کوئی تکلیف پہنچانا چاہے تو کیا وہ اس کی بھیجی تکلیف ٹال دیں گے یا وہ مجھ پر مہر (رحم) فرمانا چاہے تو کیا وہ اس کی مہر کو روک رکھیں گے تم فرماؤ اللہ مجھے بس ہے بھروسے والے اس پر بھروسہ کریں،\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmxcvii{تم فرماؤ، اے میری قوم! اپنی جگہ کام کیے جاؤ میں اپنا کام کرتا ہوں تو آگے جان جاؤ گے،\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmxcviii{کس پر آتا ہے وہ عذاب کہ اسے رسوا کرے گا اور کس پر اترتا ہے عذاب کہ رہ پڑے گا\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmxcix{بیشک ہم نے تم پر یہ کتاب لوگوں کی ہدایت کو حق کے ساتھ اتاری تو جس نے راہ پائی تو اپنے بھلے کو اور جو بہکا وہ اپنے ہی برے کو بہکا اور تم کچھ ان کے ذمہ دار نہیں\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmc{اللہ جانوں کو وفات دیتا ہے ان کی موت کے وقت اور جو نہ مریں انہیں ان کے سوتے میں پھر جس پر موت کا حکم فرمادیا اسے روک رکھتا ہے اور دوسری ایک میعاد مقرر تک چھوڑ دیتا ہے بیشک اس میں ضرور نشانیاں ہیں سوچنے والوں کے لیے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmci{کیا انہوں نے اللہ کے مقابل کچھ سفارشی بنا رکھے ہیں تم فرماؤ کیا اگرچہ وہ کسی چیز کے مالک نہ ہوں اور نہ عقل رکھیں،\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmcii{تم فرماؤ شفاعت تو سب اللہ کے ہاتھ میں ہے اسی کے لیے ہے آسمانوں اور زمین کی بادشاہی، پھر تمہیں اسی کی طرف پلٹنا ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmciii{اور جب ایک اللہ کا ذکر کیا جاتا ہے دل سمٹ جاتے ہیں ان کے جو آخرت پر ایمان نہیں لاتے اور جب اس کے سوا اوروں کا ذکر ہوتا ہے جبھی وہ خوشیاں مناتے ہیں،\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmciv{تم عرض کرو اے اللہ! آسمانوں اور زمین کے پیدا کرنے والے نہاں اور عیاں کے جاننے والے تو اپنے بندوں میں فیصلہ فرمائے گا جس میں وہ اختلاف رکھتے تھے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmcv{اور اگر ظالموں کے لیے ہوتا جو کچھ زمین میں ہے سب اور اس کے ساتھ اس جیسا تو یہ سب چھڑائی (چھڑانے) میں دیتے روز ِ قیامت کے بڑے عذاب سے اور انہیں اللہ کی طرف سے وہ بات ظاہر ہوئی جو ان کے خیال میں نہ تھی\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmcvi{اور ان پر اپنی کمائی ہوئی برائیاں کھل گئیں اور ان پر آپڑا وہ جس کی ہنسی بناتے تھے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmcvii{پھر جب آدمی کو کوئی تکلیف پہنچتی ہے تو ہمیں بلاتا ہے پھر جب اسے ہم اپنے پاس سے کوئی نعمت عطا فرمائیں کہتا ہے یہ تو مجھے ایک علم کی بدولت ملی ہے بلکہ وہ تو آزمائش ہے مگر ان میں بہتوں کو علم نہیں\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmcviii{ان سے اگلے بھی ایسے ہی کہہ چکے تو ان کا کمایا ان کے کچھ کام نہ آیا،\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmcix{تو ان پر پڑ گئیں ان کی کمائیوں کی برائیاں اور وہ جو ان میں ظالم عنقریب ان پر پڑیں گی ان کی کمائیوں کی برائیاں اور وہ قابو سے نہیں نکل سکتے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmcx{کیا انہیں معلوم نہیں کہ اللہ روزی کشادہ کرتا ہے جس کے لیے چاہے اور تنگ فرماتا ہے، بیشک اس میں ضرور نشانیاں ہیں ایمان والوں کے لیے،\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmcxi{تم فرماؤ اے میرے وہ بندو! جنہوں نے اپنی جانوں پر زیادتی کی اللہ کی رحمت سے ناامید نہ ہو، بیشک اللہ سب گناہ بخش دیتا ہے بیشک وہی بخشنے والا مہربان ہے،\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmcxii{اور اپنے رب کی طرف رجوع لاؤ اور اس کے حضور گردن رکھو قبل اس کے کہ تم پر عذاب آئے پھر تمہاری مدد نہ ہو،\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmcxiii{اور اس کی پیروی کرو جو اچھی سے اچھی تمہارے رب سے تمہاری طرف اتاری گئی قبل اس کے کہ عذاب تم پر اچانک آجائے اور تمہیں خبر نہ ہو\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmcxiv{کہ کہیں کوئی جان یہ نہ کہے کہ ہائے افسوس! ان تقصیروں پر جو میں نے اللہ کے بارے میں کیں اور بیشک میں ہنسی بنایا کرتا تھا\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmcxv{یا کہے اگر اللہ مجھے راہ دکھاتا تو میں ڈر والوں میں ہوتا،\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmmcxvi{یا کہے جب عذاب دیکھے کسی طرح مجھے واپسی ملے کہ میں نیکیاں کروں\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmmcxvii{ہاں کیوں نہیں بیشک تیرے پاس میری آیتیں آئیں تو تُو نے انہیں جھٹلایا اور تکبر کیا اور تو کافر تھا\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmmcxviii{اور قیامت کے دن تم دیکھو گے انہیں جنہوں نے اللہ پر جھوٹ باندھا کہ ان کے منہ کالے ہیں کیا مغرور ٹھکانا جہنم میں نہیں\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmmcxix{اور اللہ بچائے گا پرہیزگاروں کو ان کی نجات کی جگہ نہ انہیں عذاب چھوئے اور نہ انہیں غم ہو،\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmmcxx{اللہ ہر چیز کا پیدا کرنے والا ہے، اور وہ ہرچیز کا مختار ہے،\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxi{اسی کے لیے ہیں آسمانوں اور زمین کی کنجیاں اور جنہوں نے اللہ کی آیتوں کا انکار کیا وہی نقصان میں ہیں،\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxii{تم فرماؤ تو کیا اللہ کے سوا دوسرے کے پوجنے کو مجھ سے کہتے ہو، اے جاہلو!\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxiii{اور بیشک وحی کی گئی تمہاری طرف اور تم سے اگلوں کی طرف کہ اسے سننے والے اگر تو نے اللہ کا شریک کیا تو ضرور تیرا سب کیا دھرا اَکارت جائے گا اور ضرور تو ہار میں رہے گا،\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxiv{بلکہ اللہ ہی کی بندگی کر اور شکر والوں سے ہو\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxv{اور انہوں نے اللہ کی قدر نہ کی جیسا کہ اس کا حق تھا اور وہ قیامت کے دن سب زمینوں کو سمیٹ دے گا اور اس کی قدرت سے سب آسمان لپیٹ دیے جائیں گے اور ان کے شرک سے پاک اور برتر ہے،\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxvi{اور صُور پھونکا جائے گا تو بے ہوش ہوجائیں گے جتنے آسمانوں میں ہیں اور جتنے زمین میں مگر جسے اللہ چاہے پھر وہ دوبارہ پھونکا جائے گا جبھی وہ دیکھتے ہوئے کھڑے ہوجائیں گے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxvii{اور زمین جگمگا اٹھے گی اپنے رب کے نور سے اور رکھی جائے گی کتاب اور لائے جائیں گے انبیاء اور یہ نبی اور اس کی امت کے ان پر گواہ ہونگے اور لوگوں میں سچا فیصلہ فرمادیا جائے گا اور ان پر ظلم نہ ہوگا،\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxviii{اور ہر جان کو اس کا کیا بھرپور دیا جائے گا اور اسے خوب معلوم جو وہ کرتے تھے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxix{اور کافر جہنم کی طرف ہانکے جائیں گے گروہ گروہ یہاں تک کہ جب وہاں پہنچیں گے اس کے دروازے کھولے جائیں گے اور اس کے داروغہ ان سے کہیں گے کیا تمہارے پاس تمہیں میں سے وہ رسول نہ آئے تھے جو تم پر تمہارے رب کی آیتیں پڑھتے تھے اور تمہیں اس دن سے ملنے سے ڈراتے تھے، کہیں گے کیوں نہیں مگر عذاب کا قول کافروں پر ٹھیک اترا\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxx{فرمایا جائے گا جاؤ جہنم کے دروازوں میں اس میں ہمیشہ رہنے، تو کیا ہی برا ٹھکانا متکبروں کا،\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxi{اور جو اپنے رب سے ڈرتے تھے ان کی سواریاں گروہ گروہ جنت کی طرف چلائی جائیں گی، یہاں تک کہ جب وہاں پہنچیں گے اور اس کے دروازے کھلے ہوئے ہوں گے اور اس کے داروغہ ان سے کہیں گے سلام تم پر تم خوب رہے تو جنت میں جاؤ ہمیشہ رہنے،\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxii{اور وہ کہیں گے سب خوبیاں اللہ کو جس نے اپنا وعدہ ہم سے سچا کیا اور ہمیں اس زمین کا وارث کیا کہ ہم جنت میں رہیں جہاں چاہیں، تو کیا ہی اچھا ثواب کامیوں (اچھے کام کرنیوالوں) کا\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxiii{اور تم فرشتوں کو دیکھو گے عرش کے آس پاس حلقہ کیے اپنے رب کی تعریف کے ساتھ ا س کی پاکی بولتے اور لوگوں میں سچا فیصلہ فرمادیا جائے گا اور کہا جائے گا کہ سب خوبیاں اللہ کو جو سارے جہاں کا رب\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxiv{\basmalahur حٰمٓ\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxv{یہ کتاب اتارنا ہے اللہ کی طرف سے جو عزت والا، علم والا،\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxvi{گناہ بخشنے والا اور توبہ قبول کرنے والا سخت عذاب کرنے والا بڑے انعام والا اس کے سوا کوئی معبود نہیں، اسی کی طرف پھرنا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxvii{اللہ کی آیتوں میں جھگڑا نہیں کرتے مگر کافر تو اے سننے والے تجھے دھوکا نہ دے ان کا شہروں میں اہل گہلے (اِتراتے) پھرنا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxviii{ان سے پہلے نوح کی قوم اور ان کے بعد کے گروہوں نے جھٹلایا، اور ہر امت نے یہ قصد کیا کہ اپنے رسول کو پکڑ لیں اور باطل کے ساتھ جھگڑے کہ اس سے حق کو ٹال دیں تو میں نے انہیں پکڑا، پھر کیسا ہوا میرا عذاب\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxix{اور یونہی تمہارے رب کی بات کافروں پر ثابت ہوچکی ہے کہ وہ دوزخی ہیں،\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmcxl{وہ جو عرش اٹھاتے ہیں اور جو اس کے گرد ہیں اپنے کی تعریف کے ساتھ اس کی پاکی بولتے اور اس پر ایمان لاتے اور مسلمانوں کی مغفرت مانگتے ہیں اے رب ہمارے تیرے رحمت و علم میں ہر چیز کی سمائی ہے تو انہیں بخش دے جنہوں نے توبہ کی اور تیری راہ پر چلے اور انہیں دوزخ کے عذاب سے بچالے،\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmcxli{اے ہمارے رب! اور انہیں بسنے کے باغوں میں داخل کر جن کا تو نے ان سے وعدہ فرمایا ہے اور ان کو جو نیک ہوں ان کے باپ دادا اور بیبیوں اور اولاد میں بیشک تو ہی عزت و حکمت والا ہے،\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmcxlii{اور انہیں گناہوں کی شامت سے بچالے، اور جسے تو اس دن گناہوں کی شامت سے بچائے تو بیشک تو نے اس پر رحم فرمایا، اور یہی بڑی کامیابی ہے،\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmcxliii{بیشک جنہوں نے کفر کیا ان کو ندا کی جائے گی کہ ضرور تم سے اللہ کی بیزاری اس سے بہت زیادہ ہے جیسے تم آج اپنی جان سے بیزار ہو جب کہ تم ایمان کی طرف بلائے جاتے تو تم کفر کرتے،\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmcxliv{کہیں گے اے ہمارے رب تو نے ہمیں دوبارہ مردہ کیا اور دوبارہ زندہ کیا اب ہم اپنے گناہوں پر مُقِر ہوئے تو آگ سے نکلنے کی بھی کوئی راہ ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmcxlv{یہ اس پر ہوا کہ جب ایک اللہ پکارا جاتا تو تم کفر کرتے اور ان کا شریک ٹھہرایا جاتا تو تم مان لیتے تو حکم اللہ کے لیے ہے جو سب سے بلند بڑا،\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmcxlvi{وہی ہے کہ تمہیں اپنی نشانیاں دکھاتا ہے اور تمہارے لیے آسمان سے روزی اتارتا ہے اور نصیحت نہیں مانتا مگر جو رجوع لائے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmcxlvii{تو اللہ کی بندگی کرو نرے اس کے بندے ہوکر پڑے برا مانیں کافر،\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmcxlviii{بلند درجے دینے والا عرش کامالک ایمان کی جان وحی ڈالتا ہے اپنے حکم سے اپنے بندوں میں جس پر چاہے کہ وہ ملنے کے دن سے ڈرائے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmcxlix{جس دن وہ بالکل ظاہر ہوجائیں گے اللہ پر ان کا کچھ حال چھپا نہ ہوگا آج کسی کی بادشاہی ہے ایک اللہ سب پر غا لب کی، ف۳۷)\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmcl{آج ہر جان اپنے کےٴ کا بدلہ پاےٴ گی آج کسی پر زیادتی نہیں، بیشک اللہ جلد حساب لینے والا ہے،\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmcli{اور انہیں ڈراؤ اس نزدیک آنے والی آفت کے دن سے جب دل گلوں کے پاس آجائیں گے غم میں بھرے، اور ظالموں کا نہ کوئی دوست نہ کوئی سفارشی جس کا کہا مانا جائے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmclii{اللہ جانتا ہے چوری چھپے کی نگاہ اور جو کچھ سینوں میں چھپا ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmcliii{اور اللہ سچا فیصلہ فرماتا ہے، اور اس کے سوا جن کو پوجتے ہیں وہ کچھ فیصلہ نہیں کرتے بیشک اللہ ہی سنتا اور دیکھتا ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmcliv{تو کیا انہوں نے زمین میں سفر نہ کیا کہ دیکھتے کیسا انجام ہوا ان سے اگلوں کا ان کی قوت اور زمین میں جو نشانیاں چھوڑ گئے ان سے زائد تو اللہ نے انہیں ان کے گناہوں پر پکڑا، اور اللہ سے ان کا کوئی بچانے والا نہ ہوا\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmclv{یہ اس لیے کہ ان کے پاس ان کے رسول روشن نشانیاں لے کر آئے پھر وہ کفر کرتے تو اللہ نے انہیں پکڑا، بیشک اللہ زبردست عذاب والا ہے،\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmclvi{اور بیشک ہم نے موسیٰ کو اپنی نشانیوں اور روشن سند کے ساتھ بھیجا،\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmclvii{فرعون اور ہامان اور قارون کی طرف تو وہ بولے جادوگر ہے بڑا جھوٹا\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmclviii{پھر جب وہ ان پر ہمارے پاس سے حق لایا بولے جو اس پر ایمان لائے ان کے بیٹے قتل کرو اور عورتیں زندہ رکھو اور کافروں کا داؤ نہیں مگر بھٹکتا پھرتا\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmclix{اور فرعون بولا مجھے چھوڑو میں موسیٰ کو قتل کروں اور وہ اپنے رب کو پکارے میں ڈرتا ہوں کہیں وہ تمہارا دین بدل دے یا زمین میں فساد چمکائے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmclx{اور موسیٰ نے کہا میں تمہارے اور اپنے رب کی پناہ لیتا ہوں ہر متکبر سے کہ حساب کے دن پر یقین نہیں لاتا\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmclxi{اور بولا فرعون والوں میں سے ایک مرد مسلمان کہ اپنے ایمان کو چھپاتا تھا کیا ایک مرد کو اس پر مارے ڈالتے ہو کہ وہ کہتا ہے کہ میرا رب اللہ ہے اور بیشک وہ روشن نشانیاں تمہارے پاس تمہارے رب کی طرف سے لائے اور اگر بالفرض وہ غلط کہتے ہیں تو ان کی غلط گوئی کا وبال ان پر، اور اگر وہ سچے ہیں تو تمہیں پہنچ جائے گا کچھ وہ جس کا تمہیں وعدہ دیتے ہیں بیشک اللہ راہ نہیں دیتا اسے جو حد سے بڑھنے والا بڑا جھوٹا ہو\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmclxii{اے میری قوم! آج بادشاہی تمہاری ہے اس زمین میں غلبہ رکھتے ہو تو اللہ کے عذاب سے ہمیں کون بچالے گا اگر ہم پر آئے فرعون بولا میں تو تمہیں وہی سمجھاتا ہوں جو میری سوجھ ہے اور میں تمہیں وہی بتاتا ہوں جو بھلائی کی راہ ہے،\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmclxiii{اور وہ ایمان والا بولا اے میری قوم! مجھے تم پر اگلے گروہوں کے دن کا سا خوف ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmclxiv{جیسا دستور گزرا نوح کی قوم اور عاد اور ثمود اور ان کے بعد اوروں کا اور اللہ بندوں پر ظلم نہیں چاہتا\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmclxv{اور اے میری قوم میں تم پر اس دن سے ڈراتا ہوں جس دن پکار مچے گی\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmclxvi{جس دن پیٹھ دے کر بھاگو گے اللہ سے تمہیں کوئی بچانے والا نہیں، اور جسے اللہ گمراہ کرے اس کا کوئی راہ دکھانے والا نہیں،\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmclxvii{اور بیشک اس سے پہلے تمہارے پاس یوسف روشن نشانیاں لے کر آئے تو تم ان کے لائے ہوئے سے شک ہی میں رہے، یہاں تک کہ جب انہوں نے انتقال فرمایا تم بولے ہرگز اب اللہ کوئی رسول نہ بھیجے گا اللہ یونہی گمراہ کرتا ہے اسے جو حد سے بڑھنے والا شک لانے والا ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmclxviii{وہ جو اللہ کی آیتوں میں جھگڑا کرتے ہیں بغیر کسی سند کے، کہ انہیں ملی ہو، کس قدر سخت بیزاری کی بات ہے اللہ کے نزدیک اور ایمان لانے والوں کے نزدیک، اللہ یوں ہی مہر کردیتا ہے متکبر سرکش کے سارے دل پر\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmclxix{اور فرعون بولا اے ہامان! میرے لیے اونچا محل بنا شاید میں پہنچ جاؤں راستوں تک،\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmclxx{کا ہے کے راستے آسمان کے تو موسیٰ کے خدا کو جھانک کر دیکھوں اور بیشک میرے گمان میں تو وہ جھوٹا ہے اور یونہی فرعون کی نگاہ میں اس کا برا کام بھلا کر دکھا گیا اور وہ راستے میں روکا گیا، اور فرعون کا داؤ ہلاک ہونے ہی کو تھا،\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxi{اور وہ ایمان والا بولا، اے میری قوم! میرے پیچھے چلو میں تمہیں بھلائی کی راہ بتاؤں،\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxii{اے میری قوم! یہ دنیا کا جینا تو کچھ برتنا ہی ہے اور بیشک وه پچھلا ہمیشہ رہنے کا گھر ہے،\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxiii{جو برُا کام کرے تو اسے بدلہ نہ ملے گا مگر اتنا ہی اور جو اچھا کام کرے مرد خواه عورت اور جو مسلمان تو وہ جنت میں داخل کیے جائیں گے وہاں بے گنتی رزق پائیں گے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxiv{اور اے میری قوم مجھے کیا ہوا میں تمہیں بلاتا ہوں نجات کی طرف اور تم مجھے بلاتے ہو دوزخ کی طرف\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxv{مجھے اس طرف بلاتے ہو کہ اللہ کا انکا کروں اور ایسے کو اس کا شریک کروں جو میرے علم میں نہیں، اور میں تمہیں اس عزت والے بہت بخشنے والے کی طرف بلاتا ہوں،\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxvi{آپ ہی ثابت ہوا کہ جس کی طرف مجھے بلاتے ہو اسے بلانا کہیں کام کا نہیں دنیا میں نہ آخرت میں اور یہ ہمارا پھرنا اللہ کی طرف ہے اور یہ کہ حد سے گزرنے والے ہی دوزخی ہیں،\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxvii{تو جلد وہ وقت آتا ہے کہ جو میں تم سے کہہ رہا ہوں، اسے یاد کرو گے اور میں اپنے کام اللہ کو سونپتا ہوں، بیشک اللہ بندوں کو دیکھتا ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxviii{تو اللہ نے اسے بچالیا ان کے مکر کی برائیوں سے اور فرعون والوں کو برے عذاب نے آ گھیرا،\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxix{آ گ جس پر صبح و شام پیش کیے جاتے ہیں اور جس دن قیامت قائم ہوگی، حکم ہوگا فرعون والوں کو سخت تر عذاب میں داخل کرو،\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxx{اور جب وہ آگ میں باہم جھگڑیں گے تو کمزور ان سے کہیں گے جو بڑے بنتے تھے ہم تمہارے تابع تھے تو کیا تم ہم سے آگ کا کوئی حصہ گھٹا لوگے،\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxi{وہ تکبر والے بولے ہم سب آگ میں ہیں بیشک اللہ بندوں میں فیصلہ فرماچکا\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxii{اور جو آگ میں ہیں اس کے داروغوں سے بولے اپنے رب سے دعا کرو ہم پر عذاب کا ایک دن ہلکا کردے،\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxiii{انہوں نے کہا کیا تمہارے پاس تمہارے رسول نشانیاں نہ لاتے تھے بولے کیوں نہیں بولے تو تمہیں دعا کرو اور کافروں کی دعا نہیں، مگر بھٹکتے پھرنے کو،\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxiv{بیشک ضرور ہم اپنے رسولوں کی مدد کریں گے اور ایمان والوں کی دنیا کی زندگی میں اور جس دن گواہ کھڑے ہوں گے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxv{جس دن ظالموں کو ان کے بہانے کچھ کام نہ دیں گے اور ان کے لیے لعنت ہے اور ان کے لیے بُرا گھر\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxvi{اور بیشک ہم نے موسیٰ کو رہنمائی عطا فرمائی اور بنی اسرائیل کو کتاب کا وارث کیا\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxvii{عقلمندوں کی ہدایت اور نصیحت کو تو اے محبوب،\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxviii{تم صبر کرو بیشک اللہ کا وعدہ سچا ہے اور اپنوں کے گناہوں کی معافی چاہو اور اپنے رب کی تعریف کرتے ہوئے صبح اور شام اس کی پاکی بولو\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxix{وہ جو اللہ کی آیتوں میں جھگڑا کرتے ہیں بغیر کسی سند کے جو انہیں ملی ہو ان کے دلوں میں نہیں مگر ایک بڑائی کی ہوس جسے نہ پہنچیں گے تو تم اللہ کی پناہ مانگو بیشک وہی سنتا دیکھتا ہے،\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmcxc{بیشک آسمانوں اور زمین کی پیدائش آدمیوں کی پیدائش سے بہت بڑی لیکن بہت لوگ نہیں جانتے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmmcxci{اور اندھا اور انکھیارا برابر نہیں اور نہ وہ جو ایمان لائے اور اچھے کام کیے اور بدکار کتنا کم دھیان کرتے ہو،\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmmcxcii{بیشک قیامت ضرور آنے والی ہے اس میں کچھ شک نہیں لیکن بہت لوگ ایمان نہیں لاتے\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmmcxciii{اور تمہارے رب نے فرمایا مجھ سے دعا کرو میں قبول کروں گا بیشک وہ جو میری عبادت سے اونچے کھینچتے (تکبر کرتے) ہیں عنقریب جہنم میں جائیں گے ذلیل ہوکر،\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmmcxciv{اللہ ہے جس نے تمہارے لیے رات بنائی کہ اس میں آرام پاؤ اور دن بنایا آنکھیں کھولتا بیشک اللہ لوگوں پر فضل والا ہے لیکن بہت آدمی شکر نہیں کرتے،\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmmcxcv{وہ ہے اللہ تمہارا رب ہر چیز کا بنانے والا اس کے سوا کسی کی بندگی نہیں تو کہاں اوندھے جاتے ہو\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmmcxcvi{یونہی اوندھے ہوتے ہیں وہ جو اللہ کی آیتوں کا انکار کرتے ہیں\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmmcxcvii{اللہ ہے جس نے تمہارے لیے زمین ٹھہراؤ بنائی اور آسمان چھت اور تمہاری تصویر کی تو تمہاری صورتیں اچھی بنائیں اور تمہیں ستھری چیزیں روزی دیں یہ ہے اللہ تمہارا رب، تو بڑی برکت والا ہے اللہ رب سارے جہان کا،\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmmcxcviii{وہی زندہ ہے اس کے سوا کسی کی بندگی نہیں تو اسے پوجو نرے اسی کے بندے ہوکر، سب خوبیاں اللہ کو جو سارے جہاں کا رب،\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmmcxcix{تم فرماؤ میں منع کیا گیا ہوں کہ انہیں پوجوں جنہیں تم اللہ کے سوا پوجتے ہو جبکہ میرے پاس روشن دلیلیں میرے رب کی طرف سے آئیں اور مجھے حکم ہوا ہے کہ رب العالمین کے حضور گردن رکھوں،\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmmcc{وہی ہے جس نے تمہیں مٹی سے بنایا پھر پانی کی بوند سے پھر خون کی پھٹک سے پھرتمہیں نکالتا ہے بچہ پھرتمہیں باقی رکھتا ہے کہ اپنی جوانی کو پہنچو پھر اس لیے کہ بوڑھے ہو اور تم میں کوئی پہلے ہی اٹھالیا جاتا ہے اور اس لیے کہ تم ایک مقرر وعدہ تک پہنچو اور اس لیے کہ سمجھو\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmmcci{وہی ہے کہ جِلاتا ہے اور مارتا ہے پھر جب کوئی حکم فرماتا ہے تو اس سے یہی کہتا ہے کہ ہو جا جبھی وہ ہوجاتا ہے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmmccii{کیا تم نے انہیں نہ دیکھا جو اللہ کی آیتوں میں جھگڑے ہیں کہاں پھیرے جاتے ہیں\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmmcciii{وہ جنہوں نے جھٹلائی کتاب اور جو ہم نے اپنے رسولوں کے ساتھ بھیجا، ف۱۵۰) وہ عنقریب جان جائیں گے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmmcciv{جب ان کی گردنوں میں طوق ہوں گے اور زنجیریں گھسیٹے جائیں گے،\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmmccv{کھولتے پانی میں، پھر آگ میں دہکائے جائیں گے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmmccvi{پھر ان سے فرمایا جائے گا کہاں گئے وہ جو تم شریک بناتے تھے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmmccvii{اللہ کے مقابل، کہیں گے وہ تو ہم سے گم گئے بلکہ ہم پہلے کچھ پوجتے ہی نہ تھے اللہ یونہی گمراہ کرتا ہے کافروں کو،\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmmccviii{یہ اس کا بدلہ ہے جو تم زمین میں باطل پر خوش ہوتے تھے اور اس کا بدلہ ہے جو تم اتراتے تھے،\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmmccix{جاؤ جہنم کے دروازوں میں اس میں ہمیشہ رہنے، تو کیا ہی برا ٹھکانا مغروروں کا\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmmccx{تو تم صبر کرو بیشک اللہ کا وعدہ سچا ہے، تو اگر ہم تمہیں دکھادیں کچھ وہ چیز جس کا انہیں وعدہ دیا جاتا ہے یا تمہیں پہلے ہی وفات دیں بہرحال انہیں ہماری ہی طرف پھرنا\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmmccxi{اور بیشک ہم نے تم سے پہلے کتنے رسول بھیجے کہ جن میں کسی کا احوال تم سے بیان فرمایا اور کسی کا احوال نہ بیان فرمایا اور کسی رسول کو نہیں پہنچتا کہ کوئی نشانی لے آئے بے حکم خدا کے، پھر جب اللہ کا حکم آئے گا سچا فیصلہ فرمادیا جائے گا اور باطل والوں کا وہاں خسارہ،\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmmccxii{اللہ ہے جس نے تمہارے لیے چوپائے بنائے کہ کسی پر سوار ہو اور کسی کا گوشت کھاؤ،\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmmmccxiii{اور تمہارے لیے ان میں کتنے ہی فائدے ہیں اور اس لیے کہ تم ان کی پیٹھ پر اپنے دل کی مرادوں کو پہنچو اور ان پر اور کشتیوں پر سوار ہوتے ہو،\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmmmccxiv{اور وہ تمہیں اپنی نشانیاں دکھاتا ہے تو اللہ کی کونسی نشانی کا انکار کرو گے\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmmmccxv{کیا انہوں نے زمین میں سفر نہ کیا کہ دیکھتے ان سے اگلوں کا کیسا انجام ہوا، وہ ان سے بہت تھے اور ان کی قوت اور زمین میں نشانیاں ان سے زیادہ تو ان کے کیا کام آیا جو انہوں نے کمایا،\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmmmccxvi{تو جب ان کے پاس ان کے رسول روشن دلیلیں لائے، تو وہ اسی پر خوش رہے جو ان کے پاس دنیا کا علم تھا اور انہیں پر الٹ پڑا جس کی ہنسی بناتے تھے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmmmccxvii{پھر جب انہوں نے ہمارا عذاب دیکھا بولے ہم ایک اللہ پر ایمان لائے اور جو اس کے شریک کرتے تھے ان کے منکر ہوئے\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmmmccxviii{تو ان کے ایمان نے انہیں کام نہ دیا جب انہوں نے ہمارا عذاب دیکھ لیا، اللہ کا دستور جو اس کے بندوں میں گزر چکا اور وہاں کافر گھاٹے میں رہے\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmmmccxix{\basmalahur حٰمٓ\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmccxx{یہ اتارا ہے بڑے رحم والے مہربان کا،\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxi{ایک کتاب ہے جس کی آیتیں مفصل فرمائی گئیں عربی قرآن عقل والوں کے لیے،\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxii{خوشخبری دیتا اور ڈر سناتا تو ان میں اکثر نے منہ پھیرا تو وہ سنتے ہی نہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxiii{اور بولے ہمارے دل غلاف میں ہیں اس بات سے جس کی طرف تم ہمیں بلاتے ہو اور ہمارے کانوں میں ٹینٹ (روئی) ہے اور ہمارے اور تمہارے درمیان روک ہے تو تم اپنا کام کرو ہم اپنا کام کرتے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxiv{تم فرماؤ آدمی ہونے میں تو میں تمہیں جیسا ہوں مجھے وحی ہوتی ہے کہ تمہارا معبود ایک ہی معبود ہے، تو اس کے حضور سیدھے رہو اور اس سے معافی مانگو اور خرابی ہے شرک والوں کو،\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxv{وہ جو زکوٰة نہیں دیتے اور وہ آخرت کے منکر ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxvi{بیشک جو ایمان لائے اور اچھے کام کیے ان کے لیے بے انتہا ثواب ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxvii{تم فرماؤ کیا تم لوگ اس کا انکار رکھتے ہو جس نے دو دن میں زمین بنائی اور اس کے ہمسر ٹھہراتے رہو وہ ہے سارے جہان کا رب\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxviii{اور اس میں اس کے اوپر سے لنگر ڈالے (بھاری بوجھ رکھے) اور اس میں برکت رکھی اور اس میں اس کے بسنے والوں کی روزیاں مقرر کیں یہ سب ملاکر چار دن میں ٹھیک جواب پوچھنے والوں کو،\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxix{پھر آسمان کی طرف قصد فرمایا اور وہ دھواں تھا تو اس سے اور زمین سے فرمایا کہ دونوں حاضر ہو خوشی سے چاہے ناخوشی سے، دونوں نے عرض کی کہ ہم رغبت کے ساتھ حاضر ہوئے،\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxx{تو انہیں پورے سات آسمان کردیا دو دن میں اور ہر آسمان میں اسی کے کام کے احکام بھیجے اور ہم نے نیچے کے آسمان کو چراغوں سے آراستہ کیا اور نگہبانی کے لیے یہ اس عزت والے علم والے کا ٹھہرایا ہوا ہے،\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxi{پھر اگر وہ منہ پھیریں تو تم فرماؤ کہ میں تمہیں ڈراتا ہوں ایک کڑ ک سے جیسی کڑ ک عاد اور ثمود پر آئی تھی\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxii{جب رسول ان کے آگے پیچھے پھرتے تھے کہ اللہ کے سوا کسی کو نہ پوجو، بولے ہمارا رب چاہتا تو فرشتے اتارتا تو جو کچھ تم لے کر بھیجے گئے ہم اسے نہیں مانتے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxiii{تو وہ جو عاد تھے انہیں نے زمین میں ناحق تکبر کیا اور بولے ہم سے زیادہ کس کا زور، اور کیا انہوں نے نہ جانا کہ اللہ جس نے انہیں بنایا ان سے زیادہ قوی ہے، اور ہماری آیتوں کا انکار کرتے تھے،\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxiv{تو ہم نے ان پر ایک آندھی بھیجی سخت گرج کی ان کی شامت کے دنوں میں کہ ہم انہیں رسوائی کا عذاب چکھائیں دنیا کی زندگی میں اور بیشک آخرت کے عذاب میں سب سے بڑی رسوائی ہے اور ان کی مدد نہ ہوگی،\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxv{اور رہے ثمود انہیں ہم نے راہ دکھائی تو انہوں نے سوجھنے پر اندھے ہونے کو پسند کیا تو انہیں ذلت کے عذاب کی کڑ ک نے آ لیا سزا ان کے کیے کی\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxvi{اور ہم نے انہیں بچالیا جو ایمان لائے اور ڈرتے تھے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxvii{اور جس دن اللہ کے دشمن آگ کی طرف ہانکے جائیں گے تو ان کے اگلوں کو روکیں گے،\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxviii{یہاں تک کہ پچھلے آ ملیں یہاں تک کہ جب وہاں پہنچیں گے ان کے کان اور ان کی آنکھیں اور ان کے چمڑے سب ان پر ان کے کیے کی گواہی دیں گے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxix{اور وه اپنی کھالوں سے کہیں گے تم نے ہم پر کیوں گواہی دی، وہ کہیں گی ہمیں اللہ نے بلوایا جس نے ہر چیز کو گویائی بخشی اور اس نے تمہیں پہلی بار بنایا اور اسی کی طرف تمہیں پھرنا ہے،\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmccxl{اور تم اس سے کہاں چھپ کر جاتے کہ تم پر گواہی دیں تمہارے کان اور تمہاری آنکھیں اور تمہاری کھالیں لیکن تم تو یہ سمجھے بیٹھے تھے کہ اللہ تمہارے بہت سے کام نہیں جانتا\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmccxli{اور یہ ہے تمہارا وہ گمان جو تم نے اپنے رب کے ساتھ کیا اور اس نے تمہیں ہلاک کردیا تو اب رہ گئے ہارے ہوؤں میں،\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmccxlii{پھر اگر وہ صبر کریں تو آگ ان کا ٹھکانا ہے اور اگر وہ منانا چاہیں تو کوئی ان کا منانا نہ مانے،\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmccxliii{اور ہم نے ان پر کچھ ساتھی تعینات کیے انہوں نے انہیں بھلا کردیا جو ان کے آگے ہے اور جو ان کے پیچھے اور ان پر بات پوری ہوئی ان گروہوں کے ساتھ جو ان سے پہلے گزر چکے جن اور آدمیوں کے، بیشک وہ زیاں کار تھے،\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmccxliv{اور کافر بولے یہ قرآن نہ سنو اور اس میں بیہودہ غل کرو شاید یونہی تم غالب آؤ\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmccxlv{تو بیشک ضرور ہم کافروں کو سخت عذاب چکھائیں گے اور بیشک ہم ان کے بُرے سے بُرے کام کا انہیں بدلہ دیں گے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmccxlvi{یہ ہے اللہ کے دشمنوں کا بدلہ آ گ، اس میں انہیں ہمیشہ رہنا ہے، سزا اس کی کہ ہماری آیتوں کا انکار کرتے تھے،\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmccxlvii{اور کافر بولے اے ہمارے رب ہمیں دکھا وہ دونوں جن اور آدمی جنہوں نے ہمیں گمراہ کیا کہ ہم انہیں اپنے پاؤں تلے ڈالیں کہ وہ ہر نیچے سے نیچے رہیں\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmccxlviii{بیشک وہ جنہوں نے کہا ہمارا رب اللہ ہے پھر اس پر قائم رہے ان پر فرشتے اترتے ہیں کہ نہ ڈرو اور نہ غم کرو اور خوش ہو اس جنت پر جس کا تمہیں وعدہ دیا جاتا تھا\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmccxlix{ہم تمہارے دوست ہیں دنیا کی زندگی میں اور آخرت میں اور تمہارے لیے ہے اس میں جو تمہارا جی چاہے اور تمہارے لیے اس میں جو مانگو،\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmccl{مہمانی بخشنے والے مہربان کی طرف سے،\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmccli{اور اس سے زیادہ کس کی بات اچھی جو اللہ کی طرف بلائے اور نیکی کرے اور کہے میں مسلمان ہوں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmcclii{اور نیکی اور بدی برابر نہ ہوجائیں گی، اے سننے والے برائی کو بھلائی سے ٹال جبھی وہ کہ تجھ میں اور اس میں دشمنی تھی ایسا ہوجائے گا جیسا کہ گہرا دوست\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmccliii{اور یہ دولت نہیں ملتی مگر صابروں کو، اور اسے نہیں پاتا مگر بڑے نصیب والا،\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmccliv{اور اگر تجھے شیطان کا کوئی کونچا (تکلیف) پہنچے تو اللہ کی پناہ مانگ بیشک وہی سنتا جانتا ہے،\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmcclv{اور اس کی نشانیوں میں سے ہیں رات اور دن اور سورج اور چاند سجدہ نہ کرو سورج کو اور نہ چاند کو اور اللہ کو سجدہ کرو جس نے انہیں پیدا کیا اگر تم اس کے بندے ہو،\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmcclvi{تو اگر یہ تکبر کریں تو وہ جو تمہارے رب کے پاس ہیں رات دن اس کی پاکی بولتے ہیں اور اکتاتے نہیں، السجدة ۔۱۱)\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmcclvii{اور اس کی نشانیوں سے ہے کہ تو زمین کو دیکھے بے قدر پڑی پھر جب ہم نے اس پر پانی اتارا تر و تازہ ہوئی اور بڑھ چلی، بیشک جس نے اسے جِلایا ضرور مردے جِلائے گا، بیشک وہ سب کچھ کرسکتا ہے،\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmcclviii{بیشک وہ جو ہماری آیتوں میں ٹیڑھے چلتے ہیں ہم سے چھپے نہیں تو کیا جو آ گ میں ڈالا جائے گا وہ بھلا، یا جو قیامت میں امان سے آئے گا جو جی میں آئے کرو بیشک وہ تمہارے کام دیکھ رہا ہے،\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmcclix{بیشک جو ذکر سے منکر ہوئے جب وہ ان کے پاس آیا ان کی خرابی کا کچھ حال نہ پوچھ، اور بیشک وہ عزت والی کتاب ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmcclx{باطل کو اس کی طرف راہ نہیں نہ اس کے آگے سے نہ اس کے پیچھے سے اتارا ہوا ہے حکمت والے سب خوبیوں سراہے کا،\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxi{تم سے نہ فرمایا جائے مگر وہی جو تم سے اگلے رسولوں کو فرمایا، کہ بیشک تمہارا رب بخشش والا اور دردناک عذاب والا ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxii{اور اگر ہم اسے عجمی زبان کا قرآن کرتے تو ضرور کہتے کہ اس کی آیتیں کیوں نہ کھولی گئیں کیا کتاب عجمی اور نبی عربی تم فرماؤ وہ ایمان والوں کے لیے ہدایت اور شفا ہے اور وہ جو ایمان نہیں لاتے ان کے کانوں میں ٹینٹ (روئی) ہے اور وہ ان پر اندھا پن ہے گویا وہ دور جگہ سے پکارے جاتے ہیں\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxiii{اور بیشک ہم نے موسیٰ کو کتاب عطا فرمائی تو اس میں اختلاف کیا گیا اور اگر ایک بات تمہارے رب کی طرف سے گزر نہ چکی ہوتی تو جبھی ان کا فیصلہ ہوجاتا اور بیشک وہ ضرور اس کی طرف سے ایک دھوکا ڈالنے والے شک میں ہیں،\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxiv{جو نیکی کرے وہ اپنے بھلے کو اور جو برائی کرے اپنے بُرے کو، اور تمہارا رب بندوں پر ظلم نہیں کرتا،\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxv{قیامت کے علم کا اسی پر حوالہ ہے اور کوئی پھل اپنے غلاف سے نہیں نکلتا اور نہ کسی مادہ کو پیٹ رہے اور نہ جنے مگر اس کے علم سے اور جس دن انہیں ندا فرمائے گا کہاں ہیں میرے شریک کہیں گے ہم تجھ سے کہہ چکے ہیں کہ ہم میں کوئی گواہ نہیں\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxvi{اور گم گیا ان سے جسے پہلے پوجتے تھے اور سمجھ لیے کہ انہیں کہیں بھاگنے کی جگہ نہیں،\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxvii{آدمی بھلائی مانگنے سے نہیں اُکتاتا اور کوئی برائی پہنچے تو ناامید آس ٹوٹا\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxviii{اور اگر ہم اسے کچھ اپنی رحمت کا مزہ دیں اس تکلیف کے بعد جو اسے پہنچی تھی تو کہے گا یہ تو میری ہے اور میرے گمان میں قیامت قائم نہ ہوگی اور اگر میں رب کی طرف لوٹایا بھی گیا تو ضرور میرے لیے اس کے پاس بھی خوبی ہی ہے تو ضرور ہم بتادیں گے کافروں کو جو انہوں نے کیا اور ضرور انہیں گاڑھا عذاب چکھائیں گے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxix{اورجب ہم آدمی پر احسان کرتے ہیں تو منہ پھیر لیتا ہے اور اپنی طرف دور ہٹ جاتا ہے اور جب اسے تکلیف پہنچتی ہے تو چوڑی دعا والا ہے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxx{تم فرماؤ بھلا بتاؤ اگر یہ قرآن اللہکے پاس سے ہے پھر تم اس کے منکر ہوئے تو اس سے بڑھ کر گمراہ کون جو دور کی ضد میں ہے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxi{ابھی ہم انہیں دکھائیں گے اپنی آیتیں دنیا بھر میں اور خود ان کے آپے میں یہاں تک کہ ان پر کھل جائے کہ بیشک وہ حق ہے کیا تمہارے رب کا ہر چیز پر گواہ ہونا کافی نہیں،\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxii{سنو انہیں ضرور اپنے رب سے ملنے میں شک ہے سنو! وہ ہر چیز کو محیط ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxiii{\basmalahur حٰمٓ\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxiv{عٓسٓقٓ\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxv{یونہی وحی فرماتا ہے تمہاری طرف اور تم سے اگلوں کی طرف اللہ عزت و حکمت والا،\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxvi{اسی کا ہے جو کچھ آسمان میں ہے اور جو کچھ زمین میں ہے، اور وہی بلندی و عظمت والا ہے،\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxvii{قریب ہوتا ہے کہ آسمان اپنے اوپر سے شق ہوجائیں اور فرشتے اپنے رب کی تعریف کے ساتھ اس کی پاکی بولتے اور زمین والوں کے لیے معافی مانگتے ہیں سن لو بیشک اللہ ہی بخشنے والا مہربان ہے،\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxviii{اور جنہوں نے اللہ کے سوا اور والی بنارکھے ہیں وہ اللہ کی نگاہ میں ہیں اور تم ان کے ذمہ دار نہیں،\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxix{اور یونہی ہم نے تمہاری طرف عربی قرآن وحی بھیجا کہ تم ڈراؤ سب شہروں کی اصل مکہ والوں کو اور جتنے اس کے گرد ہیں اور تم ڈراؤ اکٹھے ہونے کے دن سے جس میں کچھ شک نہیں ایک گروہ جنت میں ہے اور ایک گروہ دوزخ میں،\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxx{اور اللہ چاہتا تو ان سب کو ایک دین پر کردیتا لیکن اللہ اپنی رحمت میں لیتا ہے جسے چاہے اور ظالموں کا نہ کوئی دوست نہ مددگار\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxi{کیا اللہ کے سوا اور والی ٹھہرالیے ہیں تو اللہ ہی والی ہے اور وہ مُردے جِلائے گا، اور وہ سب کچھ کرسکتا ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxii{تم جس بات میں اختلاف کرو تو اس کا فیصلہ اللہ کے سپرد ہے یہ ہے اللہ میرا رب میں نے اس پر بھروسہ کیا، اور میں اس کی طرف رجوع لاتا ہوں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxiii{آسمانوں اور زمین کا بنانے والا، تمہارے لیے تمہیں میں سے جوڑے بنائے اور نر و مادہ چوپائے، اس سے تمہاری نسل پھیلاتا ہے، اس جیسا کوئی نہیں، اور وہی سنتا دیکھتا ہے،\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxiv{اسی کے لیے ہیں آسمانوں اور زمین کی کنجیاں روزی وسیع کرتا ہے جس کے لیے چاہے اور تنگ فرماتا ہے بیشک وہ سب کچھ جانتا ہے،\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxv{تمہارے لیے دین کی وہ راہ ڈالی جس کا حکم اس نے نوح کو دیا اور جو ہم نے تمہاری طرف وحی کی اور جس کا حکم ہم نے ابراہیم اور موسیٰ اور عیسیٰ کو دیا کہ دین ٹھیک رکھو اور اس میں پھوٹ نہ ڈالو مشرکوں پر بہت ہی گراں ہے وہ جس کی طرف تم انہیں بلاتے ہو، اور اللہ اپنے قریب کے لیے چن لیتا ہے جسے چاہے اور اپنی طرف راہ دیتا ہے اسے جو رجوع لائے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxvi{اور انہوں نے پھوٹ نہ ڈالی مگر بعد اس کے کہ انہیں علم آچکا تھا آپس کے حسد سے اور اگر تمہارے رب کی ایک بات گزر نہ چکی ہوتی ایک مقرر میعاد تک تو کب کا ان میں فیصلہ کردیا ہوتا اور بیشک وہ جو ان کے بعد کتاب کے وارث ہوئے وہ اس سے ایک دھوکا ڈالنے والے شک میں ہیں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxvii{تو اسی لیے بلاؤ اور ثابت قدم رہو جیسا تمہیں حکم ہوا ہے اور ان کی خواہشوں پر نہ چلو اور کہو کہ میں ایمان لایا اس پر جو کوئی کتاب اللہ نے اتاری اور مجھے حکم ہے کہ میں تم میں انصاف کروں اللہ ہمارا اور تمہارا سب کا رب ہے ہمارے لیے ہمارا عمل اور تمہارے لیے تمہارا کیا کوئی حجت نہیں ہم میں اور تم میں اللہ ہم سب کو جمع کرے گا اور اسی کی طرف پھرنا ہے،\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxviii{اور وہ جو اللہ کے بارے میں جھگڑتے ہیں بعد اس کے کہ مسلمان اس کی دعوت قبول کرچکے ہیں ان کی دلیل محض بے ثبات ہے ان کے رب کے پاس اور ان پر غضب ہے اور ان کے لیے سخت عذاب ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxix{اللہ ہے جس نے حق کے ساتھ کتاب اتاری اور انصاف کی ترازو اور تم کیا جانو شاید قیامت قریب ہی ہو\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmccxc{اس کی جلدی مچارہے ہیں وہ جو اس پر ایمان نہیں رکھتے اور جنہیں اس پر ایمان ہے وہ اس سے ڈر رہے ہیں اورجانتے ہیں کہ بیشک وہ حق ہے، سنتے ہو بیشک جو قیامت میں شک کرتے ہیں ضرور دُور کی گمراہی میں ہیں،\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmccxci{اللہ اپنے بندوں پر لطف فرماتا ہے جسے چاہے روزی دیتا ہے اور وہی قوت و عزت والا ہے،\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmccxcii{جو آخرت کی کھیتی چاہے ہم اس کے لیے اس کی کھیتی بڑھائیں اور جو دنیا کی کھیتی چاہے ہم اسے اس میں سے کچھ دیں گے اور آخرت میں اس کا کچھ حصہ نہیں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmccxciii{یا ان کے لیے کچھ شریک ہیں جنہوں نے ان کے لیے وہ دین نکال دیا ہے کہ اللہ نے اس کی اجازت نہ دی اور اگر ایک فیصلہ کا وعدہ نہ ہوتا تو یہیں ان میں فیصلہ کردیا جاتا اور بیشک ظالموں کے لیے دردناک عذاب ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmccxciv{تم ظالموں کو دیکھو گے کہ اپنی کمائیوں سے سہمے ہوئے ہوں گے اور وہ ان پر پڑ کر رہیں گی اور جو ایمان لائے اور اچھے کام کیے وہ جنت کی پھلواریوں میں ہیں، ان کے لیے ان کے رب کے پاس ہے جو چاہیں، یہی بڑا فضل ہے،\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmccxcv{یہ ہے وہ جس کی خوشخبری دیتا ہے اللہ اپنے بندوں کو جو ایمان لائے اور اچھے کام کیے، تم فرماؤ میں اس پر تم سے کچھ اجرت نہیں مانگتا مگر قرابت کی محبت اور جو نیک کام کرے ہم اس کے لیے اس میں اور خوبی بڑھائیں، بیشک اللہ بخشنے والا قدر فرمانے والا ہے،\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmccxcvi{یا یہ کہتے ہیں کہ انہوں نے اللہ پر جھوٹ باندھ لیا اور اللہ چاہے تو تمہارے اوپر اپنی رحمت و حفاظت کی مہر فرمادے اور مٹا تا ہے باطل کو اور حق کو ثابت فرماتا ہے اپنی باتوں سے بیشک وہ دلوں کی باتیں جانتا ہے،\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmccxcvii{اور وہی ہے جو اپنے بندوں کی توبہ قبول فرماتا اور گناہوں سے درگزر فرماتا ہے اور جانتا ہے جو کچھ تم کرتے ہو،\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmccxcviii{اور دعا قبول فرماتا ہے ان کی جو ایمان لائے اور اچھے کام کیے اور انہیں اپنے فضل سے اور انعام دیتا ہے، اور کافروں کے لیے سخت عذاب ہے،\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmccxcix{اور اگر اللہ اپنے سب بندوں کا رزق وسیع کردیتا تو ضرور زمین میں فساد پھیلاتے لیکن وہ اندازہ سے اتارتا ہے جتنا چاہے، بیشک وہ بندوں سے خبردار ہے انہیں دیکھتا ہے،\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmccc{اور وہی ہے کہ مینہ اتارتا ہے ان کے نا امید ہونے پر اور اپنی رحمت پھیلاتا ہے اور وہی کام بنانے والا ہے سب خوبیوں سراہا،\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmccci{اور اس کی نشانیوں سے ہے آسمانوں اور زمین کی پیدائش اور جو چلنے والے ان میں پھیلائے، اور وہ ان کے اکٹھا کرنے پر جب چاہے قادر ہے،\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmcccii{اور تمہیں جو مصیبت پہنچی وہ اس کے سبب سے ہے جو تمہارے ہاتھوں نے کمایا اور بہت کچھ تو معاف فرمادیتا ہے،\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmccciii{اور تم زمین میں قابو سے نہیں نکل سکتے اور نہ اللہ کے مقابل تمہارا کوئی دوست نہ مددگار\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmccciv{اور اس کی نشانیوں سے ہیں دریا میں چلنے والیاں جیسے پہاڑیاں،\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmcccv{وہ چاہے تو ہوا تھما دے اس کی پیٹھ پر ٹھہری رہ جائیں بیشک اس میں ضرور نشانیاں ہیں ہر بڑے صابر شاکر کو\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmcccvi{یا انہیں تباہ کردے لوگوں کے گناہوں کے سبب اور بہت معاف فرمادے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmcccvii{اور جان جائیں وہ جو ہماری آیتوں میں جھگڑتے ہیں، کہ انہیں کہیں بھا گنے کی جگہ نہیں،\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmcccviii{تمہیں جو کچھ ملا ہے وہ جیتی دنیا میں برتنےکا ہے اور وہ جو اللہ کے پاس ہے بہتر ہے اور زیادہ باقی رہنے والا ان کے لیے جو ایمان لائے اور اپنے رب پر بھروسہ کرتے ہیں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmcccix{اور وہ جو بڑے بڑے گناہوں اور بے حیائیوں سے بچتے ہیں اور جب غصہ آئے معاف کردیتے ہیں،\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmcccx{اور وہ جنہوں نے اپنے رب کا حکم مانا اور نماز قائم رکھی اور ان کا کام ان کے آپس کے مشورے سے ہے اور ہمارے دیے سے کچھ ہماری راہ میں خرچ کرتے ہیں،\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxi{اور وہ کہ جب انہیں بغاوت پہنچے بدلہ لیتے ہیں\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxii{اور برائی کا بدلہ اسی کی برابر برائی ہے تو جس نے معاف کیا اور کام سنوارا تو اس کا اجر اللہ پر ہے، بیشک وہ دوست نہیں رکھتا ظالموں کو\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxiii{اور بے شک جس نے اپنی مظلو می پر بدلہ لیا ان پر کچھ مواخذہ کی راه نہیں،\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxiv{مواخذہ تو انہیں پر ہے جو لوگوں پر ظلم کرتے ہیں اور زمین میں ناحق سرکشی پھیلاتے ہیں ان کے لیے دردناک عذاب ہے،\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxv{اور بیشک جس نے صبر کیا اور بخش دیا تو یہ ضرور ہمت کے کام ہیں،\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxvi{اور جسے اللہ گمراہ کرے اس کا کوئی رفیق نہیں اللہ کے مقابل اور تم ظالموں کو دیکھو گے کہ جب عذاب دیکھیں گے کہیں گے کیا واپس جانے کا کوئی راستہ ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxvii{اور تم انہیں دیکھو گے کہ آگ پر پیش کیے جاتے ہیں ذلت سے دبے لچے چھپی نگاہوں دیکھتے ہیں اور ایمان والے کہیں گے بیشک ہار (نقصان) میں وہ ہیں جو اپنی جانیں اور اپنے گھر والے ہار بیٹھے قیامت کے دن سنتے ہو بیشک ظالم ہمیشہ کے عذاب میں ہیں،\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxviii{اور ان کے کوئی دوست نہ ہوئے کہ اللہ کے مقابل ان کی مدد کرتے اور جسے اللہ گمراہ کرے اس کے لیے کہیں راستہ نہیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxix{اپنے رب کا حکم مانو اس دن کے آنے سے پہلے جو اللہ کی طرف سے ٹلنے والا نہیں اس دن تمہیں کوئی پناہ نہ ہوگی اور نہ تمہیں انکار کرتے بنے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxx{تو اگر وہ منہ پھیریں تو ہم نے تمہیں ان پر نگہبان بناکر نہیں بھیجا تم پر تو نہیں مگر پہنچادینا اور جب ہم آدمی کو اپنی طرف سے کسی رحمت کا مزہ دیتے ہیں اور اس پر خوش ہوجاتا ہے اور اگر انہیں کوئی برائی پہنچے بدلہ اس کا جو ان کے ہاتھوں نے آگے بھیجا تو انسان بڑا ناشکرا ہے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxi{اللہ ہی کے لیے ہے آسمانوں اور زمین کی سلطنت پیدا کرتا ہے جو چاہے جسے چاہے بیٹیاں عطا فرمائے اور جسے چاہے بیٹے دے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxii{یا دونوں ملا دے بیٹے اور بیٹیاں اور جسے چاہے بانجھ کردے بیشک وہ علم و قدرت والا ہے،\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxiii{اور کسی آدمی کو نہیں پہنچتا کہ اللہ اس سے کلام فرمائے مگر وحی کے طور پر یا یوں کہ وہ بشر پر وہ عظمت کے ادھر ہو یا کوئی فرشتہ بھیجے کہ وہ اس کے حکم سے وحی کرے جو وہ چاہے بیشک وہ بلندی و حکمت والا ہے،\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxiv{اور یونہی ہم نے تمہیں وحی بھیجی ایک جان فزا چیز اپنے حکم سے، اس سے پہلے نہ تم کتاب جانتے تھے نہ احکام شرع کی تفصیل ہاں ہم نے اسے نور کیا جس سے ہم راہ دکھاتے ہیں اپنے بندوں سے جسے چاہتے ہیں، اور بیشک تم ضرور سیدھی راہ بتاتے ہو\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxv{اللہ کی راہ کہ اسی کا ہے جو کچھ آسمانوں میں ہے اور جو کچھ زمین میں، سنتے ہو سب کام اللہ ہی کی طرف پھیرتے ہیں،\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxvi{\basmalahur حٰمٓ\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxvii{روشن کتاب کی قسم\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxviii{ہم نے اسے عربی قرآن اتارا کہ تم سمجھو\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxix{اور بیشک وہ اصل کتاب میں ہمارے پاس ضرور بلندی و حکمت والا ہے،\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxx{تو کیا ہم تم سے ذکر کا پہلو پھیردیں اس پر کہ تم لوگ حد سے بڑھنے والے ہو\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxi{اور ہم نے کتنے ہی غیب بتانے والے (نبی) اگلوں میں بھیجے،\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxii{اور ان کے پاس جو غیب بتانے والا (نبی) آیا اس کی ہنسی ہی بنایا کیے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxiii{تو ہم نے وہ ہلاک کردیے جو ان سے بھی پکڑ میں سخت تھے اور اگلوں کا حال گزر چکا ہے،\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxiv{اور اگر تم ان سے پوچھو کہ آسمان اور زمین کس نے بنائے تو ضرور کہیں گے انہیں بنایا اس عزت والے علم والے نے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxv{جس نے تمہارے لیے زمین کو بچھونا کیا اورتمہارے لیے اس میں راستے کیے کہ تم راہ پاؤ\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxvi{اور وہ جس نے آسمان سے پانی اتارا ایک اندازے سے تو ہم نے اس سے ایک مردہ شہر زندہ فرمادیا، یونہی تم نکالے جاؤ گے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxvii{اور جس نے سب جوڑے بنائے اور تمہارے لیے کشتیوں اور چوپایوں سے سواریاں بنائیں،\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxviii{کہ تم ان کی پیٹھوں پر ٹھیک بیٹھو پھر اپنے رب کی نعمت یاد کرو جب اس پر ٹھیک بیٹھ لو اور یوں کہو پاکی ہے اسے جس نے اس سواری کو ہمارے بس میں کردیا اور یہ ہمارے بوتے (قابو) کی نہ تھی،\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxix{اور بیشک ہمیں اپنے رب کی طرف پلٹنا ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxl{اور اس کے لیے اس کے بندوں میں سے ٹکڑا ٹھہرایا بیشک آدمی کھلا ناشکرا ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxli{کیا اس نے اپنے لیے اپنی مخلوق میں سے بیٹیاں لیں اور تمہیں بیٹوں کے ساتھ خاص کیا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxlii{اور جب ان میں کسی کو خوشخبری دی جائے اس چیز کی جس کا وصف رحمن کے لیے بتاچکا ہے تو دن بھر اس کا منہ کالا رہے اور غم کھایا کرے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxliii{اور کیا وہ جو گہنے (زیور) میں پروان چڑھے اور بحث میں صاف بات نہ کرے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxliv{اور انہوں نے فرشتوں کو، کہ رحمٰن کے بندے ہیں عورتیں ٹھہرایا کیا ان کے بناتے وقت یہ حاضر تھے اب لکھ لی جائے گی ان کی گواہی اور ان سے جواب طلب ہوگا\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxlv{اور بولے اگر رحمٰن چاہتا ہم انہیں نہ پوجتے انہیں اس کی حقیقت کچھ معلوم نہیں یونہی اٹکلیں دوڑاتے ہیں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxlvi{یا اس سے قبل ہم نے انہیں کوئی کتاب دی ہے جسے وہ تھامے ہوئے ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxlvii{بلکہ بولے ہم نے اپنے باپ دادا کو ایک دین پر پایا اور ہم ان کی لکیر پر چل رہے ہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxlviii{اور ایسے ہی ہم نے تم سے پہلے جب کسی شہر میں ڈر سنانے والا بھیجا وہاں کے آسُودوں (امیروں) نے یہی کہا کہ ہم نے اپنے باپ دادا کو ایک دین پر پایا اور ہم ان کی لکیر کے پیچھے ہیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxlix{نبی نے فرمایا اور کیا جب بھی کہ میں تمہارے پاس وہ لاؤں جو سیدھی راہ ہو اس سے جس پر تمہارے باپ دادا تھے بولے جو کچھ تم لے کر بھیجے گئے ہم اسے نہیں مانتے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmcccl{تو ہم نے ان سے بدلہ لیا تو دیکھو جھٹلانے والوں کا کیسا انجام ہوا،\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmcccli{اور جب ابراہیم نے اپنے باپ اور اپنی قوم سے فرمایا میں بیزار ہوں تمہارے معبودو ں سے،\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmccclii{سوا اس کے جس نے مجھے پیدا کیا کہ ضرور وہ بہت جلد مجھے راہ دے گا،\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmcccliii{اور اسے اپنی نسل میں باقی کلام رکھا کہ کہیں وہ باز آئیں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmcccliv{بلکہ میں نے انہیں اور ان کے باپ دادا کو دنیا کے فائدے دیے یہاں تک کہ ان کے پاس حق اور صاف بتانے والا رسول تشریف لایا\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmccclv{اور جب ان کے پاس حق آیا بولے یہ جادو ہے اور ہم اس کے منکر ہیں،\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmccclvi{اور بولے کیوں نہ اتارا گیا یہ قرآن ان دو شہروں کے کسی بڑے آدمی پر\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmccclvii{کیا تمہارے رب کی رحمت وہ بانٹتے ہیں ہم نے ان میں ان کی زیست کا سامان دنیا کی زندگی میں بانٹا اور ان میں ایک دوسرے پر درجوں بلندی دی کہ ان میں ایک دوسرے کی ہنسی بنائے اور تمہارے رب کی رحمت ان کی جمع جتھا سے بہتر\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmccclviii{اور اگر یہ نہ ہوتا کہ سب لوگ ایک دین پر ہوجائیں تو ہم ضرور رحمٰن کے منکروں کے لیے چاندی کی چھتیں اور سیڑھیاں بناتے جن پر چڑھتے،\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmccclix{اور ان کے گھروں کے لیے چاندی کے دروازے اور چاندی کے تخت جن پر تکیہ لگاتے،\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmccclx{اور طرح طرح کی آرائش اور یہ جو کچھ ہے جیتی دنیا ہی کا اسباب ہے، اور آخرت تمہارے رب کے پاس پرہیزگاروں کے لیے ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxi{اور جسے رند تو آئے (شب کوری ہو) رحمن کے ذکر سے ہم اس پر ایک شیطان تعینات کریں کہ وہ اس کا ساتھی رہے،\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxii{اور بیشک وہ شیاطین ان کو راہ سے روکتے ہیں اور سمجھتے یہ ہیں کہ وہ راہ پر ہیں،\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxiii{یہاں تک کہ جب کافر ہمارے پاس آئے گا اپنے شیطان سے کہے گا ہائے کسی طرح مجھ میں تجھ میں پورب پچھم کا فاصلہ ہوتا تو کیا ہی برا ساتھی ہے،\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxiv{اور ہرگز تمہارا اس سے بھلا نہ ہوگا آج جبکہ تم نے ظلم کیا کہ تم سب عذاب میں شریک ہو،\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxv{تو کیا تم بہروں کو سناؤ گے یا اندھوں کو راہ دکھاؤ گے اور انہیں جو کھلی گمراہی میں ہیں\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxvi{تو اگر ہم تمہیں لے جائیں تو ان سے ہم ضرور بدلہ لیں گے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxvii{یا تمہیں دکھادیں جس کا انہیں ہم نے وعدہ دیا ہے تو ہم ان پر بڑی قدرت والے ہیں،\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxviii{تو مضبوط تھامے رہو اسے جو تمہاری طرف وحی کی گئی بیشک تم سیدھی راہ پر ہو،\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxix{اور بیشک وہ شرف ہے تمہارے لیے اور تمہاری قوم کے لیے اور عنقریب تم سے پوچھا جائے گا\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxx{اور ان سے پوچھو جو ہم نے تم سے پہلے رسول بھیجے کیا ہم نے رحمان کے سوا کچھ اور خدا ٹھہرائے جن کو پوجا ہو\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxi{اور بیشک ہم نے موسیٰ کو اپنی نشایوں کے ساتھ فرعون اور اس کے سرداروں کی طرف بھیجا تو اس نے فرمایا بیشک میں اس کا رسول ہوں جو سارے جہاں کا مالک ہے،\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxii{پھر جب وہ ان کے پاس ہماری نشانیاں لایا جبھی وہ ان پر ہنسنے لگے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxiii{اور ہم انہیں جو نشانی دکھاتے وہ پہلے سے بڑی ہوتی اور ہم نے انہیں مصیبت میں گرفتار کیا کہ وہ بام آئیں\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxiv{اور بولے کہ اے جادوگر ہمارے لیے اپنے رب سے دعا کر کہ اس عہد کے سبب جو اس کا تیرے پاس ہے بیشک ہم ہدایت پر آئیں گے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxv{پھر جب ہم نے ان سے وہ مصیبت ٹال دی جبھی وہ عہد توڑ گئے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxvi{اور فرعون اپنی قوم میں پکارا کہ اے میری قوم! کیا میرے لیے مصر کی سلطنت نہیں اور یہ نہریں کہ میرے نیچے بہتی ہیں تو کیا تم دیکھتے نہیں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxvii{یا میں بہتر ہوں اس سے کہ ذلیل ہے اور بات صاف کرتا معلوم نہیں ہوتا\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxviii{تو اس پر کیوں نہ ڈالے گئے سونے کے کنگن یا اس کے ساتھ فرشتے آتے کہ اس کے پاس رہتے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxix{پھر اس نے اپنی قوم کو کم عقل کرلیا تو وہ اس کے کہنے پر چلے بیشک وہ بے حکم لوگ تھے،\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxx{پھر جب انہوں نے وہ کیا جس پر ہمارا غضب ان پر آیا ہم نے ان سے بدلہ لیا تو ہم نے ان سب کو ڈبودیا،\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxi{انہیں ہم نے کردیا اگلی داستان اور کہاوت پچھلوں کے لیے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxii{اور جب ابنِ مریم کی مثال بیان کی جائے، جبھی تمہاری قوم اس سے ہنسنے لگتے ہیں\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxiii{اور کہتے ہیں کیا ہمارے معبود بہتر ہیں یا وہ انہوں نے تم سے یہ نہ کہی مگر ناحق جھگڑے کو بلکہ وہ ہیں جھگڑالو لوگ\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxiv{وہ تو نہیں مگر ایک بندہ جس پر ہم نے احسان فرمایا اور اسے ہم نے بنی اسرائیل کے لیے عجیب نمونہ بنایا\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxv{اور اگر ہم چاہتے تو زمین میں تمہارے بدلے فرشتے بساتے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxvi{اور بیشک عیسی ٰ قیامت کی خبر ہے تو ہرگز قیامت میں شک نہ کرنا اور میرے پیرو ہونا یہ سیدھی راہ ہے،\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxvii{اور ہرگز شیطان تمہیں نہ روک دے بیشک وہ تمہارا کھلا دشمن ہے،\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxviii{اور جب عیسیٰ روشن نشانیاں لایا اس نے فرمایا میں تمہارے پاس حکمت لے کر آیا اور اس لیے میں تم سے بیان کردوں بعض وہ باتیں جن میں تم اختلاف رکھتے ہو تو اللہ سے ڈرو اور میرا حکم مانو،\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxix{بیشک اللہ میرا رب اور تمہارا رب تو اسے پوجو، یہ سیدھی راہ ہے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxc{پھر وہ گروہ آپس میں مختلف ہوگئے تو ظالموں کی خرابی ہے ایک درد ناک دن کے عذاب سے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxci{کاہے کے انتظار میں ہیں مگر قیامت کے کہ ان پر اچانک آجائے اور انہیں خبر نہ ہو،\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxcii{گہرے دوست اس دن ایک دوسرے کے دشمن ہوں گے مگر پرہیزگار\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxciii{ان سے فرمایا جائے گا اے میرے بندو آج نہ تم پر خوف نہ تم کو غم ہو،\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxciv{وہ جو ہماری آیتوں پر ایمان لائے اور مسلمان تھے،\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxcv{داخل ہو جنت میں تم اور تمہاری بیبیاں اور تمہاری خاطریں ہوتیں\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxcvi{ان پر دورہ ہوگا سونے کے پیالوں اور جاموں کا اور اس میں جو جی چاہے اور جس سے آنکھ کو لذت پہنچے اور تم اس میں ہمیشہ رہو گے،\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxcvii{اور یہ ہے وہ جنت جس کے تم وارث کیے گئے اپنے اعمال سے،\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxcviii{تمہارے لیے اس میں بہت میوے ہیں کہ ان میں سے کھاؤ\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxcix{بیشک مجرم جہنم کے عذاب میں ہمیشہ رہنے والے ہیں،\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmmcd{وہ کبھی ان پر سے ہلکا نہ پڑے گا اور وہ اس میں بے آ س رہیں گے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmmcdi{اور ہم نے ان پر کچھ ظلم نہ کیا، ہاں وہ خود ہی ظالم تھے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmmcdii{اور وہ پکاریں گے اے مالک تیرا رب ہمیں تمام کرچکے وہ فرمائے گا تمہیں تو ٹھہرنا\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmmcdiii{بیشک ہم تمہارے پاس حق لائے مگر تم میں اکثر کو حق ناگوار ہے،\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmmcdiv{کیا انہوں نے اپنے خیال میں کوئی کام پکا کرلیا ہے\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmmmcdv{تو ہم اپنا کام پکا کرنے والے ہیں کیا اس گھمنڈ میں ہیں کہ ہم ان کی آہستہ بات اور ان کی مشورت نہیں سنتے، ہاں کیوں نہیں اور ہمارے فرشتے ان کے پاس لکھ رہے ہیں،\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmmmcdvi{تم فرماؤ بفرض محال رحمٰن کے کوئی بچہ ہوتا، تو سب سے پہلے میں پوجتا\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmmmcdvii{پاکی ہے آسمانوں اور زمین کے رب کو، عرش کے رب کو ان باتوں سے جو یہ بناتے ہیں\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmmmcdviii{تو تم انہیں چھوڑو کہ بیہودہ باتیں کریں اور کھیلیں یہاں تک کہ اپنے اس دن کو پائیں جس کا ان سے وعدہ ہے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmmmcdix{اور وہی آسمان والوں کا خدا اور زمین والوں کا خدا اور وہی حکمت و علم والا ہے،\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmmmcdx{اور بڑی برکت والا ہے وہ کہ اسی کے لیے ہے سلطنت آسمانوں اور زمین کی اور جو کچھ ان کے درمیان ہے اور اسی کے پاس ہے قیامت کا علم، اور تمہیں اس کی طرف پھرنا،\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxi{اور جن کو یہ اللہ کے سوا پوجتے ہیں شفاعت کا اختیار نہیں رکھتے، ہاں شفاعت کا اختیار انہیں ہے جو حق کی گواہی دیں اور علم رکھیں\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxii{اور اگر تم ان سے پوچھو انہیں کس نے پیدا کیا تو ضرور کہیں گے اللہ نے تو کہاں اوندھے جاتے ہیں\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxiii{مجھے رسول کے اس کہنے کی قسم کہ اے میرے رب! یہ لوگ ایمان نہیں لاتے،\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxiv{تو ان سے درگزر کرو اور فرماؤ بس سلام ہے کہ آگے جان جائیں گے\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxv{\basmalahur حٰمٓ\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxvi{قسم اس روشن کتاب کی\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxvii{بیشک ہم نے اسے برکت والی رات میں اتارا بیشک ہم ڈر سنانے والے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxviii{اس میں بانٹ دیا جاتا ہے ہر حکمت والا کام\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxix{ہمارے پاس کے حکم سے، بیشک ہم بھیجنے والے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxx{تمہارے رب کی طرف سے رحمت، بیشک وہی سنتا جانتا ہے،\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxi{وہ جو رب ہے آسمانوں اور زمین کا اور جو کچھ ان کے درمیان ہے، اگر تمہیں یقین ہو\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxii{اس کے سوا کسی کی بندگی نہیں وہ جِلائے اور مارے، تمہارا رب اور تمہارے اگلے باپ دادا کا رب،\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxiii{بلکہ وہ شک میں پڑے کھیل رہے ہیں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxiv{تو تم اس دن کے منتظر رہو جب آسمان ایک ظاہر دھواں لائے گا،\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxv{کہ لوگوں کو ڈھانپ لے گا یہ ہے دردناک عذاب،\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxvi{اس دن کہیں گے، اے ہمارے رب! ہم پر سے عذاب کھول دے ہم ایمان لاتے ہیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxvii{کہاں سے ہو انہیں نصیحت ماننا حالانکہ ان کے پاس صاف بیان فرمانے والا رسول تشریف لاچکا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxviii{اس سے روگرداں ہوئے اور بولے سکھایا ہوا دیوانہ ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxix{ہم کچھ دنوں کو عذاب کھولے دیتے ہیں تم پھر وہی کرو گے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxx{جس دن ہم سب سے بڑی پکڑ پکڑیں گے بیشک ہم بدلہ لینے والے ہیں،\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxi{اور بیشک ہم نے ان سے پہلے فرعون کی قوم کو جانچا اور ان کے پاس ایک معزز رسول تشریف لایا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxii{کہ اللہ کے بندوں کو مجھے سپرد کردو بیشک میں تمہارے لیے امانت والا رسول ہوں،\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxiii{اور اللہ کے مقابل سرکشی نہ کرو، میں تمہارے پاس ایک روشن سند لاتا ہوں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxiv{اور میں پناہ لیتا ہوں اپنے رب اور تمہارے رب کی اس سے کہ تم مجھے سنگسار کرو\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxv{اور اگر میرا یقین نہ لاؤ تو مجھ سے کنارے ہوجاؤ\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxvi{تو اس نے اپنے رب سے دعا کی کہ یہ مجرم لوگ ہیں،\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxvii{ہم نے حکم فرمایا کہ میرے بندوں کو راتوں رات لے نکل ضرور تمہارا پیچھا کیا جائے گا\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxviii{اور دریا کو یونہی جگہ جگہ سے چھوڑ دے بیشک وہ لشکر ڈبو دیا جائے گا\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxix{کتنے چھوڑ گئے باغ اور چشمے،\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxl{او رکھیت اور عمدہ مکانات\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxli{اور نعمتیں جن میں فارغ البال تھے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxlii{ہم نے یونہی کیا اور ان کا وارث دوسری قوم کو کردیا\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxliii{تو ان پر آسمان اور زمین نہ روئے اور انہیں مہلت نہ دی گئی\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxliv{اور بیشک ہم نے بنی اسرائیل کو ذلت کے عذاب سے نجات بخشی\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxlv{فرعون سے، بیشک وہ متکبر حد سے بڑھنے والوں سے،\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxlvi{اور بیشک ہم نے انہیں دانستہ چن لیا اس زمانے والوں سے،\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxlvii{ہم نے انہیں وہ نشانیاں عطا فرمائیں جن میں صریح انعام تھا\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxlviii{بیشک یہ کہتے ہیں،\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxlix{وہ تو نہیں مگر ہمارا ایک دفعہ کا مرنا اور ہم اٹھائے نہ جائیں گے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmcdl{تو ہمارے باپ دادا کو لے آؤ اگر تم سچے ہو\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmcdli{کیا وہ بہتر ہیں یا تبع کی قوم اور جو ان سے پہلے تھے ہم نے انہیں ہلاک کردیا بیشک وہ مجرم لوگ تھے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlii{اور ہم نے نہ بنائے آسمان اور زمین اور جو کچھ ان کے درمیان ہے کھیل کے طور پر\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmcdliii{ہم نے انہیں نہ بنایا مگر حق کے ساتھ لیکن ان میں اکثر جانتے نہیں\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmcdliv{بیشک فیصلہ کا دن ان سب کی میعاد ہے،\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlv{جس دن کوئی دوست کسی دوست کے کچھ کام نہ آئے گا اور نہ ان کی مدد ہوگی\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlvi{مگر جس پر اللہ رحم کرے بیشک وہی عزت والا مہربان ہے،\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlvii{بیشک تھوہڑ کا پیڑ\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlviii{گنہگاروں کی خوراک ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlix{گلے ہوئے تانبے کی طرح پیٹوں میں جوش مارتا ہے،\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlx{جیسا کھولتا پانی جوش مارے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxi{اسے پکڑو ٹھیک بھڑکتی آگ کی طرف بزور گھسیٹتے لے جاؤ،\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxii{پھر اس کے سر کے اوپر کھولتے پانی کا عذاب ڈالو\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxiii{چکھ، ہاں ہاں تو ہی بڑا عزت والا کرم والا ہے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxiv{بیشک یہ ہے وہ جس میں تم شبہہ کرتے تھے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxv{بیشک ڈر والے امان کی جگہ میں ہیں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxvi{باغوں اور چشموں میں،\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxvii{پہنیں گے کریب اور قنادیز آمنے سامنے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxviii{یونہی ہے، اور ہم نے انہیں بیاہ دیا نہایت سیاہ اور روشن بڑی آنکھوں والیوں سے،\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxix{اس میں ہر قسم کا میوہ مانگیں گے امن و امان سے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxx{اس میں پہلی موت کے سوا پھر موت نہ چکھیں گے اور اللہ نے انہیں آگ کے عذاب سے بچالیا،\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxi{تمہارے رب کے فضل سے، یہی بڑی کامیابی ہے،\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxii{تو ہم نے اس قرآن کو تمہاری زبان میں آسان کیا کہ وہ سمجھیں\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxiii{تو تم انتظار کرو وہ بھی کسی انتظار میں ہیں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxiv{\basmalahur حٰمٓ\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxv{کتاب کا اتارنا ہے اللہ عزت و حکمت والے کی طرف سے،\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxvi{بیشک آسمانوں اور زمین میں نشانیاں ہیں ایمان والوں کے لیے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxvii{اور تمہاری پیدائش میں اور جو جو جانور وہ پھیلاتا ہے ان میں نشانیاں ہیں یقین والوں کے لیے،\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxviii{اور رات اور دن کی تبدیلیوں میں اور اس میں کہ اللہ نے آسمان سے روزی کا سبب مینہ اتارا تو اس سے زمین کو اس کے مَرے پیچھے زندہ کیا اور ہواؤں کی گردش میں نشانیاں ہیں عقل مندوں کے لیے،\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxix{یہ اللہ کی آیتیں ہیں کہ ہم تم پر حق کے ساتھ پڑھتے ہیں، پھر اللہ اور اس کی آیتوں کو چھوڑ کر کونسی بات پر ایمان لائیں گے،\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxx{خرابی ہے ہر بڑے بہتان ہائے گنہگار کے لیے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxi{اللہ کی آیتوں کو سنتا ہے کہ اس پر پڑھی جاتی ہیں پھر ہٹ پر جمتا ہے غرور کرتا گویا انہیں سنا ہی نہیں تو اسے خوشخبری سناؤ درد ناک عذاب کی،\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxii{اور جب ہماری آیتوں میں سے کسی پر اطلاع پائے اس کی ہنسی بناتا ہے ان کے لیے خواری کا عذاب،\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxiii{ان کے پیچھے جہنم ہے اور انہیں کچھ کام نہ دے گا ان کا کمایا ہوا اور نہ وہ جو اللہ کے سوا حمایتی ٹھہرا رکھے تھے اور ان کے لیے بڑا عذاب ہے،\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxiv{یہ راہ دکھانا ہے اور جنہوں نے اپنے رب کی آیتوں کو نہ مانا ان کے لیے دردناک عذاب میں سے سخت تر عذاب ہے،\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxv{اللہ ہے جس نے تمہارے بس میں دریا کردیا کہ اس میں اس کے حکم سے کشتیاں چلیں اور اس لیے کہ اس کا فضل تلاش کرو اور اس لیے کہ حق مانو\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxvi{اور تمہارے لیے کام میں لگائے جو کچھ آسمان میں ہیں اور جو کچھ زمین میں اپنے حکم سے بے شک اس میں نشا نیاں ہیں سوچنے والوں کے لئے،\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxvii{ایمان وا لوں سے فرماؤ درگزریں ان سے جو اللہ کے دنوں کی امید نہیں رکھتے تاکہ اللہ ایک قوم کو اس کی کمائی کا بدلہ دے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxviii{جو بھلا کام کرے تو اپنے لیے اور برا کرے تو اپنے برے کو پھر اپنے رب کی طرف پھیرے جاؤ گے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxix{اور بیشک ہم نے بنی اسرائیل کو کتاب اور حکومت اور نبوت عطا فرمائی اور ہم نے انہیں ستھری روزیاں دیں اور انہیں ان کے زمانے والوں پر فضیلت بخشی،\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxc{اور ہم نے انہیں اس کام کی روشن دلیلیں دیں تو انہوں نے اختلاف نہ کیا مگر بعد اس کے کہ علم ان کے پاس آچکا آپس کے حسد سے بیشک تمہارا رب قیامت کے دن ان میں فیصلہ کردے گا جس بات میں اختلاف کرتے یں،\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxci{پھر ہم نے اس کام کے عمدہ راستہ پر تمہیں کیا تو اسی راہ پر چلو اور نادانوں کی خواہشوں کا ساتھ نہ دو\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxcii{بیشک وہ اللہ کے مقابل تمہیں کچھ کام نہ دیں گے، اور بیشک ظالم ایک دوسرے کے دوست ہیں اور ڈر والوں کا دوست اللہ\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxciii{یہ لوگوں کی آنکھیں کھولنا ہے اور ایمان والوں کے لیے ہدایت و رحمت،\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxciv{کیا جنہوں نے برائیوں کا ارتکاب کیا یہ سمجھتے ہیں کہ ہم انہیں ان جیسا کردیں گے جو ایمان لائے اور اچھے کام کیے کہ ان کی ان کی زندگی اور موت برابر ہوجائے کیا ہی برا حکم لگاتے ہیں،\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxcv{اور اللہ نے آسمان اور زمین کو حق کے ساتھ بنایا اور اس لیے کہ ہر جان اپنے کیے کا بدلہ پائے اور ان پر ظلم نہ ہوگا،\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxcvi{بھلا دیکھو تو وہ جس نے اپنی خواہش کو اپنا خدا ٹھہرالیا اور اللہ نے اسے با وصف علم کے گمراہ کیا اور اس کے کان اور دل پر مہر لگادی اور اس کی آنکھوں پر پردہ ڈالا تو اللہ کے بعد اسے کون راہ دکھائے، تو کیا تم دھیان نہیں کرتے،\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxcvii{اور بولے وہ تو نہیں مگر یہی ہماری دنیا کی زندگی مرتے ہیں اور جیتے ہیں اور ہمیں ہلاک نہیں کرتا مگر زمانہ اور انہیں اس کا علم نہیں وہ تو نرے گمان دوڑاتے ہیں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxcviii{اور جب ان پر ہماری روشن آیتیں پڑھی جائیں تو بس ان کی حجت یہی ہوتی ہے کہ کہتے ہیں کہ ہمارے باپ دادا کو لے آؤ اگر تم سچے ہو\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxcix{تم فرماؤ اللہ تمہیں جِلاتا ہے پھر تم کو مارے گا پھر تم سب کو اکٹھا کریگا قیامت کے دن جس میں کوئی شک نہیں لیکن بہت آدمی نہیں جانتے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmd{اور اللہ ہی کے لیے ہے آسمانوں اور زمین کی سلطنت، اور جس دن قیامت قائم ہوگی باطل والوں کی اس دن ہار ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmdi{اور تم ہر گرو ه کو دیکھو گے زانو کے بل گرے ہوئے ہر گروہ اپنے نامہٴ اعمال کی طرف بلایا جائے گا آج تمہیں تمہارے کیے کا بدلہ دیا جائے گا،\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmdii{ہمارا یہ نوشتہ تم پر حق بولتا ہے، ہم لکھتے رہے تھے جو تم نے کیا،\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmdiii{تو وہ جو ایمان لائے اور اچھے کام کیے ان کا رب انہیں اپنی رحمت میں لے گا یہی کھلی کامیابی ہے،\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmdiv{اور جو کافر ہوئے ان سے فرمایا جائے گا، کیا نہ تھا کہ میری آیتیں تم پر پڑھی جاتی تھیں تو تم تکبر کرتے تھے اور تم مجرم لوگ تھے،\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmdv{اور جب کہا جاتا بیشک اللہ کا وعدہ سچا ہے اور قیامت میں شک نہیں تم کہتے ہم نہیں جانتے قیامت کیا چیز ہے ہمیں تو یونہی کچھ گمان سا ہوتا ہے اور ہمیں یقین نہیں،\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmdvi{اور ان پر کھل گئیں ان کے کاموں کی برائیاں اور انہیں گھیرلیا اس عذاب نے جس کی ہنسی بناتے تھے،\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmdvii{اور فرمایا جائے گا آج ہم تمہیں چھوڑدیں گے جیسے تم اپنے اس دن کے ملنے کو بھولے ہوئے تھے اور تمہارا ٹھکانا آ گ ہے اور تمہارا کوئی مددگار نہیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmdviii{یہ اس لیے کہ تم نے اللہ کی آیتوں کا ٹھٹھا (مذاق) بنایا اور دنیا کی زندگی نے تمہیں فریب دیا تو آج نہ وہ آگ سے نکالے جائیں اور نہ ان سے کوئی منانا چاہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmdix{تو اللہ ہی کے لیے سب خوبیاں ہیں آسمانوں کا رب اور زمین کا رب اور سارے جہاں کا رب،\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmdx{اور اسی کے لیے بڑائی ہے آسمانوں اور زمین میں، اور وہی عزت و حکمت والا ہے،\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmdxi{\basmalahur حٰمٓ\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmdxii{یہ کتاب اتارنا ہے اللہ عزت و حکمت والے کی طرف سے،\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmdxiii{ہم نے نہ بنائے آسمان اور زمین اور جو کچھ ان کے درمیان ہے مگر حق کے ساتھ اور ایک مقرر میعاد پر اور کافر اس چیز سے کہ ڈرائے گئے منہ پھیرے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmdxiv{تم فرماؤ بھلا بتاؤ تو وہ جو تم اللہ کے سوا پوجتے ہو مجھے دکھاؤ انہوں نے زمین کا کون سا ذرہ بنایا یا آسمان میں ان کا کوئی حصہ ہے، میرے پاس لاؤ اس سے پہلی کوئی کتاب یا کچھ بچا کھچا علم اگر تم سچے ہو\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmdxv{اور اس سے بڑھ کر گمراہ کون جو اللہ کے سوا ایسوں کو پوجے جو قیامت تک اس کی نہ سنیں اور انہیں ان کی پوجا کی خبر تک نہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmdxvi{اور جب لوگوں کا حشر ہوگا وہ ان کے دشمن ہوں گے اور ان سے منکر ہوجائیں گے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmdxvii{اور جب ان پر پڑھی جائیں ہماری روشن آیتیں تو کافر اپنے پاس آئے ہوئے حق کو کہتے ہیں یہ کھلا جادو ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmdxviii{کیا کہتے ہیں انہوں نے اسے جی سے بنایا تم فرماؤ اگر میں نے اسے جی سے بنالیا ہوگا تو تم اللہ کے سامنے میرا کچھ اختیار نہیں رکھتے وہ خوب جانتا ہے جن باتوں میں تم مشغول ہو اور وہ کافی ہے میرے اور تمہارے درمیان گواہ، اور وہی بخشنے والا مہربان ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmdxix{تم فرماؤ میں کوئی انوکھا رسول نہیں اور میں نہیں جانتا میرے ساتھ کیا کیا جائے گا اور تمہارے ساتھ کیا میں تو اسی کا تابع ہوں جو مجھے وحی ہوتی ہے اور میں نہیں مگر صاف ڈر سنانے والا،\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmdxx{تم فرماؤ بھلا دیکھو تو اگر وہ قرآن اللہ کے پاس سے ہو اور تم نے اس کا انکار کیا اور بنی اسرائیل کا ایک گواہ اس پر گواہی دے چکا تو وہ ایمان لایا اور تم نے تکبر کیا بیشک اللہ راہ نہیں دیتا ظالموں کو،\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxi{اور کافروں نے مسلمانوں کو کہا اگر اس میں کچھ بھلائی ہو تو یہ ہم سے آگے اس تک نہ پہنچ جاتے اور جب انہیں اس کی ہدایت نہ ہوئی تو اب کہیں گے کہ یہ پرانا بہتان ہے،\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxii{اور اس سے پہلے موسیٰ کی کتاب سے پیشوا اور مہربانی، اور یہ کتاب ہے تصدیق فرماتی عربی زبان میں کہ ظالموں کو ڈر سنائے، اور نیکوں کو بشارت،\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxiii{بیشک وہ جنہوں نے کہا ہمارا رب اللہ ہے پھر ثابت قدم رہے نہ ان پر خوف نہ ان کو غم\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxiv{وہ جنت والے ہیں ہمیشہ اس میں رہیں گے ان کے اعمال کا انعام،\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxv{اور ہم نے آدمی کو حکم کیا اپنے ماں باپ سے بھلائی کرے، ا س کی ماں نے اسے پیٹ میں رکھا تکلیف سے اور جنا اس کو تکلیف سے، اور اسے اٹھائے پھرنا اور اس کا دودھ چھڑانا تیس مہینے میں ہے یہاں تک کہ جب اپنے زور کو پہنچا اور چالیس برس کا ہوا عرض کی اے میرے رب! میرے دل میں ڈال کہ میں تیری نعمت کا شکر کروں جو تو نے مجھ پر اور میرے ماں باپ پر کی اور میں وہ کام کروں جو تجھے پسند آئے اور میرے لیے میری اولاد میں صلاح (نیکی) رکھ میں تیری طرف رجوع لایا اور میں مسلمان ہوں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxvi{یہ ہیں وہ جن کی نیکیاں ہم قبول فرمائیں گے اور ان کی تقصیروں سے درگزر فرمائیں گے جنت والوں میں، سچا وعدہ جو انہیں دیا جاتا تھا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxvii{اور وہ جس نے اپنے ماں باپ سے کہا اُف تم سے دل پک گیا (بیزار ہے) کیا مجھے یہ وعدہ دیتے ہو کہ پھر زندہ کیا جاؤں گا حالانکہ مجھ پر سے پہلے سنگتیں گزر چکیں اور وہ دونوں اللہ سے فریاد کرتے ہیں تیری خرابی ہو ایمان لا، بیشک اللہ کا وعدہ سچا ہے تو کہتا ہے یہ تو نہیں مگر اگلوں کی کہانیاں\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxviii{یہ وہ ہیں جن پر بات ثابت ہوچکی ان گروہوں میں جو ان سے پلے گزرے جن اور آدمی، بیشک وہ زیاں کار تھے،\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxix{اور ہر ایک کے لیے اپنے اپنے عمل کے درجے ہیں اور تاکہ اللہ ان کے کام انہیں پورے بھردے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxx{اور ان پر ظلم نہ ہوگا، اور جس دن کافر آگ پر پیش کیے جائیں گے، ان سے فرمایا جائے گا تم اپنے حصہ کی پاک چیزیں اپنی دنیا ہی کی زندگی میں فنا کرچکے اور انہیں برت چکے تو آج تمہیں ذلت کا عذاب بدلہ دیا جائے گا سزا اس کی کہ تم زمین میں ناحق تکبر کرتے تھے اور سزا اس کی کہ حکم عدولی کرتے تھے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxi{اور یاد کرو عاد کے ہم قوم کو جب اس نے ان کو سرزمینِ احقاف میں ڈرایا اور بیشک اس سے پہلے ڈر سنانے والے گزر چکے اور اس کے بعد آئے کہ اللہ کے سوا کسی کو نہ پُوجو، بیشک مجھے تم پر ایک بڑے دن کے عذاب کا اندیشہ ہے،\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxii{بولے کیا تم اس لیے آئے کہ ہمیں ہمارے معبودوں سے پھیر دو، تو ہم پر لاؤ جس کا ہمیں وعدہ دیتے ہو اگر تم سچے ہو،\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxiii{اس نے فرمایا اس کی خبر تو اللہ ہی کے پاس ہے میں تو تمہیں اپنے رب کے پیام پہنچاتا ہوں ہاں میری دانست میں تم نرے جاہل لوگ ہو\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxiv{پھر جب انہوں نے عذاب کو دیکھا بادل کی طرح آسمان کے کنارے میں پھیلا ہوا ان کی وادیوں کی طرف آتا بولے یہ بادل ہے کہ ہم پر برسے گا بلکہ یہ تو وہ ہے جس کی تم جلدی مچاتے تھے، ایک آندھی ہے جس میں دردناک عذاب،\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxv{ہر چیز کو تباہ کر ڈالتی ہے اپنے رب کے حکم سے تو صبح رہ گئے کہ نظر نہ آتے تھے مگر ان کے سُونے مکان، ہم ایسی ہی سزا دیتے ہیں مجرموں کو،\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxvi{اور بیشک ہم نے انہیں وہ مقدور دیے تھے جو تم کو نہ دیے اور ان کے لیے کان اور آنکھ اور دل بنائے تو ان کے کام کان اور آنکھیں اور دل کچھ کام نہ آئے جبکہ وہ اللہ کی آیتوں کا انکار کرتے تھے اور انہیں گھیرلیا اس عذاب نے جس کی ہنسی بناتے تھے،\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxvii{اور بیشک ہم نے ہلاک کردیں تمہارے آس پاس کی بستیاں اور طرح طرح کی نشانیاں لائے کہ وہ باز آئیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxviii{تو کیوں نہ مدد کی ان کی جن کو انہوں نے اللہ کے سوا قرب حاصل کرنے کو خدا ٹھہرا رکھا تھا بلکہ وہ ان سے گم گئے اور یہ ان کا بہتان و افتراء ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxix{اور جبکہ ہم نے تمہاری طرف کتنے جن پھیرے کان لگا کر قرآن سنتے، پھر جب وہاں حاضر ہوئے آپس میں بولے خاموش رہو پھر جب پڑھنا ہوچکا اپنی قوم کی طرف ڈر سناتے پلٹے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmdxl{بولے اے ہماری قوم ہم نے ایک کتاب سنی کہ موسیٰ کے بعد اتاری گئی اگلی کتابوں کی تصدیق فرمائی حق اور سیدھی راہ دکھائی،\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmdxli{اے ہماری قوم! اللہ کے منادی کی بات مانو اور اس پر ایمان لاؤ کہ وہ تمہارے کچھ گناہ بخش دے اور تمہیں دردناک عذاب سے بچالے،\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmdxlii{اور جو اللہ کے منادی کی بات نہ مانے وہ زمین میں قابو سے نکل کر جانے والا نہیں اور اللہ کے سامنے اس کا کوئی مددگار نہیں وہ کھلی گمراہی میں ہیں،\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmdxliii{کیا انہوں نے نہ جانا کہ وہ اللہ جس نے آسمان اور زمین بنائے اور ان کے بنانے میں نہ تھکا قادر ہے کہ مردے جِلائے، کیوں نہیں بیشک وہ سب کچھ کرسکتا ہے،\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmdxliv{اور جس دن کافر آگ پر پیش کیے جائیں گے، ان سے فرمایا جائے گا کیا یہ حق نہیں کہیں گے کیوں نہیں ہمارے رب کی قسم، فرمایا جائے گا تو عذاب چکھو بدلہ اپنے کفر کا\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmdxlv{تو تم صبر کرو جیسا ہمت والے رسولوں نے صبر کیا اور ان کے لیے جلدی نہ کرو گویا وہ جس دن دیکھیں گے جو انہیں وعدہ دیا جاتا ہے دنیا میں نہ ٹھہرے تھے مگر دن کی ایک گھڑی بھر یہ پہنچانا ہے تو کون ہلاک کیے جائیں گے مگر بے حکم لوگ\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmdxlvi{\basmalahur جنہوں نے کفر کیا اور اللہ کی راہ سے روکا اللہ نے ان کے عمل برباد کیے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmdxlvii{اور ایمان لائے اور اچھے کام کیے اور اس پر ایمان لائے جو محمد پر اتارا گیا اور وہی ان کے رب کے پاس سے حق ہے اللہ نے ان کی برائیاں اتار دیں اور ان کی حالتیں سنوار دیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmdxlviii{یہ اس لیے کہ کافر باطل کے پیرو ہوئے اور ایمان والوں نے حق کی پیروی کی جو ان کے رب کی طرف سے ہے اللہ لوگوں سے ان کے احوال یونہی بیان فرماتا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmdxlix{تو جب کافروں سے تمہارا سامناہو تو گردنیں مارنا ہے یہاں تک کہ جب انہیں خوب قتل کرلو تو مضبوط باندھو، پھر اس کے بعد چاہے احسان کرکے چھوڑ دو چاہے فدیہ لے لو یہاں تک کہ لڑائی اپنابوجھ رکھ دے بات یہ ہے اوراللہ چاہتا تو آپ ہی اُن سے بدلہ لیتا مگر اس لئے تم میں ایک کو دوسرے سے جانچے اور جو اللہ کی راہ میں مارے گئے اللہ ہرگز ان کے عمل ضائع نہ فرمائے گا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmdl{جلد انہیں راہ دے گا اور ان کا کام بنادے گا،\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmdli{اور انہیں جنت میں لے جائے گا انہیں اس کی پہچان کرادی ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmdlii{اے ایمان والو اگر تم دین خدا کی مدد کرو گے اللہ تمہاری مدد کرے گا اور تمہارے قدم جمادے گا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmdliii{اور جنہوں نے کفر کیا تو ان پر تباہی پڑے اور اللہ ان کے اعمال برباد کرے،\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmdliv{یہ اس لیے کہ انہیں ناگوار ہوا جو اللہ نے اتارا تو اللہ نے ان کا کیا دھرا اِکارت کیا،\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmdlv{تو کیا انہوں نے زمین میں سفر نہ کیا کہ دیکھتے ان سے اگلوں کا کیسا انجام ہوا، اللہ نے ان پر تباہی ڈالی اور ان کافروں کے لیے بھی ویسی کتنی ہی ہیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmdlvi{یہ اس لیے کہ مسلمانوں کا مولیٰ اللہ ہے اور کافروں کا کوئی مولیٰ نہیں،\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmdlvii{بیشک اللہ داخل فرمائے گا انہیں جو ایمان لائے اور اچھے کام کیے باغوں میں جن کے نیچے نہریں رواں، اور کافر برتتے ہیں اور کھاتے ہیں جیسے چوپائے کھائیں اور آگ میں ان کا ٹھکانا ہے،\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmdlviii{اور کتنے ہی شہر کہ اس شہر سے قوت میں زیادہ تھے جس نے تمہیں تمہارے شہر سے باہر کیا، ہم نے انہیں ہلاک فرمایا تو ان کا کوئی مددگار نہیں\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmdlix{تو کیا جو اپنے رب کی طرف سے روشن دلیل پر ہو اُس جیسا ہوگا جس کے برے عمل اسے بھلے دکھائے گئے اور وہ اپنی خواہشوں کے پیچھے چلے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmdlx{احوال اس جنت کا جس کا وعدہ پرہیزگاروں سے ہے، اس میں ایسی پانی کی نہریں ہیں جو کبھی نہ بگڑے اور ایسے دودھ کی نہریں ہیں جس کا مزہ نہ بدلا اور ایسی شراب کی نہریں ہیں جس کے پینے میں لذت ہے اور ایسی شہد کی نہریں ہیں جو صاف کیا گیا اور ان کے لیے اس میں ہر قسم کے پھل ہیں، اور اپنے رب کی مغفرت کیا ایسے چین والے ان کی برابر ہوجائیں گے جنہیں ہمیشہ آگ میں رہنا اور انہیں کھولتا پانی پلایا جائے گا کہ آنتوں کے ٹکڑے ٹکڑے کردے،\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxi{اور ان میں سے بعض تمہارے ارشاد سنتے ہیں یہاں تک کہ جب تمہارے پاس سے نکل کر جائیں علم والوں سے کہتے ہیں ابھی انہوں نے کیا فرمایا یہ ہیں وہ جن کے دلوں پر اللہ نے مہر کردی اور اپنی خواہشوں کے تابع ہوئے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxii{اور جنہوں نے راہ پائی اللہ نے ان کی ہدایت اور زیادہ فرمائی اور ان کی پرہیزگاری انہیں عطا فرمائی\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxiii{تو کاہے کے انتظار میں ہیں مگر قیامت کے کہ ان پر اچانک آجائے، کہ اس کی علامتیں تو آہی چکی ہیں پھر جب آجائے گی تو کہاں وہ اور کہاں ان کا سمجھنا،\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxiv{تو جان لو کہ اللہ کے سوا کسی کی بندگی نہیں اور اے محبوب! اپنے خاصوں اور عام مسلمان مردوں اور عورتوں کے گناہوں کی معافی مانگو اور اللہ جانتا ہے دن کو تمہارا پھرنا اور رات کو تمہارا آرام لینا\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxv{اور مسلمان کہتے ہیں کوئی سورت کیوں نہ اتاری گئی پھر جب کوئی پختہ سورت اتاری گئی اور اس میں جہاد کا حکم فرمایا گیا تو تم دیکھو گے انہیں جن کے دلوں میں بیماری ہے کہ تمہاری طرف اس کا دیکھنا دیکھتے ہیں جس پر مُرونی چھائی ہو، تو ان کے حق میں بہتر یہ تھا کہ فرمانبرداری کرتے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxvi{اور اچھی بات کہتے پھر جب حکم ناطق ہوچکا تو اگر اللہ سے سچے رہتے تو ان کا بھلا تھا،\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxvii{تو کیا تمہارے یہ لچھن نظر آتے ہیں کہ اگر تمہیں حکومت ملے تو زمین میں فساد پھیلاؤ اور اپنے رشتے کاٹ دو،\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxviii{یہ ہیں وہ لوگ جن پر اللہ نے لعنت کی اور انہیں حق سے بہرا کردیا اور ان کی آنکھیں پھوڑ دیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxix{تو کیا وہ قرآن کو سوچتے نہیں یا بعضے دلوں پر ان کے قفل لگے ہیں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxx{بیشک وہ جو اپنے پیچھے پلٹ گئے بعد اس کے کہ ہدایت ان پر کھل چکی تھی شیطان نے انہیں فریب دیا اور انہیں دنیا میں مدتوں رہنے کی امید دلائی\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxi{یہ اس لیے کہ انہوں نے کہا ان لوگوں سے جنہیں اللہ کا اتارا ہوا ناگوار ہے ایک کام میں ہم تمہاری مانیں گے اور اللہ ان کی چھپی ہوئی جانتا ہے،\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxii{تو کیسا ہوگا جب فرشتے ان کی روح قبض کریں گے ان کے منہ اور ان کی پیٹھیں مارتے ہوئے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxiii{یہ اس لیے کہ وہ ایسی بات کے تابع ہوئے جس میں اللہ کی ناراضی ہے اور اس کی خوشی انہیں گوارا نہ ہوئی تو اس نے ان کے اعمال اَکارت کردیے،\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxiv{کیا جن کے دلوں میں بیماری ہے اس گھمنڈ میں ہیں کہ اللہ ان کے چھپے بَیر ظاہر نہ فرمائے گا\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxv{اور اگر ہم چاہیں تو تمہیں ان کو دکھادیں کہ تم ان کی صورت سے پہچان لو اور ضرور تم انہیں بات کے اسلوب میں پہچان لو گے اور اللہ تمہارے عمل جانتا ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxvi{اور ضرور ہم تمہیں جانچیں گے یہاں تک کہ دیکھ لیں تمہارے جہاد کرنے والوں اور صابروں کو اور تمہاری خبریں آزمالیں\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxvii{بیشک وہ جنہوں نے کفر کیا اور اللہ کی راہ سے روکا اور رسول کی مخالفت کی بعد اس کے کہ ہدایت ان پر ظاہر ہوچکی تھی وہ ہرگز اللہ کو کچھ نقصان نہ پہچائیں گے، اور بہت جلد اللہ ان کا کیا دھرا اَکارت کردے گا\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxviii{اے ایمان والو اللہ کا حکم مانو اور رسول کا حکم مانو اور اپنے عمل باطل نہ کرو\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxix{بیشک جنہوں نے کفر کیا اور اللہ کی راہ سے روکا پھر کافر ہی مرگئے تو اللہ ہر گز انہیں نہ بخشے گا\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxx{تو تم سستی نہ کرو اور آپ صلح کی طرف نہ بلاؤ اور تم ہی غالب آؤ گے، اور اللہ تمہارے ساتھ ہے اور وہ ہرگز تمہارے اعمال میں تمہیں نقصان نہ دے گا\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxi{دنیا کی زندگی تو یہی کھیل کود ہے اور اگر تم ایمان لاؤ اور پرہیزگاری کرو تو وہ تم کو تمہارے ثواب عطا فرمائے گا اور کچھ تم سے تمہارے مال نہ مانگے گا\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxii{اگر انہیں تم سے طلب کرے اور زیادہ طلب کرے تم بخل کرو گے اور وہ بخل تمہارے دلوں کے میل ظاہر کردے گا،\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxiii{ہاں ہاں یہ جو تم ہو بلائے جاتے ہو کہ اللہ کی راہ میں خرچ کرو تو تم میں کوئی بخل کرتا ہے اور جو بخل کرے وہ اپنی ہی جان پر بخل کرتا ہے اور اللہ بے نیاز ہے اور تم سب محتاج اور اگر تم منہ پھیرو تو وہ تمہارے سوا اور لوگ بدل لے گا پھر وہ تم جیسے نہ ہوں گے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxiv{\basmalahur بیشک ہم نے تمہارے لیے روشن فتح دی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxv{تاکہ اللہ تمہارے سبب سے گناہ بخشے تمہارے اگلوں کے اور تمہارے پچھلوں کے اور اپنی نعمتیں تم پر تمام کردے اور تمہیں سیدھی راہ دکھادے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxvi{اور اللہ تمہاری زبردست مدد فرمائے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxvii{وہی ہے جس نے ایمان والوں کے دلوں میں اطمینان اتارا تاکہ انہیں یقین پر یقین بڑھے اور اللہ ہی کی ملک ہیں تمام لشکر آسمانوں اور زمین کے اور اللہ علم و حکمت والا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxviii{تاکہ ایمان والے مردوں اور ایمان والی عورتوں کو باغوں میں لے جائے جن کے نیچے نہریں رواں ہمیشہ ان میں رہیں اور انکی برائیاں ان سے اتار دے، اور یہ اللہ کے یہاں بڑی کامیابی ہے،\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxix{اور عذاب دے منافق مَردوں اور منافق عورتوں اور مشرک مَردوں اور مشرک عورتوں کو جو اللہ پر گمان رکھتے ہیں انہیں پر ہے بری گردش اور اللہ نے اُن پر غضب فرمایا اور انہیں لعنت کی اور ان کے لیے جہنم تیار فرمایا، اور وہ کیا ہی برا انجام ہے،\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmdxc{اور اللہ ہی کی ملک ہیں آسمانوں اور زمین کے سب لشکر، اور اللہ عزت و حکمت والا ہے،\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmdxci{بیشک ہم نے تمہیں بھیجا حاضر و ناظر اور خوشی اور ڈر سناتا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmdxcii{تاکہ اے لوگو تم اللہ اور اس کے رسول پر ایمان لاؤ اور رسول کی تعظیم و توقیر کرو اور صبح و شام اللہ کی پاکی بولو\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmdxciii{وہ جو تمہاری بیعت کرتے ہیں وہ تو اللہ ہی سے بیعت کرتے ہیں ان کے ہاتھوں پر اللہ کا ہاتھ ہے، تو جس نے عہد توڑا اس نے اپنے بڑے عہد کو توڑا اور جس نے پورا کیا وہ عہد جو اس نے اللہ سے کیا تھا تو بہت جلد اللہ اسے بڑا ثواب دے گا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmdxciv{اب تم سے کہیں گے جو گنوار (اعرابی) پیچھے رہ گئے تھے کہ ہمیں ہمارے مال اور ہمارے گھر والوں نے مشغول رکھا اب حضور ہماری مغفرت چاہیں اپنی زبانوں سے وہ بات کہتے ہیں جو ان کے دلوں میں نہیں تم فرماؤ تو اللہ کے سامنے کسے تمہارا کچھ اختیار ہے اگر وہ تمہارا برا چاہے یا تمہاری بھلائی کا ارادہ فرمائے، بلکہ اللہ کو تمہارے کاموں کی خبر ہے،\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmdxcv{بلکہ تم تو یہ سمجھے ہوئے تھے کہ رسول اور مسلمان ہرگز گھروں کو واپس نہ آئیں گے اور اسی کو اپنے دلوں میں بھلا سمجھیں ہوئے تھے اور تم نے برا گمان کیا اور تم ہلاک ہونے والے لوگ تھے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmdxcvi{اور جو ایمان نہ لائے اللہ اور اس کے رسول پر تو بیشک ہم نے کافروں کے لیے بھڑکتی آگ تیار کر رکھی ہے،\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmdxcvii{اور اللہ ہی کے لیے ہے آسمانوں اور زمین کی سلطنت، جسے چاہے بخشے اور جسے چاہے عذاب کرے اور اللہ بخشنے والا مہربان ہے،\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmdxcviii{اب کہیں گے پیچھے بیٹھ رہنے والے جب تم غنیمتیں لینے چلو تو ہمیں بھی اپنے پیچھے آنے دو وہ چاہتے ہیں اللہ کا کلام بدل دیں تم فرماؤ ہرگز ہمارے ساتھ نہ آؤ اللہ نے پہلے سے یونہی فرمادیا تو اب کہیں گے بلکہ تم ہم سے جلتے ہو بلکہ وہ بات نہ سمجھتے تھے مگر تھوڑی\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmdxcix{ان پیچھے رہ گئے ہوئے گنواروں سے فرماؤ عنقریب تم ایک سخت لڑائی والی قوم کی طرف بلائے جاؤ گے کہ ان سے لڑو یا وہ مسلمان ہوجائیں، پھر اگر تم فرمان مانو گے اللہ تمہیں اچھا ثواب دے گا، ور اگر پھر گے جیسے پہلے پھر گئے تو تمھیں درد ناک عذاب دے گا،\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmdc{اندھے پر تنگی نہیں اور نہ لنگڑے پر مضائقہ اور نہ بیمار پر مواخذہ اور جو اللہ اور اس کے رسول کا حکم مانے اللہ اسے باغوں میں لے جائے گا جن کے نیچے نہریں رواں اور جو پھر جائے گا اسے دردناک عذاب فرمائے گا،\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmdci{بیشک اللہ راضی ہوا ایمان والوں سے جب وہ اس پیڑ کے نیچے تمہاری بیعت کرتے تھے تو اللہ نے جانا جو ان کے دلوں میں ہے تو ان پر اطمینان اتارا اور انہیں جلد آنے والی فتح کا انعام دیا\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmdcii{اور بہت سی غنیمتیں جن کو لیں، اور اللہ عزت و حکمت والا ہے،\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmdciii{اور اللہ نے تم سے وعدہ کیا ہے بہت سی غنیمتوں کا کہ تم لو گے تو تمہیں یہ جلد عطا فرمادی اور لوگوں کے ہاتھ تم سے روک دیے اور اس لیے کہ ایمان والوں کے لیے نشانی ہو اور تمہیں سیدھی راہ دکھائے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmdciv{اور ایک اور جو تمہارے بل (بس) کی نہ تھی وہ اللہ کے قبضہ میں ہے، اور اللہ ہر چیز پر قادر ہے،\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmdcv{اور اگر کافر تم سے لڑیں تو ضرور تمہارے مقابلہ سے پیٹھ پھیردیں گے پھر کوئی حمایتی نہ پائیں گے نہ مددگار،\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmdcvi{اللہ کا دستور ہے کہ پہلے سے چلا آتا ہے اور ہرگز تم اللہ کا دستور بدلتا نہ پاؤ گے،\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmdcvii{اور وہی ہے جس نے ان کے ہاتھ تم سے روک دیے اور تمہارے ہاتھ ان سے روک دیے وادی مکہ میں بعد اس کے کہ تمہیں ان پر قابو دے دیا تھا، اور اللہ تمہارے کام دیکھتا ہے،\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmdcviii{وہ وہ ہیں جنہوں نے کفر کیا اور تمہیں مسجدِ حرام سے روکا اور قربانی کے جانور رُکے پڑے اپنی جگہ پہنچنے سے اور اگر یہ نہ ہوتا کچھ مسلمان مرد اور کچھ مسلمان عورتیں جن کی تمہیں خبر نہیں کہیں تم انہیں روند ڈالو تو تمہیں ان کی طرف سے انجانی میں کوئی مکروہ پہنچے تو ہم تمہیں ان کی قتال کی اجازت دیتے ان کا یہ بچاؤ اس لیے ہے کہ اللہ اپنی رحمت میں داخل کرے جسے چاہے، اگر وہ جدا ہوجاتے تو ہم ضرور ان میں کے کافروں کو دردناک عذاب دیتے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmdcix{جبکہ کافروں نے اپنے دلوں میں اَڑ رکھی وہی زمانہٴ جاہلیت کی اَڑ (ضد) تو اللہ نے اپنا اطمینان اپنے رسول اور ایمان والوں پر اتارا اور پرہیزگاری کا کلمہ ان پر لازم فرمایا اور وہ اس کے زیادہ سزاوار اور اس کے اہل تھے اور اللہ سب کچھ جانتا ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmdcx{بیشک اللہ نے سچ کردیا اپنے رسول کا سچا خواب بیشک تم ضرور مسجد حرام میں داخل ہوگے اگر اللہ چاہے امن و امان سے اپنے سروں کے بال منڈاتے یا ترشواتے بے خوف، تو اس نے جانا جو تمہیں معلوم نیں تو اس سے پہلے ایک نزدیک آنے والی فتح رکھی\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxi{وہی ہے جس نے اپنے رسول کو ہدایت اور سچے دین کے ساتھ بھیجا کہ اسے سب دینوں پر غالب کرے اور اللہ کافی ہے گواہ\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxii{محمد اللہ کے رسول ہیں، اور ان کے ساتھ والے کافروں پر سخت ہیں اور آپس میں نرم دل تو انہیں دیکھے گا رکوع کرتے سجدے میں گرتے اللہ کا فضل و رضا چاہتے، ان کی علامت ان کے چہروں میں ہے سجدوں کے نشان سے یہ ان کی صفت توریت میں ہے، اور ان کی صفت انجیل میں جیسے ایک کھیتی اس نے اپنا پٹھا نکالا پھر اسے طاقت دی پھر دبیز ہوئی پھر اپنی ساق پر سیدھی کھڑی ہوئی کسانوں کو بھلی لگتی ہے تاکہ ان سے کافروں کے دل جلیں، اللہ نے وعدہ کیا ان سے جو ان میں ایمان اور اچھے کاموں والے ہیں بخشش اور بڑے ثواب کا،\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxiii{\basmalahur اے ایمان والو اللہ اور اس کے رسول سے آگے نہ بڑھو اور اللہ سے ڈرو بیشک اللہ سنتا جانتا ہے،\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxiv{اے ایمان والو اپنی آوازیں اونچی نہ کرو اس غیب بتانے والے (نبی) کی آواز سے اور ان کے حضور بات چلا کر نہ کہو جیسے آپس میں ایک دوسرے کے سامنے چلاتے ہو کہ کہیں تمہارے عمل اَکارت نہ ہوجائیں اور تمہیں خبر نہ ہو\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxv{بیشک وہ جو اپنی آوازیں پست کرتے ہیں رسول اللہ کے پاس وہ ہیں جن کا دل اللہ نے پرہیزگاری کے لیے پرکھ لیا ہے، ان کے لیے بخشش اور بڑا ثواب ہے،\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxvi{بیشک وہ جو تمہیں حجروں کے باہر سے پکارتے ہیں ان میں اکثر بے عقل ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxvii{اور اگر وہ صبر کرتے یہاں تک کہ تم آپ ان کے پاس تشریف لاتے تو یہ ان کے لیے بہتر تھا، اور اللہ بخشنے والا مہربان ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxviii{اے ایمان والو اگر کوئی فاسق تمہارے پاس کوئی خبر لائے تو تحقیق کرلو کہ کہیں کسی قوم کو بے جانے ایذا نہ دے بیٹھو پھر اپنے کیے پر پچھتاتے رہ جاؤ،\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxix{اور جان لو کہ تم میں اللہ کے رسول ہیں بہت معاملوں میں اگر یہ تمہاری خوشی کریں تو تم ضرور مشقت میں پڑو لیکن اللہ نے تمہیں ایمان پیارا کردیا ہے اور اسے تمہارے دلوں میں آراستہ کردیا اور کفر اور حکم عدولی اور نافرمانی تمہیں ناگوار کر دی، ایسے ہی لوگ راہ پر ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxx{اللہ کا فضل اور احسان، اور اللہ علم و حکمت والا ہے،\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxi{اور اگر مسلمانوں کے دو گروہ آپس میں لڑیں تو ان میں صلح کراؤ پھر اگر ایک دوسرے پر زیادتی کرے تو اس زیادتی والے سے لڑو یہاں تک کہ وہ اللہ کے حکم کی طرف پلٹ آئے، پھر اگر پلٹ آئے تو انصاف کے ساتھ ان میں اصلاح کردو اور عدل کرو، بیشک عدل والے اللہ کو پیارے ہیں،\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxii{مسلمان مسلمان بھائی ہیں تو اپنے دو بھائیوں میں صلح کرو اور اللہ سے ڈرو کہ تم پر رحمت ہو\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxiii{اے ایمان والو نہ مَرد مَردوں سے ہنسیں عجب نہیں کہ وہ ان ہنسنے والوں سے بہتر ہوں اور نہ عورتیں عورتوں سے، دور نہیں کہ وہ ان ہنسے والیوں سے بہتر ہوں اور آپس میں طعنہ نہ کرو اور ایک دوسرے کے برے نام نہ رکھو کیا ہی برا نام ہے مسلمان ہوکر فاسق کہلانا اور جو توبہ نہ کریں تو وہی ظالم ہیں،\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxiv{اے ایمان والو بہت گمانوں سے بچو بیشک کوئی گمان گناہ ہوجاتا ہے اور عیب نہ ڈھونڈھو اور ایک دوسرے کی غیبت نہ کرو کیا تم میں کوئی پسند رکھے گا کہ اپنے مرے بھائی کا گوشت کھائے تو یہ تمہیں گوارا نہ ہوگا اور اللہ سے ڈرو بیشک اللہ بہت توبہ قبول کرنے والا مہربان ہے،\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxv{اے لوگو! ہم نے تمہیں ایک مرد اورایک عورت سے پیدا کیا اور تمہیں شاخیں اور قبیلے کیا کہ آپس میں پہچان رکھو بیشک اللہ کے یہاں تم میں زیادہ عزت والا وہ جو تم میں زیادہ پرہیزگارہے بیشک اللہ جاننے والا خبردار ہے،\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxvi{گنوار بولے ہم ایمان لائے تم فرماؤ تم ایمان تو نہ لائے ہاں یوں کہوں کہ ہم مطیع ہوئے اور ابھی ایمان تمہارے دلوں میں کہاں داخل ہوا اور اگر تم اللہ اور اس کے رسول کی فرمانبرداری کرو گے تو تمہارے کسی عمل کا تمہیں نقصان نہ دے گا بیشک اللہ بخشنے والا مہربان ہے،\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxvii{ایمان والے تو وہی ہیں جو اللہ اور اس کے رسول پر ایمان لائے پھر شک نہ کیا اور اپنی جان اور مال سے اللہ کی راہ میں جہاد کیا وہی سچے ہیں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxviii{تم فرماؤ کیا تم اللہ کو اپنا دین بتاتے ہو، اور اللہ جانتا ہے جو کچھ آسمانوں میں اور جو کچھ زمین میں ہے اور اللہ سب کچھ جانتا ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxix{اے محبوب وہ تم پر احسان جتاتے ہیں کہ مسلمان ہوگئے، تم فرماؤ اپنے اسلام کا احسان مجھ پر نہ رکھو بلکہ اللہ تم پر احسان رکھتا ہے کہ اس نے تمہیں اسلام کی ہدایت کی اگر تم سچے ہو\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxx{بیشک اللہ جانتا ہے آسمانوں اور زمین کے سب غیب، اور اللہ تمہارے کام دیکھ رہا ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxi{\basmalahur عزت والے قرآن کی قسم\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxii{بلکہ انھیں اس کا اچنبھا ہوا کہ ان کے پاس انہی میں کا ایک ڈر سنانے والا تشریف لایا تو کافر بولے یہ تو عجیب بات ہے،\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxiii{کیا جب ہم مرجائیں اور مٹی ہوجائیں گے پھر جیئں گے یہ پلٹنا دور ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxiv{ہم جانتے ہیں جو کچھ زمین ان میں سے گھٹاتی ہے اور ہمارے پاس ایک یاد رکھنے والی کتاب ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxv{بلکہ انہوں نے حق کو جھٹلایا جب وہ ان کے پاس آیا تو وہ ایک مضطرب بے ثبات بات میں ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxvi{تو کیا انہوں نے اپنے اوپر آسمان کو نہ دیکھا ہم نے اسے کیسے بنایا اور سنوارا اور اس میں کہیں رخنہ نہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxvii{اور زمین کو ہم نے پھیلایا اور اس میں لنگر ڈالے (بھاری وزن رکھے) (ف۹۱۴ اور اس میں ہر بارونق جوڑا اُگایا،\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxviii{سوجھ اور سمجھ ہر رجوع والے بندے کے لیے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxix{اور ہم نے آسمان سے برکت والا پانی اتارا تو اس سے باغ اُگائے اور اناج کہ کاٹا جاتا ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxl{اور کھجور کے لمبے درخت جن کا پکا گابھا،\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxli{بندووں کی روزی کے لیے اور ہم نے اس سے مردہ شہر جِلایا یونہی قبروں سے تمہارا نکلنا ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxlii{ان سے پہلے جھٹلایا نوح کی قوم اور رس والوں اور ثمود\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxliii{اور عاد اور فرعون اور لوط کے ہم قوموں\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxliv{اور بَن والوں اور تبع کی قوم نے ان میں ہر ایک نے رسولوں کو جھٹلایا تو میرے عذاب کا وعدہ ثابت ہوگیا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxlv{تو کیا ہم پہلی بار بناکر تھک گئے بلکہ وہ نئے بننے سے شبہ میں ہیں،\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxlvi{اور بیشک ہم نے آدمی کو پیدا کیا اور ہم جانتے ہیں جو وسوسہ اس کا نفس ڈالتا ہے اور ہم دل کی رگ سے بھی اس سے زیادہ نزدیک ہیں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxlvii{اور جب اس سے لیتے ہیں دو لینے والے ایک داہنے بیٹھا اور ایک بائیں\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxlviii{کوئی بات وہ زبان سے نہیں نکالتا کہ اس کے پاس ایک محافظ تیار نہ بیٹھا ہو\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxlix{اور آئی موت کی سختی حق کے ساتھ یہ ہے جس سے تو بھاگتا تھا،\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmdcl{اور صُور پھونکا گیا یہ ہے وعدہٴ عذاب کا دن\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmdcli{اور ہر جان یوں حاضر ہوئی کہ اس کے ساتھ ایک ہانکنے والا اور ایک گواہ\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmdclii{بیشک تو اس سے غفلت میں تھا تو ہم نے تجھ پر سے پردہ اٹھایا تو آج تیری نگاہ تیز ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmdcliii{اور اس کا ہمنشین فرشتہ بولا یہ ہے جو میرے پاس حاضر ہے،\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmdcliv{حکم ہوگا تم دونوں جہنم میں ڈال دو ہر بڑے ناشکرے ہٹ دھرم کو،\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmdclv{جو بھلائی سے بہت روکنے والا حد سے بڑھنے والا شک کرنے والا\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmdclvi{جس نے اللہ کے ساتھ کوئی اور معبود ٹھہرایا تم دونوں اسے سخت عذاب میں ڈالو،\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmdclvii{اس کے ساتھی شیطان نے کہا ہمارے رب میں نے اسے سرکش نہ کیا ہاں یہ آپ ہی دور کی گمراہی میں تھا\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmdclviii{فرمائے گا میرے پاس نہ جھگڑو میں تمہیں پہلے ہی عذاب کا ڈر سنا چکا تھا\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmdclix{میرے یہاں بات بدلتی نہیں اور نہ میں بندوں پر ظلم کروں،\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmdclx{جس دن ہم جہنم سے فرمائیں گے کیا تو بھر گئی وہ عرض کرے گی کچھ اور زیادہ ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxi{اور پاس لائی جائے گی جنت پرہیزگاروں کے کہ ان سے دور نہ ہوگی\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxii{یہ ہے وہ جس کا تم وعدہ دیے جاتے ہو ہر رجوع لانے والے نگہداشت والے کے لیے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxiii{جو رحمن سے بے دیکھے ڈرتا ہے اور رجوع کرتا ہوا دل لایا\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxiv{ان سے فرمایا جائے گا جنت میں جاؤ سلامتی کے ساتھ یہ ہمیشگی کا دن ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxv{ان کے لیے ہے اس میں جو چاہیں اور ہمارے پاس اس سے بھی زیادہ ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxvi{اور ان سے پہلے ہم نے کتنی سنگتیں (قومیں) ہلاک فرمادیں کہ گرفت میں ان سے سخت تھیں تو شہروں میں کاوشیں کیں ہے کہیں بھاگنے کی جگہ\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxvii{بیشک اس میں نصیحت ہے اس کے لیے جو دِل رکھتا ہو یا کان لگائے اور متوجہ ہو،\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxviii{اور بیشک ہم نے آسمانوں اور زمین کو اور جو کچھ ان کے درمیان ہے چھ دن میں بنایا، اور تکان ہمارے پاس نہ آئی\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxix{تو ان کی باتوں پر صبر کرو اور اپنے رب کی تعریف کرتے ہوئے اس کی پاکی بولو سورج چمکنے سے پہلے اور ڈوبنے سے پہلے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxx{اور کچھ رات گئے اس کی تسبیح کرو اور نمازوں کے بعد\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxi{اور کان لگا کر سنو جس دن پکارنے والا پکارے گا ایک پاس جگہ سے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxii{جس دن چنگھاڑ سنیں گے حق کے ساتھ، یہ دن ہے قبروں سے باہر آنے کا،\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxiii{بیشک ہم جِلائیں اور ہم ماریں اور ہماری طرف پھرنا ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxiv{جس دن زمین ان سے پھٹے گی تو جلدی کرتے ہوئے نکلیں گے یہ حشر ہے ہم کو آسان،\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxv{ہم خوب جان رہے ہیں جو وہ کہہ رہے ہیں اور کچھ تم ان پر جبر کرنے والے نہیں تو قرآن سے نصیحت کرو اسے جو میری دھمکی سے ڈرے،\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxvi{\basmalahur قسم ان کی جو بکھیر کر اڑانے والیاں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxvii{پھر بوجھ اٹھانے والیاں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxviii{پھر نرم چلنے والیاں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxix{پھر حکم سے بانٹنے والیاں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxx{بیشک جس بات کا تمہیں وعدہ دیا جاتا ہے ضروری سچ ہے،\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxi{اور بیشک انصاف ضرور ہونا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxii{آرائش والے آسمان کی قسم\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxiii{تم مختلف بات میں ہو\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxiv{اس قرآن سے وہی اوندھا کیا جاتا ہے جس کی قسمت ہی میں اوندھایا جانا ہو\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxv{مارے جایں دل سے تراشنے والے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxvi{جو نشے میں بھولے ہوئے ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxvii{پوچھتے ہیں انصاف کا دن کب ہوگا\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxviii{اس دن ہوگا جس دن وہ آگ پر تپائے جائیں گے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxix{اور فرمایا جائے گا چکھو اپنا تپنا، یہ ہے وہ جس کی تمہیں جلدی تھی\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxc{بیشک پرہیزگار باغوں اور چشموں میں ہیں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxci{اپنے رب کی عطائیں لیتے ہوئے، بیشک وہ اس سے پہلے نیکو کار تھے،\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxcii{وہ رات میں کم سویا کرتے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxciii{اور پچھلی رات استغفار کرتے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxciv{اور ان کے مالوں میں حق تھا منگتا اور بے نصیب کا\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxcv{اور زمین میں نشانیاں ہیں یقین والوں کو\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxcvi{اور خود تم میں تو کیا تمہیں سوجھتا نہیں،\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxcvii{اور آسمان میں تمہارا رزق ہے اور جو تمہیں وعدہ دیا جاتا ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxcviii{تو آسمان اور زمین کے رب کی قسم بیشک یہ قرآن حق ہے ویسی ہی زبان میں جو تم بولتے ہو،\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxcix{اے محبوب! کیا تمہارے پاس ابراہیم کے معزز مہمانوں کی خبر آئی\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmdcc{جب وہ اس کے پاس آکر بولے سلام کہا، سلام ناشناسا لوگ ہیں\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmdcci{پھر اپنے گھر گیا تو ایک فربہ بچھڑا لے آیا\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmdccii{پھر اسے ان کے پاس رکھا کہا کیا تم کھاتے نہیں،\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmdcciii{تو اپنے جی میں ان سے ڈرنے لگا وہ بولے ڈریے نہیں اور اسے ایک علم والے لڑکے کی بشارت دی،\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmdcciv{اس پر اس کی بی بی چلاتی آئی پھر اپنا ماتھا ٹھونکا اور بولی کیا بڑھیا بانجھ\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmdccv{انہوں نے کہا تمہارے رب نے یونہی فرمادیا، اور وہی حکیم دانا ہے،\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmdccvi{ابراہیم نے فرمایا تو اے فرشتو! تم کس کام سے آئے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmdccvii{بولے ہم ایک مجرم قوم کی طرف بھیجے گئے ہیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmdccviii{کہ ان پر گارے کے بنائے ہوئے پتھر چھوڑیں،\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmdccix{جو تمہارے رب کے پاس حد سے بڑھنے والوں کے لیے نشان کیے رکھے ہیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmdccx{تو ہم نے اس شہر میں جو ایمان والے تھے نکال لیے،\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxi{تو ہم نے وہاں ایک ہی گھر مسلمان پایا\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxii{اور ہم نے اس میں نشانی باقی رکھی ان کے لیے جو دردناک عذاب سے ڈرتے ہیں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxiii{اور موسیٰ میں جب ہم نے اسے روشن سند لے کر فرعون کے پاس بھیجا\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxiv{تو اپنے لشکر سمیت پھر گیا اورت بولا جادوگر ہے یا دیوانہ،\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxv{تو ہم نے اسے اور اس کے لشکر کو پکڑ کر دریا میں ڈال دیا اس حال میں کہ وہ اپنے آپ کو ملامت کررہا تھا\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxvi{اور عاد میں جب ہم نے ان پر خشک آندھی بھیجی\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxvii{جس چیز پر گزرتی اسے گلی ہوئی چیز کی طرح چھوڑتی\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxviii{اور ثمود میں جب ان سے فرمایا گیا ایک وقت تک برت لو\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxix{تو انہوں نے اپنے رب کے حکم سے سرکشی کی تو ان کی آنکھوں کے سامنے انہیں کڑک نے آلیا\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxx{تو وہ نہ کھڑے ہوسکے اور نہ وہ بدلہ لے سکتے تھے،\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxi{اور ان سے پہلے قوم نوح کو ہلاک فرمایا، بیشک وہ فاسق لوگ تھے،\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxii{اور آسمان کو ہم نے ہاتھوں سے بنایا اور بیشک ہم وسعت دینے والے ہیں\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxiii{اور زمین کو ہم نے فرش کیا تو ہم کیا ہی اچھے بچھالے والے،\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxiv{اور ہم نے ہر چیز کے دو جوڑ بنائے کہ تم دھیان کرو\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxv{تو اللہ کی طرف بھاگو بیشک میں اس کی طرف سے تمہارے لیے صریح ڈر سنانے والا ہوں،\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxvi{اور اللہ کے ساتھ اور معبود نہ ٹھہراؤ، بیشک میں اس کی طرف سے تمہارے لیے صریح ڈر سنانے والا ہوں،\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxvii{یونہی جب ان سے اگلوں کے پاس کوئی رسول تشریف لایا تو یہی بولے کہ جادوگر ہے یا دیوانہ،\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxviii{کیا آپس میں ایک دوسرے کو یہ بات کہہ مرے ہیں بلکہ وہ سرکش لوگ ہیں\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxix{تو اے محبوب! تم ان سے منہ پھیر لو تو تم پر کچھ الزام نہیں\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxx{اور سمجھاؤ کہ سمجھانا مسلمانوں کو فائدہ دیتا ہے،\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxi{اور میں نے جن اور آدمی اتنے ہی لیے بنائے کہ میری بندگی کریں\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxii{میں ان سے کچھ رزق نہیں مانگتا اور نہ یہ چاہتا ہوں کہ وہ مجھے کھانا دیں\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxiii{بیشک اللہ ہی بڑا رزق دینے والا قوت والا قدرت والا ہے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxiv{تو بیشک ان ظالموں کے لیے عذاب کی ایک باری ہے جیسے ان کے ساتھ والوں کے لیے ایک باری تھی تو مجھ سے جلدی نہ کریں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxv{تو کافروں کی خرابی ہے ان کے اس دن سے جس کا وعدہ دیے جاتے ہیں\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxvi{\basmalahur طور کی قسم\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxvii{اور اس نوشتہ کی\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxviii{جو کھلے دفتر میں لکھا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxix{اور بیت معمور\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxl{اور بلند چھت\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxli{اور سلگائے ہوئے سمندر کی\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxlii{بیشک تیرے رب کا عذاب ضرور ہونا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxliii{اسے کوئی ٹالنے والا نہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxliv{جس دن آسمان ہلنا سا ہلنا ہلیں گے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxlv{اور پہاڑ چلنا سا چلنا چلیں گے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxlvi{تو اس دن جھٹلانے والوں کی خرابی ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxlvii{وہ جو مشغلہ میں کھیل رہے ہیں،\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxlviii{جس دن جہنم کی طرف دھکا دے کر دھکیلے جائیں گے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxlix{یہ ہے وہ آگ جسے تم جھٹلاتے تھے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmdccl{تو کیا یہ جادو ہے یا تمہیں سوجھتا نہیں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmdccli{اس میں جاؤ اب چاہے صبر کرو یا نہ کرو، سب تم پر ایک سا ہے تمہیں اسی کا بدلہ جو تم کرتے تھے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclii{بیشک پرہیزگار باغوں اور چین میں ہیں\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmdccliii{اپنے رب کے دین پر شاد شاد اور انہیں ان کے رب نے آگ کے عذاب سے بچالیا\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmdccliv{کھاؤ اور پیو خوشگواری سے صِلہ اپنے اعمال کا\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclv{تختوں پر تکیہ لگائے جو قطار لگا کر بچھے ہیں اور ہم نے انہیں بیاہ دیا بڑی آنکھوں والی حوروں سے،\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclvi{اور جو ایمان لائے اور ان کی اولاد نے ایمان کے ساتھ ان کی پیروی کی ہم نے ان کی اولاد ان سے ملادی اور ان کے عمل میں انہیں کچھ کمی نہ دی سب آدمی اپنے کیے میں گرفتار ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclvii{اور ہم نے ان کی مدد فرمائی میوے اور گوشت سے جو چاہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclviii{ایک دوسرے سے لیتے ہیں وہ جام جس میں نہ بیہودگی اور گنہگاری\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclix{اور ان کے خدمت گار لڑکے ان کے گرد پھریں گے گویا وہ موتی ہیں چھپا کر رکھے گئے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclx{اور ان میں ایک نے دوسرے کی طرف منہ کیا پوچھتے ہوئے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxi{بولے بیشک ہم اس سے پہلے اپنے گھروں میں سہمے ہوئے تھے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxii{تو اللہ نے ہم پر احسان کیا اور ہمیں لُو کے عذاب سے بچالیا\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxiii{بیشک ہم نے اپنی پہلی زندگی میں اس کی عبادت کی تھی، بیشک وہی احسان فرمانے والا مہربان ہے،\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxiv{تو اے محبوب! تم نصیحت فرماؤ کہ تم اپنے رب کے فضل سے نہ کاہن ہو نہ مجنون،\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxv{یا کہتے ہیں یہ شاعر ہیں ہمیں ان پر حوادثِ زمانہ کا انتظارہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxvi{تم فرماؤ انتظار کیے جاؤ میں بھی تمہارے انتظار میں ہوں\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxvii{کیا ان کی عقلیں انہیں یہی بتاتی ہیں یا وہ سرکش لوگ ہیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxviii{یا کہتے ہیں انہوں نے یہ قرآن بنالیا، بلکہ وہ ایمان نہیں رکھتے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxix{تو اس جیسی ایک بات تو لے آئیں اگر سچے ہیں،\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxx{کیا وہ کسی اصل سے نہ بنائے گئے یا وہی بنانے والے ہیں\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxi{یا آسمان اور زمین انہوں نے پیدا کیے بلکہ انہیں یقین نہیں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxii{یا ان کے پاس تمہارے رب کے خزانے ہیں یا وہ کڑوڑے (حاکمِ اعلیٰ) ہیں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxiii{یا ان کے پاس کوئی زینہ ہے جس میں چڑھ کر سن لیتے ہیں تو ان کا سننے والا کوئی روشن سند لائے،\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxiv{کیا اس کو بیٹیاں اور تم کو بیٹے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxv{یا تم ان سے کچھ اجرت مانگتے ہہو تو وہ چٹی کے بوجھ میں دبے ہیں\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxvi{یا ان کے پاس غیب ہیں جس سے وہ حکم لگاتے ہیں\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxvii{یا کسی داؤ ں (فریب) کے ارادہ میں ہیں تو کافروں پر ہی داؤں (فریب) پڑنا ہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxviii{یا اللہ کے سوا ان کا کوئی اور خدا ہے اللہ کو پاکی ان کے شرک سے،\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxix{اور اگر آسمان سے کوئی ٹکڑا گرتا دیکھیں تو کہیں گے تہ بہ تہ بادل ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxx{تو تم انہیں چھوڑ دو یہاں تک کہ وہ اپنے اس دن سے ملیں جس میں بے ہوش ہوں گے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxi{جس دن ان کا داؤ ں (فریب) کچھ کام نہ دے گا اور نہ ان کی مدد ہو\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxii{اور بیشک ظالموں کے لیے اس سے پہلے ایک عذاب ہے مگر ان میں اکثر کو خبر نہیں\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxiii{اور اے محبوب! تم اپنے رب کے حکم پر ٹھہرے رہو کہ بیشک تم ہماری نگہداشت میں ہو اور اپنے رب کی تعریف کرتے ہوئے اس کی پاکی بولو جب تم کھڑے ہو\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxiv{اور کچھ رات میں اس کی پاکی بولو اور تاروں کے پیٹھ دیتے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxv{\basmalahur اس پیارے چمکتے تارے محمد کی قسم! جب یہ معراج سے اترے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxvi{تمہارے صاحب نہ بہکے نہ بے راہ چلے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxvii{اور وہ کوئی بات اپنی خواہش سے نہیں کرتے،\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxviii{وہ تو نہیں مگر وحی جو انہیں کی جاتی ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxix{انہیں سکھایا سخت قوتوں والے طاقتور نے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxc{پھر اس جلوہ نے قصد فرمایا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxci{اور وہ آسمان بریں کے سب سے بلند کنارہ پر تھا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxcii{پھر وہ جلوہ نزدیک ہوا پھر خوب اتر آیا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxciii{تو اس جلوے اور اس محبوب میں دو ہاتھ کا فاصلہ رہا بلکہ اس سے بھی کم\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxciv{اب وحی فرمائی اپنے بندے کو جو وحی فرمائی\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxcv{دل نے جھوٹ نہ کہا جو دیکھا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxcvi{تو کیا تم ان سے ان کے دیکھے ہوئے پر جھگڑ تے ہو\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxcvii{اور انہوں نے تو وہ جلوہ دوبار دیکھا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxcviii{سدرة المنتہیٰ کے پاس\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxcix{اس کے پاس جنت الماویٰ ہے،\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmdccc{جب سدرہ پر چھا رہا تھا جو چھا رہا تھا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmdccci{آنکھ نہ کسی طرف پھر نہ حد سے بڑھی\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccii{بیشک اپنے رب کی بہت بڑی نشانیاں دیکھیں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmdccciii{تو کیا تم نے دیکھ ا لات اور عزیٰ\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmdccciv{اور اس تیسری منات کو\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccv{کیا تم کو بیٹا اور اس کو بیٹی\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccvi{جب تو یہ سخت بھونڈی تقسیم ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccvii{وہ تو نہیں مگر کچھ نام کہ تم نے اور تمہارے باپ دادا نے رکھ لیے ہیں اللہ نے ان کی کوئی سند نہیں اتاری، وہ تو نرے گمان اور نفس کی خواہشوں کے پیچھے ہیں حالانکہ بیشک ان کے پاس ان کے رب کی طرف سے ہدایت آئی\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccviii{کیا آدمی کو مل جائے گا جو کچھ وہ خیال باندھے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccix{تو آخرت اور دنیا سب کا مالک اللہ ہی ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccx{اور کتنے ہی فرشتے ہیں آسمانوں میں کہ ان کی سفارش کچھ کام نہیں آتی مگر جبکہ اللہ اجازت دے دے جس کے لیے چاہے اور پسند فرمائے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxi{بیشک وہ جو آخرت پر ایمان رکھتے نہیں ملائکہ کا نام عورتوں کا سا رکھتے ہیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxii{اور انہیں اس کی کچھ خبر نہیں، وہ تو نرے گمان کے پیچھے ہیں، اور بیشک گمان یقین کی جگہ کچھ کام نہیں دیتا\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxiii{تو تم اس سے منہ پھیر لو، جو ہماری یاد سے پھرا اور اس نے نہ چاہی مگر دنیا کی زندگی\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxiv{یہاں تک ان کے علم کی پہنچ ہے بیشک تمہارا خوب جانتا ہے جو اس کی راہ سے بہکا اور وہ خوب جانتا ہے جس نے راہ پائی،\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxv{اور اللہ ہی کا ہے جو کچھ آسمانوں میں ہے اور جو کچھ زمین میں تاکہ برائی کرنے والوں کو ان کے کیے کا بدلہ دے اور نیکی کرنے والوں کو نہایت اچھا صلہ عطا فرمائے،\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxvi{وہ جو بڑے گناہوں اور بے حیائیوں سے بچتے ہیں مگر اتنا کہ گناہ کے پاس گئے اور رک گئے بیشک تمہارے رب کی مغفرت وسیع ہے، وہ تمہیں خوب جانتا ہے تمہیں مٹی سے پیدا کیا اور جب تم اپنی ماؤں کے پیٹ میں حمل تھے، تو آپ اپنی جانوں کو ستھرا نہ بتاؤ وہ خوب جانتا ہے جو پرہیزگار ہیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxvii{تو کیا تم نے دیکھا جو پھر گیا\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxviii{اور کچھ تھوڑا سا دیا اور روک رکھا\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxix{کیا اس کے پاس غیب کا علم ہے تو وہ دیکھ رہا ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxx{کیا اسے اس کی خبر نہ آئی جو صحیفوں میں ہے موسیٰ کے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxi{اور ابراہیم کے جو پورے احکام بجالایا\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxii{کہ کوئی بوجھ اٹھانے والی جان دوسری کا بوجھ نہیں اٹھاتی\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxiii{اور یہ کہ آدمی نہ پاے گا مگر اپنی کوشش\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxiv{اور یہ کہ اس کی کو شش عنقر یب دیکھی جاے گی\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxv{پھر اس کا بھرپور بدلا دیا جائے گا\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxvi{اور یہ کہ بیشک تمہارے رب ہی کی طرف انتہا ہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxvii{اور یہ کہ وہی ہے جس نے ہنسایا اور رلایا\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxviii{اور یہ کہ وہی ہے جس نے مارا اور جِلایا\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxix{اور یہ کہ اسی نے دو جوڑے بنائے نر اور مادہ\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxx{نطفہ سے جب ڈالا جائے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxi{اور یہ کہ اسی کے ذمہ ہے پچھلا اٹھانا (دوبارہ زندہ کرنا)\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxii{اور یہ کہ اسی نے غنیٰ دی اور قناعت دی\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxiii{او ریہ کہ وہی ستارہ شِعریٰ کا رب ہے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxiv{اور یہ کہ اسی نے پہلی عاد کو ہلاک فرمایا\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxv{اور ثمود کو تو کوئی باقی نہ چھوڑا\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxvi{اور ان سے پہلے نوح کی قوم کو بیشک وہ ان سے بھی ظالم اور سرکش تھے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxvii{اور اس نے الٹنے والی بستی کو نیچے گرایا\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxviii{تو اس پر چھایا جو کچھ چھایا\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxix{تو اے سننے والے اپنے رب کی کون سی نعمتوں میں شک کرے گا،\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxl{یہ ایک ڈر سنانے والے ہیں اگلے ڈرانے والوں کی طرح\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxli{پاس آئی پاس آنے والی\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxlii{اللہ کے سوا اس کا کوئی کھولنے والا نہیں\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxliii{تو کیا اس بات سے تم تعجب کرتے ہو\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxliv{اور ہنستے ہو اور روتے نہیں\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxlv{اور تم کھیل میں پڑے ہو،\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxlvi{تو اللہ کے لیے سجدہ اور اس کی بندگی کرو\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxlvii{\basmalahur پاس آئی قيامت اور شق ہوگیا چاند\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxlviii{اور اگر دیکھیں کوئی نشانی تو منہ پھیرتے اور کہتے ہیں یہ تو جادو ہے چلا آتا،\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxlix{اور انہوں نے جھٹلایا اور اپنی خواہشوں کے پیچھے ہوئے اور ہر کام قرار پاچکا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccl{اور بیشک ان کے پاس وہ خبریں آئیں جن میں کافی روک تھی\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccli{انتہاء کو پہنچی ہوئی حکمت پھر کیا کام دیں ڈر سنانے والے،\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclii{تو تم ان سے منہ پھیرلو جس دن بلانے والا ایک سخت بے پہچانی بات کی طرف بلائے گا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccliii{نیچی آنکھیں کیے ہوئے قبروں سے نکلیں گے گویا وہ ٹڈی ہیں پھیلی ہوئی\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccliv{بلانے والے کی طرف لپکتے ہوئے کافر کہیں گے یہ دن سخت ہے،\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclv{ان سے پہلے نوح کی قوم نے جھٹلایا تو ہمارے بندہ کو جھوٹا بتایا اور بولے وہ مجنون ہے اور اسے جھڑکا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclvi{تو اس نے اپنے رب سے دعا کی کہ میں مغلوب ہوں تو میرا بدلہ لے،\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclvii{تو ہم نے آسمان کے دروازے کھول دیے زور کے بہتے پانی سے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclviii{اور زمین چشمے کرکے بہا دی تو دونوں پانی مل گئے اس مقدار پر جو مقدر تھی\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclix{اور ہم نے نوح کو سوار کیا تختوں اور کیلوں والی پر کہ\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclx{ہماری نگاہ کے روبرو بہتی اس کے صلہ میں جس کے ساتھ کفر کیا گیا تھا،\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxi{اور ہم نے اس نشانی چھوڑا تو ہے کوئی دھیان کرنے والا\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxii{تو کیسا ہوا میرا عذاب اور میری دھمکیاں،\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxiii{اور بیشک ہم نے قرآن یاد کرنے کے لیے آسان فرمادیا تو ہے کوئی یاد کرنے والا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxiv{عاد نے جھٹلایا تو کیسا ہوا میرا عذاب اور میرے ڈر دلانے کے فرمان\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxv{بیشک ہم نے ان پر ایک سخت آندھی بھیجی ایسے دن میں جس کی نحوست ان پر ہمیشہ کے لیے رہی\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxvi{لوگوں کو یوں دے مارتی تھی کہ گویا اکھڑی ہوئی کھجوروں کے ڈنڈ (سوکھے تنے) ہیں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxvii{تو کیا کیسا ہوا میرا عذاب اور ڈر کے فرمان،\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxviii{اور بیشک ہم نے آسان کیا قرآن یاد کرنے کے لیے تو ہے کوئی یاد کرنے والا،\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxix{ثمود نے رسولوں کو جھٹلایا\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxx{تو بولے کیا ہم اپنے میں کے ایک آدمی کی تابعداری کریں جب تو ہم ضرور گمراہ اور دیوانے ہیں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxi{کیا ہم سب میں سے اس پر بلکہ یہ سخت جھوٹا اترونا (شیخی باز) ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxii{بہت جلد کل جان جائیں گے کون تھا بڑا جھوٹا اترونا (شیخی باز)\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxiii{ہم ناقہ بھیجنے والے ہیں انکی جانچ کو تو اے صا لح! تو راہ دیکھ اور صبر کر\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxiv{اور انہیں خبر دے دے کہ پانی ان میں حصوں سے ہے ہر حصہ پر وہ حاضر ہو جس کی باری ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxv{تو انہوں نے اپنے ساتھی کو پکارا تو اس نے لے کر اس کی کونچیں کاٹ دیں\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxvi{پھر کیسا ہوا میرا عذاب اور ڈر کے فرمان\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxvii{بیشک ہم نے ان پر ایک چنگھاڑ بھیجی جبھی وہ ہوگئے جیسے گھیرا بنانے والے کی بچی ہوئی گھاس سوکھی روندی ہوئی\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxviii{اور بیشک ہم نے آسان کیا قرآن یاد کرنے کے لیے تو ہے کوئی یاد کرنے والا،\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxix{لوط کی قوم نے رسولوں کو جھٹلایا،\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxx{بیشک ہم نے ان پر پتھراؤ بھیجا سوائے لو ط کے گھر والوں کے ہم نے انہیں پچھلے پہر بچالیا،\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxi{اپنے پاس کی نعمت فرماکر، ہم یونہی صلہ دیتے ہیں اسے جو شکر کرے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxii{اور بیشک اس نے انہیں ہماری گرفت سے ڈرایا تو انہوں نے ڈر کے فرمانوں میں شک کیا\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxiii{انہوں نے اسے اس کے مہمانوں سے پھسلانا چاہا تو ہم نے ان کی آنکھیں میٹ دی (چوپٹ کردیں) فرمایا چکھو میرا عذاب اور ڈر کے فرمان\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxiv{اور بیشک صبح تڑکے ان پر ٹھہرنے والا عذاب آیا\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxv{تو چکھو میرا عذاب اور ڈر کے فرمان،\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxvi{اور بیشک ہم نے آسان کیا قرآن یاد کرنے کے لیے تو ہے کوئی یاد کرنے والا،\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxvii{اور بیشک فرعون والوں کے پاس رسول آئے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxviii{انہوں نے ہماری سب نشانیاں جھٹلائیں تو ہم نے ان پر گرفت کی جو ایک عزت والے اور عظیم قدرت والے کی شان تھی،\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxix{کیا تمہارے کافر ان سے بہتر ہیں یا کتابوں میں تمہاری چھٹی لکھی ہوئی ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxc{یا یہ کہتے ہیں کہ ہم سب مل کر بدلہ لے لیں گے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxci{اب بھگائی جاتی ہے یہ جماعت اور پیٹھیں پھیردیں گے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxcii{بلکہ ان کا وعدہ قیامت پر ہے اور قیامت نہایت کڑوی اور سخت کڑوی\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxciii{بیشک مجرم گمراہ اور دیوانے ہیں\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxciv{جس دن آگ میں اپنے مونہوں پر گھسیٹے جائیں گے اور فرمایا جائے گا، چکھو دوزخ کی آنچ،\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxcv{بیشک ہم نے ہر چیز ایک اندازہ سے پیدا فرمائی\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxcvi{اور ہمارا کام تو ایک بات کی بات ہے جیسے پلک مارنا\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxcvii{اور بیشک ہم نے تمہاری وضع کے ہلاک کردیے تو ہے کوئی دھیان کرنے والا\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxcviii{اور انہوں نے جو کچھ کیا سب کتابوں میں ہے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxcix{اور ہر چھوٹی بڑی چیز لکھی ہوئی ہے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmcm{بیشک پرہیزگار باغوں اور نہر میں ہیں،\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmcmi{سچ کی مجلس میں عظیم قدرت والے بادشاہ کے حضور\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmcmii{\basmalahur رحمٰن\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmcmiii{نے اپنے محبوب کو قرآن سکھایا\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmcmiv{انسانیت کی جان محمد کو پیدا کیا،\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmcmv{ما کان وما یکون کا بیان انہیں سکھایا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmcmvi{سورج اور چاند حساب سے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmcmvii{اور سبزے اور پیڑ سجدہ کرتے ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmcmviii{اور آسمان کو اللہ نے بلند کیا اور ترازو رکھی\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmcmix{کہ ترازو میں بے اعتدالی نہ کرو\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmcmx{اور انصاف کے ساتھ تول قائم کرو اور وزن نہ گھٹاؤ،\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxi{اور زمین رکھی مخلوق کے لیے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxii{اس میں میوے اور غلاف والی کھجوریں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxiii{اور بھُس کے ساتھ اناج اور خوشبو کے پھول،\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxiv{تو اے جن و انس! تم دونوں اپنے رب کی کون سی نعمت کو جھٹلاؤ گے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxv{اس نے آدمی کو بنا یا بجتی مٹی سے جیسے ٹھیکری\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxvi{اور جن کو پیدا فرمایا آگ کے لُوکے (لپیٹ) سے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxvii{تو تم دونوں اپنے رب کی کونسی نعمت جھٹلاؤ گے،\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxviii{دونوں پورب کا رب اور دونوں پچھم کا رب\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxix{تو تم دونوں اپنے رب کی کونسی نعمت جھٹلاؤ گے،\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxx{اس نے دو سمندر بہائے کہ دیکھنے میں معلوم ہوں ملے ہوئے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxi{اور ہے ان میں روک کہ ایک دوسرے پر بڑھ نہیں سکتا\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxii{تو اپنے رب کی کونسی نعمت جھٹلاؤ گے،\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxiii{ان میں سے موتی اور مونگا نکلتا ہے،\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxiv{تو اپنے رب کی کونسی نعمت جھٹلاؤ گے،\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxv{اور اسی کی ہیں وہ چلنے والیاں کہ دریا میں اٹھی ہوئی ہیں جیسے پہاڑ\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxvi{تو اپنے رب کی کونسی نعمت جھٹلاؤ گے،\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxvii{زمین پر جتنے ہیں سب کو فنا ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxviii{اور باقی ہے تمہارے رب کی ذات عظمت اور بزرگی والا\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxix{تو اپنے رب کی کونسی نعمت جھٹلاؤ گے،\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxx{اسی کے منگتا ہیں جتنے آسمانوں اور زمین میں ہیں اسے ہر دن ایک کام ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxi{تو اپنے رب کی کونسی نعمت جھٹلاؤ گے،\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxii{جلد سب کام نبٹا کر ہم تمہارے حساب کا قصد فرماتے ہیں اے دونوں بھاری گروہ\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxiii{تو اپنے رب کی کونسی نعمت جھٹلاؤ گے،\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxiv{اے جن و انسان کے گروہ اگر تم سے ہوسکے کہ آسمانوں اور زمین کے کناروں سے نکل جاؤ تو نکل جاؤ، جہاں نکل کر جاؤ گے اسی کی سلطنت ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxv{تو اپنے رب کی کونسی نعمت جھٹلاؤ گے،\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxvi{تم پر چھوڑی جائے گی بے دھویں کی آگ کی لپٹ اور بے لپٹ کا کالا دھواں تو پھر بدلا نہ لے سکو گے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxvii{تو اپنے رب کی کونسی نعمت جھٹلاؤ گے،\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxviii{پھر جب آسمان پھٹ ائے گا تو گلاب کے پھول کا سا ہوجائے گا جیسے سرخ نری (بکرے کی رنگی ہوئی کھال)\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxix{تو اپنے رب کی کونسی نعمت جھٹلاؤ گے،\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxl{تو اس دن گنہگار کے گناہ کی پوچھ نہ ہوگی کسی آدمی اور جِن سے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxli{تو اپنے رب کی کونسی نعمت جھٹلاؤ گے،\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxlii{مجرم اپنے چہرے سے پہچانے جائیں گے تو ماتھا اور پاؤں پکڑ کر جہنم میں ڈالے جائیں گے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxliii{تو اپنے رب کی کونسی نعمت جھٹلاؤ گے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxliv{یہ ہے وہ جہنم جسے مجرم جھٹلاتے ہیں،\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxlv{پھیرے کریں گے اس میں اور انتہا کے جلتے کھولتے پانی میں\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxlvi{تو اپنے رب کی کونسی نعمت جھٹلاؤ گے،\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxlvii{اور جو اپنے رب کے حضور کھڑے ہونے سے ڈرے اس کے لیے دو جنتیں ہیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxlviii{تو اپنے رب کی کونسی نعمت جھٹلاؤ گے،\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxlix{بہت سی ڈالوں والیاں\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmcml{تو اپنے رب کی کونسی نعمت جھٹلاؤ گے،\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmcmli{ان میں دو چشمے بہتے ہیں\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlii{تو اپنے رب کی کونسی نعمت جھٹلاؤ گے،\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmcmliii{ان میں ہر میوہ دو دو قسم کا،\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmcmliv{تو اپنے رب کی کونسی نعمت جھٹلاؤ گے،\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlv{اور ایسے بچھونوں پر تکیہ لگائے جن کا اَستر قناویز کا اور دونوں کے میوے اتنے جھکے ہوئے کہ نیچے سے چن لو\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlvi{تو اپنے رب کی کونسی نعمت جھٹلاؤ گے،\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlvii{ان بچھونوں پر وہ عورتیں ہیں کہ شوہر کے سوا کسی کو آنکھ اٹھا کر نہیں دیکھتیں ان سے پہلے انہیں نہ چھوا کسی آدمی اور نہ جِن نے،\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlviii{تو اپنے رب کی کونسی نعمت جھٹلاؤ گے،\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlix{گویا وہ لعل اور یاقوت اور مونگا ہیں\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlx{تو اپنے رب کی کونسی نعمت جھٹلاؤ گے،\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxi{نیکی کا بدلہ کیا ہے مگر نیکی\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxii{تو اپنے رب کی کونسی نعمت جھٹلاؤ گے،\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxiii{اور ان کے سوا دو جنتیں اور ہیں\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxiv{تو اپنے رب کی کونسی نعمت جھٹلاؤ گے،\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxv{نہایت سبزی سے سیاہی کی جھلک دے رہی ہیں،\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxvi{تو اپنے رب کی کونسی نعمت جھٹلاؤ گے،\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxvii{ان میں دو چشمے ہیں چھلکتے ہوئے،\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxviii{تو اپنے رب کی کونسی نعمت جھٹلاؤ گے،\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxix{ان میں میوے اور کھجوریں اور انار ہیں،\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxx{تو اپنے رب کی کونسی نعمت جھٹلاؤ گے،\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxi{ان میں عورتیں ہیں عادت کی نیک صورت کی اچھی\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxii{تو اپنے رب کی کونسی نعمت جھٹلاؤ گے،\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxiii{حوریں ہیں خیموں میں پردہ نشین\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxiv{تو اپنے رب کی کونسی نعمت جھٹلاؤ گے،\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxv{ان سے پہلے انہیں ہاتھ نہ لگایا کسی آدمی اور نہ کسی جِن نے،\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxvi{تو اپنے رب کی کونسی نعمت جھٹلاؤ گے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxvii{تکیہ لگائے ہوئے سبز بچھونوں اور منقش خوبصورت چاندنیوں پر،\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxviii{تو اپنے رب کی کونسی نعمت جھٹلاؤ گے،\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxix{بڑی برکت والا ہے تمہارے رب کا نام جو عظمت اور بزرگی والا،\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxx{\basmalahur جب ہولے گی وہ ہونے والی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxi{اس وقت اس کے ہونے میں کسی کو انکار کی گنجائش نہ ہوگی،\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxii{کسی کو پست کرنے والی کسی کو بلندی دینے والی\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxiii{جب زمین کانپے گی تھرتھرا کر\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxiv{اور پہاڑ ریزہ ریزہ ہوجائیں گے چُورا ہوکر\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxv{تو ہوجائیں گے جیسے روزن کی دھوپ میں غبار کے باریک ذرے پھیلے ہوئے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxvi{اور تین قسم کے ہوجاؤ گے،\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxvii{تو دہنی طرف والے کیسے دہنی طرف والے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxviii{اور بائیں طرف والے کیسے بائیں طرف والے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxix{اور جو سبقت لے گئے وہ تو سبقت ہی لے گئے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxc{وہی مقربِ بارگاہ ہیں،\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxci{چین کے باغوں میں،\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxcii{اگلوں میں سے ایک گروہ\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxciii{اور پچھلوں میں سے تھوڑے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxciv{جڑاؤ تختوں پر ہوں گے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxcv{ان پر تکیہ لگائے ہوئے آمنے سامنے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxcvi{ان کے گرد لیے پھریں گے ہمیشہ رہنے والے لڑکے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxcvii{کوزے اور آفتابے اور جام اور آنکھوں کے سامنے بہتی شراب\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxcviii{کہ اس سے نہ انہیں درد سر ہو اور نہ ہوش میں فرق آئے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxcix{اور میوے جو پسند کریں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmm{اور پرندوں کا گوشت جو چاہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmi{اور بڑی آنکھ والیاں حوریں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmii{جیسے چھپے رکھے ہوئے موتی\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmiii{صلہ ان کے اعمال کا\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmiv{اس میں نہ سنیں گے نہ کوئی بیکار با ت نہ گنہگاری\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmv{ہاں یہ کہنا ہوگا سلام سلام\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmvi{اور دہنی طرف والے کیسے دہنی طرف والے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmvii{بے کانٹوں کی بیریوں میں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmviii{اور کیلے کے گچھوں میں\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmix{اور ہمیشہ کے سائے میں\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmx{اور ہمیشہ جاری پانی میں\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmxi{اور بہت سے میووں میں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmxii{جو نہ ختم ہوں اور نہ روکے جائیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmxiii{اور بلند بچھونوں میں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmxiv{بیشک ہم نے ان عورتوں کو اچھی اٹھان اٹھایا،\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmxv{تو انہیں بنایا کنواریاں اپنے شوہر پر پیاریاں،\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmxvi{انہیں پیار دلائیاں ایک عمر والیاں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmxvii{دہنی طرف والوں کے لیے،\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmxviii{اگلوں میں سے ایک گروہ،\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmxix{اور پچھلوں میں سے ایک گروہ\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmxx{اور بائیں طرف والے کیسے بائیں طرف والے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxi{جلتی ہوا اور کھولتے پانی میں،\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxii{اور جلتے دھوئیں کی چھاؤں میں\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxiii{جو نہ ٹھنڈی نہ عزت کی،\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxiv{بیشک وہ اس سے پہلے نعمتوں میں تھے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxv{اور اس بڑے گناہ کی ہٹ (ضد) رکھتے تھے،\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxvi{اور کہتے تھے کیا جب ہم مرجائیں اور ہڈیاں ہوجائیں تو کیا ضرور ہم اٹھائے جائیں گے،\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxvii{اور کیا ہمارے اگلے باپ دادا بھی،\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxviii{تم فرماؤ بیشک سب اگلے اور پچھلے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxix{ضرور اکٹھے کیے جائیں گے، ایک جانے ہوئے دن کی میعاد پر\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxx{پھر بیشک تم اے گمراہو جھٹلانے والو\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxi{ضرور تھوہر کے پیڑ میں سے کھاؤ گے،\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxii{پھر اس سے پیٹ بھرو گے،\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxiii{پھر اس پر کھولتا پانی پیو گے،\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxiv{پھر ایسا پیو گے جیسے سخت پیاسے اونٹ پئیں\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxv{یہ ان کی مہمانی ہے انصاف کے دن،\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxvi{ہم نے تمہیں پیدا کیا تو تم کیوں نہیں سچ مانتے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxvii{تو بھلا دیکھو تو وہ منی جو گراتے ہو\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxviii{کیا تم اس کا آدمی بناتے ہو یا ہم بنانے والے ہیں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxix{ہم نے تم میں مرنا ٹھہرایا اور ہم اس سے ہارے نہیں،\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmmmxl{کہ تم جیسے اور بدل دیں اور تمہاری صورتیں وہ کردیں جس کی تمہیں حبر نہیں\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmmmxli{اور بیشک تم جان چکے ہو پہلی اٹھان پھر کیوں نہیں سوچتے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmmmxlii{تو بھلا بتاؤ تو جو بوتے ہو،\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmmmxliii{کیا تم اس کی کھیتی بناتے ہو یا ہم بنانے والے ہیں\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmmmxliv{ہم چاہیں تو اسے روندن (پامال) کردیں پھر تم باتیں بناتے رہ جاؤ\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmmmxlv{کہ ہم پر چٹی پڑی\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmmmxlvi{بلکہ ہم بے نصیب رہے،\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmmmxlvii{تو بھلا بتاؤ تو وہ پانی جو پیتے ہو،\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmmmxlviii{کیا تم نے اسے بادل سے اتارا یا ہم ہیں اتارنے والے\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmmmxlix{ہم چاہیں تو اسے کھاری کردیں پھر کیوں نہیں شکر کرتے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmmml{تو بھلا بتاؤں تو وہ آگ جو تم روشن کرتے ہو\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmmmli{کیا تم نے اس کا پیڑ پیدا کیا یا ہم ہیں پیدا کرنے والے،\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmmmlii{ہم نے اسے جہنم کا یادگار بنایا اور جنگل میں مسافروں کا فائدہ\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmmmliii{تو اے محبوب تم پاکی بولو اپنے عظمت والے رب کے نام کی،\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmmmliv{تو مجھے قسم ہے ان جگہوں کی جہاں تارے ڈوبتے ہیں\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmmmlv{اور تم سمجھو تو یہ بڑی قسم ہے،\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmmmlvi{بیشک یہ عزت والا قرآن ہے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmmmlvii{محفوظ نوشتہ میں\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmmmlviii{اسے نہ چھوئیں مگر باوضو\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmmmmlix{اتارا ہوا ہے سارے جہان کے رب کا،\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmmmmlx{تو کیا اس بات میں تم سستی کرتے ہو\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxi{اور اپنا حصہ یہ رکھتے ہو کہ جھٹلاتے ہو\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxii{پھر کیوں نہ ہو جب جان گلے تک پہنچے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxiii{اور تم اس وقت دیکھ رہے ہو\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxiv{اور ہم اس کے زیادہ پاس ہیں تم سے مگر تمہیں نگاہ نیں\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxv{تو کیوں نہ ہوا اگر تمہیں بدلہ ملنا نہیں\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxvi{کہ اسے لوٹا لاتے اگر تم سچے ہو\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxvii{پھر وہ مرنے والا اگر مقربوں سے ہے\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxviii{تو راحت ہے اور پھول اور چین کے باغ\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxix{اور اگر دہنی طرف والوں سے ہو\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxx{تو اے محبوب تم پر سلام دہنی طرف والوں سے\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxi{اور اگر جھٹلانے والے گمراہوں میں سے ہو\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxii{تو اس کی مہمانی کھولتا پانی،\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxiii{اور بھڑکتی آگ میں دھنسانا\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxiv{یہ بیشک اعلیٰ درجہ کی یقینی بات ہے،\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxv{تو اے محبوب تم اپنے عظمت والے رب کے نام کی پاکی بولو\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxvi{\basmalahur اللہ کی پاکی بولتا ہے جو کچھ آسمان اور زمین میں ہے اور وہی عزت و حکمت والا ہے،\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxvii{اسی کے لیے ہے آسمانوں اور زمین کی سلطنت، جِلاتا ہے اور مارتا اور وہ سب کچھ کرسکتا ہے،\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxviii{وہی اول وہی آخر وہی ظاہر وہی باطن اور وہی سب کچھ جانتا ہے،\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxix{وہی ہے جس نے آسمان اور زمین چھ دن میں پیدا کیے پھر عرش پر استوا فرمایا جیسا کہ اس کی شان کے لائق ہے، جانتا ہے جو زمین کے اندر جا تا ہے اور جو اس سے باہر نکلتا ہے اور جو آسمان سے اترتا ہے اور جو اس میں چڑھتا ہے اور وہ تمہارے ساتھ ہے تم کہیں ہو، اور اللہ تمہارے کام دیکھ رہا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxx{اسی کی ہے آسمانوں اور زمین کی سلطنت، اور اللہ ہی کی طرف، سب کاموں کی رجوع،\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxi{رات کو دن کے حصے میں لاتا ہے اور دن کو رات کے حصے میں لاتا ہے اور وہ دلوں کی بات جانتا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxii{اللہ اور اس کے رسول پر ایمان لاؤ اور اس کی راہ میں کچھ وہ خرچ کرو جس میں تمہیں اَوروں کا جانشین کیا تو جو تم میں ایمان لائے اور اس کی راہ میں خرچ کیا ان کے لیے بڑا ثواب ہے،\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxiii{اور تمہیں کیا ہے کہ اللہ پر ایمان نہ لاؤ، حالانکہ یہ رسول تمہیں بلارہے ہیں کہ اپنے ر ب پر ایمان لاؤ اور بیشک وہ تم سے پہلے سے عہد لے چکا ہے اگر تمہیں یقین ہو،\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxiv{وہی ہے کہ اپنے بندہ پر روشن آیتیں اتارتا ہے تاکہ تمہیں اندھیریوں سے اجالے کی طرف لے جائے اور بیشک ا لله تم پر ضرور مہربان رحم والا،\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxv{اور تمہیں کیا ہے کہ اللہ کی راہ میں خرچ نہ کرو حالانکہ آسمانوں اور زمین میں سب کا وارث اللہ ہی ہے تم میں برابر نہیں وہ جنہوں نے فتحِ مکہ سے قبل خرچ اور جہاد کیا وہ مرتبہ میں ان سے بڑے ہیں جنہوں نے بعد فتح کے خرچ اور جہاد کیا، اور ان سب سے اللہ جنت کا وعدہ فرماچکا اور اللہ کو تمہارے کاموں کی خبر ہے،\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxvi{کون ہے جو اللہ کو قرض دے اچھا قرض تو وہ اس کے لیے دونے کرے اور اللہ کو عزت کا ثواب دے،\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxvii{جس دن تم ایمان والے مردوں اور ایمان والی عورتوں کو دیکھو گے کہ ان کا نور ہے ان کے آگے اور ان کے دہنے دوڑتا ہے ان سے فرمایا جارہا ہے کہ آج تمہاری سب سے زیادہ خوشی کی بات وہ جنتیں ہیں جن کے نیچے نہریں بہیں تم ان میں ہمیشہ رہو، یہی بڑی کامیابی ہے،\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxviii{جس دن منافق مرد اور منافق عورتیں مسلمانوں سے کہیں گے کہ ہمیں یک نگاہ دیکھو کہ ہم تمہارے نور سے کچھ حصہ لیں، کہا جائے گا اپنے پیچھے لوٹو (ُ۳۴) وہاں نور ڈھونڈو وہ لوٹیں گے، جبھی ان کے درمیان ایک دیوار کھڑی کردی جائے گی جس میں ایک دروازہ ہے اس کے اندر کی طرف رحمت اور اس کے باہر کی طرف عذاب،\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxix{منافق مسلمانوں کو پکاریں گے کیا ہم تمہارے ساتھ نہ تھے وہ کہیں گے کیوں نہیں مگر تم نے تو اپنی جانیں فتنہ میں ڈالیں اور مسلمانوں کی برائی تکتے اور شک رکھتے اور جھوٹی طمع نے تمھیں فریب دیا یہاں تک کہ اللہ کا حکم آگیا اور تمہیں اللہ کے حکم پر اس بڑے فریبی نے مغرور رکھا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmxc{تو آج نہ تم سے کوئی فدیہ لیا جائے اور نہ کھلے کافروں سے، تمہارا ٹھکانا آگ ہے، وہ تمہاری رفیق ہے، اور کیا ہی برا انجام،\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmxci{کیا ایمان والوں کو ابھی وہ وقت نہ آیا کہ ان کے دل جھک جائیں اللہ کی یاد اور اس حق کے لیے جو اترا اور ان جیسے نہ ہوں جن کو پہلے کتاب دی گئی پھر ان پر مدت دراز ہوئی تو ان کے دل سخت ہوگئے اور ان میں بہت فاسق ہیں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmxcii{جان لو کہ اللہ زمین کو زندہ کرتا ہے اس کے مرے پیچھے بیشک ہم نے تمہارے لیے نشانیاں بیان فرمادیں کہ تمہیں سمجھ ہو،\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmxciii{بیشک صدقہ دینے والے مرد اور صدقہ دینے والی عورتیں اور وہ جنہوں نے اللہ کو اچھا قرض دیا ان کے دونے ہیں اور ان کے لیے عزت کا ثواب ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmxciv{اور وہ جو اللہ اور اس کے سب رسولوں پر ایمان لائیں وہی ہیں کامل سچے، اور اَوروں پر گواہ اپنے رب کے یہاں، ان کے لیے ان کا ثواب اور ان کا نور ہے اور جنہوں نے کفر کیا اور ہماری آیتیں جھٹلائیں وہ دوزخی ہیں،\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmxcv{جان لو کہ دنیا کی زندگی تو نہیں مگر کھیل کود اور آرائش اور تمہارا آپس میں بڑائی مارنا اور مال اور اولاد میں ایک دوسرے پر زیادتی چاہنا اس مینھ کی طرح جس کا اُگایاسبزہ کسانوں کو بھایا پھر سوکھا کہ تو اسے زرد دیکھے پھر روندن (پامال کیا ہوا) ہوگیا اور آخرت میں سخت عذاب ہے اور اللہ کی طرف سے بخشش اور اس کی رضا اور دنیا کا جینا تو نہیں مگر دھوکے کا مال\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmxcvi{بڑھ کر چلو اپنے رب کی بخشش اور اس جنت کی طرف جس کی چوڑائی جیسے آسمان اور زمین کا پھیلاؤ تیار ہوئی ہے ان کے لیے جو اللہ اور اس کے سب رسولوں پر ایمان لائے، یہ اللہ کا فضل ہے جسے چاہے دے، اور اللہ بڑا فضل والا ہے،\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmxcvii{نہیں پہنچتی کوئی مصیبت زمین میں اور نہ تمہاری جانوں میں مگر وہ ایک کتاب میں ہے قبل اس کے کہ ہم اسے پیدا کریں بیشک یہ اللہ کو آسان ہے،\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmxcviii{اس لیے کہ غم نہ کھاؤ اس پر جو ہاتھ سے جائے اور خوش نہ ہو اس پر جو تم کو دیا اور اللہ کو نہیں کوئی اترونا (شیخی بگھارنے والا) بڑائی مارنے والا،\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmxcix{وہ جو آپ بخل کریں اور اوروں سے بخل کو کہیں اور جو منہ پھیرے تو بیشک اللہ ہی بے نیاز ہے سب خوبیوں سراہا،\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmc{بیشک ہم نے اپنے رسولوں کو دلیلوں کے ساتھ بھیجا اور ان کے ساتھ کتاب اور عدل کی ترازو اتاری کہ لوگ انصاف پر قائم ہوں اور ہم نے لوہا اتارا اس میں سخت آنچ (نقصان) اور لوگوں کے فائدے اور اس لیے کہ اللہ دیکھے اس کو جو بے دیکھے اس کی اور اس کے رسولوں کی مدد کرتا ہے، بیشک اللہ قورت والا غالب ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmci{اور بیشک ہم نے نوح اور ابراہیم کو بھیجا اور ان کی اولاد میں نبوت اور کتاب رکھی تو ان میں کوئی راہ پر آیا اور ان میں بہتیرے فاسق ہیں،\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmcii{پھر ہم نے ان کے پیچھے اسی راہ پر اپنے اور رسول بھیجے اور ان کے پیچھے عیسیٰ بن مریم کو بھیجا اور اسے انجیل عطا فرمائی اور اس کے پیروں کے دل میں نرمی اور رحمت رکھی اور راہب بننا تو یہ بات انہوں نے دین میں اپنی طرف سے نکالی ہم نے ان پر مقرر نہ کی تھی ہاں یہ بدعت انہوں نے ا لله کی رضا چاہنے کو پیدا کی پھر اسے نہ نباہا جیسا اس کے نباہنے کا حق تھا تو ان کے ایمان والوں کو ہم نے ان کا ثواب عطا کیا، اور ان میں سے بہتیرے فاسق ہیں،\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmciii{اے ایمان والو! اللہ سے ڈرو اور اس کے رسول پر ایمان لاؤ وہ اپنی رحمت کے دو حصے تمہیں عطا فرمائے گا اور تمہارے لیے نور کردے گا جس میں چلو اور تمہیں بخش دے گا، اور اللہ بخشنے والا مہربان ہے،\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmciv{یہ اس لیے کہ کتاب والے کافر جان جائیں کہ اللہ کے فضل پر ان کا کچھ قابو نہیں اور یہ کہ فضل اللہ کے ہاتھ ہے دیتا ہے جسے چاہے، اور اللہ بڑے فضل والا ہے،\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmcv{\basmalahur بیشک اللہ نے سنی اس کی بات جو تم سے اپنے شوہر کے معاملہ میں بحث کرتی ہے اور اللہ سے شکایت کرتی ہے، اور اللہ تم دونوں کی گفتگو سن رہا ہے، بیشک اللہ سنتا دیکھتا ہے،\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcvi{وہ جو تم میں اپنی بیبیوں کو اپنی ماں کی جگہ کہہ بیٹھتے ہیں وہ ان کی مائیں نہیں ان کی مائیں تو وہی ہیں جن سے وہ پیدا ہیں اور وہ بیشک بری اور نری جھوٹ بات کہتے ہیں اور بیشک اللہ ضرور معاف کرنے والا اور بخشنے والا ہے،\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcvii{اور وہ جو اپنی بیبیوں کو اپنی ماں کی جگہ کہیں پھر وہی کرنا چاہیں جس پر اتنی بری بات کہہ چکے تو ان پر لازم ہے ایک بردہ آزاد کرنا قبل اس کے کہ ایک دوسرے کو ہاتھ لگائیں یہ ہے جو نصیحت تمہیں کی جاتی ہے، اور اللہ تمہارے کاموں سے خبردار ہے،\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcviii{پھر جسے بردہ نہ ملے تو لگاتار دو مہینے کے روزے قبل اس کے کہ ایک دوسرے کو ہاتھ لگائیں پھر جس سے روزے بھی نہ ہوسکیں تو ساٹھ مسکینوں کا پیٹ بھرنا یہ اس لیے کہ تم اللہ اور اس کے رسول پر ایمان رکھو اور یہ اللہ کی حدیں ہیں اور کافروں کے لیے دردناک عذاب ہے،\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcix{بیشک وہ جو مخالفت کرتے ہیں اللہ اور اس کے رسول کی ذلیل کیے گئے جیسے ان سے اگلوں کو ذلت دی گئی اور بیشک ہم نے روشن آیتیں اتاریں اور کافروں کے لیے خواری کا عذاب ہے،\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcx{جس دن اللہ ان سب کو اٹھائے گا پھر انہیں ان کے کو تک جتادے گا اللہ نے انہیں گن رکھا ہے اور وہ بھول گئے اور ہر چیز اللہ کے سامنے ہے،\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxi{اے سننے والے کیا تو نے نہ دیکھا کہ اللہ جانتا ہے جو کچھ آسمانوں میں ہے اور جو کچھ زمین میں جہاں کہیں تین شخصوں کی سرگوشی ہو تو چوتھا وہ موجود ہے اور پانچ کی تو چھٹا وہ اور نہ اس سے کم اور نہ اس سے زیادہ کی مگر یہ کہ وہ ان کے ساتھ ہے جہاں کہیں ہوں پھر انہیں قیامت کے دن بتادے گا جو کچھ انہوں نے کیا، بیشک اللہ سب کچھ جانتا ہے،\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxii{کیا تم نے انہیں نہ دیکھا جنہیں بری مشورت سے منع فرمایا گیا تھا پھر وہی کرتے ہیں جس کی ممانعت ہوئی تھی اور آپس میں گناہ اور حد سے بڑھنے اور رسول کی نافرمانی کے مشورے کرتے ہیں اور جب تمہارے حضور حاضر ہوتے ہیں تو ان لفظوں سے تمہیں مجرا کرتے ہیں جو لفظ اللہ نے تمہارے اعزاز میں نہ کہے اور اپنے دلوں میں کہتے ہیں ہمیں اللہ عذاب کیوں نہیں کرتا ہمارے اس کہنے پر انہیں جہنم بس ہے، اس میں دھنسیں گے، تو کیا ہی برا انجام،\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxiii{اے ایمان والو تم جب آپس میں مشورت کرو تو گناہ اور حد سے بڑھنے اور رسول کی نافرمانی کی مشورت نہ کرو اور نیکی اورپرہیزگاری کی مشورت کرو، اور اللہ سے ڈرو جس کی طرف اٹھائے جاؤ گے،\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxiv{وہ مشورت تو شیطان ہی کی طرف سے ہے اس لیے کہ ایمان والوں کو رنج دے اور وہ اس کا کچھ نہیں بگاڑ سکتا بے حکم خدا کے، اور مسلمانوں کو اللہ ہی پر بھروسہ چاہیے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxv{اے ایمان والو جب تم سے کہا جائے مجلسوں میں جگہ دو تو جگہ دو اللہ تمہیں جگہ دے گا اور جب کہا جائے اٹھ کھڑے ہو تو اٹھ کھڑے ہو اللہ تمہارے ایمان والوں کے اور ان کے جن کو علم دیا گیا درجے بلند فرمائے گا، اور اللہ کو تمہارے کاموں کی خبر ہے،\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxvi{اے ایمان والو جب تم رسول سے کوئی بات آہستہ عرض کرنا چاہو تو اپنی عرض سے پہلے کچھ صدقہ دے لو یہ تمہارے لیے بہت بہتر اور بہت ستھرا ہے، پھر اگر تمہیں مقدور نہ ہو تو اللہ بخشنے والا مہربان ہے،\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxvii{کیا تم اس سے ڈرے کہ تم اپنی عرض سے پہلے کچھ صدقے دو پھر جب تم نے یہ نہ کیا، اور اللہ نے اپنی مہر سے تم پر رجوع فرمائی تو نماز قائم رکھو اور زکوٰة دو اور اللہ اور اس کے رسول کے فرمانبردار رہو، اور اللہ تمہارے کاموں کو جانتا ہے،\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxviii{کیا تم نے انہیں نہ دیکھا جو ایسوں کے دوست ہوئے جن پر اللہ کا غضب ہے وہ نہ تم میں سے نہ ان میں سے وہ دانستہ جھوٹی قسم کھاتے ہیں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxix{اللہ نے ان کے لیے سخت عذاب تیار کر رکھا ہے، بیشک وہ بہت ہی برے کام کرتے ہیں،\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxx{انہوں نے اپنی قسموں کو ڈھال بنالیا ہے تو اللہ کی راہ سے روکا تو ان کے لیے خواری کا عذاب ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxi{ان کے مال اور ان کی اولاد اللہ کے سامنے انہیں کچھ کام نہ دیں گے وہ دوزخی ہیں، انہیں اس میں ہمیشہ رہنا،\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxii{جس دن اللہ ان سب کو اٹھائے گا تو اس کے حضور بھی ایسے ہی قسمیں کھائیں گے جیسی تمہارے سامنے کھارہے ہیں اور وہ یہ سمجھتے ہیں کہ انہوں نے کچھ کیا سنتے ہو بیشک وہی جھوٹے ہیں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxiii{ان پر شیطان غالب آگیا تو انہیں اللہ کی یاد بھلا دی، وہ شیطان کے گروہ ہیں، سنتا ہے بیشک شیطان ہی کا گروہ ہار میں ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxiv{بیشک وہ جو اللہ اور اس کے رسول کی مخالفت کرتے ہیں وہ سب سے زیادہ ذلیلوں میں ہیں،\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxv{اللہ لکھ چکا کہ ضرور میں غالب آؤں گا اور میرے رسول بیشک اللہ قوت والا عزت والا ہے،\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxvi{تم نہ پاؤ گے ان لوگوں کو جو یقین رکھتے ہیں اللہ اور پچھلے دن پر کہ دوستی کریں ان سے جنہوں نے اللہ اور اس کے رسول سے مخالفت کی اگرچہ وہ ان کے باپ یا بیٹے یا بھائی یا کنبے والے ہوں یہ ہیں جن کے دلوں میں اللہ نے ایمان نقش فرمادیا اور اپنی طرف کی روح سے ان کی مدد کی اور انہیں باغوں میں لے جائے گا جن کے نیچے نہریں بہیں ان میں ہمیشہ رہیں، اللہ ان سے راضی اور وہ اللہ سے راضی یہ اللہ کی جماعت ہے، سنتا ہے اللہ ہی کی جماعت کامیاب ہے،\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxvii{\basmalahur اللہ کی پاکی بولتا ہے جو کچھ آسمانوں میں ہے اور جو کچھ زمین میں، اور وہ وہی عزت و حکمت والا ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxviii{وہی ہے جس نے ان کافر کتابیوں کو ان کے گھروں سے نکالا ان کے پہلے حشر کے لیے تمہیں گمان نہ تھا کہ وہ نکلیں گے اور وہ سمجھتے تھے کہ ان کے قلعے انہیں اللہ سے بچالیں گے تو اللہ کا حکم ان کے پاس آیا جہاں سے ان کا گمان بھی نہ تھا اور اس نے ان کے دلوں میں رُعب ڈالا کہ اپنے گھر ویران کرتے ہیں اپنے ہاتھوں اور مسلمانوں کے ہاتھوں تو عبرت لو اے نگاہ والو،\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxix{اور اگر نہ ہوتا کہ اللہ نے ان پر گھر سے اجڑنا لکھ دیا تھا تو دنیا ہی میں ان پر عذاب فرماتا اور ان کے لیے آخرت میں آگ کا عذاب ہے،\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxx{یہ اس لیے کہ وہ اللہ سے اور اس کے رسول سے پھٹے (جدا) رہے اور جو اللہ اور اس کے رسول سے پھٹا رہے تو بیشک اللہ کا عذاب سخت ہے،\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxi{جو درخت تم نے کاٹے یا ان کی جڑوں پر قائم چھوڑ دیے یہ سب اللہ کی اجازت سے تھا اور اس لیے کہ فاسقوں کو رسوا کرے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxii{اور جو غنیمت دلائی اللہ نے اپنے رسول کو ان سے تو تم نے ان پر نہ اپنے گھوڑے دوڑائے تھے اور نہ اونٹ ہاں اللہ اپنے رسولوں کے قابو میں دے دیتا ہے جسے چاہے اور اللہ سب کچھ کرسکتا ہے،\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxiii{جو غنیمت دلائی اللہ نے اپنے رسول کو شہر والوں سے وہ اللہ اور رسول کی ہے اور رشتہ داروں اور یتیموں اور مسکینوں اور مسافروں کے لیے کہ تمہارے اغنیا کا مال نہ جائے (ف۹۲۱ اور جو کچھ تمہیں رسول عطا فرمائیں وہ لو اور جس سے منع فرمائیں باز رہو، اور اللہ سے ڈرو بیشک اللہ کا عذاب سخت ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxiv{ان فقیر ہجرت کرنے والوں کے لیے جو اپنے گھروں اور مالوں سے نکالے گئے اللہ کا فضل اور اس کی رضا چاہتے اور اللہ و رسول کی مدد کرتے وہی سچے ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxv{اور جنہوں نے پہلے سے اس شہر اور ایمان میں گھر بنالیا دوست رکھتے ہیں انہیں جو ان کی طرف ہجرت کرکے گئے اور اپنے دلوں میں کوئی حاجت نہیں پاتے اس چیز کو جو دیے گئے اور اپنی جانوں پر ان کو ترجیح دیتے ہیں اگرچہ انہیں شدید محتاجی ہو اور جو اپنے نفس کے لالچ سے بچایا گیا تو وہی کامیاب ہیں،\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxvi{اور وہ جو ان کے بعد آئے عرض کرتے ہیں اے ہمارے رب ہمیں بخش دے اور ہمارے بھائیوں کو جو ہم سے پہلے ایمان لائے اور ہمارے دل میں ایمان والوں کی طرف سے کینہ نہ رکھ اے ہمارے رب بیشک تو ہی نہایت مہربان رحم والا ہے،\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxvii{کیا تم نے منافقوں کو نہ دیکھا کہ اپنے بھائیوں کافر کتابیوں سے کہتے ہیں کہ اگر تم نکالے گئے تو ضرور ہم تمہارے ساتھ جائیں گے اور ہرگز تمہارے بارے میں کسی کی نہ مانیں گے اور اگر تم سے لڑائی ہوئی تو ہم ضرور تمہاری مدد کریں گے، اور اللہ گواہ ہے کہ وہ جھوٹے ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxviii{اگر وہ نکالے گئے تو یہ ان کے ساتھ نہ نکلیں گے، اور ان سے لڑائی ہوئی تو یہ ان کی مدد نہ کریں گے اگر ان کی مدد کی بھی تو ضرور پیٹھ پھیر کر بھاگیں گے، پھر مدد نہ پائیں گے،\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxix{بیشک ان کے دلوں میں اللہ سے زیادہ تمہارا ڈر ہے یہ اس لیے کہ وہ ناسمجھ لوگ ہیں\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxl{یہ سب مل کر بھی تم سے نہ لڑیں گے مگر قلعہ بند شہروں میں یا دُھسّوں (شہر پناہ) کے پیچھے، آپس میں ان کی آنچ (جنگ) سخت ہے تم انہیں ایک جتھا سمجھو گے اور ان کے دل الگ الگ ہیں، یہ اس لیے کہ وہ بے عقل لوگ ہیں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxli{ان کی سی کہاوت جو ابھی قریب زمانہ میں ان سے پہلے تھے انہوں نے اپنے کام کا وبال چکھا اور ان کے لیے دردناک عذاب ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxlii{شیطان کی کہاوت جب اس نے آدمی سے کہا کفر کر پھر جب اس نے کفر کرلیا بولا میں تجھ سے الگ ہوں میں اللہ سے ڈرتا ہوں جو سارے جہان کا رب\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxliii{تو ان دونوں کا انجام یہ ہوا کہ وہ دونوں آگ میں ہیں ہمیشہ اس میں رہے، اور ظالموں کو یہی سزا ہے،\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxliv{اے ایمان والو اللہ سے ڈرو اور ہر جان دیکھے کہ کل کے لیے آگے کیا بھیجا اور اللہ سے ڈرو بیشک اللہ کو تمہارے کاموں کی خبر ہے،\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxlv{اور ان جیسے نہ ہو جو اللہ کو بھول بیٹھے تو اللہ نے انہیں بلا میں ڈالا کہ اپنی جانیں یاد نہ رہیں وہی فاسق ہیں،\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxlvi{دوزخ والے اور جنت والے برابر نہیں جنت والے ہی مراد کو پہنچے،\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxlvii{اگر ہم یہ قرآن کسی پہاڑ پر اتارتے تو ضرور تو اسے دیکھتا جھکا ہوا پاش پاش ہوتا اللہ کے خوف سے اور یہ مثالیں لوگوں کے لیے ہم بیان فرماتے ہیں کہ وہ سوچیں،\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxlviii{وہی اللہ ہے جس کے سوا کوئی معبود نہیں، ہر نہاں و عیاں کا جاننے والا وہی ہے بڑا مہربان رحمت والا،\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxlix{وہی ہے اللہ جس کے سوا کوئی معبود نہیں بادشاہ نہایت پاک سلامتی دینے والا امان بخشنے والا حفاظت فرمانے والا عزت والا عظمت والا تکبر والا اللہ کو پاکی ہے ان کے شرک سے،\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmcl{وہی ہے اللہ بنانے والا پیدا کرنے والا ہر ایک کو صورت دینے والا اسی کے ہیں سب اچھے نام اس کی پاکی بولتا ہے جو کچھ آسمانوں اور زمین میں ہے اور وہی عزت و حکمت والا ہے،\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmcli{\basmalahur اے ایمان والو میرے اور اپنے دشمنوں کو دوست نہ بناؤ تم انہیں خبریں پہنچاتے ہو دوستی سے حالانکہ وہ منکر ہیں اس حق کے جو تمہارے پاس آیا گھر سے جدا کرتے ہیں رسول کو اور تمہیں اس پر کہ تم اپنے رب پر ایمان لائے، اگر تم نکلے ہو میری راہ میں جہاد کرنے اور میری رضا چاہنے کو تو ان سے دوستی نہ کرو تم انہیں خفیہ پیامِ محبت بھیجتے ہو، اور میں خوب جانتا ہوں جو تم چھپاؤ اور جو ظاہر کرو، اور تم میں جو ایسا کرے بیشک وہ سیدھی راہ سے بہکا،\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmclii{اگر تمہیں پائیں تو تمہارے دشمن ہوں گے اور تمہاری طرف اپنے ہاتھ اور اپنی زبانیں برائی کے ساتھ دراز کریں گے اور ان کی تمنا ہے کہ کسی طرح تم کافر ہوجاؤ\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcliii{ہرگز کام نہ آئیں گے تمہیں تمہارے رشتے اور نہ تمہاری اولاد قیامت کے دن، تمہیں ان سے الگ کردے گا اور اللہ تمہارے کام دیکھ رہا ہے،\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcliv{بیشک تمہارے لیے اچھی پیروی تھی ابراہیم اور اس کے ساتھ والوں میں جب انہوں نے اپنی قوم سے کہا بیشک ہم بیزار ہیں تم سے اور ان سے جنہیں اللہ کے سوا پوجتے ہو، ہم تمہارے منکر ہوئے اور ہم میں اور تم میں دشمنی اور عداوت ظاہر ہوگئی ہمیشہ کے لیے جب تک تم ایک اللہ پر ایمان نہ لاؤ مگر ابراہیم کا اپنے باپ سے کہنا کہ میں ضرور تیری مغفرت چاہوں گا اور میں اللہ کے سامنے تیر ے کسی نفع کا مالک نہیں اے ہمارے رب ہم نے تجھی پر بھروسہ کیا اور تیری ہی طرف رجوع لائے اور تیری ہی طرف پھرنا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmclv{اے ہمارے رب ہمیں کافروں کی آزمائش میں نہ ڈال اور ہمیں بخش دے، اے ہمارے رب بیشک تو ہی عزت و حکمت والا ہے،\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmclvi{بیشک تمہارے لیے ان میں اچھی پیروی تھی اسے جو اللہ اور پچھلے دن کا امیدوار ہو اور جو منہ پھیرے تو بیشک اللہ ہی بے نیاز ہے سب خوبیوں سراہا،\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmclvii{قریب ہے کہ اللہ تم میں اور ان میں جو ان میں سے تمہارے دشمن ہیں دوستی کردے اور اللہ قادر ہے اور بخشنے والا مہربان ہے،\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmclviii{اللہ تمہیں ان سے منع نہیں کرتا جو تم سے دین میں نہ لڑے اور تمہیں تمہارے گھروں سے نہ نکالا کہ ان کے ساتھ احسان کرو اور ان سے انصاف کا برتاؤ برتو، بیشک انصاف والے اللہ کو محبوب ہیں،\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmclix{اللہ تمہیں انہی سے منع کرتا ہے جو تم سے دین میں لڑے یا تمہیں تمہارے گھروں سے نکالا یا تمہارے نکالنے پر مدد کی کہ ان سے دوستی کرو اور جو ان سے دوستی کرے تو وہی ستمگار ہیں،\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmclx{اے ایمان والو جب تمہارے پاس مسلمان عورتیں کفرستان سے اپنے گھر چھوڑ کر آئیں تو ان کا امتحان کرو اللہ ان کے ایمان کا حال بہتر جانتا ہے، پھر اگر تمہیں ایمان والیاں معلوم ہوں تو انہیں کافروں کو واپس نہ دو، نہ یہ انہیں حلال نہ وہ انہیں حلال اور ان کے کافر شوہروں کو دے دو جو ان کا خرچ ہوا اور تم پر کچھ گناہ نہیں کہ ان سے نکاح کرلو جب ان کے مہر انہیں دو اور کافرنیوں کے نکاح پر جمے نہ رہو اور مانگ لو جو تمہارا خرچ ہوا اور کافر مانگ لیں جو انہوں نے خرچ کیا یہ اللہ کا حکم ہے، وہ تم میں فیصلہ فرماتا ہے، اور اللہ علم و حکمت والا ہے،\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxi{اور اگر مسلمانوں کے ہاتھ سے کچھ عورتیں کافروں کی طرف نکل جائیں پھر تم کافروں کو سزا دو تو جن کی عورتیں جاتی رہی تھیں غنیمت میں سے انہیں اتنا دیدو جو ان کا خرچ ہوا تھا اور اللہ سے ڈرو جس پر تمہیں ایمان ہے،\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxii{اے نبی جب تمہارے حضور مسلمان عورتیں حاضر ہوں اس پر بیعت کرنے کو کہ اللہ کا کچھ شریک نہ ٹھہرائیں گی اور نہ چوری کریں گی اور نہ بدکاری اور نہ اپنی اولاد کو قتل کریں گی اور نہ وہ بہتان لائیں گی جسے اپنے ہاتھوں اور پاؤں کے درمیان یعنی موضع ولادت میں اٹھائیں اور کسی نیک بات میں تمہاری نافرانی نہ کریں گی تو ان سے بیعت لو اور اللہ سے ان کی مغفرت چاہو بیشک اللہ بخشنے والا مہربان ہے،\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxiii{اے ایمان والو ان لوگوں سے دوستی نہ کرو جن پر اللہ کا غضب ہے وہ آخرت سے آس توڑ بیٹھے ہیں جیسے کافر آس توڑ بیٹھے قبر والوں سے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxiv{\basmalahur اللہ کی پاکی بولتا ہے جو کچھ آسمانوں میں ہے اور جو کچھ زمین میں ہے، اور وہی عزت و حکمت والا ہے،\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxv{اے ایمان والو کیوں کہتے ہو وہ جو نہیں کرتے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxvi{کیسی سخت ناپسند ہے اللہ کو وہ بات کہ وہ کہو جو نہ کرو،\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxvii{بیشک اللہ دوست رکھتا ہے انہیں جو اس کی راہ میں لڑتے ہیں پرا (صف) باندھ کر گویا وہ عمارت ہیں رانگا پلائی (سیسہ پلائی دیوار)\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxviii{اور یاد کرو جب موسیٰ نے اپنی قوم سے کہا، اے میری قوم مجھے کیوں ستاتے ہو حالانکہ تم جانتے ہو کہ میں تمہاری طرف اللہ کا رسول ہوں پھر جب وہ ٹیڑھے ہوئے اللہ نے ان کے دل ٹیڑھے کردیے اور اللہ فاسق لوگوں کو راہ نہیں دیتا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxix{اور یاد کرو جب عیسیٰ بن مریم نے کہا اے بنی اسرائیل میں تمہاری طرف اللہ کا رسول ہوں اپنے سے پہلی کتاب توریت کی تصدیق کرتا ہوا اور ان رسول کی بشارت سناتا ہوا جو میرے بعد تشریف لائیں گے ان کا نام احمد ہے پھر جب احمد ان کے پاس روشن نشانیاں لے کر تشریف لائے بولے یہ کھلا جادو،\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxx{اور اس سے بڑھ کر ظالم کون جو اللہ پر جھوٹ باندھے حالانکہ اسے اسلام کی طرف بلایا جاتا ہو اور ظالم لوگوں کو اللہ راہ نہیں دیتا،\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxi{چاہتے ہیں کہ اللہ کا نور اپنے مونھوں سے بجھادیں اور اللہ کو اپنا نور پورا کرنا پڑے برا مانیں کافر،\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxii{وہی ہے جس نے اپنے رسول کو ہدایت اور سچے دین کے ساتھ بھیجا کہ اسے سب دینوں پر غالب کرے پڑے برا مانیں مشرک،\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxiii{اے ایمان والو کیا میں بتادوں وہ تجارت جو تمہیں دردناک عذاب سے بچالے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxiv{ایمان رکھو اللہ اور اس کے رسول پر اور اللہ کی راہ میں اپنے مال و جان سے جہاد کرو، یہ تمہارے لیے بہتر ہے اگر تم جانو\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxv{وہ تمہارے گناہ بخش دے گا اور تمہیں باغوں میں لے جائے گا جن کے نیچے نہریں رواں اور پاکیزہ محلوں میں جو بسنے کے باغوں میں ہیں، یہی بڑی کامیابی ہے،\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxvi{اور ایک نعمت تمہیں اور دے گا جو تمہیں پیاری ہے اللہ کی مدد اور جلد آنے والی فتح اور اے محبوب مسلمانوں کو خوشی سنادو\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxvii{اے ایمان والو دین خدا کے مددگار ہو جیسے عیسیٰ بن مریم نے حواریوں سے کہا تھا کون ہے جو اللہ کی طرف ہو کر میری مدد کریں حواری بولے ہم دینِ خدا کے مددگار ہیں تو بنی اسرائیل سے ایک گروہ ایمان لایا اور ایک گروہ نے کفر کیا تو ہم نے ایمان والوں کو ان کے دشمنوں پر مدد دی تو غالب ہوگئے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxviii{\basmalahur اللہ کی پاکی بولتا ہے جو کچھ آسمانوں میں ہے اور جو کچھ زمین میں ہے بادشاہ کمال پاکی والا عزت والا حکمت والا،\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxix{وہی ہے جس نے اَن پڑھوں میں انہی میں سے ایک رسول بھیجا کہ ان پر اس کی آیتیں پڑھتے ہیں اور انہیں پاک کرتے ہیں اور انہیں کتاب و حکمت کا علم عطا فرماتے ہیں اور بیشک وہ اس سے پہلے ضرور کھلی گمراہی میں تھے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxx{اور ان میں سے اوروں کو پاک کرتے اور علم عطا فرماتے ہیں، جو ان اگلوں سے نہ ملے اور وہی عزت و حکمت والا ہے،\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxi{یہ اللہ کا فضل ہے جسے چاہے دے، اور اللہ بڑے فضل والا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxii{ان کی مثال جن پر توریت رکھی گئی تھی پھر انہوں نے اس کی حکم برداری نہ کی گدھے کی مثال ہے جو پیٹھ پر کتابیں اٹھائے کیا ہی بری مثال ہے ان لوگوں کی جنہوں نے اللہ کی آیتیں جھٹلائیں، اور اللہ ظالموں کو راہ نہیں دیتا،\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxiii{تم فرماؤ اے یہودیو! اگر تمہیں یہ گمان ہے کہ تم اللہ کے دوست ہو اور لوگ نہیں تو مرنے کی آرزو کرو اگر تم سچے ہو\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxiv{اور وہ کبھی اس کی آرزو نہ کریں گے ان کوتکوں کے سبب جو ان کے ہاتھ آگے بھیج چکے ہیں اور اللہ ظالموں کو جانتا ہے،\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxv{تم فرماؤ وہ موت جس سے تم بھاگتے ہو وہ تو ضرور تمہیں ملنی ہے پھر اس کی طرف پھیرے جاؤ گے جو چھپا اور ظاہر سب کچھ جانتا ہے پھر وہ تمہیں بتادے گا جو تم نے کیا تھا،\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxvi{اے ایمان والو جب نماز کی اذان ہو جمعہ کے دن تو اللہ کے ذکر کی طرف دوڑو اور خرید و فروخت چھوڑ دو یہ تمہارے لیے بہتر ہے اگر تم جانو،\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxvii{پھر جب نماز ہوچکے تو زمین میں پھیل جاؤ اور اللہ کا فضل تلاش کرو اور اللہ کو بہت یاد کرو اس امید پر کہ فلاح پاؤ،\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxviii{اور جب انہوں نے کوئی تجارت یا کھیل دیکھا اس کی طرف چل دیے اور تمہیں خطبے میں کھڑا چھوڑ گئے تم فرماؤ وہ جو اللہ کے پاس ہے کھیل سے اور تجارت سے بہتر ہے، اور اللہ کا رزق سب سے اچھا،\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxix{\basmalahur جب منافق تمہارے حضور حاضر ہوتے ہیں کہتے ہیں کہ ہم گواہی دیتے ہیں کہ حضور بیشک یقیناً اللہ کے رسول ہیں اور اللہ جانتا ہے کہ تم اس کے رسول ہو، اور اللہ گواہی دیتا ہے کہ منافق ضرور جھوٹے ہیں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxc{اور انہوں نے اپنی قسموں کو ڈھال ٹھہرالیا تو اللہ کی راہ سے روکا بیشک وہ بہت ہی برے کام کرتے ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxci{یہ اس لیے کہ وہ زبان سے ایمان لائے پھر دل سے کافر ہوئے تو ان کے دلوں پر مہر کردی گئی تو اب وہ کچھ نہیں سمجھتے،\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxcii{اور جب تو انہیں دیکھے ان کے جسم تجھے بھلے معلوم ہوں، اور اگر بات کریں تو تُو ان کی بات غور سے سنے گویا وہ کڑیاں ہیں دیوار سے ٹکائی ہوئی ہر بلند آواز اپنے ہی اوپر لے جاتے ہیں وہ دشمن ہیں تو ان سے بچتے رہو اللہ انہیں مارے کہاں اوندھے جاتے ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxciii{اور جب ان سے کہا جائے کہ آؤ رسول اللہ تمہارے لیے معافی چاہیں تو اپنے سر گھماتے ہیں اور تم انہیں دیکھو کہ غور کرتے ہوئے منہ پھیر لیتے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxciv{ان پر ایک سا ہے تم ان کی معافی چاہو یا نہ چاہو، اللہ انہیں ہر گز نہ بخشے گا بیشک اللہ فاسقوں کو راہ نہیں دیتا،\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxcv{وہی ہیں جو کہتے ہیں کہ ان پر خرچ نہ کرو جو رسول اللہ کے پاس ہیں یہاں تک کہ پریشان ہوجائیں، اور اللہ ہی کے لیے ہیں آسمانوں اور زمین کے خزانے مگر منافقوں کو سمجھ نہیں،\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxcvi{کہتے ہیں ہم مدینہ پھر کر گئے تو ضرور جو بڑی عزت والا ہے وہ اس میں سے نکال دے گا اسے جو نہایت ذلت والا ہے اور عزت تو اللہ اور اس کے رسول اور مسلمانوں ہی کے لیے ہے مگر منافقوں کو خبر نہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxcvii{اے ایمان والو تمہارے مال نہ تمہاری اولاد کوئی چیز تمہیں اللہ کے ذکر سے غافل نہ کرے اور جو ایسا کرے تو وہی لوگ نقصان میں ہیں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxcviii{اور ہمارے دیے میں سے کچھ ہماری راہ میں خرچ کرو قبل اس کے کہ تم میں کسی کو موت آئے پھر کہنے لگے، اے میرے رب تو نے مجھے تھوڑی مدت تک کیوں مہلت نہ دی کہ میں صدقہ دیتا اور نیکوں میں ہوتا،\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxcix{اور ہرگز اللہ کسی جان کو مہلت نہ دے گا جب اس کا وعدہ آجائے اور اللہ کو تمہارے کاموں کی خبر ہے،\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcc{\basmalahur اللہ کی پاکی بولتا ہے جو کچھ آسمانوں میں ہے اور جو کچھ زمین میں، اسی کا ملک ہے اور اسی کی تعریف اور وہ ہر چیز پر قادر ہے،\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcci{وہی ہے جس نے تمہیں پیدا کیا تو تم میں کوئی کافر اور تم میں کوئی مسلمان اور اللہ تمہارے کام دیکھ رہا ہے،\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmccii{اس نے آسمان اور زمین حق کے ساتھ بنائے اور تمہاری تصویر کی تو تمہاری اچھی صورت بنائی اور اسی کی طرف پھرنا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcciii{جانتا ہے جو کچھ آسمانوں اور زمین میں ہے اور جانتا ہے جو تم چھپاتے اور ظاہر کرتے ہو، اور اللہ دلوں کی بات جانتا ہے،\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcciv{کیا تمہیں ان کی خبر نہ آئی جنہوں نے تم سے پہلے کفر کیا اور اپنے کام کا وبال چکھا اور ان کے لیے دردناک عذاب ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmccv{یہ اس لیے کہ ان کے پاس ان کے رسول روشن دلیلیں لاتے تو بولے، کیا آدمی ہمیں راہ بتائیں گے تو کافر ہوئے اور پھر گئے اور اللہ نے بے نیازی کو کام فرمایا، اور اللہ بے نیاز ہے سب خوبیوں سراہا،\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmccvi{کافروں نے بکا کہ وہ ہرگز نہ اٹھائے جائیں گے، تم فرماؤ کیوں نہیں میرے رب کی قسم تم ضرور اٹھائے جاؤ گے پھر تمہارے کوتک تمہیں جتا دیے جائیں گے، اور یہ اللہ کو آسان ہے،\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmccvii{تو ایمان لاؤ اللہ اور اس کے رسول اور اس نور پر جو ہم نے اتارا، اور اللہ تمہارے کاموں سے خبردار ہے،\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmccviii{جس دن تمہیں اکٹھا کرے گا سب جمع ہونے کے دن وہ دن ہے ہار والوں کی ہار کھلنے کا اور جو اللہ پر ایمان لائے اور اچھا کام کرے اللہ اس کی برائیاں اتاردے گا اور اسے باغوں میں لے جائے گا جن کے نیچے نہریں بہیں کہ وہ ہمیشہ ان میں رہیں، یہی بڑی کامیابی ہے،\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmccix{اور جنہوں نے کفر کیا اور ہماری آیتیں جھٹلائیں وہ آگ والے ہیں ہمیشہ اس میں رہیں، اور کیا ہی برا انجام،\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmccx{کوئی مصیبت نہیں پہنچتی مگر اللہ کے حکم سے، اور جو اللہ پر ایمان لائے اللہ اس کے دل کو ہدایت فرمادے گا اور اللہ سب کچھ جانتا ہے،\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxi{اور اللہ کا حکم مانو اور رسول کا حکم مانو، پھر اگر تم منہ پھیرو تو جان لو کہ ہمارے رسول پر صرف صریح پہنچا دینا ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxii{اللہ ہے جس کے سوا کسی کی بندگی نہیں اور اللہ ہی پر ایمان والے بھروسہ کریں،\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxiii{اے ایمان والو تمہاری کچھ بی بیا ں اور بچے تمہارے دشمن ہیں تو ان سے احتیاط رکھو اور اگر معاف کرو اور درگزرو اور بخش دو تو بیشک اللہ بخشنے والا مہربان ہے،\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxiv{تمہارے مال اور تمہارے بچے جانچ ہی ہیں اور اللہ کے پاس بڑا ثواب ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxv{تو اللہ سے ڈرو جہاں تک ہوسکے اور فرمان سنو اور حکم مانو اور اللہ کی راہ میں خرچ کرو اپنے بھلے کو، اور جو اپنی جان کے لالچ سے بچایا گیا تو وہی فلاح پانے والے ہیں،\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxvi{اگر تم اللہ کو اچھا قرض دو گے وہ تمہارے لیے اس کے دونے کردے گا اور تمہیں بخش دے گا اور اللہ قدر فرمانے والے حلم والا ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxvii{ہر نہاں اور عیاں کا جاننے والا عزت والا حکمت والا،\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxviii{\basmalahur اے نبی جب تم لوگ عورتوں کو طلاق دو تو ان کی عدت کے وقت پر انہیں طلاق دو اور عدت کا شمار رکھو اور اپنے رب اللہ سے ڈرو، عدت میں انہیں ان کے گھروں سے نہ نکالو اور نہ وہ آپ نکلیں مگر یہ کہ کوئی صریح بے حیائی کی بات لائیں اور یہ اللہ کی حدیں ہیں، اور جو اللہ کی حدوں سے آگے بڑھا بیشک اس نے اپنی جان پر ظلم کیا، تمہیں نہیں معلوم شاید اللہ اس کے بعد کوئی نیا حکم بھیجے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxix{تو جب وہ اپنی میعاد تک پہنچنے کو ہوں تو انہیں بھلائی کے ساتھ روک لو یا بھلائی کے ساتھ جدا کرو اور اپنے میں دو ثقہ کو گواہ کرلو اور اللہ کے لیے گواہی قائم کرو اس سے نصیحت فرمائی جاتی ہے اسے جو اللہ اور پچھلے دن پر ایمان رکھتا ہو اور جو اللہ سے ڈرے اللہ اس کے لیے نجات کی راہ نکال دے گا\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxx{اور اسے وہاں سے روزی دے گا جہاں اس کا گمان نہ ہو، اور جو اللہ پر بھروسہ کرے تو وہ اسے کافی ہے بیشک اللہ اپنا کام پورا کرنے والا ہے، بیشک اللہ نے ہر چیز کا ایک اندازہ رکھا ہے،\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxi{اور تمہاری عورتوں میں جنہیں حیض کی امید نہ رہی اگر تمہیں کچھ شک ہو تو ان کی عدت تین مہینے ہے اور ان کی جنہیں ابھی حیض نہ آیا اور حمل والیوں کی میعاد یہ ہے کہ وہ اپنا حمل جَن لیں اور جو اللہ سے ڈرے اللہ اس کے کام میں آسانی فرمادے گا،\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxii{یہ اللہ کا حکم ہے کہ اس نے تمہاری طرف اتارا، اور جو اللہ سے ڈرے اللہ اس کی برائیاں اتار دے گا اور اسے بڑا ثواب دے گا،\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxiii{عورتوں کو وہاں رکھو جہاں خود رہتے ہو اپنی طاقت بھر اور انہیں ضرر نہ دو کہ ان پر تنگی کرو اور اگر حمل والیاں ہوں تو انہیں نان و نفقہ دو یہاں تک کہ ان کے بچہ پیدا ہو پھر اگر وہ تمہارے لیے بچہ کو دودھ پلائیں تو انہیں اس کی اجرت دو اور آپس میں معقول طور پر مشورہ کرو پھر اگر باہم مضائقہ کرو (دشوار سمجھو) تو قریب ہے کہ اسے اور دودھ پلانے والی مل جائے گی،\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxiv{مقدور والا اپنے مقدور کے قابل نفقہ دے، اور جس پر اس کا رزق تنگ کیا گیا وہ اس میں سے نفقہ دے جو اسے اللہ نے دیا، اللہ کسی جان پر بوجھ نہیں رکھتا مگر اسی قابل جتنا اسے دیا ہے، قریب ہے اللہ دشواری کے بعد آسانی فرمادے گا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxv{اور کتنے ہی شہر تھے جنہوں نے اپنے رب کے حکم اور اس کے رسولوں سے سرکشی کی تو ہم نے ان سے سخت حسا ب لیا اور انہیں بری مار دی\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxvi{تو انہوں نے اپنے کیے کا وبال چکھا اور ان کے کام انجام گھاٹا ہوا،\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxvii{اللہ نے ان کے لیے سخت عذاب تیار کر رکھا ہے تو اللہ سے ڈرو اے عقل والو! وہ جو ایمان لائے ہو، بیشک اللہ نے تمہارے لیے عزت اتاری ہے،\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxviii{وہ رسول کہ تم پر اللہ کی روشن آیتیں پڑھتا ہے تاکہ انہیں جو ایمان لائے اور اچھے کام کیے اندھیریوں سے اجالے کی طرف لے جائے، اور جو اللہ پر ایمان لائے اور اچھا کام کرے وہ اسے باغوں میں لے جائے گا جن کے نیچے نہریں بہیں جن میں ہمیشہ ہمیشہ رہیں، بیشک اللہ نے اس کے لیے اچھی روزی رکھی\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxix{اللہ ہے جس نے سات آسمان بنائے اور انہی کی برابر زمینیں حکم ان کے درمیان اترتا ہے تاکہ تم جان لو کہ اللہ سب کچھ کرسکتا ہے، اللہ کا علم ہر چیز کو محیط ہے،\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxx{\basmalahur اے غیب بتا نے والے (نبی) تم اپنے اوپر کیوں حرام کئے لیتے ہو وه چیز جو اللہ نے تمھارے لئے حلال کی اپنی بیبیوں کی مرضی چاہتے ہو اور اللہ بخشنے والا ٴ مہربان ہے،\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxi{بیشک اللہ نے تمہارے لیے تمہاری قسموں کا اتار مقرر فرمادیا اور اللہ تمہارا مولیٰ ہے، اور اللہ علم و حکمت والا ہے،\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxii{اور جب نبی نے اپنی ایک بی بی سے ایک راز کی بات فرمائی پھر جب وہ اس کا ذکر کر بیٹھی اور اللہ نے اسے نبی پر ظاہر کردیا تو نبی نے اسے کچھ جتایا اور کچھ سے چشم پوشی فرمائی پھر جب نبی نے اسے اس کی خبر دی بولی حضور کو کس نے بتایا، فرمایا مجھے علم والے خبردار نے بتایا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxiii{نبی کی دونوں بیبیو! اگر اللہ کی طرف تم رجوع کرو تو ضرور تمہارے دل راہ سے کچھ ہٹ گئے ہیں اور اگر ان پر زور باندھو تو بیشک اللہ ان کا مددگار ہے اور جبریل اور نیک ایمان والے، اور اس کے بعد فرشتے مدد پر ہیں،\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxiv{ان کا رب قریب ہے اگر وہ تمہیں طلاق دے دیں کہ انہیں تم سے بہتر بیبیاں بدل دے اطاعت والیاں ایمان والیاں ادب والیاں توبہ والیاں بندگی والیاں روزہ داریں بیاہیاں اور کنواریاں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxv{اے ایمان والو! اپنی جانوں اور اپنے گھر والوں کو آگ سے بچاؤ جس کے ایندھن آدمی اور پتھر ہیں اس پر سخت کرّے (طاقتور) فرشتے مقرر ہیں جو اللہ کا حکم نہیں ٹالتے اور جو انہیں حکم ہو وہی کرتے ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxvi{اے کافرو! آج بہانے نہ بناؤ تمہیں وہی بدلہ ملے گا جو تم کرتے تھے،\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxvii{اے ایمان والو! اللہ کی طرف ایسی توبہ کرو جو آگے کو نصیحت ہوجائے قریب ہے تمہارا رب تمہاری برائیاں تم سے اتار دے اور تمہیں باغوں میں لے جائے جن کے نیچے نہریں بہیں جس دن اللہ رسوا نہ کرے گا نبی اور ان کے ساتھ کے ایمان والوں کو ان کا نور دوڑتا ہوگا ان کے آگے اور ان کے دہنے عرض کریں گے، اے ہمارے رب! ہمارے لیے ہمارا نور پورا کردے اور ہمیں بخش دے، بیشک تجھے ہر چیز پر قدرت ہے،\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxviii{اے غیب بتانے والے! (نبی) کافروں پر اور منافقوں پر جہاد کرو اور ان پر سختی فرماؤ، اور ان کا ٹھکانا جہنم ہے، اور کیا ہی برا انجام،\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxix{اللہ کافروں کی مثال دیتا ہے نوح کی عورت اور لوط کی عورت، وہ ہمارے بندوں میں دو سزا وارِ (لائق) قرب بندوں کے نکاح میں تمہیں پھر انہوں نے ان سے دغا کی تو وہ اللہ کے سامنے انہیں کچھ کام نہ آئے اور فرما دیا گیا کے تم دونوں عورتیں جہنم میں جاؤ جانے والوں کے ساتھ\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxl{اور اللہ مسلمانو ں کی مثال بیان فر ماتا ہے فرعون کی بی بی جب اس نے عرض کی، اے میرے رب! میرے لیے اپنے پاس جنت میں گھر بنا اور مجھے فرعون اور اس کے کام سے نجات دے اور مجھے ظالم لوگوں سے نجات بخش\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxli{اور عمران کی بیٹی مریم جس نے اپنی پارسائی کی حفاظت کی تو ہم نے اس میں اپنی طرف کی روح پھونکی اور اس نے اپنے رب کی باتوں اور اس کی کتابوں کی تصدیق کی اور فرمانبرداروں میں ہوئی،\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxlii{\basmalahur بڑی برکت والا ہے وہ جس کے قبضہ میں سارا ملک اور وہ ہر چیز پر قادر ہے،\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxliii{وہ جس نے موت اور زندگی پیدا کی کہ تمہاری جانچ ہو تم میں کس کا کام زیادہ اچھا ہے اور وہی عزت والا بخشش والا ہے،\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxliv{جس نے سات آسمان بنائے ایک کے اوپر دوسرا، تو رحمٰن کے بنانے میں کیا فرق دیکھتا ہے تو نگاہ اٹھا کر دیکھ تجھے کوئی رخنہ نظر آتا ہے،\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxlv{پھر دوبارہ نگاہ اٹھا نظر تیری طرف ناکام پلٹ آئے گی تھکی ماندی\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxlvi{اور بیشک ہم نے نیچے کے آسمان کو چراغوں سے آراستہ کیا اور انہیں شیطانوں کے لیے مار کیا اور ان کے لیے بھڑکتی آگ کا عذاب تیار فرمایا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxlvii{اور جنہوں نے اپنے رب کے ساتھ کفر کیا ان کے لیے جہنم کا عذاب ہے، اور کیا ہی برا انجام،\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxlviii{جب اس میں ڈالے جائیں گے اس کا رینکنا (چنگھاڑنا) سنیں گے کہ جوش مارتی ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxlix{معلوم ہوتا ہے کہ شدت غضب میں پھٹ جائے گی، جب کبھی کوئی گروہ اس میں ڈالا جائے گا اس کے داروغہ ان سے پوچھیں گے کیا تمہارے پاس کوئی ڈر سنانے والا نہ آیا تھا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmccl{کہیں گے کیوں نہیں بیشک ہمارے پاس ڈر سنانے والے تشریف لائے پھر ہم نے جھٹلایا اور کہا اللہ نے کچھ نہیں اُتارا، تم تو نہیں مگر بڑی گمراہی میں،\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmccli{اور کہیں گے اگر ہم سنتے یا سمجھتے تو دوزخ والوں میں نہ ہوتے،\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclii{اب اپنے گناہ کا اقرار کیا تو پھٹکار ہو دوزخیوں کو،\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmccliii{بیشک جو بے دیکھے اپنے رب سے ڈرتے ہیں ان کے لیے بخشش اور بڑا ثواب ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmccliv{اور تم اپنی بات آہستہ کہو یا آواز سے، وہ تو دلوں کی جانتا ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclv{کیا وہ نہ جانے جس نے پیدا کیا؟ اور وہی ہے ہر باریکی جانتا خبردار،\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclvi{وہی ہے جس نے تمہارے لیے زمین رام (تابع) کر دی تو اس کے رستوں میں چلو اور اللہ کی روزی میں سے کھاؤ اور اسی کی طرف اٹھنا ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclvii{کیا تم اس سےنڈر ہوگئے جس کی سلطنت آسمان میں ہے کہ تمہیں زمین میں دھنسادے جبھی وہ کانپتی رہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclviii{یا تم نڈر ہوگئے اس سے جس کی سلطنت آسمان میں ہے کہ تم پر پتھراؤ بھیجے تو اب جانو گے کیسا تھا میرا ڈرانا،\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclix{اور بیشک ان سے اگلوں نے جھٹلایا تو کیسا ہوا میرا انکار\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclx{اور کیا انہوں نے اپنے اوپر پرندے نہ دیکھے پر پھیلاتے اور سمیٹتے انہیں کوئی نہیں روکتا سوا رحمٰن کے بیشک وہ سب کچھ دیکھتا ہے،\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxi{یا وہ کونسا تمہارا لشکر ہے کہ رحمٰن کے مقابل تمہاری مدد کرے کافر نہیں مگر دھوکے میں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxii{یا کونسا ایسا ہے جو تمہیں روزی دے اگر وہ اپنی روزی روک لے بلکہ وہ سرکش اور نفرت میں ڈھیٹ بنے ہوئے ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxiii{تو کیا وہ جو اپنے منہ کے بل اوندھا چلے زیادہ راہ پر ہے یا وہ جو سیدھا چلے سیدھی راہ پر\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxiv{تم فرماؤ وہی ہے جس نے تمہیں پیدا کیا اور تمہارے لیے کان اور آنکھ اور دل بنائے کتنا کم حق مانتے ہو\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxv{تم فرماؤ وہی ہے جس نے تمہیں زمین میں پھیلایا اور اسی کی طرف اٹھائے جاؤ گے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxvi{اور کہتے ہیں یہ وعدہ کب آئے گا اگر تم سچے ہو،\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxvii{تم فرماؤ یہ علم تو اللہ کے پاس ہے، اور میں تو یہی صاف ڈر سنانے والا ہوں\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxviii{پھر جب اسے پاس دیکھیں گے کافروں کے منہ بگڑ جائیں گے اور ان سے فرمادیا جائے گا یہ ہے جو تم مانگتے تھے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxix{تم فرماؤ بھلا دیکھو تو اگر اللہ مجھے اور میرے ساتھ والوں کو بلاک کردے یا ہم پر رحم فرمائے تو وہ کونسا ہے جو کافروں کو دکھ کے عذاب سے بچالے گا\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxx{تم فرماؤ وہی رحمٰن ہے ہم اس پر ایمان لائے اور اسی پر بھروسہ کیا، تو اب جان جاؤ گے کون کھلی گمراہی میں ہے،\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxi{تم فرماؤ بھلا دیکھو تو اگر صبح کو تمہارا پانی زمین میں دھنس جائے تو وہ کون ہے جو تمہیں پانی لادے نگاہ کے سامنے بہتا\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxii{\basmalahur قلم اور ان کے لکھے کی قسم\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxiii{تم اپنے رب کے فضل سے مجنون نہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxiv{اور ضرور تمہارے لیے بے انتہا ثواب ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxv{اور بیشک تمہاری خُو بُو (خُلق) بڑی شان کی ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxvi{تو اب کوئی دم جاتا ہے کہ تم بھی دیکھ لو گے اور وہ بھی دیکھ لیں گے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxvii{کہ تم میں کون مجنون تھا،\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxviii{بیشک تمہارا رب خوب جانتا ہے جو اس کی راہ سے بہکے، اور وہ خوب جانتا ہے جو راہ پر ہے،\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxix{تو جھٹلانے والوں کی بات نہ سننا،\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxx{وہ تو اس آرزو میں ہیں کہ کسی طرح تم نرمی کرو تو وہ بھی نرم پڑجائیں،\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxi{اور ہر ایسے کی بات نہ سننا جو بڑا قسمیں کھانے والا ذلیل\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxii{بہت طعنے دینے والا بہت اِدھر کی اُدھر لگاتا پھرنے والا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxiii{بھلائی سے بڑا روکنے والا حد سے بڑھنے والا گنہگار\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxiv{درشت خُو اس سب پر طرہ یہ کہ اس کی اصل میں خطا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxv{اس پر کہ کچھ مال اور بیٹے رکھتا ہے،\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxvi{جب اس پر ہماری آیتیں پڑھی جائیں کہتا ہے کہ اگلوں کی کہانیاں ہیں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxvii{قریب ہے کہ ہم اس کی سور کی سی تھوتھنی پر داغ دیں گے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxviii{بیشک ہم نے انہیں جانچا جیسا اس باغ والوں کو جانچا تھا جب انہوں نے قسم کھائی کہ ضرور صبح ہوتے اس کھیت کو کاٹ لیں گے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxix{اور انشاء اللہ نہ کہا\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxc{تو اس پر تیرے رب کی طرف سے ایک پھیری کرنے والا پھیرا کر گیا اور وہ سوتے تھے،\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxci{تو صبح رہ گیا جیسے پھل ٹوٹا ہوا\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxcii{پھر انہوں نے صبح ہوتے ایک دوسرے کو پکارا،\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxciii{کہ تڑکے اپنی کھیتی چلو اگر تمہیں کاٹنی ہے،\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxciv{تو چلے اور آپس میں آہستہ آہستہ کہتے جاتے تھے کہ\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxcv{ہرگز آج کوئی مسکین تمہارے باغ میں آنے نہ پائے،\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxcvi{اور تڑکے چلے اپنے اس ارادہ پر قدرت سمجھتے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxcvii{پھر جب اسے بولے بیشک ہم راستہ بہک گئے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxcviii{بلکہ ہم بے نصیب ہوئے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxcix{ان میں جو سب سے غنیمت تھا بولا کیا میں تم سے نہیں کہتا تھا کہ تسبیح کیوں نہیں کرتے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmccc{بولے پاکی ہے ہمارے رب کو بیشک ہم ظالم تھے،\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmccci{اب ایک دوسرے کی طرف ملامت کرتا متوجہ ہوا\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccii{بولے ہائے خرابی ہماری بیشک ہم سرکش تھے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmccciii{امید ہے ہمیں ہمارا رب اس سے بہتر بدل دے ہم اپنے رب کی طرف رغبت لاتے ہیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmccciv{مار ایسی ہوتی ہے اور بیشک آخرت کی مار سب سے بڑی، کیا اچھا تھا اگر وہ جانتے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccv{بیشک ڈر والوں کے لیے ان کے رب کے پاس چین کے باغ ہیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccvi{کیا ہم مسلمانوں کو مجرموں کا سا کردیں\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccvii{تمہیں کیا ہوا کیسا حکم لگاتے ہو\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccviii{کیا تمہارے لیے کوئی کتاب ہے اس میں پڑھتے ہو،\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccix{کہ تمہارے لیے اس میں جو تم پسند کرو،\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccx{یا تمہارے لیے ہم پر کچھ قسمیں ہیں قیامت تک پہنچتی ہوئی کہ تمہیں ملے گا جو کچھ دعویٰ کرتے ہو\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxi{تم ان سے پوچھو ان میں کون سا اس کا ضامن ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxii{یا ان کے پاس کچھ شریک ہیں تو اپنے شریکوں کو لے کر آئیں اگر سچے ہیں\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxiii{جس دن ایک ساق کھولی جائے گی (جس کے معنی اللہ ہی جانتا ہے) اور سجدہ کو بلائے جائیں گے تو نہ کرسکیں گے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxiv{نیچی نگاہیں کیے ہوئے ان پر خواری چڑھ رہی ہوگی، اور بیشک دنیا میں سجدہ کے لیے بلائے جاتے تھے جب تندرست تھے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxv{تو جو اس بات کو جھٹلاتا ہے اسے مجھ پر چھوڑ دو قریب ہے کہ ہم انہیں آہستہ آہستہ لے جائیں گے جہاں سے انہیں خبر نہ ہوگی،\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxvi{اور میں انہیں ڈھیل دوں گا، بیشک میری خفیہ تدبیر بہت پکی ہے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxvii{یا تم ان سے اجرت مانگتے ہو کہ وہ چٹی کے بوجھ میں دبے ہیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxviii{یا ان کے پاس غیب ہے کہ وہ لکھ رہے ہیں\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxix{تو تم اپنے رب کے حکم کا انتظار کر و اور اس مچھلی والے کی طرح نہ ہونا جب اس حال میں پکارا کہ اس کا دل گھٹ رہا تھا\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxx{اگر اس کے رب کی نعمت اس کی خبر کو نہ پہنچ جاتی تو ضرور میدان پر پھینک دیا جاتا الزام دیا ہوا\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxi{تو اسے اس کے رب نے چن لیا اور اپنے قربِ خاص کے سزاواروں (حقداروں) میں کرلیا،\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxii{اور ضرور کافر تو ایسے معلوم ہوتے ہیں کہ گویا اپنی بد نظر لگا کر تمہیں گرادیں گے جب قرآن سنتے ہیں اور کہتے ہیں یہ ضرور عقل سے دور ہیں،\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxiii{اور وہ تو نہیں مگر نصیحت سارے جہاں کے لیے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxiv{\basmalahur وہ حق ہونے والی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxv{کیسی وہ حق ہونے والی\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxvi{اور تم نے کیا جانا کیسی وہ حق ہونے والی\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxvii{ثمود اور عاد نے اس سخت صدمہ دینے والی کو جھٹلایا،\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxviii{تو ثمود تو ہلاک کیے گئے حد سے گزری ہوئی چنگھاڑ سے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxix{اور رہے عاد وہ ہلاک کیے گئے نہایت سخت گرجتی آندھی سے،\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxx{وہ ان پر قوت سے لگادی سات راتیں اور آٹھ دن لگاتار تو ان لوگوں کو ان میں دیکھو بچھڑے ہوئے گویا وہ کھجور کے ڈھنڈ (سوکھے تنے) ہیں گرے ہوئے،\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxi{تو تم ان میں کسی کو بچا ہوا دیکھتے ہو\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxii{اور فرعون اور اس سے اگلے اور الٹنے والی بستیاں خطا لائے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxiii{تو انہوں نے اپنے رب کے رسولوں کا حکم نہ مانا تو اس نے انہیں بڑھی چڑھی گرفت سے پکڑا،\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxiv{بیشک جب پانی نے سر اٹھایا تھا ہم نے تمہیں کشتی میں سوار کیا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxv{کہ اسے تمہارے لیے یادگار کریں اور اسے محفوظ رکھے وہ کان کہ سن کر محفوظ رکھتا ہو\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxvi{پھرجب صور پھونک دیا جائے ایک دم،\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxvii{اور زمین اور پہاڑ اٹھا کر دفعتا ً چُورا کردیے جائیں،\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxviii{وہ دن ہے کہ ہو پڑے گی وہ ہونے والی\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxix{اور آسمان پھٹ جائے گا تو اس دن اس کا پتلا حال ہوگا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxl{اور فرشتے اس کے کناروں پر کھڑے ہوں گے اور اس دن تمہارے رب کا عرش اپنے اوپر آٹھ فرشتے اٹھائیں گے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxli{اس دن تم سب پیش ہو گے کہ تم میں کوئی چھپنے والی جان چھپ نہ سکے گی،\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxlii{تو وہ جو اپنا نامہٴ اعمال دہنے ہاتھ میں دیا جائے گا کہے گا لو میرے نامہٴ اعمال پڑھو،\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxliii{مجھے یقین تھا کہ میں اپنے حساب کو پہنچوں گا\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxliv{تو وہ من مانتے چین میں ہے،\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxlv{بلند باغ میں،\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxlvi{جس کے خوشے جھکے ہوئے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxlvii{کھاؤ اور پیو رچتا ہوا صلہ اس کا جو تم نے گزرے دنوں میں آگے بھیجا\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxlviii{اور وہ جو اپنا نامہٴ اعمال بائیں ہاتھ میں دیا جائے گا کہے گا ہائے کسی طرح مجھے اپنا نوشتہ نہ دیا جاتا،\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxlix{اور میں نہ جانتا کہ میرا حساب کیا ہے،\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccl{ہائے کسی طرح موت ہی قصہ چکا جاتی\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccli{میرے کچھ کام نہ آیا میرا مال\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclii{میرا سب زور جاتا رہا\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccliii{اسے پکڑو پھر اسے طوق ڈالو\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccliv{پھر اسے بھڑکتی آگ میں دھنساؤ،\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclv{پھر ایسی زنجیر میں جس کا ناپ ستر ہاتھ ہے اسے پُرو دو\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclvi{بیشک وہ عظمت والے اللہ پر ایمان نہ لاتا تھا\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclvii{اور مسکین کو کھانے دینے کی رغبت نہ دیتا\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclviii{تو آج یہاں اس کا کوئی دوست نہیں\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclix{اور نہ کچھ کھانے کو مگر دوزخیوں کا پیپ،\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclx{اسے نہ کھائیں گے مگر خطاکار\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxi{تو مجھے قسم ان چیزوں کی جنہیں تم دیکھتے ہو،\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxii{اور جنہیں تم نہیں دیکھتے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxiii{بیشک یہ قرآن ایک کرم والے رسول سے باتیں ہیں\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxiv{اور وہ کسی شاعر کی بات نہیں کتنا کم یقین رکھتے ہو\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxv{اور نہ کسی کاہن کی بات کتنا کم دھیان کرتے ہو\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxvi{اس نے اتارا ہے جو سارے جہان کا رب ہے،\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxvii{اور اگر وہ ہم پر ایک بات بھی بنا کر کہتے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxviii{ضرور ہم ان سے بقوت بدلہ لیتے،\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxix{پھر ان کی رگِ دل کاٹ دیتے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxx{پھر تم میں کوئی ان کا بچانے والا نہ ہوتا،\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxi{اور بیشک یہ قرآن ڈر والوں کو نصیحت ہے،\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxii{اور ضرور ہم جانتے ہیں کہ تم کچھ جھٹلانے والے ہیں،\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxiii{اور بیشک وہ کافروں پر حسرت ہے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxiv{اور بیشک وہ یقین حق ہے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxv{تو اے محبوب تم اپنے عظمت والے رب کی پاکی بولو\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxvi{\basmalahur ایک مانگنے والا وہ عذاب مانگتا ہے،\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxvii{جو کافروں پر ہونے والا ہے، اس کا کوئی ٹالنے والا نہیں،\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxviii{وہ ہوگا اللہ کی طرف سے جو بلندیوں کا مالک ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxix{ملائکہ اور جبریل اس کی بارگاہ کی طرف عروج کرتے ہیں وہ عذاب اس دن ہوگا جس کی مقدار پچاس ہزار برس ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxx{تو تم اچھی طرح صبر کرو،\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxi{وہ اسے دور سمجھ رہے ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxii{اور ہم اسے نزدیک دیکھ رہے ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxiii{جس دن آسمان ہوگا جیسی گلی چاندی،\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxiv{اور پہاڑ ایسے ہلکے ہوجائیں گے جیسے اون\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxv{اور کوئی دوست کسی دوست کی بات نہ پوچھے گا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxvi{ہوں گے انہیں دیکھتے ہوئے مجرم آرزو کرے گا، کاش! اس دن کے عذاب سے چھٹنے کے بدلے میں دے دے اپنے بیٹے،\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxvii{اور اپنی جورو اور اپنا بھائی،\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxviii{اور اپنا کنبہ جس میں اس کی جگہ ہے،\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxix{اور جتنے زمین میں ہیں سب پھر یہ بدلہ دنیا اسے بچالے،\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxc{ہرگز نہیں وہ تو بھڑکتی آگ ہے،\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxci{کھال اتار لینے والی بلارہی ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxcii{اس کو جس نے پیٹھ دی اور منہ پھیرا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxciii{اور جوڑ کر سینت رکھا (محفوظ کرلیا)\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxciv{بیشک آدمی بنایا گیا ہے بڑا بے صبرا حریص،\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxcv{جب اسے برائی پہنچے تو سخت گھبرانے والا،\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxcvi{اور جب بھلائی پہنچے تو روک رکھنے والا\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxcvii{مگر نمازی،\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxcviii{جو اپنی نماز کے پابند ہیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxcix{اور وہ جن کے مال میں ایک معلوم حق ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmcd{اس کے لیے جو مانگے اور جو مانگ بھی نہ سکے تو محروم رہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdi{اور ہو جو انصاف کا دن سچ جانتے ہیں\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdii{اور وہ جو اپنے رب کے عذاب سے ڈر رہے ہیں،\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdiii{بیشک ان کے رب کا عذاب نڈر ہونے کی چیز نہیں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdiv{اور ہو جو اپنی شرمگاہوں کی حفاظت کرتے ہیں،\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdv{مگر اپنی بیبیوں یا اپنے ہاتھ کے مال کنیزوں سے کہ ان پر کچھ ملامت نہیں،\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdvi{تو جو ان دو کے سوا اور چاہے وہی حد سے بڑھنے والے ہیں\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdvii{اور وہ جو اپنی امانتوں اور اپنے عہد کی حفاظت کرتے ہیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdviii{اور وہ جو اپنی گواہیوں پر قائم ہیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdix{اور وہ جو اپنی نماز کی حفاظت کرتے ہیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdx{یہ ہیں جن کا باغوں میں اعزاز ہوگا\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxi{تو ان کافروں کو کیا ہوا تمہاری طرف تیز نگاہ سے دیکھتے ہیں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxii{داہنے اور بائیں گروہ کے گروہ،\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxiii{کیا ان میں ہر شخص یہ طمع کرتا ہے کہ چین کے باغ میں داخل کیا جائے،\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxiv{ہرگز نہیں، بیشک ہم نے انہیں اس چیز سے بنایا جسے جانتے ہیں\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxv{تو مجھے قسم ہے اس کی جو سب پُوربوں سب پچھموں کا مالک ہے کہ ضرور ہم قادر ہیں،\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxvi{کہ ان سے اچھے بدل دیں اور ہم سے کوئی نکل کر نہیں جاسکتا\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxvii{تو انہیں چھوڑ دو ان کی بیہودگیوں میں پڑے اور کھیلتے ہوئے یہاں تک کہ اپنے اس دن سے ملیں جس کا انہیں وعدہ دیا جاتا ہے،\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxviii{جس دن قبروں سے نکلیں گے جھپٹتے ہوئے گویا وہ نشانیوں کی طرف لپک رہے ہیں\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxix{آنکھیں نیچی کیے ہوئے ان پر ذلت سوار، یہ ہے ان کا وہ دن جس کا ان سے وعدہ تھا\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxx{\basmalahur بیشک ہم نے نوح کو اس کی قوم کی طرف بھیجا کہ ان کو ڈرا اس سے پہلے کہ ان پر دردناک عذاب آئے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxi{اس نے فرمایا اے میری قوم! میں تمہارے لیے صریح ڈر سنانے والا ہوں،\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxii{کہ اللہ کی بندگی کرو اور اس سے ڈرو اور میرا حکم مانو،\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxiii{وہ تمہارے کچھ گناہ بخش دے گا اور ایک مقرر میعاد تک تمہیں مہلت دے گا بیشک اللہ کا وعدہ جب آتا ہے ہٹایا نہیں جاتا کسی طرح تم جانتے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxiv{عرض کی اے میرے رب! میں نے اپنی قوم کو رات دن بلایا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxv{تو میرے بلانے سے انہیں بھاگنا ہی بڑھا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxvi{اور میں نے جتنی بار انہیں بلایا کہ تو ان کو بخشے انہوں نے اپنے کانوں میں انگلیاں دے لیں اور اپنے کپڑے اوڑھ لیے اور ہٹ کی اور بڑا غرور کیا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxvii{پھر میں نے انہیں علانیہ بلایا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxviii{پھر میں نے ان سے با علان بھی کہا اور آہستہ خفیہ بھی کہا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxix{تو میں نے کہا اپنے رب سے معافی مانگو وہ بڑا معاف فرمانے والا ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxx{تم پر شراٹے کا (موسلا دھار) مینھ بھیجے گا،\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxi{اور مال اور بیٹوں سے تمہاری مدد کرے گا اور تمہارے لیے باغ بنادے گا اور تمہارے لیے نہریں بنائے گا\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxii{تمہیں کیا ہوا اللہ سے عزت حاصل کرنے کی امید نہیں کرتے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxiii{حالانکہ اس نے تمہیں طرح طرح بنایا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxiv{کیا تم نہیں دیکھتے اللہ نے کیونکر سات آسمان بنائے ایک پر ایک،\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxv{اور ان میں چاند کو روشن کیا اور سورج کو چراغ\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxvi{اور اللہ نے تمہیں سبزے کی طرح زمین سے اُگایا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxvii{پھر تمہیں اسی میں لے جائے گا اور دبارہ نکالے گا\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxviii{اور اللہ نے تمہارے لیے زمین کو بچھونا بنایا،\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxix{کہ اس کے وسیع راستوں میں چلو،\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxl{نوح نے عرض کی، اے میرے رب! انہوں نے میری نافرمانی کی اور ایسے کے پیچھے ہولیے جیسے اس کے مال اور اولاد نے نقصان ہی بڑھایا\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxli{اور بہت بڑا داؤ ں کھیلے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxlii{اور بولے ہرگز نہ چھوڑنا اپنے خداؤں کو اور ہرگز نہ چھوڑنا ودّ اور سواع اور یغوث اور یعوق اور نسر کو\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxliii{اور بیشک انہوں نے بہتوں کو بہکایا اور تو ظالموں کو زیادہ نہ کرنا مگر گمراہی\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxliv{اپنی کیسی خطاؤں پر ڈبوئے گئے پھر آگ میں داخل کیے گئے تو انہوں نے اللہ کے مقابل اپنا کوئی مددگار نہ پایا\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxlv{اور نوح نے عرض کی، اے میرے رب! زمین پر کافروں میں سے کوئی بسنے والا نہ چھوڑ،\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxlvi{بیشک اگر تو انہیں رہنے دے گا تو تیرے بندوں کو گمراہ کردیں گے اور ان کے اولاد ہوگی تو وہ بھی نہ ہوگی مگر بدکار بڑی ناشکر\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxlvii{اے میرے رب مجھے بخش دے اور میرے ماں باپ کو اور اسے جو ایمان کے ساتھ میرے گھر میں ہے اور سب مسلمان مردوں اور سب مسلمان عورتوں کو، اور کافروں کو نہ بڑھا مگر تباہی\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxlviii{\basmalahur تم فرماؤ مجھے وحی ہوئی کہ کچھ جنوں نے میرا پڑھنا کان لگا کر سنا تو بولے ہم نے ایک عجیب قرآن سنا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxlix{کہ بھلائی کی راہ بتا تا ہے تو ہم اس پر ایمان لائے، اور ہم ہرگز کسی کو اپنے رب کا شریک نہ کریں گے،\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdl{اور یہ کہ ہمارے رب کی شان بہت بلند ہے نہ اس نے عورت اختیار کی اور نہ بچہ\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdli{اور یہ کہ ہم میں کا بے وقوف اللہ پر بڑھ کر بات کہتا تھا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlii{اور یہ کہ ہمیں خیال تھا کہ ہرگز آدمی اور جِن اللہ پر جھوٹ نہ باندھیں گے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdliii{اور یہ کہ آدمیوں میں کچھ مرد جنوں کے کچھ مردوں کے پناہ لیتے تھے تو اس سے اور بھی ان کا تکبر بڑھا،\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdliv{اور یہ کہ انہوں نے گمان کیا جیسا تمہیں گمان ہے کہ اللہ ہرگز کوئی رسول نہ بھیجے گا،\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlv{اور یہ کہ ہم نے آسمان کو چھوا تو اسے پایا کہ سخت پہرے اور آگ کی چنگاریوں سے بھردیا گیا ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlvi{اور یہ کہ ہم پہلے آسمان میں سننے کے لیے کچھ موقعوں پر بیٹھا کرتے تھے، پھر اب جو کوئی سنے وہ اپنی تاک میں آگ کا لُوکا (لپٹ) پائے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlvii{اور یہ کہ ہمیں نہیں معلوم کہ زمین والوں سے کوئی برائی کا ارادہ فرمایا گیا ہے یا ان کے نے کوئی بھلائی چاہی ہے،\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlviii{اور یہ کہ ہم میں کچھ نیک ہیں اور کچھ دوسری طرح کے ہیں، ہم کئی راہیں پھٹے ہوئے ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlix{اور یہ کہ ہم کو یقین ہوا کہ ہر گز زمین اللہ کے قابو سے نہ نکل سکیں گے اور نہ بھاگ کر اس کے قبضہ سے باہر ہوں،\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlx{اور یہ کہ ہم نے جب ہدایت سنی اس پر ایمان لائے، تو جو اپنے رب پر ایمان لائے اسے نہ کسی کمی کا خوف اور نہ زیادگی کا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxi{اور یہ کہ ہم میں کچھ مسلمان ہیں اور کچھ ظالم تو جو اسلام لائے انہوں نے بھلائی سوچی\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxii{اور رہے ظالم وہ جہنم کے ایندھن ہوئے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxiii{اور فرماؤ کہ مجھے یہ وحی ہوئی ہے کہ اگر وہ راہ پر سیدھے رہتے تو ضرور ہم انہیں وافر پانی دیتے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxiv{کہ اس پر انہیں جانچیں اور جو اپنے رب کی یاد سے منہ پھیرے وہ اسے چڑھتے عذاب میں ڈالے گا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxv{اور یہ کہ مسجدیں اللہ ہی کی ہیں تو اللہ کے ساتھ کسی کی بندگی نہ کرو\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxvi{اور یہ کہ جب اللہ کا بندہ اس کی بندگی کرنے کھڑا ہوا تو قریب تھا کہ وہ جن اس پر ٹھٹھ کے ٹھٹھ ہوجائیں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxvii{تم فرماؤ میں تو اپنے رب ہی کی بندگی کرتا ہوں اور کسی کو اس کا شریک نہیں ٹھہراتا،\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxviii{تم فرماؤ میں تمہارے کسی برے بھلے کا مالک نہیں،\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxix{تم فرماؤ ہرگز مجھے اللہ سے کوئی نہ بچائے گا اور ہرگز اس کے سوا کوئی پناہ نہ پاؤں گا،\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxx{مگر اللہ کے پیام پہنچاتا اور اس کی رسالتیں اور جو اللہ اور اس کے رسول کا حکم نہ مانے تو بیشک ان کے لیے جہنم کی آگ ہے جس میں ہمیشہ ہمیشہ رہیں،\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxi{یہاں تک کہ جب دیکھیں گے جو وعدہ دیا جاتا ہے تو اب جان جائیں گے کہ کس ک مددگار کمزور اور کس کی گنتی کم\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxii{تم فرماؤ میں نہیں جانتا آیا نزدیک ہے وہ جس کا تمہیں وعدہ دیا جاتا ہے یا میرا رب اسے کچھ وقفہ دے گا\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxiii{غیب کا جاننے والا تو اپنے غیب پر کسی کو مسلط نہیں کرتا\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxiv{سوائے اپنے پسندیدہ رسولوں کے کہ ان کے آگے پیچھے پہرا مقرر کر دیتا ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxv{تا کہ دیکھ لے کہ انہوں نے اپنے رب کے پیام پہنچا دیے اور جو کچھ ان کے پاس سب اس کے علم میں ہے اور اس نے ہر چیز کی گنتی شمار کر رکھی ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxvi{\basmalahur اے جھرمٹ مارنے والے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxvii{رات میں قیام فرما سوا کچھ رات کے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxviii{آدھی رات یا اس سے کچھ تم کرو،\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxix{یا اس پر کچھ بڑھاؤ اور قرآن خوب ٹھہر ٹھہر کر پڑھو\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxx{بیشک عنقریب ہم تم پر ایک بھاری بات ڈالیں گے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxi{بیشک رات کا اٹھنا وہ زیادہ دباؤ ڈالتا ہے اور بات خوب سیدھی نکلتی ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxii{بیشک دن میں تو تم کو بہت سے کام ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxiii{اور اپنے رب کا نام یاد کرو اور سب سے ٹوٹ کر اسی کے ہو رہو\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxiv{وہ پورب کا رب اور پچھم کا رب اس کے سوا کوئی معبود نہیں تو تم اسی کو اپنا کارساز بناؤ\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxv{اور کافروں کی باتوں پر صبر فرماؤ اور انہیں اچھی طرح چھوڑ دو\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxvi{اور مجھ پر چھوڑو ان جھٹلانے والے مالداروں کو اور انہیں تھوڑی مہلت دو\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxvii{بیشک ہمارے پاس بھاری بیڑیاں ہیں اور بھڑکتی آگ،\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxviii{اور گلے میں پھنستا کھانا اور دردناک عذاب\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxix{جس دن تھرتھرائیں گے زمین اور پہاڑ اور پہاڑ ہوجائیں گے ریتے کا ٹیلہ بہتا ہوا،\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxc{بیشک ہم نے تمہاری طرف ایک رسول بھیجے کہ تم پر حاضر ناظر ہیں جیسے ہم نے فرعون کی طرف رسول بھیجے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxci{تو فرعون نے اس رسول کا حکم نہ مانا تو ہم نے اسے سخت گرفت سے پکڑا،\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxcii{پھر کیسے بچو گے اگر کفر کرو اس دن جو بچوں کو بوڑھا کردے گا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxciii{آسمان اس کے صدمے سے پھٹ جائے گا، اللہ کا وعدہ ہوکر رہنا،\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxciv{بیشک یہ نصیحت ہے، تو جو چاہے اپنے رب کی طرف راہ لے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxcv{بیشک تمہارا رب جانتا ہے کہ تم قیام کرتے ہو کبھی دو تہائی رات کے قریب، کبھی آدمی رات، کبھی تہائی اور ایک جماعت تمہارے ساتھ والی اور اللہ رات اور دن کا اندازہ فرماتا ہے، اسے معلوم ہے کہ اے مسلمانو! تم سے رات کا شمار نہ ہوسکے گا تو اس نے اپنی مہر سے تم پر رجوع فرمائی اب قرآن میں سے جتنا تم پر آسان ہو اتنا پڑھو اسے معلوم ہے کہ عنقریب کچھ تم میں سے بیمار ہوں گے اور کچھ زمین میں سفر کریں گے اللہ کا فضل تلاش کرنے اور کچھ اللہ کی راہ میں لڑتے ہوں گے تو جتنا قرآن میسر ہو پڑھو اور نماز قائم رکھو اور زکوٰة دو اور اللہ کو اچھا قرض دو اور اپنے لیے جو بھلائی آگے بھیجو گے اسے اللہ کے پاس بہتر اور بڑے ثواب کی پاؤ گے، اور اللہ سے بخشش مانگو، بیشک اللہ بخشنے والا مہربان ہے،\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxcvi{\basmalahur اے بالا پوش اوڑھنے والے!\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxcvii{کھڑے ہوجاؤ پھر ڈر سناؤ\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxcviii{اور اپنے رب ہی کی بڑائی بولو\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxcix{اور اپنے کپڑے پاک رکھو\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmd{اور بتوں سے دور رہو،\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdi{اور زیادہ لینے کی نیت سے کسی پر احسان نہ کرو\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdii{اور اپنے رب کے لیے صبر کیے رہو\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdiii{پھر جب صور پھونکا جائے گا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdiv{تو وہ دن کڑا (سخت) دن ہے،\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdv{کافروں پر آسان نہیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdvi{اسے مجھ پر چھوڑ جسے میں نے اکیلا پیدا کیا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdvii{اور اسے وسیع مال دیا\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdviii{اور بیٹے دیے سامنے حاضر رہتے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdix{اور میں نے اس کے لیے طرح طرح کی تیاریاں کیں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdx{پھر یہ طمع کرتا ہے کہ میں اور زیادہ دوں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxi{ہرگز نہیں وہ تو میری آیتوں سے عناد رکھتا ہے،\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxii{قریب ہے کہ میں اسے آگ کے پہاڑ صعود پر چڑھاؤں،\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxiii{بیشک وہ سوچا اور دل میں کچھ بات ٹھہرائی\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxiv{تو اس پر لعنت ہو کیسی ٹھہرائی،\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxv{پھر اس پر لعنت ہو کیسی ٹھہرائی،\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxvi{پھر نظر اٹھا کر دیکھا،\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxvii{پھر تیوری چڑھائی اور منہ بگاڑا،\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxviii{پھر پیٹھ پھیری اور تکبر کیا،\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxix{پھر بولا یہ تو وہی جادو ہے اگلوں سے سیکھا،\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxx{یہ نہیں مگر آدمی کا کلام\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxi{کوئی دم جاتا ہے کہ میں اسے دوزخ میں دھنساتا ہوں،\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxii{اور تم نے کیا جانا دوزخ کیا ہے،\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxiii{نہ چھوڑے نہ لگی رکھے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxiv{آدمی کی کھال اتار لیتی ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxv{اس پر اُنیس داروغہ ہیں\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxvi{اور ہم نے دوزخ کے داروغہ نہ کیے مگر فرشتے، اور ہم نے ان کی یہ گنتی نہ رکھی مگر کافروں کی جانچ کو اس لیے کہ کتاب والوں کو یقین آئے اور ایمان والوں کا ایمان بڑھے اور کتاب والوں اور مسلمانوں کو کوئی شک نہ رہے اور دل کے روگی (مریض) اور کافر کہیں اس اچنبھے کی بات میں اللہ کا کیا مطلب ہے، یونہی اللہ گمراہ کرتا ہے جسے چاہے اور ہدایت فرماتا ہے جسے چاہے، اور تمہارے رب کے لشکروں کو اس کے سوا کوئی نہیں جانتا، اور وہ تو نہیں مگر آدمی کے لیے نصیحت،\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxvii{ہاں ہاں چاند کی قسم،\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxviii{اور رات کی جب پیٹھ پھیرے،\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxix{اور صبح کی جب اجا لا ڈالے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxx{بیشک دوزخ بہت بڑی چیزوں میں کی ایک ہے،\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxi{آدمیوں کو ڈراؤ،\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxii{اسے جو تم میں چاہے، کہ آگے آئے یا پیچھے رہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxiii{ہر جان اپنی کرنی (اعمال) میں گروی ہے،\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxiv{مگر دہنی طرف والے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxv{باغوں میں پوچھتے ہیں،\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxvi{مجرموں سے،\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxvii{تمہیں کیا بات دوزخ میں لے گئی،\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxviii{وہ بولے ہم نماز نہ پڑھتے تھے،\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxix{اور مسکین کو کھانا نہ دیتے تھے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxl{اور بیہودہ فکر والوں کے ساتھ بیہودہ فکریں کرتے تھے،\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxli{اور ہم انصاف کے دن کو جھٹلاتے رہے،\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxlii{یہاں تک کہ ہمیں موت آئی،\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxliii{تو انہیں سفارشیوں کی سفارش کام نہ دے گی\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxliv{تو انہیں کیا ہوا نصیحت سے منہ پھیرتے ہیں\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxlv{گویا وہ بھڑکے ہوئے گدھے ہوں،\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxlvi{کہ شیر سے بھاگے ہوں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxlvii{بلکہ ان میں کا ہر شخص چاہتا ہے کہ کھلے صحیفے اس کے ہاتھ میں دے دیے جائیں\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxlviii{ہرگز نہیں بلکہ ان کو آخرت کا ڈر نہیں\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxlix{ہاں ہاں بیشک وہ نصیحت ہے،\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmmdl{تو جو چاہے اس سے نصیحت لے،\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmmdli{اور وہ کیا نصیحت مانیں مگر جب اللہ چاہے، وہی ہے ڈرنے کے لائق اور اسی کی شان ہے مغفرت فرمانا،\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlii{\basmalahur روزِ قیامت کی قسم! یاد فرماتا ہوں،\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdliii{اور اس جان کی قسم! جو اپنے اوپر ملامت کرے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdliv{کیا آدمی یہ سمجھتا ہے کہ ہم ہرگز اس کی ہڈیاں جمع نہ فرمائیں گے،\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlv{کیوں نہیں ہم قادر ہیں کہ اس کے پور ٹھیک بنادیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlvi{بلکہ آدمی چاہتا ہے کہ اس کی نگاہ کے سامنے بدی کرے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlvii{پوچھتا ہے قیامت کا دن کب ہوگا،\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlviii{پھر جس دن آنکھ چوندھیائے گی\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlix{اور چاند کہے گا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlx{اور سورج اور چاند ملادیے جائیں گے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxi{اس دن آدمی کہے گا کدھر بھاگ کر جاؤں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxii{ہرگز نہیں کوئی پناہ نہیں،\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxiii{اس دن تیرے رب ہی کی طرف جاکر ٹھہرنا ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxiv{اس دن آدمی کو اس کا سب اگلا پچھلا جتادیا جائے گا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxv{بلکہ آدمی خود ہی اپنے حال پر پوری نگاہ رکھتا ہے،\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxvi{اور اگر اس کے پاس جتنے بہانے ہوں سب لا ڈالے،\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxvii{جب بھی نہ سنا جائے گا تم یاد کرنے کی جلدی میں قرآن کے ساتھ اپنی زبان کو حرکت نہ دو\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxviii{بیشک اس کا محفوظ کرنا اور پڑھنا ہمارے ذمہ ہے،\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxix{تو جب ہم اسے پڑھ چکیں اس وقت اس پڑھے ہوئے کی اتباع کرو\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxx{پھر بیشک اس کی باریکیوں کا تم پر ظاہر فرمانا ہمارے ذمہ ہے،\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxi{کوئی نہیں بلکہ اے کافرو! تم پاؤں تلے کی (دنیاوی فائدے کو) عزیز دوست رکھتے ہو\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxii{اور آخرت کو چھوڑ بیٹھے ہو،\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxiii{کچھ منہ اس دن تر و تازہ ہوں گے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxiv{اپنے رب کا دیکھتے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxv{اور کچھ منہ اس دن بگڑے ہوئے ہوں گے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxvi{سمجھتے ہوں گے کہ ان کے ساتھ وہ کی جائے گی جو کمر کو توڑ دے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxvii{ہاں ہاں جب جان گلے کو پہنچ جائے گی\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxviii{اور کہیں گے کہ ہے کوئی جھاڑ پھونک کرے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxix{سمجھ لے گا کہ یہ جدائی کی گھڑی ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxx{اور پنڈلی سے پنڈلی لپٹ جائے گی\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxi{اس دن تیرے رب ہی کی طرف ہانکنا ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxii{اس نے نہ تو سچ مانا اور نہ نماز پڑھی،\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxiii{ہاں جھٹلایا اور منہ پھیرا\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxiv{پھر اپنے گھر کو اکڑتا چلا\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxv{تیری خرابی ا ٓ لگی اب آ لگی،\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxvi{پھر تیری خرابی آ لگی اب آ لگی،\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxvii{کیا آدمی اس گھمنڈ میں ہے کہ آزاد چھوڑ دیا جائے گا\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxviii{کیا وہ ایک بوند نہ تھا اس منی کا کہ گرائی جائے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxix{پھر خون کی پھٹک ہوا تو اس نے پیدا فرمایا پھر ٹھیک بنایا\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxc{تو اس سے دو جوڑ بنائے مرد اور عورت،\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxci{کیا جس نے یہ کچھ کیا وہ مردے نہ جِلا سکے گا،\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxcii{\basmalahur بیشک آدمی پر ایک وقت وہ گزرا کہ کہیں اس کا نام بھی نہ تھا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxciii{بیشک ہم نے آدمی کو کیا ملی ہوئی منی سے کہ وہ اسے جانچیں تو اسے سنتا دیکھتا کردیا\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxciv{بیشک ہم نے اسے راہ بتائی یا حق مانتا یا ناشکری کرتا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxcv{بیشک ہم نے کافروں کے لیے تیار کر رکھی ہیں زنجیریں اور طوق اور بھڑکتی آگ\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxcvi{بیشک نیک پئیں گے اس جام میں سے جس کی ملونی کافور ہے وہ کافور کیا ایک چشمہ ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxcvii{جس میں سے اللہ کے نہایت خاص بندے پئیں گے اپنے محلوں میں اسے جہاں چاہیں بہا کر لے جائیں گے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxcviii{اپنی منتیں پوری کرتے ہیں اور اس دن سے ڈرتے ہیں جس کی برائی پھیلی ہوئی ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxcix{اور کھانا کھلاتے ہیں اس کی محبت پر مسکین اور یتیم اور اسیر کو،\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdc{ان سے کہتے ہیں ہم تمہیں خاص اللہ کے لیے کھانا دیتےہیں تم سے کوئی بدلہ یا شکر گزاری نہیں مانگتے،\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdci{بیشک ہمیں اپنے رب سے ایک ایسے دن کا ڈر ہے جو بہت ترش نہایت سخت ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcii{تو انہیں اللہ نے اس دن کے شر سے بچالیا اور انہیں تازگی اور شادمانی دی،\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdciii{اور ان کے صبر پر انہیں جنت اور ریشمی کپڑے صلہ میں دیے،\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdciv{جنت میں تختوں پر تکیہ لگائے ہوں گے، نہ اس میں دھوپ دیکھیں گے نہ ٹھٹر (سخت سردی)\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcv{اور اس کے سائے ان پر جھکے ہوں گے اور اس کے گچھے جھکا کر نیچے کردیے گئے ہوں گے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcvi{اور ان پر چاندی کے برتنوں اور کوزوں کا دور ہوگا جو شیشے کے مثل ہورہے ہوں گے،\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcvii{کیسے شیشے چاندی کے ساقیوں نے انہیں پورے اندازہ پر رکھا ہوگا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcviii{اور اس میں وہ جام پلائے جائیں گے جس کی ملونی ادرک ہوگی\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcix{وہ ادرک کیا ہے جنت میں ایک چشمہ ہے جسے سلسبیل کہتے ہیں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcx{اور ان کے آس پاس خدمت میں پھریں گے ہمیشہ رہنے والے لڑکے جب تو انہیں دیکھے تو انہیں سمجھے کہ موتی ہیں بکھیرے ہوئے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxi{اور جب تو ادھر نظر اٹھائے ایک چین دیکھے اور بڑی سلطنت\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxii{ان کے بدن پر ہیں کریب کے سبز کپڑے اور قنا ویز کے اور انہیں چاندی کے کنگن پہنائے گئے اور انہیں ان کے رب نے ستھری شراب پلائی\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxiii{ان سے فرمایا جائے گا یہ تمہارا صلہ ہے اور تمہاری محنت ٹھکانے لگی\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxiv{بیشک ہم نے تم پر قرآن بتدریج اتارا\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxv{تو اپنے رب کے حکم پر صابر رہو اور ان میں کسی گنہگار یا ناشکرے کی بات نہ سنو\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxvi{اور اپنے رب کا نام صبح و شام یاد کرو\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxvii{اور کچھ میں اسے سجدہ کرو اور بڑی رات تک اس کی پاکی بولو\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxviii{بیشک یہ لوگ پاؤں تلے کی (دنیاوی فائدے کو) عزیز رکھتے ہیں اور اپنے پیچھے ایک بھاری دن کو چھوڑ بیٹھے ہیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxix{ہم نے انہیں پیدا کیا اور ان کے جوڑ بند مضبوط کیے اور ہم جب چاہیں ان جیسے اور بدل دیں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxx{بیشک یہ نصیحت ہے تو جو چاہے اپنے رب کی طرف راہ لے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxi{اور تم کیا چاہو مگر یہ کہ اللہ چاہے بیشک وہ علم و حکمت والا ہے،\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxii{اپنی رحمت میں لیتا ہے جسے چاہے اور ظالموں کے لیے اس نے دردناک عذاب تیار کر رکھا ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxiii{\basmalahur قسم ان کی جو بھیجی جاتی ہیں لگاتار\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxiv{پھر زور سے جھونکا دینے والیاں،\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxv{پھر ابھار کر اٹھانے والیاں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxvi{پھر حق ناحق کو خوب جدا کرنے والیاں،\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxvii{پھر ان کی قسم جو ذکر کا لقا کرتی ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxviii{حجت تمام کرنے یا ڈرانے کو،\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxix{بیشک جس بات کا تم وعدہ دیے جاتے ہو ضرور ہونی ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxx{پھر جب تارے محو کردیے جائیں،\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxi{اور جب آسمان میں رخنے پڑیں،\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxii{اور جب پہاڑ غبار کرکے اڑا دیے جا ئیں،\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxiii{اور جب رسولوں کا وقت آئے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxiv{کس دن کے لیے ٹھہرائے گئے تھے،\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxv{روز فیصلہ کے لیے،\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxvi{اور تو کیا جانے وہ روز فیصلہ کیا ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxvii{جھٹلانے والوں کی اس دن خرابی\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxviii{کیا ہم نے اگلوں کو ہلاک نہ فرمایا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxix{پھر پچھلوں کو ان کے پیچھے پہنچائیں گے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxl{مجرموں کے ساتھ ہم ایسا ہی کرتے ہیں،\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxli{اس دن جھٹلانے والوں کی خرابی،\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxlii{کیا ہم نے تمہیں ایک بے قدر پانی سے پیدا نہ فرمایا\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxliii{پھر اسے ایک محفوظ جگہ میں رکھا\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxliv{ایک معلوم اندازہ تک\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxlv{پھر ہم نے اندازہ فرمایا، تو ہم کیا ہی اچھے قادر\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxlvi{اس دن جھٹلانے والوں کی خرابی،\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxlvii{کیا ہم نے زمین کو جمع کرنے والی نہ کیا،\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxlviii{تمہارے زندوں اور مردوں کی\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxlix{اور ہم نے اس میں اونچے اونچے لنگر ڈالے اور ہم نے تمہیں خوب میٹھا پانی پلایا\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcl{اس دن جھٹلانے والوں کی خرابی\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcli{چلو اس کی طرف جسے جھٹلاتے تھے،\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclii{چلو اس دھوئیں کے سائے کی طرف جس کی تین شاخیں\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcliii{نہ سایہ دے نہ لپٹ سے بچائے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcliv{بیشک دوزخ چنگاریاں اڑاتی ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclv{جیسے اونچے محل گویا وہ زرد رنگ کے اونٹ ہیں،\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclvi{اس دن جھٹلانے والوں کی خرابی،\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclvii{یہ دن ہے کہ وہ بول نہ سکیں گے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclviii{اور نہ انہیں اجازت ملے کہ عذر کریں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclix{اس دن جھٹلانے والوں کی خرابی،\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclx{یہ ہے فیصلہ کا دن، ہم نے تمہیں جمع کیا اور سب اگلوں کو\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxi{اب اگر تمہارا کوئی داؤ ہو تو مجھ پر چل لو\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxii{اس دن جھٹلانے والوں کی خرابی،\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxiii{بیشک ڈر والے سایوں اور چشموں میں ہیں،\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxiv{اور میووں میں جو ان کا جی چاہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxv{کھاؤ اور پیو رچتا ہوا اپنے اعمال کا صلہ\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxvi{بیشک نیکوں کو ہم ایسا ہی بدلہ دیتے ہیں،\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxvii{اس دن جھٹلانے والوں کی خرابی\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxviii{کچھ دن کھالو اور برت لو ضرور تم مجرم ہو\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxix{اس دن جھٹلانے والوں کی خرابی،\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxx{اور جب ان سے کہا جائے کہ نماز پڑھو تو نہیں پڑھتے،\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxi{اس دن جھٹلانے والوں کی خرابی،\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxii{پھر اس کے بعد کون سی بات پر ایمان لائیں گے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxiii{\basmalahur یہ آپس میں کاہے کی پوچھ گچھ کررہے ہیں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxiv{بڑی خبر کی\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxv{جس میں وہ کئی راہ ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxvi{ہاں ہاں اب جائیں گے،\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxvii{پھر ہاں ہاں جان جائیں گے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxviii{کیا ہم نے زمین کو بچھونا نہ کیا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxix{اور پہاڑوں کو میخیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxx{اور تمہیں جوڑے بنایا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxi{اور تمہاری نیند کو آرام کیا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxii{اور رات کو پردہ پوش کیا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxiii{اور دن کو روزگار کے لیے بنایا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxiv{اور تمہارے اوپر سات مضبوط چنائیاں چنیں (تعمیر کیں)\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxv{اور ان میں ایک نہایت چمکتا چراغ رکھا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxvi{اور پھر بدلیوں سے زور کا پانی اتارا،\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxvii{کہ اس سے پیدا فرمائیں اناج اور سبزہ،\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxviii{اور گھنے باغ\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxix{بیشک فیصلہ کا دن ٹھہرا ہوا وقت ہے،\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxc{جس دن صور پھونکا جائے گا تو تم چلے آؤ گے فوجوں کی فوجیں،\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxci{اور آسمان کھولا جائے گا کہ دروازے ہوجائے گا\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxcii{اور پہاڑ چلائے جائیں گے کہ ہوجائیں گے جیسے چمکتا ریتا دور سے پانی کا دھوکا دیتا،\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxciii{بیشک جہنم تاک میں ہے،\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxciv{سرکشوں کا ٹھکانا،\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxcv{اس میں قرنوں (مدتوں) رہیں گے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxcvi{اس میں کسی طرح کی ٹھنڈک کا مزہ نہ پائیں گے اور نہ کچھ پینے کو،\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxcvii{مگر کھولتا پانی اور دوزخیوں کا جلتا پیپ،\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxcviii{جیسے کو تیسا بدلہ\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxcix{بیشک انہیں حساب کا خوف نہ تھا\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcc{اور انہوں نے ہماری آیتیں حد بھر جھٹلائیں،\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcci{اور ہم نے ہر چیز لکھ کر شمار کر رکھی ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccii{اب چکھو کہ ہم تمہیں نہ بڑھائیں گے مگر عذاب،\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcciii{بیشک ڈر والوں کو کامیابی کی جگہ ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcciv{باغ ہیں اور انگور،\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccv{اور اٹھتے جوبن والیاں ایک عمر کی،\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccvi{اور چھلکتا جام\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccvii{جس میں نہ کوئی بیہودہ بات سنیں نہ جھٹلانا\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccviii{صلہ تمہارے رب کی طرف سے نہایت کافی عطا،\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccix{وہ جو رب ہے آسمانوں کا اور زمین کا اور جو کچھ ان کے درمیان ہے رحمن کہ اس سے بات کرنے کا اختیار نہ رکھیں گے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccx{جس دن جبریل کھڑا ہوگا اور سب فرشتے پرا باندھے (صفیں بنائے) کوئی نہ بول سکے گا مگر جسے رحمن نے اذن دیا اور اس نے ٹھیک بات کہی\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxi{وہ سچا دن ہے اب جو چاہے اپنے رب کی طرف راہ بنالے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxii{ہم تمہیں ایک عذاب سے ڈراتے ہیں کہ نزدیک آگیا جس دن آدمی دیکھے گا جو کچھ اس کے ہاتھوں نے آگے بھیجا اور کافر کہے گا ہائے میں کسی طرح خاک ہوجاتا\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxiii{\basmalahur قسم ان کی کہ سختی سے جان کھینچیں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxiv{اور نرمی سے بند کھولیں)\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxv{اور آسانی سے پیریں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxvi{پھر آگے بڑھ کر جلد پہنچیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxvii{پھر کام کی تدبیر کریں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxviii{کہ کافروں پر ضرور عذاب ہوگا جس دن تھر تھرائے گی تھرتھرانے والی\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxix{اس کے پیچھے آئے گی پیچھے آنے والی\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxx{کتنے دل اس دن دھڑکتے ہوں گے،\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxi{آنکھ اوپر نہ اٹھا سکیں گے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxii{کافر کہتے ہیں کیا ہم پھر الٹے پاؤں پلٹیں گے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxiii{کیا ہم جب گلی ہڈیاں ہوجائیں گے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxiv{بولے یوں تو یہ پلٹنا تو نرا نقصان ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxv{تو وہ نہیں مگر ایک جھڑکی\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxvi{جبھی وہ کھلے میدان میں آپڑے ہوں گے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxvii{کیا تمہیں موسیٰ کی خبر آئی\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxviii{جب اسے اس کے رب نے پاک جنگل طویٰ میں ندا فرمائی،\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxix{کہ فرعون کے پاس جا اس نے سر اٹھایا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxx{اس سے کہہ کیا تجھے رغبت اس طرف ہے کہ ستھرا ہو\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxi{اور تجھے تیرے رب کی طرف راہ بتاؤں کہ تو ڈرے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxii{پھر موسیٰ نے اسے بہت بڑی نشانی دکھائی\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxiii{اس پر اس نے جھٹلایا اور نافرمانی کی،\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxiv{پھر پیٹھ دی اپنی کوشش میں لگا\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxv{تو لوگوں کو جمع کیا پھر پکارا،\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxvi{پھر بولا میں تمہارا سب سے اونچا رب ہوں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxvii{تو اللہ نے اسے دنیا و آخرت دونوں کے عذاب میں پکڑا\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxviii{بیشک اس میں سیکھ ملتا ہے اسے جو ڈرے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxix{کیا تمہاری سمجھ کے مطابق تمہارا بنانا مشکل یا آسمان کا اللہ نے اسے بنایا،\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxl{اس کی چھت اونچی کی پھر اسے ٹھیک کیا\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxli{اس کی رات اندھیری کی اور اس کی روشنی چمکائی\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxlii{اور اس کے بعد زمین پھیلائی\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxliii{اس میں سے اس کا پانی اور چارہ نکا لا\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxliv{اور پہاڑوں کو جمایا\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxlv{تمہارے اور تمہارے چوپایوں کے فائدہ کو،\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxlvi{پھر جب آئے گی وہ عام مصیبت سب سے بڑی\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxlvii{اس دن آدمی یاد کرے گا جو کوشش کی تھی\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxlviii{اور جہنم ہر دیکھنے والے پر ظاہر کی جائے گی\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxlix{تو وہ جس نے سرکشی کی\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccl{اور دنیا کی زندگی کو ترجیح دی\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccli{تو بیشک جہنم ہی اس کا ٹھکانا ہے،\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclii{اور وہ جو اپنے رب کے حضور کھڑے ہونے سے ڈرا اور نفس کو خواہش سے روکا\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccliii{تو بیشک جنت ہی ٹھکانا ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccliv{تم سے قیامت کو پوچھتے ہیں کہ وہ کب کے لیے ٹھہری ہوئی ہے،\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclv{تمہیں اس کے بیان سے کیا تعلق\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclvi{تمہارے رب ہی تک اس کی انتہا ہے،\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclvii{تم تو فقط اسے ڈرا نے والے ہو جو اس سے ڈرے،\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclviii{گویا جس دن وہ اسے دیکھیں گے دنیا میں نہ رہے تھے مگر ایک شام یا اس کے دن چڑھے،\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclix{\basmalahur تیوری چڑھائی اور منہ پھیرا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclx{اس پر کہ اس کے پاس وہ نابینا حاضر ہوا\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxi{اور تمہیں کیا معلوم شاید وہ ستھرا ہو\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxii{یا نصیحت لے تو اسے نصیحت فائدہ دے،\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxiii{وہ جو بے پرواہ بنتا ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxiv{تم اس کے تو پیچھے پڑتے ہو\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxv{اور تمہارا کچھ زیاں نہیں اس میں کہ وہ ستھرا نہ ہو\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxvi{اور وہ جو تمہارے حضور ملکتا (ناز سے دوڑتا ہوا) آتا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxvii{اور وہ ڈر رہا ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxviii{تو اسے چھوڑ کر اور طرف مشغول ہوتے ہو،\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxix{یوں نہیں یہ تو سمجھانا ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxx{تو جو چاہے اسے یا د کرے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxi{ان صحیفوں میں کہ عزت والے ہیں\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxii{بلندی والے پاکی والے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxiii{ایسوں کے ہاتھ لکھے ہوئے،\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxiv{جو کرم والے نکوئی والے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxv{آدمی مارا جائیو کیا ناشکر ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxvi{اسے کاہے سے بنایا،\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxvii{پانی کی بوند سے اسے پیدا فرمایا، پھر اسے طرح طرح کے اندازوں پر رکھا\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxviii{پھر اسے راستہ آسان کیا\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxix{پھر اسے موت دی پھر قبر میں رکھوایا\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxx{پھر جب چاہا اسے باہر نکالا\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxi{کوئی نہیں، اس نے اب تک پورا نہ کیا جو اسے حکم ہوا تھا\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxii{تو آدمی کو چاہیے اپنے کھانوں کو دیکھے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxiii{کہ ہم نے اچھی طرح پانی ڈالا\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxiv{پھر زمین کو خوب چیرا،\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxv{تو اس میں اُگایا اناج،\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxvi{اور انگور اور چارہ،\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxvii{اور زیتون اور کھجور،\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxviii{اور گھنے باغیچے،\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxix{اور میوے اور دُوب (گھاس)\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxc{تمہارے فائدے کو اور تمہارے چوپایوں کے،\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxci{پھر جب آئے گی وہ کان پھاڑنے والی چنگھاڑ\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxcii{اس دن آدمی بھاگے گا اپنے بھائی،\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxciii{اور ماں اور باپ،\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxciv{اور جُورو اور بیٹوں سے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxcv{ان میں سے ہر ایک کو اس دن ایک فکر ہے کہ وہی اسے بس ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxcvi{کتنے منہ اس دن روشن ہوں گے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxcvii{ہنستے خوشیاں مناتے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxcviii{اور کتنے مونہوں پر اس دن گرد پڑی ہوگی،\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxcix{ان پر سیاہی چڑھ رہی ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccc{یہ وہی ہیں کافر بدکار،\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccci{\basmalahur جب دھوپ لپیٹی جائے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccii{اور جب تارے جھڑ پڑیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccciii{اور جب پہاڑ چلائے جائیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccciv{اور جب تھلکی (گابھن) اونٹنیاں چھوٹی پھریں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccv{اور جب وحشی جانور جمع کیے جائیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccvi{اور جب سمندر سلگائے جائیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccvii{اور جب جانوں کے جوڑ بنیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccviii{اور جب زندہ دبائی ہوئی سے پوچھا جائے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccix{کس خطا پر ماری گئی\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccx{اور جب نامہٴ اعمال کھولے جائیں،\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxi{اور جب آسمان جگہ سے کھینچ لیا جائے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxii{اور جب جہنم بھڑکایا جائے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxiii{اور جب جنت پاس لائی جائے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxiv{ہر جان کو معلوم ہوجائے گا جو حاضر لائی\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxv{تو قسم ہے ان کی جو الٹے پھریں،\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxvi{سیدھے چلیں تھم رہیں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxvii{اور رات کی جب پیٹھ دے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxviii{اور صبح کی جب دم لے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxix{بیشک یہ عزت والے رسول کا پڑھنا ہے،\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxx{جو قوت والا ہے مالک عرش کے حضور عزت والا وہاں اس کا حکم مانا جاتا ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxi{امانت دار ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxii{اور تمہارے صاحب مجنون نہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxiii{اور بیشک انہوں نے اسے روشن کنارہ پر دیکھا\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxiv{اور یہ نبی غیب بتانے میں بخیل نہیں،\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxv{اور قرآن، مردود شیطان کا پڑھا ہوا نہیں،\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxvi{پھر کدھر جاتے ہو\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxvii{وہ تو نصیحت ہی ہے سارے جہان کے لیے،\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxviii{اس کے لیے جو تم میں سیدھا ہونا چاہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxix{اور تم کیا چا ہو مگر یہ کہ چاہے اللہ سارے جہان کا رب،\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxx{\basmalahur جب آسمان پھٹ پڑے،\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxi{اور جب تارے جھڑ پڑیں،\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxii{اور جب سمندر بہادیے جائیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxiii{اور جب قبریں کریدی جائیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxiv{ہر جان، جان لے گی جو اس نے آگے بھیجا اور جو پیچھے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxv{اے آدمی! تجھے کس چیز نے فریب دیا اپنے کرم والے رب سے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxvi{جس نے تجھے پیدا کیا پھر ٹھیک بنایا پھر ہموار فرمایا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxvii{جس صورت میں چاہا تجھے ترکیب دیا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxviii{کوئی نہیں بلکہ تم انصاف ہونے کو جھٹلانتے ہو\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxix{اور بیشک تم پر کچھ نگہبان ہیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxl{معزز لکھنے والے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxli{جانتے ہیں جو کچھ تم کرو\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxlii{بیشک نِکو کار ضرور چین میں ہیں\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxliii{اور بیشک بدکار ضرور دوزخ میں ہیں،\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxliv{انصاف کے دن اس میں جائیں گے،\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxlv{اور اس سے کہیں چھپ نہ سکیں گے،\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxlvi{اور تو کیا جانیں کیسا انصاف کا دن،\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxlvii{پھر تو کیا جانے کیسا انصاف کا دن،\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxlviii{جس دن کوئی جان کسی جان کا کچھ اختیار نہ رکھے گی اور سارا حکم اس دن اللہ کا ہے،\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxlix{\basmalahur کم تولنے والوں کی خرابی ہے،\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccl{وہ کہ جب اوروں سے ناپ لیں پورا لیں،\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccli{اور جب انہیں ناپ تول کردی کم کردیں،\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclii{کیا ان لوگوں کو گمان نہیں کہ انہیں اٹھنا ہے،\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccliii{ایک عظمت والے دن کے لیے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccliv{جس دن سب لوگ رب العالمین کے حضور کھڑے ہوں گے،\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclv{بیشک کافروں کی لکھت سب سے نیچی جگہ سجین میں ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclvi{اور تو کیا جانے سجین کیسی ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclvii{وہ لکھت ایک مہر کیا نوشتہ ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclviii{اس دن جھٹلانے والوں کی خرابی ہے،\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclix{جو انصاف کے دن کو جھٹلاتے ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclx{اور اسے نہ جھٹلائے گا مگر ہر سرکش\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxi{جب اس پر ہماری آیتیں پڑھی جائیں کہے اگلوں کی کہانیاں ہیں،\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxii{کوئی نہیں بلکہ ان کے دلوں پر زنگ چڑھادیا ہے ان کی کمائیوں نے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxiii{ہاں ہاں بیشک وہ اس دن اپنے رب کے دیدار سے محروم ہیں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxiv{پھر بیشک انہیں جہنم میں داخل ہونا،\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxv{پھر کہا جائے گا، یہ ہے وہ جسے تم جھٹلاتے تھے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxvi{ہاں ہاں بیشک نیکوں کی لکھت سب سے اونچا محل علیین میں ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxvii{اور تو کیا جانے علیین کیسی ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxviii{وہ لکھت ایک مہر کیا نوشتہ ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxix{کہ مقرب جس کی زیارت کرتے ہیں،\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxx{بیشک نیکوکار ضرور چین میں ہیں،\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxi{تختوں پر دیکھتے ہیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxii{تو ان کے چہروں میں چین کی تازگی پہنچانے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxiii{نتھری شراب پلائے جائیں گے جو مہُر کی ہوئی رکھی ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxiv{اس کی مہُر مشک پر ہے، اور اسی پر چاہیے کہ للچائیں للچانے والے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxv{اور اس کی ملونی تسنیم سے ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxvi{وہ چشمہ جس سے مقربانِ بارگاہ پیتے ہیں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxvii{بیشک مجرم لوگ ایمان والوں سے ہنسا کرتے تھے،\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxviii{اور جب وہ ان پر گزرتے تو یہ آپس میں ان پر آنکھوں سے اشارے کرتے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxix{اور جب (ف۹۳۳ اپنے گھر پلٹتے خوشیاں کرتے پلٹتے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxx{اور جب مسلمانوں کو دیکھتے کہتے بیشک یہ لوگ بہکے ہوئے ہیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxi{اور یہ کچھ ان پر نگہبان بناکر نہ بھیجے گئے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxii{تو آج ایمان والے کافروں سے ہنستے ہیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxiii{تختوں پر بیٹھے دیکھتے ہیں\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxiv{کیوں کچھ بدلا ملا کافروں کو اپنے کیے کا\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxv{\basmalahur جب آسمان شق ہو\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxvi{اور اپنے رب کا حکم سنے اور اسے سزاوار ہی یہ ہے،\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxvii{اور جب زمین دراز کی جائے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxviii{اور جو کچھ اس میں ہے ڈال دے اور خالی ہوجائے،\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxix{اور اپنے رب کا حکم سنے اور اسے سزاوار ہی یہ ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxc{اے آدمی! بیشک تجھے اپنے رب کی طرف ضرور دوڑنا ہے پھر اس سے ملنا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxci{تو وہ وہ اپنا نامہٴ اعمال دہنے ہاتھ میں دیا جائے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxcii{اس سے عنقریب سہل حساب لیا جائے گا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxciii{اور اپنے گھر والوں کی طرف شاد شاد پلٹے گا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxciv{اور وہ جس کا نامہٴ اعمال اس کی پیٹھ کے پیچھے دیا جائے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxcv{وہ عنقریب موت مانگے گا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxcvi{اور بھڑکتی ا ٓ گ میں جائے گا،\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxcvii{بیشک وہ اپنے گھر میں خوش تھا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxcviii{وہ سمجھا کہ اسے پھرنا نہیں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxcix{ہاں کیوں نہیں بیشک اس کا رب اسے دیکھ رہا ہے،\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcm{تو مجھے قسم ہے شام کے اجالے کی\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmi{اور رات کی اور جو چیزیں اس میں جمع ہوتی ہیں\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmii{اور چاند کی جب پورا ہو\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmiii{ضرور تم منزل بہ منزل چڑھو گے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmiv{تو کیا ہوا انہیں ایمان نہیں لاتے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmv{اور جب قرآن پڑھا جائے سجدہ نہیں کرتے السجدة ۔۱۳\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmvi{بلکہ کافر جھٹلا رہے ہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmvii{اور اللہ خوب جانتا ہے جو اپنے جی میں رکھتے ہیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmviii{تو تم انہیں دردناک عذاب کی بشارت دو\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmix{مگر جو ایمان لائے اور اچھے کام کیے ان کے لیے وہ ثواب ہے جو کبھی ختم نہ ہوگا،\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmx{\basmalahur قسم آسمان کی، جس میں برج ہیں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxi{اور اس دن کی جس کا وعدہ ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxii{اور اس دن کی جو گواہ ہے اور اس دن کی جس میں حاضر ہوتے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxiii{کھائی والوں پر لعنت ہو\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxiv{اس بھڑکتی آ گ والے،\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxv{جب وہ اس کے کناروں پر بیٹھے تھے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxvi{اور وه خد گواه ہیں جو کہ مسلما نوں کے ساتھ کر رہے تھے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxvii{اور انھیں مسلمانوں کا کیا برا لگا یہی نہ کے وہ ایمان لا ئے اللہ والے سب خو بیوں سرا ہے پر،\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxviii{کے اس کے لئے آسمانوں اور زمین کی سلطنت ہے اور اللہ ہر چیز پر گواه ہے،\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxix{بے شک جنھو ں نے ایذا دی مسلمان مردوں اور مسلمان عورتوں کو پھر تو بہ نہ کی ان کے لئے جہنم کا عذاب ہے اور ان کے لئے آگ کا عذاب\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxx{بے شک جو ایما ن لائے اور اچھے کام کئے ان کے لئے باغ ہیں جن کے نیچے نہریں رواں یہی بڑی کامیابی ہے،\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxi{بے شک تیرے رب کی گرفت بہت سخت ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxii{بے شک وه پہلے اور پھر کرے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxiii{اور وہی ہے بخشنے والا اپنے نیک بندوں پر پیارا،\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxiv{عزت والے عرش کا مالک،\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxv{ہمیشہ جو چاہے کہ لینے والا،\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxvi{کیا تمھارے پاس لشکروں کے بات آئی\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxvii{وه لشکر کون فرعون اور ثمود\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxviii{بلکہ کافر جھٹلا نے میں ہیں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxix{اور اللہ ان کے پیچھے سے انھیں گھیرے ہوئے ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxx{بلکہ وه کمال شرف والا قران ہے،\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxi{لو ح محفوظ میں،\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxii{\basmalahur آسمان کی قسم اور رات کے آنے والے کی، ف۲)\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxiii{اور کچھ تم نے جا نا وه رات کو آنے والا کیا ہے،\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxiv{خوب چمکتا تارا،\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxv{کوئی جان نہیں جس پر نگہبان نہ ہو\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxvi{تو چاہئے کہ آدمی غور کرے کہ کس چیز سے بنا یا گیا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxvii{جَست کرتے (اوچھلتے ہوئے) پانی سے، ف۵)\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxviii{جو نکلتا ہے پیٹھ اور سینوں کے بیچ سے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxix{بے شک اللہ اس کے واپس کرینے پر قادر ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxl{جس دن چھپی باتوں کی جانچ ہوگی\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxli{تو آدمی کے پاس نہ کچھ زور ہوگا نہ کوئی مددگار\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxlii{آسمان کی قسم! جس سے مینھ اترتا ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxliii{اور زمین کی جو اس سے کھلتی ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxliv{بیشک قرآن ضرور فیصلہ کی بات ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxlv{اور کوئی ہنسی کی بات نہیں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxlvi{بیشک کافر اپنا سا داؤ چلتے ہیں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxlvii{اور میں اپنی خفیہ تدبیر فرماتا ہوں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxlviii{تو تم کافروں کو ڈھیل دو انہیں کچھ تھوڑی مہلت دو\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxlix{\basmalahur اپنے رب کے نام کی پاکی بولو جب سے بلند ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcml{جس نے بناکر ٹھیک کیا\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmli{اور جس نے اندازہ پر رکھ کر راہ دی\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlii{اور جس نے چارہ نکالا،\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmliii{پھر اسے خشک سیاہ کردیا،\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmliv{اب ہم تمہیں پڑھائیں گے کہ تم نہ بھولو گے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlv{مگر جو اللہ چاہے بیشک وہ جانتا ہے ہر کھلے اور چھپے کو،\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlvi{اور ہم تمہارے لیے آسانی کا سامان کردیں گے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlvii{تو تم نصیحت فرماؤ اگر نصیحت کام دے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlviii{عنقریب نصیحت مانے گا جو ڈرتا ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlix{اور اس سے وہ بڑا بدبخت دور رہے گا،\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlx{جو سب سے بڑی آگ میں جائے گا\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxi{پھر نہ اس میں مرے اور نہ جیے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxii{بیشک مراد کو پہنچا جو ستھرا ہوا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxiii{اور اپنے رب کا نام لے کر نماز پڑھی\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxiv{بلکہ تم جیتی دنیا کو ترجیح دیتے ہو\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxv{اور آخرت بہتر اور باقی رہنے والی،\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxvi{بیشک یہ اگلے صحیفوں میں ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxvii{ابراہیم اور موسیٰ کے صحیفوں میں،\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxviii{\basmalahur بیشک تمہارے پاس اس مصیبت کی خبر آئی جو چھا جائے گی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxix{کتنے ہی منہ اس دن ذلیل ہوں گے،\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxx{کام کریں مشقت جھیلیں،\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxi{جائیں بھڑکتی آگ میں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxii{نہایت جلتے چشمہ کا پانی پلائے جائیں،\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxiii{ان کے لیے کچھ کھانا نہیں مگر آگ کے کانٹے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxiv{کہ نہ فربہی لائیں اور نہ بھوک میں کام دیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxv{کتنے ہی منہ اس دن چین میں ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxvi{اپنی کوشش پر راضی\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxvii{بلند باغ میں،\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxviii{کہ اس میں کوئی بیہودہ بات نہ سنیں گے،\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxix{اس میں رواں چشمہ ہے،\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxx{اس میں بلند تخت ہیں،\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxi{اور چنے ہوئے کوزے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxii{اور برابر برابر بچھے ہوئے قالین\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxiii{اور پھیلی ہوئی چاندنیاں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxiv{تو کیا اونٹ کو نہیں دیکھتے کیسا بنایا گیا،\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxv{اور آسمان کو کیسا اونچا کیا گیا\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxvi{اور پہاڑوں کو، کیسے قائم کیے گئے،\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxvii{اور زمین کو، کیسے بچھائی گئی،\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxviii{تو تم نصیحت سناؤ تم تو یہی نصیحت سنانے والے ہو،\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxix{تم کچھ ان پر کڑ وڑا (ضامن) نہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxc{ہاں جو منہ پھیرے اور کفر کرے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxci{تو اسے اللہ بڑا عذاب دے گا\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxcii{بیشک ہماری ہی طرف ان کا پھرنا\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxciii{پھر بیشک ہماری ہی طرف ان کا حساب ہے،\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxciv{\basmalahur اس صبح کی قسم\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxcv{اور دس راتوں کی\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxcvi{اور جفت اور طاق کی\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxcvii{اور رات کی جب چل دے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxcviii{کیوں اس میں عقلمند کے لیے قسم ہوئی\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxcix{کیا تم نے نہ دیکھا تمہارے رب نے عاد کے ساتھ کیسا کیا،\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmm{وہ اِرم حد سے زیادہ طول والے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmi{کہ اس جیسا شہروں میں پیدا نہ ہوا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmii{اور ثمود جنہوں نے وادی میں پتھر کی چٹانیں کاٹیں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmmiii{اور فرعون کہ چومیخا کرتا (سخت سزائیں دیتا)\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmmiv{جنہوں نے شہروں میں سرکشی کی\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmmv{پھر ان میں بہت فساد پھیلایا\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmmvi{تو ان پر تمہارے رب نے عذاب کا کوڑا بقوت مارا،\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmmvii{بیشک تمہارے رب کی نظر سے کچھ غائب نہیں،\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmmviii{لیکن آدمی تو جب اسے اس کا رب آزمائے کہ اس کو جاہ اور نعمت دے، جب تو کہتا ہے میرے رب نے مجھے عزت دی،\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmmix{اور اگر آزمائے اور اس کا رزق اس پر تنگ کرے، تو کہتا ہے میرے رب نے مجھے خوار کیا،\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmmx{یوں نہیں بلکہ تم یتیم کی عزت نہیں کرتے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxi{اور آپس میں ایک دوسرے کو مسکین کے کھلانے کی رغبت نہیں دیتے،\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxii{اور میراث کا مال ہپ ہپ کھاتے ہو\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxiii{اور مال کی نہایت محبت رکھتے ہو\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxiv{ہاں ہاں جب زمین ٹکرا کر پاش پاش کردی جائے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxv{اور تمہارے رب کا حکم آئے اور فرشتے قطار قطار،\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxvi{اور اس دن جہنم لائے جائے اس دن آدمی سوچے گا اور اب اسے سوچنے کا وقت کہاں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxvii{کہے گا ہائے کسی طرح میں نے جیتے جی نیکی آگے بھیجی ہوتی،\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxviii{تو اس دن اس کا سا عذاب کوئی نہیں کرتا،\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxix{اور اس کا سا باندھنا کوئی نہیں باندھتا،\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxx{اے اطمینان والی جان\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxi{اپنے رب کی طرف واپس ہو یوں کہ تو اس سے راضی وہ تجھ سے راضی،\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxii{پھر میرے خاص بندوں میں داخل ہو،\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxiii{اور میری جنت میں آ،\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxiv{\basmalahur مجھے اس شہر کی قسم\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxv{کہ اے محبوب! تم اس شہر میں تشریف فرما ہو\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxvi{اور تمہارے باپ ابراہیم کی قسم اور اس کی اولاد کی کہ تم ہو\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxvii{بیشک ہم نے آدمی کو مشقت میں رہتا پیدا کیا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxviii{کیا آدمی یہ سمجھتا ہے کہ ہرگز اس پر کوئی قدرت نہیں پائے گا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxix{کہتا ہے میں نے ڈھیروں مال فنا کردیا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxx{کیا آدمی یہ سمجھتا ہے کہ اسے کسی نے نہ دیکھا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxi{کیا ہم نے اس کی دو آنکھیں نہ بنائیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxii{اور زبان اور دو ہونٹ\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxiii{اور اسے دو ابھری چیزوں کی راہ بتائی\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxiv{پھر بے تامل گھاٹی میں نہ کودا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxv{اور تو نے کیا جانا وہ گھاٹی کیا ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxvi{کسی بندے کی گردن چھڑانا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxvii{یا بھوک کے دن کھانا دینا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxviii{رشتہ دار یتیم کو،\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxix{یا خاک نشین مسکین کو\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxl{پھر ہو ان سے جو ایمان لائے اور انہوں نے آپس میں صبر کی وصیتیں کیں اور آپس میں مہربانی کی وصیتیں کیں\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxli{یہ دہنی طرف والے ہیں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxlii{اور جنہوں نے ہماری آیتوں سے کفر کیا وہ بائیں طرف والے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxliii{ان پر آگ ہے کہ اس میں ڈال کر اوپر سے بند کردی گئی\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxliv{\basmalahur سورج اور اس کی روشنی کی قسم،\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxlv{اور چاند کی جب اس کے پیچھے آئے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxlvi{اور دن کی جب اسے چمکائے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxlvii{اور رات کی جب اسے چھپائے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxlviii{اور آسمان اور اس کے بنانے والے کی قسم،\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxlix{اور زمین اور اس کے پھیلانے والے کی قسم،\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmml{اور جان کی اور اس کی جس نے اسے ٹھیک بنایا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmli{پھر اس کی بدکاری اور اس کی پرہیزگاری دل میں ڈالی\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlii{بیشک مراد کو پہنچایا جس نے اسے ستھرا کیا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmmliii{اور نامراد ہوا جس نے اسے معصیت میں چھپایا،\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmmliv{ثمود نے اپنی سرکشی سے جھٹلایا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlv{جبکہ اس کا سب سے بدبخت اٹھ کھڑا ہوا،\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlvi{تو ان سے اللہ کے رسول نے فرمایا اللہ کے ناقہ اور اس کی پینے کی باری سے بچو\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlvii{تو انہوں نے اسے جھٹلایا پھر ناقہ کی کوچیں کاٹ دیں تو ان پر ان کے رب نے ان کے گناہ کے سبب تباہی ڈال کر وہ بستی برابر کردی\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlviii{اور اس کے پیچھا کرنے والے کا اسے خوف نہیں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlix{\basmalahur اور رات کی قسم جب چھائے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlx{اور دن کی جب چمکے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxi{اور اس کی جس نے نر و مادہ بنائے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxii{بیشک تمہاری کوشش مختلف ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxiii{تو وہ جس نے دیا اور پرہیزگاری کی\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxiv{اور سب سے اچھی کو سچ مانا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxv{تو بہت جلد ہم اسے آسانی مہیا کردیں گے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxvi{اور وہ جس نے بخل کیا اور بے پرواہ بنا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxvii{اور سب سے اچھی کو جھٹلایا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxviii{تو بہت جلد ہم اسے دشواری مہیا کردیں گے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxix{اور اس کا مال اسے کام نہ آئے گا جب ہلاکت میں پڑے گا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxx{بیشک ہدایت فرمانا ہمارے ذمہ ہے،\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxi{اور بیشک آخرت اور دنیا دونوں کے ہمیں مالک ہیں،\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxii{تو میں تمہیں ڈراتا ہوں اس آگ سے جو بھڑک رہی ہے،\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxiii{نہ جائے گا اس میں مگر بڑا بدبخت،\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxiv{جس نے جھٹلایا اور منہ پھیرا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxv{اور بہت اس سے دور رکھا جائے گا جو سب سے زیادہ پرہیزگار،\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxvi{جو اپنا مال دیتا ہے کہ ستھرا ہو\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxvii{اور کسی کا اس پر کچھ احسان نہیں جس کا بدلہ دیا جائے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxviii{صرف اپنے رب کی رضا چاہتا ہے جو سب سے بلند ہے،\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxix{اور بیشک قریب ہے کہ وہ راضی ہوگا\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxx{\basmalahur چاشت کی قسم\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxi{اور رات کی جب پردہ ڈالے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxii{کہ تمہیں تمہارے رب نے نہ چھوڑا، اور نہ مکروہ جانا،\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxiii{اور بیشک پچھلی تمہارے لیے پہلی سے بہتر ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxiv{اور بیشک قریب ہے کہ تمہارا رب تمہیں اتنا دے گا کہ تم راضی ہوجاؤ گے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxv{کیا اس نے تمہیں یتیم نہ پایا پھر جگہ دی\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxvi{اور تمہیں اپنی محبت میں خود رفتہ پایا تو اپنی طرف راہ دی\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxvii{اور تمہیں حاجت مند پایا پھر غنی کردیا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxviii{تو یتیم پر دباؤ نہ ڈالو\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxix{اور منگتا کو نہ جھڑکو\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxc{اور اپنے رب کی نعمت کا خوب چرچا کرو\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxci{\basmalahur کیا ہم نے تمہارا سینہ کشادہ نہ کیا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxcii{اور تم پر سے تمہارا بوجھ اتار لیا،\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxciii{جس نے تمہاری پیٹھ توڑی تھی\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxciv{اور ہم نے تمہارے لیے تمہارا ذکر بلند کردیا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxcv{تو بیشک دشواری کے ساتھ آسانی ہے،\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxcvi{بیشک دشواری کے ساتھ آسانی ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxcvii{تو جب تم نماز سے فارغ ہو تو دعا میں محنت کرو\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxcviii{اور اپنے رب ہی کی طرف رغبت کرو\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxcix{\basmalahur انجیر کی قسم اور زیتون\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmc{اور طور سینا\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmci{اور اس امان والے شہر کی\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcii{بیشک ہم نے آدمی کو اچھی صورت پر بنایا،\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmciii{پھر اسے ہر نیچی سے نیچی حالت کی طرف پھیردیا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmciv{مگر جو ایمان لائے اور اچھے کام کیے کہ انہیں بے حد ثواب ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcv{تو اب کیا چیز تجھے انصاف کے جھٹلانے پر باعث ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcvi{کیا اللہ سب حاکموں سے بڑھ کر حاکم نہیں،\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcvii{\basmalahur پڑھو اپنے رب کے نام سے جس نے پیدا کیا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcviii{آدمی کو خون کی پھٹک سے بنایا، پڑھو\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcix{اور تمہارا رب ہی سب سے بڑا کریم،\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcx{جس نے قلم سے لکھنا سکھایا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxi{آدمی کو سکھایا جو نہ جانتا تھا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxii{ہاں ہاں بیشک آدمی سرکشی کرتا ہے،\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxiii{اس پر کہ اپنے آپ کو غنی سمجھ لیا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxiv{بیشک تمہارے رب ہی کی طرف پھرنا ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxv{بھلا دیکھو تو جو منع کرتا ہے،\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxvi{بندے کو جب وہ نماز پڑھے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxvii{بھلا دیکھو تو اگر وہ ہدایت پر ہوتا،\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxviii{یا پرہیزگاری بتاتا تو کیا خوب تھا،\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxix{بھلا دیکھو تو اگر جھٹلایا اور منہ پھیرا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxx{تو کیا حال ہوگا کیا نہ جانا کہ اللہ دیکھ رہا ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxi{ہاں ہاں اگر باز نہ آیا تو ضرور ہم پیشانی کے بال پکڑ کر کھینچیں گے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxii{کیسی پیشانی جھوٹی خطاکار،\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxiii{اب پکارے اپنی مجلس کو\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxiv{ابھی ہم سپاہیوں کو بلاتے ہیں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxv{ہاں ہاں، اس کی نہ سنو اور سجدہ کرو اور ہم سے قریب ہوجاؤ، (السجدة ۔۱۴)\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxvi{\basmalahur بیشک ہم نے اسے شبِ قدر میں اتارا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxvii{اور تم نے کیا جانا کیا شبِ قدر،\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxviii{شبِ قدر ہزار مہینوں سے بہتر\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxix{اس میں فرشتے اور جبریل اترتے ہیں اپنے رب کے حکم سے ہر کام کے لیے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxx{وہ سلامتی ہے، صبح چمکتے تک\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxi{\basmalahur کتابی کافر اور مشرک اپنا دین چھوڑنے کو نہ تھے جب تک ان کے پاس روشن دلیل نہ آئے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxii{وہ کون وہ اللہ کا رسول کہ پاک صحیفے پڑھتا ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxiii{ان میں سیدھی باتیں لکھی ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxiv{اور پھوٹ نہ پڑی کتاب والوں میں مگر بعد اس کے کہ وہ روشن دلیل ان کے پاس تشریف لائے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxv{اور ان لوگوں کو تو یہی حکم ہوا کہ اللہ کی بندگی کریں نرے اسی پر عقیدہ لاتے ایک طرف کے ہوکر اور نماز قائم کریں اور زکوٰة دیں اور یہ سیدھا دین ہے،\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxvi{بیشک جتنے کافر ہیں کتابی اور مشرک سب جہنم کی آگ میں ہیں ہمیشہ اس میں رہیں گے، وہی تمام مخلوق میں بدتر ہیں،\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxvii{بیشک جو ایمان لائے اور اچھے کام کیے وہی تمام مخلوق ہیں بہتر ہیں،\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxviii{ان کا صلہ ان کے رب کے پاس بسنے کے باغ ہیں جن کے نیچے نہریں بہیں ان میں ہمیشہ ہمیشہ رہیں، اللہ ان سے راضی اور وہ اس سے راضی یہ اس کے لیے ہے جو اپنے رب سے ڈرے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxix{\basmalahur جب زمین تھرتھرا دی جائے جیسا اس کا تھرتھرانا ٹھہرا ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxl{اور زمین اپنے بوجھ باہر پھینک دے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxli{اور آدمی کہے اسے کیا ہوا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxlii{اس دن وہ اپنی خبریں بتائے گی\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxliii{اس لیے کہ تمہارے رب نے اسے حکم بھیجا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxliv{اس دن لوگ اپنے رب کی طرف پھریں گے کئی راہ ہوکر تاکہ اپنا کیا دکھائیں جائیں تو،\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxlv{جو ایک ذرہ بھر بھلائی کرے اسے دیکھے گا،\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxlvi{اور جو ایک ذرہ بھر برائی کرے اسے دیکھے گا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxlvii{\basmalahur قسم ان کی جو دوڑتے ہیں سینے سے آواز نکلتی ہوئی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxlviii{پھر پتھروں سے آگ نکالتے ہیں سم مارکر\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxlix{پھر صبح ہوتے تاراج کرتے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcl{پھر اس وقت غبار اڑاتے ہیں،\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcli{پھر دشمن کے بیچ لشکر میں جاتے ہیں،\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclii{بیشک آدمی اپنے رب کا بڑا ناشکرا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcliii{اور بیشک وہ اس پر خود گواہ ہے،\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcliv{اور بیشک وہ مال کی چاہت میں ضرور کرّا (تیز) ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclv{تو کیا نہیں جانتا جب اٹھائے جائیں گے جو قبروں میں ہیں،\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclvi{اور کھول دی جائے گی جو سینوں میں ہے،\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclvii{بیشک ان کے رب کو اس دن ان کی سب خبر ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclviii{\basmalahur دل دہلانے والی،\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclix{کیا وہ دہلانے والی،\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclx{اور تو نے کیا جانا کیا ہے دہلانے والی\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxi{جس دن آدمی ہوں گے جیسے پھیلے پتنگے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxii{اور پہاڑ ہوں گے جیسے دھنکی اون\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxiii{تو جس کی تولیں بھاری ہوئیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxiv{وہ تو من مانتے عیش میں ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxv{اور جس کی تولیں ہلکی پڑیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxvi{وہ نیچا دکھانے والی گود میں ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxvii{اور تو نے کیا جانا، کیا نیچا دکھانے والی،\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxviii{ایک آگ شعلے مارتی\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxix{\basmalahur تمہیں غافل رکھا مال کی زیادہ طلبی نے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxx{یہاں تک کہ تم نے قبروں کا منہ دیکھا\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxi{ہاں ہاں جلد جان جاؤ گے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxii{پھر ہاں ہاں جلد جان جاؤ گے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxiii{ہاں ہاں اگر یقین کا جاننا جانتے تو مال کی محبت نہ رکھتے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxiv{بیشک ضرور جنہم کو دیکھو گے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxv{پھر بیشک ضرور اسے یقینی دیکھنا دیکھو گے،\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxvi{پھر بیشک ضرور اس دن تم سے نعمتوں کی پرسش ہوگی\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxvii{\basmalahur اس زمانہ محبوب کی قسم\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxviii{بیشک آدمی ضرور نقصان میں ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxix{مگر جو ایمان لائے اور اچھے کام کیے اور ایک دورے کو حق کی تاکید کی اور ایک دوسرے کو صبر کی وصیت کی\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxx{\basmalahur خرابی ہے اس کے لیے جو لوگوں کے منہ پر عیب کرے پیٹھ پیچھے بدی کرے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxi{جس نے مال جوڑا اور گن گن کر رکھا،\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxii{کیا یہ سمجھتا ہے کہ اس کا مال اسے دنیا میں ہمیشہ رکھے گا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxiii{ہر گز نہیں ضرور وہ روندنے والی میں پھینکا جائے گا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxiv{اور تو نے کیا جانا کیا روندنے والی،\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxv{اللہ کی آگ کہ بھڑک رہی ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxvi{وہ جو دلوں پر چڑھ جائے گی\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxvii{بیشک وہ ان پر بند کردی جائے گی\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxviii{لمبے لمبے ستونوں میں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxix{\basmalahur اے محبوب! کیا تم نے نہ دیکھا تمہارے رب نے ان ہاتھی والوں کیا حال کیا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxc{کیا ان کا داؤ تباہی میں نہ ڈالا،\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxci{اور ان پر پرندوں کی ٹکڑیاں (فوجیں) بھیجیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxcii{کہ انہیں کنکر کے پتھروں سے مارتے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxciii{تو انہیں کر ڈالا جیسے کھائی کھیتی کی پتی (بھوسہ)\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxciv{\basmalahur اس لیے کہ قریش کو میل دلایا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxcv{ان کے جاڑے اور گرمی دونوں کے کوچ میں میل دلایا (رغبت دلائی)\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxcvi{تو انہیں چاہیے اس گھر کے رب کی بندگی کریں،\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxcvii{جس نے انہیں بھوک میں کھانا دیا، اور انہیں ایک بڑے خوف سے امان بخشا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxcviii{\basmalahur بھلا دیکھو تو جو دین کو جھٹلاتا ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxcix{پھر وہ وہ ہے جو یتیم کو دھکے دیتا ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcc{اور مسکین کو کھانا دینے کی رغبت نہیں دیتا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcci{تو ان نمازیوں کی خرابی ہے،\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccii{جو اپنی نماز سے بھولے بیٹھے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcciii{وہ جو دکھاوا کرتے ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcciv{اور بر تنے کی چیز مانگے نہیں دیتے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccv{\basmalahur اے محبوب! بیشک ہم نے تمہیں بے شمار خوبیاں عطا فرمائیں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccvi{تو تم اپنے رب کے لیے نماز پڑھو اور قربانی کرو\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccvii{بیشک جو تمہارا دشمن ہے وہی ہر خیر سے محروم ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccviii{\basmalahur تم فرماؤ اے کافرو،\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccix{نہ میں پوجتا ہوں جو تم پوجتے ہو،\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccx{اور نہ تم پوجتے ہو جو میں پوجتا ہوں،\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxi{اور نہ میں پوجوں گا جو تم نے پوجا،\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxii{اور نہ تم پوجو گے جو میں پوجتا ہوں،\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxiii{تمہیں تمہارا دین اور مجھے میرا دین\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxiv{\basmalahur جب اللہ کی مدد اور فتح آئے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxv{اور لوگوں کو تم دیکھو کہ اللہ کے دین میں فوج فوج داخل ہوتے ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxvi{تو اپنے رب کی ثناء کرتے ہوئے اس کی پاکی بولو اور اس سے بخشش چاہو بیشک وہ بہت توبہ قبول کرنے والا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxvii{\basmalahur تباہ ہوجائیں ابولہب کے دونوں ہاتھ اور وہ تباہ ہوہی گیا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxviii{اسے کچھ کام نہ آیا اس کا مال اور نہ جو کمایا\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxix{اب دھنستا ہے لپٹ مارتی آگ میں وہ،\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxx{اور اس کی جُورو لکڑیوں کا گٹھا سر پر اٹھاتی،\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxi{اس کے گلے میں کھجور کی چھال کا رسّا،\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxii{\basmalahur تم فرماؤ وہ اللہ ہے وہ ایک ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxiii{اللہ بے نیاز ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxiv{نہ اس کی کوئی اولاد اور نہ وہ کسی سے پیدا ہوا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxv{اور نہ اس کے جوڑ کا کوئی\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxvi{\basmalahur تم فرماؤ میں اس کی پناہ لیتا ہوں جو صبح کا پیدا کرنے والا ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxvii{اس کی سب مخلوق کی شر سے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxviii{اور اندھیری ڈالنے والے کے شر سے جب وہ ڈوبے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxix{اور ان عورتوں کے شر سے جو گرہوں میں پھونکتی ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxx{اور حسد والے کے شر سے جب وہ مجھ سے جلے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxxi{\basmalahur تم کہو میں اس کی پناہ میں آیا جو سب لوگوں کا رب\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxxii{سب لوگوں کا بادشاہ\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxxiii{سب لوگوں کا خدا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxxiv{اس کے شر سے جو دل میں برے خطرے ڈالے اور دبک رہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxxv{وہ جو لوگوں کے دلوں میں وسوسے ڈالتے ہیں،\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxxvi{جن اور آدمی\qt@no{(6)}}%
%% End of file `qurantext-urv.translation.def'.
